(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  13155168,     357720]*)
(*NotebookOutlinePosition[  13243814,     360450]*)
(*  CellTagsIndexPosition[  13232258,     360089]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["3. Introduction to Linear Partial Differential Equations", "Title",
  CellTags->"c:1"],

Cell["", "Text"],

Cell["\<\
\tIn this chapter we derive analytic solutions to some of the \
common linear partial differential equations (PDEs) of mathematical physics. \
We first examine PDEs in one spatial dimension, focusing on the wave equation \
and the heat equation.We then solve a PDE in more than one spatial dimension: \
 Laplace's equation.\
\>", "Text"],

Cell[TextData[{
  "\t  For the simple cases discussed in this chapter, we will find that \
solutions can be obtained in terms of Fourier series, using the ",
  StyleBox["method of separation of variables",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
3.1 Separation of Variables and Fourier Series Methods in Solutions \
of the Wave and Heat Equations\
\>", "Subtitle",
  CellTags->"c:3"],

Cell[" ", "Text"],

Cell[CellGroupData[{

Cell["3.1.1 Derivation of the Wave Equation", "Subsubtitle",
  CellTags->{"i:3", "c:4"}],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  CellTags->"c:5"],

Cell["\<\
\tThe first partial differential equation that we will discuss is \
the wave equation in one dimension. This equation describes (among other \
things) the transverse vibrations of a string under tension, such as a guitar \
or violin string. In the next two sub-subsections we will derive the wave \
equation for a string,  from first principles.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["String Equilibrium", "Section",
  CellTags->{"i:4", "c:6"}],

Cell[TextData[{
  "\tConsider a string, stretched tight in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction between posts at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ". (See Fig. ",
  ButtonBox["3.1",
    ButtonData:>"Fig. 3.1",
    ButtonStyle->"Hyperlink"],
  ".) The tension in the string at point ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  "is ",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\)]],
  ".  Tension is a force, and so has units of newtons.  The tension ",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\)]],
  " at point ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is defined as the force pulling on the piece of string to the left of \
point ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  " as it is acted on by  the string to the right of this point (see Fig. ",
  ButtonBox["3.1",
    ButtonData:>"Fig. 3.1",
    ButtonStyle->"Hyperlink"],
  ").  According to Newton's third law,  the force acting on the string to \
the right of point ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  " as it is pulled by the string on the left is ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\(T(x)\)\)\)]],
  ": the forces of the two sections acting on one another are equal and \
opposite.  Furthermore, tension always acts in the direction along the \
string. We will define positive tension forces as those acting to the right- \
in the positive ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:R0000kb000`400?l00000o`00003oo`3ooooo
0?oooj@0oooo003o0?ooool0ooooY03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo
003o0?ooool0ooooY03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0
ooooY03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool0
0?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool00?l0ooooo`3o
oonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool00?l0ooooo`3ooonT0?ooo`00
GP3oool20820P0030<30`03oool0oooo00P0oooo0P20P80Z0?ooo`<0P82000<0`<300?ooo`3oool0
o`3ooooo0?ooo`L0oooo001N0?ooo`@0000000<0`<300?ooo`3oool01@3oool01010@40000000000
0010@40V0?ooo`030<30`020P800000000D0000000<0@4100?ooo`3oool0o`3ooooo0?ooo`D0oooo
001N0?ooo`D000001`3oool5000002D0oooo0`0000001020P800oooo0?ooo`20P80300000?l0oooo
o`3oool60?ooo`00GP3oool2000000040410@020P80000000410@0D0oooo00L0P820000000000000
00000820P0000000@41002<0oooo00@0@410000000000000`<30103oool01@20P800000000000000
0000`<300?l0ooooo`3oool40?ooo`00GP3oool20820P0<0oooo00<0@4100000003oool00`3oool0
1010@40000000000000000020?ooo`030410@030`<00oooo0200oooo00@0`<30000000000000P820
1P3oool01030`<00000000000010@43o0?ooool0oooo103oool006<0oooo00<0P82000000020P800
0`3oool3000000050820P03oool0oooo0?ooo`20P8008@3oool3000000P0oooo0`0000000`20P800
oooo0?ooo`3o0?ooool0oooo0@3oool006@0oooo00<0P82000000030`<000P3oool3000000050820
P03oool0oooo0?ooo`20P800803oool01020P800000000000020P8080?ooo`040820P00000000000
0410@?l0ooooo`3oool30?ooo`00I@3oool00`20P800@4100?ooo`04000000030<30`03oool0oooo
0240oooo00D0`<3000000000000000000<30`0080?ooo`050<30`0000000000000000030`<00o`3o
ooma0?ooo`030<30`020P800P82000X0oooo00<0`<300820P03oool0P03oool006H0oooo00<00000
0?ooo`0000000`00000T0?ooo`040820P00000000000000000X0oooo0`0000000`20P800oooo0?oo
o`3o0?ooofl0oooo00@0P82000000000000000002@3oool300000200oooo5@0000000`20P800oooo
0?ooo`180?ooo`00IP3oool00`20P800@41000000003000002@0oooo00@0@4100000000000000000
2P3oool3000000030410@03oool0oooo0?l0ooooK`3oool01@20P8000000000000000000@41000L0
oooo100000000`10@400oooo0?ooo`0O0?ooo`030820P010@400000000<0000000<0@4100820P020
P8001P20P805000004X0oooo001W0?ooo`040410@00000000000000002D0oooo0`0000000`10@400
oooo0?ooo`080?ooo`@00000o`3oooma0?ooo`040820P000000000000820P080000000<0`<300?oo
o`3oool00P3oool01@20P8000000000000000000P8200080@4108P3oool4000000/0oooo00@0P820
0000000000000000B@3oool006L0oooo00@0P82000000000000000009@3oool3000000030820P03o
ool0oooo00T0oooo0`00003o0?ooog40oooo00<0P8200000003oool00P3oool2000000@0oooo00@0
P82000000000000000000P3oool00`000000oooo0?ooo`0P0?ooo`040820P00000000000000000`0
oooo00<0P820000000000000B@3oool006L0oooo0`0000000`10@400oooo0?ooo`0R0?ooo`050<30
`0000000000000000020P8002`3oool3000000030820P03oool0oooo0?l0ooooM03oool00`000000
`<300?ooo`020?ooo`<0000000D0@4100?ooo`3oool0`<300000000Q0?ooo`050820P00000000000
00000030`<00303oool00`10@40000000820P0180?ooo`00IP3oool01@30`<000000000000000000
P82000X0oooo600000020?ooo`050820P0000000000000000020P8002`3oool400000?l0ooooMP3o
ool00`30`<0000000820P0020?ooo`<0000000H0P8200?ooo`3oool0oooo0820P030`<0Q0?ooo`<0
000000<0P8200?ooo`3oool02`3oool00`000000@4100?ooo`170?ooo`00IP3oool00`20P8000000
00000002000000X0oooo600000020?ooo`050820P0000000000000000020P8002`3oool400000?l0
ooooM`3oool01020P80000000?ooo`20P803000000030820P03oool0oooo02@0oooo0`0000000`20
P800oooo0?ooo`0<0?ooo`030000003oool0oooo04H0oooo001V0?ooo`060820P000000000000000
0020P80000008`3oool01@20P8000000000000000000P82000/0oooo1000003o0?ooogL0oooo00@0
`<3000000020P800P8200`00000W0?ooo`040820P00000000000000000h0oooo00<0@4100<30`03o
ool0AP3oool006H0oooo0`0000001010@400oooo00000010@40R0?ooo`050820P000000000000000
0020P8002`3oool400000?l0ooooN@3oool00`000000@41000000002000002L0oooo00D0P8200000
0000000000000820P00>0?ooo`030<30`03oool0oooo04D0oooo001U0?ooo`050<30`00000000000
00000020P8000P3oool20410@080oooo0P20P8000`30`<00oooo0?ooo`0J0?ooo`050820P0000000
000000000020P8002`3oool400000?l0ooooN@3oool01@30`<000000000000000000P82002P0oooo
1000001F0?ooo`00I@3oool4000000040820P03oool0oooo0820P0H00000703oool01@20P8000000
000000000000P82000/0oooo1000003o0?ooogX0oooo0`0000000`20P800oooo0?ooo`0V0?ooo`@0
0000EP3oool00640oooo0`20P805000000@0oooo00<0@4100000000000000`00000L0?ooo`050820
P0000000000000000020P8002`3oool400000?l0ooooN@3oool01@20P8000000000000000000`<30
02T0oooo0`0000000`20P800oooo0?ooo`1C0?ooo`00H@3oool20820P0D000001P3oool01@20P800
0000000000000000@4100080oooo6020P8020?ooo`050<30`0000000000000000020P8002`3oool3
000000030820P03oool0oooo0?l0ooooM`3oool01010@400000000000000000:0?oooaP00000203o
ool3000000030410@03oool0oooo05<0oooo001V0?ooo`0300000020P800oooo00L0oooo0P000003
0?oooaP000000`3oool4000000/0oooo0`00003o0?ooogX0oooo100000000`20P800oooo0?ooo`07
0?oooaP00000203oool01020P800000000000000001E0?ooo`00M@3ooolH0820P0<0oooo1000000:
0?ooo`040820P0000000000000000?l0ooooNP3oool3000000030?ooo`000000oooo02P0oooo00@0
P8200000000000000000E@3oool00900oooo00@0@41000000000000000002P3oool3000000030410
@03oool0oooo0?l0ooooM`3oool3000000040410@03oool0P8200410@2T0oooo0`0000000`20P800
oooo0?ooo`1B0?ooo`00T03oool01020P800000000000000000:0?ooo`<0000000<0P8200?ooo`3o
ool0o`3ooomg0?ooo`<0000000<0P8200?ooo`3oool00P00000X0?ooo`<0000000<0P8200?ooo`3o
ool0DP3oool00900oooo00D0`<3000000000000000000820P0080?ooo`050<30`000000000000000
0030`<00o`3ooomh0?ooo`050410@0000000000000000020P8000P3oool01020P80000000410@020
P802000000030410@03oool0oooo0240oooo00@0@4100000000000000000E03oool00940oooo00@0
P820000000000000P820203oool01020P800000000000010@43o0?ooogD0oooo00@0`<300820P020
P800@410100000040?ooo`030820P0000000000000<000008`3oool01020P800000000000000001D
0?ooo`00TP3oool3000000P0oooo0`0000000`20P800oooo0?ooo`3o0?ooog<0oooo00<0P8200000
00000000100000000`20P800oooo0?ooo`030?ooo`030820P0000000000000800000903oool40000
05<0oooo002B0?ooo`040<30`000000000000820P0H0oooo00@0`<30000000000000@410o`3ooomh
0?ooo`<0P8200P0000000`30`<00oooo0?ooo`040?ooo`040820P000000000000<30`080oooo6000
000:0?ooo`@00000D`3oool009<0oooo00@0@410000000000000@4101@3oool01010@40000000000
0030`<3o0?ooohX0oooo6020P80:0?ooo`050820P0000000000000000020P800DP3oool009@0oooo
0`0000001020P800oooo0?ooo`20P80300000?l0oooo[`3oool3000000030820P03oool0oooo0500
oooo002E0?ooo`030820P0000000000000@0000000<0@4100<30`03oool0o`3ooon^0?ooo`040410
@000000000000410@580oooo002G0?ooo`040<30`020P800P8200820P?l0oooo/P3oool01020P800
000000000000001B0?ooo`00o`3ooooo0?ooodh0oooo00D0P82000000000000000000820P01A0?oo
o`00o`3ooooo0?ooodl0oooo0`0000000`20P800oooo0?ooo`1?0?ooo`00o`3ooooo0?ooodl0oooo
1000001A0?ooo`00o`3ooooo0?ooodl0oooo100000000`20P800oooo0?ooo`1>0?ooo`00o`3ooooo
0?ooodl0oooo1@0000000`20P800oooo0?ooo`1=0?ooo`00o`3ooooo0?oood`0oooo0P20P8000`10
@400000000000004000000030410@020P800P82004`0oooo003o0?ooool0ooooY03oool00?l0oooo
o`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool00?l0ooooo`3ooonT0?oo
o`00I@3oool01P3fm_H0jNWY0>KViP3Ogml0b<S80;6a/@80XZ:R00<0TY:B08:2PP22PX801`1cLg<4
0;Vi^Ol0oooo`P3oool02`3fm_H0jNWY0>KViP3Ogml0b<S80;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2
00H0Lg=c00<0UYJF0;Vi^@2i^KT00P2i^KT00`3Lg=`0oooo0?ooo`1=0?ooo`00HP3oool02@3kno/0
k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@020::RXP0309:BTP22PX80PX:200h0Lg=c0P2i
^KWo0?oookX0oooo00h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K40ZZZZ09ZJVP2B
TY80RXZ:08:2PPh0Lg=c00<0UYJF0=cLg03oool0BP3oool00640oooo00X0o_kn0?_kn`3^k^h0i>CT
0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0P2RXZ800`2BTY80PX:208:2PP0@07=cLol0oooo^P3oool0
3P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401c
Lg=;0?ooo`00H@3oool02P3no_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::R
XP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0o`3ooong0?ooo`0>0?Ogm`3^k^h0i>CT
0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0
oooo04P0oooo001Q0?ooo`0:0?knoP3kno/0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80
XZ:R00<0TY:B08:2PP22PX80401cLg<00`2i^KT0oooo0?ooo`3o0?oookL0oooo00h0moOg0>k^kP3T
i>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K40ZZZZ09ZJVP2BTY80RXZ:08:2PQ00Lg=c00<0^KVi0?oo
o`3oool0B03oool00640oooo00X0o_kn0?_kn`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a
0P2RXZ800`2BTY80PX:208:2PP0@07=cL`030;Vi^@3oool0oooo0?l0oooo]`3oool03P3gmoL0k^k^
0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0
oooo0?ooo`180?ooo`00H@3oool02P3no_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a
/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0T03oool200000?l0oooo9@3o
ool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2
401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<
c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0T03oool2
00000?l0oooo9@3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ
09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0no_k0>k^kP3T
i>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?oo
o`3oool0T03oool200000?l0oooo9@3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh
0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3n
o_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100
Lg=c00<0^KVi0?ooo`3oool0T03oool200000?l0oooo9@3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C
0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?oo
o`00H@3oool02P3no_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:B
TP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0T03oool200000?l0oooo9@3oool03P3gmoL0k^k^
0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0
oooo0?ooo`180?ooo`00H@3oool02P3no_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a
/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0T03oool200000?l0oooo9@3o
ool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2
401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<
c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0T03oool2
00000?l0oooo9@3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ
09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0no_k0>k^kP3T
i>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?oo
o`3oool0o`3ooong0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0:ZZZP2J
VYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:0?knoP3kno/0k^k^
0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX80401cLg<00`2i^KT0
oooo0?ooo`3o0?oookL0oooo00h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K40ZZZZ
09ZJVP2BTY80RXZ:08:2PQ00Lg=c00<0^KVi0?ooo`3oool0B03oool00640oooo00X0o_kn0?_kn`3^
k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0P2RXZ800`2BTY80PX:208:2PP0@07=cL`030;Vi
^@3oool0oooo0?l0oooo]`3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2Z
ZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0no_k
0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0
^KVi0?ooo`3oool0o`3ooong0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a
0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:0?knoP3k
no/0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX80401cLg<0
0`2i^KT0oooo0?ooo`3o0?oookL0oooo00h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a
/K40ZZZZ09ZJVP2BTY80RXZ:08:2PQ00Lg=c00<0^KVi0?ooo`3oool0B03oool00640oooo00X0o_kn
0?_kn`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0P2RXZ800`2BTY80PX:208:2PP0@07=c
L`030;Vi^@3oool0oooo0?l0oooo]`3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh
0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3n
o_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100
Lg=c00<0^KVi0?ooo`3oool0o`3ooong0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h
^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:
0?knoP3kno/0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX80
401cLg<00`2i^KT0oooo0?ooo`3o0?oookL0oooo00h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno
0;Rh^02a/K40ZZZZ09ZJVP2BTY80RXZ:08:2PQ00Lg=c00<0^KVi0?ooo`3oool0B03oool00640oooo
00X0o_kn0?_kn`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0P2RXZ800`2BTY80PX:208:2
PP0@07=cL`030;Vi^@3oool0oooo0?l0oooo]`3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o
_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3o
ool02P3no_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80
PX:20100Lg=c00<0^KVi0?ooo`3oool0o`3ooong0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<
0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q
0?ooo`0:0?knoP3kno/0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2
PP22PX80401cLg<00`2i^KT0oooo0?ooo`3o0?oookL0oooo00h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<
c<`0_kno0;Rh^02a/K40ZZZZ09ZJVP2BTY80RXZ:08:2PQ00Lg=c00<0^KVi0?ooo`3oool0B03oool0
0640oooo00X0o_kn0?_kn`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0P2RXZ800`2BTY80
PX:208:2PP0@07=cL`030;Vi^@3oool0oooo0?l0oooo]`3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C
0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?oo
o`00H@3oool02P3no_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:B
TP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0T03oool20820P?l0oooo9@3oool03P3gmoL0k^k^
0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0
oooo0?ooo`180?ooo`00H@3oool02P3no_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a
/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0T03oool200000?l0oooo9@3o
ool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2
401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<
c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0T03oool2
00000?l0oooo9@3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ
09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0no_k0>k^kP3T
i>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?oo
o`3oool0T03oool200000?l0oooo9@3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh
0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3n
o_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100
Lg=c00<0^KVi0?ooo`3oool0T03oool200000?l0oooo9@3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C
0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?oo
o`00H@3oool02P3no_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:B
TP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0T03oool200000?l0oooo9@3oool03P3gmoL0k^k^
0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0
oooo0?ooo`180?ooo`00H@3oool02P3no_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a
/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0T03oool200000?l0oooo9@3o
ool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2
401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<
c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0T03oool2
0820P?l0oooo9@3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ
09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0no_k0>k^kP3T
i>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?oo
o`3oool0o`3ooong0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0:ZZZP2J
VYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:0?knoP3kno/0k^k^
0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX80401cLg<00`2i^KT0
oooo0?ooo`3o0?oookL0oooo00h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K40ZZZZ
09ZJVP2BTY80RXZ:08:2PQ00Lg=c00<0^KVi0?ooo`3oool0B03oool00640oooo00X0o_kn0?_kn`3^
k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0P2RXZ800`2BTY80PX:208:2PP0@07=cL`030;Vi
^@3oool0oooo0?l0oooo]`3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2Z
ZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0no_k
0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0
^KVi0?ooo`3oool0o`3ooong0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a
0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:0?knoP3k
no/0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX80401cLg<0
0`2i^KT0oooo0?ooo`3o0?oookL0oooo00h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a
/K40ZZZZ09ZJVP2BTY80RXZ:08:2PQ00Lg=c00<0^KVi0?ooo`3oool0B03oool00640oooo00X0o_kn
0?_kn`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0P2RXZ800`2BTY80PX:208:2PP0@07=c
L`030;Vi^@3oool0oooo0?l0oooo]`3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh
0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3n
o_h0no_k0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100
Lg=c00<0^KVi0?ooo`3oool0o`3ooong0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h
^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:
0?knoP3kno/0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX80
401cLg<00`2i^KT0oooo0?ooo`3o0?oookL0oooo00h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno
0;Rh^02a/K40ZZZZ09ZJVP2BTY80RXZ:08:2PQ00Lg=c00<0^KVi0?ooo`3oool0B03oool00640oooo
00X0o_kn0?Win@3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0P2RXZ800`2BTY80PX:208:2
PP0@07=cL`030;Vi^@3oool0oooo0?l0oooo]`3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o
_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3o
ool02P3no_h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80
PX:20100Lg=c00<0^KVi0?ooo`3oool0o`3ooong0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<
0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q
0?ooo`0:0?knoP3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2
PP22PX80401cLg<00`2i^KT0oooo0?ooo`3o0?oookL0oooo00h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<
c<`0_kno0;Rh^02a/K40ZZZZ09ZJVP2BTY80RXZ:08:2PQ00Lg=c00<0^KVi0?ooo`3oool0B03oool0
0640oooo00X0o_kn0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0P2RXZ800`2BTY80
PX:208:2PP0@07=cL`030;Vi^@3oool0oooo0?l0oooo]`3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C
0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?oo
o`00H@3oool02P3no_h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:B
TP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0T03oool200000?l0oooo9@3oool03P3gmoL0k^k^
0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0
oooo0?ooo`180?ooo`00H@3oool02P3no_h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a
/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0T03oool200000?l0oooo9@3o
ool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2
401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<
c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0T03oool2
00000?l0oooo9@3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ
09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0moOg0>k^kP3T
i>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:200l0Lg=c00<0>SXj05eM
G@20P800T@20P80200000?l0P8209@20P8003P1lO7`0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh
0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3n
o_h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:200l0
Lg=co`00002l0000000=0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K40ZZZZ09ZJVP2BTY80
RXZ:08:2PP0@07=cL`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:0?knoP3gmoL0k^k^0>CTi03O
gml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX803`1cLg?o00000;`0000000d0
k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:20100Lg=c00<0
^KVi0?ooo`3oool0B03oool00640oooo00X0o_kn0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h
^;P0/K6a0P2RXZ800`2BTY80PX:208:2PP0?07=cLol00000_00000003@3^k^h0i>CT0=oOg`3Cdm<0
c<c<0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX80401cLg<00`2i^KT0oooo0?ooo`180?oo
o`00H@3oool02P3no_h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:B
TP22PX80PX:200l0Lg=co`00002l0000000=0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K40
ZZZZ09ZJVP2BTY80RXZ:08:2PP0@07=cL`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:0?knoP3g
moL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX803`1cLg?o
00000;`0000000d0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0
PX:20100Lg=c00<0^KVi0?ooo`3oool0B03oool00640oooo00X0o_kn0?Ogm`3^k^h0i>CT0=oOg`3C
dm<0c<c<0;no_`2h^;P0/K6a0P2RXZ800`2BTY80PX:208:2PP0?07=cLol00000_00000003@3^k^h0
i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX80401cLg<00`2i^KT0
oooo0?ooo`180?ooo`00H@3oool02P3no_h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a
/K420::RXP0309:BTP22PX80PX:200l0Lg=c00<0>SXj05eMG@20P800o`20P82h0820P00>07alO03^
k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi
^@3oool0oooo04P0oooo001Q0?ooo`0:0?knoP3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh
0;6a/@80XZ:R00<0TY:B08:2PP22PX80401cLg<00`2i^KT0oooo0?ooo`3o0?oookL0oooo00h0moOg
0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K40ZZZZ09ZJVP2BTY80RXZ:08:2PQ00Lg=c00<0
^KVi0?ooo`3oool0B03oool00640oooo00X0o_kn0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h
^;P0/K6a0P2RXZ800`2BTY80PX:208:2PP0@07=cL`030;Vi^@3oool0oooo0?l0oooo]`3oool03P3g
moL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<0
0`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno
0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0o`3ooong0?ooo`0>
0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=c
L`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:0?knoP3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o
_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX80401cLg<00`2i^KT0oooo0?ooo`3o0?oookL0oooo
00h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K40ZZZZ09ZJVP2BTY80RXZ:08:2PQ00
Lg=c00<0^KVi0?ooo`3oool0B03oool00640oooo00X0o_kn0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<
0;no_`2h^;P0/K6a0P2RXZ800`2BTY80PX:208:2PP0@07=cL`030;Vi^@3oool0oooo0?l0oooo]`3o
ool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2
401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<
c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0o`3ooong
0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22
PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:0?knoP3gmoL0k^k^0>CTi03Ogml0dm?C
0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX80401cLg<00`2i^KT0oooo0?ooo`3o0?oo
okL0oooo00h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K40ZZZZ09ZJVP2BTY80RXZ:
08:2PQ00Lg=c00<0^KVi0?ooo`3oool0B03oool00640oooo00X0o_kn0?Ogm`3^k^h0i>CT0=oOg`3C
dm<0c<c<0;no_`2h^;P0/K6a0P2RXZ800`2BTY80PX:208:2PP0@07=cL`030;Vi^@3oool0oooo0?l0
oooo]`3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:
RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?ooo`00H@3oool02P3no_h0moOg0>k^kP3Ti>@0gmoO
0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0
o`3ooong0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B
08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:0?knoP3gmoL0k^k^0>CTi03O
gml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX80401cLg<00`2i^KT0oooo0?oo
o`2@0?ooo`800000o`3ooolU0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a
0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:0?knoP3g
moL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX80401cLg<0
0`2i^KT0oooo0?ooo`2@0?ooo`800000o`3ooolU0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<
0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q
0?ooo`0:0?knoP3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2
PP22PX80401cLg<00`2i^KT0oooo0?ooo`2@0?ooo`800000o`3ooolU0?ooo`0>0?Ogm`3^k^h0i>CT
0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0
oooo04P0oooo001Q0?ooo`0:0?knoP3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80
XZ:R00<0TY:B08:2PP22PX80401cLg<00`2i^KT0oooo0?ooo`2@0?ooo`800000o`3ooolU0?ooo`0>
0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=c
L`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:0?knoP3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o
_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX80401cLg<00`2i^KT0oooo0?ooo`2@0?ooo`800000
o`3ooolU0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B
08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:0?knoP3gmoL0k^k^0>CTi03O
gml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX80401cLg<00`2i^KT0oooo0?oo
o`2@0?ooo`800000o`3ooolU0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a
0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q0?ooo`0:0?knoP3g
moL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2PP22PX80401cLg<0
0`2i^KT0oooo0?ooo`2@0?ooo`800000o`3ooolU0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<
0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0oooo001Q
0?ooo`0:0?knoP3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0TY:B08:2
PP22PX80401cLg<00`2i^KT0oooo0?ooo`3o0?oookL0oooo00h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<
c<`0_kno0;Rh^02a/K40ZZZZ09ZJVP2BTY80RXZ:08:2PQ00Lg=c00<0^KVi0?ooo`3oool0B03oool0
0640oooo00X0o_kn0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0P2RXZ800`2BTY80
PX:208:2PP0@07=cL`030;Vi^@3oool0oooo0?l0oooo]`3oool03P3gmoL0k^k^0>CTi03Ogml0dm?C
0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?ooo`180?oo
o`00H@3oool02P3no_h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::RXP0309:B
TP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0o`3ooong0?ooo`0>0?Ogm`3^k^h0i>CT0=oOg`3C
dm<0c<c<0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0oooo04P0
oooo001Q0?ooo`0:0?knoP3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80XZ:R00<0
TY:B08:2PP22PX80401cLg<00`2i^KT0oooo0?ooo`3o0?oookL0oooo00h0moOg0>k^kP3Ti>@0gmoO
0=?Cd`3<c<`0_kno0;Rh^02a/K40ZZZZ09ZJVP2BTY80RXZ:08:2PQ00Lg=c00<0^KVi0?ooo`3oool0
B03oool00640oooo00X0o_kn0?Ogm`3^k^h0i>CT0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0P2RXZ80
0`2BTY80PX:208:2PP0@07=cL`030;Vi^@3oool0oooo0?l0oooo]`3oool03P3gmoL0k^k^0>CTi03O
gml0dm?C0<c<c02o_kl0^;Rh0;6a/@2ZZZX0VYZJ09:BTP2:RXX0PX:2401cLg<00`2i^KT0oooo0?oo
o`180?ooo`00H@3oool02P3no_h0moOg0>k^kP3Ti>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K420::R
XP0309:BTP22PX80PX:20100Lg=c00<0^KVi0?ooo`3oool0o`3ooong0?ooo`0>0?Ogm`3^k^h0i>CT
0=oOg`3Cdm<0c<c<0;no_`2h^;P0/K6a0:ZZZP2JVYX0TY:B08Z:RP22PX8@07=cL`030;Vi^@3oool0
oooo04P0oooo001Q0?ooo`0:0?knoP3gmoL0k^k^0>CTi03Ogml0dm?C0<c<c02o_kl0^;Rh0;6a/@80
XZ:R00<0TY:B08:2PP22PX80401cLg<00`2i^KT0oooo0?ooo`3o0?oookL0oooo00h0moOg0>k^kP3T
i>@0gmoO0=?Cd`3<c<`0_kno0;Rh^02a/K40ZZZZ09ZJVP2BTY80RXZ:08:2PQ00Lg=c00<0^KVi0?oo
o`3oool0B03oool00640oooo00X0o_kn0?Ogm`3^k^h0i>CT0<G5a@2SXj<0X:2P09VIV@2FUYH0TY:B
0P2;Rh/C07=cL`030;Vi^@3oool0oooo0?l0oooo]`3oool02`3gmoL0k^k^0>CTi035aLD0Xj>S0:2P
X02IVIT0UYJF09:BTP2?Shl0Ogmo01<0Lg=c00<0^KVi0?ooo`3oool0B03oool00600oooo00<0g=cL
0;Vi^@1cLg<07@1cLg<00`2i^KT0oooo0?ooo`3o0?oookH0oooo00<0^KVi07=cL`1cLg<0701cLg<0
0`2i^KT0oooo0?ooo`180?ooo`00H03ooolP07=cL`030;Vi^@3oool0oooo0?l0oooo]@3ooolP07=c
L`030;Vi^@3oool0oooo04P0oooo001P0?ooo`0309JFUP1cLg<0Lg=c01`0Lg=c00<0UYJF0=cLg03o
ool0o`3ooonf0?ooo`030;Vi^@1cLg<0Lg=c01`0Lg=c00<0UYJF0=cLg03oool0B@3oool00680oooo
00<0g=cL0;Vi^@1cLg<05`1cLg<00`2FUYH0^KVi0?ooo`3o0?oook/0oooo0P2i^KTH07=cL`0309JF
UP2i^KT0g=cL04`0oooo001Y0?ooo`030;Vi^@1cLg<0Lg=c00X0Lg=c00<0^KVi0?ooo`3oool0o`3o
ooo80?ooo`030;Vi^@1cLg<0Lg=c00X0Lg=c00<0^KVi0?ooo`3oool0DP3oool00?l0oooo503oool2
00000?l0ooooSP3oool00?l0oooo503oool200000?l0ooooSP3oool00?l0oooo503oool200000?l0
ooooSP3oool00?l0oooo503oool200000?l0ooooSP3oool00?l0oooo503oool200000?l0ooooSP3o
ool00?l0oooo503oool200000?l0ooooSP3oool00?l0oooo503oool200000?l0ooooSP3oool00?l0
ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool00?l0ooooo`3ooonT
0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool00?l0ooooo`3ooonT0?ooo`00o`3o
oooo0?oooj@0oooo003o0?ooool0ooooY03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0
oooo003o0?ooool0ooooY03oool00?l0oooo503oool20820P?l0ooooSP3oool00?l0oooo503oool2
00000?l0ooooSP3oool00?l0oooo503oool200000?l0ooooSP3oool00?l0oooo503oool200000?l0
ooooSP3oool00?l0oooo503oool200000?l0ooooSP3oool00?l0oooo503oool200000?l0ooooSP3o
ool00?l0oooo503oool200000?l0ooooSP3oool00?l0oooo503oool200000?l0ooooSP3oool00?l0
ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool00?l0ooooo`3ooonT
0?ooo`00o`3ooooo0?oooj@0oooo001j0?ooo`030<30`03oool0oooo01D0oooo00<0`<300?ooo`3o
ool0o`3ooooo0?ooo`l0oooo001h0?ooo`030820P010@400oooo01P0oooo00<0@4100<30`03oool0
o`3ooooo0?ooo`h0oooo001g0?ooo`8000006`3oool00`20P80000000?ooo`3o0?ooool0oooo3@3o
ool007H0oooo0P10@40M0?ooo`030820P010@400oooo0?l0oooo5P3oool20820P1L0oooo00<0`<30
0820P030`<00f@3oool007D0oooo0P10@40O0?ooo`030820P010@400oooo0?l0oooo4`3oool00`30
`<00@4100820P00J0?ooo`80P820f03oool007@0oooo0P00000Q0?ooo`800000o`3ooolC0?ooo`03
00000020P800oooo01/0oooo00<0P8200000003oool0eP3oool007<0oooo00<0@41000000010@400
8@3oool00`20P80000000410@03o0?oooa00oooo00<0`<3000000010@4007P3oool00`20P800@410
0?ooo`3E0?ooo`00LP3oool01030`<00000000000030`<0R0?ooo`80000000<0`<300?ooo`3oool0
o`3oool<0?ooo`030<30`0000000P8200200oooo0P10@43E0?ooo`00LP3oool2000000030820P03o
ool0oooo0280oooo0P00003o0?ooo`d0oooo00<0`<3000000010@4008P3oool2000000030<30`03o
ool0oooo0=40oooo001a0?ooo`<000009@3oool3000002d0oooo00<000000820P03oool0SP3oool0
0`000000oooo0?ooo`1:0?ooo`030820P0000000P8200280oooo00<0P82000000020P800d`3oool0
05H0oooo3020P8000`30`<00oooo0?ooo`0;0?ooo`040<30`000000000000410@0P0oooo0P000000
0`20P800`<300?ooo`070?ooo`030820P0000000@41000h0oooo00@0P820000000000000`<309`3o
ool00`30`<00P8200410@002000000030<30`03oool0oooo08h0oooo00D0`<300410@0000000@410
0820P0170?ooo`030820P0000000000002<0oooo00@0`<30000000000000`<30dP3oool005P0oooo
00<0`<300410@0000000100000000`30`<00oooo0?ooo`0>0?ooo`040410@000000000000820P0P0
oooo100000000`30`<00oooo0?ooo`040?ooo`030820P000000000000080000000<0`<300?ooo`3o
ool02P3oool01020P800000000000010@40S0?ooo`030<30`020P800P82000@0000000<0`<300?oo
o`3oool0TP3oool00`20P800000000000002000000030410@020P800oooo0440oooo00@0`<300000
00000000P820903oool2000000030410@03oool0oooo0=00oooo001J0?ooo`@000004P3oool30000
00030820P03oool0oooo00H0oooo1@0000060?ooo`H000003@3oool300000240oooo00<0P8200000
000000001@0000000`20P800oooo0?ooo`2D0?ooo`030820P0000000000000D00000@03oool01020
P800000000000020P8070?ooo`80000000<0P8200?ooo`3oool0203oool2000000l0oooo0P00003B
0?ooo`00FP3oool01010@400000000000000000A0?ooo`040<30`00000000000000000T0oooo00L0
00000410@03oool0`<300410@0000000`<3000@0oooo0`0000001020P800oooo0410@020P80<0?oo
o`<0000000<0P8200?ooo`3oool06`3oool20820P0L0000000<0@4100820P03oool0U`3oool00`30
`<00000000000006000000030820P030`<00oooo0200oooo00<0`<300820P010@4001`0000030820
P0h0oooo0`0000080?ooo`@0000000<0`<300?ooo`3oool01@3oool01010@400000000000010@40>
0?ooo`<00000d@3oool005X0oooo00<0`<300000000000000P00000@0?ooo`040820P00000000000
000000h0oooo00<000000410@03oool00P3oool01@20P8000000000000000000`<300080oooo00<0
@4100?ooo`3oool02P3oool3000000030410@03oool0oooo01L0oooo0P20P8000`10@40000000000
0007000000030410@03oool0oooo09T0oooo00<0`<30000000000000200000000`10@400P8200820
P00Q0?ooo`050410@0000000000000000010@4004@3oool01020P80000000000000000080?ooo`D0
000000<0`<300?ooo`3oool00`3oool00`30`<00000000000003000000030<30`03oool0oooo00X0
oooo00@0@410000000000000P820d03oool005/0oooo1000000@0?ooo`@000003`3oool01@000000
P8200?ooo`3oool0P82000<000000`3oool00`20P80000000?ooo`0:0?ooo`@000005P3oool00`20
P80000000000000<000009h0oooo3P00000O0?ooo`050820P0000000000000000020P8004@3oool0
1020P800000000000020P8080?ooo`80000000@0P8200?ooo`00000000001@3oool01@20P8000000
000000000000oooo00800000303oool01020P800000000000000003@0?ooo`00F`3oool01@20P800
0000000000000000`<3000l0oooo0`0000000`10@400oooo0?ooo`0=0?ooo`050<30`0000000oooo
0?ooo`10@4000`00000@0?ooo`040820P0000000000000000180oooo00<0`<300820P00000003P00
00000`10@400oooo0?ooo`2M0?ooo`030<30`0000000000000d0000000<0@4100820P03oool06`3o
ool3000000030410@03oool0oooo00l0oooo0`0000000`20P800oooo0?ooo`060?ooo`80P8200`3o
ool00`10@400P8200?ooo`030?ooo`040410@0000000000000000080oooo00<0@4100<30`03oool0
2P3oool01020P800000000000000003@0?ooo`00G03oool3000000030820P03oool0oooo00d0oooo
0`0000000`20P800oooo0?ooo`0>0?ooo`030410@020P800oooo00<0000000<0P8200?ooo`3oool0
3P3oool01@20P8000000000000000000P82000h0oooo00<0`<300820P010@4004@0000000`30`<00
oooo0?ooo`2N0?ooo`030820P000000000000100000000<0P8200?ooo`3oool05`3oool01020P800
000000000000000@0?ooo`050820P0000000000000000020P8003@3oool00`30`<0000000820P003
0?ooo`<0000000D0P8200?ooo`3oool0oooo0410@00;0?ooo`050820P0000000000000000020P800
c`3oool005`0oooo1000000>0?ooo`@0000000<0P8200?ooo`3oool03`3oool00`000000oooo0000
0002000000030820P03oool0oooo00h0oooo00<0P8200000000000000P00000=0?oooaD00000XP3o
oolE000001L0oooo00@0P8200000000000000000403oool4000000030820P03oool0oooo00`0oooo
00<0P82000000020P8000P3oool3000000030820P03oool0oooo00h0oooo0`0000000`20P800oooo
0?ooo`3=0?ooo`00A03oool<0820P0`0oooo00@0P82000000000000000003P3oool4000000030820
P03oool0oooo00l0oooo00<0@4100000000000000P0000000`30`<00oooo0?ooo`0>0?ooo`030820
P00000000000008000002@3oool20820P1H0000000<0P8200?ooo`3oool0X03oool00`20P8000000
0000000D00000080P820503oool4000000l0oooo1000000@0?ooo`0300000010@400oooo00@00000
00<0`<300?ooo`3oool03P3oool3000000030820P03oool0oooo0<d0oooo00140?ooo`030820P000
0000000000T0000000<0`<300?ooo`3oool02@3oool01@30`<000000000000000000`<3000d0oooo
100000000`20P800oooo0?ooo`0@0?ooo`@000004@3oool00`20P800000000000002000000D0oooo
00<0`<300820P0000000600000000`20P800oooo0?ooo`2R0?ooo`030410@0000000000001L00000
00<0P8200?ooo`3oool03`3oool4000000030<30`03oool0oooo00/0oooo00<0`<30000000000000
0P00000A0?ooo`030410@030`<00000000<000004@3oool400000<l0oooo00150?ooo`/0000000<0
P8200?ooo`3oool02P3oool3000000030820P03oool0oooo00/0oooo100000000`20P800oooo0?oo
o`0?0?ooo`030820P00000000000008000004@3oool00`20P800000000000002000000@0oooo00<0
P820000000000000I@00000=0?ooo`030820P0000000000006D000004@3oool3000000030820P03o
ool0oooo00/0oooo00<0P8200000000000000P00000A0?ooo`030820P0000000000000<000004@3o
ool400000<l0oooo00150?ooo`/0000000<0P8200?ooo`3oool02P3oool3000000030410@03oool0
oooo00/0oooo100000000`20P800oooo0?ooo`0?0?ooo`040820P0000000000000000180oooo00<0
P8200000000000000P0000000`3oool0`<300410@01Y000000d0oooo00<0P820000000000000I`00
00000`20P800oooo0?ooo`0<0?ooo`<0000000<0P8200?ooo`3oool02`3oool00`20P80000000000
000200000180oooo00@0@41000000000000000004P3oool400000<l0oooo001M0?ooo`040820P000
00000000000000d0oooo100000000`20P800oooo0?ooo`0?0?ooo`@0000000<0P8200?ooo`3oool0
3`3oool00`20P800000000000002000000<0oooo0P20P8000`10@40000000000000H000004`0P820
3@3oool00`30`<00P8200820P0190820P0030410@0000000000001P000000P20P8000`30`<00oooo
0?ooo`0=0?ooo`040820P00000000000000000d0oooo00<0P8200000000000000P00000B0?ooo`04
0410@0000000000000000180oooo1000003?0?ooo`00G@3oool01020P800000000000000000=0?oo
o`@0000000<0P8200?ooo`3oool03`3oool3000000030820P0000000P8200100oooo00<0P8200000
000000000P0000070?ooo`030820P0000000000001L00000Y03oool00`20P80000000000000F0000
01@0oooo00@0P82000000000000000003@3oool00`20P80000000000000200000180oooo0`000000
0`20P800oooo0?ooo`0@0?ooo`@00000c`3oool005h0oooo1000000<0?ooo`@0000000<0P8200?oo
o`3oool03P3oool01030`<0000000000000000020820P0030410@03oool0oooo00h0oooo00D0P820
00000000000000000820P00:0?ooo`030820P010@400000001@0000000<0`<300?ooo`3oool0X03o
ool00`20P80000000000000C00000080P8205P3oool01@30`<000000000000000000P82000`0oooo
00<0P8200000000000000P00000A0?ooo`050<30`0000000000000000020P8004P3oool400000<l0
oooo001N0?ooo`@0000000<0`<300?ooo`3oool02P3oool3000000030820P03oool0oooo00h0oooo
00@0P82000000000000000000P3oool20410@0l0oooo00@0P82000000000000000003`3oool20820
P1800000X@3oool00`30`<0000000000000@00000080P8206`3oool3000000030820P03oool0oooo
00X0oooo00<0P8200000000000000P00000A0?ooo`060820P0000000000000000010@400P8204@3o
ool400000<l0oooo001O0?ooo`<0000000<0P8200?ooo`3oool02P3oool3000000030410@03oool0
oooo00d0oooo00<0`<300000000000000P0000030?ooo`80000000D0P8200410@000000000000<30
`0090?ooo`@000004P3oool00`30`<00P8200820P00>000000030410@03oool0oooo09d0oooo00<0
`<300000000000003@0000020820P1l0oooo00@0P8200000000000000000303oool00`20P8000000
0000000200000140oooo00L0@41000000000000000000<30`0000000`<300100oooo0`0000000`10
@400oooo0?ooo`3=0?ooo`00G`3oool3000000030820P03oool0oooo00X0oooo1000000?0?ooo`@0
000000D0P8200?ooo`3oool0oooo0820P005000000030820P03oool0oooo00L0oooo0`0000000`20
P800oooo0?ooo`0D0?ooo`030820P0000000000000`00000WP3oool>000002<0oooo00@0P8200000
0000000000003@3oool400000140oooo0`0000001020P800oooo00000000000@0?ooo`<0000000<0
P8200?ooo`3oool0c@3oool005l0oooo00@0P8200000000000000000303oool01020P80000000000
0000000<0?ooo`L0000000<0`<300?ooo`3oool00P3oool00`20P800000000000002000000030820
P03oool0oooo00L0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`80P8202P0000000`10@400oooo
0?ooo`2I0?ooo`030<30`0000000000000T000000P20P80U0?ooo`030<30`0000000000000800000
303oool400000100oooo00D0P82000000000000000000820P0020?ooo`80@4100P3oool20820P003
0<30`03oool0oooo00L0oooo00D0`<3000000000000000000820P03?0?ooo`00G`3oool01@20P800
0000000000000000`<3000/0oooo00@0`<3000000000000000003@3oool01P30`<00P8200820P010
@40000000820P0H0oooo00@0`<300410@0000000@4102@3oool01@30`<000000000000000000`<30
01d0oooo0P20P807000000030410@020P800oooo09L0oooo00<0`<300000000000001P0000000`20
P800`<300?ooo`0Y0?ooo`@00000303oool4000000030820P03oool0oooo00`0oooo00<0@4100000
000000000P0000001030`<00oooo0?ooo`30`<06000000T0oooo00D0P82000000000000000000<30
`03?0?ooo`00H03oool3000000030820P03oool0oooo00X0oooo0`0000000`20P800oooo0?ooo`0S
0?ooo`040820P0000000000000000240oooo00<0P8200000000000001@0000000`20P800oooo0?oo
o`2D0?ooo`030820P0000000000000D00000;`3oool3000000030820P03oool0oooo00X0oooo0`00
00000`20P800oooo0?ooo`090?ooo`P00000103oool00`20P800000000000003000000T0oooo00@0
P8200000000000000000d03oool00600oooo0`0000000`20P800oooo0?ooo`0:0?ooo`040820P000
000000000820P2D0oooo00@0P820000000000000P820903oool20820P0@0000000<0`<300?ooo`3o
ool0TP3oool00`20P800000000000002000000030820P030`<00oooo0300oooo0`0000000`20P800
oooo0?ooo`0:0?ooo`<0000000<0P8200?ooo`3oool02@3oool20820P0D000001P3oool01@20P800
0000000000000000@41000T0oooo00@0P8200000000000000000d03oool005H0oooo00<0`<300?oo
o`3oool01`3oool01020P80000000000000000090?ooo`040<30`03oool0oooo0?ooo`80000000<0
@4100?ooo`3oool08`3oool00`10@40000000000000Y0?ooo`80P8200P0000000`30`<00oooo0?oo
o`2>0?ooo`050<30`010@40000000820P030`<00=@3oool01010@400000000000000000<0?ooo`04
0820P000000000000410@100oooo00<0P8200<30`03oool01`3oool20820P0X0oooo0`0000000`20
P800oooo0?ooo`3>0?ooo`00E`3oool00`000000oooo0?ooo`060?ooo`040820P000000000000000
00T0oooo00<0P8200?ooo`3oool00P3oool2000002D0oooo0P00000^0?ooo`80P820S`3oool00`20
P800oooo0?ooo`0g0?ooo`040820P00000000000000000d0oooo0`00000V0?ooo`<00000d@3oool0
05L0oooo00<000000<30`03oool01P3oool00`30`<00000000000002000000P0oooo00<0P8200?oo
o`3oool00P3oool00`10@40000000820P00S0?ooo`80000000<0@4100?ooo`3oool0m`3oool01@30
`<000000000000000000`<3000`0oooo00<0@4100000000000009P3oool2000000030820P03oool0
oooo0<l0oooo001H0?ooo`030410@03oool0oooo00H0oooo100000000`30`<00oooo0?ooo`050?oo
o`030820P0000000oooo00<0oooo0P0000000`30`<00oooo0?ooo`0O0?ooo`030<30`00000000000
0?40oooo00<0P8200?ooo`3oool01`3oool3000000030820P03oool0oooo00H0oooo0P30`<020?oo
o`040<30`000000000000820P2@0oooo0P0000000`10@400oooo0?ooo`3@0?ooo`00F03oool00`00
0000oooo0?ooo`070?ooo`<0000000<0P8200?ooo`3oool01@3oool00`20P80000000?ooo`030?oo
o`030820P0000000P8200240oooo0P0000000`20P800oooo0?ooo`3_0?ooo`030820P03oool0oooo
00L0oooo100000090?ooo`040820P03oool0oooo0?ooo`80000000<0P8200?ooo`3oool08@3oool0
1020P800000000000020P83B0?ooo`00F03oool20410@0030<30`03oool0oooo00D0oooo0`000000
0`20P800oooo0?ooo`050?ooo`030410@0000000P82000@0oooo00<0P82000000030`<007`3oool0
0`30`<0000000820P03b0?ooo`030<30`020P800oooo00L0oooo00@0P82000000000000000002@3o
ool00`10@400oooo0?ooo`020?ooo`030410@0000000oooo0280oooo00<0P82000000010@400d`3o
ool005P0oooo00<0P8200000000000000P20P8000`30`<00oooo0?ooo`020?ooo`040410@0000000
0000000000H0oooo00@0P820000000000000P8201@3oool00`30`<00@4100?ooo`0M0?ooo`030820
P0000000`<300?@0oooo00<000000?ooo`3oool01P3oool01@30`<000000000000000000P82000P0
oooo00<000000?ooo`3oool00P3oool00`30`<0000000820P00Q0?ooo`040<30`000000000000<30
`=<0oooo001I0?oooaL000001P3oool20820P1`0oooo00<0P82000000020P800m@3oool2000000P0
oooo0`0000000`20P800oooo0?ooo`060?ooo`800000103oool00`20P80000000?ooo`0P0?ooo`03
0820P0000000oooo0=@0oooo001I0?oooaL0P8201`3oool20820P0030<30`03oool0oooo01L0oooo
00<0`<300410@020P800mP3oool01020P800000000000030`<060?ooo`<0000000<0@4100?ooo`3o
ool01@3oool00`20P8000000000000050?ooo`030410@0000000oooo01h0oooo00<0P82000000030
`<00e@3oool007T0oooo00<0P8200<30`03oool05P3oool00`30`<00P8200?ooo`3g0?ooo`030<30
`0000000000000<000001@20P803000000H0P820100000000`30`<00oooo0?ooo`030?ooo`030820
P010@400oooo01`0oooo00<0@41000000030`<00eP3oool00?l0ooooSP3ooolG000000030820P03o
ool0oooo00@0oooo0P20P80K0?ooo`030820P0000000oooo0=L0oooo003o0?ooojd0oooo00<0`<30
00000030`<00603oool00`20P800@4100?ooo`3H0?ooo`00o`3ooon_0?ooo`030<30`03oool0oooo
01D0oooo00<0`<300?ooo`3oool0f@3oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo
003o0?ooool0ooooY03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0
ooooY03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool0
0?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool00?l0ooooo`3o
oonT0?ooo`00o`3ooooo0?oooj@0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{197.25, 70},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 3.1 Equilibrium of a string.", "Caption",
  CellTags->"Fig. 3.1"],

Cell[TextData[{
  "\tThe string in Fig. ",
  ButtonBox["3.1",
    ButtonData:>"Fig. 3.1",
    ButtonStyle->"Hyperlink"],
  " is in equilibrium. In equilibrium, in the absence of gravity or other \
such external forces, the tension in the string is uniform, and the string is \
perfectly straight. This can be understood from the following argument. \
Consider an element of the string with mass ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]m\)],
    CellOpen->False],
  " and length ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[DifferentialD]x\)\(\ \)\)\)]],
  ", running from ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x + \[DifferentialD]x\)]],
  " . If the string is straight, but the tension in the string is a function \
of position, then the tension pulling the element to the right is ",
  Cell[BoxData[
      \(TraditionalForm\`T(x + \[DifferentialD]x)\)]],
  " and that pulling the element to the left is ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\(T(x)\)\)\)]],
  " (see Fig. ",
  ButtonBox["3.2",
    ButtonData:>"Fig. 3.2",
    ButtonStyle->"Hyperlink"],
  "). However, in equilibrium, the total force on ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]m\)]],
  " must vanish, so ",
  Cell[BoxData[
      \(TraditionalForm\`T(x + \[DifferentialD]x) - T(x) = 0\)]],
  ", and therefore ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " must be independent of position in equilibrium. Also, since we have \
achieved force balance with a straight string, we have shown that a straight \
string is in equilibrium."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P0001FB000`400?l00000o`00003oo`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3o
oooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0
ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3o
ool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0
ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oood80oooo1000000@0?ooo`<00000?P3o
ool400000100oooo0`0000120?ooo`@000003@3oool3000000P0oooo0`00000@0?ooo`<00000o`3o
oom00?ooo`00o`3ooom20?ooo`H000003@3oool5000003d0oooo1P00000=0?ooo`D00000?`3oool8
000000X0oooo1P0000060?ooo`D000003@3oool00`20P80000000000000200000?l0oooo?`3oool0
0?l0oooo@P3oool7000000/0oooo2000000k0?ooo`H0000000<0P8200?ooo`3oool02@3oool70000
03d0oooo2`0000070?ooo`P000001@3oool6000000`0oooo1`00003o0?ooocd0oooo003o0?oood80
oooo200000000`30`<00oooo0?ooo`060?ooo`030<30`0000000000000L00000>P3oool700000003
0820P03oool0oooo00L0oooo00<0P8200000000000001P00000j0?ooo`030820P0000000000000/0
000000<0`<300?ooo`3oool00`3oool5000000<0P82000<000000820P03oool00P3oool700000003
0820P03oool0oooo00L0oooo00<0P8200000000000001P00003o0?oooc`0oooo003o0?oood80oooo
100000020?ooo`<00000203oool00`20P800000000000003000000<0oooo00<000000820P03oool0
>03oool400000080oooo0`0000080?ooo`H000000P3oool2000003T0oooo1`0000050?ooo`<00000
1@3oool5000000@0oooo0P0000020?ooo`<000000P3oool4000000P0oooo1@0000030?ooo`800000
o`3ooolk0?ooo`00o`3ooom20?ooo`<000001@3oool2000000L0oooo00<0P8200000000000000`00
00040?ooo`030000003oool0oooo03L0oooo0`0000040?ooo`<000001`3oool6000000<0oooo0P00
000g0?ooo`L000001`3oool3000000D0oooo1@0000040?ooo`80000000<0oooo0000000000001@3o
ool2000000030820P03oool0oooo00D0oooo1@0000040?ooo`0300000020P800oooo0?l0oooo>@3o
ool00?l0ooooBP3oool2000000L0oooo1P0000040?ooo`030820P0000000oooo03h0oooo0`000006
0?ooo`L00000103oool2000001/0oooo0P00000I0?ooo`H0000000<0P8200?ooo`3oool01P3oool0
0`20P8000000000000040?ooo`D00000103oool2000000P0oooo0P0000000`20P800oooo0?ooo`04
0?ooo`H000001@3oool00`000000oooo0?ooo`3o0?ooocP0oooo003o0?ooodX0oooo00<0P8200000
000000001P3oool6000000@0oooo00<0P8200000003oool0?`3oool3000000D0oooo1`0000040?oo
o`8000006`3oool2000001T0oooo1P0000000`20P800oooo0?ooo`070?ooo`<000000`3oool50000
00D0oooo00<000000?ooo`3oool01`3oool2000000H0oooo1P0000050?ooo`030000003oool0oooo
0?l0oooo>03oool00?l0ooooB`3oool3000000D0oooo1@0000060?ooo`800000@03oool3000000@0
oooo1P0000060?ooo`8000006P3oool2000001T0oooo1P00000;0?ooo`<000000P3oool500000100
oooo0P0000050?ooo`D000001P3oool00`20P80000000?ooo`3o0?ooocP0oooo003o0?oood`0oooo
0P0000050?ooo`D00000B@3oool2000000@0oooo1P00000R0?ooo`8000006@3oool6000000`0oooo
0`0000020?ooo`D000003`3oool00`20P80000000?ooo`040?ooo`D00000o`3ooom10?ooo`00o`3o
oom=0?ooo`8000000`3oool6000004X0oooo0P0000020?ooo`030820P0000000000000@000008P3o
ool2000001T0oooo1P00000=0?ooo`<0000000<0oooo0000000000000`00000@0?ooo`8000000`3o
ool600000?l0oooo@@3oool00?l0ooooC@3oool300000080oooo1@00001;0?ooo`<0000000<0oooo
0820P00000001000000S0?ooo`8000006@3oool6000000d0oooo0`0000000`3oool0000000000003
00000100oooo0`0000020?ooo`D00000o`3ooom20?ooo`00o`3ooom>0?ooo`040820P0000000P820
0?ooo`D00000C03oool01020P80000000820P020P805000002<0oooo0P00000I0?ooo`030820P000
0000000000<000003P3oool01020P800000000000020P804000000030820P03oool0oooo00h0oooo
00@0P82000000020P800oooo1@00003o0?oood80oooo003o0?ooodl0oooo0P0000000`3oool00000
00000003000004d0oooo0P0000000`20P800000000000003000002<0oooo0P00000J0?ooo`D00000
00<0P8200?ooo`3oool03@3oool700000140oooo0P0000000`3oool000000000000300000?l0oooo
@P3oool00?l0ooooD03oool6000004l0oooo1P00000T0?ooo`8000006P3oool5000000030820P03o
ool0oooo00d0oooo1`00000B0?ooo`H00000o`3ooom30?ooo`00o`3ooom@0?ooo`H00000C`3oool6
000002@0oooo0P00000J0?ooo`D0000000<0P8200?ooo`3oool03P3oool700000140oooo1P00003o
0?oood<0oooo003o0?oooe40oooo1@00001@0?ooo`D00000903oool2000001/0oooo1@00000@0?oo
o`L000004P3oool500000?l0oooo@`3oool00?l0ooooD03oool6000004l0oooo1P00000T0?ooo`80
00006`3oool500000140oooo1P00000A0?ooo`H00000o`3ooom30?ooo`00o`3ooom@0?ooo`D00000
D03oool5000002D0oooo0P00000L0?ooo`@000004@3oool600000140oooo1@0000000`20P800oooo
0?ooo`3o0?oood40oooo003o0?oooe00oooo1@00001@0?ooo`D000009@3oool2000001`0oooo1@00
000@0?ooo`030820P0000000000000@00000403oool5000000030820P03oool0oooo0?l0oooo@@3o
ool00?l0ooooD03oool500000500oooo1@00000U0?ooo`8000007@3oool400000100oooo00<0P820
0000000000001000000@0?ooo`D0000000<0P8200?ooo`3oool0o`3ooom10?ooo`00o`3ooom?0?oo
o`L00000CP3oool7000002@0oooo0P00000N0?ooo`@0000000<0P8200?ooo`3oool03@3oool60000
00030820P03oool0oooo00`0oooo1`00003o0?oood<0oooo003o0?ooodl0oooo1@0000000`3oool0
00000000001=0?ooo`D0000000<0oooo0000000000008`3oool2000001l0oooo1000000?0?ooo`L0
00003P3oool6000000030820P0000000oooo0?l0oooo@@3oool00?l0ooooC`3oool5000000040?oo
o`0000000000000004`0oooo1@000000103oool0000000000000000A0?ooob@000003P3oool00`20
P800000000000002000000l0oooo1P00000>0?ooo`H0000000<0P820000000000000o`3ooom10?oo
o`00o`3ooom>0?ooo`H000000P3oool2000004/0oooo1P0000020?ooo`8000004@3ooolT000000l0
oooo1@00000>0?ooo`H000003@3oool7000000030?ooo`00000000000?l0oooo@@3oool00?l0oooo
CP3oool5000000030820P03oool0oooo00<00000BP3oool5000000<0oooo0`00000Q0?ooo`800000
803oool5000000h0oooo1`00000<0?ooo`H000000P3oool300000?l0oooo@03oool00?l0ooooCP3o
ool5000000040820P03oool0oooo0?ooo`<00000B@3oool5000000@0oooo0`00000P0?ooo`800000
8@3oool5000000d0oooo1`00000<0?ooo`H000000`3oool300000?l0oooo?`3oool00?l0ooooC@3o
ool6000000030820P03oool0oooo0080oooo0`0000030?ooo`@00000@03oool6000000D0oooo0P00
00001020P800oooo0?ooo`3oool4000001P0oooo0P00000R0?ooo`D00000303oool7000000/0oooo
1`0000040?ooo`<000000`3oool01020P800000000000000003o0?ooocL0oooo003o0?oood`0oooo
1`0000060?ooo`X00000?P3oool6000000L0oooo2P00000G0?ooo`800000903oool4000000/0oooo
200000090?ooo`030820P0000000000000@000001P3oool:00000?l0oooo=P3oool00?l0ooooBP3o
ool00`20P800000000000006000000H0oooo2P00000l0?ooo`P000001`3oool:000001L0oooo0P00
000U0?ooo`<0000000<0P8200?ooo`3oool01`3oool9000000P0oooo200000060?ooo`X00000o`3o
oolf0?ooo`00o`3ooom60?ooo``0000000<0P8200?ooo`3oool01@3oool00`20P800000000000006
000003P0oooo2`0000000`10@400oooo0?ooo`060?ooo`030410@0000000000000H000005`3oool2
000002H0oooo0P20P80200000080P8201@3oool01010@400000000000020P806000000030<30`03o
ool0oooo00`0000000<0P8200?ooo`3oool01@3oool00`20P80000000000000600000?l0oooo=P3o
ool00?l0ooooB@3oool8000000`0oooo1@00000k0?ooo`030820P0000000000000H000002`3oool6
000001P0oooo0P00000Y0?ooo`X000000`3oool5000000030820P03oool0oooo00<0oooo2000000<
0?ooo`D00000o`3ooolg0?ooo`00o`3ooom=0?ooo`<000003@3oool01020P8000000000000000011
0?ooo`<000003@3oool4000001T0oooo0P00000/0?ooo`D0000000<0P8200?ooo`3oool00P3oool5
000000030820P03oool0oooo00L0oooo0`00000>0?ooo`<00000o`3ooolh0?ooo`00o`3oooo?0?oo
o`800000=P3oool5000000030820P03oool0oooo0?l0ooooD`3oool00?l0ooooc`3oool2000003L0
oooo1@00003o0?oooeD0oooo003o0?oooll0oooo0P00000g0?ooo`D00000o`3ooomE0?ooo`00o`3o
ooo?0?ooo`800000=`3oool500000?l0ooooE@3oool00?l0ooooc`3oool2000003L0oooo1P00003o
0?oooe@0oooo003o0?oooll0oooo0P00000h0?ooo`D00000o`3ooomD0?ooo`00o`3oooo?0?ooo`80
0000>03oool500000?l0ooooE03oool00?l0ooooc`3oool2000003P0oooo00<0P820000000000000
0P0000000`20P800oooo0?ooo`3o0?oooe40oooo003o0?oooll0oooo0P00000i0?ooo`D00000o`3o
oomC0?ooo`00o`3ooooo0?ooo`/0oooo1@00003o0?oooe<0oooo003o0?ooool0oooo2`3oool60000
0?l0ooooDP3oool00?l0ooooo`3oool<0?ooo`D00000o`3ooomB0?ooo`00o`3ooooo0?ooo``0oooo
1@00003o0?oooe80oooo003o0?ooool0oooo303oool500000?l0ooooDP3oool00?l0ooooo`3oool<
0?ooo`H00000o`3ooomA0?ooo`00o`3ooooo0?ooo``0oooo1P00003o0?oooe40oooo003o0?ooool0
oooo1`3oool30820P0P0000000<0P8200?ooo`3oool0o`3ooom>0?ooo`00o`3ooooo0?oooa00oooo
0`00003o0?oooe00oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool0
0?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooomE0?ooo`D00000
C03oool400000?l0oooo^03oool00?l0ooooE@3oool5000004`0oooo1000003o0?oookP0oooo003o
0?oooeD0oooo1@00001<0?ooo`@00000o`3ooonh0?ooo`00o`3ooomE0?ooo`D00000C03oool40000
0?l0oooo^03oool00?l0ooooE@3oool5000004`0oooo1000003o0?oookP0oooo003o0?oooeD0oooo
1@00001<0?ooo`@00000o`3ooonh0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo^03o
ool00?l0ooooE@3oool5000004`0oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00001<0?oo
o`@00000o`3ooonh0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo^03oool00?l0oooo
E@3oool5000004`0oooo1000003o0?oookP0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo
^03oool00?l0ooooE@3oool5000004`0oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00001<
0?ooo`@00000o`3ooonh0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo^03oool00?l0
ooooE@3oool5000004`0oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00001<0?ooo`@00000
o`3ooonh0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo^03oool00?l0ooooE@3oool5
000004`0oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00001<0?ooo`@00000o`3ooonh0?oo
o`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo^03oool00?l0ooooE@3oool5000004`0oooo
1000003o0?oookP0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool0
0?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0oooo
H`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?oo
ool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3o
oooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?oo
o`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3o
oomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oooeD0
oooo1@00001<0?ooo`@00000o`3ooonh0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo
^03oool00?l0ooooE@3oool5000004`0oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00001<
0?ooo`@00000o`3ooonh0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo^03oool00740
ooooo`00003o000001T00000f03oool00740ooooo`00003o000001T00000f03oool00740ooooo`00
003o000001T00000f03oool00740ooooo`00003o000001T00000f03oool00740ooooo`00003o0000
01T00000f03oool00740ooooo`00003o000001T00000f03oool00740ooooo`00003o000001T00000
f03oool00740ooooo`00003o000001T00000f03oool00740ooooo`00003o000001T00000f03oool0
0740ooooo`00003o000001T00000f03oool00740ooooo`00003o000001T00000f03oool00?l0oooo
o`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool0
0?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0oooo
H`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?oo
ool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3o
oooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?oo
o`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooE@3oool5000004`0oooo1000003o0?oookP0oooo
003o0?oooeD0oooo1@00001<0?ooo`@00000o`3ooonh0?ooo`00o`3ooomE0?ooo`D00000C03oool4
00000?l0oooo^03oool00?l0ooooE@3oool5000004`0oooo1000003o0?oookP0oooo003o0?oooeD0
oooo1@00001<0?ooo`@00000o`3ooonh0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo
^03oool00?l0ooooE@3oool5000004`0oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00001<
0?ooo`@00000o`3ooonh0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo^03oool00?l0
ooooE@3oool5000004`0oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00001<0?ooo`@00000
o`3ooonh0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3o
oooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0
ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3o
ool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0
ooooH`3oool00?l0ooooE@3oool5000004`0oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00
001<0?ooo`@00000o`3ooonh0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo^03oool0
0?l0ooooE@3oool5000004`0oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00001<0?ooo`@0
0000o`3ooonh0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo^03oool00?l0ooooE@3o
ool5000004`0oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00001<0?ooo`@00000o`3ooonh
0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo^03oool00?l0ooooE@3oool5000004`0
oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00001<0?ooo`@00000o`3ooonh0?ooo`00o`3o
oooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?oo
o`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3o
oomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0
ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o
0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0
oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo
0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0
oooo^03oool00?l0ooooE@3oool5000004`0oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00
001<0?ooo`@00000o`3ooonh0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo^03oool0
0?l0ooooE@3oool5000004`0oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00001<0?ooo`@0
0000o`3ooonh0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo^03oool00?l0ooooE@3o
ool5000004`0oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00001<0?ooo`@00000o`3ooonh
0?ooo`00o`3ooomE0?ooo`D00000C03oool400000?l0oooo^03oool00?l0ooooE@3oool5000004`0
oooo1000003o0?oookP0oooo003o0?oooeD0oooo1@00001<0?ooo`@00000o`3ooonh0?ooo`00o`3o
oooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?oo
o`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3o
oomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0
ooooo`3ooomS0?ooo`00J`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo
o`3oooo@0?ooo`00J@3oool2000002D0oooo00<000000820P03oool0o`3ooooo0?oooll0oooo001X
0?ooo`8000009`3oool200000?l0ooooo`3oooo?0?ooo`00IP3oool3000002P0oooo00<0P8200000
00000000o`3ooooo0?ooolh0oooo001U0?ooo`<00000:`3oool200000?l0ooooo`3oool70?ooo`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool0:`3oool006<0oooo00@0P820000000000000
P820;@3oool3000000030820P03oool0oooo0?l0oooooP3oool00`20P80000000820P02I0?ooo`04
0820P0000000P8200820P2T0oooo001R0?ooo`<00000<03oool400000?l0ooooo@3oool00`20P800
00000000002M0?ooo`<00000:03oool00680oooo0P00000b0?ooo`@00000o`3ooool0?ooo`800000
X03oool2000002L0oooo001Q0?ooo`<00000<`3oool300000?l0oooon`3oool200000:80oooo0`00
000U0?ooo`00H03oool3000000030820P03oool0oooo0340oooo0`0000000`20P800oooo0?ooo`3o
0?ooooH0oooo0`0000000`20P800oooo0?ooo`2P0?ooo`<0000000<0P8200?ooo`3oool08P3oool0
05l0oooo100000000`20P800oooo0?ooo`0b0?ooo`<00000o`3oooog0?ooo`@00000Y03oool30000
02@0oooo001N0?ooo`D00000=@3oool400000?l0oooomP3oool300000:H0oooo0`00000S0?ooo`00
GP3oool5000003D0oooo1000003o0?ooooD0oooo1000002W0?ooo`8000008`3oool005d0oooo1@00
000g0?ooo`@00000AP3oool200000?l0ooooZ`3oool400000:P0oooo0`00000R0?ooo`00G03oool0
0`20P800000000000003000000X0oooo00@0`<300820P020P800P820403oool30820P1H0oooo00<0
P8200000000000000P00000n0?ooo`<0P8201@0000000`30`<00oooo0?ooo`3o0?oooc00oooo00<0
P82000000020P8000`20P81a0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0YP3o
ool01@20P8000000000000000000P8200200oooo000b0?oooaD0000000<0P8200?ooo`3oool04@3o
ool6000000/0oooo00<0P8200000000000000`00000=0?ooo`D000005P3oool5000003/0oooo2000
003o0?ooocP0oooo1@00001_0?ooo`D00000Z@3oool00`20P80000000000000200000200oooo000f
0?ooo``000006@3oool6000000/0oooo00<0P8200000000000001000000;0?ooo`030820P0000000
000000D00000503oool5000003L0oooo2`00003o0?ooocX0oooo2000001Z0?ooo`030820P0000000
000000800000Z`3oool5000001l0oooo000h0?ooo`T000006P3oool6000000/0oooo00<0P8200000
000000001@00000:0?ooo`030820P0000000000000H000004`3oool6000003<0oooo3@00003o0?oo
oc`0oooo2P00001W0?ooo`030820P0000000000000800000Z`3oool6000001h0oooo000i0?ooo`L0
00006P3oool00`20P800000000000004000000/0oooo00<0P8200000000000001P0000090?ooo`T0
00004`3oool00`20P80000000000000300000340oooo3P00003o0?oooch0oooo3000001T0?ooo`D0
00002P3oool3000000030820P03oool0oooo00h0oooo0P0000130?ooo`D00000303oool4000000L0
oooo1000000@0?ooo`<000005P3oool5000001h0oooo000i0?ooo`L000006P3oool00`20P8000000
00000003000000`0oooo00@0P82000000000000000000P3oool3000000030820P03oool0oooo00H0
oooo1@0000030?ooo`8000004P3oool00`20P800000000000003000002h0oooo4000003o0?oood00
oooo00<0P8200000000000003000000d0?oooaH000005@3oool5000000/0oooo1@00000>0?ooo`@0
0000@03oool8000000030820P03oool0oooo00L0oooo1`0000050?ooo`H000003@3oool5000001D0
oooo1P00000M0?ooo`00>P3oool6000001X0oooo1P00000<0?ooo`030820P0000000000000D0oooo
0P0000080?ooo`D00000103oool00`000000P8200?ooo`0@0?ooo`030820P0000000000000@00000
:P3ooolA00000?l0oooo@`3ooolA000000030820P03oool0oooo03<0oooo2`0000000`20P800oooo
0?ooo`0H0?ooo`D000002`3oool6000000`0oooo1`00000m0?ooo`030820P0000000000000P00000
1`3oool00`20P800000000000006000000@0oooo1P0000000`20P800oooo0?ooo`090?ooo`L00000
503oool6000001d0oooo000j0?ooo`L000006@3oool6000001@0oooo0P0000070?ooo`H000001@3o
ool00`000000oooo0?ooo`0?0?ooo`030820P0000000000000@000009`3oool00`20P80000000000
000@000000030820P03oool0oooo0?l0oooo@P3ooolC000003D0oooo2@00000K0?ooo`D000002`3o
ool7000000/0oooo2000000l0?ooo``000001P3oool00`20P800000000000007000000<0oooo1`00
000;0?ooo`P000004`3oool7000001`0oooo000k0?ooo`H000006@3oool6000001D0oooo0P000006
0?ooo`H000001@3oool00`000000oooo0?ooo`0?0?ooo`030820P0000000000000@000009@3ooolE
00000?l0ooooAP3ooolE00000380oooo00<0P8200000000000001@00000K0?ooo`H000002`3oool8
000000T0oooo2@00000k0?ooo`h000001@3oool00`20P800000000000003000000<0oooo00@00000
0820P03oool0oooo200000090?ooo`T00000503oool6000001`0oooo000k0?ooo`H00000603oool7
000001D0oooo00<0`<300000000000001@3oool5000000H0oooo00<0`<300820P03oool03`3oool0
0`20P800000000000005000001h0oooo0`20P80F000000030820P03oool0oooo0?l0ooooAP3oool0
0`20P80000000000000D00000080P820;@3oool00`30`<00000000000005000001X0oooo00<0P820
0000000000000`00000<0?ooo`<0000000@0`<300?ooo`20P800P8200P0000000`20P800oooo0?oo
o`050?ooo`D000000`3oool00`20P80000000820P00h0?ooo`030820P0000000000000@0000000<0
P8200?ooo`3oool00P3oool01@20P8000000000000000000P82000<0oooo00<0`<30000000000000
0`0000001`20P800oooo0?ooo`3oool0@4100820P03oool00`0000001020P800oooo0?ooo`20P802
000000030820P03oool0oooo00D0oooo1P0000020?ooo`030820P0000000P8200180oooo1P000000
0`30`<00oooo0?ooo`0I0?ooo`00>`3oool7000001L0oooo1`00000G0?ooo`8000000`3oool60000
01T0oooo1`00000L0?oooaX00000o`3ooom<0?oooaX00000:`3oool8000001T0oooo1P00000C0?oo
o`<000001P3oool6000000D0oooo0P00000L0?ooo`0300000020P800oooo01P0oooo1P0000090?oo
o`<000000`3oool6000000<0oooo00<0P8200000003oool01`3oool3000000H0oooo1`0000040?oo
o`8000004@3oool6000000030820P03oool0oooo01T0oooo000l0?ooo`H000005`3oool6000001P0
oooo0`0000020?ooo`D000006P3oool7000001T0oooo7000003o0?ooodh0oooo7000000Y0?ooo`L0
00006@3oool6000001@0oooo0`0000050?ooo`H000001@3oool2000001`0oooo00<000000820P03o
ool0603oool6000000X0oooo0`0000020?ooo`H00000103oool00`000000oooo0?ooo`070?ooo`<0
00001@3oool7000000@0oooo0P00000A0?ooo`H0000000<0P8200?ooo`3oool06@3oool003`0oooo
1P00000G0?ooo`H000006@3oool200000080oooo1@00000J0?ooo`L000005P3ooolN00000?l0oooo
D03ooolM000000030820P03oool0oooo02@0oooo1`00000H0?ooo`L000005@3oool3000000@0oooo
1@0000000`20P800oooo0?ooo`040?ooo`8000006`3oool00`000000P8200?ooo`0H0?ooo`D00000
303oool3000000030?ooo`000000000000@000003`3oool3000000@0oooo1P0000060?ooo`800000
403oool7000001/0oooo000l0?ooo`L000005@3oool7000001X0oooo0P0000000`3oool000000000
0003000001X0oooo2000000C0?oooal00000o`3ooomB0?oooal00000903oool7000001P0oooo1`00
000F0?ooo`800000103oool5000000030820P03oool0oooo0240oooo00<000000820P03oool0603o
ool5000000d0oooo0P0000000`20P800oooo00000005000000l0oooo0P0000040?ooo`H00000603o
ool7000001/0oooo000m0?ooo`H000005@3oool7000001X0oooo0P0000000`3oool0000000000003
000001X0oooo2000000@0?ooob800000o`3ooomB0?ooo`030820P0000000000001l000008@3oool7
000000030820P03oool0oooo01D0oooo1`00000G0?ooo`0400000020P800oooo0?ooo`H0000000<0
P8200?ooo`3oool08@3oool00`000000P8200?ooo`0H0?ooo`D000003P3oool2000000030?ooo`00
0000000000@00000403oool200000080oooo00<0P8200000000000001000000I0?ooo`H000006`3o
ool001L0oooo4`00000C0?ooo`H000005@3oool7000001/0oooo1P00000K0?ooo`P000003@3ooolU
00000?l0ooooDP3oool00`20P80000000000000R000001l0oooo1P0000000`20P800oooo0?ooo`0E
0?ooo`H00000603oool200000080oooo1P00000T0?ooo`0300000020P800oooo01P0oooo1@00000>
0?ooo`80000000<0oooo0000000000001000000@0?ooo`<0000000<0oooo0820P00000001000000J
0?ooo`H000006`3oool001L0oooo4`00000C0?ooo`H000005@3oool7000001/0oooo1P00000K0?oo
o`P000002P3ooolW00000?l0ooooE03ooolV000001d0oooo1P0000000`20P800oooo0?ooo`0E0?oo
o`H000006@3oool00`000000oooo0?ooo`06000002@0oooo00<000000820P03oool0603oool50000
00l0oooo0P0000000`3oool000000000000300000140oooo0P0000000`3oool0P820000000040000
01X0oooo1P00000K0?ooo`00603ooolC00000180oooo1`00000D0?ooo`L00000703oool5000001/0
oooo200000070?ooobX00000o`3ooomD0?ooobX000006@3oool7000001H0oooo1`00000I0?ooo`03
0820P0000000oooo00H00000903oool00`000000P8200?ooo`0I0?ooo`@000003`3oool00`20P800
00000000000600000140oooo0P0000000`20P800000000000003000001X0oooo1`00000J0?ooo`00
603ooolC000001<0oooo1P00000D0?ooo`L000006`3oool6000001/0oooo200000040?oooj800000
J@3ooonR000001L0oooo1P00000F0?ooo`L000006@3oool00`20P80000000?ooo`06000002@0oooo
00<000000820P03oool06@3oool5000000l0oooo2000000A0?ooo`80000000<0P820000000000000
0`00000J0?ooo`L000006P3oool001P0oooo00<0P8200000000000004000000C0?ooo`H0000000<0
P8200?ooo`3oool04@3oool7000001/0oooo1@00000L0?ooo`P000000P3oool20820P:800000J@3o
oonQ00000080P8205P3oool6000001H0oooo1`00000J0?ooo`L000009@3oool00`000000P8200?oo
o`0I0?ooo`D000003`3oool00`20P800000000000005000000030820P03oool0oooo00l0oooo1P00
000K0?ooo`L000006P3oool003h0oooo00<0P8200000000000001000000C0?ooo`L000006`3oool5
000001`0oooo200000080?oooih00000J@3ooonM000001`0oooo1`00000E0?ooo`L000006`3oool6
000002D0oooo00<000000820P03oool06P3oool5000000l0oooo2000000B0?ooo`D000006`3oool7
000001X0oooo000n0?ooo`030820P0000000000000@000004`3oool7000001X0oooo1`00000K0?oo
o`P000002P3oool00`20P80000000000000T00000?l0ooooD`3oool00`20P80000000000000S0000
0200oooo1P00000E0?ooo`L000006P3oool7000002D0oooo00<000000820P03oool06P3oool50000
0100oooo1`00000A0?ooo`H000006`3oool7000001X0oooo000n0?ooo`030820P0000000000000@0
00004`3oool7000001X0oooo1`00000K0?ooo`P000003@3ooolU00000?l0ooooDP3oool00`20P800
00000000000Q00000280oooo1P00000E0?ooo`L000006P3oool6000002H0oooo00<000000820P03o
ool06P3oool00`20P80000000000000200000100oooo1`00000A0?ooo`D00000703oool7000001X0
oooo000n0?ooo`030820P0000000000000D000004P3oool7000001X0oooo1@0000000`20P8000000
0000000J0?ooo`P000004@3ooolQ00000?l0ooooDP3ooolQ000002D0oooo1`00000D0?ooo`L00000
6P3oool6000002H0oooo00<000000820P03oool06P3oool00`20P80000000000000300000100oooo
1P0000000`20P800oooo0?ooo`0>0?ooo`D00000703oool7000001X0oooo000o0?ooo`L000004P3o
ool7000001X0oooo1@0000001020P800000000000000000I0?ooo`P000004`3oool00`20P8000000
0000000M00000?l0ooooD03ooolN000002X0oooo1P00000D0?ooo`L000006P3oool6000002H0oooo
00<000000820P03oool06`3oool500000100oooo1P0000000`20P800oooo0?ooo`0>0?ooo`D00000
703oool7000001X0oooo000o0?ooo`L000004`3oool6000001T0oooo1P0000001020P800oooo0000
0000000I0?ooo`L000005`3ooolN00000?l0ooooCP3ooolM000002`0oooo1P00000D0?ooo`L00000
6@3oool00`20P800000000000005000002D0oooo00<000000820P03oool0703oool500000100oooo
1@0000000`20P800oooo0?ooo`0=0?ooo`L000006`3oool7000001X0oooo000o0?ooo`L000004`3o
ool6000001T0oooo1P0000020?ooo`<00000603oool7000001/0oooo6P00003o0?ooodd0oooo6`00
000_0?ooo`H00000503oool7000001T0oooo00<0P8200000000000001@00000U0?ooo`0300000020
P800oooo01`0oooo1P00000?0?ooo`H000003`3oool7000001/0oooo1`00000J0?ooo`00@03oool7
00000180oooo1P00000I0?ooo`H000000`3oool3000001H0oooo00<0P8200000000000001@00000M
0?ooo`030820P0000000000001H00000o`3ooom;0?oooaT00000<P3oool7000001<0oooo1`00000I
0?ooo`030820P0000000000000<0000000<0oooo000000000000903oool00`000000P8200?ooo`0M
0?ooo`D000003`3oool6000000l0oooo1@0000000`3oool000000000000J0?ooo`L000006P3oool0
0400oooo1`00000B0?ooo`L000005P3oool00`20P800000000000004000000030820P03oool0oooo
0080oooo00<0P8200000000000000`20P8001@10@4000000000000000000P82000d0oooo00<0P820
0000000000001@00000P0?ooo`@0P8204`0000000`20P800oooo0?ooo`3o0?ooodH0oooo00<0P820
0000000000004@0000030820P3H0oooo1P00000C0?ooo`030820P0000000000000@000006@3oool0
0`10@400000000000003000000040?ooo`20P80000000820P180oooo9000000>0?ooo`030820P000
000000000080000000<0`<300?ooo`3oool0303oool5000000h0oooo00<0P8200000000000000`00
0000103oool0P82000000000000I0?ooo`H0000000<0P8200?ooo`3oool0603oool00400oooo1`00
00000`20P800oooo0?ooo`0@0?ooo`H000005@3oool8000000H0oooo2P00000=0?ooo`030820P000
0000000000@000009`3oool00`20P80000000000000@00000?l0ooooAP3ooolB000003`0oooo1P00
000D0?ooo`H000006@3oool5000000<0oooo0P00000S0?ooo`0300000020P800oooo01l0oooo1000
00000`20P800oooo0?ooo`0<0?ooo`H000003@3oool5000000<0oooo0`00000H0?ooo`H000006`3o
ool00440oooo1P0000000`20P800oooo0?ooo`0@0?ooo`H00000403oool=000000L0oooo2@00000=
0?ooo`030820P0000000000000@00000:P3oool@000000030820P03oool0oooo0?l0oooo@P3oool@
00000400oooo1P00000C0?ooo`H000006@3oool5000000@0oooo0P00000R0?ooo`0300000020P800
oooo0200oooo1000000>0?ooo`H000003@3oool5000000@0oooo0`00000F0?ooo`L000006`3oool0
0440oooo1P0000000`20P800oooo0?ooo`0@0?ooo`H00000403oool<000000T0oooo2000000=0?oo
o`030820P0000000000000@00000;@3oool>00000?l0oooo@`3oool>000004<0oooo1P00000C0?oo
o`L000005`3oool6000000@0oooo00<0P820000000000000103oool3000000030820P03oool0oooo
01L0oooo00<000000820P03oool08@3oool4000000d0oooo1P00000<0?ooo`H000001@3oool20000
00040820P03oool0oooo0?ooo`@000003P3oool7000001/0oooo00110?ooo`H0000000<0P8200?oo
o`3oool0403oool00`20P800000000000003000001<0oooo2000000<0?ooo`D000003P3oool00`20
P80000000000000300000340oooo00<0P8200000000000002P00003o0?oood00oooo00<0P8200000
000000002@0000160?ooo`H000004`3oool7000001H0oooo1P0000060?ooo`X000006@3oool00`00
0000P8200?ooo`0S0?ooo`<00000303oool7000000X0oooo1P0000070?ooo`X000003@3oool70000
01/0oooo00120?ooo`H000004P3oool00`20P800000000000003000001L0oooo0`00000>0?ooo`<0
00003`3oool6000003@0oooo2`00003o0?oooch0oooo2P0000000`20P800oooo0?ooo`160?ooo`L0
00004`3oool6000001@0oooo200000060?ooo`X000006@3oool00`000000P8200?ooo`0S0?ooo`04
0820P00000000000000000X0oooo200000080?ooo`P000001`3oool:000000d0oooo1P0000000`20
P800oooo0?ooo`0I0?ooo`00@P3oool600000180oooo00<0P8200000000000001000000i0?ooo`D0
0000>03oool900000?l0oooo?03oool8000004d0oooo1P00000C0?ooo`H000003`3oool00`20P800
00000000000:000000L0oooo2@00000I0?ooo`0300000020P800oooo02@0oooo1@0000070?ooo`T0
0000103oool<000000P0oooo2@00000=0?ooo`H0000000<0P8200?ooo`3oool06@3oool00480oooo
1P00000C0?ooo`H00000>@3oool5000003`0oooo1P00003o0?ooocX0oooo1P00001@0?ooo`H00000
4`3oool6000000l0oooo00<0P8200000000000002@0000090?ooo`P000006@3oool00`000000P820
0?ooo`0V0?ooo`D00000103oool4000000030?ooo`000000000000@000000`3oool;000000030820
P03oool0oooo00H0oooo00<0P8200000000000001P00000=0?ooo`H0000000<0P8200?ooo`3oool0
6@3oool00480oooo1`00000B0?ooo`H00000>@3oool5000003h0oooo1P00003o0?ooocL0oooo1000
00000`20P800oooo0?ooo`1@0?ooo`H00000503oool500000180oooo2000000<0?ooo`D0000000<0
P8200?ooo`3oool05`3oool00`000000P8200?ooo`0X0?ooo`X000000`3oool5000000D0oooo00<0
P8200000000000001P00000;0?ooo`H000003P3oool6000001`0oooo000d0?ooo`030820P03oool0
oooo00`0oooo1P00000?0?ooo`80P8200P3oool6000003L0oooo1@0000120?ooo`D0P820o`3ooolb
0?ooo`D0P820E@3oool00`20P800000000000004000001<0oooo1@0000000`20P800oooo0?ooo`0D
0?ooo`80P8203P3oool40820P1X0oooo00<000000820P03oool0:`3oool50820P0D0oooo1@00000:
0?ooo`<0P8203@3oool40820P0h0oooo1P0000000`20P800oooo0?ooo`0J0?ooo`00=@3oool00`20
P800oooo0?ooo`0;0?ooo`H00000403oool010000000oooo0?ooo`3oool5000003L0oooo1000003o
0?ooom@0oooo00<0P8200000000000001000000D0?ooo`D00000A03oool00`000000P8200?ooo`0f
0?ooo`D00000:`3oool6000001d0oooo000e0?ooo`030820P03oool0oooo00`0oooo1P00000?0?oo
o`030000003oool0oooo0080oooo1@00000e0?ooo`@00000o`3ooooE0?ooo`030820P00000000000
00D000004`3oool5000004@0oooo00<000000820P03oool0=P3oool5000002/0oooo1P00000M0?oo
o`00=@3oool00`000000oooo0?ooo`0<0?ooo`H000003`3oool00`000000oooo0?ooo`020?ooo`D0
0000=@3oool400000?l0ooooeP3oool7000001@0oooo1@0000130?ooo`0300000020P800oooo03H0
oooo1@00000Z0?ooo`H000007P3oool003D0oooo00<0P8200?ooo`3oool0303oool6000000l0oooo
00<000000820P03oool00`3oool4000003@0oooo1000003o0?ooolP0oooo00<000000?ooo`3oool0
303oool7000000h0oooo0P0000040?ooo`D00000@`3oool00`000000P8200?ooo`0f0?ooo`H00000
:@3oool6000001h0oooo000e0?ooo`030820P0000000oooo00`0oooo1`00000>0?ooo`0300000020
P800oooo00@0oooo0`0000000`20P800oooo0?ooo`0a0?ooo`<0000000<0P8200?ooo`3oool0o`3o
ooo70?ooo`030000003oool0oooo00/0oooo1`00000?0?ooo`030000003oool0oooo0080oooo00<0
P8200000000000000P0000130?ooo`0300000020P800oooo03H0oooo00<0P8200000000000000`00
000Y0?ooo`D000007`3oool003D0oooo00<0P8200000000000003@3oool6000000h0oooo00<00000
0820P03oool01@3oool300000380oooo1000003o0?ooolX0oooo00<000000?ooo`3oool0303oool7
000000h0oooo00<000000?ooo`3oool00`3oool500000480oooo00<000000820P03oool0=P3oool0
0`20P800000000000003000002P0oooo00<0P8200000000000000P00000P0?ooo`00=@3oool00`20
P80000000000000=0?ooo`H000003P3oool2000000H0oooo0`00000b0?ooo`<00000o`3oooo;0?oo
o`8000003@3oool7000000h0oooo00<000000?ooo`3oool00`3oool500000480oooo00<000000820
P03oool0=P3oool00`20P800000000000003000002P0oooo00<0P8200000000000000P00000P0?oo
o`00=P3oool4000000/0oooo1P00000=0?ooo`<000001`3oool300000300oooo1000003o0?oool`0
oooo00<000000?ooo`3oool02`3oool7000000h0oooo0P0000050?ooo`@00000@P3oool00`000000
P8200?ooo`0g0?ooo`H000009`3oool400000240oooo000f0?ooo`H000000P20P8000`30`<00oooo
0?ooo`040?ooo`030820P0000000000000@000002P3oool00`20P800000000000002000000P0oooo
00<0@410000000000000;@3oool00`20P8000000000000020820P?l0ooooc@3oool2000000030820
P03oool0oooo00T0oooo00<0P820000000000000100000000`20P800oooo0?ooo`0;0?ooo`800000
1P3oool01@20P8000000000000000000P8200400oooo00<0P8200<30`03oool0=`3oool6000002H0
oooo00@0P820000000000000P8208P3oool003L0oooo9@0000090?ooo`800000:`3oool300000?l0
ooood03oool3000000`0oooo1P0000000`20P800oooo0?ooo`0;0?ooo`<000001P3oool4000007X0
oooo1`00000U0?ooo`800000903oool003L0oooo9@00000:0?ooo`800000:@3oool00`20P8000000
0000003o0?ooom80oooo0`00000;0?ooo`H0000000<0P8200?ooo`3oool02P3oool4000000L0oooo
1000001j0?ooo`H00000903oool3000002@0oooo001W0?ooo`<000009`3oool00`000000oooo0?oo
o`3o0?ooom80oooo1@0000090?ooo`L000002`3oool5000000P0oooo0`0000000`20P800oooo0?oo
o`1g0?ooo`H000008`3oool3000000030820P03oool0oooo0280oooo001Y0?ooo`8000009@3oool0
0`000000P8200?ooo`3o0?ooom<0oooo200000070?ooo`H000002P3oool6000000T0oooo0P000000
0`20P800oooo0?ooo`1g0?ooo`H000008P3oool3000002H0oooo001[0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0o`3ooooE0?ooobD000002P3oool00`000000oooo0?ooo`1g0?oo
o`L00000803oool3000002L0oooo003o0?ooool0ooooJ03ooolU000000X0oooo00<0P8200000003o
ool0M`3oool7000001l0oooo0`00000X0?ooo`00o`3ooooo0?oooiP0oooo0`00001b0?ooo`/00000
7P3oool2000002X0oooo003o0?ooool0ooooVP3oool2000007<0oooo00<0P8200000000000001P00
00000`20P800oooo0?ooo`0J0?ooo`800000:`3oool00?l0ooooo`3ooonL0?ooo`030820P03oool0
oooo07L0oooo0P20P8000`30`<00oooo0?ooo`0I0?ooo`030820P03oool0oooo02/0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3o
oooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0
ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3o
ool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0
ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{172.5, 62.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 3.2 Forces acting on a mass element in equilibrium.", "Caption",
  CellTags->"Fig. 3.2"],

Cell[TextData[{
  "\tHowever, if an extra force ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]F\)]],
  ", such as gravity,  acts on the element ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]m\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " direction then ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is not constant in equilibrium. Equilibrium force balance then yields  ",
  Cell[BoxData[
      \(TraditionalForm\`T(x + \[DifferentialD]x) + \[DifferentialD]F - 
          T(x) = 0\)]],
  ". ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(Taylor\)\(\ \)\)\)]],
  "expansion of this expression implies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]T/\[DifferentialD]x = \(-\
\[DifferentialD]F\)/\[DifferentialD]x\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.1)"],

Cell[TextData[{
  "For instance, if gravity points in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(-x\)\)]],
  " direction, then ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]F = \(-\[DifferentialD]m\)\ g\)]],
  ". Equation ",
  ButtonBox["(3.1.1)",
    ButtonData:>"(3.1.1)",
    ButtonStyle->"Hyperlink"],
  " then implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]T/\[DifferentialD]x = \[Rho]\ g\)]],
  ", where "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Rho](
        x) = \[DifferentialD]m/\[DifferentialD]x\)]]], "NumberedEquation",
  CellTags->"(3.1.2)"],

Cell[TextData[{
  " is the mass per unit length.  In this example the tension increases with \
increasing ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", because more of the string weight must be supported by the remaining \
string as one moves up the string against gravity,  in the +",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " direction."
}], "Text"],

Cell[TextData[{
  "\t  Since all forces have been assumed to act along the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction, the string remains straight. However, if time-independent \
forces, such as a force of gravity in the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " direction, act transverse to the string it will no longer remain straight \
in equilibrium, but will sag under the action of the transverse force. (This \
can be observed \"experimentally\" in spring-mass simulations of an elastic \
string, in Sec. ",
  ButtonBox["9.10",
    ButtonData:>{"Chapter9.nb", "Ex. 9.10"},
    ButtonStyle->"Hyperlink"],
  ".)  In what follows, we neglect the effect of such forces on the \
equilibrium of the string, and assume that the equilibrium is a straight \
horizontal string along the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\(-\)\)\)]],
  "axis, following the equation ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  ". We will examine the effect of a gravitational force in the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-direction in Sec. ",
  ButtonBox["3.1.2",
    ButtonData:>"c:8",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["String Dynamics: The Wave Equation", "Section",
  CellTags->"c:7"],

Cell[TextData[{
  "\tNow let us consider a string that has been perturbed away from \
equilibrium by a small transverse displacement in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y\)\(\ \)\)\)]],
  "-direction. The shape of the string is now a curve that changes with time, \
given by the function ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  ". (See Fig. ",
  ButtonBox["3.3",
    ButtonData:>"Fig. 3.3",
    ButtonStyle->"Hyperlink"],
  ".)  Our job is to obtain an equation of motion for ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  ".  To simplify this task, we will assume that the perturbed string is \
nearly straight: ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[PartialD]y/\[PartialD]x\)\(|\)\(<< 
          1\)\)\)]],
  " . "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009@0001[R000`400?l00000o`00003oo`3ooooo
0?oooe80oooo003o0?ooool0ooooDP3oool00?l0ooooo`3ooomB0?ooo`00o`3ooooo0?oooe80oooo
003o0?ooool0ooooDP3oool00?l0ooooo`3ooomB0?ooo`00o`3ooooo0?oooe80oooo003o0?ooool0
ooooDP3oool00?l0ooooo`3ooomB0?ooo`00o`3ooooo0?oooe80oooo003o0?ooool0ooooDP3oool0
0?l0ooooo`3ooomB0?ooo`00o`3ooooo0?oooe80oooo003o0?ooool0ooooDP3oool00?l0ooooo`3o
oomB0?ooo`00o`3ooooo0?oooe80oooo003o0?ooool0ooooDP3oool00?l0ooooo`3ooomB0?ooo`00
o`3ooooo0?oooe80oooo003S0?ooo`80000000<0P8200?ooo`3oool01P3oool00`10@40000000<30
`03o0?ooof00oooo003:0?ooo`030<30`020P800oooo01H0oooo0`0000000`10@400oooo0?ooo`04
0?ooo`050820P0000000000000000010@400o`3ooomO0?ooo`00bP3oool300000080P820503oool2
000000030820P0000000@41000D0oooo0`0000000`20P800@4100<30`03o0?oooeh0oooo00390?oo
o`030<30`0000000000000D0000000<0P8200?ooo`3oool03`3oool01P20P800`<300?ooo`3oool0
00000820P0<0oooo00@0`<3000000000000000000P3oool00`10@400`<300?ooo`3o0?oooe`0oooo
00390?ooo`030820P0000000000000L0000000<0@4100<30`03oool04@3oool00`30`<0000000<30
`0020?ooo`040820P000000000000410@080oooo00<0`<300410@03oool0o`3ooomL0?ooo`00b@3o
ool00`20P80000000000000:000000030820P03oool0oooo00l0oooo00D0`<300410@03oool0oooo
0410@002000000030820P03oool0oooo0?l0ooooG`3oool00<T0oooo3`0000000`10@400P8200<30
`00>0?ooo`030410@020P800oooo00<00000o`3ooomR0?ooo`00b@3ooolC000000030820P03oool0
oooo00/0oooo00<000000?ooo`0000000P00003o0?ooof80oooo000W0?ooo`030<30`020P800P820
09l0P8205P0000000`20P800oooo0?ooo`080?ooo`050820P0000000000000000020P800o`3ooomR
0?ooo`009`3oool00`20P80000000000002h000000030820P03oool0oooo00D0oooo00D0`<300000
0000000000000820P03o0?ooof80oooo000V0?ooo`030820P000000000000;L0000000<0P8200<30
`03oool01`3oool01020P800000000000000003o0?ooof<0oooo000V0?ooo`030820P00000000000
0:00oooo4`0000000`10@400P8200<30`00;0?ooo`050410@0000000000000000030`<00o`3ooomR
0?ooo`009P3oool00`20P80000000000002P0?oooa8000003`3oool4000000030820P03oool0oooo
0?l0ooooH03oool002H0oooo00<0P820000000000000X03oool?000000030820P030`<00oooo00l0
oooo0`0000000`20P80000000<30`03o0?ooof40oooo000V0?ooo`030820P000000000000:00oooo
00<0P8200000000000002@0000000`10@400P8200?ooo`0A0?ooo`070820P0000000000000000030
`<00P8200410@03o0?ooof40oooo000V0?ooo`030820P000000000000:00oooo00<0P82000000000
00001P0000000`10@400P8200?ooo`0D0?ooo`040410@0000000000000000080oooo0P10@4020?oo
o`80P820o`3ooomL0?ooo`009P3oool00`20P80000000000002Q0?ooo`D000000P20P80F0?ooo`03
0<30`010@40000000080000000@0P8200?ooo`3oool0oooo1@0000000`20P800oooo0?ooo`3o0?oo
oeT0oooo000V0?ooo`030820P000000000000:40oooo00@0P82000000020P800`<305`3oool70000
00050<30`03oool0oooo0?ooo`30`<00100000000`20P800oooo0?ooo`3o0?oooeT0oooo000V0?oo
o`030820P000000000000;d0oooo00D0`<300820P020P80000000410@0070?ooo`030410@0000000
@4100?l0ooooG03oool002H0oooo00<0P820000000000000o`3ooooo0?ooobT0oooo000V0?ooo`03
0820P000000000000?l0ooooo`3ooolY0?ooo`009P3oool00`20P80000000000003o0?ooool0oooo
:@3oool002H0oooo00<0P820000000000000o`3ooooo0?ooobT0oooo000V0?ooo`030820P0000000
00000?l0ooooo`3ooolY0?ooo`009P3oool00`20P80000000000003o0?ooool0oooo:@3oool002H0
oooo00<0P820000000000000o`3ooooo0?ooobT0oooo000V0?ooo`030820P000000000000?l0oooo
o`3ooolY0?ooo`009P3oool00`20P80000000000003o0?ooool0oooo:@3oool002H0oooo00<0P820
000000000000o`3ooooo0?ooobT0oooo000V0?ooo`030820P000000000000?l0ooooo`3ooolY0?oo
o`009P3oool00`20P80000000000003o0?ooool0oooo:@3oool002H0oooo00<0P820000000000000
o`3ooooo0?ooobT0oooo000V0?ooo`030820P000000000000?l0ooooo`3ooolY0?ooo`009P3oool0
0`20P80000000000003o0?ooool0oooo:@3oool002H0oooo00<0P820000000000000o`3ooooo0?oo
obT0oooo000V0?ooo`030820P000000000000?l0ooooo`3ooolY0?ooo`009P3oool00`20P8000000
0000003o0?ooool0oooo:@3oool002H0oooo00<0P820000000000000o`3ooooo0?ooobT0oooo000V
0?ooo`030820P000000000000?l0ooooo`3ooolY0?ooo`009P3oool00`20P80000000000003o0?oo
ool0oooo:@3oool002H0oooo00<0P820000000000000o`3ooooo0?ooobT0oooo000V0?ooo`030820
P000000000000?l0ooooo`3ooolY0?ooo`009P3oool00`20P80000000000003o0?ooool0oooo:@3o
ool002H0oooo00<0P820000000000000o`3ooooo0?ooobT0oooo000V0?ooo`030820P00000000000
0?l0ooooo`3ooolY0?ooo`009P3oool00`20P80000000000003o0?ooool0oooo:@3oool002H0oooo
00<0P820000000000000o`3ooooo0?ooobT0oooo000V0?ooo`030820P000000000000?l0ooooo`3o
oolY0?ooo`009P3oool00`20P80000000000003o0?ooool0oooo:@3oool002H0oooo00<0P8200000
00000000o`3ooooo0?ooobT0oooo000V0?ooo`030820P000000000000?l0ooooo`3ooolY0?ooo`00
9P3oool00`20P80000000000003o0?ooool0oooo:@3oool002H0oooo00<0P820000000000000o`3o
oooo0?ooobT0oooo000V0?ooo`030820P000000000000?l0ooooo`3ooolY0?ooo`009P3oool00`20
P80000000000003o0?ooool0oooo:@3oool002H0oooo00<0P820000000000000o`3ooooo0?ooobT0
oooo000V0?ooo`030820P000000000000?l0ooooo`3ooolY0?ooo`009P3oool00`20P80000000000
003o0?ooool0oooo:@3oool002H0oooo00<0P820000000000000o`3ooooo0?ooobT0oooo000V0?oo
o`030820P000000000000?l0ooooo`3ooolY0?ooo`009P3oool00`20P80000000000003o0?ooool0
oooo:@3oool002H0oooo00<0P820000000000000o`3ooooo0?ooobT0oooo000V0?ooo`030820P000
000000000?l0ooooo`3ooolY0?ooo`009P3oool00`20P80000000000003o0?ooool0oooo:@3oool0
02H0oooo00<0P820000000000000o`3ooooo0?ooobT0oooo000V0?ooo`030820P000000000000?l0
ooooo`3ooolY0?ooo`009P3oool00`20P80000000000003o0?ooool0oooo:@3oool002H0oooo00<0
P820000000000000o`3ooooo0?ooobT0oooo000V0?ooo`030820P000000000000?l0ooooo`3ooolY
0?ooo`009P3oool00`20P80000000000003o0?ooool0oooo:@3oool002H0oooo00<0P82000000000
0000o`3ooooo0?ooobT0oooo000V0?ooo`030820P000000000000?l0ooooo`3ooolY0?ooo`009P3o
ool00`20P80000000000003o0?ooool0oooo:@3oool002H0oooo00<0P820000000000000o`3ooooo
0?ooobT0oooo000V0?ooo`030820P000000000000?l0ooooo`3ooolY0?ooo`009P3oool00`20P800
00000000003o0?ooool0oooo:@3oool002H0oooo00<0P820000000000000o`3ooooo0?ooobT0oooo
000V0?ooo`030820P000000000000?l0ooooo`3ooolY0?ooo`009P3oool00`20P80000000000003o
0?ooool0oooo:@3oool002H0oooo00<0P820000000000000o`3ooooo0?ooobT0oooo000V0?ooo`03
0820P000000000000?l0ooooo`3ooolY0?ooo`009P3oool00`20P80000000000003o0?ooool0oooo
:@3oool002H0oooo00<0P820000000000000o`3ooooo0?ooobT0oooo000V0?ooo`030820P0000000
00000?l0ooooo`3ooolY0?ooo`009P3oool00`20P80000000000003o0?ooool0oooo:@3oool002H0
oooo00<0P820000000000000o`3ooooo0?ooobT0oooo000V0?ooo`030820P000000000000?l0oooo
o`3ooolY0?ooo`009P3oool00`20P80000000000003o0?ooool0oooo:@3oool002H0oooo00<0P820
000000000000o`3ooooo0?ooobT0oooo000V0?ooo`030820P000000000000?l0ooooo`3ooolY0?oo
o`009P3oool00`20P80000000000003o0?ooool0oooo:@3oool002H0oooo00<0P820000000000000
Y@3oool00`30`<00P8200820P0090?ooo`030820P030`<00oooo0840oooo00<0`<300820P030`<00
2@3oool00`20P800`<300?ooo`0U0?ooo`80P82000<0`<300?ooo`3oool01@3oool20820P0@0oooo
0P20P8090?ooo`030<30`020P800oooo0:00oooo000V0?ooo`030820P000000000000:D0oooo00D0
P82000000000000000000<30`0060?ooo`040410@000000000000820P840oooo00@0P82000000000
0000@4101`3oool01010@400000000000020P80S0?ooo`030<30`000000000000080000000<0@410
0<30`03oool00`3oool01@10@4000000000000000000`<300080oooo0`0000000`30`<00oooo0?oo
o`040?ooo`050<30`000000000000410@030`<00W`3oool002H0oooo00<0P820000000000000Y@3o
ool00`20P800000000000002000000030<30`03oool0oooo0080oooo00<0`<300000000000000`00
00200?ooo`050820P0000000000000000010@4001@3oool00`30`<00000000000002000000030820
P03oool0oooo01l0oooo00<0`<300000000000001@0000001030`<00oooo0?ooo`3oool300000004
0820P010@400`<300?ooo`@0000000<0P8200?ooo`3oool00`3oool00`10@4000000000000020000
09l0oooo000V0?ooo`030820P000000000000:D0oooo00@0P820000000000000oooo0P0000040?oo
o`070820P000000000000820P03oool000000820P01o0?ooo`040820P0000000P8200820P0800000
103oool01P20P800000000000020P800oooo00000240oooo00D0P82000000000000000000820P002
0?ooo`8000000`3oool300000080oooo00D000000?ooo`00000000000?ooo`02000000030820P03o
ool0oooo0080oooo0`0000000`3oool0P8200820P02N0?ooo`009P3oool00`20P80000000000002U
0?ooo`030<30`020P800oooo0080oooo00<000000820P03oool00P3oool01010@400000000000020
P8020?ooo`030410@030`<00oooo07d0oooo00L0`<300820P03oool0oooo0820P0000000P82000<0
oooo00L0@410000000000000P8200?ooo`30`<00@4100100oooo0P30`<0>0?ooo`<0000000D0@410
0?ooo`3oool0oooo0<30`0020410@080oooo00D0P820000000000000P8200?ooo`030820P0030<30
`03oool0oooo008000000`3oool01030`<0000000000000000020?ooo`030410@030`<00oooo09`0
oooo000V0?ooo`030820P000000000000:X0oooo00<0`<3000000030`<000P3oool3000000050<30
`03oool0oooo0<30`010@400P`3oool00`20P80000000<30`0020?ooo`<0000000D0`<300?ooo`3o
ool0@4100<30`00?0?ooo`80P8203P3oool3000000030<30`03oool0oooo00<0oooo00@0@4100000
0030`<00P8200P0000001020P800oooo0?ooo`30`<050?ooo`80@4100P3oool01020P80000000000
0010@4020?ooo`030<30`010@400oooo09`0oooo000V0?ooo`030820P000000000000:/0oooo00@0
`<300410@03oool0`<300`0000290?ooo`040<30`010@400oooo0<30`0<00000503oool20820P0h0
oooo0`0000070?ooo`030820P0000000`<3000<000002@3oool01010@400`<300?ooo`10@4020000
00030820P03oool0oooo09l0oooo000V0?ooo`030820P000000000000:`0oooo00<0@4100820P020
P8000P0000000`20P800oooo0?ooo`280?ooo`030410@020P800P8200080000000<0P8200?ooo`3o
ool04P3oool20820P0h0oooo0`0000080?ooo`<0@4100P0000090?ooo`030<30`0000000oooo00<0
0000XP3oool002H0oooo00<0P820000000000000[@3oool01@000000P820000000000000P82008/0
oooo00D000000820P000000000000820P00D0?ooo`80P8203P3oool01020P800000000000030`<08
0?ooo`050410@0000000000000000020P8002@3oool20820P0<00000XP3oool002H0oooo00<0P820
000000000000[@3oool01020P800000000000000002<0?ooo`040820P00000000000000001D0oooo
0P20P80>0?ooo`040820P000000000000820P0P0oooo00D0`<3000000000000000000410@00:0?oo
o`<0000000<0P8200?ooo`3oool0X03oool002H0oooo00<0P820000000000000[@3oool01030`<00
000000000000002<0?ooo`040<30`00000000000000001D0oooo0P20P80?0?ooo`<000002@3oool0
1010@400000000000000000:0?ooo`040410@000000000000820P:80oooo000V0?ooo`030820P000
000000000:d0oooo00@0P820000000000000P820S03oool01020P800000000000020P80E0?ooo`80
P8203`3oool01020P800000000000030`<080?ooo`050<30`0000000000000000030`<002@3oool3
00000:<0oooo000V0?ooo`030820P000000000000:d0oooo00@0@410000000000000@410S03oool0
1010@400000000000010@40E0?ooo`80P820403oool00`10@40000000410@0090?ooo`040410@000
000000000820P0P0oooo00D0`<3000000000000000000<30`02R0?ooo`009P3oool00`20P8000000
0000002]0?ooo`<0000000<0@4100<30`03oool0RP3oool3000000030410@030`<00oooo01<0oooo
0P20P80@0?ooo`040<30`000000000000820P0P0oooo00@0P8200000000000000000203oool00`20
P8000000000000020410@:80oooo000V0?ooo`030820P000000000000:`0oooo00H0`<3000000000
000000000<30`000002:0?ooo`060<30`0000000000000000030`<0000002P3oool00`20P8000000
0000000B000000P0oooo00@0`<30000000000000`<30203oool3000000P0oooo00H0@41000000000
0000P8200410@020P82Q0?ooo`009P3oool00`20P80000000000002/0?ooo`050820P00000000000
0820P03oool00P10@4290?ooo`050820P000000000000820P03oool00P10@40C0?ooo`80P8204P3o
ool00`10@40000000410@0080?ooo`<0000000<0P8200?ooo`3oool01@3oool3000000040?ooo`30
`<0000000<30`:00oooo000V0?ooo`030820P000000000000:`0oooo0`0000001@20P800oooo0?oo
o`000000P8200080oooo0P0000240?ooo`<0000000T0P8200?ooo`3oool000000820P03oool0P820
00000020P8003P3oool20820P1<0oooo0P0000000`20P800oooo0?ooo`050?ooo`<0000000<0P820
0?ooo`3oool0103oool01020P80000000000000000020?ooo`040820P0000000oooo0?ooo`800000
W03oool002H0oooo00<0P820000000000000ZP3oool00`30`<00@41000000002000000<0oooo00<0
P8200000000000000`0000000`20P800oooo0?ooo`1o0?ooo`030820P010@4000000008000000`3o
ool00`20P800000000000003000000h0oooo0P20P80D0?ooo`030410@0000000`<3000D0oooo00<0
`<300000000000000P0000050?ooo`050820P0000000000000000020P8000`3oool6000009/0oooo
000V0?ooo`030820P000000000000:P0oooo1P0000000`10@400oooo0?ooo`020?ooo`030410@000
000000000080000000<0P8200?ooo`3oool0O03oool00`20P800000000000004000000030410@03o
ool0oooo0080oooo00<0@4100000000000000P00000>0?ooo`80P8205@3oool01020P80000000410
@020P8020?ooo`030<30`0000000@41000<0000000<0`<300?ooo`0000001P0000001@30`<00oooo
0?ooo`3oool0`<3000D00000V`3oool002H0oooo00<0P820000000000000Z@3oool01@30`<00P820
0820P0000000@41000L0oooo00<0@41000000010@400P@3oool30820P00300000010@400oooo00D0
oooo00@0`<30000000000000`<303P3oool20820P1L0oooo0P20P803000000030820P03oool0P820
0080000000@0P8200?ooo`3oool0`<300P20P8000`10@40000000<30`0060?ooo`030410@0000000
@41009`0oooo000V0?ooo`030820P000000000000?l0ooooE`3oool20820P1h0oooo00@0`<300000
00000000@410[@3oool002H0oooo00<0P820000000000000o`3ooomG0?ooo`80P8207`3oool30000
0:d0oooo000V0?ooo`030820P000000000000?l0ooooE`3oool20820P1l0oooo00@0@41000000000
0000P820[03oool002H0oooo00<0P820000000000000o`3ooomG0?ooo`80P8207`3oool01020P800
000000000020P82/0?ooo`009P3oool00`20P80000000000003o0?oooeL0oooo0P20P80P0?ooo`<0
0000[03oool002H0oooo00<0P820000000000000o`3ooomi0?ooo`<0000000<0`<300?ooo`3oool0
Z@3oool002H0oooo00<0P820000000000000o`3ooomi0?ooo`040820P000000000000820P:/0oooo
000V0?ooo`030820P000000000000?l0ooooN@3oool01020P800000000000010@42[0?ooo`009P3o
ool00`20P80000000000003o0?ooogL0oooo0P20P8001010@400000000000000002[0?ooo`009P3o
ool00`20P80000000000003o0?ooogP0oooo00H0`<300820P020P800P82000000020P82Z0?ooo`00
9P3oool00`20P80000000000003o0?ooool0oooo:@3oool002H0oooo00<0P820000000000000BP3o
ool00`20P800oooo0?ooo`3a0?ooo`030<30`020P800`<300>H0oooo000V0?ooo`030820P0000000
000004P0oooo00@0`<30000000000000@410I@3oool20820P?l0ooooM@3oool002H0oooo00<0P820
000000000000A`3oool00`10@400000000000002000000030410@03oool0oooo0680oooo0P00003o
0?ooogD0oooo000V0?ooo`030820P0000000000004H0oooo00<0@410000000000000100000000`30
`<00oooo0?ooo`1Q0?ooo`800000o`3ooome0?ooo`009P3oool00`20P8000000000000140?ooo`03
0<30`010@400000000L0000000<0`<300?ooo`3oool0H03oool200000?l0ooooM@3oool002H0oooo
00<0P820000000000000@`3oool00`30`<00000000000009000000030<30`03oool0oooo05l0oooo
0P00003o0?ooogD0oooo000V0?ooo`030820P0000000000004@0oooo00<0@4100000000000002@00
00000`30`<00oooo0?ooo`1N0?ooo`800000o`3ooome0?ooo`009P3oool00`20P800000000000015
0?ooo`030410@0000000000000T0000000<0`<300?ooo`3oool0G@3oool20820P?l0ooooM@3oool0
02H0oooo00<0P820000000000000AP3oool00`10@400000000000009000000030<30`03oool0oooo
0?l0ooood`3oool002H0oooo00<0P820000000000000A`3oool00`10@40000000000000800000003
0410@03oool0oooo0?l0ooood`3oool002H0oooo00<0P820000000000000B03oool00`10@4000000
00000008000000030410@03oool0oooo0?l0oooodP3oool002H0oooo00<0P820000000000000B@3o
ool;000000030410@03oool0oooo0>L0oooo00<0`<300820P030`<00iP3oool002H0oooo00<0P820
000000000000BP3oool00`10@400000000000008000000030410@03oool0oooo0>H0oooo00<0P820
00000020P800iP3oool002H0oooo00<0P820000000000000B`3oool<00000>L0oooo00<0P8200000
0020P800iP3oool002H0oooo00<0P820000000000000B`3oool00`30`<0000000000000900000003
0410@03oool0oooo0>@0oooo00<0P82000000020P800iP3oool002H0oooo00<0P820000000000000
C03oool00`30`<00000000000009000000030410@03oool0oooo0><0oooo00<0P82000000020P800
iP3oool002H0oooo00<0P820000000000000C@3oool00`30`<00000000000009000000030410@03o
ool0oooo0>80oooo00<0P82000000020P800iP3oool002H0oooo00<0P820000000000000CP3oool0
0`30`<00000000000009000000030410@03oool0oooo0>40oooo00<0P82000000020P800iP3oool0
02H0oooo00<0P820000000000000C`3oool00`30`<00000000000009000000030<30`03oool0oooo
05<0oooo0P20P82;0?ooo`030<30`020P800`<300>H0oooo000V0?ooo`030820P000000000000500
oooo00<0`<300000000000002@0000000`30`<00oooo0?ooo`1B0?ooo`800000o`3ooome0?ooo`00
9P3oool00`20P80000000000001A0?ooo`030820P0000000000000T0000000<0`<300?ooo`3oool0
D@3oool200000?l0ooooM@3oool002H0oooo00<0P820000000000000DP3oool00`10@40000000000
0009000000030<30`03oool0oooo0500oooo0P00003o0?ooogD0oooo000V0?ooo`030820P0000000
000005<0oooo00<0@4100000000000002@0000000`30`<00oooo0?ooo`1?0?ooo`800000o`3ooome
0?ooo`009P3oool00`20P80000000000001D0?ooo`030410@0000000000000T0000000<0`<300?oo
o`3oool0CP3oool200000?l0ooooM@3oool002H0oooo00<0P820000000000000E@3oool00`10@400
000000000009000000030<30`03oool0oooo04d0oooo0P20P83o0?ooogD0oooo000V0?ooo`030820
P0000000000005H0oooo00<0P8200000000000002@0000000`30`<00oooo0?ooo`3o0?oool<0oooo
000V0?ooo`030820P0000000000005L0oooo00<0P8200000000000002@00003o0?ooolD0oooo000V
0?ooo`030820P0000000000005L0oooo00<0`<300000000000002@0000000`10@400oooo0?ooo`3o
0?oool80oooo000V0?ooo`030820P0000000000005P0oooo00<0`<300000000000002P0000000`30
`<00oooo0?ooo`3o0?oool00oooo000V0?ooo`030820P0000000000005T0oooo00<0`<3000000000
00002P00003H0?ooo`030820P0000000P8200>H0oooo000R0?ooo`@0P82000<0@410000000000000
1020P81F0?ooo`030<30`0000000000000T0000000<0@4100?ooo`3oool0e@3oool00`20P8000000
0820P03V0?ooo`003P3oool00`10@400oooo0?ooo`0>0?ooo`030<30`010@400000000`0000000<0
@4100820P030`<00D`3oool00`30`<00000000000009000000030410@03oool0oooo0=@0oooo00<0
P82000000020P800iP3oool000h0oooo0P0000000`30`<00oooo0?ooo`0<0?ooo`030410@0000000
000000h0000000<0`<300?ooo`3oool0DP3oool00`30`<00000000000009000000030410@03oool0
oooo0=<0oooo00<0P82000000020P800iP3oool000h0oooo00@0`<300410@0000000`<303@3oool0
0`20P80000000000000>000005H0oooo00<0`<300000000000002@0000000`10@400oooo0?ooo`3B
0?ooo`030820P0000000P8200>H0oooo000@0?ooo`030820P0000000`<3000d0oooo3`00001H0?oo
o`030<30`0000000000000T0000000<0@4100?ooo`3oool0d@3oool00`20P80000000820P03V0?oo
o`004@3oool00`30`<0000000<30`00<0?ooo`030410@0000000000000/0000000<0P8200?ooo`3o
ool0E`3oool00`30`<00000000000009000000030410@03oool0oooo04<0oooo0P20P82;0?ooo`03
0<30`020P800`<300>H0oooo000B0?ooo`030<30`0000000P82000/0oooo00<0P820000000000000
2`0000000`30`<00oooo0?ooo`1H0?ooo`030<30`0000000000000T0000000<0@4100?ooo`3oool0
@P3oool200000?l0ooooM@3oool001<0oooo00<0`<3000000020P8002`3oool=000005`0oooo00<0
`<300000000000002@0000000`10@400oooo0?ooo`110?ooo`800000o`3ooome0?ooo`00503oool2
000000030<30`03oool0oooo00P0oooo00<0P8200000000000002@0000000`20P800oooo0?ooo`1K
0?ooo`030<30`0000000000000T0000000<0@4100?ooo`3oool0@03oool200000?l0ooooM@3oool0
01@0oooo0`0000000`30`<00oooo0?ooo`070?ooo`030<30`0000000000000T0000000<0`<300?oo
o`3oool0G03oool00`30`<00000000000009000000030410@030`<00oooo03l0oooo0P00003o0?oo
ogD0oooo000D0?ooo`@000002P3oool;00000640oooo300000100?ooo`800000o`3ooome0?ooo`00
4`3oool00`30`<00000000000002000000030410@03oool0oooo00L0oooo00<0P820000000000000
1`0000000`20P800oooo0?ooo`1O0?ooo`030<30`0000000000000X0000000<0`<300?ooo`3oool0
?03oool200000?l0ooooM@3oool001<0oooo00L0P82000000000000000000820P010@400P82000T0
oooo2@0000000`30`<00oooo0?ooo`1P0?ooo`030<30`0000000000000X0000000<0`<300?ooo`3o
ool0>`3oool20820P?l0ooooM@3oool001<0oooo00P0P82000000000000000000820P03oool00000
0<30`0P0oooo00<0P8200000000000001P00001T0?ooo`030<30`0000000000000X0000000<0`<30
0?ooo`3oool0o`3ooona0?ooo`004`3oool02020P8000000000000000000`<300?ooo`30`<000000
203oool00`30`<00000000000005000000030820P03oool0oooo06<0oooo00<0`<30000000000000
2P0000000`30`<00oooo0?ooo`3o0?oook00oooo000C0?ooo`040820P00000000000000000<0oooo
00<0P8200410@03oool01`3oool7000006L0oooo00<0`<300000000000002P0000000`30`<00oooo
0?ooo`3o0?ooojl0oooo000C0?ooo`040820P00000000000000000@0oooo00<0@4100820P03oool0
1P3oool00`20P800000000000004000006T0oooo00<0@4100000000000002@0000000`30`<00oooo
0?ooo`340?ooo`030<30`020P800`<300>H0oooo000C0?ooo`040410@00000000000000000@0oooo
00<0`<3000000030`<001P3oool00`30`<00000000000003000000030820P03oool0oooo06P0oooo
00<0@4100000000000002@0000000`30`<00oooo0?ooo`330?ooo`030820P0000000P8200>H0oooo
000C0?ooo`@000001@3oool00`20P800@4100?ooo`060?ooo`D0000000<0`<300?ooo`3oool0J@3o
ool00`10@400000000000009000000030<30`03oool0oooo0<80oooo00<0P82000000020P800iP3o
ool001<0oooo100000060?ooo`030410@020P800oooo00D0oooo00<0P8200000000000000P00001]
0?ooo`030410@0000000000000T0000000<0`<300?ooo`3oool0`@3oool00`20P80000000820P03V
0?ooo`004`3oool3000000030820P03oool0oooo00@0oooo00<0`<300000003oool01P3oool30000
00030820P03oool0oooo06`0oooo00<0@4100000000000002@0000000`10@400oooo0?ooo`300?oo
o`030820P0000000P8200>H0oooo000C0?ooo`<0000000<0P8200?ooo`3oool01@3oool00`10@400
P8200?ooo`050?ooo`030410@000000000000700oooo00<0@4100000000000002@0000000`10@400
oooo0?ooo`2o0?ooo`030820P0000000P8200>H0oooo000C0?ooo`<0000000<0P8200?ooo`3oool0
1@3oool00`30`<0000000?ooo`050?ooo`030820P0000000@4100740oooo00<0P820000000000000
2@0000000`10@400oooo0?ooo`2n0?ooo`030<30`020P800`<300>H0oooo000B0?ooo`050820P000
0000000000000020P8001`3oool00`30`<0000000820P0060?ooo`0300000020P800oooo0740oooo
00<0`<300000000000002@0000000`10@400oooo0?ooo`0`0?ooo`800000o`3ooome0?ooo`004P3o
ool01@20P8000000000000000000P82000L0oooo0P0000000`20P800oooo0?ooo`040?ooo`030000
003oool0oooo0780oooo00<0P8200000000000002P00000a0?ooo`800000o`3ooome0?ooo`004@3o
ool00`30`<00000000000002000000030<30`03oool0oooo00@0oooo00@0P820000000000000P820
1P3oool00`30`<00oooo0?ooo`1c0?ooo`030410@0000000000000T0000000<0@4100?ooo`3oool0
;P3oool200000?l0ooooM@3oool000l0oooo1`0000070?ooo`040820P000000000000820P7d0oooo
00<0P8200000000000002@0000000`10@400oooo0?ooo`0]0?ooo`800000<`3oool00`30`<00P820
0820P0070?ooo`030<30`020P800`<3000<0oooo00<0`<300820P020P8002@3oool00`20P800`<30
0?ooo`3o0?ooob<0oooo000@0?ooo`060<30`020P800P8200410@0000000P8201`3oool00`30`<00
00000410@01o0?ooo`030<30`0000000000000T0000000<0@4100?ooo`3oool0;03oool200000380
oooo00<0@4100000000000000P0000000`20P800`<300?ooo`020?ooo`050<30`000000000000000
0010@4000P3oool01@20P8000000000000000000`<3000H0oooo00@0@410000000000000P820o`3o
oolS0?ooo`00X03oool00`30`<0000000000000:000000030<30`03oool0oooo02X0oooo0P00000a
0?ooo`030410@0000000000000D0000000@0`<300?ooo`3oool0P8200P0000001@10@400P8200410
@03oool0P82000@0000000<0`<300?ooo`3oool00P3oool00`30`<0000000000000300000?l0oooo
8P3oool00:40oooo00<0`<300000000000002P0000000`30`<00oooo0?ooo`0Y0?ooo`80P820<03o
ool01@30`<000000000000000000@41000<0oooo00D0@41000000030`<00oooo0<30`0020000000;
0410@03oool0`<300410@020P80000000410@03oool0P82000000030`<000`3oool01`20P8000000
00000020P800oooo0820P010@400o`3ooolQ0?ooo`00XP3oool00`30`<0000000000000:00000003
0<30`03oool0oooo05X0oooo00@0P82000000000000000001@3oool01030`<0000000<30`03oool3
00000080oooo00<0@4100?ooo`3oool00`3oool20410@0<0oooo0`0000000`20P800oooo0?ooo`02
0820P?l0oooo803oool00:<0oooo00<0`<300000000000002P0000000`30`<00oooo0?ooo`1I0?oo
o`040820P000000000000820P0H0oooo00@0`<3000000030`<00@4100P0000000`30`<00oooo0?oo
o`060?ooo`040410@020P800oooo0?ooo`<00000103oool00`20P800oooo0?ooo`3o0?oooah0oooo
002T0?ooo`030<30`0000000000000X0000000<0`<300?ooo`3oool0F03oool01020P80000000000
0020P8070?ooo`030820P0000000P8200080000000<0P8200?ooo`3oool01`3oool00`000000`<30
0820P002000000030410@03oool0oooo0?l0oooo8`3oool008X0oooo0P10@4000`30`<00oooo0?oo
o`0F0?ooo`030<30`0000000000000X0000000<0@4100?ooo`3oool0E`3oool01030`<0000000000
0020P8080?ooo`80@4100P0000000`10@400oooo0?ooo`070?ooo`030<30`010@400P82000800000
00<0P8200?ooo`3oool0>@3oool00`30`<00P8200<30`03V0?ooo`00R`3oool3000000030410@020
P800oooo01D0oooo00<0`<300000000000002P0000000`10@400oooo0?ooo`1G0?ooo`<000002@3o
ool4000000X0oooo0P10@402000000030<30`03oool0oooo03T0oooo00<0P82000000020P800iP3o
ool008/0oooo00<0`<300000000000000`0000000`10@400`<300?ooo`0C0?ooo`030<30`0000000
000000X0000000<0@4100?ooo`3oool0EP3oool01010@400000000000030`<080?ooo`050820P000
0000000000000020P8002@3oool01030`<00000000000000000l0?ooo`030820P0000000P8200>H0
oooo002<0?ooo`030410@0000000000000D0000000<0P8200<30`03oool04P3oool00`20P8000000
0000000:000000030<30`03oool0oooo05@0oooo00@0`<30000000000000P8202@3oool300000003
0820P03oool0oooo00L0oooo00@0P820000000000000@410?03oool00`20P80000000820P03V0?oo
o`00S@3oool:000001<0oooo00<0P8200000000000002P00001G0?ooo`<000002@3oool01020P800
00000000000000090?ooo`040820P000000000000820P3`0oooo00<0P82000000020P800iP3oool0
08h0oooo2P0000000`20P800`<300?ooo`0@0?ooo`030410@0000000000000X0000000<0`<300?oo
o`3oool0D`3oool01030`<00000000000030`<080?ooo`040<30`00000000000000000T0oooo00@0
@410000000000000@410?03oool00`20P80000000820P03V0?ooo`00SP3oool00`30`<0000000000
000:000000030410@020P800oooo00h0oooo00<0@4100000000000002P0000000`30`<00oooo0?oo
o`1C0?ooo`030410@0000000000000T0oooo0`0000000`20P800oooo0?ooo`060?ooo`<0000000<0
@4100<30`03oool0>P3oool00`20P80000000820P03V0?ooo`00S`3oool00`20P80000000000000<
000000030820P030`<00oooo00`0oooo00<0@4100000000000002P0000000`30`<00oooo0?ooo`0M
0?ooo`80P820=03oool00`10@40000000410@0080?ooo`040820P000000000000820P0L0oooo00H0
`<3000000000000000000<30`000000k0?ooo`030<30`020P800`<300>H0oooo002@0?ooo`030410
@0000000000000h0000000<0P8200?ooo`3oool02P3oool00`10@40000000000000:000000030<30
`03oool0oooo01`0oooo0P00000d0?ooo`040<30`000000000000820P0L0oooo00@0P82000000000
000000001`3oool01@20P800000000000020P800oooo0080@410o`3ooolT0?ooo`00T03oool00`30
`<0000000000000@000000030410@020P800oooo00T0oooo00<0@4100000000000002P0000000`30
`<00oooo0?ooo`0K0?ooo`800000=@3oool01030`<00@41000000010@4060?ooo`050820P0000000
000000000030`<001@3oool01@30`<000000000000000000`<300080oooo0P10@4020820P0800000
00<0`<300?ooo`3oool0o`3ooolL0?ooo`00T@3oool00`30`<0000000000000B000000030410@030
`<00oooo00L0oooo00<0P8200000000000002P0000000`10@400oooo0?ooo`0J0?ooo`800000=`3o
ool01020P80000000410@030`<030?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0
0P20P8000`10@400000000000002000000<0oooo00<0`<300000000000000`0000000`20P800oooo
0?ooo`3o0?oooa`0oooo002B0?ooo`030410@0000000000001@0000000<0@4100820P03oool01@3o
ool00`30`<0000000000000:000000030410@03oool0oooo01T0oooo0P00000i0?ooo`030820P000
0000@4100080P82000<000000410@030`<000`0000020?ooo`030820P010@400000000<0000000<0
`<300?ooo`3oool00P3oool00`30`<00P82000000002000000030<30`03oool0oooo0?l0oooo703o
ool009<0oooo6@0000000`10@400`<300?ooo`030?ooo`030<30`0000000000000X0000000<0@410
0?ooo`3oool0603oool2000003/0oooo00@0`<300820P020P800`<300P3oool3000000H0oooo00<0
P8200<30`03oool01P3oool00`30`<00P8200<30`03o0?oooal0oooo002C0?ooo`030<30`0000000
000000h000002`20P8040?ooo`030<30`010@400000000X0000000<0@4100<30`03oool05`3oool2
0820P440oooo00@0P8200000000000000000o`3oool`0?ooo`00U03oool00`10@400000000000009
000000030410@020P800oooo0180oooo00<0P8200000000000002P0000000`20P800oooo0?ooo`1H
0?ooo`050820P0000000000000000030`<00o`3oool_0?ooo`00U@3oool;000000030410@030`<00
oooo01<0oooo00<0`<300000000000002P0000000`10@400`<300?ooo`1H0?ooo`<0000000<0P820
0?ooo`3oool0o`3oool]0?ooo`00U@3oool00`20P80000000000000:000000030<30`03oool0oooo
0180oooo00<0`<300410@00000002`0000000`30`<00oooo0?ooo`1F0?ooo`040410@00000000000
0410@?l0oooo;`3oool009H0oooo00<0@4100000000000001P0000001@30`<000000000000000000
@41001D0oooo00<0@4100000000000002P0000000`20P800oooo0?ooo`1E0?ooo`040820P0000000
0000000004D0oooo00<0`<300820P030`<00iP3oool009H0oooo00<0P8200000000000001P000000
0`3oool0P82000000002000000030820P03oool0oooo01<0oooo3@0000000`20P800oooo0?ooo`1D
0?ooo`050820P0000000000000000020P800A03oool00`20P80000000820P03V0?ooo`00U`3oool0
0`10@400000000000004000000040820P03oool0oooo0<30`0<0000000<0@4100?ooo`3oool04P3o
ool00`30`<0000000000000;000000030<30`03oool0oooo05@0oooo0`0000000`20P800oooo0?oo
o`120?ooo`030820P0000000P8200>H0oooo002H0?ooo`H0000000H0P8200?ooo`3oool0oooo0<30
`010@402000000030410@030`<00oooo01<0oooo00<0@4100000000000002P0000000`10@400oooo
0?ooo`1C0?ooo`<0000000<0@4100?ooo`3oool0@P3oool00`20P80000000820P03V0?ooo`00V03o
ool00`30`<00000000000003000000030820P03oool0oooo00<0oooo00D0P8200000000000000000
0820P00D0?ooo`030410@0000000000000X0000000<0@4100?ooo`3oool0C`3oool00`30`<00P820
0820P004000004@0oooo00<0P82000000020P800iP3oool009T0oooo00<0`<300000000000000`00
00060?ooo`030<30`000000000000080000000<0`<300?ooo`3oool04@3oool00`10@40000000000
000:000000030410@030`<00oooo0500oooo1020P8000`000000P8200?ooo`120?ooo`030820P000
0000P8200>H0oooo002J0?ooo`030820P0000000000000800000203oool01@10@400000000000000
0000P82001<0oooo00<0`<300000000000002`0000000`30`<00oooo0?ooo`2G0?ooo`030820P000
0000P8200>H0oooo002K0?ooo`050<30`0000000000000000030`<00203oool01@20P800@4100000
00000000@41001<0oooo00<0`<300000000000002`0000000`20P800oooo0?ooo`090?ooo`80P820
R`3oool00`30`<00P8200<30`03V0?ooo`00W03oool01020P800000000000020P80:0?ooo`050410
@0000000000000000030`<004P3oool00`30`<0000000000000;000000030410@03oool0oooo00P0
oooo0P00003o0?ooogD0oooo002M0?ooo`030410@0000000@41000/0oooo00D0`<30000000000000
00000820P00C0?ooo`030<30`0000000000000/0000000<0P8200?ooo`3oool01P3oool200000?l0
ooooM@3oool009h0oooo0P00000<0?ooo`050<30`010@400000000000010@4004`3oool00`30`<00
00000000000;000000030410@03oool0oooo00D0oooo0P00003o0?ooogD0oooo002N0?ooo`030<30
`0000000`<3000d0oooo00D0P82000000000000000000<30`00B0?ooo`030<30`0000000000000/0
000000<0@4100<30`03oool0103oool200000?l0ooooM@3oool009l0oooo00<0`<300820P03oool0
3@3oool01@30`<000000000000000000P82001<0oooo00<0@4100000000000002`0000000`30`<00
oooo0?ooo`020?ooo`8000001P3oool00`30`<00P8200820P0040820P0/0oooo1P20P8000`30`<00
oooo0?ooo`080?ooo`H0P82000<0`<300?ooo`3oool0203oool00`30`<00P8200820P0040820P0/0
oooo1P20P80;0?ooo`H0P82000<0`<300?ooo`3oool0203oool00`30`<00P8200820P0040820P0/0
oooo1P20P83^0?ooo`00X03oool00`20P800oooo0?ooo`0>0?ooo`040410@000000000000410@1<0
oooo00<0@4100000000000002`0000001020P800oooo0?ooo`3oool2000000H0oooo00<0P8200000
000000001000000;0?ooo`H0000000<0P8200?ooo`3oool0203oool6000000030820P03oool0oooo
00P0oooo00<0P8200000000000001000000;0?ooo`H000002`3oool6000000030820P03oool0oooo
00P0oooo00<0P8200000000000001000000;0?ooo`H00000kP3oool00;80oooo100000000`20P800
oooo0?ooo`0@0?ooo`030820P0000000000000/0000000<0P8200?ooo`3oool0203oool00`20P800
000000000004000000/0oooo1P0000000`20P800oooo0?ooo`080?ooo`H0000000<0P8200?ooo`3o
ool0203oool00`20P800000000000004000000/0oooo1P00000;0?ooo`H0000000<0P8200?ooo`3o
ool0203oool00`20P800000000000004000000/0oooo1P00003^0?ooo`00K`3oool00`20P800`<30
0?ooo`0Y0?ooo`030820P030`<00oooo01D0oooo00D0@41000000000000000000<30`00B0?ooo`03
0410@0000000000000/0000000<0P8200?ooo`3oool01`3oool00`30`<00P8200820P0040820P0/0
oooo1P20P8000`30`<00oooo0?ooo`080?ooo`H0P82000<0`<300?ooo`3oool0203oool00`30`<00
P8200820P0040820P0/0oooo1P20P80;0?ooo`H0P82000<0`<300?ooo`3oool0203oool00`30`<00
P8200820P0040820P0/0oooo1P20P83^0?ooo`00K@3oool00`30`<00@4100<30`00/0?ooo`80@410
5P3oool01@20P8000000000000000000@4100180oooo00<0P8200000000000002`0000000`10@400
oooo0?ooo`0O0?ooo`030<30`020P800`<300?l0ooooD`3oool006`0oooo00<0`<3000000030`<00
;P3oool00`30`<00@4100<30`00F0?ooo`050820P000000000000410@030`<004@3oool00`30`<00
00000000000<000000030<30`03oool0oooo01d0oooo00<0P82000000020P800o`3ooomC0?ooo`00
J`3oool00`10@40000000<30`00F0?ooo`030410@030`<00oooo01L0oooo00<0@41000000030`<00
5P3oool01@30`<000000000000000000`<300140oooo00<0`<300410@0000000300000000`30`<00
oooo0?ooo`0L0?ooo`030820P0000000P82006T0oooo00<0`<300820P030`<00iP3oool006X0oooo
00<0`<3000000020P800603oool00`10@400`<300?ooo`0G0?ooo`030410@0000000oooo01L0oooo
00@0@410000000000000@4104P3oool00`10@40000000000000<000000030<30`03oool0oooo01X0
oooo00<0@41000000020P800403oool40820P5D0oooo00<0P82000000020P800iP3oool006T0oooo
00<0`<300000000000006P3oool00`000000`<300?ooo`0F0?ooo`030<30`0000000@41001P0oooo
00D0P820000000000000@4100<30`00B0?ooo`030820P0000000000000/0000000<0P8200?ooo`3o
ool06@3oool2000000030820P03oool0oooo00`0oooo00<0P8200000000000000P20P8001010@400
000000000020P81B0?ooo`030820P0000000P8200>H0oooo001Y0?ooo`80000000<0P8200?ooo`3o
ool0603oool00`20P800@4100?ooo`0G0?ooo`80000000<0P8200?ooo`3oool05P3oool01@30`<00
0000000000000000`<300180oooo00<0`<300000000000002`0000000`10@400oooo0?ooo`0H0?oo
o`80000000<0P8200?ooo`3oool02`3oool00`10@4000000000000040?ooo`040<30`00000000000
0410@540oooo00<0P82000000020P800iP3oool006P0oooo00<0P8200000000000006`3oool00`20
P80000000?ooo`0G0?ooo`040820P000000000000<30`1T0oooo00@0@410000000000000@4104`3o
ool00`10@40000000000000;000000030<30`03oool0oooo01H0oooo0P0000000`20P800oooo0?oo
o`0:0?ooo`040820P000000000000820P0H0oooo00<0@410000000000000D03oool00`20P8000000
0820P03V0?ooo`00C`3oool00`30`<00P8200820P00:0820P0/0oooo00@0`<30000000000000@410
1P3oool2000000030410@030`<00oooo00H0oooo00<0@41000000030`<001P3oool01030`<000000
00000020P8070?ooo`040<30`000000000000820P0d0oooo0P0000000`10@400oooo0?ooo`0H0?oo
o`050<30`000000000000410@020P8004P3oool00`20P80000000000000;000000030410@03oool0
oooo01D0oooo0P00000=0?ooo`040410@000000000000<30`0L0oooo0P0000000`10@400oooo0?oo
o`1=0?ooo`030820P0000000P8200>H0oooo001B0?ooo`030820P0000000000000<0000000<0@410
0?ooo`3oool0303oool01020P800000000000020P8060?ooo`@0000000<0`<300?ooo`3oool00`3o
ool00`20P800000000000002000000030<30`03oool0oooo0080oooo0`0000000`20P800oooo0?oo
o`050?ooo`<0000000<0@41000000030`<002`3oool3000000030<30`03oool0oooo01P0oooo00D0
`<300410@000000000000410@00B0?ooo`030<30`0000000000000/0000000<0@4100<30`03oool0
4`3oool00`20P80000000410@00=0?ooo`<00000203oool01020P800000000000020P81>0?ooo`03
0<30`020P800`<300>H0oooo001C0?ooo`030820P00000000000008000003`3oool3000000030<30
`03oool0oooo00@0oooo0P0000020410@00300000030`<00oooo00<0oooo0`0000020820P0030410
@03oool0oooo0080oooo0`0000000`20P800oooo0?ooo`050?ooo`<0000000@0oooo0<30`010@400
`<302P3oool01020P800000000000020P80L0?ooo`050410@0000000000000000030`<004@3oool0
0`30`<00@4100000000<000000030820P03oool0oooo0140oooo00<0P82000000020P800303oool0
1030`<0000000000000000080?ooo`040<30`0000000000000000?l0oooo>03oool005@0oooo1000
00000`30`<00oooo0?ooo`0;0?ooo`040820P00000000000000000L0oooo0P20P8020?ooo`030820
P0000000oooo0080oooo00@0`<3000000000000000000P3oool00`30`<00@4100?ooo`020?ooo`03
0<30`0000000@41000P0oooo0`0000001020P800oooo0<30`000000:0?ooo`040820P00000000000
000001h0oooo00@0@410000000000000P8204P3oool00`10@40000000000000;000000030410@03o
ool0oooo0100oooo00<0P82000000020P800303oool01020P80000000000000000090?ooo`<00000
00<0P8200?ooo`3oool0o`3ooole0?ooo`00E03oool01@20P8000000000000000000P82000d0oooo
00@0@4100000000000000000303oool20410@080oooo00@0P820000000000000@4100`3oool00`10
@400`<300?ooo`0<0?ooo`040820P000000000000410@080oooo0P30`<090?ooo`050820P0000000
000000000030`<007P3oool01020P800000000000010@40B0?ooo`030<30`0000000000000`00000
00<0`<300?ooo`3oool03P3oool2000000030<30`03oool0oooo00X0oooo00D0P820000000000000
00000820P0080?ooo`040820P0000000000000000?l0oooo=`3oool005@0oooo00D0P82000000000
000000000820P00=0?ooo`@000003@3oool010000000oooo0?ooo`20P802000000030820P03oool0
oooo0100oooo00@0P82000000000000000003@3oool01@20P8000000000000000000P82001l0oooo
00@0P82000000000000000004P3oool00`20P80000000000000<000000030820P03oool0oooo00d0
oooo0P00000=0?ooo`050820P0000000000000000020P800203oool01@20P8000000000000000000
P8200?l0oooo=P3oool005@0oooo00<0`<300000000000000P00000=0?ooo`<0000000<0@4100?oo
o`3oool02`3oool00`20P800@4100?ooo`03000000030<30`03oool0oooo0100oooo00@0`<300000
0000000000003P3oool3000000030820P03oool0oooo01h0oooo00@0P820000000000000@4104P3o
ool00`30`<0000000000000<000000030820P03oool0oooo00/0oooo00<0P8200000000000003@3o
ool01@20P8000000000000000000P82000P0oooo00D0`<3000000000000000000820P03o0?ooocH0
oooo001E0?ooo`@0000000<0`<300?ooo`3oool02@3oool01@20P8000000000000000000P82000h0
oooo00<0@4100<30`00000000P00000D0?ooo`<0000000<0P8200?ooo`3oool02`3oool300000003
0410@03oool0oooo01l0oooo00D0`<300410@000000000000<30`00B0?ooo`030820P00000000000
00`0000000<0`<300?ooo`3oool02@3oool2000000030820P03oool0oooo00/0oooo00D0`<300000
0000000000000820P0090?ooo`@00000o`3ooolf0?ooo`00@03oool;0820P0X0oooo00D0P8200000
0000000000000820P00;0?ooo`@0000000<0P8200?ooo`3oool0303oool01@30`<00@41000000000
0000@41001@0oooo00@0P820000000000000@4103@3oool4000002<0oooo00@0@410000000000000
P8204P3oool00`30`<0000000000000<000000030410@03oool0oooo00L0oooo00<0P82000000000
00003`3oool4000000T0oooo00D0@41000000000000000000<30`03o0?ooocD0oooo00100?ooo`03
0410@0000000000000P0000000<0`<300?ooo`3oool01`3oool01@20P8000000000000000000@410
00/0oooo100000000`20P800oooo0?ooo`0=0?ooo`040410@000000000000820P1@0oooo00@0P820
00000000000000003@3oool4000002@0oooo00@0`<30000000000000@4104`3oool00`10@4000000
0000000;000000030410@030`<00oooo00D0oooo00@0`<30000000000000P8203`3oool4000000T0
oooo00D0P82000000000000000000820P03o0?ooocD0oooo00100?ooo`030820P0000000000000P0
000000<0P8200?ooo`3oool0203oool4000000/0oooo100000000`20P800oooo0?ooo`0=0?ooo`<0
000000<0`<300?ooo`3oool04`3oool3000000030<30`03oool0oooo00X0oooo1000000U0?ooo`05
0<30`010@400000000000030`<004P3oool00`10@40000000000000<000000030820P03oool0oooo
00<0oooo00<0@410000000000000403oool01010@40000000000000000090?ooo`050820P0000000
000000000020P800o`3ooole0?ooo`00@@3oool:0820P0030<30`03oool0oooo00P0oooo00D0@410
00000000000000000820P00:0?ooo`@0000000<0P8200?ooo`3oool03@3oool3000001H0oooo00@0
@410000000000000P820303oool4000002L0oooo00D0@410000000000000P8200<30`00A0?ooo`03
0<30`0000000000000`0000000<0@4100?ooo`3oool00P3oool2000000030410@03oool0oooo00h0
oooo00<0P8200000000000003`00003o0?ooocD0oooo001F0?ooo`050820P0000000000000000020
P8002P3oool4000000030820P03oool0oooo00`0oooo00D0P82000000000000000000820P00E0?oo
o`040820P00000000000000000`0oooo1000000X0?ooo`050<30`0000000000000000030`<004@3o
ool00`30`<00@4100000000=000000030<30`03oool0P8200080000000<0`<300?ooo`3oool03P3o
ool01@20P8000000000000000000@41000T0P8201000001;0?ooo`030<30`020P800`<300>H0oooo
001F0?ooo`030<30`00000000000008000002P3oool4000000030820P03oool0oooo00`0oooo00H0
P820000000000000P82000000030`<0D0?ooo`040<30`00000000000000000`0oooo1000000Z0?oo
o`040820P000000000000410@180oooo00<0@410000000000000300000000`10@40000000000000C
0?ooo`@000002@3oool01@20P8000000000000000000`<3004X0oooo00<0P82000000020P800iP3o
ool005L0oooo1000000;0?ooo`<0000000<0P8200?ooo`3oool0303oool3000000030<30`020P800
@41001D0oooo0`0000000`20P800oooo0?ooo`090?ooo`<0000000<0P8200?ooo`3oool0:@3oool0
0`30`<00@4100410@00C0?ooo`030<30`0000000000000d0000000<0P8200?ooo`3oool04@3oool0
1010@40000000000000000090?ooo`050820P0000000000000000020P800BP3oool00`20P8000000
0820P03V0?ooo`00F03oool3000000030820P03oool0oooo00P0oooo0`0000000`10@400oooo0?oo
o`0;0?ooo`040<30`0000000000000000080oooo0P10@4020?ooo`030<30`020P800`<3000l0oooo
00@0P820000000000000P8202P3oool01@20P8000000000000000000P82004<0oooo00<0@4100000
000000003@0000000`30`<00oooo0?ooo`0?0?ooo`050820P0000000000000000030`<00203oool0
1@20P8000000000000000000P82004X0oooo00<0P82000000020P800iP3oool005P0oooo0`000000
0`10@400oooo0?ooo`080?ooo`040410@00000000000000000`0oooo00D0P8200000000000000000
0820P0030?ooo`H000003`3oool01030`<00000000000000000:0?ooo`050820P000000000000000
0030`<00A03oool00`20P80000000000000=000000030410@03oool0oooo00l0oooo0`0000000`20
P800oooo0?ooo`070?ooo`<0000000<0P8200?ooo`3oool0B03oool00`20P80000000820P03V0?oo
o`00F03oool01020P800000000000000000:0?ooo`040820P00000000000000000T0oooo00<0P820
000000000000100000001@30`<00oooo0?ooo`3oool0`<3000D000003@3oool30820P0<000000`20
P8070?ooo`040820P00000000000000004L0oooo00<0P8200000000000003@0000000`30`<00oooo
0?ooo`0=0?ooo`040820P00000000000000000T0oooo0`0000000`20P800oooo0?ooo`180?ooo`03
0820P0000000P8200>H0oooo001H0?ooo`050<30`0000000000000000030`<002P3oool3000000/0
oooo0P20P8000`10@40000000<30`0060?ooo`040<30`000000000000<30`0d0oooo00<0`<300820
P00000000`0000000`10@400P8200820P0070?ooo`040410@000000000000820P4P0oooo00<0`<30
0000000000003@0000000`10@400oooo0?ooo`0=0?ooo`<0000000<0`<300?ooo`3oool01P3oool3
000000030820P03oool0oooo04P0oooo00<0P82000000020P800803oool00`000000`<300?ooo`33
0?ooo`00F@3oool3000000030820P03oool0oooo00P0oooo0`0000000`20P800oooo0?ooo`0W0?oo
o`<0000000<0P8200?ooo`3oool01`3oool3000004/0oooo4000000>0?ooo`040820P00000000000
0820P0P0oooo0`00001^0?ooo`<00000``3oool005T0oooo0`0000000`10@400oooo0?ooo`080?oo
o`040820P000000000000820P2X0oooo00<0@4100000000000002@3oool3000004/0oooo00<0`<30
0410@00000003@0000000`10@400`<300?ooo`0;0?ooo`040<30`00000000000000000P0oooo0`00
001^0?ooo`040410@000000000000410@<80oooo001@0?ooo`030<30`03oool0oooo00H0oooo00@0
P8200000000000000000203oool00`20P800`<300?ooo`03000002/0oooo00<0@41000000030`<00
1`3oool01020P800000000000020P81=0?ooo`030820P0000000000000d0000000<0P8200?ooo`3o
ool02P3oool01030`<00000000000020P8070?ooo`80000000<0@4100?ooo`3oool0KP3oool00`20
P80000000410@0310?ooo`00D@3oool00`20P800oooo0?ooo`050?ooo`050<30`000000000000000
0030`<00203oool00`20P800oooo0<30`002000000030<30`03oool0oooo02P0oooo00<0`<300000
0020P8001`3oool00`10@40000000410@01?0?ooo`030<30`010@400000000d0000000<0@4100<30
`03oool02P3oool01030`<00000000000030`<050?ooo`040820P000000000000<30`780oooo0P10
@4300?ooo`00D@3oool00`10@400oooo0?ooo`060?ooo`<0000000<0P8200?ooo`3oool01P3oool0
1P10@400oooo0?ooo`10@40000000820P2/0oooo00<0P8200410@03oool01@3oool01030`<000000
00000030`<1A0?ooo`030820P0000000000000d0000000<0P8200?ooo`3oool02@3oool01@30`<00
000000000020P800`<300080oooo00@0P820000000000000`<30M03oool20410@;l0oooo001A0?oo
o`030820P010@400oooo00H0oooo00@0@4100000000000000000203oool01`000000oooo0?ooo`3o
ool0@41000000030`<00:`3oool00`20P800oooo0?ooo`040?ooo`030410@0000000`<3005<0oooo
00<0`<300410@00000003P0000000`10@400oooo0?ooo`090?ooo`80P820100000000`20P800`<30
0?ooo`1e0?ooo`80@410_P3oool00540oooo00<0`<3000000020P8001P3oool01020P80000000000
000000070?ooo`030820P0000000P8200080oooo00<0`<3000000010@400<@3oool00`30`<000000
0820P01F0?ooo`030<30`0000000000000h0000000<0P8200?ooo`3oool0QP3oool00`000000`<30
0?ooo`2l0?ooo`00DP3oool3000000030820P030`<00oooo0080oooo00D0`<300000000000000000
0820P0050?ooo`040410@000000000000820P0<0oooo00<0`<3000000020P800;`3oool00`30`<00
00000820P01I0?ooo`030<30`0000000000000d0000000<0@4100<30`03oool0K@3oool01@20P800
000000000010@400`<3000D0oooo00@0`<30000000000000P8202P3oool2000000030<30`03oool0
oooo0;X0oooo001B0?ooo`030820P0000000000001<000001@3oool00`10@400`<300?ooo`0/0?oo
o`030<30`0000000`<3005`0oooo00<0@4100000000000003@0000000`20P800oooo0?ooo`1Z0?oo
o`030410@0000000000000@0000000@0`<300?ooo`3oool0oooo100000000`10@400oooo0?ooo`07
0?ooo`<0000000<0`<300?ooo`3oool0^@3oool006h0oooo00<0P8200410@03oool0:P3oool00`30
`<00@4100?ooo`1N0?ooo`030<30`010@400000000h0000000<0P8200?ooo`3oool0I`3oool01@20
P8000000000000000000@4100080P8200P0000000`30`<00oooo0?ooo`03000000030?ooo`30`<00
@41000L0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`2h0?ooo`00L03oool00`30
`<00oooo0?ooo`0X0?ooo`030<30`03oool0oooo0600oooo00<0P8200000000000003@0000000`10
@400`<300?ooo`1F0?ooo`030<30`020P800`<3000d0oooo0`0000000`10@400oooo0?ooo`020?oo
o`050820P0000000`<300?ooo`20P8000P0000001020P800oooo0820P020P8060?ooo`060820P000
0000000000000030`<000000^P3oool00?l0oooo00<0`<300410@00000003P0000000`10@400`<30
0?ooo`1D0?ooo`030820P0000000P82000d0oooo0`0000000`30`<00oooo0?ooo`030?ooo`040<30
`0000000`<300820P080000000@0P8200?ooo`3oool0`<301P3oool01`20P8000000000000000000
oooo0820P010@400^@3oool00?l0oooo0P3oool00`30`<0000000000000>000000030820P03oool0
oooo0580oooo00<0P82000000020P8003@3oool3000000L0oooo00<0`<3000000030`<000`000009
0?ooo`040820P000000000000410@080oooo00<0@4100820P03oool0]`3oool00?l0oooo103ooolA
000000030820P03oool0oooo0500oooo00<0P82000000020P8003@3oool3000000P0oooo00<00000
0820P00000000P0000090?ooo`040820P000000000000820P0<0oooo00<000000?ooo`3oool0]P3o
ool00?l0oooo1@3oool00`10@40000000000000>000000030410@03oool0oooo04l0oooo00<0P820
00000020P8003@3oool00`10@4000000000000080?ooo`030<30`0000000@4100080000000<0`<30
0?ooo`3oool01P3oool01020P800000000000020P8030?ooo`80@410]`3oool00?l0oooo1`3oool0
0`10@40000000000000>000000030820P03oool0oooo04d0oooo00<0P82000000020P8003@3oool0
1020P800000000000020P8080?ooo`050820P0000000000000000020P800203oool01020P8000000
00000020P8040?ooo`0300000020P800oooo0;D0oooo003o0?ooo`P0oooo00<0`<300410@0000000
3`0000000`30`<00oooo0?ooo`1;0?ooo`030820P0000000P82000d0oooo00@0`<30000000000000
@4102@3oool4000000P0oooo0`0000000`20P800oooo0?ooo`020?ooo`030<30`0000000P8200;D0
oooo003o0?ooo`X0oooo00<0`<300410@00000003P0000000`10@400`<300?ooo`1:0?ooo`030<30
`020P800`<3000h0oooo00<0@4100000000000002@3oool01020P80000000000000000080?ooo`<0
000000<0P8200?ooo`3oool00`3oool00`20P80000000<30`02d0?ooo`00o`3oool<0?ooo`030820
P0000000000000h0000000<0@4100?ooo`3oool0F@3oool01030`<00000000000020P8090?ooo`<0
000000<0P8200?ooo`3oool01@3oool3000000030<30`03oool0oooo00@0oooo00<0P8200410@03o
ool0/`3oool00?l0oooo3P3oool00`20P80000000000000>000000030820P03oool0oooo05P0oooo
00@0P820000000000000`<30203oool01020P800000000000010@4070?ooo`<00000203oool00`00
0000`<300?ooo`2b0?ooo`00o`3oool@0?ooo`030820P0000000000000h0000000<0P8200?ooo`3o
ool0E`3oool00`10@40000000410@0080?ooo`040<30`00000000000000000L0oooo0`0000080?oo
o`030820P010@400oooo0;80oooo003o0?oooa40oooo00<0`<300410@00000003`0000000`20P800
oooo0?ooo`1F0?ooo`80000000<0P8200?ooo`3oool01P3oool3000000030<30`03oool0oooo00<0
oooo00@0`<3000000000000000002@3oool00`000000`<300?ooo`2a0?ooo`00o`3ooolC0?ooo`03
0820P0000000000000l0000000<0P8200<30`03oool0E03oool01030`<00000000000020P8070?oo
o`<0000000<0P8200?ooo`3oool00`3oool01020P80000000000000000080?ooo`030410@0000000
P8200;80oooo003o0?oooaD0oooo00<0P8200000000000003`0000000`10@400`<300?ooo`1D0?oo
o`030410@0000000@41000D0oooo00<0`<300000000000000P0000040?ooo`050<30`00000000000
00000010@4001`3oool01020P800000000000020P82b0?ooo`00o`3ooolG0?ooo`030820P0000000
000000l0000000<0@4100<30`03oool0D`3oool01020P800@41000000020P8020?ooo`030<30`000
0000@41000<0000000<0`<300820P00000001@0000000`20P800oooo0?ooo`050?ooo`040820P000
000000000820P;80oooo003o0?oooaT0oooo00<0@410000000000000400000000`20P800oooo0?oo
o`1B0?ooo`030<30`020P80000000080000000<0P8200?ooo`20P8000P0000001020P800oooo0?oo
o`30`<020820P0030410@0000000oooo00L0oooo00<0`<3000000010@400/`3oool00?l0oooo6P3o
ool00`30`<00@4100000000A000000030<30`03oool0oooo05L0oooo00@0`<30000000000000@410
a@3oool00?l0oooo703oool00`20P80000000000000A000005T0oooo0`0000350?ooo`00o`3ooolM
0?ooo`030<30`010@40000000140000000<0P8200?ooo`3oool0=03oool00`30`<00P8200<30`00N
0?ooo`<0000000<0`<300?ooo`3oool0`P3oool00?l0oooo7`3oool00`30`<00@4100000000A0000
00030820P03oool0oooo0380oooo00<0P82000000020P8007P3oool01020P800000000000020P834
0?ooo`00o`3ooolR0?ooo`030820P000000000000100000000<0P8200?ooo`3oool0<03oool00`20
P80000000820P00N0?ooo`040<30`000000000000410@<@0oooo003o0?ooob@0oooo00<0P8200000
00000000400000000`20P800oooo0?ooo`0^0?ooo`030820P0000000P82001l0oooo0`0000340?oo
o`00o`3ooolV0?ooo`030820P000000000000140000000<0P8200?ooo`3oool0:`3oool00`20P800
00000820P00O0?ooo`040410@0000000000000000<<0oooo003o0?ooobP0oooo00<0P82000000000
00004P0000000`20P800oooo0?ooo`0X0?ooo`030820P0000000P82001l0oooo00@0P82000000000
00000000``3oool00?l0oooo:P3oool00`20P80000000000000B000000030820P03oool0oooo02H0
oooo00<0`<300820P030`<007`3oool01@20P8000000000000000000P8200<80oooo003o0?ooob`0
oooo00<0P8200000000000004P0000000`20P800`<300?ooo`140?ooo`030820P010@400000000<0
000000<0@4100?ooo`3oool0`03oool00?l0oooo;P3oool00`20P80000000000000B000000030410
@030`<00oooo04L0oooo0P20P8320?ooo`00o`3oool`0?ooo`030<30`010@40000000180000000<0
P8200<30`03oool0o`3oool:0?ooo`00o`3ooolb0?ooo`030<30`010@40000000180000000<0@410
0820P03oool0o`3oool80?ooo`00o`3ooold0?ooo`030<30`010@400000001<000000P20P83o0?oo
o`H0oooo003o0?ooocH0oooo00<0`<300820P0000000500000000`20P800`<300?ooo`3o0?ooo`80
oooo003o0?ooocT0oooo5`0000000`20P800oooo0?ooo`3n0?ooo`00o`3ooolj0?ooo`030<30`010
@400000001D0000000<0P8200?ooo`3oool0o03oool00?l0oooo?@3oool00`30`<00@4100000000D
000000030410@030`<00oooo0?X0oooo003o0?oood00oooo00<0P820000000000000500000000`20
P800`<300?ooo`2?0?ooo`030820P03oool0oooo01/0oooo00<0`<300820P03oool0:@3oool00`20
P800`<300?ooo`0K0?ooo`00o`3ooom20?ooo`030820P010@400000001D000000P20P8000`30`<00
oooo0?ooo`090?ooo`030<30`020P800`<3007h0oooo0P0000000`20P800oooo0?ooo`0H0?ooo`03
0820P010@400oooo02/0oooo0P10@40K0?ooo`00o`3ooom40?ooo`030<30`020P800000001L00000
00<0P8200?ooo`3oool01`3oool00`20P80000000820P01n0?ooo`040410@000000000000410@1L0
oooo00<0`<3000000010@400;P3oool00`30`<00@4100<30`00I0?ooo`00o`3ooom70?ooo`030820
P010@400000001H0000000<0@4100820P03oool01@3oool00`20P80000000820P0200?ooo`030<30
`0000000@41001D0oooo00<0@41000000020P8005P3oool00`10@400`<300?ooo`0G0?ooo`030410
@0000000`<3001P0oooo003o0?ooodT0oooo00<0`<300820P010@4005`0000000`10@400P8200?oo
o`020?ooo`030820P0000000P8200880oooo0P10@40C0?ooo`030<30`0000000P82001P0oooo00<0
@4100<30`03oool05`3oool00`10@40000000?ooo`0G0?ooo`00o`3ooom<0?ooo`030<30`020P800
000001L0000000D0@4100820P010@40000000820P0230?ooo`80@4104@3oool00`30`<0000000000
000J0?ooo`0300000030`<00oooo01H0oooo00<0`<3000000010@4005`3oool00?l0ooooC`3oool0
0`30`<00@4100000000H000000030410@020P800oooo0880oooo0P10@40@0?ooo`80000000<0P820
0?ooo`3oool0603oool00`20P800@4100?ooo`0G0?ooo`80000000<0P8200?ooo`3oool0503oool0
0?l0ooooDP3oool00`20P800@4100000000I000000030820P030`<00oooo07l0oooo00<000000<30
`03oool03@3oool00`20P80000000000000K0?ooo`030820P0000000oooo01L0oooo00@0P8200000
00000000P8205@3oool00?l0ooooE@3oool00`20P80000000000000I000000030410@020P800P820
07`0oooo0P0000000`30`<00oooo0?ooo`0:0?ooo`040<30`000000000000410@0H0oooo00@0P820
00000010@400`<301`3oool00`30`<0000000410@0060?ooo`040<30`00000000000000000L0oooo
00@0`<30000000000000P8203@3oool3000000030<30`03oool0oooo0180oooo003o0?oooeP0oooo
0P20P80L00000080P820N03oool3000000030<30`03oool0oooo00T0oooo00@0P820000000000000
P8201P3oool01@20P8000000000000000000`<3000H0oooo100000000`30`<00oooo0?ooo`020?oo
o`@000001`3oool3000000030410@0000000P82000/0oooo0`0000000`10@400oooo0?ooo`0B0?oo
o`00o`3ooomK0?ooo`030820P0000000000001/0000000<0P8200?ooo`3oool0M03oool4000000/0
oooo0`0000000`20P800oooo0?ooo`040?ooo`030820P00000000000008000001@3oool500000003
0820P03oool0oooo0080oooo100000070?ooo`<0000000@0oooo0820P0000000P8202P3oool01020
P800000000000000000D0?ooo`00o`3ooomL0?ooo`030<30`020P800000001`0000000<0@4100820
P030`<00L@3oool01020P80000000000000000020410@0T0oooo00@0`<3000000000000000001`3o
ool01020P80000000<30`030`<020410@0@0oooo0`0000001020P800oooo0410@030`<030?ooo`04
0410@000000000000820P0L0oooo0`0000001@30`<00oooo0?ooo`000000`<3000T0oooo00D0P820
00000000000000000<30`00C0?ooo`00o`3ooomO0?ooo`030<30`020P800000001h000000P20P81]
0?ooo`070820P000000000000000003oool0@4100<30`0080?ooo`040820P00000000000000000/0
oooo00<0`<3000000030`<000P3oool01@20P8000000000000000000P8200080oooo00<000000?oo
o`3oool00P3oool00`20P800`<300?ooo`070?ooo`040410@000000000000820P080oooo00<0`<30
0410@03oool0203oool01@20P8000000000000000000P82001<0oooo003o0?ooof80oooo00<0P820
0410@00000007`0000000`10@400P8200<30`01X0?ooo`080820P000000000000000003oool0`<30
00000030`<070?ooo`@00000303oool01@30`<0000000?ooo`3oool0P82000<000000`3oool20<30
`0d0oooo00@0P82000000000000000003@3oool00`20P800000000000002000001<0oooo003o0?oo
ofH0oooo0P20P80Q00000080P82000<0`<300?ooo`3oool0H@3oool01020P800000000000020P802
0?ooo`030<30`010@400oooo00H0oooo0`0000000`10@400oooo0?ooo`0;0?ooo`030820P010@400
oooo00<0000000<0@4100?ooo`3oool0403oool01030`<00000000000000000>0?ooo`@000004`3o
ool00?l0ooooJP3oool00`20P800@4100000000Q00000080P82000<0`<300?ooo`3oool0G03oool0
1020P800000000000020P8030?ooo`80@4101@3oool01@30`<000000000000000000P82000h0oooo
00<0@4100<30`00000000P0000000`20P800oooo0?ooo`0A0?ooo`<0000000<0P8200?ooo`3oool0
2`3oool4000000030<30`03oool0oooo0100oooo003o0?ooofd0oooo00<0`<300820P010@4008P00
00000`10@400P8200820P01J0?ooo`040820P000000000000820P0@0oooo00<000000820P03oool0
0`3oool01@20P8000000000000000000P82000h0oooo00<0`<300410@00000000P0000000`30`<00
oooo0?ooo`0A0?ooo`040820P000000000000410@0d0oooo100000000`20P800oooo0?ooo`0@0?oo
o`00o`3oooma0?ooo`030<30`020P800@41002D000001020P81B0?ooo`<0000000<0P8200?ooo`3o
ool00P3oool00`30`<0000000820P0030?ooo`050820P0000000000000000020P8003`3oool01010
@400000000000000000D0?ooo`040820P00000000000000000d0oooo100000000`20P800oooo0?oo
o`0@0?ooo`00o`3ooome0?ooo`030<30`020P800@41002T000001020P81:0?ooo`<0000000<0P820
0?ooo`3oool00`3oool00`20P80000000<30`0020?ooo`050820P0000000000000000020P8003`3o
ool3000000030410@03oool0oooo01<0oooo0`0000000`20P800oooo0?ooo`0:0?ooo`@0000000<0
P8200?ooo`3oool0403oool00?l0ooooN@3oool20820P2h000001020P8120?ooo`<0000000<0`<30
0?ooo`3oool0103oool01@20P800@4100?ooo`3oool0P82000<0000000<0P8200?ooo`3oool03@3o
ool3000000030820P03oool0oooo01<0oooo00@0@4100000000000000000303oool4000000030820
P03oool0oooo0100oooo003o0?ooogh0oooo0P20P8000`10@40000000000000^000000@0P820>P3o
ool3000000P0oooo00@000000<30`03oool0P8200`0000000`20P800oooo0?ooo`0<0?ooo`030820
P00000000000008000005@3oool01@20P8000000000000000000P82000/0oooo100000000`20P800
oooo0?ooo`0@0?ooo`00o`3ooon30?ooo`80P820=00000000`10@400P8200820P0090820P0030<30
`03oool0oooo02L0oooo0`0000080?ooo`040820P010@400oooo0820P0<0000000<0P8200?ooo`3o
ool0303oool01P20P8000000000000000000P8200410@1@0oooo00D0`<3000000000000000000820
P00;0?ooo`@0000000<0P8200?ooo`3oool0403oool00?l0ooooQ`3oool00`20P800000000000018
000000d0P8203`3oool01030`<0000000000000000090?ooo`0300000030`<00oooo00<0000000<0
P8200?ooo`3oool0303oool3000000040820P03oool000000<30`1@0oooo1000000;0?ooo`@00000
4`3oool00?l0ooooRP3oool01030`<00P8200820P020P81A000000l0oooo00@0P820000000000000
0000203oool01010@40000000820P03oool3000000030410@03oool0oooo00/0oooo00@0`<300000
0000000000000P3oool01`30`<0000000<30`03oool0`<300820P030`<003`3oool01020P8000000
00000000000:0?ooo`030820P00000000000008000004`3oool00?l0ooooT03oool00`20P8000000
0000001<000000l0oooo100000070?ooo`050820P000000000000820P03oool01000000=0?ooo`<0
000000D0P8200?ooo`3oool0oooo0820P005000000l0oooo00D0P82000000000000000000820P009
0?ooo`030820P00000000000008000004`3oool00?l0ooooT`3oool01030`<00P8200820P010@418
000000`0oooo0P20P8001@10@4000000000000000000P82000L0oooo00H0P820000000000000P820
0?ooo`20P803000000T0oooo00<0`<300820P020P800100000001@20P800oooo0?ooo`3oool0`<30
00D00000403oool3000000030820P03oool0oooo00L0oooo00D0P82000000000000000000820P00C
0?ooo`00o`3ooonI0?ooo`040<30`020P800P8200410@4800000303oool00`20P800@41000000003
000000030<30`03oool0oooo00D0oooo00H0P820000000000000`<300?ooo`30`<03000000T0oooo
00<0`<300820P00000000`0000000`10@400oooo0?ooo`030?ooo`050<30`010@400000000000010
@4003@3oool00`10@400000000000006000000030820P03oool0oooo00@0oooo00D0P82000000000
000000000<30`00C0?ooo`00o`3ooonO0?ooo`030<30`020P800P8200080P820>`00000@0?ooo`03
0<30`020P800oooo00P0oooo00<0P8200<30`03oool00P3oool3000000030<30`03oool0oooo00X0
oooo00<0`<300820P03oool01`3oool20820P100oooo00<0P8200000000000000P0000090?ooo`<0
000000<0@4100?ooo`3oool04P3oool00?l0ooooZ03oool40820P3<00000803oool01020P8000000
00000020P80Z0?ooo`040820P000000000000820P0P0oooo0`0000000`20P800oooo0?ooo`0B0?oo
o`00o`3ooonb0?ooo`H0P82000<0@4100000000000009000000Q0?ooo`<00000:`3oool00`30`<00
00000410@0070?ooo`040820P00000000000000001D0oooo003o0?oookh0oooo00<0`<300820P020
P8001020P80J00000240oooo00@0`<30000000000000`<30:`3oool00`10@40000000?ooo`060?oo
o`030410@0000000@41001H0oooo003o0?ooofP0oooo0P20P81X0?ooo`d0P8208P3oool00`10@400
00000820P00/0?ooo`0300000030`<00oooo00@0oooo00@0`<30000000000000`<305P3oool00?l0
ooooI`3oool00`30`<0000000000000200000080P82000<0`<300?ooo`3oool0T@3oool00`10@400
00000<30`00[0?ooo`80`<301@3oool00`10@40000000<30`00G0?ooo`00o`3ooomW0?ooo`030<30
`020P800@41000H0000000<0@4100820P020P800S`3oool00`30`<0000000410@00a0?ooo`030<30
`0000000P82001P0oooo003o0?ooof/0oooo00<0`<300820P020P8001`0000020820P8`0oooo00<0
`<30000000000000;`3oool00`30`<0000000820P00I0?ooo`00o`3ooom`0?ooo`80P8201`000002
0820P0030<30`03oool0oooo02P0oooo00<0`<300?ooo`3oool0G03oool00`20P800@4100?ooo`0/
0?ooo`030<30`0000000`<3001X0oooo003o0?ooog@0oooo00<0`<300820P010@4001P0000000`10
@400P8200820P00W0?ooo`030820P010@400oooo05`0oooo00<0`<300410@030`<00:P3oool00`30
`<00@4100?ooo`0K0?ooo`00o`3ooomh0?ooo`030<30`020P800P82000L000000P20P80T0?ooo`03
0410@0000000P82005d0oooo00<0`<300?ooo`3oool0:03oool00`30`<00oooo0?ooo`0K0?ooo`00
o`3ooomm0?ooo`T000008`3oool300000:D0oooo003o0?ooogl0oooo0P20P8000`10@40000000000
0004000000030410@020P800`<3001h0oooo00D0P820000000000000@4100<30`02S0?ooo`00o`3o
oon30?ooo`030<30`020P800@41000H0000000<0@4100820P020P8006`3oool01P10@40000000000
00000000@4100<30`:40oooo003o0?ooohP0oooo0P20P80700000080P820603oool5000000030410
@030`<00oooo09h0oooo003o0?oooh`0oooo0P20P8000`10@400000000000004000000030410@020
P800`<3001<0oooo00<0`<30000000000000100000000`20P800oooo0?ooo`2L0?ooo`00o`3ooon@
0?ooo`030<30`020P800@41000H0000000<0@4100820P020P800403oool00`10@400000000000005
000000030820P03oool0oooo09X0oooo003o0?oooiD0oooo0P20P80700000080P820303oool00`30
`<00000000000007000000030820P03oool0oooo09P0oooo003o0?oooiT0oooo0P20P8000`10@400
000000000004000000030410@020P800`<3000P0oooo00<0@4100000000000001`0000000`10@400
`<300?ooo`2G0?ooo`00o`3ooonM0?ooo`030<30`020P800@41000H0000000<0@4100820P020P800
103oool00`30`<00000000000009000000030820P03oool0oooo09D0oooo003o0?oooj80oooo0P20
P80700000080P82000<0oooo0000000000002`0000000`30`<00oooo0?ooo`2C0?ooo`00o`3ooonV
0?ooo`80P82000<0@4100000000000004@0000000`10@400`<300?ooo`2B0?ooo`00o`3ooonZ0?oo
o`030<30`020P800@4100140000000<0P8200?ooo`3oool0T03oool00?l0oooo[@3oool00`10@400
00000000000@000000030<30`03oool0oooo08h0oooo003o0?oooj`0oooo5@0000000`20P800oooo
0?ooo`2=0?ooo`00o`3ooon[0?ooo`030410@0000000000001@0000000<0P8200<30`03oool0S03o
ool00?l0ooooZ@3oool00`30`<00@4100000000H000000030820P03oool0oooo08X0oooo003o0?oo
ojL0oooo00<0P8200410@00000006`0000000`10@400`<300?ooo`290?ooo`00o`3ooonU0?ooo`03
0820P0000000000001l0000000<0@4100?ooo`3oool0Q`3oool00?l0ooooX`3oool00`20P8000000
0000000>000000X0P820T`3oool00?l0ooooXP3oool80820P0030<30`03oool0oooo0:@0oooo003o
0?ooool0ooooDP3oool00?l0ooooo`3ooomB0?ooo`00o`3ooooo0?oooe80oooo003o0?ooool0oooo
DP3oool00?l0ooooo`3ooomB0?ooo`00o`3ooooo0?oooe80oooo003o0?ooool0ooooDP3oool00?l0
ooooo`3ooomB0?ooo`00o`3ooooo0?oooe80oooo003o0?ooogP0oooo00<0`<300?ooo`3oool0JP3o
ool00`30`<00oooo0?ooo`1Y0?ooo`00o`3ooomf0?ooo`030<30`010@400oooo06d0oooo00<0@410
0820P03oool0J03oool00?l0ooooM@3oool20410@700oooo00<0P8200410@03oool0I`3oool00?l0
ooooL`3oool00`30`<00@4100410@01H0?ooo`030<30`03oool0oooo01L0oooo00<0P82000000020
P800IP3oool00?l0ooooL`3oool00`000000@4100?ooo`1H0?ooo`030<30`010@400P82001P0oooo
00<0@41000000010@400I@3oool00?l0ooooL@3oool01030`<00000000000030`<1K0?ooo`030820
P010@400oooo01L0oooo0P0000000`30`<00oooo0?ooo`1R0?ooo`00o`3ooom`0?ooo`040<30`000
000000000410@5d0oooo00<0@4100820P03oool05`3oool2000000030<30`03oool0oooo0640oooo
003o0?ooog00oooo00@0@410000000000000`<30G@3oool00`20P80000000?ooo`0G0?ooo`030410
@0000000@41006<0oooo003o0?ooofl0oooo00@0`<3000000000000000001@3oool00`30`<00P820
0<30`0090?ooo`030820P030`<00oooo02D0oooo0P20P8000`30`<00oooo0?ooo`050?ooo`80P820
103oool20820P0T0oooo00<0`<300820P03oool01`3oool00`10@40000000<30`0070?ooo`030<30
`020P800P82000d0oooo00@0`<30000000000000P820HP3oool00?l0ooooEP3oool01030`<00P820
0820P010@406000000<0P820303oool3000000H0oooo00@0P820000000000000@4101`3oool01010
@400000000000020P80S0?ooo`030<30`000000000000080000000<0@4100<30`03oool00P3oool0
0`30`<00000000000002000000030<30`03oool0oooo00<0000000<0`<300?ooo`3oool0103oool0
1@30`<00000000000010@400`<3000@0oooo00D0`<3000000000000000000820P0060?ooo`030<30
`000000000000080000000<0P8200?ooo`3oool02P3oool300000680oooo003o0?oooeX0oooo00<0
`<300000000000000P0000000`30`<00oooo0?ooo`0<0?ooo`040<30`00000000000000000H0oooo
00D0P82000000000000000000410@0050?ooo`030<30`000000000000080000000<0P8200?ooo`3o
ool07`3oool00`30`<00000000000005000000040<30`03oool0oooo0820P0<0000000@0P8200410
@030`<00oooo100000000`30`<00oooo0?ooo`030?ooo`030410@0000000000000800000103oool0
1@20P8000000000000000000P82000H0oooo00D0P82000000000000000000<30`0020410@0/0oooo
00@0@410000000000000P820H@3oool00?l0ooooF`3oool4000000l0oooo00@0P820000000000000
P8201P3oool01P20P80000000820P020P80000000820P0@0oooo00H0P820000000000000P8200?oo
o`00000Q0?ooo`050820P0000000000000000020P8000P3oool200000080oooo00@0P82000000000
000000000P3oool01@000000oooo000000000000oooo008000001@3oool3000000030?ooo`20P800
P82000<0oooo00D0P82000000000000000000820P0060?ooo`040820P0000000000000000080oooo
0P20P80:0?ooo`040820P000000000000820P640oooo003o0?oooe/0oooo00D0P820000000000000
00000<30`00>0?ooo`<0000000<0P8200?ooo`3oool0103oool01P30`<00P8200?ooo`3oool0P820
000000@0oooo00L0@410000000000000P8200?ooo`30`<00@4100100oooo00<0P8200?ooo`3oool0
3@3oool3000000050410@03oool0oooo0?ooo`30`<000P10@4020?ooo`<0000000<0P8200?ooo`20
P8000P20P8001@30`<00oooo0?ooo`000000P82000<0oooo00@0`<3000000000000000000P3oool0
0`10@400`<300?ooo`020?ooo`030820P0000000@41000L0oooo00P0P82000000000000000000820
P03oool0`<30000000X0oooo00@0P8200000000000000000H@3oool00?l0ooooG03oool300000003
0820P03oool0oooo00/0oooo00D0`<3000000000000000000820P00;0?ooo`80@4100`3oool30000
00050<30`03oool0oooo0410@030`<003`3oool00`000000oooo0?ooo`0=0?ooo`<0000000<0`<30
0?ooo`3oool00`3oool20410@0050?ooo`000000000000000020P8000P3oool00`30`<00oooo0?oo
o`020?ooo`030<30`0000000P8200080oooo00@0P820000000000000@4100P3oool00`30`<00@410
0?ooo`0=0?ooo`<0000000<0@4100?ooo`3oool00P30`<090?ooo`050820P0000000000000000030
`<00H03oool00?l0ooooG03oool3000000030410@03oool0oooo00/0oooo00D0P820000000000000
00000820P00<0?ooo`040410@020P800oooo0<30`0<00000503oool00`000000oooo0?ooo`0=0?oo
o`<000001`3oool20410@0040?ooo`0000000000000000P0oooo00D0`<3000000030`<00oooo0410
@002000000030820P03oool0oooo0100oooo1000000=0?ooo`050<30`0000000000000000020P800
H03oool00?l0ooooG03oool01020P800000000000000000=0?ooo`040820P00000000000000000d0
oooo00@0`<3000000020P800P8200P0000000`20P800oooo0?ooo`0B0?ooo`030000003oool0oooo
00d0oooo0`0000070?ooo`040<30`0000000P8200410@08000002@3oool00`20P80000000?ooo`03
000001<0oooo00D0P82000000000000000000<30`00=0?ooo`<0000000<0P8200?ooo`3oool0GP3o
ool00?l0ooooG03oool01@30`<000000000000000000P82000`0oooo1000000?0?ooo`0500000020
P800000000000020P800503oool00`000000oooo0?ooo`0=0?ooo`040820P000000000000<30`0L0
oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`070?ooo`80P8200`00000C0?ooo`05
0<30`0000000000000000020P8003@3oool400000600oooo003o0?oooed0oooo0`0000000`20P800
oooo0?ooo`0:0?ooo`@000003`3oool01020P800000000000000000E0?ooo`030000003oool0oooo
00d0oooo00@0P820000000000000P820203oool01@20P8000000000000000000@41000X0oooo0`00
00000`20P800oooo0?ooo`0B0?ooo`@000003@3oool400000600oooo003o0?oooed0oooo00@0@410
0000000000000000303oool4000000l0oooo00@0`<3000000000000000005@3oool00`000000oooo
0?ooo`0>0?ooo`<000002@3oool01010@400000000000000000:0?ooo`040410@000000000000820
P1@0oooo00@0@41000000000000000003@3oool400000600oooo003o0?oooed0oooo00D0P8200000
0000000000000<30`00;0?ooo`@000003`3oool01020P800000000000020P80E0?ooo`030000003o
ool0oooo00h0oooo00@0P820000000000000`<30203oool01@30`<000000000000000000`<3000T0
oooo0`00000E0?ooo`050820P0000000000000000020P800303oool400000600oooo003o0?oooeh0
oooo0`0000000`20P800oooo0?ooo`090?ooo`@000003`3oool01010@400000000000010@40E0?oo
o`030000003oool0oooo00l0oooo00<0@41000000010@4002@3oool01010@400000000000020P808
0?ooo`050<30`0000000000000000030`<005@3oool3000000030410@03oool0oooo00X0oooo1000
001P0?ooo`00o`3ooomN0?ooo`<0000000<0@4100?ooo`3oool02@3oool4000000l0oooo0`000000
0`10@400`<300?ooo`0C0?ooo`030000003oool0oooo00l0oooo00@0`<30000000000000P820203o
ool01020P80000000000000000080?ooo`030820P000000000000080@4105@3oool4000000`0oooo
1000001P0?ooo`00o`3ooomN0?ooo`040820P00000000000000000/0oooo00@0@410000000000000
00003P3oool01P20P8000000000000000000`<30000000X0oooo00<0P8200000000000004P000008
0?ooo`040<30`000000000000<30`0P0oooo0`0000080?ooo`060410@000000000000820P010@400
P8205@3oool3000000030<30`03oool0oooo00T0oooo0`0000000`10@400oooo0?ooo`1N0?ooo`00
o`3ooomN0?ooo`050<30`0000000000000000030`<002P3oool01020P800000000000000000>0?oo
o`<0000000@0P8200?ooo`10@400@4104`3oool00`000000oooo0?ooo`0A0?ooo`030410@0000000
@41000P0oooo0`0000000`20P800oooo0?ooo`050?ooo`<0000000@0oooo0<30`0000000`<30503o
ool01010@400000000000020P80:0?ooo`050<30`0000000000000000020P800H03oool00?l0oooo
G`3oool3000000030820P03oool0oooo00P0oooo00D0P82000000000000000000820P00<0?ooo`05
0410@0000000000000000030`<000P3oool20410@0040820P010@40000000410@0h0oooo00<00000
0?ooo`3oool04P3oool00`20P80000000410@0070?ooo`<0000000<0@4100?ooo`3oool00`3oool0
1@30`<000000000000000000@4100080oooo00@0`<3000000020P800P8200P0000000`30`<00oooo
0?ooo`0=0?ooo`040820P000000000000410@0X0oooo00D0P82000000000000000000820P01P0?oo
o`00o`3ooomO0?ooo`@000002`3oool3000000030820P03oool0oooo00T0oooo1@0000030?ooo`03
0820P0000000000000<000003P3oool00`000000oooo0?ooo`0C0?ooo`030820P0000000P82000D0
oooo00<0P8200000000000000P0000040?ooo`030820P000000000000080000000@0P8200?ooo`3o
ool0oooo1@0000000`20P800oooo0?ooo`0>0?ooo`<000002P3oool01020P800000000000000001Q
0?ooo`00o`3ooomO0?ooo`040820P00000000000000000/0oooo0`0000000`20P800oooo0?ooo`06
0?ooo`030820P0000000000000@0000000<0@4100?ooo`3oool00P3oool00`10@400000000000002
000000h0oooo00<000000?ooo`3oool0503oool01020P80000000410@030`<020?ooo`030<30`000
0000@41000<0000000<0`<300?ooo`0000001P0000001@30`<00oooo0?ooo`3oool0`<3000@00000
00<0P8200?ooo`3oool02P3oool01030`<00P8200820P020P803000000<0P8201`3oool01020P800
000000000000001Q0?ooo`00o`3ooomO0?ooo`050<30`0000000000000000030`<002P3oool01020
P800000000000020P80:0?ooo`80P82000<0@41000000010@4001P3oool01030`<00000000000030
`<0>0?ooo`030000003oool0oooo01H0oooo00<0P8200410@00000000P0000000`20P800oooo0820
P002000000040820P03oool0oooo0<30`080P8200P0000000`30`<00oooo0?ooo`040?ooo`030410
@0000000@41000h0oooo0P20P804000000030410@020P800P82000L0oooo00@0@410000000000000
P820H@3oool00?l0ooooH03oool3000000030820P03oool0oooo00P0oooo00@0`<30000000000000
00009`3oool00`000000oooo0?ooo`0M0?ooo`040<30`000000000000410@280oooo00@0P8200000
00000000@4102@3oool300000680oooo003o0?ooof00oooo00@0@41000000000000000002`3oool0
1010@400000000000020P80V0?ooo`030000003oool0oooo01h0oooo0`00000S0?ooo`030<30`000
0000000000P0oooo00@0`<30000000000000@410HP3oool00?l0ooooF03oool00`20P800oooo0?oo
o`050?ooo`040820P00000000000000000P0oooo00@0`<300820P03oool0`<300`00000V0?ooo`03
0000003oool0oooo01h0oooo00@0@410000000000000P8208`3oool00`20P80000000820P0070?oo
o`040820P000000000000<30`680oooo003o0?oooeP0oooo00<0P8200<30`03oool01P3oool40000
00P0oooo00@0P8200?ooo`3oool0P8200P0000000`20P800oooo0?ooo`0S0?ooo`030000003oool0
oooo01h0oooo00@0P820000000000000P820903oool00`10@400P8200?ooo`060?ooo`80000000<0
P8200?ooo`3oool0H@3oool00?l0ooooF@3oool00`10@400oooo0?ooo`050?ooo`@0000000<0`<30
0?ooo`3oool01@3oool01`000000oooo0?ooo`3oool0@41000000010@4009@3oool00`000000oooo
0?ooo`0O0?ooo`<00000903oool00`30`<0000000?ooo`050?ooo`80000000<0@4100?ooo`3oool0
HP3oool00?l0ooooF@3oool00`000000P8200?ooo`050?ooo`050820P0000000000000000020P800
1`3oool00`000000`<300?ooo`020?ooo`80000000<0P8200?ooo`3oool0A03oool3000000030<30
`03oool0oooo02P0oooo00<0P82000000010@400I@3oool00?l0ooooF@3oool01020P80000000410
@030`<040?ooo`050820P0000000000000000010@4001P3oool00`10@40000000820P0040?ooo`03
0410@0000000`<3004D0oooo00@0P820000000000000P820:@3oool01030`<00000000000030`<1U
0?ooo`00o`3ooomI0?ooo`030<30`00000000000008000001020P804000000D0P82000@0@4100000
00000000@4101@3oool00`20P800@4100?ooo`140?ooo`040820P000000000000410@2P0oooo00<0
`<3000000030`<00I`3oool00?l0ooooFP3ooolE0820P0H0oooo00<0`<300410@030`<00@@3oool2
0820P0040410@00000000000000002L0oooo00<0`<300410@030`<00J03oool00?l0ooooM`3oool0
0`20P800`<300?ooo`100?ooo`060<30`020P800P8200820P0000000P8209@3oool00`30`<00P820
0?ooo`1Y0?ooo`00o`3ooooo0?oooe80oooo003o0?ooool0ooooDP3oool00?l0ooooo`3ooomB0?oo
o`00o`3ooooo0?oooe80oooo003o0?ooool0ooooDP3oool00?l0ooooo`3ooomB0?ooo`00o`3ooooo
0?oooe80oooo003o0?ooool0ooooDP3oool00?l0ooooo`3ooomB0?ooo`00o`3ooooo0?oooe80oooo
003o0?ooool0ooooDP3oool00?l0ooooo`3ooomB0?ooo`00o`3ooooo0?oooe80oooo003o0?ooool0
ooooDP3oool00?l0ooooo`3ooomB0?ooo`00o`3ooooo0?oooe80oooo003o0?ooool0ooooDP3oool0
0?l0ooooo`3ooomB0?ooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{197.625, 143.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fig. 3.3 Forces acting on a mass element in motion (displacement \
greatly exaggerated for ease of viewing).\
\>", "Caption",
  CellTags->"Fig. 3.3"],

Cell[TextData[{
  "\tThe equation of motion for ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  " can be found by applying Newton's second law to the motion of an element \
",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]m\)]],
  " of the string, located between ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x + \[DifferentialD]x\)]],
  " . The total force ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]F\_y\)]],
  "  in the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-direction on this element is determined by the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-component of the tension ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_y\)(x, t)\)]],
  " acting on each end of the string (assuming that no forces other than \
tension act in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y\)\(-\)\)\)]],
  "direction):\t"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]F\_y = \(\(T\_y\)(
              x + \[DifferentialD]x, t) - \(T\_y\)(x, 
              t) = \[DifferentialD]x\ \(\[PartialD]\/\[PartialD]x\) \
\(\(T\_y\)(x, t)\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.3)"],

Cell[TextData[{
  "By Newton's second law, this force determines the acceleration of the mass \
element in the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-direction:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]m\ \(\[PartialD]\^2\/\[PartialD]t\^2\) \
\(y(x, t)\) = \(\[DifferentialD]F\_y\  = \[DifferentialD]x \(\[PartialD]\/\
\[PartialD]x\) \(\(\(T\_y\)(x, t)\)\(.\)\(\ \)\)\)\)]]], "NumberedEquation",
  CellTags->"(3.1.4)"],

Cell[TextData[{
  "Because tension forces act along the direction of the string, the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-component of the tension is related to the displacement of the string \
from equilibrium. According to Fig. ",
  ButtonBox["3.3",
    ButtonData:>"Fig. 3.3",
    ButtonStyle->"Hyperlink"],
  ",",
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_y\)(x, t) = \(T(x, t)\)\ sin\[Theta]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " is the magnitude of the tension in the string at position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " is the angle of the element ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]m\)]],
  " with respect to the horizontal. However, since the displacement from \
equilibrium is assumed small, \[Theta] must also be small, and therefore ",
  Cell[BoxData[
      \(TraditionalForm\`sin\[Theta] \[TildeTilde] \[Theta]\)]],
  ", which implies that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(T\_y\)(x, 
          t) \[TildeTilde] \(T(x, t)\)\ \[Theta]\)]],
  " ."
}], "NumberedEquation",
  CellTags->"(3.1.5)"],

Cell[TextData[{
  " Furthermore, according to Fig. ",
  ButtonBox["3.3",
    ButtonData:>"Fig. 3.3",
    ButtonStyle->"Hyperlink"],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Theta]\)\(\ \)\)\)]],
  "is related to the displacement of the string through ",
  Cell[BoxData[
      \(TraditionalForm\`tan\[Theta]\  = \ \[PartialD]y/\[PartialD]x\)]],
  " . For small angles ",
  Cell[BoxData[
      \(TraditionalForm\`tan\[Theta] \[TildeTilde] \[Theta]\)]],
  ", so this implies ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] \[TildeTilde] \ \
\[PartialD]y/\[PartialD]x\)]],
  ". Combining this result with Eq. ",
  ButtonBox["(3.1.5)",
    ButtonData:>"(3.1.5)",
    ButtonStyle->"Hyperlink"],
  ", we obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_y\)(x, 
          t) \[TildeTilde] \(T(x, 
            t)\)\ \[PartialD]y/\(\(\[PartialD]x\)\(\ \)\)\)]],
  ". However, as we are interested only in smal-amplitude transverse \
displacements of the string, we can replace ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " by the equilibrium tension ",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\)]],
  ". Therefore, we obtain"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_y\)(x, 
          t) \[TildeTilde] \(T(x)\)\ \[PartialD]y/\[PartialD]x\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.6)"],

Cell[TextData[{
  "Applying this result to Eq. ",
  ButtonBox["(3.1.4)",
    ButtonData:>"(3.1.4)",
    ButtonStyle->"Hyperlink"],
  ",  dividing by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]m\)]],
  ",  and using Eq. ",
  ButtonBox["(3.1.2)",
    ButtonData:>"(3.1.2)",
    ButtonStyle->"Hyperlink"],
  " yields"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]t\^2\) \(y(x, 
            t)\) = \(1\/\(\[Rho](x)\)\) \(\[PartialD]\/\[PartialD]x\) \((\(T(
                x)\)\ \(\[PartialD]\/\[PartialD]x\) \(y(x, t)\))\)\)]],
  "."
}], "NumberedEquation",
  CellTags->{"(3.1.7)", "i:1"}],

Cell[TextData[{
  "Equation ",
  ButtonBox["(3.1.7)",
    ButtonData:>"(3.1.7)",
    ButtonStyle->"Hyperlink"],
  " is the wave equation for a string with equilibrium tension ",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\)]],
  " and mass per unit length ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\)]],
  ". This equation describes the evolution of small transverse displacements \
",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  " away from equilibrium. The equation is a linear partial differential \
equation in the unknown function ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  ", and is second order in time and second order in space. Since the \
equation is second-order in space, two boundary conditions are required: the \
ends of the string are fixed by the posts at each end so ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t Since the wave equation is second-order in time, two initial conditions \
are also  needed. The position and transverse velocity of each element of the \
string must be specified initially in order to determine its subsequent \
motion. In other words, we require knowledge of ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t = 0)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) \(y(x, t = 0)\)\)]],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " in the range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  ". Thus, the solution of the wave equation is specified by boundary \
conditions"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`y(0, t) = \(y(L, t) = 0\)\)]]], "NumberedEquation",
  CellTags->"(3.1.8)"],

Cell["and by initial conditions", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, 0) = \(y\_o\)(x)\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]y\/\[PartialD]t\) \((x, 0)\) = \(v\_o\)(
          x)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(3.1.9)"],

Cell[TextData[{
  "for some initial transverse displacement ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\_o\)(x)\)]],
  " and initial transverse velocity ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_o\)(x)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe wave equation can be simplified in the case that the string tension \
is uniform [",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\  = \ T\)]],
  "] and the mass density is also uniform [",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\  = \ \[Rho]\)]],
  "]. Then Eq. ",
  ButtonBox["(3.1.7)",
    ButtonData:>"(3.1.7)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]t\^2\) \(y(x, t)\) = 
        c\^2\ \(\[PartialD]\^2\/\[PartialD]x\^2\) \(y(x, t)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->{"(3.1.10)", "i:2"}],

Cell[TextData[{
  "The constant ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\)\(\ \)\)\)]],
  "is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`c = \@\(T/\[Rho]\)\)]],
  ","
}], "NumberedEquation",
  CellTags->{"(3.1.11)", "i:49"}],

Cell["\<\
and has units of a velocity. In fact we will see that this quantity \
is the speed at which transverse disturbances propagate along the string. \
\
\>", "Text"],

Cell[TextData[{
  "\tThe magnitude of ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " depends on the mass density and thickness of the string as well as the \
tension to which is it subjected .  For instance,  the high ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " string on a steel string guitar is typically made of steel with a mass \
density ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalM]\)]],
  " of roughly ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalM]", "=", 
          RowBox[{"7.5", " ", 
            RowBox[{
              StyleBox["g",
                FontSlant->"Plain"], "/", \(cm\^3\)}]}]}], 
        TraditionalForm]]],
  ". The radius of this string is",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(\(r\)\(=\)\),
              "TraditionalForm"], 
            FormBox[\(0.15\ mm\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ", giving a mass per unit length of "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Rho]", " ", "=", " ", 
          RowBox[{\(\[Pi]\ \(r\^2\) \[ScriptCapitalM]\), "=", 
            RowBox[{
              RowBox[{"0.0053", " ", 
                RowBox[{
                  StyleBox["g",
                    FontSlant->"Plain"], "/", "cm"}]}], "=", 
              RowBox[{"5.3", "\[Times]", \(10\^\(-4\)\), " ", 
                RowBox[{"kg", "/", 
                  StyleBox["m",
                    FontSlant->"Plain"]}]}]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.12)"],

Cell[TextData[{
  "According to Eq. ",
  ButtonBox["(3.1.11)",
    ButtonData:>"(3.1.11)",
    ButtonStyle->"Hyperlink"],
  ", a tension of ",
  Cell[BoxData[
      \(TraditionalForm\`T = \ 500\ N\)]],
  " yields a speed of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "=", 
          RowBox[{"970", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tAlthough we have derived the wave equation for transverse waves on a \
string, the same PDE also applies to many other types of wave disturbances \
traveling in one spatial dimension. For example, the equation applies to the \
small-amplitude waves on the surface of shallow water (neglecting surface \
tension), with ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  " now the height of the water surface [see Exercise (4) at the end of this \
section]. The equation also applies to pressure waves propagating through a \
medium such as air",
  ",",
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  " now the pressure or density in the medium.   The equation applies to \
propagation of electromagnetic waves such as visible light or radio waves, \
with ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  " now identified with the electric or magnetic field in the wave. The wave \
equation itself is the same in each case, even though the physical processes \
for each type of wave are very different.  Of course, in each instance, the \
speed of propagation ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " differs. Obviously, for sound waves ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is the speed of sound, but for light waves ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is the speed of light.  "
}], "Text",
  CellTags->"i:95"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.1.2 Solution of the Wave Equation Using Separation of Variables\
\
\>", "Subsubtitle",
  CellTags->"c:8"],

Cell[CellGroupData[{

Cell["\<\
Solution of the Wave Equation for a Uniform String and Fixed Ends\
\
\>", "Section",
  CellTags->"c:9"],

Cell[CellGroupData[{

Cell["Separation of Variables for a Uniform String", "Subsubsection"],

Cell[TextData[{
  "\tWe will now solve the wave equation for a ",
  StyleBox["uniform string",
    FontSlant->"Italic"],
  ", Eq. ",
  ButtonBox["(3.1.10)",
    ButtonData:>"(3.1.10)",
    ButtonStyle->"Hyperlink"],
  ", with boundary conditions that the ends are fixed:  ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ", and initial conditions given by Eq.  ",
  ButtonBox["(3.1.9)",
    ButtonData:>"(3.1.9)",
    ButtonStyle->"Hyperlink"],
  ".  To solve this problem, we will apply the ",
  StyleBox["method of separation of variables",
    FontSlant->"Italic"],
  ". In this method, we look for a solution to the PDE of the form "
}], "Text",
  CellTags->"i:6"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, t) = \(f(t)\) \(\[Psi](x)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(3.1.13)"],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x)\)]],
  " are some functions that need to be determined in order to satisfy the PDE \
and match the boundary and initial conditions. In fact, we will find that \
there are many possible solutions of this form, each of which satisfy the PDE \
and the ",
  "boundary",
  " conditions.  We will create a ",
  "superposition",
  " of these solutions in order to match the ",
  "initial",
  " conditions."
}], "Text"],

Cell[TextData[{
  "\tIf we substitute  Eq. ",
  ButtonBox["(3.1.13)",
    ButtonData:>"(3.1.13)",
    ButtonStyle->"Hyperlink"],
  " into the wave equation, Eq. ",
  ButtonBox["(3.1.10)",
    ButtonData:>"(3.1.10)",
    ButtonStyle->"Hyperlink"],
  ", and then divide by ",
  Cell[BoxData[
      \(TraditionalForm\`\(f(t)\)\ \(\[Psi](x)\)\)]],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(f(
                t)\)\) \[PartialD]\^2 f\/\[PartialD]t\^2 = \(c\^2\) \(1\/\(\
\[Psi](x)\)\) \[PartialD]\^2 \[Psi]\/\[PartialD]x\^2\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.14)"],

Cell[TextData[{
  "This PDE can be separated into two ordinary differential equations by \
means of the following argument: the right-hand side of the equation is a \
function only of position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " . Let us call this function ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\)]],
  ".  Then Eq. ",
  ButtonBox["(3.1.14)",
    ButtonData:>"(3.1.14)",
    ButtonStyle->"Hyperlink"],
  "  implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(f(t)\)\) \[PartialD]\^2 f\/\[PartialD]t\^2 = 
        h(x)\)]],
  ". However, the ",
  "left-hand",
  " side of this equation  is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". Therefore, ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\)]],
  " ",
  StyleBox["must be a constant",
    FontSlant->"Italic"],
  ". Let us call this constant ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", 
          FormBox[\(\[Omega]\^2\),
            "TraditionalForm"]}], TraditionalForm]]],
  ", in anticipation of the fact that it is a negative quantity. Then Eq. ",
  ButtonBox["(3.1.14)",
    ButtonData:>"(3.1.14)",
    ButtonStyle->"Hyperlink"],
  " becomes two ODES:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\(1\/\(f(
              t)\)\) \[PartialD]\^2 f\/\[PartialD]t\^2 = \
\(-\[Omega]\^2\)\)\(,\)\)\)]]], "NumberedEquation",
  CellTags->"(3.1.15)"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\^2\) \(1\/\(\[Psi](
                x)\)\) \[PartialD]\^2 \[Psi]\/\[PartialD]x\^2 = \
\(-\[Omega]\^2\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.16)"],

Cell[TextData[{
  "These two ODEs must be solved subject to the boundary and initial \
conditions. First, we consider the boundary conditions. The conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`y(0, t) = \(y(L, t) = 0\)\)]],
  "  imply that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](0) = \(\[Psi](L) = 0\)\)]],
  ".These are ",
  StyleBox["homogeneous boundary conditions",
    FontSlant->"Italic"],
  ", introduced previously in relation to Eq. ",
  ButtonBox["(2.4.28)",
    ButtonData:>{"Chapter2.nb", "(2.4.28)"},
    ButtonStyle->"Hyperlink"],
  ". With such boundary conditions,  Eq. ",
  ButtonBox["(3.1.16)",
    ButtonData:>"(3.1.16)",
    ButtonStyle->"Hyperlink"],
  " can be recognized as a special kind of boundary-value problem: an ",
  StyleBox["eigenvalue problem",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"i:8"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Eigenvalue Problem", "Subsubsection",
  CellTags->"i:7"],

Cell[TextData[{
  "\tAn eigenvalue problem such as Eq. ",
  ButtonBox["(3.1.16)",
    ButtonData:>"(3.1.16)",
    ButtonStyle->"Hyperlink"],
  " is a linear boundary-value problem with homogeneous boundary conditions. \
Also, the differential equation must depend on a parameter that can be \
varied. In this case the parameter is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ". The homogeneous boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](0) = \(\[Psi](L) = 0\)\)]],
  " imply that there is always a trivial solution to the problem,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x) = 0\)]],
  ". However, in eigenvalue problems, for special values of the parameter, \
there also exist ",
  StyleBox["nontrivial",
    FontSlant->"Italic"],
  " solutions for \[Psi], called ",
  StyleBox["eigenmodes",
    FontSlant->"Italic"],
  " or ",
  StyleBox["eigenfunctions",
    FontSlant->"Italic"],
  ".  The special values of the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " are called ",
  StyleBox["eigenfrequencies ",
    FontSlant->"Italic"],
  "(since ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " has units of a frequency)",
  StyleBox[", ",
    FontSlant->"Italic"],
  "but more generally they are called ",
  StyleBox["eigenvalues",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"i:9"],

Cell[TextData[{
  StyleBox["\t",
    FontSlant->"Italic"],
  " To find the nontrivial solutions for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  ", we match the general solution of the differential equation to the \
boundary conditions.  The general solution of Eq. ",
  ButtonBox["(3.1.16)",
    ButtonData:>"(3.1.16)",
    ButtonStyle->"Hyperlink"],
  " is"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[Psi](x)\  = \ 
      C\ cos\ \((\[Omega]\ x/c)\) + \ 
        D\ \(sin(\[Omega]\ x/c)\)\)\(\ \)\(,\)\)\)]]], "NumberedEquation",
  CellTags->"(3.1.17)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " are constants. First, the condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](0) = 0\)]],
  ", when used in Eq. ",
  ButtonBox["(3.1.17)",
    ButtonData:>"(3.1.17)",
    ButtonStyle->"Hyperlink"],
  ", implies that ",
  Cell[BoxData[
      \(TraditionalForm\`C = 0\)]],
  ". Next, the condition ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Psi](L)\)\(=\)\(0\)\(\ \)\)\)]],
  " implies that  ",
  Cell[BoxData[
      \(TraditionalForm\`D\ \(sin(\[Omega]\ L/c)\)\  = 0\)]],
  ". This equation can be satisfied  in two ways. First, we could take ",
  Cell[BoxData[
      \(TraditionalForm\`D = 0\)]],
  ", but this would then imply that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] = 0\)]],
  ", which is the trivial and uninteresting solution.  The second possibility \
is that ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ \((\[Omega]\ L/c)\) = 0\)]],
  ". This implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\ L/\ c = n\ \[Pi]\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\)\(\ \)\)\)]],
  "an integer.  "
}], "Text"],

Cell[TextData[{
  "\tThus, we find that the nontrivial solutions of Eq. ",
  ButtonBox["(3.1.16)",
    ButtonData:>"(3.1.16)",
    ButtonStyle->"Hyperlink"],
  " with boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](0) = \(\[Psi](L) = 0\)\)]],
  " are"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Psi](x)\  = \ 
        D\ sin\ n\ \[Pi]\ x/L\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... \)]]
}], "NumberedEquation",
  CellTags->"(3.1.18)"],

Cell["and also, ", "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \(\[Omega]\_n = \ n\ \[Pi]\ c/L\)\)], 
    "NumberedEquation"], "NumberedEquation"],
  StyleBox[".", "NumberedEquation"]
}], "NumberedEquation",
  CellTags->"(3.1.19)"],

Cell[TextData[{
  "These are the eigenfunctions and eigenfrequencies for this problem. We do \
not require values of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " less than zero, because the corresponding eigenmodes are just opposite in \
sign to those with ",
  Cell[BoxData[
      \(TraditionalForm\`n > 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tRecall from Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", None},
    ButtonStyle->"Hyperlink"],
  " that the solution to a boundary-value problem need not be unique. In \
eigenvalue problems, we  have an example of this indeterminacy. When ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] \[NotEqual] \ \[Omega]\_n\)]],
  ", there is only one solution, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] = 0\)]],
  ", but when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \[Omega]\_n\)]],
  ", the constant ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " can take on any value, including zero, so there are many solutions.  \
Fortunately, the specific value of this constant is not important in \
constructing the solutions to the wave equation, as we will now see."
}], "Text",
  CellTags->"i:14"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "The Solution for ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]]
}], "Subsubsection"],

Cell[TextData[{
  "\tThe time dependence of the solution is described by Eq. ",
  ButtonBox["(3.1.15)",
    ButtonData:>"(3.1.15)",
    ButtonStyle->"Hyperlink"],
  ". The general solution of this equation is "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = \ 
        A\ cos\ \[Omega]\ t\  + \ \(\(B\)\(\ \)\(sin\)\(\ \)\(\[Omega]\)\(\ \
\)\(t\)\(\ \)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " are constants.  Using Eq. ",
  ButtonBox["(3.1.19)",
    ButtonData:>"(3.1.19)",
    ButtonStyle->"Hyperlink"],
  " for the frequency, and Eq. ",
  ButtonBox["(3.1.18)",
    ButtonData:>"(3.1.18)",
    ButtonStyle->"Hyperlink"],
  " for the eigenmodes, the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t) = \(f(t)\)\ \(\[Psi](x)\)\)]],
  " is"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          t)\  = \ \((A\ cos\ \[Omega]\_n\ t\  + \ 
              B\ sin\ \[Omega]\_n\ t\ )\) \(sin(n\ \[Pi]\ x/L)\)\)]],
  ", "
}], "Text"],

Cell[TextData[{
  "where we have absorbed the constant ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " into ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  ". However, this is not the full solution to the problem. There are an \
infinite number of solutions for the eigenmodes and eigenfrequencies,  so we \
will create a ",
  StyleBox["superposition",
    FontSlant->"Italic"],
  " of these solutions, writing"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(y(x, t)\)\(\ \)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(n = 1\)\%\[Infinity]\(\((A\_n\ cos\ \
\[Omega]\_n\ t\  + \ B\_n\ sin\ \[Omega]\_n\ t)\)\(\ \ \ \)\(sin(
            n\ \[Pi]\ x/L)\)\(\ \)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.20)"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(3.1.20)",
    ButtonData:>"(3.1.20)",
    ButtonStyle->"Hyperlink"],
  " is the general solution to the wave equation for a uniform string with \
fixed ends.  This equation describes a wealth of physics, so it is worthwhile \
to pause and study its implications."
}], "Text",
  CellTags->"i:18"]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigenmodes for a Uniform String", "Subsubsection",
  CellTags->"i:99"],

Cell[TextData[{
  "\tThe eigenfunctions ",
  Cell[BoxData[
      \(TraditionalForm\`sin(n\ \[Pi]\ x/L)\)]],
  " are the normal modes of oscillation of the string. If only  a single \
normal mode is excited by the initial condition, the string executes a \
sinusoidal oscillation in time, and this oscillation persists forever. If \
several different eigenfunctions are excited by the initial conditions, each \
mode  evolves  in time independently from the others, with its own fixed \
frequency . Examples of single-mode oscillations are shown in Cell ",
  ButtonBox["3.1",
    ButtonData:>"Cell 3.1",
    ButtonStyle->"Hyperlink"],
  " for the first four normal modes, taking ",
  Cell[BoxData[
      \(TraditionalForm\`c = \(L = 1\)\)]],
  ":"
}], "Text",
  CellTags->"i:12"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(L = 1; c = 1;\), "\n", 
    \(\(\[Omega][n_]\  = \ n\ Pi\ c/L\ ;\)\), "\n", 
    \(\(plt[n_, t_]\  := \ 
        Plot[Cos[\[Omega][n] t]\ Sin[n\ Pi\ x], {x, 0, L}, 
          DisplayFunction \[Rule] Identity, PlotRange \[Rule] {\(-1\), 1}, 
          PlotLabel \[Rule] "\<n = \>" <> ToString[n]];\)\), "\n", 
    \(\(Table[
        Show[GraphicsArray[
            Table[{{plt[1, t], plt[2, t]}, {plt[3, t], plt[4, t]}}]], 
          DisplayFunction \[Rule] $DisplayFunction], {t, 0, 
          2,  .05}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.1"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .42431 L
.08255 .47871 L
.10458 .53054 L
.12507 .56939 L
.14415 .596 L
.14918 .60135 L
.15465 .60634 L
.15946 .61001 L
.16457 .61316 L
.16917 .61533 L
.17178 .61628 L
.17423 .61699 L
.17538 .61726 L
.17647 .61748 L
.17746 .61764 L
.17852 .61779 L
.17967 .61791 L
.18073 .61798 L
.182 .61803 L
.18314 .61803 L
.18435 .61798 L
.18547 .6179 L
.1867 .61777 L
.18802 .61758 L
.19071 .61702 L
.19317 .61633 L
.1979 .61447 L
.20239 .61209 L
.21236 .60467 L
.22321 .59334 L
.24299 .56438 L
.26399 .52296 L
.30174 .42683 L
.34195 .30695 L
.38063 .19166 L
.40028 .13864 L
.42177 .08806 L
.44253 .04863 L
.4614 .02227 L
.47149 .01222 L
.47611 .00859 L
.48101 .00544 L
.4835 .00411 L
.48624 .00286 L
.48876 .00191 L
.49106 .00121 L
.49378 .00059 L
.49527 .00034 L
.49596 .00025 L
Mistroke
.49669 .00017 L
.498 6e-05 L
.49921 1e-05 L
.49996 0 L
.50065 1e-05 L
.50196 6e-05 L
.50313 .00015 L
.50438 .00029 L
.50556 .00047 L
.50663 .00066 L
.50926 .0013 L
.51175 .00209 L
.5167 .00421 L
.52208 .00735 L
.53169 .01507 L
.54056 .02456 L
.55926 .05164 L
.57988 .09163 L
.62014 .19384 L
.65888 .30946 L
.70007 .43193 L
.72063 .4867 L
.73974 .53106 L
.75939 .56839 L
.77791 .59466 L
.78775 .60477 L
.79293 .60897 L
.7984 .61255 L
.80302 .61488 L
.80546 .61586 L
.80809 .61671 L
.8105 .6173 L
.8127 .61769 L
.81375 .61783 L
.81491 .61794 L
.81599 .618 L
.817 .61803 L
.81818 .61803 L
.81941 .61798 L
.82047 .6179 L
.82163 .61777 L
.82287 .61759 L
.82421 .61735 L
.82661 .61677 L
.82905 .61601 L
.83134 .61512 L
.83564 .61304 L
.84078 .60984 L
.84552 .6062 L
.85624 .59556 L
Mistroke
.87498 .56932 L
.89561 .53014 L
.93591 .42895 L
.97471 .31355 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .45981 L
.08255 .52527 L
.0932 .55403 L
.10458 .57945 L
.11009 .58961 L
.11531 .59784 L
.12038 .60454 L
.12507 .60956 L
.12951 .61325 L
.13178 .61474 L
.13422 .61603 L
.13549 .61658 L
.13666 .617 L
.13784 .61736 L
.13895 .61762 L
.14022 .61785 L
.1409 .61793 L
.14161 .61799 L
.1423 .61803 L
.14295 .61803 L
.14415 .61799 L
.14531 .61787 L
.14656 .61767 L
.14773 .61739 L
.14881 .61708 L
.15143 .61606 L
.15392 .61475 L
.15886 .61117 L
.16423 .60583 L
.17383 .59259 L
.1827 .5763 L
.20137 .53043 L
.22197 .46442 L
.26217 .30793 L
.30086 .15709 L
.32051 .09318 L
.3309 .06498 L
.342 .03993 L
.35275 .02114 L
.35784 .01426 L
.36253 .00909 L
.36724 .00504 L
.36972 .00339 L
.37235 .00199 L
.37463 .00107 L
.37573 .00073 L
.37677 .00047 L
.37799 .00024 L
.37911 9e-05 L
Mistroke
.38031 1e-05 L
.38162 1e-05 L
.38227 5e-05 L
.38296 .00011 L
.38419 .00028 L
.38551 .00056 L
.38695 .00097 L
.38955 .00199 L
.39197 .00326 L
.39649 .00647 L
.40134 .01111 L
.40698 .01804 L
.41232 .02609 L
.42232 .0449 L
.44227 .09574 L
.4607 .15587 L
.50002 .3091 L
.53782 .45692 L
.55884 .52554 L
.56803 .55063 L
.57808 .57397 L
.58722 .59118 L
.59696 .60501 L
.60236 .61057 L
.60726 .6143 L
.60962 .61565 L
.61086 .61623 L
.61218 .61677 L
.61333 .61715 L
.61459 .6175 L
.61574 .61774 L
.61682 .6179 L
.61808 .61801 L
.61871 .61803 L
.61941 .61803 L
.62065 .61796 L
.62181 .61783 L
.62248 .61772 L
.62318 .61757 L
.62443 .61725 L
.62578 .61682 L
.62725 .61622 L
.62973 .61497 L
.63238 .61327 L
.63715 .60926 L
.64214 .6038 L
.64686 .59746 L
.6557 .5826 L
.67568 .53569 L
.69413 .4784 L
Mistroke
.7335 .32774 L
.77136 .17771 L
.79241 .10603 L
.81166 .05399 L
.82118 .03415 L
.8262 .0254 L
.83155 .01745 L
.8367 .01118 L
.84136 .00668 L
.84361 .00491 L
.84604 .00331 L
.84835 .00208 L
.85045 .0012 L
.85159 .00083 L
.85283 .0005 L
.85414 .00024 L
.85538 8e-05 L
.85653 1e-05 L
.85776 1e-05 L
.85881 7e-05 L
.85997 .00021 L
.86063 .00033 L
.86132 .00047 L
.86256 .00079 L
.86535 .00181 L
.86777 .00303 L
.87041 .00472 L
.87569 .00921 L
.88133 .0156 L
.89148 .03117 L
.90173 .05195 L
.91284 .07976 L
.933 .14228 L
.97393 .29982 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34829 L
.10458 .39038 L
.14415 .42849 L
.18221 .46323 L
.22272 .49753 L
.26171 .52738 L
.30316 .55515 L
.34309 .57755 L
.3815 .59472 L
.40095 .60168 L
.42237 .60796 L
.44268 .61253 L
.45178 .61413 L
.46172 .61557 L
.4671 .61622 L
.4721 .61673 L
.47727 .61717 L
.48196 .61749 L
.48658 .61773 L
.4887 .61782 L
.49093 .6179 L
.49332 .61796 L
.49438 .61798 L
.49552 .618 L
.49675 .61802 L
.49789 .61803 L
.49859 .61803 L
.49925 .61803 L
.50049 .61803 L
.50163 .61803 L
.50286 .61802 L
.50401 .61801 L
.50508 .61799 L
.50754 .61794 L
.51014 .61786 L
.51268 .61776 L
.51504 .61765 L
.5204 .61733 L
.5293 .61659 L
.53882 .6155 L
.54906 .614 L
.56016 .61197 L
.58032 .60725 L
.62123 .59365 L
.66064 .57566 L
.69852 .55411 L
.73886 .52697 L
.77769 .49721 L
.81897 .4622 L
Mistroke
.85873 .42578 L
.89697 .38885 L
.93767 .34818 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .38693 L
.10458 .466 L
.14415 .52938 L
.18221 .57629 L
.20178 .59404 L
.21267 .60187 L
.22272 .60776 L
.23293 .61241 L
.23832 .6143 L
.24402 .61589 L
.24641 .61642 L
.24897 .61691 L
.25119 .61726 L
.25361 .61757 L
.25507 .61772 L
.25643 .61783 L
.25773 .61792 L
.2584 .61795 L
.25912 .61798 L
.25983 .618 L
.26048 .61802 L
.26176 .61803 L
.26293 .61803 L
.26416 .618 L
.26538 .61795 L
.26607 .61792 L
.26671 .61788 L
.26912 .61768 L
.27131 .61744 L
.27364 .61711 L
.27847 .61619 L
.2838 .61482 L
.29326 .61145 L
.30213 .60721 L
.32232 .59381 L
.34082 .57709 L
.38045 .52825 L
.41855 .46718 L
.45912 .39136 L
.49816 .31277 L
.53966 .22909 L
.57964 .15402 L
.61811 .09187 L
.63759 .06548 L
.65902 .0411 L
.67938 .02289 L
.69843 .01052 L
.70884 .00574 L
.71396 .00391 L
Mistroke
.71872 .00252 L
.72301 .00153 L
.72758 .00074 L
.7302 .00042 L
.73148 .00029 L
.73266 .0002 L
.73371 .00013 L
.73487 7e-05 L
.73603 3e-05 L
.73725 0 L
.73856 0 L
.73977 2e-05 L
.7404 4e-05 L
.7411 6e-05 L
.74251 .00013 L
.74375 .00021 L
.74508 .00033 L
.74748 .00059 L
.74985 .00093 L
.75235 .00136 L
.7568 .00235 L
.76198 .00383 L
.7668 .00553 L
.77773 .0105 L
.78828 .01678 L
.79823 .024 L
.81683 .04076 L
.85534 .08793 L
.89632 .15361 L
.93577 .22759 L
.97371 .30396 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.25, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`8006Yoo`D00:Ioo`H000Eoo`03001oogoo00Aoo`8004moo`@006Yoo`@0031o
o`00<Goo00<007ooOol017oo00<007ooOol0Igoo0`0017oo0P00[goo00<007ooOol017oo00<007oo
Ool0C7oo0`000goo00<007ooOol0IWoo0P000goo0P00;Woo000aOol00`00Oomoo`04Ool00`00Oomo
o`1VOol00`00Oomoo`07Ool2002]Ool00`00Oomoo`04Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool0
0`00Oomoo`1TOol00`00Oomoo`05Ool00`00Oomoo`0[Ool0035oo`03001oogoo00Aoo`03001oogoo
06Aoo`8000aoo`03001oogoo0:Yoo`03001oogoo00Aoo`03001oogoo04Yoo`03001oogoo00Moo`80
06=oo`03001oogoo00Moo`03001oogoo02Yoo`00<Goo00<007ooOol017oo0P00I7oo00<007ooOol0
3Goo00<007ooOol0ZGoo00<007ooOol017oo0P00Bgoo00<007ooOol02Goo00<007ooOol0Ggoo00<0
07ooOol02Goo00<007ooOol0:Goo000_Ool30006Ool00`00Oomoo`1ROol00`00Oomoo`0?Ool00`00
Oomoo`2VOol30006Ool00`00Oomoo`19Ool00`00Oomoo`0:Ool00`00Oomoo`1OOol00`00Oomoo`09
Ool00`00Oomoo`0YOol003Qoo`03001oogoo069oo`03001oogoo011oo`03001oogoo0:ioo`03001o
ogoo04Uoo`03001oogoo00]oo`03001oogoo05eoo`03001oogoo00]oo`03001oogoo02Qoo`00>7oo
0P00HWoo00<007ooOol04Goo00<007ooOol0[Woo0P00BGoo00<007ooOol037oo00<007ooOol0GGoo
00<007ooOol037oo00<007ooOol09goo000hOol00`00Oomoo`1POol00`00Oomoo`0COol00`00Oomo
o`2]Ool00`00Oomoo`18Ool00`00Oomoo`0=Ool00`00Oomoo`1KOol00`00Oomoo`0=Ool00`00Oomo
o`0WOol003Qoo`03001oogoo061oo`03001oogoo01Aoo`03001oogoo0:aoo`03001oogoo04Moo`03
001oogoo00ioo`03001oogoo05]oo`03001oogoo00ioo`03001oogoo02Ioo`00>7oo00<007ooOol0
Ggoo00<007ooOol05Goo00<007ooOol0[7oo00<007ooOol0Agoo00<007ooOol03Woo00<007ooOol0
FWoo00<007ooOol03goo00<007ooOol09Woo000hOol2001OOol00`00Oomoo`0GOol00`00Oomoo`2[
Ool20017Ool00`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0@Ool00`00Oomoo`0VOol003Qo
o`03001oogoo05ioo`03001oogoo01Qoo`03001oogoo0:Yoo`03001oogoo04Ioo`03001oogoo011o
o`03001oogoo05Qoo`03001oogoo015oo`03001oogoo02Eoo`00>7oo00<007ooOol0GGoo00<007oo
Ool06Goo00<007ooOol0ZWoo00<007ooOol0AGoo00<007ooOol04Woo00<007ooOol0EWoo00<007oo
Ool04Woo00<007ooOol09Goo000hOol00`00Oomoo`1MOol00`00Oomoo`0JOol00`00Oomoo`2YOol0
0`00Oomoo`15Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0COol00`00Oomoo`0TOol0
03Qoo`8005eoo`03001oogoo01]oo`03001oogoo0:Uoo`8004Eoo`03001oogoo01Aoo`03001oogoo
05Aoo`03001oogoo01Aoo`03001oogoo02Aoo`005goo0`001Woo0P001Woo00<007ooOol017oo1000
1Goo00<007ooOol0G7oo00<007ooOol077oo00<007ooOol0Qgoo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0A7oo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol05Goo00<0
07ooOol08goo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo
00<007ooOol0Fgoo00<007ooOol07Woo00<007ooOol0QGoo00D007ooOomoo`0000Eoo`8000Ioo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo04Aoo`03001oogoo01Eoo`03001oogoo05=oo`03
001oogoo01Eoo`03001oogoo02=oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`8005aoo`03001oogoo01ioo`03001oogoo07eoo`H0009oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20014Ool00`00Oomoo`0FOol00`00Oomoo`1BOol0
0`00Oomoo`0FOol00`00Oomoo`0SOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`1JOol00`00Oomoo`0POol00`00Oomoo`24Ool01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol0@goo00<007ooOol05Woo00<007ooOol0DWoo
00<007ooOol05goo00<007ooOol08Woo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo1000
1Goo00<007ooOol0FWoo00<007ooOol087oo00<007ooOol0Q7oo00D007ooOomoo`0000ioo`03001o
ogoo00=oo`@000Eoo`03001oogoo04=oo`03001oogoo01Moo`03001oogoo055oo`03001oogoo01Mo
o`03001oogoo029oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03
001oogoo05Uoo`03001oogoo029oo`03001oogoo08=oo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`12Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0H
Ool00`00Oomoo`0ROol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol0
1Woo0P00FWoo00<007ooOol08Woo00<007ooOol0Pgoo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool20013Ool00`00Oomoo`0IOol00`00Oomoo`1?Ool00`00Oomoo`0IOol0
0`00Oomoo`0QOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo05Qoo`03001oogoo02Aoo`03
001oogoo08=oo`<000aoo`D000Aoo`@000Eoo`03001oogoo049oo`03001oogoo01Uoo`03001oogoo
04moo`03001oogoo01Uoo`03001oogoo025oo`00>7oo00<007ooOol0F7oo00<007ooOol097oo00<0
07ooOol0Y7oo00<007ooOol0@Goo00<007ooOol06Woo00<007ooOol0CWoo00<007ooOol06Woo00<0
07ooOol08Goo000hOol2001HOol00`00Oomoo`0UOol00`00Oomoo`2TOol20012Ool00`00Oomoo`0K
Ool00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`0POol003Qoo`03001oogoo05Moo`03001o
ogoo02Ioo`03001oogoo0:=oo`03001oogoo045oo`03001oogoo01]oo`03001oogoo04eoo`03001o
ogoo01]oo`03001oogoo021oo`00>7oo00<007ooOol0EWoo00<007ooOol09goo00<007ooOol0Xgoo
00<007ooOol0@7oo00<007ooOol077oo00<007ooOol0CGoo00<007ooOol06goo00<007ooOol087oo
000hOol00`00Oomoo`1FOol00`00Oomoo`0WOol00`00Oomoo`2SOol00`00Oomoo`10Ool00`00Oomo
o`0MOol00`00Oomoo`1;Ool00`00Oomoo`0LOol00`00Oomoo`0POol003Qoo`8005Moo`03001oogoo
02Qoo`03001oogoo0:9oo`80045oo`03001oogoo01eoo`03001oogoo04]oo`03001oogoo01eoo`03
001oogoo01moo`00>7oo00<007ooOol0EGoo00<007ooOol0:Goo00<007ooOol0XWoo00<007ooOol0
?goo00<007ooOol07Woo00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol07goo000hOol00`00
Oomoo`1EOol00`00Oomoo`0ZOol00`00Oomoo`2QOol00`00Oomoo`0oOol00`00Oomoo`0NOol00`00
Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`0OOol003Qoo`8005Eoo`03001oogoo02]oo`03001o
ogoo0:5oo`80041oo`03001oogoo01moo`03001oogoo04Uoo`03001oogoo01moo`03001oogoo01io
o`007goo0`001Woo0P001Goo10001Goo00<007ooOol0E7oo00<007ooOol0:goo00<007ooOol0R7oo
0`001Woo0P001Goo10001Goo00<007ooOol0?Woo00<007ooOol087oo00<007ooOol0BGoo00<007oo
Ool07goo00<007ooOol07Woo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<0
07ooOol0E7oo00<007ooOol0;7oo00<007ooOol0QWoo00D007ooOomoo`0000Eoo`8000Uoo`03001o
ogoo009oo`03001oogoo03ioo`03001oogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001o
ogoo01ioo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo05=oo`03
001oogoo02eoo`03001oogoo07ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00
Oomoo`0nOol00`00Oomoo`0QOol00`00Oomoo`17Ool00`00Oomoo`0POol00`00Oomoo`0NOol001io
o`05001oogooOol0000@Ool00`00Oomoo`02Ool2001DOol00`00Oomoo`0]Ool00`00Oomoo`26Ool0
1@00Oomoogoo000047oo00<007ooOol00Woo0P00?Woo00<007ooOol08Woo00<007ooOol0Agoo00<0
07ooOol08Goo00<007ooOol07Goo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0Dgoo
00<007ooOol0;Woo00<007ooOol0QGoo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo03eoo`03
001oogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo01eoo`007Woo00D007ooOomo
o`0000aoo`03001oogoo00Ioo`03001oogoo059oo`03001oogoo02moo`03001oogoo08Eoo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0mOol00`00Oomoo`0ROol00`00Oomoo`16Ool0
0`00Oomoo`0ROol00`00Oomoo`0MOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00
Oomoo`1BOol00`00Oomoo`0`Ool00`00Oomoo`24Ool01@00Oomoogoo000037oo00<007ooOol01Woo
00<007ooOol0?Goo00<007ooOol08goo00<007ooOol0AGoo00<007ooOol08Woo00<007ooOol07Goo
000OOol3000=Ool40005Ool2001COol00`00Oomoo`0`Ool00`00Oomoo`25Ool3000=Ool40005Ool2
000mOol00`00Oomoo`0TOol00`00Oomoo`14Ool00`00Oomoo`0TOol00`00Oomoo`0LOol003Qoo`03
001oogoo055oo`03001oogoo035oo`03001oogoo09ioo`03001oogoo03aoo`03001oogoo02Aoo`03
001oogoo04Aoo`03001oogoo02Aoo`03001oogoo01aoo`00>7oo00<007ooOol0DGoo00<007ooOol0
<Woo00<007ooOol0WGoo00<007ooOol0?7oo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol0
97oo00<007ooOol077oo000hOol2001BOol00`00Oomoo`0bOol00`00Oomoo`2MOol2000mOol00`00
Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`0KOol003Qoo`03001oogoo051o
o`03001oogoo03=oo`03001oogoo09eoo`03001oogoo03]oo`03001oogoo02Ioo`03001oogoo049o
o`03001oogoo02Ioo`03001oogoo01]oo`00>7oo00<007ooOol0D7oo00<007ooOol0=7oo00<007oo
Ool0W7oo00<007ooOol0>goo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007oo
Ool06goo000hOol00`00Oomoo`1@Ool00`00Oomoo`0dOol00`00Oomoo`2LOol00`00Oomoo`0kOol0
0`00Oomoo`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomoo`0KOol003Qoo`80051oo`03
001oogoo03Ioo`03001oogoo09]oo`8003aoo`03001oogoo02Moo`03001oogoo045oo`03001oogoo
02Moo`03001oogoo01Yoo`00>7oo00<007ooOol0Cgoo00<007ooOol0=Woo00<007ooOol0Vgoo00<0
07ooOol0>Woo00<007ooOol0:7oo00<007ooOol0@7oo00<007ooOol0:7oo00<007ooOol06Woo000h
Ool00`00Oomoo`1?Ool00`00Oomoo`0fOol00`00Oomoo`2KOol00`00Oomoo`0jOol00`00Oomoo`0X
Ool00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`0JOol003Qoo`8004moo`03001oogoo03Qo
o`03001oogoo09Yoo`8003]oo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001o
ogoo01Yoo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0CWoo00<007ooOol0>7oo
00<007ooOol0NGoo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0>Woo00<007ooOol0:Goo
00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol06Goo000FOol01@00Oomoogoo00001Goo0P00
1Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo04ioo`03001oogoo03Qoo`03001oogoo
07Qoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0
>Goo00<007ooOol0:Woo00<007ooOol0?Woo00<007ooOol0:Woo00<007ooOol06Goo000>Ool60002
Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0CGoo00<007oo
Ool0>Woo00<007ooOol0Kgoo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo03Uoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo
01Uoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8004ioo`03001o
ogoo03Yoo`03001oogoo07Moo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2
000jOol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0[Ool00`00Oomoo`0HOol001Ioo`05
001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00
Oomoo`1gOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0>7oo00<007oo
Ool0;7oo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol067oo000FOol01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0C7oo00<007ooOol0?7oo00<007ooOol0
MWoo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo03Qoo`03001o
ogoo02aoo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo01Qoo`005Woo00D007ooOomoo`00
00]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001=Ool00`00Oomoo`0lOol00`00Oomoo`1f
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8003Uoo`03001oogoo
02aoo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo01Qoo`005goo0`003Goo0`001Goo1000
1Goo00<007ooOol0C7oo00<007ooOol0?7oo00<007ooOol0Mgoo0`003Goo0`001Goo10001Goo00<0
07ooOol0>7oo00<007ooOol0;7oo00<007ooOol0?7oo00<007ooOol0;Goo00<007ooOol05goo000h
Ool00`00Oomoo`1;Ool00`00Oomoo`0nOol00`00Oomoo`2GOol00`00Oomoo`0gOol00`00Oomoo`0^
Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`0GOol003Qoo`03001oogoo01moo`<000Io
o`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<0009oo`03001oogoo01Ao
o`<000Ioo`8000Eoo`<0029oo`D004Uoo`03001oogoo01moo`<000Ioo`8000Aoo`D000Aoo`03001o
ogoo015oo`<000Ioo`8000Ioo`<000Uoo`03001oogoo00aoo`<000Ioo`8000Eoo`<001Uoo`<000Io
o`8000Eoo`<0021oo`H001Aoo`00>7oo0P007goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo
000GOol20002Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P00
17oo00L007ooOomoo`00Ool0000EOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0002=o
o`03001oogoo04Uoo`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`0017oo00<007oo
Ool047oo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo00Qoo`03001oogoo00]oo`05001oogoo
Ool00005Ool20004Ool01@00Oomoogoo00005goo00<007ooOol00P001Goo0P0017oo00D007ooOomo
o`0001moo`04001oogoo000FOol003Qoo`03001oogoo01ioo`05001oogooOol0000=Ool00`00Oomo
o`0GOol01@00Oomoogoo00002goo1@005goo00D007ooOomoo`0000]oo`05001oogooOol00002Ool0
0`00Oomoo`0BOol01@00Oomoogoo00002goo00D007ooOomoo`0002=oo`03001oogoo04Uoo`03001o
ogoo01ioo`05001oogooOol0000=Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool01@00Oomoogoo0000
2goo1@002Goo00<007ooOol02goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol00`00Oomo
o`02000;Ool01@00Oomoogoo000087oo00<007oo00005Woo000hOol00`00Oomoo`0NOol01@00Oomo
ogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo
00002goo00D007ooOomoo`00009oo`03001oogoo019oo`05001oogooOol0000;Ool01@00Oomoogoo
00008goo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo009oo`03
001oogoo015oo`05001oogooOol0000;Ool01000Oomoo`002goo00<007ooOol02Woo00D007ooOomo
o`0000]oo`05001oogooOol0000GOol01@00Ool007oo00002goo00D007ooOomoo`00021oo`03001o
o`0001Ioo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogoo
Ool0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10000goo00<007ooOol04Woo00D007oo
Oomoo`0000aoo`<002Aoo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000?Ool01@00
Oomoogoo00004goo00D007ooOomoo`0000aoo`03001oo`0000]oo`03001oogoo00Yoo`05001oogoo
Ool0000;Ool4000HOol01@00Ool007oo000037oo0`008Goo00<007oo00005Woo000hOol2000OOol0
1@00Oomoogoo00003goo00<007ooOol057oo0P000goo00<007ooOol02Woo00<007oo000067oo00D0
07ooOomoo`0000]oo`03001oogoo00Eoo`03001oogoo015oo`05001oogooOol0000;Ool01@00Oomo
ogoo00008goo00<007ooOol0BGoo0P007goo00D007ooOomoo`0000moo`05001oogooOol0000COol0
1@00Oomoogoo000037oo00<007oo00002goo00<007ooOol02Woo00D007ooOomoo`0000]oo`03001o
ogoo01Uoo`05001oo`00Ool0000;Ool01@00Oomoogoo00008Goo0P005Woo000hOol00`00Oomoo`0N
Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Ioo`8000=oo`03001oogoo00]oo`8001Qoo`05
001oogooOol0000<Ool00`00Oomoo`04Ool00`00Oomoo`0AOol01@00Oomoogoo00002goo00D007oo
Oomoo`0002=oo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo
00000goo00<007ooOol04Goo00D007ooOomoo`0000eoo`8000]oo`03001oogoo00Yoo`05001oogoo
Ool0000<Ool00`00Oomoo`0HOol01@00Ool007oo00002goo00D007ooOomoo`00025oo`8001Ioo`00
>7oo00<007ooOol07goo0`003Goo0`005goo00<007oo00000P003goo00<007ooOol05goo0`003Woo
0`000goo00<007ooOol04Woo0`003Goo0`008Woo0`00Bgoo00<007ooOol07goo0`003Goo0`000goo
00<007ooOol04goo0`003goo00<007ooOol02Woo00<007ooOol02Woo0`003Woo0`0067oo0`003Goo
0`008Goo0`005Woo000hOol20019Ool00`00Oomoo`14Ool00`00Oomoo`2DOol2000fOol00`00Oomo
o`0bOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`0EOol003Qoo`03001oogoo04Qoo`03
001oogoo04Aoo`03001oogoo09Aoo`03001oogoo03Eoo`03001oogoo039oo`03001oogoo03Ioo`03
001oogoo03=oo`03001oogoo01Aoo`00>7oo00<007ooOol0B7oo00<007ooOol0A7oo00<007ooOol0
U7oo00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=Woo00<007ooOol0<goo00<007ooOol0
57oo000hOol00`00Oomoo`17Ool00`00Oomoo`16Ool00`00Oomoo`2COol00`00Oomoo`0dOol00`00
Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0DOol0039oonT0041oonT0011o
o`00>7oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol017oo00D007ooOomoo`0000Yoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`05001oogooOol00006
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool2001;Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0DOol003Qoo`8004Moo`03001oogoo04Qoo`03001o
ogoo04Eoo`03001oogoo04Yoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001o
ogoo04]oo`00>7oo0P00Agoo00<007ooOol0B7oo00<007ooOol0A7oo00<007ooOol0Bgoo0P00=7oo
00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol0C7oo000hOol20016Ool00`00Oomoo`19Ool0
0`00Oomoo`14Ool00`00Oomoo`1;Ool2000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomo
o`1<Ool003Qoo`03001oo`0004Eoo`03001oogoo04Yoo`03001oogoo04=oo`03001oogoo04]oo`80
03Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo00<007oo0000AGoo00<0
07ooOol0BWoo00<007ooOol0@Woo00<007ooOol0C7oo0P00=7oo00<007ooOol0=Woo00<007ooOol0
<Woo00<007ooOol0C7oo000hOol30014Ool00`00Oomoo`1;Ool00`00Oomoo`12Ool00`00Oomoo`1<
Ool3000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`1=Ool003Qoo`04001oogoo0013
Ool00`00Oomoo`1<Ool00`00Oomoo`11Ool00`00Oomoo`1<Ool00`00Ool0000bOol00`00Oomoo`0h
Ool00`00Oomoo`0`Ool00`00Oomoo`1=Ool003Qoo`04001oogoo0013Ool00`00Oomoo`1<Ool00`00
Oomoo`10Ool00`00Oomoo`1=Ool00`00Ool0000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00
Oomoo`1=Ool003Qoo`04001oogoo0012Ool00`00Oomoo`1=Ool00`00Oomoo`10Ool00`00Oomoo`1=
Ool00`00Ool0000bOol00`00Oomoo`0iOol00`00Oomoo`0_Ool00`00Oomoo`1=Ool003Qoo`80009o
o`03001oogoo03moo`03001oogoo04ioo`03001oogoo03moo`03001oogoo04eoo`800003Ool007oo
02moo`03001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo00D007ooOomoo`00045o
o`03001oogoo04ioo`03001oogoo03ioo`03001oogoo04ioo`04001oogoo000`Ool00`00Oomoo`0j
Ool00`00Oomoo`0^Ool00`00Oomoo`1>Ool003Qoo`05001oogooOol00010Ool00`00Oomoo`1?Ool0
0`00Oomoo`0nOol00`00Oomoo`1>Ool01000Oomoo`00<7oo00<007ooOol0>Woo00<007ooOol0;Woo
00<007ooOol0CWoo000hOol20003Ool00`00Oomoo`0mOol00`00Oomoo`1@Ool00`00Oomoo`0mOol0
0`00Oomoo`1>Ool200000goo001oo`0_Ool00`00Oomoo`0kOol00`00Oomoo`0]Ool00`00Oomoo`1>
Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo009oo`03001oogoo03aoo`03001o
ogoo055oo`03001oogoo03aoo`03001oogoo02ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`05001o
ogooOol0000^Ool00`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`1?Ool001Ioo`05001oogoo
Ool00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
?7oo00<007ooOol0DWoo00<007ooOol0>goo00<007ooOol0;Goo00D007ooOomoo`0000Eoo`8000Eo
o`04001oogoo0008Ool00`00Oomoo`02Ool01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007oo
Ool0;7oo00<007ooOol0Cgoo000FOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol0>goo00<007ooOol0DWoo00<007ooOol0>goo00<007ooOol0
;Goo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`05001oogooOol0000^Ool0
0`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`1?Ool001Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`0jOol00`00Oomoo`1COol00`00Oomoo`0j
Ool00`00Oomoo`0^Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P000goo
00<007ooOol0:goo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol0Cgoo000FOol01@00Oomo
ogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol00goo00<007ooOol0>Woo00<007ooOol0
E7oo00<007ooOol0>Goo00<007ooOol0;Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eo
o`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo051o
o`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo03Uoo`03001oogoo05Aoo`03001oogoo03Uoo`03001oogoo02ioo`05001oogooOol0000?
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`0n
Ool00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P001Goo00<007ooOol0>7oo00<007ooOol0EGoo00<007ooOol0>7oo00<0
07ooOol0;goo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20003Ool0
0`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Moo`<000eoo`<0
00Eoo`@000Eoo`03001oogoo00Aoo`03001oogoo03Qoo`03001oogoo05Ioo`03001oogoo03Moo`03
001oogoo031oo`<000eoo`<000Eoo`@000Eoo`03001oogoo00=oo`03001oogoo02Uoo`03001oogoo
03moo`03001oogoo02Qoo`03001oogoo055oo`00>7oo00<007ooOol01Goo00<007ooOol0=goo00<0
07ooOol0EWoo00<007ooOol0=goo00<007ooOol0DGoo00<007ooOol00goo00<007ooOol0:7oo00<0
07ooOol0@7oo00<007ooOol0:7oo00<007ooOol0DGoo000hOol00`00Oomoo`05Ool00`00Oomoo`0f
Ool00`00Oomoo`1GOol00`00Oomoo`0fOol00`00Oomoo`1BOol00`00Oomoo`03Ool00`00Oomoo`0X
Ool00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`1AOol003Qoo`8000Ioo`03001oogoo03Io
o`03001oogoo05Qoo`03001oogoo03Eoo`03001oogoo059oo`8000Aoo`03001oogoo02Qoo`03001o
ogoo041oo`03001oogoo02Qoo`03001oogoo055oo`00>7oo00<007ooOol01Woo00<007ooOol0=Goo
00<007ooOol0F7oo00<007ooOol0=Goo00<007ooOol0DWoo00<007ooOol017oo00<007ooOol09goo
00<007ooOol0@Goo00<007ooOol09Woo00<007ooOol0DWoo000hOol00`00Oomoo`06Ool00`00Oomo
o`0dOol00`00Oomoo`1IOol00`00Oomoo`0dOol00`00Oomoo`1COol00`00Oomoo`04Ool00`00Oomo
o`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomoo`1BOol003Qoo`8000Moo`03001oogoo
03Aoo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo05=oo`8000Eoo`03001oogoo02Ioo`03
001oogoo049oo`03001oogoo02Ioo`03001oogoo059oo`00>7oo00<007ooOol01goo00<007ooOol0
<Woo00<007ooOol0Fgoo00<007ooOol0<goo00<007ooOol0Dgoo00<007ooOol017oo00<007ooOol0
9Woo00<007ooOol0@goo00<007ooOol09Goo00<007ooOol0DWoo000hOol00`00Oomoo`07Ool00`00
Oomoo`0bOol00`00Oomoo`1KOol00`00Oomoo`0bOol00`00Oomoo`1DOol00`00Oomoo`05Ool00`00
Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`0TOol00`00Oomoo`1COol003Qoo`03001oogoo00Mo
o`03001oogoo039oo`03001oogoo05aoo`03001oogoo035oo`03001oogoo05Aoo`03001oogoo00Eo
o`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo05=oo`00>7oo0P002Goo
00<007ooOol0<7oo00<007ooOol0GGoo00<007ooOol0<Goo00<007ooOol0E7oo0P001Woo00<007oo
Ool097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol0Dgoo000OOol30006Ool20005Ool4
0005Ool00`00Oomoo`08Ool00`00Oomoo`0`Ool00`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomo
o`0lOol30006Ool20005Ool40005Ool00`00Oomoo`05Ool00`00Oomoo`0TOol00`00Oomoo`15Ool0
0`00Oomoo`0SOol00`00Oomoo`1COol001ioo`05001oogooOol00005Ool20009Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool00`00Oomoo`0k
Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol08goo
00<007ooOol0AGoo00<007ooOol08Woo00<007ooOol0E7oo000NOol01@00Oomoogoo000047oo00<0
07ooOol00Woo00<007ooOol02Goo00<007ooOol0;Woo00<007ooOol0Ggoo00<007ooOol0;Woo00<0
07ooOol0?7oo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo029o
o`03001oogoo04Ioo`03001oogoo029oo`03001oogoo05Aoo`007Woo00D007ooOomoo`00011oo`03
001oogoo009oo`8000]oo`03001oogoo02eoo`03001oogoo05moo`03001oogoo02ioo`03001oogoo
03aoo`05001oogooOol0000@Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`0ROol00`00Oomoo`16
Ool00`00Oomoo`0ROol00`00Oomoo`1DOol001ioo`05001oogooOol0000<Ool40005Ool00`00Oomo
o`0:Ool00`00Oomoo`0]Ool00`00Oomoo`1POol00`00Oomoo`0]Ool00`00Oomoo`0lOol01@00Oomo
ogoo000037oo10001Goo00<007ooOol01Woo00<007ooOol08Woo00<007ooOol0Agoo00<007ooOol0
8Goo00<007ooOol0E7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol02Woo
00<007ooOol0;7oo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0?Goo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo021oo`03001oogoo04Qoo`03001oogoo
021oo`03001oogoo05Eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`8000aoo`03001o
ogoo02]oo`03001oogoo065oo`03001oogoo02aoo`03001oogoo03eoo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool20008Ool00`00Oomoo`0POol00`00Oomoo`18Ool00`00Oomoo`0POol00`00Oomo
o`1EOol001moo`<000eoo`@000Eoo`03001oogoo00]oo`03001oogoo02Yoo`03001oogoo06=oo`03
001oogoo02Yoo`03001oogoo03moo`<000eoo`@000Eoo`03001oogoo00Moo`03001oogoo021oo`03
001oogoo04Uoo`03001oogoo01moo`03001oogoo05Eoo`00>7oo00<007ooOol037oo00<007ooOol0
:Goo00<007ooOol0Hgoo00<007ooOol0:Woo00<007ooOol0F7oo00<007ooOol01goo00<007ooOol0
7goo00<007ooOol0BWoo00<007ooOol07goo00<007ooOol0EGoo000hOol00`00Oomoo`0<Ool00`00
Oomoo`0YOol00`00Oomoo`1SOol00`00Oomoo`0ZOol00`00Oomoo`1HOol00`00Oomoo`08Ool00`00
Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`1FOol003Qoo`8000eoo`03001o
ogoo02Qoo`03001oogoo06Eoo`03001oogoo02Qoo`03001oogoo05Uoo`8000Uoo`03001oogoo01io
o`03001oogoo04]oo`03001oogoo01eoo`03001oogoo05Ioo`00>7oo00<007ooOol03Goo00<007oo
Ool09goo00<007ooOol0IGoo00<007ooOol0:7oo00<007ooOol0FGoo00<007ooOol027oo00<007oo
Ool07Goo00<007ooOol0C7oo00<007ooOol07Goo00<007ooOol0EWoo000hOol00`00Oomoo`0=Ool0
0`00Oomoo`0WOol00`00Oomoo`1VOol00`00Oomoo`0WOol00`00Oomoo`1IOol00`00Oomoo`09Ool0
0`00Oomoo`0LOol00`00Oomoo`1<Ool00`00Oomoo`0LOol00`00Oomoo`1GOol003Qoo`8000moo`03
001oogoo02Eoo`03001oogoo06Moo`03001oogoo02Ioo`03001oogoo05Yoo`8000Yoo`03001oogoo
01aoo`03001oogoo04eoo`03001oogoo01]oo`03001oogoo05Moo`00>7oo00<007ooOol03Woo00<0
07ooOol09Goo00<007ooOol0J7oo00<007ooOol09Goo00<007ooOol0FWoo00<007ooOol02Goo00<0
07ooOol06goo00<007ooOol0CWoo00<007ooOol06goo00<007ooOol0Egoo000hOol00`00Oomoo`0?
Ool00`00Oomoo`0TOol00`00Oomoo`1XOol00`00Oomoo`0TOol00`00Oomoo`1KOol00`00Oomoo`09
Ool00`00Oomoo`0KOol00`00Oomoo`1>Ool00`00Oomoo`0JOol00`00Oomoo`1HOol003Qoo`03001o
ogoo00moo`03001oogoo02=oo`03001oogoo06Yoo`03001oogoo02=oo`03001oogoo05]oo`03001o
ogoo00Yoo`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo05Qoo`00>7oo
0P0047oo00<007ooOol08goo00<007ooOol0JWoo00<007ooOol08goo00<007ooOol0Fgoo0P002goo
00<007ooOol06Goo00<007ooOol0D7oo00<007ooOol06Goo00<007ooOol0F7oo000GOol30006Ool2
0006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`0@Ool00`00Oomoo`0QOol00`00Oomoo`1/Ool0
0`00Oomoo`0QOol00`00Oomoo`0kOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomo
o`0:Ool00`00Oomoo`0IOol00`00Oomoo`1@Ool00`00Oomoo`0HOol00`00Oomoo`1IOol001Ioo`05
001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00
Oomoo`0QOol00`00Oomoo`1/Ool00`00Oomoo`0QOol00`00Oomoo`0jOol01@00Oomoogoo00001Goo
0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol067oo00<007oo
Ool0DGoo00<007ooOol05goo00<007ooOol0FGoo000FOol01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol07goo00<007ooOol0KWoo00<007ooOol0
7goo00<007ooOol0>goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo00]oo`03001oogoo01Moo`03001oogoo059oo`03001oogoo01Moo`03001oogoo05Uoo`005Woo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80019oo`03001oogoo01moo`03
001oogoo06ioo`03001oogoo01moo`03001oogoo03]oo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool2000=Ool00`00Oomoo`0FOol00`00Oomoo`1BOol00`00Oomoo`0FOol00`00
Oomoo`1JOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`0BOol0
0`00Oomoo`0MOol00`00Oomoo`1`Ool00`00Oomoo`0MOol00`00Oomoo`0lOol01@00Oomoogoo0000
3Woo00<007ooOol00goo10001Goo00<007ooOol037oo00<007ooOol05Woo00<007ooOol0Dgoo00<0
07ooOol05Goo00<007ooOol0FWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol04Woo00<007ooOol07Goo00<007ooOol0L7oo00<007ooOol077oo00<007oo
Ool0?Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00aoo`03
001oogoo01Eoo`03001oogoo05Aoo`03001oogoo01Aoo`03001oogoo05]oo`005Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000COol00`00Oomoo`0LOol00`00Oomo
o`1aOol00`00Oomoo`0LOol00`00Oomoo`0mOol01@00Oomoogoo00002goo00D007ooOomoo`0000Ao
o`03001oogoo00Ioo`8000ioo`03001oogoo01Aoo`03001oogoo05Aoo`03001oogoo01Aoo`03001o
ogoo05]oo`005goo0`0037oo1@0017oo10001Goo00<007ooOol04goo00<007ooOol06goo00<007oo
Ool0LWoo00<007ooOol06Woo00<007ooOol0?goo0`0037oo1@0017oo10001Goo00<007ooOol03Goo
00<007ooOol057oo00<007ooOol0EGoo00<007ooOol04Woo00<007ooOol0G7oo000hOol00`00Oomo
o`0COol00`00Oomoo`0JOol00`00Oomoo`1cOol00`00Oomoo`0JOol00`00Oomoo`1POol00`00Oomo
o`0>Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol00`00Oomoo`1LOol003Qoo`03
001oogoo01Aoo`03001oogoo01Uoo`03001oogoo07Aoo`03001oogoo01Qoo`03001oogoo065oo`03
001oogoo00ioo`03001oogoo019oo`03001oogoo05Ioo`03001oogoo019oo`03001oogoo05aoo`00
>7oo0P005Goo00<007ooOol067oo00<007ooOol0MGoo00<007ooOol067oo00<007ooOol0HGoo0P00
3goo00<007ooOol04Woo00<007ooOol0Egoo00<007ooOol047oo00<007ooOol0GGoo000hOol00`00
Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`1gOol00`00Oomoo`0FOol00`00Oomoo`1ROol00`00
Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0@Ool00`00Oomoo`1MOol003Qo
o`03001oogoo01Ioo`03001oogoo01Aoo`03001oogoo07Uoo`03001oogoo01Aoo`03001oogoo06=o
o`03001oogoo00moo`03001oogoo011oo`03001oogoo05Uoo`03001oogoo00ioo`03001oogoo05io
o`00>7oo0P0067oo00<007ooOol04goo00<007ooOol0NWoo00<007ooOol04goo00<007ooOol0Hgoo
0P004Goo00<007ooOol03Woo00<007ooOol0FWoo00<007ooOol03Woo00<007ooOol0GWoo000hOol0
0`00Oomoo`0HOol00`00Oomoo`0AOol00`00Oomoo`1lOol00`00Oomoo`0AOol00`00Oomoo`1TOol0
0`00Oomoo`0AOol00`00Oomoo`0=Ool00`00Oomoo`1KOol00`00Oomoo`0<Ool00`00Oomoo`1OOol0
03Qoo`03001oogoo01Uoo`03001oogoo00moo`03001oogoo07ioo`03001oogoo00moo`03001oogoo
06Eoo`03001oogoo015oo`03001oogoo00aoo`03001oogoo05eoo`03001oogoo00]oo`03001oogoo
05moo`00>7oo00<007ooOol06Goo00<007ooOol03Woo00<007ooOol0P7oo00<007ooOol03Goo00<0
07ooOol0IWoo00<007ooOol04Woo00<007ooOol02Woo00<007ooOol0Ggoo00<007ooOol02Goo00<0
07ooOol0H7oo000hOol2000KOol00`00Oomoo`0;Ool20024Ool00`00Oomoo`0;Ool00`00Oomoo`1W
Ool2000DOol00`00Oomoo`08Ool00`00Oomoo`1QOol00`00Oomoo`07Ool00`00Oomoo`1QOol002mo
o`D000Aoo`03001oogoo01]oo`03001oogoo00Uoo`03001oogoo08Eoo`03001oogoo00Uoo`03001o
ogoo05moo`D000Aoo`03001oogoo01Aoo`03001oogoo00Ioo`03001oogoo069oo`03001oogoo00Io
o`03001oogoo069oo`00<Goo00<007ooOol017oo00<007ooOol077oo0`001goo00<007ooOol0Qgoo
00<007ooOol01Woo0P00I7oo00<007ooOol017oo00<007ooOol05Goo00<007ooOol017oo00<007oo
Ool0I7oo00<007ooOol017oo00<007ooOol0Hgoo000aOol00`00Oomoo`04Ool2000POol7002;Ool8
001VOol00`00Oomoo`04Ool2000GOol6001XOol6001VOol0035oo`03001oogoo0?moobMoo`03001o
ogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00
nGoo003oOoooOomFOol00?mooomooeIoo`00UGoo0`0000Aoo`00000001Qoo`<00?moo`Moo`<00004
Ool00000000IOol3001dOol009Ioo`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000ogoo
1goo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001aoo`03
001oogoo0?moo`Eoo`05001oogooOol0000HOol5001dOol009Ioo`05001oogooOol00009Ool6000=
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00002Goo1P002Goo00@007ooOol007Eoo`00UWoo00D0
07ooOomoo`0001Yoo`800?moo`Qoo`05001oogooOol0000IOol00`00Ool0001eOol009Eoo`D001eo
o`03001oogoo0?moo`Aoo`D001Yoo`03001oo`0007Eoo`00/goo00D007ooOomoo`000?moobIoo`80
07Eoo`00]7oo0`00ogoo:7oo00<007ooOol0Lgoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol002moo`D00?moobEoo`D00?Moo`00<Goo00<0
07ooOol0ogoo9goo00<007ooOol0mgoo000VOol60005Ool00`00Oomoo`3oOolLOol60005Ool00`00
Oomoo`3gOol0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`8009moo`X004Qoo`00
<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0Vgoo0`002Woo
0`00AGoo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`2H
Ool3000@Ool20013Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`8009Qoo`03
001oogoo01=oo`03001oogoo041oo`00;goo0`001Woo00<007ooOol0ogoo7Woo0`001Woo00<007oo
Ool0UWoo00<007ooOol05Goo0P00@7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2DOol2000J
Ool2000nOol003Qoo`03001oogoo0?moobMoo`03001oogoo09=oo`03001oogoo01aoo`03001oogoo
03]oo`00>7oo0P00ogoo:7oo0P00Tgoo00<007ooOol07Woo00<007ooOol0>Woo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`2AOol00`00Oomoo`0POol00`00Oomoo`0iOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo091oo`03001oogoo029oo`03001oogoo03Qoo`00>7oo0P00ogoo:7oo0P00TGoo
00<007ooOol08Woo00<007ooOol0>7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2?Ool00`00
Oomoo`0TOol00`00Oomoo`0gOol003Qoo`03001oogoo0?moobMoo`03001oogoo08ioo`03001oogoo
02Ioo`03001oogoo03Ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0SGoo00<007ooOol0:7oo
00<007ooOol0=Goo000hOol2003oOolXOol2002=Ool00`00Oomoo`0YOol00`00Oomoo`0eOol001Mo
o`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03
001oogoo00Aoo`@000Eoo`03001oogoo08]oo`03001oogoo02]oo`03001oogoo03Aoo`005Woo00D0
07ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05
001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`2;Ool00`00
Oomoo`0/Ool00`00Oomoo`0cOol000ioo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`3lOol60002Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol0RWoo00<007ooOol0;Goo00<007ooOol0<goo000FOol01@00Oomoogoo
00003Woo00<007ooOol01goo00<007ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001o
ogoo00Moo`03001oogoo009oo`8008Yoo`03001oogoo02moo`03001oogoo039oo`005Woo00D007oo
Oomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool0
0`00Oomoo`03Ool40005Ool00`00Oomoo`29Ool00`00Oomoo`0`Ool00`00Oomoo`0aOol001Ioo`05
001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomo
ogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0R7oo00<007ooOol0<Woo00<0
07ooOol0<7oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`80
0?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00R7oo00<0
07ooOol0<goo00<007ooOol0<7oo000GOol3000<Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool3
000<Ool50004Ool40005Ool00`00Oomoo`27Ool00`00Oomoo`0dOol00`00Oomoo`0_Ool003Qoo`03
001oogoo0?moobMoo`03001oogoo08Ioo`03001oogoo03Ioo`03001oogoo02ioo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0QGoo00<007ooOol0=goo00<007ooOol0;Woo000hOol2003oOolXOol2
0026Ool00`00Oomoo`0hOol00`00Oomoo`0]Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Ao
o`03001oogoo03Yoo`03001oogoo02aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Pgoo00<0
07ooOol0>goo00<007ooOol0;7oo000hOol2003oOolXOol20024Ool00`00Oomoo`0lOol00`00Oomo
o`0[Ool003Qoo`03001oogoo0?moobMoo`03001oogoo089oo`03001oogoo03ioo`03001oogoo02Yo
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0PWoo00<007ooOol0?Woo00<007ooOol0:Woo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`21Ool00`00Oomoo`10Ool00`00Oomoo`0YOol003Qoo`80
0?moobQoo`80085oo`03001oogoo049oo`03001oogoo02Qoo`007goo0`001Woo0P001Goo10001Goo
00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0P7oo00<007ooOol0@Woo00<0
07ooOol0:7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo
3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo07moo`03001oogoo04Ao
o`03001oogoo02Moo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`Io
o`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2001oOol00`00Oomoo`16Ool00`00Oomo
o`0VOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomo
ogoo000047oo00<007ooOol00Woo00<007ooOol0OWoo00<007ooOol0AWoo00<007ooOol09Woo000N
Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eo
o`03001oogoo07eoo`03001oogoo04Qoo`03001oogoo02Eoo`007Woo00D007ooOomoo`0000aoo`03
001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomo
o`1mOol00`00Oomoo`18Ool00`00Oomoo`0UOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06
Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P00OGoo00<007ooOol0BWoo00<0
07ooOol097oo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomo
o`1kOol00`00Oomoo`1;Ool00`00Oomoo`0TOol003Qoo`03001oogoo0?moobMoo`03001oogoo07]o
o`03001oogoo04aoo`03001oogoo02=oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0NWoo00<0
07ooOol0CGoo00<007ooOol08goo000hOol2003oOolXOol2001kOol00`00Oomoo`1>Ool00`00Oomo
o`0ROol003Qoo`03001oogoo0?moobMoo`03001oogoo07Uoo`03001oogoo051oo`03001oogoo025o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0NGoo00<007ooOol0D7oo00<007ooOol08Goo000h
Ool2003oOolXOol2001iOol00`00Oomoo`1BOol00`00Oomoo`0POol003Qoo`03001oogoo0?moobMo
o`03001oogoo07Qoo`03001oogoo059oo`03001oogoo021oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0Mgoo00<007ooOol0E7oo00<007ooOol07goo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`1fOol00`00Oomoo`1EOol00`00Oomoo`0OOol003Qoo`800?moobQoo`8007Moo`03001oogoo05Io
o`03001oogoo01ioo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`00
1Woo0P0017oo1@0017oo10001Goo00<007ooOol0MGoo00<007ooOol0Egoo00<007ooOol07Woo000F
Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo0?mo
o`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0
MGoo00<007ooOol0F7oo00<007ooOol07Goo000>Ool60002Ool01@00Oomoogoo00003Goo00<007oo
Ool027oo00<007ooOol00Woo0P00oGoo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03
001oogoo009oo`8007Eoo`03001oogoo05Uoo`03001oogoo01eoo`005Woo00D007ooOomoo`0000io
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`1dOol00`00Oomoo`1JOol00`00Oomoo`0LOol001Io
o`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003goo00<007ooOol00Woo10001Goo00<007ooOol0Lgoo00<007ooOol0Fgoo00<007ooOol077oo
000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo07=oo`03001oogoo
05aoo`03001oogoo01]oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomo
o`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`80
07=oo`03001oogoo05eoo`03001oogoo01]oo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0
ogoo1Woo0`003Goo0`001Goo10001Goo00<007ooOol0LWoo00<007ooOol0GWoo00<007ooOol06Woo
000hOol00`00Oomoo`0OOol30006Ool20004Ool5000HOol30006Ool20006Ool3000HOol30006Ool2
0005Ool3000IOol30006Ool20005Ool3000ROol50019Ool00`00Oomoo`0OOol30006Ool20004Ool5
000HOol30006Ool20006Ool3000BOol00`00Oomoo`03Ool30006Ool20005Ool3000IOol30006Ool2
0005Ool3000MOol01000Oomoogoo1@0057oo000hOol2000OOol01@00Oomoogoo00001Goo0P001Goo
00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo0000
1Goo0P0017oo00D007ooOomoo`0001Moo`05001oogooOol00005Ool20004Ool01@00Oomoogoo0000
8goo00<007ooOol0BGoo0P007goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00
Oomoogoo00001Goo0P001goo00<007ooOol04Goo00<007ooOol00Woo00D007ooOomoo`0000Eoo`80
00Aoo`05001oogooOol0000GOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001eoo`03
001oogoo009oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000eoo`03001o
ogoo01Moo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomoo`0001Mo
o`05001oogooOol0000;Ool01@00Oomoogoo00008goo00<007ooOol0BGoo00<007ooOol07Woo00D0
07ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000AOol00`00Oomoo`03Ool0
1@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo0000
7Goo00<007ooOol00Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Woo
00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D0
07ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00008goo00<007ooOol0BGoo00<0
07ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000Oomo
o`004Woo00<007ooOol00goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo
00002goo00D007ooOomoo`0001ioo`05001oogooOol0000FOol003Qoo`03001oogoo01ioo`05001o
ogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomo
o`0000]oo`@001Qoo`05001oogooOol0000<Ool3000TOol00`00Oomoo`19Ool00`00Oomoo`0NOol0
1@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`00015oo`03001o
ogoo00Aoo`05001oogooOol0000;Ool4000HOol01@00Oomoogoo000037oo0`007goo00D007ooOomo
o`0001Ioo`00>7oo0P007goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<
Ool00`00Ool0000HOol01@00Oomoogoo00002goo00<007ooOol06Goo00D007ooOomoo`0000]oo`05
001oogooOol0000SOol00`00Oomoo`19Ool2000OOol01@00Oomoogoo00003goo00<007ooOol05Goo
00D007ooOomoo`0000aoo`03001oo`00015oo`03001oogoo00Aoo`05001oogooOol0000;Ool00`00
Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`03
001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`80
01Qoo`05001oogooOol0000<Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007ooOomoo`00
02=oo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo
00D007ooOomoo`0000eoo`80015oo`03001oogoo00Aoo`05001oogooOol0000<Ool00`00Oomoo`0H
Ool01@00Oomoogoo00002goo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`03001oogoo
01moo`<000eoo`<001Uoo`<000moo`03001oogoo01Moo`<000ioo`<001Qoo`<000eoo`<0029oo`<0
04]oo`03001oogoo01moo`<000eoo`<001Uoo`<000moo`03001oogoo00ioo`03001oogoo00Ioo`<0
00ioo`<001Qoo`<000eoo`<0025oo`<001Ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0KWoo
00<007ooOol0IWoo00<007ooOol05Woo000hOol2003oOolXOol2001^Ool00`00Oomoo`1XOol00`00
Oomoo`0EOol003Qoo`03001oogoo0?moobMoo`03001oogoo06eoo`03001oogoo06Qoo`03001oogoo
01Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0K7oo00<007ooOol0JWoo00<007ooOol057oo
000bOooY0010OooY000@Ool003Qoo`8000Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Moo`8004]oo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo00<007oo0000:Goo00<007ooOol0
:Goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:7oo00<007oo0000Bgoo0P00:Woo00<0
07ooOol0:Goo00<007ooOol04goo00<007ooOol04goo00<007ooOol0:Goo00<007ooOol0:Goo00<0
07ooOol057oo000hOol01000Oomoo`00eWoo00<007ooOol0C7oo0P00Jgoo00<007ooOol0Pgoo000h
Ool20002Ool00`00Oomoo`3BOol00`00Oomoo`1=Ool3001ZOol00`00Oomoo`23Ool003Qoo`03001o
ogoo009oo`03001oogoo0=1oo`03001oogoo04ioo`03001oo`0006Uoo`03001oogoo08Aoo`00>7oo
00<007ooOol00goo00<007ooOol0cWoo00<007ooOol0Cgoo00@007ooOol006Qoo`03001oogoo08Ao
o`00>7oo0P001Goo00<007ooOol0c7oo00<007ooOol0D7oo0P0000=oo`00Ool0IWoo00<007ooOol0
QGoo000hOol00`00Oomoo`05Ool00`00Oomoo`3:Ool00`00Oomoo`1AOol01@00Oomoogoo0000IWoo
00<007ooOol0QGoo000hOol00`00Oomoo`06Ool00`00Oomoo`38Ool00`00Oomoo`1BOol01@00Oomo
ogoo0000IGoo00<007ooOol0QWoo000hOol00`00Oomoo`07Ool00`00Oomoo`36Ool00`00Oomoo`1C
Ool00`00Oomoo`02Ool00`00Oomoo`1ROol00`00Oomoo`26Ool003Qoo`8000Uoo`03001oogoo0<Ao
o`03001oogoo05Aoo`8000=oo`03001oogoo065oo`03001oogoo08Moo`00>7oo00<007ooOol02Goo
00<007ooOol0`Woo00<007ooOol0EGoo00<007ooOol00goo00<007ooOol0H7oo00<007ooOol0Qgoo
000hOol00`00Oomoo`0:Ool00`00Oomoo`30Ool00`00Oomoo`1FOol00`00Oomoo`03Ool00`00Oomo
o`1OOol00`00Oomoo`28Ool003Qoo`03001oogoo00]oo`03001oogoo0;ioo`03001oogoo05Moo`03
001oogoo00Aoo`03001oogoo05ioo`03001oogoo08Qoo`00>7oo0P003Goo00<007ooOol0_7oo00<0
07ooOol0F7oo0P001Goo00<007ooOol0GGoo00<007ooOol0RGoo000GOol30006Ool20004Ool50004
Ool40005Ool00`00Oomoo`0=Ool00`00Oomoo`2jOol00`00Oomoo`0hOol30006Ool20004Ool50004
Ool40005Ool00`00Oomoo`05Ool00`00Oomoo`1LOol00`00Oomoo`29Ool001Ioo`05001oogooOol0
0005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol0^7oo
00<007ooOol0>7oo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool00`00Oomoo`1KOol00`00Oomoo`2:Ool001Ioo`05001oogooOol0000=Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool2000@Ool00`00Oomoo`2fOol00`00Oomoo`0iOol01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo0P001goo00<007ooOol0FWoo00<007ooOol0RWoo
000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol047oo00<0
07ooOol0/goo0P00?7oo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo00Ioo`03001oogoo05Uoo`03001oogoo08]oo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`@000Eoo`03001oogoo015oo`03001oogoo0;5oo`03001oogoo03aoo`05001oogooOol0000?
Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`07Ool00`00Oomoo`1HOol00`00Oomoo`2;Ool001Io
o`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomo
o`2_Ool00`00Oomoo`0mOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol0Egoo00<007ooOol0S7oo000FOol01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`8001Aoo`03001oogoo0:eoo`03001oogoo03ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P002Goo00<007ooOol0EWoo00<007oo
Ool0S7oo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`0DOol00`00Oomoo`2[Ool00`00Oomo
o`10Ool3000=Ool30005Ool40005Ool00`00Oomoo`08Ool00`00Oomoo`1EOol00`00Oomoo`2=Ool0
03Qoo`03001oogoo01Eoo`03001oogoo0:Uoo`03001oogoo069oo`03001oogoo00Uoo`03001oogoo
05=oo`03001oogoo08ioo`00>7oo0P005goo00<007ooOol0Ygoo00<007ooOol0Hgoo0P002Woo00<0
07ooOol0Dgoo00<007ooOol0SWoo000hOol00`00Oomoo`0GOol00`00Oomoo`2UOol00`00Oomoo`1T
Ool00`00Oomoo`0:Ool00`00Oomoo`1AOol00`00Oomoo`2?Ool003Qoo`03001oogoo01Qoo`03001o
ogoo0:=oo`03001oogoo06Eoo`03001oogoo00Yoo`03001oogoo055oo`03001oogoo08moo`00>7oo
00<007ooOol06Goo0P00XWoo00<007ooOol0IWoo00<007ooOol02goo00<007ooOol0Cgoo00<007oo
Ool0T7oo000hOol2000LOol00`00Oomoo`2NOol00`00Oomoo`1WOol2000<Ool00`00Oomoo`1?Ool0
0`00Oomoo`2@Ool003Qoo`03001oogoo01aoo`03001oogoo09aoo`03001oogoo06Qoo`03001oogoo
00]oo`03001oogoo04ioo`03001oogoo095oo`00>7oo00<007ooOol07Goo00<007ooOol0VWoo00<0
07ooOol0JGoo00<007ooOol037oo00<007ooOol0CGoo00<007ooOol0TGoo000hOol2000OOol00`00
Oomoo`2HOol00`00Oomoo`1ZOol2000=Ool00`00Oomoo`1<Ool00`00Oomoo`2BOol003Qoo`03001o
ogoo01moo`03001oogoo09Ioo`03001oogoo06]oo`03001oogoo00eoo`03001oogoo04Yoo`03001o
ogoo09=oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol087oo00<007ooOol0U7oo00<007oo
Ool0Dgoo0`001Woo0P001Goo10001Goo00<007ooOol03Goo00<007ooOol0BWoo00<007ooOol0Tgoo
000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol0
TWoo00<007ooOol0Dgoo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo00io
o`03001oogoo04Qoo`03001oogoo09Aoo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`80
02=oo`80091oo`8005Ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000?Ool00`00Oomoo`18
Ool00`00Oomoo`2DOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0TOol0
0`00Oomoo`2<Ool00`00Oomoo`1FOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0
3goo00<007ooOol0AWoo00<007ooOol0UGoo000NOol01@00Oomoogoo000037oo10001Goo00<007oo
Ool09Goo00<007ooOol0RWoo00<007ooOol0Egoo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo
00moo`03001oogoo04Ioo`03001oogoo09Eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Io
o`03001oogoo02Ioo`03001oogoo08Qoo`03001oogoo05Qoo`05001oogooOol0000<Ool00`00Oomo
o`06Ool00`00Oomoo`0@Ool00`00Oomoo`14Ool00`00Oomoo`2FOol001ioo`05001oogooOol0000<
Ool00`00Oomoo`06Ool2000XOol00`00Oomoo`26Ool00`00Oomoo`1IOol01@00Oomoogoo000037oo
00<007ooOol01Woo0P004Woo00<007ooOol0@Woo00<007ooOol0Ugoo000OOol3000=Ool40005Ool0
0`00Oomoo`0XOol00`00Oomoo`24Ool00`00Oomoo`1KOol3000=Ool40005Ool00`00Oomoo`0BOol0
0`00Oomoo`11Ool00`00Oomoo`2GOol003Qoo`03001oogoo02Uoo`03001oogoo089oo`03001oogoo
07Eoo`03001oogoo019oo`03001oogoo041oo`03001oogoo09Qoo`00>7oo0P00:goo00<007ooOol0
P7oo00<007ooOol0MWoo0P0057oo00<007ooOol0?Woo00<007ooOol0VGoo000hOol00`00Oomoo`0[
Ool2001nOol2001iOol00`00Oomoo`0DOol00`00Oomoo`0mOol00`00Oomoo`2IOol003Qoo`03001o
ogoo02eoo`03001oogoo07Yoo`03001oogoo07Uoo`03001oogoo01Aoo`03001oogoo03aoo`03001o
ogoo09Yoo`00>7oo00<007ooOol0;Woo00<007ooOol0N7oo00<007ooOol0NWoo00<007ooOol05Goo
00<007ooOol0>goo00<007ooOol0VWoo000hOol2000`Ool2001fOol2001mOol2000GOol00`00Oomo
o`0iOol00`00Oomoo`2KOol003Qoo`03001oogoo035oo`03001oogoo079oo`03001oogoo07eoo`03
001oogoo01Moo`03001oogoo03Moo`03001oogoo09aoo`00>7oo00<007ooOol0<Woo00<007ooOol0
L7oo00<007ooOol0OWoo00<007ooOol05goo00<007ooOol0=goo00<007ooOol0W7oo000hOol2000d
Ool00`00Oomoo`1^Ool00`00Oomoo`1oOol2000IOol00`00Oomoo`0eOol00`00Oomoo`2MOol001Mo
o`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo03Aoo`8006aoo`80065oo`<000Io
o`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo01Uoo`03001oogoo03=oo`03001oogoo09io
o`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo
03Ioo`8006Qoo`80069oo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`0IOol00`00Oomoo`0cOol00`00Oomoo`2NOol001Ioo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0hOol00`00Oomoo`1TOol00`00Oomoo`1ROol0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol06Woo00<007ooOol0
<Goo00<007ooOol0Wgoo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo
0P00>Woo0P00HWoo0P00IGoo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80
01aoo`03001oogoo02moo`03001oogoo0:1oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=o
o`@000Eoo`03001oogoo03]oo`8005ioo`8006Moo`05001oogooOol0000>Ool00`00Oomoo`03Ool4
0005Ool00`00Oomoo`0LOol00`00Oomoo`0]Ool00`00Oomoo`2QOol001Ioo`05001oogooOol0000?
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0mOol00`00Oomoo`1JOol00`00Oomoo`1W
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol077oo00<007oo
Ool0;7oo00<007ooOol0XWoo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001o
ogoo00Ioo`03001oogoo03ioo`8005Qoo`8006Yoo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo00<007ooOol07Goo00<007ooOol0:Woo00<007ooOol0Xgoo000GOol3000<
Ool50004Ool40005Ool20011Ool2001DOol2001]Ool3000<Ool50004Ool40005Ool2000OOol00`00
Oomoo`0YOol00`00Oomoo`2SOol003Qoo`03001oogoo049oo`80051oo`80091oo`03001oogoo01io
o`03001oogoo02Qoo`03001oogoo0:Aoo`00>7oo00<007ooOol0A7oo00<007ooOol0C7oo00<007oo
Ool0T7oo00<007ooOol07goo00<007ooOol09Woo00<007ooOol0YGoo000hOol20016Ool2001:Ool2
002COol2000QOol00`00Oomoo`0TOol00`00Oomoo`2VOol003Qoo`03001oogoo04Moo`8004Ioo`80
09Eoo`03001oogoo025oo`8002=oo`03001oogoo0:Moo`00>7oo00<007ooOol0BGoo0P00@Woo0P00
Ugoo00<007ooOol08goo00<007ooOol07goo00<007ooOol0Z7oo000hOol00`00Oomoo`1;Ool3000l
Ool3002IOol00`00Oomoo`0TOol00`00Oomoo`0MOol00`00Oomoo`2YOol003Qoo`8004moo`8003Qo
o`8009aoo`8002Ioo`03001oogoo01]oo`03001oogoo0:Yoo`00>7oo00<007ooOol0D7oo0P00=7oo
0P00WWoo00<007ooOol09Woo0P006Goo0P00[Goo000hOol00`00Oomoo`1BOol2000_Ool3002POol0
0`00Oomoo`0XOol00`00Oomoo`0DOol2002_Ool003Qoo`8005Eoo`8002Yoo`<00:=oo`8002Yoo`80
01=oo`03001oogoo0:moo`00;goo1@0017oo00<007ooOol0EWoo0`008goo1000WGoo1@0017oo00<0
07ooOol0:goo00<007ooOol03Woo0P00/Woo000aOol00`00Oomoo`04Ool00`00Oomoo`1IOol4000K
Ool4002SOol00`00Oomoo`04Ool00`00Oomoo`0/Ool00`00Oomoo`0;Ool2002dOol0035oo`03001o
ogoo00Aoo`03001oogoo05eoo`P000ioo`D00:Moo`03001oogoo00Aoo`03001oogoo02eoo`@000Mo
o`800;Ioo`00<Goo00<007ooOol017oo0P00IWoo3P00[7oo00<007ooOol017oo0P00<Woo1`00^7oo
000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo
0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3003oOolWOol3003iOol00?mo
oomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo1@00ogoo1Goo0`0000Aoo`000000
01Moo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogoo
Ool00009Ool6000:Ool01000Oomoo`00M7oo002FOol01@00Oomoogoo00006goo00<007ooOol0ogoo
1Woo00D007ooOomoo`0001Yoo`03001oogoo07Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03
001oogoo0?moo`Ioo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05001oogoo
Ool0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo000077oo00<007ooOol0LWoo002EOol5000L
Ool00`00Oomoo`3oOol5Ool5000MOol00`00Oomoo`1bOol00;Ioo`03001oogoo0?moob=oo`05001o
ogooOol0001dOol00;Aoo`<00?moobIoo`<007Eoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00\
\>"],
  ImageRangeCache->{{{0, 595.562}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.375, \
284.25}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.375, 284.25}, {175.5, 8.75}} -> {0, -3, 0, \
0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .41174 L
.08255 .46022 L
.10458 .5064 L
.12507 .54101 L
.14415 .56472 L
.14918 .56949 L
.15465 .57393 L
.15946 .5772 L
.16457 .58001 L
.16917 .58194 L
.17178 .58279 L
.17423 .58342 L
.17538 .58366 L
.17647 .58386 L
.17746 .58401 L
.17852 .58414 L
.17967 .58424 L
.18073 .58431 L
.182 .58435 L
.18314 .58435 L
.18435 .58431 L
.18547 .58424 L
.1867 .58412 L
.18802 .58395 L
.19071 .58345 L
.19317 .58283 L
.1979 .58118 L
.20239 .57906 L
.21236 .57245 L
.22321 .56235 L
.24299 .53655 L
.26399 .49964 L
.30174 .41399 L
.34195 .30717 L
.38063 .20445 L
.40028 .15721 L
.42177 .11214 L
.44253 .07701 L
.4614 .05353 L
.47149 .04457 L
.47611 .04134 L
.48101 .03853 L
.4835 .03734 L
.48624 .03623 L
.48876 .03538 L
.49106 .03476 L
.49378 .0342 L
.49527 .03398 L
.49596 .0339 L
Mistroke
.49669 .03383 L
.498 .03373 L
.49921 .03369 L
.49996 .03368 L
.50065 .03369 L
.50196 .03373 L
.50313 .03381 L
.50438 .03394 L
.50556 .0341 L
.50663 .03427 L
.50926 .03484 L
.51175 .03554 L
.5167 .03743 L
.52208 .04023 L
.53169 .04711 L
.54056 .05557 L
.55926 .07969 L
.57988 .11532 L
.62014 .2064 L
.65888 .30941 L
.70007 .41854 L
.72063 .46734 L
.73974 .50686 L
.75939 .54012 L
.77791 .56353 L
.78775 .57254 L
.79293 .57628 L
.7984 .57947 L
.80302 .58155 L
.80546 .58241 L
.80809 .58317 L
.8105 .5837 L
.8127 .58405 L
.81375 .58417 L
.81491 .58427 L
.81599 .58432 L
.817 .58435 L
.81818 .58435 L
.81941 .5843 L
.82047 .58423 L
.82163 .58412 L
.82287 .58396 L
.82421 .58374 L
.82661 .58322 L
.82905 .58255 L
.83134 .58176 L
.83564 .57991 L
.84078 .57705 L
.84552 .57381 L
.85624 .56433 L
Mistroke
.87498 .54094 L
.89561 .50604 L
.93591 .41587 L
.97471 .31306 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .43101 L
.08255 .48397 L
.0932 .50724 L
.10458 .5278 L
.11009 .53602 L
.11531 .54268 L
.12038 .5481 L
.12507 .55216 L
.12951 .55515 L
.13178 .55635 L
.13422 .55739 L
.13549 .55784 L
.13666 .55818 L
.13784 .55847 L
.13895 .55868 L
.14022 .55887 L
.1409 .55893 L
.14161 .55898 L
.1423 .55901 L
.14295 .55902 L
.14415 .55898 L
.14531 .55889 L
.14656 .55872 L
.14773 .5585 L
.14881 .55825 L
.15143 .55742 L
.15392 .55636 L
.15886 .55347 L
.16423 .54914 L
.17383 .53844 L
.1827 .52525 L
.20137 .48814 L
.22197 .43474 L
.26217 .30814 L
.30086 .1861 L
.32051 .1344 L
.3309 .11159 L
.342 .09132 L
.35275 .07612 L
.35784 .07055 L
.36253 .06637 L
.36724 .0631 L
.36972 .06176 L
.37235 .06063 L
.37463 .05989 L
.37573 .05961 L
.37677 .0594 L
.37799 .05921 L
.37911 .05909 L
Mistroke
.38031 .05903 L
.38162 .05903 L
.38227 .05905 L
.38296 .0591 L
.38419 .05924 L
.38551 .05947 L
.38695 .0598 L
.38955 .06062 L
.39197 .06165 L
.39649 .06425 L
.40134 .068 L
.40698 .07361 L
.41232 .08012 L
.42232 .09535 L
.44227 .13647 L
.4607 .18512 L
.50002 .30909 L
.53782 .42867 L
.55884 .48419 L
.56803 .50449 L
.57808 .52337 L
.58722 .53729 L
.59696 .54848 L
.60236 .55298 L
.60726 .556 L
.60962 .55709 L
.61086 .55756 L
.61218 .55799 L
.61333 .55831 L
.61459 .55859 L
.61574 .55878 L
.61682 .55891 L
.61808 .559 L
.61871 .55901 L
.61941 .55901 L
.62065 .55896 L
.62181 .55885 L
.62248 .55876 L
.62318 .55865 L
.62443 .55839 L
.62578 .55803 L
.62725 .55755 L
.62973 .55654 L
.63238 .55516 L
.63715 .55192 L
.64214 .5475 L
.64686 .54237 L
.6557 .53035 L
.67568 .4924 L
.69413 .44605 L
Mistroke
.7335 .32417 L
.77136 .20279 L
.79241 .1448 L
.81166 .1027 L
.82118 .08664 L
.8262 .07956 L
.83155 .07313 L
.8367 .06806 L
.84136 .06442 L
.84361 .06299 L
.84604 .06169 L
.84835 .0607 L
.85045 .05999 L
.85159 .05969 L
.85283 .05942 L
.85414 .05921 L
.85538 .05908 L
.85653 .05903 L
.85776 .05903 L
.85881 .05908 L
.85997 .05919 L
.86063 .05928 L
.86132 .0594 L
.86256 .05966 L
.86535 .06048 L
.86777 .06147 L
.87041 .06284 L
.87569 .06646 L
.88133 .07164 L
.89148 .08424 L
.90173 .10105 L
.91284 .12354 L
.933 .17412 L
.97393 .30158 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34781 L
.10458 .38938 L
.14415 .42702 L
.18221 .46133 L
.22272 .49521 L
.26171 .5247 L
.30316 .55212 L
.34309 .57425 L
.3815 .59121 L
.40095 .59808 L
.42237 .60428 L
.44268 .60879 L
.45178 .61038 L
.46172 .6118 L
.4671 .61243 L
.4721 .61294 L
.47727 .61337 L
.48196 .61369 L
.48658 .61393 L
.4887 .61402 L
.49093 .61409 L
.49332 .61416 L
.49438 .61418 L
.49552 .6142 L
.49675 .61421 L
.49789 .61422 L
.49859 .61423 L
.49925 .61423 L
.50049 .61423 L
.50163 .61423 L
.50286 .61422 L
.50401 .6142 L
.50508 .61419 L
.50754 .61413 L
.51014 .61406 L
.51268 .61396 L
.51504 .61385 L
.5204 .61354 L
.5293 .6128 L
.53882 .61173 L
.54906 .61024 L
.56016 .60824 L
.58032 .60358 L
.62123 .59015 L
.66064 .57237 L
.69852 .55109 L
.73886 .52429 L
.77769 .49489 L
.81897 .46031 L
Mistroke
.85873 .42434 L
.89697 .38787 L
.93767 .3477 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .38312 L
.10458 .45832 L
.14415 .5186 L
.18221 .56321 L
.20178 .58009 L
.21267 .58754 L
.22272 .59314 L
.23293 .59756 L
.23832 .59936 L
.24402 .60087 L
.24641 .60137 L
.24897 .60184 L
.25119 .60218 L
.25361 .60247 L
.25507 .60261 L
.25643 .60272 L
.25773 .6028 L
.2584 .60283 L
.25912 .60286 L
.25983 .60288 L
.26048 .6029 L
.26176 .60291 L
.26293 .6029 L
.26416 .60288 L
.26538 .60283 L
.26607 .6028 L
.26671 .60276 L
.26912 .60258 L
.27131 .60234 L
.27364 .60203 L
.27847 .60116 L
.2838 .59985 L
.29326 .59665 L
.30213 .59262 L
.32232 .57987 L
.34082 .56397 L
.38045 .51752 L
.41855 .45944 L
.45912 .38733 L
.49816 .31258 L
.53966 .233 L
.57964 .16161 L
.61811 .1025 L
.63759 .0774 L
.65902 .05421 L
.67938 .0369 L
.69843 .02513 L
.70884 .02058 L
.71396 .01884 L
Mistroke
.71872 .01752 L
.72301 .01658 L
.72758 .01583 L
.7302 .01552 L
.73148 .0154 L
.73266 .01531 L
.73371 .01525 L
.73487 .01519 L
.73603 .01515 L
.73725 .01513 L
.73856 .01513 L
.73977 .01514 L
.7404 .01516 L
.7411 .01518 L
.74251 .01525 L
.74375 .01533 L
.74508 .01544 L
.74748 .01569 L
.74985 .01601 L
.75235 .01642 L
.7568 .01736 L
.76198 .01877 L
.7668 .02038 L
.77773 .02511 L
.78828 .03109 L
.79823 .03795 L
.81683 .05389 L
.85534 .09875 L
.89632 .16122 L
.93577 .23157 L
.97371 .30421 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L2000`400?l00000o`00003ooooooooo
oooooeKooooo003oooooooooooooE_ooool00?oooooooooooomFooooo`00oooooooooooooeKooooo
003oooooooooooooE_ooool00?oooooooooooomFooooo`00oooooooooooooeKooooo003ooooooooo
ooooE_ooool00?oooooooooooomFooooo`00oooooooooooooeKooooo003oooooooooooooE_ooool0
0?oooooooooooomFooooo`00;oooool4o`000003oa0@4?oooooooooo0?oooooo8oooool4o`000003
oa0@4?oooooooooo0?Gooooo000aooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003ooooo
ooooo`3gooooo`009_ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2o`000?oooooo5_oo
ool6o`0000Gooooo00?o0000ooooooooool01?ooool2o`000?7ooooo000aooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooolPooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0l?ooool0037ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
ob3ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3`ooooo`00<Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo8?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?3ooooo000aooooo`03o`000?oooooooooo00Cooooo0_l0003oooooob7ooooo
00?o0000ooooooooool01?ooool2o`000?7ooooo000_ooooo`03oeEEEOmVIVKo000000Kooooo00?o
0000ooooooooool0oooooolNooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0l?oo
ool003Sooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo0?3ooooo000hoooo
o`;o0000oooooolXooooo`;o0000lOooool003Sooooo00?o0000ooooooooool0JOooool6o`000;Oo
oooo00?o0000ooooooooool0l?ooool003Sooooo00?o0000ooooooooool0Ioooool2o`0000Kooooo
00?o0000ooooooooool0]?ooool00ol0003oooooooooo`3`ooooo`00>?ooool00ol0003ooooooooo
o`1Vooooo`03o`000?oooooooooo00Oooooo0ol0002cooooo`03o`000?oooooooooo0?3ooooo000h
ooooo`;o0000IOooool2o`0000gooooo00?o0000ooooooooool0/?ooool2o`000?7ooooo000hoooo
o`03o`000?oooooooooo06?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2_oooo
o`03o`000?oooooooooo0?3ooooo000hooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo0?3ooooo000hooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2^ooooo`03o`00
0?oooooooooo04gooooo1_l0001Xooooo`Ko0000;oooool003Sooooo0_l0001Rooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0[Oooool2o`0004gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Tooooo`;o00001Oooool00ol0003oooooooooo`0/ooooo`005_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`2:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`06ooooo`;o0000Hoooool00ol0003oooooooooo`06oooo
o`;o0000;?ooool001Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omE
EEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo08[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`003_ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool2
o`0005oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`21ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`02ooooo`;o0000B_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`005_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo05kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`28ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Xooooo`005_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Co
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo08So
oooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09oooool0
01Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0Qoooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09ooo
ool001Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`06ooooo`;o0000GOooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo08Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`06ooooo`;o0000B?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Voooo
o`005_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001Oooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Q_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001Oooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo02Kooooo000hooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool09Oooool003Sooooo0_l0001Kooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0Yoooool2o`0004Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool09Oooool003Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Tooooo`00>?ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02?ooooo000hooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`2Uooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08oooool0
03Sooooo0_l0001Iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Y?ooool2o`00
04Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool08_ooool003Sooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Rooooo`00>?ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0Xoooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo027ooooo
000hooooo`;o0000Eoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0:?ooooo0_l0
0013ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo027ooooo000Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`29ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08Oooool001kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`28ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo023ooooo000Fooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0P?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`007_ooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool2o`0005Kooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`27ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`03ooooo`;o0000@Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Pooooo`007_oo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`27ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`007_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0Q_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo000N
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo05?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`26ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool07oooool001kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
1Oooool2o`0005Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`26ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo0_l0000oooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01ko
oooo000hooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`2Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool003Sooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09oooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`00>?ooool2o`0005?ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`2Nooooo`;o0000?_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0M
ooooo`00>?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0W_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01gooooo000hooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Mooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool07Oooool003Sooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Looooo`00>?ooool2o`0005;ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`2Mooooo`;o0000?Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Looooo`00>?ooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0W?ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01cooooo000hooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool06oooool003Sooooo0_l0001@ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0Voooool2o`0003cooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06oooool001Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`1iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01_ooooo000Fooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo07Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01[ooooo000>ooooo`Ko
00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`1`ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool06_ooool001Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool00oooool2o`0004oooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`1hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000kooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo000F
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0N?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Iooooo`005_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`1gooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0Iooooo`005_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo0_l0001>ooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0Moooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo0_l0000jooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo01Wooooo000Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`1fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool06?ooool003Sooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0H
ooooo`00>?ooool00ol0003oooooooooo`0Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol0000Gooooo`05onk^k_l0003o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`0Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Kok^k^oc8b<_l0003o410@olc<c?l0000Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Pooooo`Co000000?o410@ooooooooool0Aooo
ool00ol0003oooooooooo`0Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00005ooooo`03o`000?oooooooooo00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Kooooo00?o0000ooooooooool03?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`05oooool0
1Oo^k^ko<S8bo`000?lb<S;o000000Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
7_ooool00ol0003oooooo`000003o`000003oa0@4?oooooooooo01;ooooo000hooooo`;o00007ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@05oooool01OmgMgOo0000oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
01Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01omEEEGoMgMgoooooonH
V9So8B4Qooooool000005_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B408_ooool00ol0003oooooooooo`19ooooo`;o00007oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool00ol0003oooooooooo`0?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Gooooo`05ogMgMonHV9Sooooo
oiRHV?l000001Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@0Oooooo`04o`000?oo
ooooooooo`0001Kooooo000hooooo`03o`000?oooooooooo01kooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^01Sooooo00Go410@o`000?oooooooooooa0@400;ooooo`Go
00005oooool01Ol@413ooooooooooooooooo410@00_ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000001Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00008_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01kooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool04?ooool01Ol@
413ooooooooooooooooo410@00_ooooo1Ol00009ooooo`03o`000?oooooooooo00_ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000005oooool01Ol@413ooooo
ooooool0003o410@00_ooooo00Go0000ooooooooooooooooo`00000Oooooo`04o`000?oooooooooo
o`0001Kooooo000hooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^01Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0001Sooooo00Go0000ooooooooooooooooo`00000;ooooo`07o`000?nHV9SooooooiRH
V?lQ8B7oooooo`00000Fooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b02;ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Nooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP04ooooo`03o`000?oooooooooo013o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000[ooooo00?o0000
ooooooooool02oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@0Gooooo`03o`000?oooooooooo00;o00002oooool01Olb<S;oV9RHoooooonHV9So<S8b01oo
oooo00Co0000oooooooooooo00005_ooool003Sooooo00?o0000ooooooooool07_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool05_ooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo00006?ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c002ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`08_ooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000000_ooooo
00CogMgMoeEEEOoooooo00002_ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oEEEEo`000?l@413oc<c<01Oooooo00?o0000ooooooooool00_l0000;
ooooo`05olc<c?l0003o0000o`000?o<c<`08?ooool00ol0003oooooo`00000Fooooo`00>?ooool2
o`0001oooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Gooooo00Go
0000oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001Sooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo00Cooooo00?o0000ooooooooool04oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Rooooo`03o`000?oooooo
oooo04Wooooo0_l0000Oooooo`05oa0@4?ooooooooooooooool@41003oooool01Ol0003ooooooooo
oooooooo000001?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000_o
oooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7
Qoooool06Oooool01Ol@413oooooo`000?oooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@
400Pooooo`03o`000?oooooo000001Kooooo000hooooo`03o`000?oooooooooo01kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41005_ooool01_l0003oMgMg
oiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000006?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?ogMgMoa0@4?nHV9P01Oooool00ol0003oooooooooo`0Booooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000002;ooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00?ooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l000002oooool00ol0003oooooooooo`0:ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Iooooo`05ogMgMonHV9So0000oiRHV?mgMgL0
2oooool01Ol0003o^[Zjoooooonj^[[o0000023ooooo00?o0000ooooool000005_ooool003Sooooo
00?o0000ooooooooool07_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00Fooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000oooo
o`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4103ooooo`03
o`000?oooooooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT08?ooool00omEEEGoIVIVo`00001;ooooo`03o`000?oooooooooo01kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool00ol0003ooooo
ooooo`0Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000
oa0@41Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
8?ooool00omEEEGo0000o`00000Fooooo`00>?ooool2o`0004Wooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`2Eooooo`;o0000=_ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Eooooo`00>?ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0U?ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01Gooooo000hooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool05?ooool003Sooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0Dooooo`00<_oooooYo`00043ooooojOl0000@ooooo`00>?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`;o0000Boooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool003Sooooo
0_l00017ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`1:ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo04cooooo000hooooo`;o0000Aoooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Boooool2o`0003Cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo04cooooo000h
ooooo`;o0000A_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool0Boooool2o`0003Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo04cooooo000hooooo`03o`000?oooooo000004Gooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04_ooooo0_l0000doooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1<oooo
o`00>?ooool00ol0003oooooo`000014ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo000003;ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04gooooo000hooooo`?o0000
A?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
C?ooool3o`0003;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo04gooooo000hooooo`04o`000?ooooooooooo`0004?ooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04cooooo00?o0000ooooool00000
<_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
COooool003Sooooo00Co0000oooooooooooo0000@_ooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool0COooool01?l0003oooooooooool0000`ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1>ooooo`00
>?ooool01Ol0003ooooooooooooooooo0000047ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo04gooooo00Co0000oooooooooooo0000<?ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0C_ooool003So
oooo0_l00002ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo04kooooo0_l000000ooooooo0000ooooo`0_ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1>ooooo`00
>?ooool01Ol0003ooooooooooooooooo0000043ooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo04kooooo00Go0000ooooooooooooooooo`00000^oooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?oooo
o`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo04kooooo00Go0000oooooooo
ooooooooo`00000^ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`1?ooooo`00>?ooool2o`0000?ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Coooool2o`0000;o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0Coooool001Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`1@ooooo`005_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0D?ooool001Kooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo053ooooo000Fooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00005ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool00oooool2o`0000Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0DOooool001Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0;oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Aooooo`005_ooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0;oooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0DOooool001Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`;o00001_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0_ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0DOooool001Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0`oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0D_ooool003Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0D_ooool003Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0D_ooool003Sooooo0_l00007ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo05?ooooo0_l00006ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05?ooooo000hooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo05?ooooo000hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0E?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05?ooooo000hooooo`;o00002Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`1Dooooo`;o00001oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Dooooo`00>?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0GOooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`1Dooooo`00>?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Dooooo`00>?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Goooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`1Eooooo`00>?ooool2o`0000[ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0E_ooool2o`0000Sooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0EOooool001kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0looooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0EOooool001ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1Fooooo`007_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03gooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`1Fooooo`007_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool00oooool2o`0000cooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0?_ooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool2o`0000[ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
E_ooool001kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03kooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo05Oooooo000Nooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0?oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo05Oooooo000Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`;o00003_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0oooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00002oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`1Hooooo`007_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0@?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00005ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0F?ooool003Sooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0F?ooool003Sooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0FOooool003Sooooo0_l0000?
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo05_ooooo0_l0000<ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0D_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05Wooooo000hoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Zoooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo05[ooooo000hooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0G?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05[ooooo000hooooo`;o0000
4Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`1Looooo`;o00003_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Kooooo`00>?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0K?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1Looooo`00>?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo05Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Looooo`00>?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Koooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Mooooo`00>?ooool2o`0001?ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Goooool2o`0000oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0GOooool001Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?oo
ool00ol0003oooooooooo`0?ooooo`;o00004Oooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0G_ooool001Kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0nooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Jooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0G_ooool001Kooooo00Go410@oooooooooooooooo
oa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0M?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo03kooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00_ooooo0_l0001Nooooo`;o00003Oooool00ol0003oooooooooo`1Oooooo`00
5_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo
<S8booooo`03ooooo`;o00005Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0oooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000Coooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo063ooooo000Fooooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo03oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0HOooool001Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo043ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;o
oooo000Fooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b
00Cooooo00?o0000ooooooooool01_ooool2o`0001Sooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oo
oooooooo00Kooooo0_l0000Fooooo`?o00000_ooool2o`0006Sooooo0_l00003ooooo`;o0000IOoo
ool001Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Gooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo07cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`12ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l00005ooooo`03o`000?oooooooooo01Oooooo1?l0001Zooooo`Co0000
Ioooool003Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo07kooooo00?o0000ooooooooool03_ooool2o`0006Oooooo00?o0000ooooooooool0l?oo
ool003Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo083ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo0?3ooooo000hooooo`;o00007?ooool00ol0003oooooooooo`0:ooooo`;o0000Q?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo06Sooooo0_l0003aooooo`00>?ooool00ol0003o
ooooooooo`0Looooo`;o00002?ooool2o`0008Oooooo0ol00008ooooo`03o`000?oooooooooo06Wo
oooo00?o0000ooooooooool0l?ooool003Sooooo00?o0000ooooooooool07_ooool3o`0000?ooooo
0_l0002<ooooo`;o00000_ooool4o`0006cooooo00?o0000ooooooooool0l?ooool003Sooooo0_l0
000Rooooo`?o0000T?ooool3o`0006oooooo0_l0003aooooo`00>?ooool00ol0003oooooooooo`3o
ooooobOooooo00?o0000ooooooooool0l?ooool003Sooooo00?o0000ooooooooool0oooooolWoooo
o`03o`000?oooooooooo0?3ooooo000hooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003o
ooooooooo`3`ooooo`00>?ooool2o`000?oooooo:?ooool2o`000?7ooooo000_ooooo`Co000000?o
410@ooooooooool00_ooool00ol0003oooooooooo`3ooooooakooooo1?l000000ol@413ooooooooo
o`02ooooo`03o`000?oooooooooo0?3ooooo000aooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooolPooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0l?ooool0
037ooooo00?o0000ooooooooool01?ooool2o`000?oooooo8Oooool00ol0003oooooooooo`04oooo
o`;o0000lOooool0037ooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo0?Oo
oooo000aooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`3gooooo`00<Ooo
ool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool0moooool0037ooooo00?o0000
ooooooooool0oooooolWooooo`03o`000?oooooooooo0?Oooooo000_ooooo`03oeEEEOmVIVKo0000
0?oooooo9oooool00omEEEGoIVIVo`00003iooooo`00oooooooooooooeKooooo003ooooooooooooo
E_ooool009Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05oiRH
V?l@413o0000oc8b<_o<c<`0ooooool6ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool05oooool2o`000003oa0@4?oooooooooo07;ooooo002Fooooo`05o`000?oooooooooooooo
ool000002Oooool6o`0000Wooooo00Go410@okZj^_ooooooMgMgoc8b<P3oooooo`Oooooo00Go0000
ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`1cooooo`00U_ooool0
1Ol0003ooooooooooooooooo000001cooooo00?o0000ooooooooool0ooooool5ooooo`05o`000?oo
ooooooooooooool000006?ooool5o`0007Cooooo002Fooooo`05o`000?ooooooooooooooool00000
2Oooool6o`0000cooooo00?oZJVYoa0@4?ooool0ooooool6ooooo`05o`000?ooooooooooooooool0
00002Oooool6o`0000Wooooo00CoA4A4omgMgOoooooo0000MOooool009Kooooo00Go0000ohN7Qooo
ooooZJVYo`00000Jooooo`03oa0@4?l0003o^[Zj0?oooooo1oooool01Ol0003oQhN7oooooonYZJWo
000001Sooooo00CogMgMoeEEEOoooooo0000MOooool009Gooooo00?o410@o`000?mgMgL00_l00000
0onHV9Soooooooooo`0Iooooo`03okZj^_lQ8B7ooooo0?oooooo1Oooool00ol@413o0000ogMgM`02
o`000003oiRHV?oooooooooo01Oooooo00?oMgMgolc<c?l00000MOooool00;?ooooo00Go410@oiRH
V?oooooo^[Zjo`00003oooooobGooooo00?ok^k^odA4A?l00000MOooool00;?ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@3oooooobKooooo00?oMgMgo`000?ooool0M?ooool00?oooooooooooomFoooo
o`00oooooooooooooeKooooo003oooooooooooooE_ooool00?oooooooooooomFooooo`00oooooooo
oooooeKooooo003oooooooooooooE_ooool00?oooooooooooomFooooo`00oooooooooooooeKooooo
003oooooooooooooE_ooool00?oooooooooooomFooooo`00oooooooooooooeKooooo003ooooooooo
ooooE_ooool00?oooooooooooomFooooo`00oooooooooooooeKooooo003oooooooooooooE_ooool0
0?oooooooooooomFooooo`00oooooooooooooeKooooo003oooooooooooooE_ooool00?oooooooooo
oomFooooo`00oooooooooooooeKooooo003oooooooooooooE_ooool00?oooooooooooomFooooo`00
;oooool4o`000003oa0@4?oooooooooo0?oooooo8oooool4o`000003oa0@4?oooooooooo0?Gooooo
000aooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`3gooooo`009_ooool6
o`0000Gooooo00?o0000ooooooooool0oooooolLooooo`Ko00001Oooool00ol0003oooooooooo`3g
ooooo`00<Oooool00ol0003oooooooooo`04ooooo`;o0000oooooolQooooo`03o`000?oooooooooo
00Cooooo0_l0003aooooo`00<Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo8?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?3ooooo000aooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooolPooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0l?ooool0037ooooo00?o0000ooooooooool01?ooool2o`000?oooooo8Ooo
ool00ol0003oooooooooo`04ooooo`;o0000X?ooool8o`0004Wooooo000_ooooo`03oeEEEOmVIVKo
000000Kooooo00?o0000ooooooooool0oooooolNooooo`03oeEEEOmVIVKo000000Kooooo00?o0000
ooooooooool0Voooool4o`0000Sooooo1?l00015ooooo`00>?ooool00ol0003oooooooooo`3ooooo
obOooooo00?o0000ooooooooool0V?ooool3o`00013ooooo0_l00013ooooo`00>?ooool00ol0003o
ooooooooo`3oooooobOooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo043ooooo000hooooo`;o0000oooooolXooooo`;o0000Uoooool00ol0003ooooo
ooooo`0Eooooo`;o0000@?ooool003Sooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oo
oooooooo09Cooooo0_l0000Jooooo`;o0000?_ooool003Sooooo00?o0000ooooooooool0oooooolW
ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0k
ooooo`00>?ooool2o`000?oooooo:?ooool2o`0009?ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0jooooo`00>?ooool00ol0003oooooooooo`3oooooobOooooo00?o0000oooooooo
ool0TOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03Wooooo000hooooo`03o`00
0?oooooooooo0?oooooo9oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0>?ooool003Sooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oo
oooooooo093ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0hooooo`00>?ooool2
o`000?oooooo:?ooool2o`00093ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0g
ooooo`005_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo1Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo08kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0fooooo`005_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`3oooooo`Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omE
EEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0SOooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo000>ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?cooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0S?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Gooooo000Fooooo`05o`000?oooooooooo
ooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0003o
ooooo`Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool00oooool2o`0008cooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0dooooo`005_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0ooooool5ooooo`05o`00
0?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0<oooool001Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo
00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Gooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`2:ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<oooool0
01Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`06ooooo`;o0000ooooool6ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool2o`0008[o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0booooo`005_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001Oooool00ol0003oooooooooo`3oooooo`Go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Gooooo00?o0000oooo
ooooool0R?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo037ooooo000hooooo`03
o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0<?ooool003Sooooo00?o0000ooooooooool0oooooolWooooo`03o`00
0?oooooooooo08Oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0`ooooo`00>?oo
ool2o`000?oooooo:?ooool2o`0008Oooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0_ooooo`00>?ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool0QOooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02kooooo000hooooo`03o`000?oooooooooo
0?oooooo9oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool0;Oooool003Sooooo0_l0003oooooobSooooo0_l00025ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0;Oooool003Sooooo00?o0000ooooooooool0oooooolWooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0/ooooo`00>?oo
ool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool0Poooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo02_ooooo000hooooo`03o`000?oooooooooo0?oooooo9oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0:oooool0
03Sooooo0_l0003oooooobSooooo0_l00023ooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0:_ooool001kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0ooooool=ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`00
0?oooooooooo087ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Yooooo`007_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0ooooool=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0:?ooool001Kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`02ooooo`;o0000ooooool6ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool2o`00087ooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`0Xooooo`007_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooo`gooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo02Oooooo000Nooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooo
ool=ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Co
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo02Ko
oooo000Nooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0?oooooo3Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool09_ooool001kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo0_l0003oooooo`kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo00Kooooo0_l0001nooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool09Oooool0
01kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3o
ooooo`gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooooooo
o`1mooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool09Oooool003Sooooo00?o0000
ooooooooool0oooooolWooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`0Tooooo`00>?ooool00ol0003oooooooooo`3oooooobOooooo00?o0000oooo
ooooool0Noooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02?ooooo000hooooo`;o
0000oooooolXooooo`;o0000O?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02?o
oooo000hooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool08_ooool003Sooooo00?o0000ooooooooool0oooo
oolWooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`0Rooooo`00>?ooool2o`000?oooooo:?ooool2o`0007[ooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`0Qooooo`00>?ooool00ol0003oooooooooo`3oooooobOooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo027ooooo000hooooo`03
o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool08?ooool003Sooooo00?o0000ooooooooool0oooooolWooooo`03o`00
0?oooooooooo07Oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Pooooo`00>?oo
ool2o`000?oooooo:?ooool2o`0007Sooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`0Oooooo`005_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0ooooool5ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool07_ooool001Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooo`Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`1eooooo`03o`00
0?oooooooooo05Oooooo00?o0000ooooooooool07_ooool000kooooo1_l00002ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo
0_l0003mooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`02ooooo`;o0000M_ooool00ol0003oooooooooo`1Hooooo`03
o`000?oooooooooo01gooooo000Fooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0ooooool5ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
01gooooo000Fooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooo`Gooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`0Looooo`005_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1Oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Looooo`00
5_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Kooooo0_l0003oooooo`Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`;o0000M?oo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01_ooooo000Fooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`03o`00
0?oooooooooo0?oooooo1Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
05gooooo00?o0000ooooooooool06oooool003Sooooo00?o0000ooooooooool07_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00005oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool05Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08?ooool4o`00
0003oa0@4?oooooooooo04Oooooo00?o0000ooooooooool07_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00005oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool04Oooool02Ol0003oooooooooooooooook^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<01cooooo
00Co0000oooooooooooooooo1?l000000ol@413oooooooooo`0Booooo`00>?ooool2o`0001oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
01Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0F
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@0Rooooo`03o`000?oooooooooo04Wooooo0_l0000Oooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Gooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@0Gooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@0Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?oo
ool003Sooooo00?o0000ooooooooool07_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h06?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Gooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001Sooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000008_ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo01kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^01Sooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00004_ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000001Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000
7Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo000hooooo`03o`000?oo
oooooooo01kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Oooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001Sooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Rooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h05oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00004_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q01Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S807_ooool01Ol0003ooooooooooooooooo000001Kooooo000hooooo`03o`000?oooooo
oooo01kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Kooooo00Go
0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0001Sooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`06?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00Rooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool05_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00004_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<01Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`07_ooool01Ol0003ooooooooooooooooo000001Kooooo000hooooo`;o00007oooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool05Oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000006?ooool01Ol@413ooooooooooooooooo410@00_ooooo
00?oEEEEohN7Qoooool06_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oo
oooo^[Zjoa0@400Rooooo`03o`000?oooooooooo04Wooooo0_l0000Oooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`0Eooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00omgMgOoc<c<o`00000Aooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo01Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41007oooool01?l0003oooooooooool0000Fooooo`00>?ooool00ol0
003oooooooooo`0Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@01Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000008_ooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo01kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41005oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l0
00004Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooM
gMgo410@oiRHV00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj
^[[o000001oooooo00Co0000oooooooooooo00005_ooool003Sooooo00?o0000ooooooooool07_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Gooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnYZJWo410@o`000?l@413oZJVY023ooooo00?oEEEEofIVI_l00000Boooool00ol0003o
ooooooooo`0Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<01Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00oooooo00?o
0000ooooooooool01Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o
410@5oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0P
ooooo`03o`000?mVIVKo000001Kooooo000hooooo`03o`000?oooooooooo0?oooooo9oooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool05_ooool003So
oooo0_l0003oooooobSooooo0_l0001^ooooo`03o`000?oooooooooo06Sooooo00?o0000oooooooo
ool05Oooool003Sooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Eooooo`00>?ooool00ol0003ooooooooo
o`3oooooobOooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo01Cooooo000booooonWo0000@?oooooYo`00013ooooo000hooooo`;o00002Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`;o0000Boooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool05?ooool003Sooooo00?o0000ooooool00000:Oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooo000004_ooooo0_l0000Zooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Dooooo`00>?ooool01?l0003ooooo
ooooool0003Fooooo`03o`000?oooooooooo04cooooo0_l0001[ooooo`03o`000?oooooooooo08?o
oooo000hooooo`;o00000_ooool00ol0003oooooooooo`3Booooo`03o`000?oooooooooo04gooooo
0ol0001Zooooo`03o`000?oooooooooo08?ooooo000hooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0d?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo000006Wooooo00?o
0000ooooooooool0Q?ooool003Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3>
ooooo`03o`000?oooooooooo04oooooo00Co0000oooooooooooo0000J?ooool00ol0003ooooooooo
o`24ooooo`00>?ooool2o`0000Gooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`1@
ooooo`;o000000?oooooo`000?ooool0I_ooool00ol0003oooooooooo`25ooooo`00>?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0DOooool01Ol0
003ooooooooooooooooo000006Kooooo00?o0000ooooooooool0QOooool003Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo08Kooooo000hooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`27ooooo`00
>?ooool2o`0000Wooooo00?o0000ooooooooool0a?ooool00ol0003oooooooooo`1Dooooo`;o0000
1?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo08Oooooo000hooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0`_ooool00ol0003oooooooooo`1Eooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`28ooooo`00>?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool0E_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0R?ooool0
03Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo
08Wooooo000hooooo`;o00003Oooool00ol0003oooooooooo`2looooo`03o`000?oooooooooo05So
oooo0_l00006ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0ROooool001Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`0gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo05_ooooo00?o0000ooooooooool0R_ooool001Kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool0
>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`2:ooooo`005_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`;o00004?ooool00ol0
003oooooooooo`2fooooo`03o`000?oooooooooo03Wooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool2o`0000Oooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`2;ooooo`005_ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0/oooool2o`0003cooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0Roooool001Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0/Oooool00ol0003ooooo
ooooo`0looooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool0S?ooool001Kooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo0:oooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`2<ooooo`005_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Kooooo0_l0000Dooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0?_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Kooooo0_l00009ooooo`03o`000?oooooooooo05Gooooo00?o0000oooooooo
ool0SOooool001Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2[oooo
o`03o`000?oooooooooo03oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Cooooo`03o`000?oooooooooo08kooooo000hooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0ZOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0Doooool00ol0003oooooooooo`2>ooooo`00>?ooool2o`0001Oooooo00?o0000oooo
ooooool0Yoooool00ol0003oooooooooo`1Sooooo`;o00002oooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo08oooooo000hooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0YOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0DOooool00ol0003oooooooooo`2?ooooo`00>?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo0:;ooooo0_l0001Wooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`2@ooooo`00>?ooool00ol0003oooooooooo`0Iooooo`;o0000XOoo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`2Aooooo`00>?ooool2o`0001cooooo00?o0000ooooooooool0WOooool0
0ol0003oooooooooo`1Xooooo`;o00003Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo097ooooo000hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Voooool00ol0
003oooooooooo`1Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`2Booooo`00>?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo09Wo
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool0T_ooool003Sooooo0_l0000Oooooo`03o`000?oooooooooo09Oooooo
00?o0000ooooooooool0Joooool2o`0000kooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`2Cooooo`00>?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo09Gooooo00?o
0000ooooooooool0K?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool0U?ooool001kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`2Cooooo`03o`000?oooooooooo05?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo09Cooooo000Nooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo093ooooo0_l0001Fooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool0UOooool001kooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo0_l0000Sooooo`;o0000Soooool00ol0003oooooooooo`1F
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00004?oo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo09Gooooo000Nooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0Roooool00ol0003oooooooooo`1Gooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`2Fooooo`007_ooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0ROooool00ol0003oooooooooo`1Hooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo09Oooooo000Nooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo0_l00028ooooo`03o`000?oooooo
oooo05Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo09Oooooo000N
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o0000:Ooo
ool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo05[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo00Kooooo0_l0000Cooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool0V?ooool001kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
1Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
Foooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`2Iooooo`00>?ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0M_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0VOooool003Sooooo0_l0
000/ooooo`;o0000O_ooool2o`0007Wooooo0_l0000Eooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool0V_ooool003Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo09[ooooo000hooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`2Kooooo`00>?ooool00ol0003oooooooooo`0_ooooo`;o
0000M_ooool2o`0007gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo09cooooo000hooooo`;o0000<_ooool00ol0003oooooooooo`1booooo`03o`00
0?oooooooooo07gooooo0_l0000Hooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
W?ooool003Sooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo07kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo09gooooo000hooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`2Nooooo`00>?ooool2o`0003Gooooo0_l0001/ooooo`;o0000P_ooool2o`00
01[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2Nooooo`005_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Ioooool2
o`0006;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Woooool001Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0=oooool2o`0006Kooooo00?o0000ooooooooool0H_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0X?ooool001Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo067o
oooo0_l0001Uooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo0:7ooooo000Fooooo`05o`000?ooooooooooooooool000003_ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000kooooo`03o`000?oooooooooo
05kooooo0_l0001Wooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000Nooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0X_ooool001Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo03_ooooo0_l0
001Mooooo`03o`000?oooooooooo06Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Sooooo`005_ooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0F?ooool2o`0006[ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Y?ooool001Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03kooooo0_l0001Gooooo`03o`000?oooooo
oooo06[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`2Uooooo`005_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00001Oooool2o`00047ooooo0_l0001Cooooo`;o0000KOooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001Oooool2o`00027ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`2Vooooo`00>?ooool00ol0003oooooooooo`12ooooo`;o0000
Coooool2o`00097ooooo00?o0000ooooooooool08Oooool2o`0002?ooooo00?o0000ooooooooool0
Yoooool003Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo097ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo0:Sooooo000hooooo`;o0000A_ooool2o`0004Wooooo0_l0002Dooooo`;o00009Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0:Wooooo000hooooo`03o`000?oooooooooo
04Oooooo0_l00014ooooo`?o0000U_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0Z_ooool003Sooooo00?o0000ooooooooool0BOooool2o`00043o
oooo0_l0002Iooooo`03o`000?oooooooooo02Kooooo0_l0000Iooooo`;o0000[Oooool003Sooooo
00?o0000ooooooooool0Boooool3o`0003[ooooo0ol0002Kooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool05?ooool2o`000:oooooo000hooooo`;o0000Coooool2o`0003Kooooo0_l0
002Nooooo`;o0000:_ooool2o`0001?ooooo00?o0000ooooooooool0[oooool003Sooooo00?o0000
ooooooooool0D?ooool3o`00037ooooo0_l0002Pooooo`03o`000?oooooooooo02_ooooo0_l0000?
ooooo`;o0000/_ooool003Sooooo00?o0000ooooooooool0Doooool3o`0002_ooooo0ol0002Roooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool02_ooool2o`000;Cooooo000hooooo`;o
0000Eoooool3o`0002Kooooo0_l0002Uooooo`;o0000;oooool<o`000;Kooooo000_ooooo`Co0000
00?o410@ooooooooool00_ooool00ol0003oooooooooo`1Iooooo`Co00007oooool3o`0009kooooo
1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?3ooooo000aooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0GOooool7o`0000oooooo2Ol0002Sooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0l?ooool0037ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Tooooo`oo0000[?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?3ooooo000aooooo`03o`000?oooooooooo00Cooooo0_l0003oooooob7ooooo00?o0000oooo
ooooool01?ooool2o`000?7ooooo000aooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003o
ooooooooo`3gooooo`00<Oooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool0
moooool0037ooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo0?Oooooo000_
ooooo`03oeEEEOmVIVKo00000?oooooo9oooool00omEEEGoIVIVo`00003iooooo`00oooooooooooo
oeKooooo003oooooooooooooE_ooool009Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413o
ooooooooo`0Fooooo`Co000000?o410@ooooooooool0ooooool3ooooo`04oa0@4?l0003o0000oooo
o`;o000000?o410@ooooooooool05Oooool5o`0007Cooooo002Fooooo`05o`000?oooooooooooooo
ool000002Oooool6o`0000cooooo00?o0000ooooooooool0ooooool6ooooo`05o`000?oooooooooo
ooooool000002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A01dooooo`00U_ooool0
1Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0ooooool6ooooo`05o`000?oo
ooooooooooooool000006Oooool00onHV9So8B4Qonk^kP1eooooo`00U_ooool01Ol0003ooooooooo
oooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo0?oooooo1_ooool01Ol0003ooooo
oooooooooooo000000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^07Cooooo002Fooooo`05o`00
0?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`3oooooo`Kooooo00Go0000ohN7Qooo
ooooZJVYo`00000Kooooo`03ogMgMomVIVKooooo07?ooooo002Eooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooooooool06Oooool00ol0003oooooooooo`3oooooo`Gooooo00?o410@o`000?mg
MgL00_l000000onHV9Soooooooooo`0Jooooo`03o`000?oooooooooo07;ooooo002fooooo`03o`00
0?oooooooooo0?oooooo8oooool01Ol0003o^[ZjoooooonHV9So410@07Cooooo002dooooo`03oeEE
EOmVIVKo00000?oooooo9Oooool01OnHV9So410@o`000?lQ8B7oc<c<07Cooooo003ooooooooooooo
E_ooool00?oooooooooooomFooooo`00oooooooooooooeKooooo003oooooooooooooE_ooool00?oo
oooooooooomFooooo`00oooooooooooooeKooooo003oooooooooooooE_ooool00?oooooooooooomF
ooooo`00oooooooooooooeKooooo003oooooooooooooE_ooool00?oooooooooooomFooooo`00oooo
oooooooooeKooooo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .37678 L
.08255 .40876 L
.10458 .43923 L
.12507 .46206 L
.14415 .4777 L
.14918 .48085 L
.15465 .48378 L
.15946 .48594 L
.16457 .48779 L
.16917 .48906 L
.17178 .48962 L
.17423 .49004 L
.17538 .4902 L
.17647 .49033 L
.17746 .49042 L
.17852 .49051 L
.17967 .49058 L
.18073 .49062 L
.182 .49065 L
.18314 .49065 L
.18435 .49062 L
.18547 .49058 L
.1867 .4905 L
.18802 .49039 L
.19071 .49006 L
.19317 .48965 L
.1979 .48856 L
.20239 .48716 L
.21236 .4828 L
.22321 .47614 L
.24299 .45911 L
.26399 .43477 L
.30174 .37827 L
.34195 .3078 L
.38063 .24004 L
.40028 .20887 L
.42177 .17914 L
.44253 .15597 L
.4614 .14047 L
.47149 .13456 L
.47611 .13243 L
.48101 .13058 L
.4835 .1298 L
.48624 .12906 L
.48876 .1285 L
.49106 .12809 L
.49378 .12773 L
.49527 .12758 L
.49596 .12753 L
Mistroke
.49669 .12748 L
.498 .12742 L
.49921 .12739 L
.49996 .12738 L
.50065 .12739 L
.50196 .12742 L
.50313 .12747 L
.50438 .12755 L
.50556 .12766 L
.50663 .12777 L
.50926 .12814 L
.51175 .12861 L
.5167 .12986 L
.52208 .1317 L
.53169 .13624 L
.54056 .14182 L
.55926 .15773 L
.57988 .18124 L
.62014 .24132 L
.65888 .30928 L
.70007 .38127 L
.72063 .41346 L
.73974 .43953 L
.75939 .46147 L
.77791 .47691 L
.78775 .48286 L
.79293 .48533 L
.7984 .48743 L
.80302 .4888 L
.80546 .48937 L
.80809 .48987 L
.8105 .49022 L
.8127 .49045 L
.81375 .49053 L
.81491 .49059 L
.81599 .49063 L
.817 .49065 L
.81818 .49065 L
.81941 .49062 L
.82047 .49057 L
.82163 .4905 L
.82287 .49039 L
.82421 .49025 L
.82661 .48991 L
.82905 .48946 L
.83134 .48894 L
.83564 .48772 L
.84078 .48584 L
.84552 .48369 L
.85624 .47744 L
Mistroke
.87498 .46202 L
.89561 .43899 L
.93591 .37951 L
.97471 .31168 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35562 L
.08255 .37584 L
.0932 .38473 L
.10458 .39259 L
.11009 .39572 L
.11531 .39827 L
.12038 .40034 L
.12507 .40189 L
.12951 .40303 L
.13178 .40349 L
.13422 .40389 L
.13549 .40406 L
.13666 .40419 L
.13784 .4043 L
.13895 .40438 L
.14022 .40445 L
.1409 .40448 L
.14161 .4045 L
.1423 .40451 L
.14295 .40451 L
.14415 .40449 L
.14531 .40446 L
.14656 .40439 L
.14773 .40431 L
.14881 .40421 L
.15143 .4039 L
.15392 .40349 L
.15886 .40239 L
.16423 .40074 L
.17383 .39665 L
.1827 .39161 L
.20137 .37744 L
.22197 .35704 L
.26217 .30868 L
.30086 .26207 L
.32051 .24232 L
.3309 .23361 L
.342 .22586 L
.35275 .22006 L
.35784 .21793 L
.36253 .21633 L
.36724 .21508 L
.36972 .21457 L
.37235 .21414 L
.37463 .21386 L
.37573 .21375 L
.37677 .21367 L
.37799 .2136 L
.37911 .21355 L
Mistroke
.38031 .21353 L
.38162 .21353 L
.38227 .21354 L
.38296 .21356 L
.38419 .21361 L
.38551 .2137 L
.38695 .21382 L
.38955 .21414 L
.39197 .21453 L
.39649 .21553 L
.40134 .21696 L
.40698 .2191 L
.41232 .22159 L
.42232 .2274 L
.44227 .24311 L
.4607 .26169 L
.50002 .30904 L
.53782 .35472 L
.55884 .37593 L
.56803 .38368 L
.57808 .39089 L
.58722 .39621 L
.59696 .40048 L
.60236 .4022 L
.60726 .40336 L
.60962 .40377 L
.61086 .40395 L
.61218 .40412 L
.61333 .40424 L
.61459 .40434 L
.61574 .40442 L
.61682 .40447 L
.61808 .4045 L
.61871 .40451 L
.61941 .40451 L
.62065 .40449 L
.62181 .40444 L
.62248 .40441 L
.62318 .40437 L
.62443 .40427 L
.62578 .40413 L
.62725 .40395 L
.62973 .40356 L
.63238 .40304 L
.63715 .4018 L
.64214 .40011 L
.64686 .39815 L
.6557 .39356 L
.67568 .37906 L
.69413 .36136 L
Mistroke
.7335 .3148 L
.77136 .26844 L
.79241 .24629 L
.81166 .23021 L
.82118 .22408 L
.8262 .22137 L
.83155 .21892 L
.8367 .21698 L
.84136 .21559 L
.84361 .21504 L
.84604 .21455 L
.84835 .21417 L
.85045 .2139 L
.85159 .21378 L
.85283 .21368 L
.85414 .2136 L
.85538 .21355 L
.85653 .21353 L
.85776 .21353 L
.85881 .21355 L
.85997 .21359 L
.86063 .21363 L
.86132 .21367 L
.86256 .21377 L
.86535 .21409 L
.86777 .21446 L
.87041 .21498 L
.87569 .21637 L
.88133 .21835 L
.89148 .22316 L
.90173 .22958 L
.91284 .23817 L
.933 .25749 L
.97393 .30617 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34637 L
.10458 .3864 L
.14415 .42264 L
.18221 .45568 L
.22272 .48831 L
.26171 .5167 L
.30316 .5431 L
.34309 .56441 L
.3815 .58074 L
.40095 .58736 L
.42237 .59333 L
.44268 .59767 L
.45178 .5992 L
.46172 .60057 L
.4671 .60118 L
.4721 .60167 L
.47727 .60208 L
.48196 .60239 L
.48658 .60262 L
.4887 .60271 L
.49093 .60278 L
.49332 .60284 L
.49438 .60286 L
.49552 .60288 L
.49675 .60289 L
.49789 .6029 L
.49859 .60291 L
.49925 .60291 L
.50049 .60291 L
.50163 .60291 L
.50286 .6029 L
.50401 .60288 L
.50508 .60287 L
.50754 .60282 L
.51014 .60275 L
.51268 .60265 L
.51504 .60255 L
.5204 .60224 L
.5293 .60154 L
.53882 .6005 L
.54906 .59907 L
.56016 .59714 L
.58032 .59266 L
.62123 .57972 L
.66064 .56261 L
.69852 .54211 L
.73886 .5163 L
.77769 .488 L
.81897 .4547 L
Mistroke
.85873 .42007 L
.89697 .38495 L
.93767 .34626 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .37205 L
.10458 .43602 L
.14415 .4873 L
.18221 .52525 L
.20178 .53961 L
.21267 .54594 L
.22272 .55071 L
.23293 .55446 L
.23832 .556 L
.24402 .55728 L
.24641 .55771 L
.24897 .55811 L
.25119 .55839 L
.25361 .55864 L
.25507 .55876 L
.25643 .55885 L
.25773 .55892 L
.2584 .55895 L
.25912 .55897 L
.25983 .55899 L
.26048 .55901 L
.26176 .55902 L
.26293 .55901 L
.26416 .55899 L
.26538 .55895 L
.26607 .55892 L
.26671 .55889 L
.26912 .55873 L
.27131 .55854 L
.27364 .55827 L
.27847 .55753 L
.2838 .55641 L
.29326 .55369 L
.30213 .55026 L
.32232 .53942 L
.34082 .52589 L
.38045 .48638 L
.41855 .43698 L
.45912 .37564 L
.49816 .31205 L
.53966 .24435 L
.57964 .18362 L
.61811 .13334 L
.63759 .11199 L
.65902 .09227 L
.67938 .07754 L
.69843 .06753 L
.70884 .06366 L
.71396 .06218 L
Mistroke
.71872 .06106 L
.72301 .06025 L
.72758 .05962 L
.7302 .05936 L
.73148 .05926 L
.73266 .05918 L
.73371 .05912 L
.73487 .05907 L
.73603 .05904 L
.73725 .05902 L
.73856 .05902 L
.73977 .05903 L
.7404 .05905 L
.7411 .05907 L
.74251 .05912 L
.74375 .05919 L
.74508 .05928 L
.74748 .0595 L
.74985 .05977 L
.75235 .06012 L
.7568 .06092 L
.76198 .06212 L
.7668 .06349 L
.77773 .06751 L
.78828 .07259 L
.79823 .07843 L
.81683 .09199 L
.85534 .13016 L
.89632 .18329 L
.93577 .24314 L
.97371 .30493 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L2000`400?l00000o`00003ooooooooo
oooooeKooooo003oooooooooooooE_ooool00?oooooooooooomFooooo`00oooooooooooooeKooooo
003oooooooooooooE_ooool00?oooooooooooomFooooo`00oooooooooooooeKooooo003ooooooooo
ooooE_ooool00?oooooooooooomFooooo`00oooooooooooooeKooooo003oooooooooooooE_ooool0
0?oooooooooooomFooooo`00;oooool4o`000003oa0@4?oooooooooo0?oooooo8oooool4o`000003
oa0@4?oooooooooo0?Gooooo000aooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003ooooo
ooooo`3gooooo`009_ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2o`000?oooooo5_oo
ool6o`0000Gooooo00?o0000ooooooooool01?ooool2o`000?7ooooo000aooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooolPooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0l?ooool0037ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
ob3ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3`ooooo`00<Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo8?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?3ooooo000aooooo`03o`000?oooooooooo00Cooooo0_l0003oooooob7ooooo
00?o0000ooooooooool01?ooool2o`000?7ooooo000_ooooo`03oeEEEOmVIVKo000000Kooooo00?o
0000ooooooooool0oooooolNooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0l?oo
ool003Sooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo0?3ooooo000hoooo
o`;o0000oooooolXooooo`;o0000lOooool003Sooooo00?o0000ooooooooool0oooooolWooooo`03
o`000?oooooooooo0?3ooooo000hooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003ooooo
ooooo`3`ooooo`00>?ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool0l?oo
ool003Sooooo0_l0003oooooobSooooo0_l0003aooooo`00>?ooool00ol0003oooooooooo`3ooooo
obOooooo00?o0000ooooooooool0l?ooool003Sooooo00?o0000ooooooooool0oooooolWooooo`03
o`000?oooooooooo0?3ooooo000hooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003ooooo
ooooo`3`ooooo`00>?ooool2o`000?oooooo:?ooool2o`000?7ooooo000Fooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Cooooo00?o0000ooooooooool0ooooool5ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Cooooo00?o0000ooooooooool0l?ooool001Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0ooooool5ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?3ooooo000>oooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`02ooooo`;o0000oOooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool2o`000?7ooooo000F
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00?ooooo00?o0000ooooooooool0ooooool5ooooo`05o`000?ooooooooooooooool00000
3_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
l?ooool001Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo1Oooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Cooooo00?o0000ooooooooool0l?ooool001Kooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3o
ooooo`Gooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3`ooooo`005_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Kooooo
0_l0003oooooo`Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`06ooooo`;o0000lOooool001Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Gooooo00?o0000ooooooooool0ooooool5oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00005ooooo`03o`000?oooooo
oooo0?3ooooo000hooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`3`oooo
o`00>?ooool2o`000?oooooo:?ooool2o`000?7ooooo000hooooo`03o`000?oooooooooo0?oooooo
9oooool00ol0003oooooooooo`3`ooooo`00>?ooool00ol0003oooooooooo`3oooooobOooooo00?o
0000ooooooooool0l?ooool003Sooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooo
oooo0?3ooooo000hooooo`;o0000oooooolXooooo`;o0000lOooool003Sooooo00?o0000oooooooo
ool0Ioooool9o`000;Kooooo00?o0000ooooooooool0l?ooool003Sooooo00?o0000ooooooooool0
I?ooool3o`0000Wooooo0ol0002cooooo`03o`000?oooooooooo0?3ooooo000hooooo`;o0000I?oo
ool00ol0003oooooooooo`0=ooooo`;o0000/Oooool2o`000?7ooooo000Nooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`00
0?oooooooooo067ooooo0_l0000Booooo`03o`000?oooooooooo09Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000oooo
ooooool0l?ooool001kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`2Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3`ooooo`005_ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08[ooooo1_l00002ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?3ooooo000N
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`;o0000Gooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo097ooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0003aooooo`007_ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2@ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0l?ooool0
01kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo08oooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0l?oo
ool001kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo08kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
l?ooool001kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool2o`0005cooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`2=ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000Gooooo0_l0003aooooo`00>?ooool00ol0003oooooooooo`1Jooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`3`ooooo`00>?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0YOoo
ool00ol0003oooooooooo`3`ooooo`00>?ooool2o`0005[ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`2Uooooo`;o0000lOooool003Sooooo00?o0000ooooooooool0F?ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool0l?ooool003So
oooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0:?o
oooo00?o0000ooooooooool0l?ooool003Sooooo00?o0000ooooooooool0E_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0l?ooool003Sooooo0_l0
001Gooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0X_ooool2o`000?7ooooo000h
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Q
ooooo`03o`000?oooooooooo0?3ooooo000hooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo0?3ooooo000hooooo`;o
0000EOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0:3ooooo0_l0001<ooooo`_o
0000Hoooool;o`0002cooooo000Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0O_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool0BOooool2o`0000_ooooo00?o0000ooooooooool0G_ooool2o`0000_ooooo0_l0
000Zooooo`005_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1mooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0<ooooo`;o0000G?ooool2o`00
00oooooo0_l0000Xooooo`003_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0M?ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`16ooooo`;o00004Oooool2o`0005Wooooo00?o0000ooooooooool04Oooool2
o`0002Kooooo000Fooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0001Booooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0O?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`03ooooo`;o0000AOooool2o`0001Gooooo00?o0000ooooooooool0E?oo
ool2o`0001Kooooo00?o0000ooooooooool08oooool001Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1kooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02;ooooo000Fooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
07[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02;ooooo000Foooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01_ooool2o`00057ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`1jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01_ooool2o`0004;ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08Oooool001Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
07Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Pooooo`00>?ooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Voooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo000hooooo`03o`000?oooooooooo
01kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0001Oooooo00Gok^k^
oc8b<_l0003o<S8bo`000005ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo01Gooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l0003oc<c<01So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<023ooooo1?l000000ol@413oooooooooo`17ooooo`03o`000?oooooooooo01kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000_ooooo00?o0000ooooooooool02Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000Co410@oooooooooooo
00005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`05oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ob4Q8Oooool00ooo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<01Sooooo00?o0000ooooooooool01Oooool4o`000003oa0@
4?oooooooooo01;ooooo000hooooo`;o00007oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@05oooool01OmgMgOoV9RHooooool0003oMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So000001Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q02;ooooo00?o0000oooooooo
ool0BOooool2o`0001oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400[ooooo00?o0000ooooooooool02_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B405oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ob4Q8OlQ8B401?ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q01Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0D
ooooo`00>?ooool00ol0003oooooooooo`0Nooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP0Hooooo`05oa0@4?ooooooooooo`000?l@41002oooool5o`0001Oooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006?ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool07_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02oooool00ol0003oooooooooo`0:ooooo`05oa0@4?ooooooooooooooool@4100
2oooool5o`0000?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`00000Gooooo`05oa0@4?ooooooooooooooool@41000oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Cooooo000hooooo`03o`000?oooooooooo01kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Oooooo00Go0000ooooool0003ooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0001Sooooo00Go0000ooooooooooooooooo`00000;oooo
o`06o`000?nHV9SooooooiRHV?lQ8B7o00005oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P0Rooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool07_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0
0005ooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?nHV9SooooooiRHV?lQ8B405oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool01Olb<S;oV9RHoooooonHV9So<S8b01[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Dooooo`00>?ooool00ol0003oooooooooo`0Nooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`0Fooooo`05o`000?oooooo0000ooooool000002ooo
ool01?oMgMgoEEEEooooool0000Hooooo`05o`000?ooooooooooooooool000002oooool01_l0003o
EEEEo`000?l@413oc<c<o`0001Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0
003o0000o`000?o<c<`08_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Oooooo00?o0000oooooooo
ool03?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool0
0ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<01Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Ko
oooo00Goc<c<o`000?l0003o0000olc<c00Kooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool05?ooool003Sooooo0_l0000Oooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`0Eooooo`05oa0@4?l0003oooooooooool@41003?ooool00omgMgOoc<c<o`00000H
ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`03ooooo`03o`000?oo
oooooooo01Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
41008_ooool00ol0003oooooooooo`19ooooo`;o00007oooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00kooooo00Go410@
oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo01Wooooo00Oo410@oooooooooooooooo
oa0@4?oooooo000000Wooooo00Go410@okZj^_oooooo^[Zjoa0@400Looooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05?ooool003Sooooo00?o0000ooooooooool07_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Gooooo`05ogMgMol0003o
oooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ooMgMgo410@oiRHV003ooooo`03o`000?oooooooooo01Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000008_ooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo01kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00oo^k^koA4A4o`000008ooooo`03o`000?oooooooooo00gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01Wooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0000:
ooooo`05o`000?nj^[[ooooookZj^_l000007Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Cooooo000hooooo`03o`000?oooooooooo01kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`05oooool01Ol0003o<S8bo`000?lb<S;ok^k^00go
oooo00?oMgMgo`000?ooool05oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4
A?l0003o410@0_ooool00ol0003oooooooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY023ooooo00?oEEEEofIVI_l00000Boooool00ol0003ooooo
ooooo`0Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Gooooo00?o0000ooooooooool03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool02?ooool00ol0003oooooooooo`0<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool01?o<c<coA4A4o`000?l@410Gooooo`05onk^k_lb<S;o0000oc8b<_l000002oooool01OnYZJWo
410@o`000?l@413oZJVY01kooooo00Go0000oooooomEEEGoIVIVo`00000Fooooo`00>?ooool2o`00
04_ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2Fooooo`;o0000>Oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Gooooo`00>?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Ko
oooo000hooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`2Dooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05Oooool003Sooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo09Cooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Dooooo`00<_oooooYo`00043ooooojOl0000@
ooooo`00>?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool2o`0004_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo0_l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?oo
ool003Sooooo0_l00017ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`1;ooooo`;o0000=?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0C?ooool003Sooooo0_l00016ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1;ooooo`?o0000<_ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0COooool003So
oooo00?o0000ooooool00000AOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0C?ooool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1>ooooo`00>?ooool01?l0003o
ooooooooool00013ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`1=ooooo`05o`000?ooooooooooooooool00000;_ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Coooool003Sooooo00Co0000oooo
oooooooo0000@oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo053ooooo000hoooo
o`;o00000_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`1>ooooo`;o00000oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Aoooo
o`00>?ooool01Ol0003ooooooooooooooooo0000043ooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`1Aooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Booooo`00>?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1Cooooo`00>?ooool2o`0000Cooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`1Cooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0D?ooool2o`0000Oooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0E?ooool003Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0EOooool003Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Gooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0E_ooool003Sooooo0_l00006ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0E_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo05;ooooo0_l0000:ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo05Oooooo000Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo033ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo00[ooooo0_l0
000Kooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1Hooooo`005_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0<Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool05_ooool2o`0005?ooooo00?o0000ooooooooool05_ooool2o`00
05_ooooo000Fooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0aoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool04oooool2o`0005gooooo000Fooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00008
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo03;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool2o`0000oooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0GOoo
ool001Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
<oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool03oooool2o`00013ooooo0_l0001Joooo
o`;o00003oooool2o`00063ooooo000Fooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0cooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool2o`0000cooooo0_l0001N
ooooo`?o00002oooool00ol0003oooooooooo`1Pooooo`005_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo0_l0
000:ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo03Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`;o00005?ooool2o`0000Oo
oooo0ol0001Sooooo`;o00001oooool2o`0006?ooooo000Fooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0=Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001Oooool00ol0003oooooooooo`0Eooooo`Oo0000J?oo
ool7o`0006Gooooo000hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Eoooool0
0ol0003oooooooooo`3`ooooo`00>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
05Sooooo00?o0000ooooooooool0l?ooool003Sooooo0_l0000=ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo05So
oooo0_l0003aooooo`00>?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool0l?ooool003Sooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo0?3ooooo000hooooo`;o00003oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1J
ooooo`;o0000lOooool003Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo0?3ooooo000hooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0G?ooool00ol0003oooooooooo`3`ooooo`00>?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo05gooooo00?o0000ooooooooool0l?ooool003Sooooo0_l0000Booooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo05kooooo0_l0003aooooo`007_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0l?ooool001kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0l?ooool001kooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool2
o`0001Wooooo0_l0001fooooo`;o00006Oooool00ol0003oooooooooo`17ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?3ooooo000N
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`;o00005ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`18ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`;o0000lOooool001kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Wo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`3`ooooo`007_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0O?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04[ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0l?oo
ool001kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo0_l0
000Jooooo`03o`000?oooooooooo00kooooo0_l00020ooooo`;o00003oooool2o`0004gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo0_l0003aooooo`007_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo
0_l0000<ooooo`;o0000Q?ooool00ol0003oooooooooo`0:ooooo`;o0000Coooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?3ooooo000hooooo`03o`00
0?oooooooooo01cooooo0ol00006ooooo`?o0000Qoooool4o`0000Gooooo0ol0001[ooooo`03o`00
0?oooooooooo0?3ooooo000hooooo`03o`000?oooooooooo01oooooo1_l0002=ooooo`Oo0000KOoo
ool00ol0003oooooooooo`3`ooooo`00>?ooool2o`000?oooooo:?ooool2o`000?7ooooo000hoooo
o`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`3`ooooo`00>?ooool00ol0003o
ooooooooo`3oooooobOooooo00?o0000ooooooooool0l?ooool003Sooooo0_l0003oooooobSooooo
0_l0003aooooo`00>?ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool0l?oo
ool003Sooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo0?3ooooo000hoooo
o`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`3`ooooo`00>?ooool2o`000?oo
oooo:?ooool2o`000?7ooooo000Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000oooo
ooooool0ooooool5ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0l?oo
ool001Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0ooooool5ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo0?3ooooo000Fooooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
ooooool5ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0l?ooool001Kooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool00oooool2o`000?oo
oooo1_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`03ooooo`;o0000lOooool001Kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooo
oooo0?oooooo1Oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0l?ooool001Kooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`3oooooo`Gooooo00Go410@oooooooooooooooooa0@400>ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3`ooooo`00
5_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04oooo
o`03o`000?oooooooooo00Kooooo0_l0003oooooo`Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`06ooooo`;o0000lOoo
ool001Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Gooooo00?o
0000ooooooooool0ooooool5ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00005ooooo`03o`000?oooooooooo0?3ooooo000hooooo`03o`000?oooooooooo0?oooooo9ooo
ool00ol0003oooooooooo`3`ooooo`00>?ooool00ol0003oooooooooo`3oooooobOooooo00?o0000
ooooooooool0l?ooool003Sooooo0_l0003oooooobSooooo0_l0003aooooo`00>?ooool00ol0003o
ooooooooo`3oooooobOooooo00?o0000ooooooooool0l?ooool003Sooooo00?o0000ooooooooool0
oooooolWooooo`03o`000?oooooooooo0?3ooooo000hooooo`;o0000oooooolXooooo`;o0000lOoo
ool003Sooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo0?3ooooo000hoooo
o`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`3`ooooo`00>?ooool00ol0003o
ooooooooo`3oooooobOooooo00?o0000ooooooooool0l?ooool003Sooooo0_l0003oooooobSooooo
0_l0003aooooo`00;oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooo
oolNooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3`ooooo`00<Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo8?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?3ooooo000aooooo`03o`000?oooooooooo00Cooooo0_l0003ooooo
ob7ooooo00?o0000ooooooooool01?ooool2o`000?7ooooo000aooooo`03o`000?oooooooooo0?oo
oooo9oooool00ol0003oooooooooo`3gooooo`00<Oooool00ol0003oooooooooo`3oooooobOooooo
00?o0000ooooooooool0moooool0037ooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oo
oooooooo0?Oooooo000aooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`3g
ooooo`00;oooool00omEEEGoIVIVo`00003oooooobOooooo00?oEEEEofIVI_l00000nOooool00?oo
oooooooooomFooooo`00oooooooooooooeKooooo002Eooooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool05Oooool01OnHV9So410@o`000?lb<S;oc<c<0?oooooo1_ooool01?l@413o
0000o`000?ooool2o`000003oa0@4?oooooooooo01Oooooo0_l000000ol@413oooooooooo`1boooo
o`00U_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80ooooool7ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o
0000ooooooooool0Loooool009Kooooo00Go0000ooooooooooooooooo`00000Looooo`03o`000?oo
oooooooo0?oooooo1Oooool01Ol0003ooooooooooooooooo000001Sooooo1Ol0001dooooo`00U_oo
ool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03ojVYZOl@413ooooo0?oooooo
1_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`04odA4A?oMgMgoooooo`00
07Gooooo002Fooooo`05o`000?n7QhOoooooojVYZOl000006_ooool00ol@413o0000okZj^P3ooooo
o`Oooooo00Go0000ohN7QoooooooZJVYo`00000Hooooo`04omgMgOmEEEGoooooo`0007Gooooo002E
ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00onj^[[o8B4Qooooo`3o
ooooo`Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Gooooo`03ogMgMoo<c<co
000007Gooooo002cooooo`05oa0@4?nHV9SooooookZj^_l00000oooooolUooooo`03onk^k_m4A4Co
000007Gooooo002cooooo`05ojVYZOl@413o0000oa0@4?nYZJT0oooooolVooooo`03ogMgMol0003o
oooo07Cooooo003oooooooooooooE_ooool00?oooooooooooomFooooo`00oooooooooooooeKooooo
003oooooooooooooE_ooool00?oooooooooooomFooooo`00oooooooooooooeKooooo003ooooooooo
ooooE_ooool00?oooooooooooomFooooo`00oooooooooooooeKooooo003oooooooooooooE_ooool0
0?oooooooooooomFooooo`00oooooooooooooeKooooo003oooooooooooooE_ooool00?oooooooooo
oomFooooo`00oooooooooooooeKooooo003oooooooooooooE_ooool00?oooooooooooomFooooo`00
oooooooooooooeKooooo003oooooooooooooE_ooool00?oooooooooooomFooooo`00oooooooooooo
oeKooooo003oooooooooooooE_ooool002oooooo1?l000000ol@413oooooooooo`3oooooob?ooooo
1?l000000ol@413oooooooooo`3eooooo`00<Oooool00ol0003oooooooooo`3oooooobOooooo00?o
0000ooooooooool0moooool002Kooooo1_l00005ooooo`03o`000?oooooooooo0?oooooo7?ooool6
o`0000Gooooo00?o0000ooooooooool0moooool0037ooooo00?o0000ooooooooool01?ooool2o`00
0?oooooo8Oooool00ol0003oooooooooo`04ooooo`;o0000lOooool0037ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooob3ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3`ooooo`00<Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
8?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?3ooooo000aooooo`03o`000?oo
oooooooo00Cooooo0_l0003oooooob7ooooo00?o0000ooooooooool01?ooool2o`000?7ooooo000_
ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooolNooooo`03oeEEEOmVIVKo
000000Kooooo00?o0000ooooooooool0l?ooool003Sooooo00?o0000ooooooooool0oooooolWoooo
o`03o`000?oooooooooo0?3ooooo000hooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003o
ooooooooo`3`ooooo`00>?ooool2o`000?oooooo:?ooool2o`000?7ooooo000hooooo`03o`000?oo
oooooooo0?oooooo9oooool00ol0003oooooooooo`3`ooooo`00>?ooool00ol0003oooooooooo`3o
ooooobOooooo00?o0000ooooooooool0l?ooool003Sooooo0_l0003oooooobSooooo0_l0003aoooo
o`00>?ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool0l?ooool003Sooooo
00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo0?3ooooo000hooooo`03o`000?oo
oooooooo0?oooooo9oooool00ol0003oooooooooo`2Pooooo`Ko0000B_ooool003Sooooo0_l0003o
ooooobSooooo0_l0002Looooo`Go00001_ooool5o`0004Gooooo000Fooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Cooooo00?o0000ooooooooool0ooooool5ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool0V?ooool3o`00013ooooo0ol00012ooooo`005_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`3oooooo`Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0Uoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03oooooo000>ooooo`Ko
00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0U_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03kooooo000Foooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00?ooooo0_l0003oooooo`Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool00oooool2o`0009Gooooo0_l0000Jooooo`;o0000?_oo
ool001Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo1Oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00?o0000ooooooooool0T_ooool2o`0001kooooo0_l0000looooo`005_ooool01Ol@413o
oooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo1Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo097ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0iooooo`005_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Kooooo0_l0
003oooooo`Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`06ooooo`;o0000TOooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo03Sooooo000Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00005ooooo`03o`000?oooooooooo0?oooooo1Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo1Ol00004ooooo`Co00001Oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0>?ooool003Sooooo00?o0000ooooooooool0oooooolWooooo`03
o`000?oooooooooo08kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0gooooo`00
>?ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool0SOooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo03Kooooo000hooooo`;o0000oooooolXooooo`;o0000SOoo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Gooooo000hooooo`03o`000?oooooo
oooo0?oooooo9oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0=?ooool003Sooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo
08_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0cooooo`00>?ooool2o`000?oo
oooo:?ooool2o`0008_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0booooo`00
>?ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool0ROooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo037ooooo000hooooo`03o`000?oooooooooo0?oooooo9ooo
ool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<?oo
ool003Sooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo08Oooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0`ooooo`00>?ooool2o`000?oooooo:?ooool2o`00
08Sooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0_ooooo`007_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool0
0ol0003oooooooooo`3oooooo`gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0Q_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo02kooooo000Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooo`gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo08Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0]ooooo`00
5_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;o
oooo0_l0003oooooo`Kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`02ooooo`;o0000QOooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
02cooooo000Nooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo0?oooooo3Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool0:oooool001kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooo`gooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0:oooool001kooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool=ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Zooooo`007_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool2o`000?oooooo3_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool2o`0008;ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0Yooooo`007_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?oooooo3Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`0Xooooo`00>?ooool00ol0003oooooooooo`3oooooobOooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo02Oooooo000hoooo
o`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool09_ooool003Sooooo0_l0003oooooobSooooo0_l0001oooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool09_ooool003Sooooo00?o0000ooooooooool0
oooooolWooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0Uooooo`00>?ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool0O?oo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02Cooooo000hooooo`;o0000oooooolX
ooooo`;o0000O?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02Cooooo000hoooo
o`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool08oooool003Sooooo00?o0000ooooooooool0oooooolWooooo`03
o`000?oooooooooo07[ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Rooooo`00
>?ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool0NOooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo02;ooooo000hooooo`;o0000oooooolXooooo`;o0000N_oo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo027ooooo000Fooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1?ooool00ol0003oooooooooo`3oooooo`Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo
07Sooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Qooooo`005_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo1Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`0Pooooo`003_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool2o`000?gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;o
oooo0_l0001gooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool07oooool001Kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`3oooooo`Gooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo05Gooooo00?o0000ooooooooool07oooool001Kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004
ooooo`03o`000?oooooooooo0?oooooo1Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0
MOooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01kooooo000Fooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0ooooool5ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0M?ooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo01gooooo000Fooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool2o`00
0?oooooo1_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Kooooo0_l0001eooooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool07Oooool001Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo00?o0000ooooooooool0ooooool5ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005oooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Loooo
o`00>?ooool00ol0003oooooooooo`0Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol0000Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`0Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o410@olc<c00Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Pooooo`Co000000?o410@ooooooooool0Aoooool00ol0
003oooooooooo`0Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000G
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Booooo`08o`000?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<01Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<01_ooooo00?o0000ooooooooool00_ooool4o`000003oa0@
4?oooooooooo01;ooooo000hooooo`;o00007oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@05oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q02;ooooo00?o0000oooooooo
ool0BOooool2o`0001oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A401Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Booooo`09o`000?oooooooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B405oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B406oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01Cooooo000hooooo`03o`000?oooooooooo01kooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01Sooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00005oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`00000Hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002;ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Nooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Hooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0001;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`00000Gooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000001cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Dooooo`00>?ooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP0Gooooo`05o`000?ooooooooooooooool000002oooool01?m4
A4CogMgMooooool0000Hooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S808_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01kooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Oooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0001?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Gooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b01gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Dooooo`00>?ooool00ol0003oooooooooo`0Nooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`0Fooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0000Hooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oEEEEo`000?l@413oc<c<01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0
003o0000o`000?o<c<`08_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Kooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0001;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Gooooo`05o`00
0?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<01gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Dooooo`00>?ooool2o`0001oooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo01Gooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000001Sooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo01[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
41008_ooool00ol0003oooooooooo`19ooooo`;o00007oooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool05Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000004_ooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00omEEEGoQhN7ooooo`0Iooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zj
oooooonj^[[o410@01kooooo00Go0000ooooooooooooooooo`00000Fooooo`00>?ooool00ol0003o
ooooooooo`0Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@01Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000008_ooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo01kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41005oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
4Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000001kooooo00Go0000ooooooooooooooooo`00000Fooooo`00>?ooool00ol0003oooooooooo`0N
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<01Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo01Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT08?ooool00omEEEGoIVIVo`00001;ooooo`03o`00
0?oooooooooo01kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`05oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool04?ooool0
0ol0003oooooooooo`04ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`00
0?l@410Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY
01oooooo00Co0000oeEEEOmVIVKo00005_ooool003Sooooo00?o0000ooooooooool0oooooolWoooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Foooo
o`00>?ooool2o`000?oooooo:?ooool2o`0006oooooo00?o0000ooooooooool0I_ooool00ol0003o
ooooooooo`0Fooooo`00>?ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo01Gooooo000hooooo`03o`000?oo
oooooooo0?oooooo9oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06[ooooo00?o
0000ooooooooool05?ooool003;ooooojOl00010ooooonWo00004?ooool003Sooooo0_l00009oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo0_l0001;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Dooooo`00>?ooool00ol0003oooooo`00000Yooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooool00000Boooool2o`0002[ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Cooooo000hooooo`04o`00
0?ooooooooooo`000=Kooooo00?o0000ooooooooool0C?ooool00ol0003oooooo`00001Zooooo`03
o`000?oooooooooo08?ooooo000hooooo`;o00000_ooool00ol0003oooooooooo`3Booooo`03o`00
0?oooooooooo04gooooo0ol0001Yooooo`03o`000?oooooooooo08Cooooo000hooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0d?ooool00ol0003oooooooooo`1>ooooo`04o`000?oo
ooooooooo`0006Sooooo00?o0000ooooooooool0Q?ooool003Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo04oooooo00Co0000oooooooooooo0000
Ioooool00ol0003oooooooooo`25ooooo`00>?ooool2o`0000Gooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`1@ooooo`;o00000_ooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo08Gooooo000hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0b_ooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`26ooooo`00>?ooool00ol0003oooooooooo`06ooooo`;o0000b?ooool2o`00
05Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
08Oooooo000hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0a?ooool00ol0003o
ooooooooo`1Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`27ooooo`00>?ooool2o`0000[ooooo00?o0000ooooooooool0`_ooool00ol0003ooooo
ooooo`1Eooooo`;o00001?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo08Sooooo
000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0`?ooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`28ooooo`00>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0;kooooo00?o0000
ooooooooool0Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool0ROooool003Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2loooo
o`03o`000?oooooooooo05Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo08[ooooo000hooooo`;o00003_ooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo05Wooooo0_l00007ooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool0R_ooool001Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0^?ooool00ol0003oooooooooo`0hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0Roooool001Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;Kooooo
00?o0000ooooooooool0>Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2;ooooo`005_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02oooo
o`;o00004Oooool00ol0003oooooooooo`2cooooo`;o0000??ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`;o00002Oooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo08cooooo000Fooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo03cooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0SOoo
ool001Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
[oooool00ol0003oooooooooo`0mooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0S_ooool001Kooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0?_ooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`2>
ooooo`005_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Kooooo0_l0000Eooooo`03o`000?oooooooooo0:_ooooo00?o
0000ooooooooool0?oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo0_l0000;ooooo`03o`000?oooooooooo057o
oooo00?o0000ooooooooool0Soooool001Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`2Yooooo`03o`000?oooooooooo043ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo093ooooo000hooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`2@ooooo`00>?ooool2o`00
01Sooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`1Tooooo`;o00003Oooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo097ooooo000hooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0X_ooool2o`0006Oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo09;ooooo000hooooo`03o`000?oooooooooo01Wooooo
0_l0002Qooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1:ooooo`03o`000?oooooooooo09?ooooo000hooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0WOooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`2Cooooo`00>?ooool2o`0001gooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`1Yooooo`;o00003oooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo09Cooooo000hooooo`03o`000?oooooooooo01gooooo0_l0002Joooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo09Gooooo000hooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0U_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`2Eooooo`00>?ooool2o`00027ooooo00?o0000ooooooooool0
U?ooool00ol0003oooooooooo`1/ooooo`;o00004Oooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo09Kooooo000hooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0T_oo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`2Gooooo`007_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Rooooo`;o0000
T?ooool2o`0005Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo09Sooooo000Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
08cooooo00?o0000ooooooooool0E_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo09Wooooo000Nooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`02ooooo`;o00009_ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooo
oooo05Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0_l0
000Eooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0V_ooool001kooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo05Sooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo09[ooooo000Nooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`26ooooo`03o`000?oooooooooo05Wooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0Voooool001kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`24
ooooo`03o`000?oooooooooo05[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo09cooooo000Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`06ooooo`;o0000:_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo05_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo0_l0000Hooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0WOooool001kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool0G?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Nooooo`00
>?ooool00ol0003oooooooooo`0[ooooo`;o0000O_ooool2o`0007Wooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo09oooooo000hooooo`;o0000;_oo
ool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo07Wooooo0_l0000Kooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0X?ooool003Sooooo00?o0000ooooooooool0;_ooool2
o`0007Sooooo0_l0001looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`2Qooooo`00>?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
07Cooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0X_ooool003Sooooo00?o0000ooooooooool0<Oooool2o`0007;o
oooo0_l0001oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`2Sooooo`00>?ooool2o`0003Cooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`1oooooo`;o00007oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0:Cooooo
000hooooo`03o`000?oooooooooo03Cooooo0_l0001/ooooo`;o0000P_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0YOooool003Sooooo00?o0000
ooooooooool0=_ooool2o`0006Sooooo0_l00024ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`2Vooooo`00>?ooool2o`0003Wooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`24ooooo`;o00008_ooool2o`0002?ooooo00?o0000oooo
ooooool0Yoooool001Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0i
ooooo`;o0000H_ooool2o`0006Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Z?ooool001Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0>oooool2o`0005kooooo0_l0001Wooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`2Yooooo`005_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`1Wooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo0:[ooooo000Fooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000ooooo
o`;o0000F?ooool2o`0006[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool00oooool2o`0002Oooooo0ol0000Hooooo`;o0000[Oooool0
01Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo043ooooo0_l0001Eooooo`03o`000?oo
oooooooo06[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo02Wooooo0_l0000Cooooo`?o
0000[oooool001Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`12ooooo`;o0000DOooool2o`0006go
oooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0[ooooo`;o00003oooool2o`000;;ooooo000Fooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04cooooo0_l0001_
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0]ooooo`?o00002_ooool2o`000;Cooooo
000Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00005ooooo`;o0000
A_ooool2o`0004_ooooo00?o0000ooooooooool0Koooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001Oooool2o`00037ooooo2_l0002fooooo`00>?ooool00ol0003ooooo
ooooo`17ooooo`;o0000Aoooool2o`0009Cooooo00?o0000ooooooooool0l?ooool003Sooooo00?o
0000ooooooooool0BOooool2o`0004;ooooo0ol0002Fooooo`03o`000?oooooooooo0?3ooooo000h
ooooo`;o0000C?ooool3o`0003gooooo0_l0002Iooooo`;o0000lOooool003Sooooo00?o0000oooo
ooooool0C_ooool2o`0003Sooooo0ol0002Kooooo`03o`000?oooooooooo0?3ooooo000hooooo`03
o`000?oooooooooo053ooooo0_l0000dooooo`;o0000W_ooool00ol0003oooooooooo`3`ooooo`00
>?ooool00ol0003oooooooooo`1Booooo`;o0000;oooool3o`000:3ooooo00?o0000ooooooooool0
l?ooool003Sooooo0_l0001Eooooo`Co0000:?ooool3o`000:?ooooo0_l0003aooooo`00>?ooool0
0ol0003oooooooooo`1Hooooo`Go00007oooool4o`000:Kooooo00?o0000ooooooooool0l?ooool0
03Sooooo00?o0000ooooooooool0GOooool5o`0001Cooooo1_l0002Zooooo`03o`000?oooooooooo
0?3ooooo000hooooo`;o0000HooooolDo`000;3ooooo0_l0003aooooo`00;oooool4o`000003oa0@
4?oooooooooo00;ooooo00?o0000ooooooooool0oooooolNooooo`Co000000?o410@ooooooooool0
0_ooool00ol0003oooooooooo`3`ooooo`00<Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooo8?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?3ooooo000a
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolPooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0l?ooool0037ooooo00?o0000ooooooooool01?ooool2o`00
0?oooooo8Oooool00ol0003oooooooooo`04ooooo`;o0000lOooool0037ooooo00?o0000oooooooo
ool0oooooolWooooo`03o`000?oooooooooo0?Oooooo000aooooo`03o`000?oooooooooo0?oooooo
9oooool00ol0003oooooooooo`3gooooo`00<Oooool00ol0003oooooooooo`3oooooobOooooo00?o
0000ooooooooool0moooool002oooooo00?oEEEEofIVI_l00000oooooolWooooo`03oeEEEOmVIVKo
00000?Wooooo003oooooooooooooE_ooool00?oooooooooooomFooooo`00UOooool01?l@413o0000
o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000000ol@413oooooooooo`3oooooo`?o
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`Go0000M?ooool009Ko
oooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`3ooooo
o`Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_oo
ooooA4A407Cooooo002Fooooo`05o`000?ooooooooooooooool000006oooool00ol0003ooooooooo
o`3oooooo`Kooooo00Go0000ooooooooooooooooo`00000Iooooo`03oiRHV?lQ8B7ok^k^07Gooooo
002Fooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool0
ooooool6ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^
k^h0M?ooool009Kooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo0?oo
oooo1_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?oMgMgofIVI_ooool0Loooool009Go
oooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo0?oo
oooo1Oooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01[ooooo00?o0000oooooooo
ool0L_ooool00;Kooooo00?o0000ooooooooool0oooooolSooooo`05o`000?nj^[[ooooooiRHV?l@
4100M?ooool00;Cooooo00?oEEEEofIVI_l00000oooooolUooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`0M?ooool00?oooooooooooomFooooo`00oooooooooooooeKooooo003oooooooooooooE_ooool0
0?oooooooooooomFooooo`00oooooooooooooeKooooo003oooooooooooooE_ooool00?oooooooooo
oomFooooo`00oooooooooooooeKooooo003oooooooooooooE_ooool00?oooooooooooomFooooo`00
oooooooooooooeKooooo003oooooooooooooE_ooool00001\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32705 L
.08255 .33556 L
.10458 .34367 L
.12507 .34975 L
.14415 .35391 L
.14918 .35475 L
.15465 .35553 L
.15946 .3561 L
.16457 .3566 L
.16917 .35694 L
.17178 .35708 L
.17423 .35719 L
.17538 .35724 L
.17647 .35727 L
.17746 .3573 L
.17852 .35732 L
.17967 .35734 L
.18073 .35735 L
.182 .35736 L
.18314 .35736 L
.18435 .35735 L
.18547 .35734 L
.1867 .35732 L
.18802 .35729 L
.19071 .3572 L
.19317 .35709 L
.1979 .3568 L
.20239 .35643 L
.21236 .35527 L
.22321 .35349 L
.24299 .34896 L
.26399 .34249 L
.30174 .32745 L
.34195 .30869 L
.38063 .29066 L
.40028 .28236 L
.42177 .27445 L
.44253 .26828 L
.4614 .26416 L
.47149 .26259 L
.47611 .26202 L
.48101 .26153 L
.4835 .26132 L
.48624 .26112 L
.48876 .26097 L
.49106 .26087 L
.49378 .26077 L
.49527 .26073 L
.49596 .26071 L
Mistroke
.49669 .2607 L
.498 .26069 L
.49921 .26068 L
.49996 .26068 L
.50065 .26068 L
.50196 .26069 L
.50313 .2607 L
.50438 .26072 L
.50556 .26075 L
.50663 .26078 L
.50926 .26088 L
.51175 .261 L
.5167 .26133 L
.52208 .26183 L
.53169 .26303 L
.54056 .26452 L
.55926 .26875 L
.57988 .27501 L
.62014 .291 L
.65888 .30909 L
.70007 .32825 L
.72063 .33681 L
.73974 .34375 L
.75939 .34959 L
.77791 .3537 L
.78775 .35528 L
.79293 .35594 L
.7984 .3565 L
.80302 .35686 L
.80546 .35702 L
.80809 .35715 L
.8105 .35724 L
.8127 .3573 L
.81375 .35733 L
.81491 .35734 L
.81599 .35735 L
.817 .35736 L
.81818 .35736 L
.81941 .35735 L
.82047 .35734 L
.82163 .35732 L
.82287 .35729 L
.82421 .35725 L
.82661 .35716 L
.82905 .35704 L
.83134 .3569 L
.83564 .35658 L
.84078 .35608 L
.84552 .35551 L
.85624 .35384 L
Mistroke
.87498 .34974 L
.89561 .34361 L
.93591 .32778 L
.97471 .30973 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .26242 L
.08255 .24219 L
.0932 .2333 L
.10458 .22545 L
.11009 .22231 L
.11531 .21977 L
.12038 .21769 L
.12507 .21614 L
.12951 .215 L
.13178 .21454 L
.13422 .21415 L
.13549 .21398 L
.13666 .21384 L
.13784 .21373 L
.13895 .21365 L
.14022 .21358 L
.1409 .21356 L
.14161 .21354 L
.1423 .21353 L
.14295 .21353 L
.14415 .21354 L
.14531 .21358 L
.14656 .21364 L
.14773 .21372 L
.14881 .21382 L
.15143 .21414 L
.15392 .21454 L
.15886 .21565 L
.16423 .2173 L
.17383 .22139 L
.1827 .22642 L
.20137 .2406 L
.22197 .261 L
.26217 .30935 L
.30086 .35597 L
.32051 .37571 L
.3309 .38443 L
.342 .39217 L
.35275 .39797 L
.35784 .4001 L
.36253 .4017 L
.36724 .40295 L
.36972 .40346 L
.37235 .40389 L
.37463 .40418 L
.37573 .40428 L
.37677 .40436 L
.37799 .40444 L
.37911 .40448 L
Mistroke
.38031 .40451 L
.38162 .4045 L
.38227 .40449 L
.38296 .40448 L
.38419 .40442 L
.38551 .40434 L
.38695 .40421 L
.38955 .40389 L
.39197 .4035 L
.39649 .40251 L
.40134 .40108 L
.40698 .39893 L
.41232 .39645 L
.42232 .39063 L
.44227 .37492 L
.4607 .35634 L
.50002 .30899 L
.53782 .26331 L
.55884 .24211 L
.56803 .23435 L
.57808 .22714 L
.58722 .22183 L
.59696 .21755 L
.60236 .21583 L
.60726 .21468 L
.60962 .21426 L
.61086 .21408 L
.61218 .21392 L
.61333 .2138 L
.61459 .21369 L
.61574 .21362 L
.61682 .21357 L
.61808 .21353 L
.61871 .21353 L
.61941 .21353 L
.62065 .21355 L
.62181 .21359 L
.62248 .21362 L
.62318 .21367 L
.62443 .21377 L
.62578 .2139 L
.62725 .21408 L
.62973 .21447 L
.63238 .215 L
.63715 .21624 L
.64214 .21792 L
.64686 .21988 L
.6557 .22447 L
.67568 .23897 L
.69413 .25668 L
Mistroke
.7335 .30323 L
.77136 .34959 L
.79241 .37174 L
.81166 .38782 L
.82118 .39396 L
.8262 .39666 L
.83155 .39912 L
.8367 .40105 L
.84136 .40244 L
.84361 .40299 L
.84604 .40349 L
.84835 .40387 L
.85045 .40414 L
.85159 .40425 L
.85283 .40435 L
.85414 .40443 L
.85538 .40448 L
.85653 .40451 L
.85776 .40451 L
.85881 .40449 L
.85997 .40444 L
.86063 .40441 L
.86132 .40436 L
.86256 .40426 L
.86535 .40395 L
.86777 .40357 L
.87041 .40305 L
.87569 .40166 L
.88133 .39969 L
.89148 .39488 L
.90173 .38845 L
.91284 .37986 L
.933 .36054 L
.97393 .31186 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34401 L
.10458 .38151 L
.14415 .41547 L
.18221 .44642 L
.22272 .47699 L
.26171 .50358 L
.30316 .52832 L
.34309 .54829 L
.3815 .56358 L
.40095 .56979 L
.42237 .57537 L
.44268 .57945 L
.45178 .58088 L
.46172 .58216 L
.4671 .58273 L
.4721 .58319 L
.47727 .58358 L
.48196 .58387 L
.48658 .58408 L
.4887 .58416 L
.49093 .58423 L
.49332 .58429 L
.49438 .58431 L
.49552 .58432 L
.49675 .58434 L
.49789 .58435 L
.49859 .58435 L
.49925 .58435 L
.50049 .58435 L
.50163 .58435 L
.50286 .58434 L
.50401 .58433 L
.50508 .58431 L
.50754 .58427 L
.51014 .5842 L
.51268 .58411 L
.51504 .58401 L
.5204 .58373 L
.5293 .58307 L
.53882 .5821 L
.54906 .58076 L
.56016 .57895 L
.58032 .57475 L
.62123 .56263 L
.66064 .54659 L
.69852 .52739 L
.73886 .50321 L
.77769 .4767 L
.81897 .4455 L
Mistroke
.85873 .41305 L
.89697 .38015 L
.93767 .34391 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35481 L
.10458 .40129 L
.14415 .43855 L
.18221 .46612 L
.20178 .47655 L
.21267 .48115 L
.22272 .48462 L
.23293 .48734 L
.23832 .48846 L
.24402 .48939 L
.24641 .4897 L
.24897 .48999 L
.25119 .4902 L
.25361 .49038 L
.25507 .49047 L
.25643 .49053 L
.25773 .49058 L
.2584 .4906 L
.25912 .49062 L
.25983 .49064 L
.26048 .49064 L
.26176 .49065 L
.26293 .49065 L
.26416 .49063 L
.26538 .4906 L
.26607 .49058 L
.26671 .49056 L
.26912 .49045 L
.27131 .4903 L
.27364 .49011 L
.27847 .48957 L
.2838 .48876 L
.29326 .48678 L
.30213 .48429 L
.32232 .47642 L
.34082 .46659 L
.38045 .43788 L
.41855 .40199 L
.45912 .35742 L
.49816 .31122 L
.53966 .26203 L
.57964 .21791 L
.61811 .18138 L
.63759 .16587 L
.65902 .15154 L
.67938 .14084 L
.69843 .13357 L
.70884 .13076 L
.71396 .12968 L
Mistroke
.71872 .12886 L
.72301 .12828 L
.72758 .12782 L
.7302 .12763 L
.73148 .12755 L
.73266 .1275 L
.73371 .12746 L
.73487 .12742 L
.73603 .1274 L
.73725 .12738 L
.73856 .12738 L
.73977 .12739 L
.7404 .1274 L
.7411 .12742 L
.74251 .12746 L
.74375 .12751 L
.74508 .12757 L
.74748 .12773 L
.74985 .12793 L
.75235 .12818 L
.7568 .12876 L
.76198 .12963 L
.7668 .13063 L
.77773 .13356 L
.78828 .13725 L
.79823 .14149 L
.81683 .15134 L
.85534 .17907 L
.89632 .21767 L
.93577 .26115 L
.97371 .30604 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo0P00
1Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo
10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00
Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Io
o`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`007goo0`001Woo0P001Goo
10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00
Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eo
o`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`005Woo1P000Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo0?moo`Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomo
ogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomoogoo000037oo10001Goo00<007oo
Ool0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool0
0`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool0
1@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0l7oo000OOol3000=Ool40005Ool2003o
Ool?Ool3000=Ool40005Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`8001Eoo`T006Ioo`T006Aoo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo
1Woo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol04Woo0P002Goo1000H7oo0P002Goo0`00
HGoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001o
ogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<0
07ooOol03goo0`003goo00<007ooOol0FWoo0`003Woo0P00Ggoo000>Ool60002Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0o7oo1P000Woo00D007ooOomoo`00
00eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo015oo`8005Qoo`80
01=oo`03001oogoo05aoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000=Ool2000F
Ool00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`1KOol001Ioo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo
10001Goo00<007ooOol02goo00<007ooOol05goo00<007ooOol0DWoo00<007ooOol05Woo00<007oo
Ool0FWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Yoo`03
001oogoo01Uoo`03001oogoo051oo`03001oogoo01Qoo`03001oogoo05Uoo`005Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000]oo`03001oogoo01Yoo`03001oogoo04ioo`03
001oogoo01Yoo`03001oogoo05Qoo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo
0`003Goo0`001Goo10001Goo00<007ooOol02Goo00<007ooOol077oo00<007ooOol0C7oo00<007oo
Ool077oo00<007ooOol0Egoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`08Ool00`00Oomoo`0N
Ool00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`1FOol003Qoo`03001oogoo01moo`<000Io
o`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<001Yoo`<000Ioo`8000Eo
o`<0025oo`D004Uoo`03001oogoo00Moo`03001oogoo01Eoo`<000Ioo`<000=oo`D001Qoo`<000Io
o`8000Ioo`<001Ioo`03001oo`00008000Ioo`8000Eoo`<000ioo`03001oogoo00Qoo`<000Ioo`80
00Eoo`<0025oo`D001Aoo`00>7oo0P007goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000G
Ool01@00Oomoogoo00001Goo0P001goo00<007ooOol060000Woo00<007ooOol00goo0P0017oo00D0
07ooOomoo`0001Qoo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol0
BGoo0P001goo00<007ooOol05Goo00D007ooOomoo`0000Eoo`800003Ool007oo009oo`04001oogoo
000GOol01@00Oomoogoo00001Goo0P001goo00<007ooOol057oo00<007oo00000goo00<007ooOol0
0goo0P0017oo00D007ooOomoo`0000eoo`03001oogoo00Moo`05001oogooOol00005Ool20004Ool0
1@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Goo
00<007ooOol05goo00D007ooOomoo`0000]oo`H001Ioo`03001oo`00008000]oo`05001oogooOol0
000HOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03001oogoo00Io
o`03001oogoo01Eoo`05001oogooOol00008Ool00`00Oomoo`02Ool00`00Oomoo`0GOol01@00Oomo
ogoo00002goo1@005Goo00<007oo00000goo00<007ooOol02Goo00D007ooOomoo`0000ioo`03001o
ogoo00Ioo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00
Oomoo`0NOol01@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`@001Qoo`04
001oogooOol40008Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogooOol0000R
Ool00`00Oomoo`19Ool00`00Oomoo`05Ool00`00Oomoo`0FOol01@00Oomoogoo00002Goo00<007oo
Ool00Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000EOol01000Oomoo`000goo
00<007ooOol02Goo00D007ooOomoo`0000moo`03001oogoo00Eoo`05001oogooOol0000;Ool01@00
Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003goo00<0
07ooOol05Goo00D007ooOomoo`0000Uoo`800004Ool007oo000HOol01@00Oomoogoo00000goo0P00
1Woo10006Goo00D007ooOomoo`0000aoo`<002=oo`03001oogoo04Uoo`03001oogoo00Aoo`03001o
ogoo01Moo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`0EOol01@00Oomoogoo0000
37oo00<007oo000057oo00D007ooOomoo`0000=oo`03001oogoo00Uoo`@0015oo`03001oogoo00Ao
o`05001oogooOol0000<Ool3000SOol00`00Oomoo`0DOol003Qoo`8001moo`05001oogooOol0000?
Ool00`00Oomoo`0EOol01@00Oomoogoo00001Woo0`000goo00<007oo000067oo00D007ooOomoo`00
00Eoo`8000Aoo`03001oogoo01Yoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007oo
Ool0BGoo0P0017oo00<007ooOol067oo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00
Oomoogoo000037oo00<007oo00004goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo
01=oo`03001oogoo00=oo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo
000hOol00`00Oomoo`0NOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0
0004Ool20007Ool2000HOol01@00Oomoogoo00001goo0`000Woo00<007ooOol06Goo00D007ooOomo
o`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`02Ool00`00Oomoo`0IOol0
1@00Oomoogoo00002goo0P000Woo00<007ooOol05Goo00D007ooOomoo`0000eoo`80019oo`03001o
ogoo00=oo`05001oogooOol0000<Ool00`00Oomoo`0COol00`00Oomoo`02Ool01@00Oomoogoo0000
2goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07goo0`003Goo0`006Goo
0`000goo0P002Woo00<007ooOol05goo0`002goo0P0000Aoo`00000001Uoo`<000eoo`<0025oo`<0
04]oo`05001oogooOol0000MOol3000=Ool3000IOol3000?Ool00`00Oomoo`0?Ool00`00Oomoo`05
Ool3000>Ool3000COol00`00Oomoo`02Ool3000=Ool3000QOol3000FOol003Qoo`80051oo`8003Io
o`8009eoo`80009oo`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02eoo`03001oogoo04io
o`00>7oo00<007ooOol0CGoo0P00>Woo0P00Vgoo00@007ooOol0031oo`03001oogoo03Yoo`03001o
ogoo02moo`03001oogoo04eoo`00>7oo00<007ooOol0BWoo0`00?Woo0`00V7oo00<007oo0000<Woo
00<007ooOol0>7oo00<007ooOol0<Goo00<007ooOol0C7oo000hOol00`00Oomoo`18Ool20014Ool2
002FOol2000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`1<Ool0039oonT0041oonT0
011oo`00>7oo00@007oo000000Moo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`04001oogooOol30004Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`03
Ool30002Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool20002Ool00`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool20009Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0DOol003Qoo`04001oogooOol3
000mOol2001BOol2000lOol3001@Ool00`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomoo`0gOol0
0`00Oomoo`0aOol00`00Oomoo`0EOol003Qoo`8000Eoo`8003Qoo`<005Ioo`<003Moo`8005=oo`80
03Moo`03001oogoo031oo`03001oogoo03Uoo`03001oogoo02moo`03001oogoo01Ioo`00>7oo00<0
07ooOol01Woo0P00=7oo0P00G7oo0P00<goo0P00EGoo00<007ooOol0=goo00<007ooOol0;Woo00<0
07ooOol0>goo00<007ooOol0;Goo00<007ooOol05goo000hOol00`00Oomoo`08Ool3000_Ool2001P
Ool2000_Ool2001GOol00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00Oomoo`0lOol00`00Oomoo`0/
Ool00`00Oomoo`0HOol003Qoo`03001oogoo00]oo`8002]oo`8006Aoo`8002Yoo`<005Uoo`03001o
ogoo03Uoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo01Uoo`00>7oo
0P003Woo0`009Woo0P00J7oo0`009Goo0P00G7oo0P00>Woo00<007ooOol0:Woo00<007ooOol0?goo
00<007ooOol0:Goo00<007ooOol06Goo000hOol00`00Oomoo`0@Ool3000POol3001]Ool3000OOol3
001NOol00`00Oomoo`0jOol00`00Oomoo`0XOol00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomo
o`0JOol003Qoo`03001oogoo01=oo`D001Ioo`D007=oo`D001Eoo`D0065oo`03001oogoo03]oo`03
001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03001oogoo01]oo`00>7oo00<007ooOol0
67oo0`003goo1000OGoo0`003goo0`00IWoo00<007ooOol0?7oo00<007ooOol097oo00<007ooOol0
AGoo00<007ooOol08goo00<007ooOol077oo000hOol2000LOol?0024Ool?001YOol2000nOol2000S
Ool00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`0MOol003Qoo`03001oogoo0?moobMoo`03
001oogoo03moo`03001oogoo01moo`03001oogoo04Uoo`03001oogoo01moo`03001oogoo01ioo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0@7oo00<007ooOol07Goo00<007ooOol0Bgoo00<007oo
Ool07Goo00<007ooOol07goo000hOol2003oOolXOol20012Ool00`00Oomoo`0KOol00`00Oomoo`1=
Ool00`00Oomoo`0KOol00`00Oomoo`0POol001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001o
ogoo0?moo`Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo049oo`03001oogoo01Qoo`80
055oo`03001oogoo01Uoo`03001oogoo025oo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001o
ogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Goo00@0
07ooOol000Qoo`03001oogoo009oo`03001oogoo04=oo`03001oogoo01Ioo`03001oogoo059oo`03
001oogoo01Ioo`8002Aoo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009o
o`03001oogoo0?moo`Eoo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00
Oomoo`14Ool2000EOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`0TOol001Ioo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00Woo0P00Agoo00<007ooOol04Goo00<007ooOol0EWoo0`004Woo
00<007ooOol09Goo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo04Moo`8000moo`80
05aoo`03001oogoo00ioo`03001oogoo02Ioo`005Woo00D007ooOomoo`0000moo`03001oogoo009o
o`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00
Oomoo`06Ool00`00Oomoo`19Ool00`00Oomoo`0;Ool00`00Oomoo`1MOol00`00Oomoo`0;Ool2000Y
Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo
00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001;Ool20007Ool4001Q
Ool30007Ool3000[Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo0?moo`Ioo`<000eoo`<0
00Eoo`@000Eoo`03001oogoo04aoo`L006Qoo`L002ioo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`
Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo0P00ogoo:7oo0P00lGoo000OOol30006Ool20005Ool40005Ool00`00Oomoo`3oOol>Ool30006
Ool20005Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol00005Ool20009Ool00`00Oomo
o`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007oo
Ool0l7oo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007oo
Oomoo`00011oo`03001oogoo009oo`03001oogoo0?1oo`007Woo00D007ooOomoo`00011oo`03001o
ogoo009oo`800?moo`ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003aOol001ioo`05001o
ogooOol0000<Ool40005Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo10001Goo00<007oo
Ool0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0ogoo3Goo00D007oo
Oomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`800?moo`ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003aOol001moo`<000eo
o`@000Eoo`03001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?mo
obQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000GOol30006Ool20006Ool00`00Oomoo`04Ool4
0005Ool00`00Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3`
Ool001Ioo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomo
o`3oOol5Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007oo
Ool0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?1oo`00
5Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogoo
Ool0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool0
0`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol00goo
10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
1Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03
001oogoo0?1oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2
003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?5oo`00
5goo0`0037oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`0037oo1@0017oo10001Goo00<007oo
Ool0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol002moo`D000Ao
o`03001oogoo0?mooaioo`D000Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0
ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00
Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0
ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001o
ogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00nGoo003oOoooOomFOol00?mooomo
oeIoo`00UGoo0`0000Aoo`00000001Qoo`<00?moo`Moo`<00004Ool00000000IOol3001dOol009Io
o`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000ogoo1goo00D007ooOomoo`0000Uoo`H0
00aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001aoo`03001oogoo0?moo`Eoo`05001oogoo
Ool0000HOol5001dOol009Ioo`05001oogooOol00009Ool6000=Ool00`00Oomoo`3oOol5Ool01@00
Oomoogoo00002Goo1P002Goo00@007ooOol007Eoo`00UWoo00D007ooOomoo`0001Yoo`800?moo`Qo
o`05001oogooOol0000IOol00`00Ool0001eOol009Eoo`D001eoo`03001oogoo0?moo`Aoo`D001Yo
o`03001oo`0007Eoo`00/goo00D007ooOomoo`000?moobIoo`8007Eoo`00]7oo0`00ogoo:7oo00<0
07ooOol0Lgoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol002moo`D00?moobEoo`D00?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0
mgoo000VOol60005Ool00`00Oomoo`3oOolLOol60005Ool00`00Oomoo`3gOol0035oo`03001oogoo
00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo
87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol0
0`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Ao
o`800?5oo`00;goo0`001Woo00<007ooOol0ogoo7Woo0`001Woo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol001Moo`<000Ioo`8000Ioo`03001oogoo
00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001o
ogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool0
0`00Oomoo`3`Ool000ioo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`3lOol60002Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00
ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?5oo`005Woo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000>
Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Ao
o`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P00lGoo000GOol3000<Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool3000<Ool50004
Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolX
Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo09ioo`X004Qoo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0Vgoo0`002Woo0`00AGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2G
Ool4000@Ool50010Ool003Qoo`800?moobQoo`8009Eoo`<001Uoo`8003ioo`007goo0`001Woo0P00
1Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0TWoo0P007Woo
0P00?7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo
00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo095oo`03001oogoo021oo`03
001oogoo03Uoo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`Ioo`H0
009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2002@Ool2000TOol2000iOol001ioo`05001o
ogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007oo
Ool00Woo00<007ooOol0SGoo0P00:7oo00<007ooOol0=Woo000NOol01@00Oomoogoo000037oo1000
1Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo08aoo`03001oogoo
02Uoo`03001oogoo03Eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?mo
o`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`2;Ool00`00Oomoo`0[Ool2000e
Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo
00<007ooOol01Woo0P00Rgoo00<007ooOol0;Woo00<007ooOol0<Woo000OOol3000=Ool40005Ool0
0`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`29Ool00`00Oomoo`0`Ool00`00Oomoo`0a
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Qoo`03001oogoo039oo`80035oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0QWoo0P00=goo00<007ooOol0;Woo000hOol2003oOolXOol20026
Ool00`00Oomoo`0hOol00`00Oomoo`0]Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Aoo`03
001oogoo03Yoo`03001oogoo02aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Pgoo00<007oo
Ool0?7oo00<007ooOol0:goo000hOol2003oOolXOol20023Ool00`00Oomoo`0nOol00`00Oomoo`0Z
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo085oo`03001oogoo041oo`03001oogoo02Uoo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0P7oo00<007ooOol0@Woo00<007ooOol0:7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`1oOol00`00Oomoo`14Ool00`00Oomoo`0WOol003Qoo`800?mo
obQoo`8007moo`03001oogoo04Ioo`03001oogoo02Ioo`005goo0`001Woo0P0017oo1@0017oo1000
1Goo00<007ooOol0ogoo1Woo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0OGoo00<007oo
Ool0Agoo00<007ooOol09Woo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03
001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo
00<007ooOol00Woo00<007ooOol0O7oo00<007ooOol0BGoo00<007ooOol09Goo000>Ool60002Ool0
1@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P00oGoo1P000Woo00D007ooOomo
o`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8007aoo`03001oogoo04]oo`03001oogoo02Ao
o`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eo
o`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`1jOol00`00Oomo
o`1=Ool00`00Oomoo`0SOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00
Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0NGoo00<0
07ooOol0Cgoo00<007ooOol08Woo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo07Qoo`03001oogoo055oo`03001oogoo025oo`005Woo00D007ooOomoo`0000]oo`05
001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomo
o`0000Aoo`03001oogoo00Ioo`8007Qoo`03001oogoo05=oo`03001oogoo021oo`005goo0`003Goo
0`001Goo10001Goo00<007ooOol0ogoo1Woo0`003Goo0`001Goo10001Goo00<007ooOol0MWoo00<0
07ooOol0EGoo00<007ooOol07goo000hOol00`00Oomoo`0OOol30006Ool20004Ool5000HOol30006
Ool20006Ool3000HOol30006Ool20005Ool3000JOol30006Ool20005Ool3000QOol50019Ool00`00
Oomoo`0OOol30006Ool20004Ool5000HOol30006Ool20006Ool3000FOol00`00Ool000020006Ool2
0005Ool3000IOol30006Ool20005Ool3000IOol00`00Oomoo`05Ool5000DOol003Qoo`8001moo`05
001oogooOol00005Ool20005Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03001o
ogoo01Ioo`05001oogooOol00005Ool20004Ool01@00Oomoogoo000067oo00D007ooOomoo`0000Eo
o`8000Aoo`05001oogooOol0000ROol00`00Oomoo`19Ool2000OOol01@00Oomoogoo00001Goo0P00
1Goo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00Oomoo`0DOol00`00Ool00003
Ool00`00Oomoo`03Ool20004Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Eoo`8000Aoo`05
001oogooOol0000IOol00`00Oomoo`06Ool00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001o
ogooOol0000=Ool00`00Oomoo`0GOol01@00Oomoogoo00002goo1@005goo00D007ooOomoo`0000]o
o`05001oogooOol0000HOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uo
o`03001oogoo01ioo`05001oogooOol0000=Ool00`00Oomoo`0GOol01@00Oomoogoo00002goo1@00
5Goo00<007oo00000goo00<007ooOol02Goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool0
1@00Oomoogoo00006Goo00<007ooOol01Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00
Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomo
ogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<0
07ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0
000;Ool01000Oomoo`005Goo00@007ooOol000=oo`03001oogoo00Uoo`05001oogooOol0000GOol0
1@00Oomoogoo00002goo00D007ooOomoo`0001Yoo`03001oogoo00Eoo`03001oogoo01Aoo`00>7oo
00<007ooOol07Woo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00
Ool0000HOol01@00Oomoogoo00002goo10006Goo00D007ooOomoo`0000aoo`<002=oo`03001oogoo
04Uoo`03001oogoo01ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo
00<007oo000057oo00D007ooOomoo`0000=oo`03001oogoo00Uoo`@001Qoo`05001oogooOol0000<
Ool3000LOol00`00Oomoo`04Ool00`00Oomoo`0DOol003Qoo`8001moo`05001oogooOol0000?Ool0
0`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`0000]oo`03001o
ogoo01Yoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo0P007goo00D0
07ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000COol00`00Oomo
o`02Ool01@00Oomoogoo00002goo00<007ooOol06Goo00D007ooOomoo`0000]oo`05001oogooOol0
000LOol00`00Oomoo`03Ool00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogooOol0000;
Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8001Qoo`05001oogooOol0000<Ool00`00
Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03001oogoo
01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8001=oo`03
001oogoo009oo`05001oogooOol0000<Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007oo
Oomoo`0001eoo`03001oogoo009oo`03001oogoo01Aoo`00>7oo00<007ooOol07goo0`003Goo0`00
6Goo0`003goo00<007ooOol05goo0`003Woo0`006Goo0`003Goo0`008Goo0`00Bgoo00<007ooOol0
7goo0`003Goo0`006Goo0`003goo00<007ooOol047oo00<007ooOol017oo0`003Woo0`0067oo0`00
3Goo0`007goo00<007oo00000P005Woo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1_Ool00`00
Oomoo`1SOol00`00Oomoo`0HOol003Qoo`800?moobQoo`8006moo`03001oogoo06Eoo`03001oogoo
01Moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0KWoo00<007ooOol0IWoo00<007ooOol05Woo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1]Ool00`00Oomoo`1XOol00`00Oomoo`0EOol0039o
onT0041oonT0011oo`00>7oo00<007oo000027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol01Woo00<007oo0000Bgoo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol057oo000hOol01000Oomoo`00:7oo
00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol09Woo00@007ooOol004]o
o`8002Yoo`03001oogoo02Uoo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo02Uoo`03001o
ogoo02Uoo`03001oogoo01Aoo`00>7oo00D007ooOomoo`000=Aoo`03001oogoo04eoo`03001oo`00
06Yoo`03001oogoo08=oo`00>7oo0P000goo00<007ooOol0d7oo00<007ooOol0CWoo0P0000=oo`00
Ool0Igoo00<007ooOol0Q7oo000hOol00`00Oomoo`03Ool00`00Oomoo`3>Ool00`00Oomoo`1?Ool0
1@00Oomoogoo0000IWoo00<007ooOol0QGoo000hOol00`00Oomoo`04Ool00`00Oomoo`3<Ool00`00
Oomoo`1@Ool00`00Oomoo`02Ool00`00Oomoo`1ROol00`00Oomoo`26Ool003Qoo`8000Ioo`03001o
ogoo0<Yoo`03001oogoo055oo`8000=oo`03001oogoo065oo`03001oogoo08Moo`00>7oo00<007oo
Ool01Woo0P00b7oo0P00E7oo00<007ooOol00goo00<007ooOol0Ggoo00<007ooOol0R7oo000hOol0
0`00Oomoo`08Ool00`00Oomoo`34Ool00`00Oomoo`1DOol00`00Oomoo`04Ool00`00Oomoo`1MOol0
0`00Oomoo`29Ool003Qoo`03001oogoo00Uoo`03001oogoo0<9oo`03001oogoo05Eoo`03001oogoo
00Eoo`03001oogoo05]oo`03001oogoo08Yoo`00>7oo0P002goo00<007ooOol0`7oo00<007ooOol0
EWoo0P001goo00<007ooOol0FGoo00<007ooOol0Rgoo000hOol00`00Oomoo`0;Ool00`00Oomoo`2n
Ool00`00Oomoo`1GOol00`00Oomoo`06Ool00`00Oomoo`1IOol00`00Oomoo`2;Ool003Qoo`03001o
ogoo00aoo`03001oogoo0;aoo`03001oogoo05Qoo`03001oogoo00Moo`03001oogoo05Moo`03001o
ogoo08aoo`00>7oo00<007ooOol03Goo00<007ooOol0^Woo00<007ooOol0FGoo00<007ooOol027oo
00<007ooOol0EGoo00<007ooOol0SGoo000hOol2000?Ool00`00Oomoo`2hOol00`00Oomoo`1JOol2
000:Ool00`00Oomoo`1COol00`00Oomoo`2>Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03
001oogoo00moo`03001oogoo0;Ioo`03001oogoo03Yoo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03
001oogoo00Yoo`03001oogoo055oo`03001oogoo08moo`005Woo00D007ooOomoo`0000Eoo`8000Eo
o`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool2002dOol2000lOol01@00Oomoogoo
00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo04mo
o`03001oogoo091oo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`80
01=oo`03001oogoo0;1oo`03001oogoo03aoo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool2000<Ool00`00Oomoo`1>Ool00`00Oomoo`2AOol001Ioo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`2^Ool00`00Oomoo`0mOol0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0
C7oo00<007ooOol0TWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007oo
Ool057oo00<007ooOol0Zgoo0P00@7oo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03
001oogoo00eoo`03001oogoo04Yoo`03001oogoo09=oo`005Woo00D007ooOomoo`0000moo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo0:Uoo`03001oogoo041oo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`18Ool0
0`00Oomoo`2DOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo
0P005goo00<007ooOol0Ygoo00<007ooOol0@Goo00D007ooOomoo`0000]oo`05001oogooOol00004
Ool00`00Oomoo`06Ool2000@Ool20016Ool2002GOol001Moo`<000eoo`<000Eoo`@000Eoo`03001o
ogoo01Moo`03001oogoo0:Eoo`03001oogoo04=oo`<000eoo`<000Eoo`@000Eoo`03001oogoo015o
o`03001oogoo049oo`03001oogoo09Moo`00>7oo00<007ooOol067oo00<007ooOol0XWoo0P00Igoo
00<007ooOol04Woo00<007ooOol0@7oo00<007ooOol0V7oo000hOol2000JOol2002QOol00`00Oomo
o`1WOol2000DOol00`00Oomoo`0nOol00`00Oomoo`2IOol003Qoo`03001oogoo01]oo`03001oogoo
09eoo`03001oogoo06Qoo`03001oogoo01Aoo`8003eoo`03001oogoo09Yoo`00>7oo00<007ooOol0
77oo00<007ooOol0Vgoo00<007ooOol0JGoo00<007ooOol05Woo00<007ooOol0>Goo00<007ooOol0
Vgoo000hOol00`00Oomoo`0MOol2002JOol00`00Oomoo`1ZOol00`00Oomoo`0GOol00`00Oomoo`0g
Ool00`00Oomoo`2LOol003Qoo`80021oo`03001oogoo09Ioo`03001oogoo06]oo`8001Uoo`03001o
ogoo03Eoo`03001oogoo09eoo`00>7oo00<007ooOol087oo00<007ooOol0U7oo00<007ooOol0K7oo
00<007ooOol06Goo0P00<goo0P00X7oo000hOol00`00Oomoo`0QOol00`00Oomoo`2BOol00`00Oomo
o`1]Ool00`00Oomoo`0KOol00`00Oomoo`0_Ool00`00Oomoo`2POol003Qoo`8002=oo`80091oo`80
071oo`8001eoo`03001oogoo02eoo`03001oogoo0:5oo`00>7oo00<007ooOol097oo00<007ooOol0
S7oo00<007ooOol0L7oo00<007ooOol07Goo00<007ooOol0:Woo0P00Y7oo000OOol30006Ool20005
Ool40005Ool00`00Oomoo`0UOol00`00Oomoo`2:Ool00`00Oomoo`1HOol30006Ool20005Ool40005
Ool00`00Oomoo`0NOol00`00Oomoo`0XOol00`00Oomoo`2TOol001ioo`05001oogooOol00005Ool2
0009Ool00`00Oomoo`02Ool00`00Oomoo`0VOol20028Ool2001JOol01@00Oomoogoo00001Goo0P00
2Goo00<007ooOol00Woo00<007ooOol07goo00<007ooOol09Woo00<007ooOol0YGoo000NOol01@00
Oomoogoo000047oo00<007ooOol00Woo0P00:Goo00<007ooOol0Q7oo00<007ooOol0FWoo00D007oo
Oomoo`00011oo`03001oogoo009oo`80025oo`03001oogoo02Aoo`03001oogoo0:Ioo`007Woo00D0
07ooOomoo`00011oo`03001oogoo009oo`03001oogoo02Uoo`03001oogoo089oo`03001oogoo05]o
o`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0QOol2000ROol2002YOol001ioo`05
001oogooOol0000<Ool40005Ool00`00Oomoo`0ZOol00`00Oomoo`20Ool00`00Oomoo`1LOol01@00
Oomoogoo000037oo10001Goo00<007ooOol08goo0`007Goo0P00Zgoo000NOol01@00Oomoogoo0000
37oo00<007ooOol01Woo00<007ooOol0:goo0P00OWoo0P00Ggoo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`03001oogoo02Ioo`<001Qoo`800:eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo
00Ioo`8002ioo`03001oogoo07Yoo`03001oogoo05moo`05001oogooOol0000<Ool00`00Oomoo`06
Ool2000ZOol2000COol3002_Ool001moo`<000eoo`@000Eoo`03001oogoo02ioo`8007Qoo`8006=o
o`<000eoo`@000Eoo`03001oogoo02]oo`8000eoo`@00;9oo`00>7oo00<007ooOol0<7oo00<007oo
Ool0M7oo00<007ooOol0O7oo00<007ooOol0;Goo3@00]Woo000hOol2000bOol2001bOol2001oOol2
003aOol003Qoo`03001oogoo03=oo`03001oogoo06ioo`03001oogoo07moo`03001oogoo0?1oo`00
>7oo00<007ooOol0=7oo0P00K7oo0P00PWoo00<007ooOol0l7oo000hOol00`00Oomoo`0fOol2001X
Ool20024Ool00`00Oomoo`3`Ool003Qoo`8003Uoo`03001oogoo06Aoo`03001oogoo08Aoo`800?5o
o`00>7oo00<007ooOol0>Goo0P00HWoo0P00Qgoo00<007ooOol0l7oo000hOol00`00Oomoo`0kOol2
001NOol20029Ool00`00Oomoo`3`Ool003Qoo`8003ioo`03001oogoo05Yoo`03001oogoo08Uoo`80
0?5oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0?Woo0P00F7oo0P00
Jgoo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0@7oo0P00E7oo0P00K7oo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`00
5Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo049oo`80051o
o`8006ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool0
01Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20015Ool00`00Oomoo`1;
Ool2001`Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00lGoo000FOol0
1@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0AGoo0P00BGoo0P00LWoo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo04Moo`<004=oo`<007Aoo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0
000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0BWoo0`00?Woo0P00Mgoo00D0
07ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Moo`<0
00aoo`D000Aoo`@000Eoo`8004ioo`<003Qoo`<007Yoo`<000aoo`D000Aoo`@000Eoo`800?5oo`00
>7oo00<007ooOol0D7oo0P00=7oo0P00WWoo00<007ooOol0l7oo000hOol00`00Oomoo`1BOol2000_
Ool3002POol00`00Oomoo`3`Ool003Qoo`8005Eoo`@002Qoo`<00:=oo`800?5oo`00>7oo00<007oo
Ool0F7oo1@007goo1000YWoo00<007ooOol0l7oo000hOol00`00Oomoo`1MOol5000DOol6002ZOol0
0`00Oomoo`3`Ool003Qoo`03001oogoo069ooa@00;1oo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo
0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000_Ool50004Ool00`00Oomoo`3oOolNOol50004
Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03
001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007oo
Ool0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001o
ogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003o
OoooOomFOol009Eoo`<00004Ool00000000HOol5003oOol5Ool3000017oo000000005goo1@00M7oo
002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H0
00Yoo`04001oogoo001dOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomo
ogoo00006Woo00<007ooOol0M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo
1Woo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001]oo`03
001oogoo0?moo`Ioo`05001oogooOol0000LOol00`00Oomoo`1bOol009Eoo`D001aoo`03001oogoo
0?moo`Eoo`D001eoo`03001oogoo079oo`00]Woo00<007ooOol0ogoo8goo00D007ooOomoo`0007Ao
o`00]7oo0`00ogoo9Woo0`00MGoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .27339 L
.08255 .25658 L
.10458 .24056 L
.12507 .22856 L
.14415 .22033 L
.14918 .21868 L
.15465 .21714 L
.15946 .216 L
.16457 .21503 L
.16917 .21436 L
.17178 .21407 L
.17423 .21385 L
.17538 .21377 L
.17647 .2137 L
.17746 .21365 L
.17852 .2136 L
.17967 .21356 L
.18073 .21354 L
.182 .21353 L
.18314 .21353 L
.18435 .21354 L
.18547 .21357 L
.1867 .21361 L
.18802 .21367 L
.19071 .21384 L
.19317 .21405 L
.1979 .21463 L
.20239 .21536 L
.21236 .21765 L
.22321 .22116 L
.24299 .23011 L
.26399 .2429 L
.30174 .27261 L
.34195 .30966 L
.38063 .34528 L
.40028 .36167 L
.42177 .3773 L
.44253 .38948 L
.4614 .39763 L
.47149 .40073 L
.47611 .40185 L
.48101 .40283 L
.4835 .40324 L
.48624 .40362 L
.48876 .40392 L
.49106 .40414 L
.49378 .40433 L
.49527 .4044 L
.49596 .40443 L
Mistroke
.49669 .40446 L
.498 .40449 L
.49921 .40451 L
.49996 .40451 L
.50065 .40451 L
.50196 .40449 L
.50313 .40446 L
.50438 .40442 L
.50556 .40436 L
.50663 .4043 L
.50926 .40411 L
.51175 .40386 L
.5167 .40321 L
.52208 .40224 L
.53169 .39985 L
.54056 .39692 L
.55926 .38855 L
.57988 .37619 L
.62014 .34461 L
.65888 .30888 L
.70007 .27103 L
.72063 .25411 L
.73974 .2404 L
.75939 .22887 L
.77791 .22075 L
.78775 .21762 L
.79293 .21633 L
.7984 .21522 L
.80302 .2145 L
.80546 .2142 L
.80809 .21394 L
.8105 .21375 L
.8127 .21363 L
.81375 .21359 L
.81491 .21356 L
.81599 .21354 L
.817 .21353 L
.81818 .21353 L
.81941 .21354 L
.82047 .21357 L
.82163 .21361 L
.82287 .21366 L
.82421 .21374 L
.82661 .21392 L
.82905 .21415 L
.83134 .21443 L
.83564 .21507 L
.84078 .21606 L
.84552 .21718 L
.85624 .22047 L
Mistroke
.87498 .22858 L
.89561 .24069 L
.93591 .27196 L
.97471 .30761 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .18702 L
.08255 .13407 L
.0932 .1108 L
.10458 .09023 L
.11009 .08202 L
.11531 .07535 L
.12038 .06993 L
.12507 .06587 L
.12951 .06288 L
.13178 .06168 L
.13422 .06064 L
.13549 .0602 L
.13666 .05985 L
.13784 .05956 L
.13895 .05935 L
.14022 .05917 L
.1409 .0591 L
.14161 .05905 L
.1423 .05902 L
.14295 .05902 L
.14415 .05905 L
.14531 .05915 L
.14656 .05932 L
.14773 .05953 L
.14881 .05979 L
.15143 .06061 L
.15392 .06167 L
.15886 .06457 L
.16423 .06889 L
.17383 .0796 L
.1827 .09278 L
.20137 .12989 L
.22197 .18329 L
.26217 .3099 L
.30086 .43193 L
.32051 .48363 L
.3309 .50645 L
.342 .52672 L
.35275 .54191 L
.35784 .54748 L
.36253 .55166 L
.36724 .55494 L
.36972 .55628 L
.37235 .55741 L
.37463 .55815 L
.37573 .55842 L
.37677 .55864 L
.37799 .55883 L
.37911 .55894 L
Mistroke
.38031 .55901 L
.38162 .55901 L
.38227 .55898 L
.38296 .55893 L
.38419 .55879 L
.38551 .55857 L
.38695 .55823 L
.38955 .55741 L
.39197 .55638 L
.39649 .55378 L
.40134 .55003 L
.40698 .54442 L
.41232 .53791 L
.42232 .52269 L
.44227 .48156 L
.4607 .43291 L
.50002 .30895 L
.53782 .18936 L
.55884 .13385 L
.56803 .11355 L
.57808 .09466 L
.58722 .08075 L
.59696 .06956 L
.60236 .06505 L
.60726 .06204 L
.60962 .06095 L
.61086 .06047 L
.61218 .06004 L
.61333 .05973 L
.61459 .05945 L
.61574 .05925 L
.61682 .05913 L
.61808 .05904 L
.61871 .05902 L
.61941 .05902 L
.62065 .05907 L
.62181 .05918 L
.62248 .05927 L
.62318 .05939 L
.62443 .05965 L
.62578 .06 L
.62725 .06048 L
.62973 .0615 L
.63238 .06287 L
.63715 .06611 L
.64214 .07053 L
.64686 .07566 L
.6557 .08768 L
.67568 .12564 L
.69413 .17199 L
Mistroke
.7335 .29387 L
.77136 .41524 L
.79241 .47323 L
.81166 .51534 L
.82118 .53139 L
.8262 .53847 L
.83155 .5449 L
.8367 .54998 L
.84136 .55361 L
.84361 .55504 L
.84604 .55634 L
.84835 .55734 L
.85045 .55804 L
.85159 .55835 L
.85283 .55861 L
.85414 .55882 L
.85538 .55895 L
.85653 .55901 L
.85776 .55901 L
.85881 .55896 L
.85997 .55884 L
.86063 .55875 L
.86132 .55864 L
.86256 .55838 L
.86535 .55755 L
.86777 .55656 L
.87041 .5552 L
.87569 .55157 L
.88133 .5464 L
.89148 .5338 L
.90173 .51699 L
.91284 .49449 L
.933 .44391 L
.97393 .31646 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34079 L
.10458 .37484 L
.14415 .40567 L
.18221 .43378 L
.22272 .46153 L
.26171 .48568 L
.30316 .50814 L
.34309 .52627 L
.3815 .54016 L
.40095 .54579 L
.42237 .55086 L
.44268 .55456 L
.45178 .55586 L
.46172 .55703 L
.4671 .55755 L
.4721 .55796 L
.47727 .55831 L
.48196 .55857 L
.48658 .55877 L
.4887 .55884 L
.49093 .55891 L
.49332 .55896 L
.49438 .55897 L
.49552 .55899 L
.49675 .559 L
.49789 .55901 L
.49859 .55901 L
.49925 .55902 L
.50049 .55902 L
.50163 .55901 L
.50286 .55901 L
.50401 .559 L
.50508 .55898 L
.50754 .55894 L
.51014 .55888 L
.51268 .5588 L
.51504 .55871 L
.5204 .55845 L
.5293 .55785 L
.53882 .55697 L
.54906 .55575 L
.56016 .55411 L
.58032 .55029 L
.62123 .53929 L
.66064 .52473 L
.69852 .5073 L
.73886 .48534 L
.77769 .46127 L
.81897 .43294 L
Mistroke
.85873 .40348 L
.89697 .37361 L
.93767 .3407 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33309 L
.10458 .35753 L
.14415 .37711 L
.18221 .39161 L
.20178 .39709 L
.21267 .39951 L
.22272 .40133 L
.23293 .40277 L
.23832 .40335 L
.24402 .40384 L
.24641 .40401 L
.24897 .40416 L
.25119 .40427 L
.25361 .40437 L
.25507 .40441 L
.25643 .40445 L
.25773 .40447 L
.2584 .40448 L
.25912 .40449 L
.25983 .4045 L
.26048 .4045 L
.26176 .40451 L
.26293 .40451 L
.26416 .4045 L
.26538 .40448 L
.26607 .40447 L
.26671 .40446 L
.26912 .4044 L
.27131 .40432 L
.27364 .40422 L
.27847 .40394 L
.2838 .40351 L
.29326 .40247 L
.30213 .40116 L
.32232 .39702 L
.34082 .39186 L
.38045 .37677 L
.41855 .35789 L
.45912 .33446 L
.49816 .31018 L
.53966 .28432 L
.57964 .26112 L
.61811 .24191 L
.63759 .23376 L
.65902 .22623 L
.67938 .2206 L
.69843 .21678 L
.70884 .2153 L
.71396 .21473 L
Mistroke
.71872 .2143 L
.72301 .214 L
.72758 .21376 L
.7302 .21366 L
.73148 .21362 L
.73266 .21359 L
.73371 .21357 L
.73487 .21355 L
.73603 .21353 L
.73725 .21353 L
.73856 .21353 L
.73977 .21353 L
.7404 .21354 L
.7411 .21354 L
.74251 .21357 L
.74375 .21359 L
.74508 .21363 L
.74748 .21371 L
.74985 .21381 L
.75235 .21395 L
.7568 .21425 L
.76198 .21471 L
.7668 .21523 L
.77773 .21677 L
.78828 .21871 L
.79823 .22094 L
.81683 .22612 L
.85534 .2407 L
.89632 .26099 L
.93577 .28385 L
.97371 .30745 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`0FOol6001YOol5001VOol003Qoo`800?moobQoo`8001Eoo`80
00Ioo`03001oogoo06Aoo`8000Eoo`03001oogoo06=oo`005goo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool04goo00<007ooOol01goo00<007ooOol0HWoo00<007ooOol01Woo00<007ooOol0HWoo000FOol0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo01=oo`03
001oogoo00Qoo`03001oogoo061oo`03001oogoo00Qoo`03001oogoo065oo`003Woo1P000Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000COol00`00Oomoo`0:Ool00`00Oomoo`1NOol0
0`00Oomoo`0:Ool00`00Oomoo`1POol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol04Goo00<007ooOol037oo00<007ooOol0G7oo00<007ooOol02goo00<007ooOol0
H7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo011oo`03001oogoo00eoo`03001o
ogoo05aoo`03001oogoo00aoo`03001oogoo05moo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`1JOol00`00Oomoo`0>Ool0
0`00Oomoo`1NOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo
0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000@Ool0
0`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0?Ool00`00Oomoo`1NOol001Moo`<000aoo`D0
00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo00ioo`03001o
ogoo015oo`03001oogoo05Qoo`03001oogoo011oo`03001oogoo05eoo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0
G7oo000hOol2003oOolXOol2000?Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol0
0`00Oomoo`1LOol003Qoo`03001oogoo0?moobMoo`03001oogoo00eoo`03001oogoo01Aoo`03001o
ogoo05Eoo`03001oogoo01=oo`03001oogoo05]oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
3Goo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol057oo00<007ooOol0Fgoo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomoo`1COol00`00Oomoo`0EOol0
0`00Oomoo`1JOol003Qoo`800?moobQoo`8000aoo`03001oogoo01Moo`03001oogoo059oo`03001o
ogoo01Moo`03001oogoo05Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol02goo00<007ooOol0
67oo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol0FGoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`1HOol0
03Qoo`800?moobQoo`8000]oo`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03001o
ogoo05Qoo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo1000
1Goo00<007ooOol02Woo00<007ooOol06Woo00<007ooOol0CWoo00<007ooOol06Woo00<007ooOol0
F7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo01]oo`03001o
ogoo04ioo`03001oogoo01]oo`03001oogoo05Moo`005Woo1P000Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo0?moo`Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`09Ool00`00Oomoo`0LOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`1GOol0
01ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<0
07ooOol00Woo0P002Woo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol0
Egoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000ao
o`@000Eoo`03001oogoo00Qoo`03001oogoo01ioo`03001oogoo04]oo`03001oogoo01eoo`03001o
ogoo05Ioo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0NOol00`00Oomoo`1:Ool0
0`00Oomoo`0NOol00`00Oomoo`1FOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00
Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
7Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000OOol3000=Ool40005Ool2003o
Ool?Ool3000=Ool40005Ool20008Ool00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol0
0`00Oomoo`1EOol003Qoo`03001oogoo0?moobMoo`03001oogoo00Moo`03001oogoo021oo`03001o
ogoo04Qoo`03001oogoo021oo`03001oogoo05Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
1goo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol087oo00<007ooOol0EGoo000hOol2003o
OolXOol20007Ool00`00Oomoo`0ROol00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`1DOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo04Ioo`03001o
ogoo029oo`03001oogoo05Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol01Woo00<007ooOol0
8Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol0E7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`06Ool00`00Oomoo`0SOol00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`1COol0
03Qoo`800?moobQoo`8000Ioo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001o
ogoo05=oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol01Goo00<007ooOol097oo00<007ooOol0
A7oo00<007ooOol097oo00<007ooOol0Dgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`05Ool0
0`00Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`1BOol003Qoo`8001eoo`d0
08Ioo``006]oo`8000Eoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo
059oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol067oo10003Goo1000OWoo1000
37oo1@00AGoo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol017oo00<007ooOol09Woo00<0
07ooOol0@Woo00<007ooOol09Woo00<007ooOol0DWoo000FOol01@00Oomoogoo00001Goo0P001Goo
00@007ooOol000Qoo`03001oogoo009oo`03001oogoo01Eoo`<001Eoo`8007Uoo`<001Eoo`80049o
o`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol09goo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol0DGoo000>Ool60002Ool0
1@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol04goo0P006Woo00<0
07ooOol0M7oo0P006Woo0P00>7oo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001o
ogoo055oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8001=oo`03
001oogoo01]oo`8007=oo`03001oogoo01aoo`8003ioo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00
Oomoo`1AOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`0AOol0
0`00Oomoo`0NOol3001_Ool00`00Oomoo`0OOol00`00Oomoo`0kOol01@00Oomoogoo00003goo00<0
07ooOol00Woo10001Goo00<007ooOol00goo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0
:Goo00<007ooOol0D7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol03goo0P0097oo0P00Jgoo0P008goo0P00>goo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo
02Yoo`03001oogoo051oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomo
o`06Ool2000?Ool00`00Oomoo`0VOol00`00Oomoo`1VOol2000WOol00`00Oomoo`0hOol01@00Oomo
ogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000=oo`03001oogoo02Yoo`03001o
ogoo03ioo`03001oogoo02Yoo`03001oogoo051oo`005goo0`003Goo0`001Goo10001Goo00<007oo
Ool03Goo00<007ooOol0:7oo00<007ooOol0I7oo00<007ooOol0:7oo00<007ooOol0>7oo0`003Goo
0`001Goo10001Goo00<007ooOol00Woo00<007ooOol0:goo00<007ooOol0?Goo00<007ooOol0:goo
00<007ooOol0Cgoo000hOol00`00Oomoo`0<Ool00`00Oomoo`0ZOol00`00Oomoo`1ROol00`00Oomo
o`0ZOol2001IOol01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0
Cgoo000hOol00`00Oomoo`0:Ool2000COol30006Ool20004Ool50007Ool00`00Oomoo`0>Ool30006
Ool20006Ool3000HOol30006Ool20005Ool3000COol00`00Oomoo`04Ool30006Ool20005Ool3000F
Ool00`00Oomoo`08Ool50019Ool01@00Oomoogoo00007Goo0`001Woo0P0017oo1@0067oo0`001Woo
0P001Woo0`0047oo00<007ooOol01Goo0`001Woo0P001Goo0`0057oo00<007ooOol00Woo0`001Woo
0P001Goo0`008Goo1@0057oo000hOol2000:Ool00`00Oomoo`0BOol01@00Oomoogoo00001Goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00aoo`05001oogooOol00005Ool20007Ool00`00Oomoo`0F
Ool01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00015oo`03001oogoo00Aoo`05001oogoo
Ool00005Ool20004Ool01@00Oomoogoo00005Woo00<007ooOol02Goo00<007ooOol0BGoo0P000Woo
00<007ooOol06Woo00D007ooOomoo`0000Eoo`8000Eoo`800003Ool007oo01Ioo`05001oogooOol0
0005Ool20007Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool01@00Oomoogoo00001Goo0P0017oo00D0
07ooOomoo`0001Aoo`04001oogoo0003Ool00`00Oomoo`03Ool20004Ool01@00Oomoogoo00008Woo
00<007ooOol057oo000hOol00`00Oomoo`08Ool00`00Oomoo`0COol01@00Oomoogoo00003Goo00<0
07ooOol02Goo00<007ooOol02goo00D007ooOomoo`0000]oo`D001Moo`05001oogooOol0000;Ool0
1@00Oomoogoo000047oo00<007ooOol01Goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol0
0`00Oomoo`08Ool00`00Oomoo`19Ool01000Oomoo`007Goo00D007ooOomoo`0000eoo`8001Qoo`05
001oogooOol0000;Ool5000?Ool00`00Oomoo`05Ool01@00Oomoogoo00002goo00D007ooOomoo`00
01Aoo`04001oogoo0003Ool00`00Oomoo`09Ool01@00Oomoogoo00008Woo00<007ooOol057oo000h
Ool00`00Oomoo`07Ool00`00Oomoo`0DOol01@00Oomoogoo00003Woo00<007ooOol02Goo0P002goo
00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomoo`0000io
o`8000Qoo`05001oogooOol0000;Ool01@00Oomoogoo000067oo0P0027oo00<007ooOol0BGoo00@0
07ooOol001eoo`05001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007oo
Ool0011oo`03001oogoo00Eoo`05001oogooOol0000;Ool01@00Oomoogoo000057oo00@007ooOol0
00=oo`03001oogoo00Uoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo00Eo
o`8001Moo`05001oogooOol0000?Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool01@00Oomoogoo0000
37oo00<007oo000067oo00D007ooOomoo`0000]oo`@000ioo`03001oogoo00Qoo`05001oogooOol0
000<Ool3000KOol00`00Oomoo`05Ool00`00Oomoo`19Ool01000Oomoo`007Goo00D007ooOomoo`00
00ioo`8001Moo`05001oogooOol0000<Ool00`00Ool0000@Ool00`00Oomoo`05Ool01@00Oomoogoo
00002goo10005Woo00<007oo00000goo00<007ooOol02Woo0`008goo00<007ooOol057oo000hOol2
0005Ool00`00Oomoo`0GOol01@00Oomoogoo00003goo00<007ooOol02goo00<007ooOol01goo00D0
07ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`0>Ool00`00Oomo
o`09Ool01@00Oomoogoo00002goo00D007ooOomoo`0001]oo`03001oogoo00Aoo`03001oogoo04Uo
o`<001ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo0000
3goo00<007ooOol01Woo00D007ooOomoo`0000]oo`03001oogoo01Moo`03001oo`0000=oo`03001o
ogoo00Uoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo00=oo`03001oogoo
01Qoo`05001oogooOol0000;Ool01@00Oomoogoo00003Woo00<007ooOol01Woo00D007ooOomoo`00
00eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool01@00Oomoogoo
00002goo00D007ooOomoo`0001aoo`03001oogoo00=oo`03001oogoo04Uoo`03001oo`0001ioo`05
001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8000moo`03001oogoo
00Ioo`05001oogooOol0000<Ool00`00Oomoo`0FOol00`00Ool00003Ool00`00Oomoo`09Ool01@00
Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`02Ool00`00Oomoo`0JOol3000=Ool3
000@Ool00`00Oomoo`06Ool3000?Ool00`00Oomoo`0GOol3000>Ool3000:Ool00`00Oomoo`0<Ool3
000=Ool3000NOol00`00Oomoo`03001;Ool00`00Ool0000OOol3000=Ool4000HOol3000?Ool00`00
Oomoo`0=Ool00`00Oomoo`07Ool3000>Ool3000FOol00`00Ool00002000=Ool3000QOol3000FOol0
03Qoo`80009oo`03001oogoo03moo`03001oogoo04ioo`03001oogoo03moo`03001oogoo04eoo`80
03Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo00@007ooOol004=oo`03
001oogoo04aoo`03001oogoo045oo`03001oogoo04aoo`8003Aoo`03001oogoo03Ioo`03001oogoo
039oo`03001oogoo04aoo`00>7oo00<007oo0000AGoo00<007ooOol0BWoo00<007ooOol0@goo00<0
07ooOol0Bgoo0P00=7oo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol0C7oo000hOol20017
Ool00`00Oomoo`18Ool00`00Oomoo`15Ool00`00Oomoo`1:Ool00`00Oomoo`0dOol00`00Oomoo`0d
Ool00`00Oomoo`0dOol00`00Oomoo`1;Ool0039oonT0041oonT0011oo`00>7oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol01goo0P002Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007oo000027oo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0BGoo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool057oo000hOol00`00Oomoo`1:Ool00`00Oomoo`10Ool00`00Oomoo`2FOol00`00Oomoo`0dOol0
0`00Oomoo`0dOol00`00Oomoo`0eOol00`00Oomoo`0cOol00`00Oomoo`0DOol003Qoo`8004aoo`03
001oogoo03ioo`03001oogoo09Moo`8003Ioo`03001oogoo039oo`03001oogoo03Ioo`03001oogoo
03=oo`03001oogoo01Aoo`00>7oo00<007ooOol0C7oo00<007ooOol0?7oo00<007ooOol0V7oo00<0
07ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol05Goo000h
Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00Oomoo`2IOol00`00Oomoo`0eOol00`00Oomoo`0b
Ool00`00Oomoo`0gOol00`00Oomoo`0aOol00`00Oomoo`0EOol003Qoo`03001oogoo04ioo`03001o
ogoo03Qoo`03001oogoo09Yoo`03001oogoo03Ioo`03001oogoo031oo`03001oogoo03Qoo`03001o
ogoo035oo`03001oogoo01Eoo`00>7oo0P00D7oo00<007ooOol0=Woo00<007ooOol0Vgoo0P00=goo
00<007ooOol0<7oo00<007ooOol0>7oo00<007ooOol0<7oo00<007ooOol05Woo000hOol00`00Oomo
o`1@Ool00`00Oomoo`0cOol2002NOol00`00Oomoo`0fOol00`00Oomoo`0`Ool00`00Oomoo`0iOol0
0`00Oomoo`0_Ool00`00Oomoo`0FOol003Qoo`03001oogoo055oo`03001oogoo035oo`03001oogoo
09ioo`03001oogoo03Moo`03001oogoo02ioo`03001oogoo03Yoo`03001oogoo02moo`03001oogoo
01Ioo`00>7oo00<007ooOol0DWoo00<007ooOol0;goo00<007ooOol0Wgoo00<007ooOol0=goo00<0
07ooOol0;Woo00<007ooOol0>Woo00<007ooOol0;Woo00<007ooOol05goo000hOol2001DOol00`00
Oomoo`0/Ool2002ROol2000hOol00`00Oomoo`0^Ool00`00Oomoo`0kOol00`00Oomoo`0]Ool00`00
Oomoo`0GOol003Qoo`03001oogoo05Aoo`8002]oo`03001oogoo0:9oo`03001oogoo03Qoo`03001o
ogoo02aoo`03001oogoo03aoo`03001oogoo02eoo`03001oogoo01Moo`00>7oo00<007ooOol0EWoo
00<007ooOol09goo00<007ooOol0Xgoo00<007ooOol0>7oo00<007ooOol0;7oo00<007ooOol0?7oo
00<007ooOol0;7oo00<007ooOol067oo000hOol2001HOol00`00Oomoo`0UOol00`00Oomoo`2TOol2
000iOol00`00Oomoo`0/Ool00`00Oomoo`0mOol00`00Oomoo`0[Ool00`00Oomoo`0HOol001Moo`<0
00Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo05Qoo`03001oogoo029oo`8008Ioo`<000Ioo`80
00Aoo`D000Aoo`@000Eoo`03001oogoo03Uoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo
02]oo`03001oogoo01Qoo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00
Oomoo`02Ool00`00Oomoo`1IOol2000POol20027Ool01@00Oomoogoo00001Goo0P001Goo00@007oo
Ool000Qoo`03001oogoo009oo`03001oogoo03Uoo`03001oogoo02Yoo`03001oogoo03ioo`03001o
ogoo02Yoo`03001oogoo01Uoo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo05]oo`<001aoo`03001oogoo08Moo`05001oogooOol0000=Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0oOol00`00Oomoo`0Y
Ool00`00Oomoo`0IOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2
001OOol2000HOol2002:Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00
>goo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol06Goo000FOol01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0H7oo0P0057oo0P00S7oo00D007oo
Oomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo03Yoo`03001oogoo02Qoo`03001oogoo
041oo`03001oogoo02Qoo`03001oogoo01Yoo`005Woo00D007ooOomoo`0000moo`03001oogoo009o
o`03001oogoo00Ioo`03001oogoo069oo`<000moo`8008ioo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`0jOol00`00Oomoo`0XOol00`00Oomoo`11Ool00`00Oomo
o`0WOol00`00Oomoo`0JOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P00IWoo0P002Goo1000T7oo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool2000lOol00`00Oomoo`0WOol00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`0J
Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo06Moo`T009Eoo`<000eoo`<000Eoo`@000Eo
o`03001oogoo03]oo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01]o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0>goo00<007ooOol09Woo00<007ooOol0@goo00<0
07ooOol09Goo00<007ooOol06goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0lOol00`00Oomo
o`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`0KOol003Qoo`800?moobQoo`8003eo
o`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo01aoo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0?7oo00<007ooOol097oo00<007ooOol0AGoo00<007ooOol08goo00<0
07ooOol077oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0mOol00`00Oomoo`0SOol00`00Oomo
o`15Ool00`00Oomoo`0SOol00`00Oomoo`0LOol003Qoo`800?moobQoo`8003ioo`03001oogoo029o
o`03001oogoo04Ioo`03001oogoo029oo`03001oogoo01eoo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0?Goo00<007ooOol08Woo00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol07Goo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`0nOol00`00Oomoo`0QOol00`00Oomoo`17Ool00`00Oomo
o`0QOol00`00Oomoo`0MOol003Qoo`03001oogoo0?moobMoo`03001oogoo03ioo`03001oogoo021o
o`03001oogoo04Qoo`03001oogoo021oo`03001oogoo01ioo`00>7oo0P00ogoo:7oo0P00?goo00<0
07ooOol087oo00<007ooOol0BGoo00<007ooOol07goo00<007ooOol07Woo000OOol30006Ool20005
Ool40005Ool00`00Oomoo`3oOol>Ool30006Ool20005Ool40005Ool00`00Oomoo`0oOol00`00Oomo
o`0OOol00`00Oomoo`19Ool00`00Oomoo`0NOol00`00Oomoo`0OOol001ioo`05001oogooOol00005
Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol00Woo00<007ooOol0?goo00<007ooOol07Woo00<007ooOol0BWoo00<007ooOol07Woo00<0
07ooOol07goo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`00011oo`03001oogoo009oo`03001oogoo041oo`03001oogoo01eoo`03001oogoo04]o
o`03001oogoo01eoo`03001oogoo01moo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`80
0?moo`ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool20011Ool00`00Oomoo`0MOol00`00Oomo
o`1;Ool00`00Oomoo`0LOol00`00Oomoo`0POol001ioo`05001oogooOol0000<Ool40005Ool00`00
Oomoo`3oOol=Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0@Goo00<007ooOol06goo00<0
07ooOol0C7oo00<007ooOol077oo00<007ooOol087oo000NOol01@00Oomoogoo000037oo00<007oo
Ool01Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo045o
o`03001oogoo01]oo`03001oogoo04eoo`03001oogoo01]oo`03001oogoo021oo`007Woo00D007oo
Oomoo`0000aoo`03001oogoo00Ioo`800?moo`ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2
0012Ool00`00Oomoo`0KOol00`00Oomoo`1=Ool00`00Oomoo`0JOol00`00Oomoo`0QOol001moo`<0
00eoo`@000Eoo`03001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo049oo`03001oogoo01Uo
o`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0@Woo00<007ooOol06Goo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol08Goo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`13Ool00`00Oomoo`0GOol00`00Oomoo`1@Ool00`00Oomo
o`0HOol00`00Oomoo`0ROol003Qoo`800?moobQoo`8004Aoo`03001oogoo01Moo`03001oogoo055o
o`03001oogoo01Moo`03001oogoo029oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0@goo00<0
07ooOol05Woo00<007ooOol0DWoo00<007ooOol05goo00<007ooOol08Woo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`14Ool00`00Oomoo`0DOol00`00Oomoo`1DOol00`00Oomoo`0EOol00`00Oomo
o`0SOol003Qoo`800?moobQoo`8004Eoo`03001oogoo01Aoo`03001oogoo05Aoo`03001oogoo01Ao
o`03001oogoo02Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0A7oo00<007ooOol04goo00<0
07ooOol0EGoo00<007ooOol057oo00<007ooOol097oo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`15Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol00`00Oomoo`0UOol003Qoo`03
001oogoo0?moobMoo`03001oogoo04Ioo`03001oogoo011oo`03001oogoo05Qoo`03001oogoo015o
o`03001oogoo02Eoo`00>7oo0P00ogoo:7oo0P00B7oo00<007ooOol03goo00<007ooOol0FGoo00<0
07ooOol03goo00<007ooOol09Woo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00
Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`17Ool00`00Oomo
o`0>Ool00`00Oomoo`1KOol00`00Oomoo`0>Ool00`00Oomoo`0VOol001Ioo`05001oogooOol00005
Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo0000
1Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0B7oo00<007ooOol03Goo00<0
07ooOol0Fgoo00<007ooOol03Goo00<007ooOol09goo000FOol01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo04Qoo`03001oogoo00aoo`03001oogoo05eoo`03001oogoo00ao
o`03001oogoo02Moo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80
0?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2001:Ool00`00Oomo
o`0:Ool00`00Oomoo`1OOol00`00Oomoo`0:Ool00`00Oomoo`0XOol001Ioo`05001oogooOol0000>
Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol0
0goo10001Goo00<007ooOol0BWoo00<007ooOol027oo00<007ooOol0H7oo00<007ooOol027oo0P00
:goo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo04]oo`03001o
ogoo00Ioo`03001oogoo069oo`8000Moo`03001oogoo02]oo`005Woo00D007ooOomoo`0000]oo`05
001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomo
o`0000Aoo`03001oogoo00Ioo`8004eoo`<000=oo`8006Moo`8000=oo`8002ioo`005goo0`0037oo
1@0017oo10001Goo00<007ooOol0ogoo1Woo0`0037oo1@0017oo10001Goo00<007ooOol0CWoo1000
JWoo1000<7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMo
o`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol002moo`D0
00Aoo`03001oogoo0?mooaioo`D000Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007oo
Ool0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol0
0`00Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007oo
Ool0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03
001oogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00nGoo003oOoooOomFOol00?mo
oomooeIoo`00UGoo0`0000Aoo`00000001Qoo`<00?moo`Moo`<00004Ool00000000IOol3001dOol0
09Ioo`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000ogoo1goo00D007ooOomoo`0000Uo
o`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001aoo`03001oogoo0?moo`Eoo`05001o
ogooOol0000HOol5001dOol009Ioo`05001oogooOol00009Ool6000=Ool00`00Oomoo`3oOol5Ool0
1@00Oomoogoo00002Goo1P002Goo00@007ooOol007Eoo`00UWoo00D007ooOomoo`0001Yoo`800?mo
o`Qoo`05001oogooOol0000IOol00`00Ool0001eOol009Eoo`D001eoo`03001oogoo0?moo`Aoo`D0
01Yoo`03001oo`0007Eoo`00/goo00D007ooOomoo`000?moobIoo`8007Eoo`00]7oo0`00ogoo:7oo
00<007ooOol0Lgoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomF
Ool00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol002moo`D00?moobEoo`D00?Moo`00<Goo00<007ooOol0ogoo9goo00<007oo
Ool0mgoo000VOol60005Ool00`00Oomoo`3oOolLOol60005Ool00`00Oomoo`3gOol0035oo`03001o
ogoo00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol017oo00<007ooOol0
ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolP
Ool00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo
00Aoo`800?5oo`00;goo0`001Woo00<007ooOol0ogoo7Woo0`001Woo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol001Moo`<000Ioo`8000Ioo`03001o
ogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03
001oogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009o
o`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`3`Ool000ioo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`3lOol60002Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo
0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?5oo`005Woo
00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0
000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000?Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`00
00Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<0
07ooOol01Woo0P00lGoo000GOol3000<Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool3000<Ool5
0004Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003o
OolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`800?5oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo1000
1Goo00<007ooOol0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007oo
Ool0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`005Woo
1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`Ioo`H0009oo`05001oogooOol0
000@Ool00`00Oomoo`02Ool2003aOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0l7oo000NOol01@00
Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001o
ogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00
Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P00lGoo000OOol3000=
Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003o
OolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`2MOol<0017Ool003Qoo`800?moobQoo`8009Qoo`H000aoo`L0041oo`005goo0`001Woo
0P0017oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P0017oo1@0017oo10001Goo00<0
07ooOol0Tgoo10006Goo1000?7oo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qo
o`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`00
27oo00<007ooOol00Woo00<007ooOol0Sgoo10008Goo0`00>Goo000>Ool60002Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo0P00oGoo1P000Woo00D007ooOomoo`0000eoo`03
001oogoo00Qoo`03001oogoo009oo`8008eoo`<002Qoo`<003Ioo`005Woo00D007ooOomoo`0000io
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`2:Ool2000^Ool3000cOol001Ioo`05001oogooOol0
000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007oo
Ool00Woo10001Goo00<007ooOol0R7oo0P00<goo0P00<Goo000FOol01@00Oomoogoo00003goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo08Ioo`8003Moo`8002moo`005Woo00D007ooOomoo`0000]o
o`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`8008Eoo`8003]oo`8002eoo`005goo0`003Goo0`001Goo1000
1Goo00<007ooOol0ogoo1Woo0`003Goo0`001Goo10001Goo00<007ooOol0PGoo0`00?goo0P00:goo
000hOol00`00Oomoo`0OOol30006Ool20004Ool5000HOol30006Ool20006Ool3000HOol30006Ool2
0005Ool3000JOol30006Ool20005Ool3000QOol50019Ool00`00Oomoo`0OOol30006Ool20004Ool5
000HOol30006Ool20006Ool3000HOol30005Ool30005Ool3000IOol30006Ool20005Ool3000?Ool2
000@Ool5000DOol003Qoo`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`005goo00D0
07ooOomoo`0000Eoo`8000Moo`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool01@00Oomo
ogoo000067oo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000ROol00`00Oomoo`19Ool2
000OOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool20007
Ool00`00Oomoo`0FOol01@00Oomoogoo00000Woo0P0000=oo`00000017oo00D007ooOomoo`0001Mo
o`05001oogooOol00005Ool20004Ool01@00Oomoogoo000047oo0P0047oo00<007ooOol057oo000h
Ool00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol05goo00D007ooOomoo`0000]oo`D0
01Moo`05001oogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogoo
Ool0000ROol00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol05goo
00D007ooOomoo`0000]oo`D001Moo`04001oogooOol30009Ool01@00Oomoogoo00005goo00D007oo
Oomoo`0000]oo`05001oogooOol0000BOol2000>Ool00`00Oomoo`0DOol003Qoo`03001oogoo01io
o`05001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol001Qoo`05
001oogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogooOol0000R
Ool00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Woo00<007ooOol05Woo00D007oo
Oomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001o
ogooOol0000;Ool01@00Oomoogoo000057oo0P0037oo00<007ooOol057oo000hOol00`00Oomoo`0N
Ool01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05
001oogooOol0000;Ool4000IOol01@00Oomoogoo000037oo0`008goo00<007ooOol0BGoo00<007oo
Ool07Woo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000H
Ool00`00Ool00002000;Ool4000HOol01@00Oomoogoo000037oo0`005goo00<007ooOol02Goo00<0
07ooOol057oo000hOol2000OOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`00
00aoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`0JOol01@00Oomoogoo00002goo
00D007ooOomoo`00029oo`03001oogoo04Uoo`8001moo`05001oogooOol0000?Ool00`00Oomoo`0E
Ool01@00Oomoogoo000037oo00<007oo000067oo0P000Woo00<007ooOol02Goo00<007ooOol06Goo
00D007ooOomoo`0000]oo`05001oogooOol0000GOol20009Ool00`00Oomoo`0DOol003Qoo`03001o
ogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8001Qo
o`05001oogooOol0000<Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`00029o
o`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D0
07ooOomoo`0000eoo`8001Moo`8000=oo`03001oogoo00Yoo`03001oogoo01Qoo`05001oogooOol0
000;Ool01@00Oomoogoo00006Goo0P001goo00<007ooOol057oo000hOol00`00Oomoo`0OOol3000=
Ool3000IOol3000?Ool00`00Oomoo`0GOol3000>Ool3000IOol3000=Ool3000QOol3001;Ool00`00
Oomoo`0OOol3000=Ool3000IOol3000?Ool00`00Oomoo`0COol20002Ool3000>Ool3000HOol3000=
Ool3000LOol00`00Oomoo`02Ool3000FOol003Qoo`03001oogoo0?moobMoo`03001oogoo079oo`03
001oogoo05ioo`8001]oo`00>7oo0P00ogoo:7oo0P00LGoo0P00Hgoo00<007ooOol067oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`1_Ool00`00Oomoo`1TOol2000HOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo06eoo`8006Uoo`03001oogoo01Eoo`00<Wooj@00@7ooj@0047oo000hOol00`00
Ool00008Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00
Ool0001;Ool00`00Ool00008Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`07Ool2000:Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`0DOol003Qoo`04001oogoo000XOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00
Oomoo`0ZOol00`00Oomoo`0VOol01000Oomoo`00Bgoo00<007ooOol00P009goo00<007ooOol0:Goo
00<007ooOol047oo0P005goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol057oo000hOol0
1@00Oomoogoo0000e7oo00<007ooOol0CGoo00<007ooOol00Woo00<007ooOol0HGoo0P00R7oo000h
Ool20003Ool00`00Oomoo`3@Ool00`00Oomoo`1>Ool20004Ool2001POol00`00Oomoo`28Ool003Qo
o`03001oogoo00=oo`03001oogoo0<ioo`03001oogoo04moo`03001oogoo00Eoo`03001oogoo05]o
o`8008]oo`00>7oo00<007ooOol017oo00<007ooOol0c7oo00<007ooOol0D7oo00<007ooOol01Woo
0P00FGoo0P00SGoo000hOol20006Ool00`00Oomoo`3:Ool00`00Oomoo`1AOol20009Ool2001EOol2
002?Ool003Qoo`03001oogoo00Ioo`800<Qoo`8005Aoo`03001oogoo00Yoo`80059oo`03001oogoo
08moo`00>7oo00<007ooOol027oo00<007ooOol0a7oo00<007ooOol0E7oo00<007ooOol037oo00<0
07ooOol0CGoo0P00TWoo000hOol00`00Oomoo`09Ool20032Ool2001GOol00`00Oomoo`0=Ool2001;
Ool2002DOol003Qoo`8000aoo`03001oogoo0;ioo`03001oogoo05Moo`80011oo`8004Qoo`03001o
ogoo09Aoo`00>7oo00<007ooOol037oo00<007ooOol0_7oo00<007ooOol0F7oo00<007ooOol04Goo
0P00A7oo0P00Ugoo000hOol00`00Oomoo`0=Ool2002jOol2001KOol00`00Oomoo`0COol20010Ool2
002IOol003Qoo`03001oogoo00moo`03001oogoo0;Ioo`03001oogoo05]oo`03001oogoo01Eoo`80
03]oo`<009]oo`00>7oo0P004Goo0P00]7oo0P00GWoo0P0067oo0P00=goo0P00WWoo000GOol30006
Ool20004Ool50004Ool40005Ool00`00Oomoo`0BOol00`00Oomoo`2`Ool00`00Oomoo`0mOol30006
Ool20004Ool50004Ool40005Ool00`00Oomoo`0IOol2000cOol2002POol001Ioo`05001oogooOol0
0005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol04goo00<007ooOol0[Woo
00<007ooOol0?Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`0KOol3000]Ool3002ROol001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool2000EOol00`00Oomoo`2[Ool20010Ool01@00Oomoogoo00003Goo00<007ooOol027oo
00<007ooOol00Woo0P007goo0`009goo0`00YGoo000FOol01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol05Goo00<007ooOol0ZGoo00<007ooOol0@7oo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo025oo`80029oo`<00:Qoo`005Woo
00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo01Ioo`03001oogoo0:Moo`03
001oogoo045oo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`0SOol3000M
Ool2002[Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`0GOol00`00Oomoo`2UOol00`00Oomoo`12Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol09Woo1@005Goo0`00[Goo000FOol01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`8001Uoo`03001oogoo0:9oo`8004Eoo`05001oogooOol0000;
Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00;7oo5@00/7oo000GOol3000=Ool30005Ool4
0005Ool00`00Oomoo`0IOol2002QOol00`00Oomoo`16Ool3000=Ool30005Ool40005Ool00`00Oomo
o`3`Ool003Qoo`03001oogoo01]oo`03001oogoo09eoo`03001oogoo06Qoo`03001oogoo0?1oo`00
>7oo0P007Goo0P00Vgoo0P00Jgoo0P00lGoo000hOol00`00Oomoo`0NOol00`00Oomoo`2GOol00`00
Oomoo`1[Ool00`00Oomoo`3`Ool003Qoo`03001oogoo01moo`8009Ioo`03001oogoo06aoo`03001o
ogoo0?1oo`00>7oo00<007ooOol08Goo00<007ooOol0TWoo00<007ooOol0KGoo00<007ooOol0l7oo
000hOol2000SOol2002@Ool2001`Ool2003aOol003Qoo`03001oogoo02Aoo`03001oogoo08aoo`03
001oogoo071oo`03001oogoo0?1oo`00>7oo00<007ooOol09Goo00<007ooOol0RWoo00<007ooOol0
LGoo00<007ooOol0l7oo000hOol2000WOol20028Ool2001dOol2003aOol003Qoo`03001oogoo02Qo
o`03001oogoo08Aoo`03001oogoo07Aoo`03001oogoo0?1oo`007goo0`001Woo0P001Goo10001Goo
00<007ooOol0:Goo00<007ooOol0PWoo00<007ooOol0G7oo0`001Woo0P001Goo10001Goo00<007oo
Ool0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0:Woo00<0
07ooOol0P7oo00<007ooOol0G7oo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001o
ogoo0?1oo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`8002aoo`8007ioo`8005moo`05
001oogooOol0000@Ool00`00Oomoo`02Ool2003aOol001ioo`05001oogooOol0000@Ool00`00Oomo
o`02Ool00`00Oomoo`0]Ool2001jOol2001QOol01@00Oomoogoo000047oo00<007ooOol00Woo00<0
07ooOol0l7oo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0;goo0P00MWoo0P00Hgoo
00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`03001oogoo035oo`03001oogoo079oo`03001oogoo06=oo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2000c
Ool2001`Ool2001VOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00lGoo000OOol3000=Ool4
0005Ool00`00Oomoo`0dOol2001/Ool2001YOol3000=Ool40005Ool00`00Oomoo`3`Ool003Qoo`03
001oogoo03Ioo`8006Qoo`8008Aoo`03001oogoo0?1oo`00>7oo0P00>Goo0P00I7oo0P00QWoo0P00
lGoo000hOol00`00Oomoo`0jOol2001POol20028Ool00`00Oomoo`3`Ool003Qoo`03001oogoo03ao
o`8005aoo`8008Yoo`03001oogoo0?1oo`00>7oo00<007ooOol0?Woo0P00F7oo0P00S7oo00<007oo
Ool0l7oo000hOol20011Ool2001DOol2002>Ool2003aOol003Qoo`03001oogoo049oo`80051oo`80
091oo`03001oogoo0?1oo`00>7oo00<007ooOol0A7oo00<007ooOol0Bgoo0P00TWoo00<007ooOol0
l7oo000hOol20016Ool20019Ool2002DOol2003aOol001Moo`<000Ioo`8000Ioo`03001oogoo00Ao
o`@000Eoo`03001oogoo04Moo`<004=oo`<007Eoo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eo
o`03001oogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo04Yoo`<003ioo`8007Moo`05001oogooOol00005Ool20006Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`1=Ool3000hOol3001iOol01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo0P00DGoo0`00<Woo0`00O7oo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`800?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001o
ogoo05=oo`D002Qoo`D007moo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomo
o`3`Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`1H
Ool5000OOol40024Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool0l7oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001o
ogoo05eoo`D001Aoo`H008Qoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol0
1Woo00<007ooOol0l7oo000GOol3000<Ool50004Ool40005Ool2001SOolD002?Ool3000<Ool50004
Ool40005Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00
;goo1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001o
ogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3
003oOolWOol3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo1@00
ogoo1Goo0`0000Aoo`00000001Moo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001o
ogoo0?moo`Ioo`05001oogooOol00009Ool6000:Ool01000Oomoo`00M7oo002FOol01@00Oomoogoo
00006goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001Yoo`03001oogoo07Aoo`00UWoo00D007oo
Oomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000<Ool00`00Oomo
o`1cOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo000077oo00<0
07ooOol0LWoo002EOol5000LOol00`00Oomoo`3oOol5Ool5000MOol00`00Oomoo`1bOol00;Ioo`03
001oogoo0?moob=oo`05001oogooOol0001dOol00;Aoo`<00?moobIoo`<007Eoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22749 L
.08255 .18903 L
.10458 .15237 L
.12507 .12491 L
.14415 .10609 L
.14918 .10231 L
.15465 .09878 L
.15946 .09618 L
.16457 .09396 L
.16917 .09242 L
.17178 .09175 L
.17423 .09125 L
.17538 .09106 L
.17647 .0909 L
.17746 .09078 L
.17852 .09068 L
.17967 .0906 L
.18073 .09054 L
.182 .09051 L
.18314 .09051 L
.18435 .09054 L
.18547 .0906 L
.1867 .09069 L
.18802 .09083 L
.19071 .09122 L
.19317 .09172 L
.1979 .09303 L
.20239 .09471 L
.21236 .09996 L
.22321 .10797 L
.24299 .12845 L
.26399 .15773 L
.30174 .22571 L
.34195 .31048 L
.38063 .392 L
.40028 .42949 L
.42177 .46526 L
.44253 .49314 L
.4614 .51178 L
.47149 .51888 L
.47611 .52145 L
.48101 .52368 L
.4835 .52462 L
.48624 .5255 L
.48876 .52617 L
.49106 .52667 L
.49378 .52711 L
.49527 .52729 L
.49596 .52735 L
Mistroke
.49669 .52741 L
.498 .52748 L
.49921 .52752 L
.49996 .52752 L
.50065 .52752 L
.50196 .52748 L
.50313 .52742 L
.50438 .52732 L
.50556 .52719 L
.50663 .52705 L
.50926 .52661 L
.51175 .52605 L
.5167 .52455 L
.52208 .52233 L
.53169 .51687 L
.54056 .51016 L
.55926 .49101 L
.57988 .46273 L
.62014 .39046 L
.65888 .3087 L
.70007 .2221 L
.72063 .18337 L
.73974 .15201 L
.75939 .12561 L
.77791 .10704 L
.78775 .09989 L
.79293 .09692 L
.7984 .09438 L
.80302 .09274 L
.80546 .09205 L
.80809 .09145 L
.8105 .09103 L
.8127 .09075 L
.81375 .09066 L
.81491 .09058 L
.81599 .09053 L
.817 .09051 L
.81818 .09051 L
.81941 .09055 L
.82047 .09061 L
.82163 .09069 L
.82287 .09082 L
.82421 .091 L
.82661 .0914 L
.82905 .09194 L
.83134 .09257 L
.83564 .09404 L
.84078 .0963 L
.84552 .09888 L
.85624 .1064 L
Mistroke
.87498 .12496 L
.89561 .15266 L
.93591 .22421 L
.97471 .30581 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .15822 L
.08255 .09277 L
.0932 .064 L
.10458 .03858 L
.11009 .02843 L
.11531 .02019 L
.12038 .01349 L
.12507 .00848 L
.12951 .00478 L
.13178 .0033 L
.13422 .00201 L
.13549 .00146 L
.13666 .00103 L
.13784 .00068 L
.13895 .00041 L
.14022 .00019 L
.1409 .0001 L
.14161 4e-05 L
.1423 1e-05 L
.14295 0 L
.14415 5e-05 L
.14531 .00016 L
.14656 .00037 L
.14773 .00064 L
.14881 .00095 L
.15143 .00197 L
.15392 .00328 L
.15886 .00686 L
.16423 .01221 L
.17383 .02544 L
.1827 .04173 L
.20137 .08761 L
.22197 .15361 L
.26217 .31011 L
.30086 .46095 L
.32051 .52485 L
.3309 .55305 L
.342 .57811 L
.35275 .59689 L
.35784 .60377 L
.36253 .60895 L
.36724 .61299 L
.36972 .61465 L
.37235 .61605 L
.37463 .61696 L
.37573 .6173 L
.37677 .61756 L
.37799 .6178 L
.37911 .61794 L
Mistroke
.38031 .61802 L
.38162 .61802 L
.38227 .61799 L
.38296 .61793 L
.38419 .61775 L
.38551 .61748 L
.38695 .61707 L
.38955 .61605 L
.39197 .61478 L
.39649 .61156 L
.40134 .60693 L
.40698 .59999 L
.41232 .59194 L
.42232 .57313 L
.44227 .52229 L
.4607 .46216 L
.50002 .30893 L
.53782 .16112 L
.55884 .0925 L
.56803 .0674 L
.57808 .04406 L
.58722 .02686 L
.59696 .01303 L
.60236 .00746 L
.60726 .00373 L
.60962 .00239 L
.61086 .0018 L
.61218 .00127 L
.61333 .00088 L
.61459 .00053 L
.61574 .00029 L
.61682 .00013 L
.61808 3e-05 L
.61871 0 L
.61941 0 L
.62065 7e-05 L
.62181 .00021 L
.62248 .00032 L
.62318 .00046 L
.62443 .00078 L
.62578 .00122 L
.62725 .00181 L
.62973 .00306 L
.63238 .00477 L
.63715 .00877 L
.64214 .01424 L
.64686 .02058 L
.6557 .03543 L
.67568 .08235 L
.69413 .13964 L
Mistroke
.7335 .29029 L
.77136 .44032 L
.79241 .512 L
.81166 .56404 L
.82118 .58388 L
.8262 .59264 L
.83155 .60059 L
.8367 .60686 L
.84136 .61136 L
.84361 .61312 L
.84604 .61473 L
.84835 .61596 L
.85045 .61683 L
.85159 .61721 L
.85283 .61753 L
.85414 .61779 L
.85538 .61795 L
.85653 .61802 L
.85776 .61802 L
.85881 .61796 L
.85997 .61782 L
.86063 .61771 L
.86132 .61756 L
.86256 .61724 L
.86535 .61622 L
.86777 .615 L
.87041 .61331 L
.87569 .60883 L
.88133 .60244 L
.89148 .58686 L
.90173 .56608 L
.91284 .53828 L
.933 .47576 L
.97393 .31822 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33679 L
.10458 .36655 L
.14415 .3935 L
.18221 .41806 L
.22272 .44232 L
.26171 .46343 L
.30316 .48306 L
.34309 .4989 L
.3815 .51104 L
.40095 .51596 L
.42237 .5204 L
.44268 .52363 L
.45178 .52477 L
.46172 .52578 L
.4671 .52624 L
.4721 .5266 L
.47727 .52691 L
.48196 .52714 L
.48658 .52731 L
.4887 .52737 L
.49093 .52743 L
.49332 .52747 L
.49438 .52749 L
.49552 .5275 L
.49675 .52751 L
.49789 .52752 L
.49859 .52752 L
.49925 .52752 L
.50049 .52752 L
.50163 .52752 L
.50286 .52752 L
.50401 .52751 L
.50508 .52749 L
.50754 .52746 L
.51014 .5274 L
.51268 .52733 L
.51504 .52726 L
.5204 .52703 L
.5293 .5265 L
.53882 .52574 L
.54906 .52467 L
.56016 .52324 L
.58032 .5199 L
.62123 .51028 L
.66064 .49756 L
.69852 .48232 L
.73886 .46313 L
.77769 .44209 L
.81897 .41733 L
Mistroke
.85873 .39158 L
.89697 .36547 L
.93767 .33671 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20178 .30902 L
.21267 .30902 L
.22272 .30902 L
.23293 .30902 L
.23832 .30902 L
.24402 .30902 L
.24641 .30902 L
.24897 .30902 L
.25119 .30902 L
.25361 .30902 L
.25507 .30902 L
.25643 .30902 L
.25773 .30902 L
.2584 .30902 L
.25912 .30902 L
.25983 .30902 L
.26048 .30902 L
.26176 .30902 L
.26293 .30902 L
.26416 .30902 L
.26538 .30902 L
.26607 .30902 L
.26671 .30902 L
.26912 .30902 L
.27131 .30902 L
.27364 .30902 L
.27847 .30902 L
.2838 .30902 L
.29326 .30902 L
.30213 .30902 L
.32232 .30902 L
.34082 .30902 L
.38045 .30902 L
.41855 .30902 L
.45912 .30902 L
.49816 .30902 L
.53966 .30902 L
.57964 .30902 L
.61811 .30902 L
.63759 .30902 L
.65902 .30902 L
.67938 .30902 L
.69843 .30902 L
.70884 .30902 L
.71396 .30902 L
Mistroke
.71872 .30902 L
.72301 .30902 L
.72758 .30902 L
.7302 .30902 L
.73148 .30902 L
.73266 .30902 L
.73371 .30902 L
.73487 .30902 L
.73603 .30902 L
.73725 .30902 L
.73856 .30902 L
.73977 .30902 L
.7404 .30902 L
.7411 .30902 L
.74251 .30902 L
.74375 .30902 L
.74508 .30902 L
.74748 .30902 L
.74985 .30902 L
.75235 .30902 L
.7568 .30902 L
.76198 .30902 L
.7668 .30902 L
.77773 .30902 L
.78828 .30902 L
.79823 .30902 L
.81683 .30902 L
.85534 .30902 L
.89632 .30902 L
.93577 .30902 L
.97371 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`8001Qoo`@006Yoo`@006Moo`00
<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol05Goo0`000Woo
0P00J7oo0P000goo0P00IGoo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04
Ool00`00Oomoo`0DOol00`00Oomoo`05Ool00`00Oomoo`1TOol00`00Oomoo`05Ool00`00Oomoo`1R
Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo01=oo`03
001oogoo00Moo`03001oogoo069oo`03001oogoo00Moo`03001oogoo065oo`00<Goo00<007ooOol0
17oo0P00ogoo8Goo00<007ooOol017oo0P0057oo00<007ooOol027oo00<007ooOol0H7oo00<007oo
Ool027oo00<007ooOol0HGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`0B
Ool00`00Oomoo`0:Ool00`00Oomoo`1NOol00`00Oomoo`0:Ool00`00Oomoo`1POol003Qoo`03001o
ogoo0?moobMoo`03001oogoo019oo`03001oogoo00]oo`03001oogoo05aoo`03001oogoo00]oo`03
001oogoo061oo`00>7oo0P00ogoo:7oo0P004Woo00<007ooOol037oo00<007ooOol0G7oo00<007oo
Ool037oo00<007ooOol0Ggoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0@Ool00`00Oomoo`0>
Ool00`00Oomoo`1JOol00`00Oomoo`0>Ool00`00Oomoo`1NOol003Qoo`03001oogoo0?moobMoo`03
001oogoo00moo`03001oogoo00moo`03001oogoo05Yoo`03001oogoo00ioo`03001oogoo05ioo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol03goo00<007ooOol047oo00<007ooOol0F7oo00<007oo
Ool047oo00<007ooOol0GGoo000hOol2003oOolXOol2000?Ool00`00Oomoo`0AOol00`00Oomoo`1H
Ool00`00Oomoo`0@Ool00`00Oomoo`1MOol003Qoo`03001oogoo0?moobMoo`03001oogoo00ioo`03
001oogoo019oo`03001oogoo05Ioo`03001oogoo019oo`03001oogoo05aoo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007oo
Ool0G7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0=Ool00`00Oomoo`0COol00`00Oomoo`1F
Ool00`00Oomoo`0COol00`00Oomoo`1KOol003Qoo`800?moobQoo`8000ioo`03001oogoo01Aoo`03
001oogoo05Aoo`03001oogoo01Aoo`03001oogoo05]oo`005goo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool03Goo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol057oo00<007ooOol0Fgoo000FOol0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00aoo`03
001oogoo01Ioo`03001oogoo05=oo`03001oogoo01Eoo`03001oogoo05Yoo`003Woo1P000Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000=Ool00`00Oomoo`0FOol00`00Oomoo`1BOol0
0`00Oomoo`0FOol00`00Oomoo`1JOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol02goo00<007ooOol05goo00<007ooOol0DWoo00<007ooOol05goo00<007ooOol0
FGoo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo00]oo`03001oogoo01Qoo`03001o
ogoo055oo`03001oogoo01Moo`03001oogoo05Uoo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo01moo`H008ioo`H004]oo`05001oogooOol0000?Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool00`00
Oomoo`0HOol00`00Oomoo`1IOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<0
07ooOol01Woo0P007Goo10001Goo1000Qgoo0`001Goo0P00BWoo00D007ooOomoo`0000]oo`05001o
ogooOol00004Ool00`00Oomoo`06Ool2000;Ool00`00Oomoo`0IOol00`00Oomoo`1@Ool00`00Oomo
o`0IOol00`00Oomoo`1HOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo01]oo`03001oogoo
00]oo`03001oogoo089oo`8000Yoo`<004Qoo`<000aoo`D000Aoo`@000Eoo`03001oogoo00Yoo`03
001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo05Qoo`00>7oo00<007ooOol0
6Woo00<007ooOol03Goo00<007ooOol0P7oo00<007ooOol03Goo00<007ooOol0IWoo00<007ooOol0
2Woo00<007ooOol06Woo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol0F7oo000hOol2000I
Ool2000AOol00`00Oomoo`1mOol2000AOol00`00Oomoo`1UOol2000:Ool00`00Oomoo`0KOol00`00
Oomoo`1>Ool00`00Oomoo`0KOol00`00Oomoo`1GOol003Qoo`03001oogoo01Moo`03001oogoo019o
o`03001oogoo07]oo`03001oogoo019oo`03001oogoo06Aoo`03001oogoo00Uoo`03001oogoo01ao
o`03001oogoo04eoo`03001oogoo01]oo`03001oogoo05Moo`00>7oo00<007ooOol05Woo00<007oo
Ool057oo00<007ooOol0NGoo00<007ooOol057oo00<007ooOol0Hgoo00<007ooOol02Goo00<007oo
Ool077oo00<007ooOol0CGoo00<007ooOol06goo00<007ooOol0Egoo000hOol00`00Oomoo`0EOol0
0`00Oomoo`0FOol00`00Oomoo`1gOol00`00Oomoo`0FOol00`00Oomoo`1ROol00`00Oomoo`09Ool0
0`00Oomoo`0LOol00`00Oomoo`1<Ool00`00Oomoo`0LOol00`00Oomoo`1GOol003Qoo`8001Eoo`03
001oogoo01Qoo`03001oogoo07Eoo`03001oogoo01Qoo`03001oogoo065oo`8000Uoo`03001oogoo
01ioo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo05Ioo`00>7oo00<007ooOol057oo00<0
07ooOol06Goo00<007ooOol0M7oo00<007ooOol067oo00<007ooOol0HGoo00<007ooOol027oo00<0
07ooOol07Woo00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol0EWoo000hOol00`00Oomoo`0C
Ool00`00Oomoo`0JOol00`00Oomoo`1cOol00`00Oomoo`0JOol00`00Oomoo`1POol00`00Oomoo`08
Ool00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`1FOol003Qoo`8001=o
o`03001oogoo01aoo`03001oogoo075oo`03001oogoo01aoo`03001oogoo05moo`8000Qoo`03001o
ogoo021oo`03001oogoo04Uoo`03001oogoo01moo`03001oogoo05Eoo`007goo0`001Woo0P001Goo
10001Goo00<007ooOol04Woo00<007ooOol07Goo00<007ooOol0L7oo00<007ooOol07Goo00<007oo
Ool0AGoo0`001Woo0P001Goo10001Goo00<007ooOol01goo00<007ooOol087oo00<007ooOol0BGoo
00<007ooOol07goo00<007ooOol0EGoo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0Woo00<007ooOol04Goo00<007ooOol07goo00<007ooOol0KWoo00<007ooOol07Woo00<007ooOol0
A7oo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo021o
o`03001oogoo04Qoo`03001oogoo021oo`03001oogoo05Eoo`005Woo1P000Woo00D007ooOomoo`00
011oo`03001oogoo009oo`03001oogoo011oo`03001oogoo021oo`03001oogoo06eoo`03001oogoo
021oo`03001oogoo03]oo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`0QOol00`00Oomoo`17Ool00`00Oomoo`0POol00`00Oomoo`1EOol001ioo`05001o
ogooOol0000@Ool00`00Oomoo`02Ool2000AOol00`00Oomoo`0QOol00`00Oomoo`1/Ool00`00Oomo
o`0QOol00`00Oomoo`12Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P001goo00<007ooOol0
8Woo00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol0E7oo000NOol01@00Oomoogoo000037oo
10001Goo00<007ooOol03goo00<007ooOol08goo00<007ooOol0JWoo00<007ooOol08Woo00<007oo
Ool0@Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo
04Ioo`03001oogoo029oo`03001oogoo05Aoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Io
o`03001oogoo00moo`03001oogoo02=oo`03001oogoo06Uoo`03001oogoo02Aoo`03001oogoo045o
o`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0ROol00`00Oomo
o`16Ool00`00Oomoo`0ROol00`00Oomoo`1DOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06
Ool00`00Oomoo`0>Ool00`00Oomoo`0UOol00`00Oomoo`1XOol00`00Oomoo`0TOol00`00Oomoo`11
Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol08goo00<007oo
Ool0AGoo00<007ooOol08Woo00<007ooOol0E7oo000OOol3000=Ool40005Ool2000>Ool00`00Oomo
o`0VOol00`00Oomoo`1WOol00`00Oomoo`0VOol00`00Oomoo`11Ool3000=Ool40005Ool20006Ool0
0`00Oomoo`0TOol00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`1COol003Qoo`03001oogoo
00eoo`03001oogoo02Moo`03001oogoo06Ioo`03001oogoo02Moo`03001oogoo05Uoo`03001oogoo
00Eoo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo05=oo`00>7oo00<0
07ooOol037oo00<007ooOol0:7oo00<007ooOol0IGoo00<007ooOol0:7oo00<007ooOol0FGoo00<0
07ooOol01Goo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol0Dgoo000h
Ool2000=Ool00`00Oomoo`0YOol00`00Oomoo`1SOol00`00Oomoo`0ZOol00`00Oomoo`1HOol20006
Ool00`00Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`1BOol003Qoo`03001o
ogoo00]oo`03001oogoo02Yoo`03001oogoo06=oo`03001oogoo02Yoo`03001oogoo05Qoo`03001o
ogoo00Aoo`03001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03001oogoo059oo`00>7oo
00<007ooOol02goo00<007ooOol0:goo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0Egoo
00<007ooOol017oo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol0DWoo
000hOol00`00Oomoo`0:Ool00`00Oomoo`0]Ool00`00Oomoo`1POol00`00Oomoo`0/Ool00`00Oomo
o`1GOol00`00Oomoo`04Ool00`00Oomoo`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomo
o`1BOol003Qoo`8000]oo`03001oogoo02eoo`03001oogoo05moo`03001oogoo02ioo`03001oogoo
05Ioo`8000Eoo`03001oogoo02Moo`03001oogoo045oo`03001oogoo02Moo`03001oogoo055oo`00
>7oo00<007ooOol02Goo00<007ooOol0;goo00<007ooOol0GWoo00<007ooOol0;Woo00<007ooOol0
EWoo00<007ooOol00goo00<007ooOol0:7oo00<007ooOol0@7oo00<007ooOol0:7oo00<007ooOol0
DGoo000hOol00`00Oomoo`08Ool00`00Oomoo`0`Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool00`00
Oomoo`1EOol00`00Oomoo`03Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00
Oomoo`1AOol003Qoo`8000Uoo`03001oogoo035oo`03001oogoo05aoo`03001oogoo035oo`03001o
ogoo05Aoo`8000Aoo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo055o
o`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol01goo00<007ooOol0<Woo00<007oo
Ool0G7oo00<007ooOol0<Goo00<007ooOol0<goo0`001Woo0P0017oo1@0017oo10001Goo00<007oo
Ool00goo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol0D7oo000FOol0
1@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Moo`03
001oogoo03=oo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo035oo`05001oogooOol00005
Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0:Woo00<0
07ooOol0?Woo00<007ooOol0:Woo00<007ooOol0D7oo000>Ool60002Ool01@00Oomoogoo00003Goo
00<007ooOol027oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0=7oo00<007ooOol0FWoo
00<007ooOol0<goo00<007ooOol0:Goo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03
001oogoo051oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000Mo
o`03001oogoo03Eoo`03001oogoo05Qoo`03001oogoo03Eoo`03001oogoo031oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`0ZOol00`00Oomoo`0nOol0
0`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005
Ool00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`1HOol00`00Oomoo`0eOol00`00Oomoo`0`
Ool01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00D007ooOomoo`0002ioo`03001oogoo
03eoo`03001oogoo02]oo`03001oogoo04moo`005Woo00D007ooOomoo`0000moo`03001oogoo009o
o`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo03Moo`03001oogoo05Ioo`03001oogoo03Mo
o`03001oogoo02moo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomo
ogoo0000;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo000FOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000Eoo`03001oogoo03Qoo`03001oogoo
05Ioo`03001oogoo03Moo`03001oogoo02moo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol01Woo0P000Woo00<007ooOol0;7oo00<007ooOol0?7oo00<007ooOol0;7oo00<007oo
Ool0Cgoo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`04Ool00`00Oomoo`0iOol00`00Oomo
o`1DOol00`00Oomoo`0iOol00`00Oomoo`0_Ool3000=Ool30005Ool40005Ool01@00Oomoogoo0000
;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo000hOol00`00Oomoo`03Ool00`00
Oomoo`0jOol00`00Oomoo`1DOol00`00Oomoo`0iOol00`00Oomoo`1@Ool01000Oomoo`00<7oo00<0
07ooOol0>goo00<007ooOol0;Goo00<007ooOol0CWoo000hOol00`00Oomoo`03Ool00`00Oomoo`0I
Ool30006Ool20004Ool5000>Ool00`00Oomoo`07Ool30006Ool20006Ool3000HOol30006Ool20005
Ool3000<Ool00`00Oomoo`0;Ool30006Ool20005Ool3000MOol01000Oomoogoo1@00BGoo00@007oo
Ool001ioo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<000moo`03001oogoo00Ioo`<000Io
o`8000Eoo`<001Eoo`04001oogooOol30006Ool20005Ool3000QOol5000DOol003Qoo`8000=oo`03
001oogoo01Uoo`05001oogooOol00005Ool20005Ool01000Oomoo`003Woo00<007ooOol01Woo00D0
07ooOomoo`0000Eoo`8000Moo`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool01@00Oomo
ogoo00002goo00<007ooOol02Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000LOol0
0`00Oomoo`03Ool00`00Oomoo`19Ool200000goo001oo`0LOol01@00Oomoogoo00001Goo0P001Goo
00@007oo000001Moo`05001oogooOol00005Ool20007Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool0
1@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Aoo`04001oogoo0003Ool00`00Oomoo`03
Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`02Ool00`00Oomo
o`0IOol01@00Oomoogoo00003Goo00<007ooOol03goo00<007ooOol01Goo00D007ooOomoo`0000]o
o`D001Moo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00<007ooOol02goo00D007ooOomo
o`0000]oo`05001oogooOol0000MOol00`00Oomoo`02Ool00`00Oomoo`19Ool01000Oomoo`007Goo
00D007ooOomoo`0000eoo`8001Qoo`05001oogooOol0000;Ool5000?Ool00`00Oomoo`05Ool01@00
Oomoogoo00002goo00D007ooOomoo`0001Eoo`03001oo`0000=oo`03001oogoo00Uoo`05001oogoo
Ool0000ROol00`00Oomoo`0DOol003Qoo`05001oogooOol0000LOol01@00Oomoogoo00003Woo00<0
07ooOol03Woo00<007ooOol01Goo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Yoo`03001oogoo00]oo`05001oogooOol0000;Ool01@00Oomoogoo
00007Goo00<007ooOol00Woo00<007ooOol0BGoo00<007oo00007Woo00D007ooOomoo`0000ioo`80
01Moo`05001oogooOol0000;Ool01000Oomoo`0047oo00<007ooOol01Goo00D007ooOomoo`0000]o
o`05001oogooOol0000EOol00`00Ool00003Ool00`00Oomoo`09Ool01@00Oomoogoo00008Woo00<0
07ooOol057oo000hOol01@00Oomoogoo000077oo00D007ooOomoo`0000moo`03001oogoo00ioo`03
001oogoo00Aoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10002Woo
00<007ooOol037oo00D007ooOomoo`0000aoo`<001ioo`03001oogoo009oo`03001oogoo04Uoo`03
001oo`0001ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo
00003goo00<007ooOol01Woo00D007ooOomoo`0000]oo`@001Ioo`03001oo`0000=oo`03001oogoo
00Yoo`<002=oo`03001oogoo01Aoo`00>7oo0P000Woo00<007ooOol06Woo00D007ooOomoo`0000mo
o`03001oogoo00ioo`03001oogoo00Aoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomo
ogoo00002goo00<007ooOol02goo00<007ooOol037oo00D007ooOomoo`0000]oo`05001oogooOol0
000NOol01@00Oomoogoo0000Bgoo0`007Woo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001o
ogooOol0000<Ool00`00Ool0000?Ool00`00Oomoo`06Ool01@00Oomoogoo00002goo00<007ooOol0
5goo00<007oo00000goo00<007ooOol02Goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo
00@007ooOol001eoo`05001oogooOol0000;Ool01@00Oomoogoo00004Goo00<007ooOol00goo00D0
07ooOomoo`0000eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool0
1@00Oomoogoo00002goo00D007ooOomoo`0001ioo`05001oogooOol0001;Ool00`00Ool0000NOol0
1@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000=Ool2000?Ool00`00Oomo
o`06Ool01@00Oomoogoo000037oo00<007ooOol05goo0P000goo00<007ooOol02Goo00D007ooOomo
o`00029oo`03001oogoo01Aoo`00>7oo00@007ooOol001ioo`<000eoo`<0019oo`03001oogoo00Ao
o`<000moo`03001oogoo01Moo`<000ioo`<000Qoo`03001oogoo00ioo`<000eoo`<0021oo`@004]o
o`80021oo`<000eoo`<00003Ool007oo01Ioo`<000moo`03001oogoo00aoo`03001oogoo00Qoo`<0
00ioo`<001Ioo`03001oo`00008000eoo`<0025oo`<001Ioo`00>7oo0`00AGoo00<007ooOol0BWoo
00<007ooOol0@Woo00<007ooOol0C7oo0P00=7oo00<007ooOol0=Woo00<007ooOol0<Woo00<007oo
Ool0C7oo000hOol00`00Ool00015Ool00`00Oomoo`1:Ool00`00Oomoo`13Ool00`00Oomoo`1;Ool2
000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`1<Ool003Qoo`8004Moo`03001oogoo
04Qoo`03001oogoo04Aoo`03001oogoo04]oo`8003Aoo`03001oogoo03Ioo`03001oogoo03=oo`03
001oogoo04]oo`00>7oo0P00Agoo00<007ooOol0B7oo00<007ooOol0AGoo00<007ooOol0BWoo00<0
07ooOol0=7oo00<007ooOol0=7oo00<007ooOol0=7oo00<007ooOol0Bgoo000bOooY0010OooY000@
Ool003Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Eoo`04001oogoo000:Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool01@00Oomoogoo00001Woo
00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol0BGoo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol057oo000hOol00`00Oomoo`18Ool00`00Oomo
o`14Ool00`00Oomoo`2DOol00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0eOol00`00Oomo
o`0cOol00`00Oomoo`0DOol003Qoo`8004Uoo`03001oogoo04Aoo`03001oogoo09Aoo`8003Ioo`03
001oogoo039oo`03001oogoo03Ioo`03001oogoo03=oo`03001oogoo01Aoo`00>7oo00<007ooOol0
BGoo00<007ooOol0@Woo00<007ooOol0UGoo00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0
=Woo00<007ooOol0<goo00<007ooOol057oo000hOol00`00Oomoo`19Ool00`00Oomoo`12Ool00`00
Oomoo`2EOol00`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00
Oomoo`0EOol003Qoo`03001oogoo04Yoo`03001oogoo041oo`03001oogoo09Ioo`03001oogoo03Eo
o`03001oogoo039oo`03001oogoo03Moo`03001oogoo035oo`03001oogoo01Eoo`00>7oo0P00Bgoo
00<007ooOol0@7oo00<007ooOol0UWoo0P00=goo00<007ooOol0<7oo00<007ooOol0>7oo00<007oo
Ool0<Goo00<007ooOol05Goo000hOol00`00Oomoo`1;Ool00`00Oomoo`0nOol00`00Oomoo`2GOol0
0`00Oomoo`0fOol00`00Oomoo`0`Ool00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`0FOol0
03Qoo`03001oogoo04]oo`03001oogoo03ioo`03001oogoo09Moo`03001oogoo03Ioo`03001oogoo
031oo`03001oogoo03Qoo`03001oogoo031oo`03001oogoo01Ioo`00>7oo00<007ooOol0C7oo00<0
07ooOol0?7oo00<007ooOol0V7oo00<007ooOol0=Woo00<007ooOol0<7oo00<007ooOol0>Goo00<0
07ooOol0;goo00<007ooOol05Woo000hOol2001=Ool00`00Oomoo`0lOol00`00Oomoo`2HOol2000h
Ool00`00Oomoo`0^Ool00`00Oomoo`0jOol00`00Oomoo`0_Ool00`00Oomoo`0FOol003Qoo`03001o
ogoo04aoo`03001oogoo03aoo`03001oogoo09Qoo`03001oogoo03Moo`03001oogoo02ioo`03001o
ogoo03Yoo`03001oogoo02ioo`03001oogoo01Moo`00>7oo00<007ooOol0CGoo00<007ooOol0>Woo
00<007ooOol0VGoo00<007ooOol0=goo00<007ooOol0;Woo00<007ooOol0>goo00<007ooOol0;Goo
00<007ooOol05goo000hOol2001>Ool00`00Oomoo`0jOol00`00Oomoo`2IOol2000hOol00`00Oomo
o`0^Ool00`00Oomoo`0kOol00`00Oomoo`0]Ool00`00Oomoo`0GOol001Moo`<000Ioo`8000Aoo`D0
00Aoo`@000Eoo`03001oogoo04ioo`03001oogoo03Qoo`03001oogoo07Uoo`<000Ioo`8000Aoo`D0
00Aoo`@000Eoo`03001oogoo03Qoo`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02eoo`03
001oogoo01Moo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02
Ool00`00Oomoo`1>Ool00`00Oomoo`0hOol00`00Oomoo`1hOol01@00Oomoogoo00001Goo0P001Goo
00@007ooOol000Qoo`03001oogoo009oo`03001oogoo03Qoo`03001oogoo02aoo`03001oogoo03ao
o`03001oogoo02aoo`03001oogoo01Qoo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo04moo`03001oogoo03Ioo`03001oogoo07Uoo`05001oogooOol0000=
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00Oomoo`0m
Ool00`00Oomoo`0[Ool00`00Oomoo`0HOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool2001@Ool00`00Oomoo`0fOol00`00Oomoo`1iOol01@00Oomoogoo00003Woo00<0
07ooOol01goo00<007ooOol00Woo0P00>Woo00<007ooOol0:Woo00<007ooOol0?Woo00<007ooOol0
:goo00<007ooOol067oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007oo
Ool0D7oo00<007ooOol0=7oo00<007ooOol0NWoo00D007ooOomoo`0000moo`03001oogoo009oo`@0
00Eoo`03001oogoo03Uoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo
01Uoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo051o
o`03001oogoo03Aoo`03001oogoo07Yoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00Oomo
o`0IOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00DWoo
00<007ooOol0<Woo00<007ooOol0Ngoo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool2000jOol00`00Oomoo`0ZOol00`00Oomoo`0oOol00`00Oomoo`0YOol00`00Oomoo`0I
Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo055oo`03001oogoo039oo`03001oogoo07ao
o`<000eoo`<000Eoo`@000Eoo`03001oogoo03Yoo`03001oogoo02Qoo`03001oogoo041oo`03001o
ogoo02Uoo`03001oogoo01Uoo`00>7oo00<007ooOol0DWoo00<007ooOol0<7oo00<007ooOol0WWoo
00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol0@7oo00<007ooOol0:7oo00<007ooOol06Woo
000hOol00`00Oomoo`1BOol00`00Oomoo`0_Ool00`00Oomoo`2OOol00`00Oomoo`0jOol00`00Oomo
o`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`0JOol003Qoo`8005=oo`03001oogoo
02moo`03001oogoo09moo`8003]oo`03001oogoo02Qoo`03001oogoo045oo`03001oogoo02Moo`03
001oogoo01Yoo`00>7oo00<007ooOol0Dgoo00<007ooOol0;Goo00<007ooOol0X7oo00<007ooOol0
>goo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol06goo000hOol00`00
Oomoo`1COol00`00Oomoo`0]Ool00`00Oomoo`2POol00`00Oomoo`0kOol00`00Oomoo`0VOol00`00
Oomoo`12Ool00`00Oomoo`0VOol00`00Oomoo`0KOol003Qoo`8005Eoo`03001oogoo02]oo`03001o
ogoo0:5oo`8003aoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01]o
o`00>7oo00<007ooOol0E7oo00<007ooOol0:goo00<007ooOol0XGoo00<007ooOol0>goo00<007oo
Ool09Woo00<007ooOol0@goo00<007ooOol09Goo00<007ooOol06goo000hOol00`00Oomoo`1EOol0
0`00Oomoo`0YOol00`00Oomoo`2ROol00`00Oomoo`0lOol00`00Oomoo`0TOol00`00Oomoo`14Ool0
0`00Oomoo`0TOol00`00Oomoo`0LOol003Qoo`03001oogoo05Ioo`03001oogoo02Qoo`03001oogoo
0:9oo`03001oogoo03aoo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo
01aoo`00>7oo0P00Egoo00<007ooOol09goo00<007ooOol0Xgoo0P00?Goo00<007ooOol097oo00<0
07ooOol0A7oo00<007ooOol097oo00<007ooOol077oo000OOol30006Ool20005Ool40005Ool00`00
Oomoo`1GOol00`00Oomoo`0UOol00`00Oomoo`2;Ool30006Ool20005Ool40005Ool00`00Oomoo`0l
Ool00`00Oomoo`0TOol00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`0LOol001ioo`05001o
ogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`1GOol00`00Oomoo`0UOol00`00Oomo
o`2:Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0?Goo00<007ooOol0
8Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol07Goo000NOol01@00Oomoogoo000047oo
00<007ooOol00Woo00<007ooOol0F7oo00<007ooOol08goo00<007ooOol0Rgoo00D007ooOomoo`00
011oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo029oo`03001oogoo04Ioo`03001oogoo
029oo`03001oogoo01eoo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`8005Yoo`03001o
ogoo029oo`03001oogoo08]oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000nOol00`00Oomo
o`0ROol00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`0MOol001ioo`05001oogooOol0000<
Ool40005Ool00`00Oomoo`1IOol00`00Oomoo`0QOol00`00Oomoo`2<Ool01@00Oomoogoo000037oo
10001Goo00<007ooOol0?Woo00<007ooOol08Goo00<007ooOol0Agoo00<007ooOol087oo00<007oo
Ool07Woo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0FWoo00<007ooOol0
7goo00<007ooOol0SGoo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo03ioo`03001o
ogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001oogoo01ioo`007Woo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`8005aoo`03001oogoo01eoo`03001oogoo08ioo`05001oogooOol0000<
Ool00`00Oomoo`06Ool2000oOol00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00
Oomoo`0NOol001moo`<000eoo`@000Eoo`03001oogoo05aoo`03001oogoo01aoo`03001oogoo08mo
o`<000eoo`@000Eoo`03001oogoo03moo`03001oogoo01moo`03001oogoo04Uoo`03001oogoo01mo
o`03001oogoo01ioo`00>7oo00<007ooOol0GGoo00<007ooOol06Woo00<007ooOol0ZGoo00<007oo
Ool0?goo00<007ooOol07Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol07goo000hOol0
0`00Oomoo`1NOol00`00Oomoo`0HOol00`00Oomoo`2ZOol00`00Oomoo`0oOol00`00Oomoo`0NOol0
0`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`0OOol003Qoo`8005moo`03001oogoo01Moo`03
001oogoo0:]oo`80045oo`03001oogoo01eoo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo
01moo`00>7oo00<007ooOol0Ggoo00<007ooOol05Goo00<007ooOol0[7oo00<007ooOol0@7oo00<0
07ooOol07Goo00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol07goo000hOol00`00Oomoo`1P
Ool00`00Oomoo`0COol00`00Oomoo`2]Ool00`00Oomoo`10Ool00`00Oomoo`0LOol00`00Oomoo`1<
Ool00`00Oomoo`0LOol00`00Oomoo`0POol003Qoo`80069oo`03001oogoo015oo`03001oogoo0:io
o`80049oo`03001oogoo01]oo`03001oogoo04eoo`03001oogoo01]oo`03001oogoo021oo`00>7oo
00<007ooOol0HWoo0`003goo00<007ooOol0[goo00<007ooOol0@Goo00<007ooOol06goo00<007oo
Ool0CGoo00<007ooOol06goo00<007ooOol087oo000hOol00`00Oomoo`1UOol00`00Oomoo`0:Ool2
002bOol00`00Oomoo`11Ool00`00Oomoo`0JOol00`00Oomoo`1>Ool00`00Oomoo`0JOol00`00Oomo
o`0QOol003Qoo`03001oogoo06Ioo`03001oogoo00Moo`800;Aoo`03001oogoo049oo`03001oogoo
01Uoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025oo`00>7oo0P00J7oo2@00]Woo0P00
@goo00<007ooOol06Goo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol08Goo000GOol30006
Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomo
o`04Ool40005Ool00`00Oomoo`12Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0IOol0
0`00Oomoo`0QOol001Ioo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol0@goo00<007ooOol05goo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol0
8Woo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo04=oo`03001o
ogoo01Moo`03001oogoo055oo`03001oogoo01Moo`03001oogoo029oo`005Woo00D007ooOomoo`00
00ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool20014Ool00`00Oomoo`0FOol00`00Oomoo`1BOol00`00Oomoo`0GOol0
0`00Oomoo`0ROol001Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3o
Ool5Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0A7oo00<007ooOol0
5Goo00<007ooOol0Dgoo00<007ooOol05Goo00<007ooOol08goo000FOol01@00Oomoogoo00003goo
00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo04Aoo`03001oogoo01Aoo`03001oogoo05Aoo`03001o
ogoo01Eoo`03001oogoo02=oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Io
o`8004Eoo`03001oogoo01Aoo`03001oogoo05Aoo`03001oogoo01Aoo`03001oogoo02Aoo`005goo
0`0037oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`0037oo1@0017oo10001Goo00<007ooOol0
AGoo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04goo00<007ooOol097oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`15Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol0
0`00Oomoo`0UOol003Qoo`03001oogoo0?moobMoo`03001oogoo04Ioo`03001oogoo015oo`03001o
ogoo05Ioo`03001oogoo019oo`03001oogoo02Eoo`00>7oo0P00ogoo:7oo0P00Agoo00<007ooOol0
47oo00<007ooOol0F7oo00<007ooOol047oo00<007ooOol09Woo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`17Ool00`00Oomoo`0?Ool00`00Oomoo`1IOol00`00Oomoo`0?Ool00`00Oomoo`0VOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo04Moo`03001oogoo00ioo`03001oogoo05]oo`03001o
ogoo00ioo`03001oogoo02Ioo`00>7oo0P00ogoo:7oo0P00BGoo00<007ooOol03Goo00<007ooOol0
Fgoo00<007ooOol03Goo00<007ooOol09goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`18Ool0
0`00Oomoo`0<Ool00`00Oomoo`1MOol00`00Oomoo`0<Ool00`00Oomoo`0WOol003Qoo`03001oogoo
0?moobMoo`03001oogoo04Qoo`03001oogoo00aoo`03001oogoo05eoo`03001oogoo00]oo`03001o
ogoo02Qoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0BGoo00<007ooOol02Woo00<007ooOol0
Ggoo00<007ooOol02Woo00<007ooOol0:7oo000hOol2003oOolXOol2001;Ool00`00Oomoo`08Ool0
0`00Oomoo`1POol00`00Oomoo`08Ool2000[Ool002moo`D000Aoo`03001oogoo0?mooaioo`D000Ao
o`03001oogoo04]oo`03001oogoo00Ioo`03001oogoo069oo`03001oogoo00Ioo`03001oogoo02]o
o`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0C7oo00<0
07ooOol017oo00<007ooOol0I7oo0P001Goo00<007ooOol0;7oo000aOol00`00Oomoo`04Ool2003o
OolQOol00`00Oomoo`04Ool2001>Ool6001XOol6000_Ool0035oo`03001oogoo0?moobMoo`03001o
ogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00
nGoo003oOoooOomFOol00?mooomooeIoo`00UGoo0`0000Aoo`00000001Qoo`<00?moo`Moo`<00004
Ool00000000IOol3001dOol009Ioo`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000ogoo
1goo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001aoo`03
001oogoo0?moo`Eoo`05001oogooOol0000HOol5001dOol009Ioo`05001oogooOol00009Ool6000=
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00002Goo1P002Goo00@007ooOol007Eoo`00UWoo00D0
07ooOomoo`0001Yoo`800?moo`Qoo`05001oogooOol0000IOol00`00Ool0001eOol009Eoo`D001eo
o`03001oogoo0?moo`Aoo`D001Yoo`03001oo`0007Eoo`00/goo00D007ooOomoo`000?moobIoo`80
07Eoo`00]7oo0`00ogoo:7oo00<007ooOol0Lgoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol002moo`D00?moobEoo`D00?Moo`00<Goo00<0
07ooOol0ogoo9goo00<007ooOol0mgoo000VOol60005Ool00`00Oomoo`3oOolLOol60005Ool00`00
Oomoo`3gOol0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<0
07ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomo
o`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Ao
o`800?moob5oo`03001oogoo00Aoo`800?5oo`00;goo0`001Woo00<007ooOol0ogoo7Woo0`001Woo
00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?mo
obMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol001Mo
o`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03
001oogoo00Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool000ioo`H0009oo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3lOol60002Ool01@00Oomoogoo00003Woo00<0
07ooOol01goo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001o
ogoo009oo`800?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo
0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05
001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomo
ogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool0
1@00Oomoogoo000017oo00<007ooOol01Woo0P00lGoo000GOol3000<Ool50004Ool40005Ool00`00
Oomoo`3oOol6Ool3000<Ool50004Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMo
o`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2
003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`3`Ool003Qoo`800?moobQoo`800?5oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo
3Woo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo
00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009o
o`03001oogoo0?1oo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`Io
o`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003aOol001ioo`05001oogooOol0000@
Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<0
07ooOol0l7oo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomo
o`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03
001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05
001oogooOol0000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol0
1Woo0P00lGoo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomo
o`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03
001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo
0P0017oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P0017oo1@0017oo10001Goo00<0
07ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009o
o`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol0
0Woo00<007ooOol0l7oo000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007oo
Ool00Woo0P00oGoo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`80
0?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?mo
o`Eoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Io
o`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003goo00<007ooOol00Woo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00003goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03
001oogoo00Ioo`800?5oo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo0`003Goo
0`001Goo10001Goo00<007ooOol0l7oo000hOol00`00Oomoo`0OOol30006Ool20004Ool5000HOol3
0006Ool20006Ool3000HOol30006Ool20005Ool3000JOol30006Ool20005Ool3000QOol50019Ool0
0`00Oomoo`0OOol30006Ool20004Ool5000HOol30006Ool20006Ool3000HOol30006Ool20005Ool3
000IOol30006Ool20005Ool3000QOol5000DOol003Qoo`8001moo`05001oogooOol00005Ool20005
Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo01Ioo`05001oogooOol0
0005Ool20004Ool01@00Oomoogoo000067oo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0
000ROol00`00Oomoo`19Ool2000OOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05
001oogooOol00005Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00D007oo
Oomoo`0001Moo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol057oo
000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol05goo00D007ooOomoo`0000]o
o`D001Moo`05001oogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001o
ogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol0
5goo00D007ooOomoo`0000]oo`D001Moo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D0
07ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05
001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol001Qoo`05001o
ogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogooOol0000ROol0
0`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomo
o`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogoo
Ool0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomo
ogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0
000;Ool4000IOol01@00Oomoogoo000037oo0`008goo00<007ooOol0BGoo00<007ooOol07Woo00D0
07ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomo
ogoo00002goo100067oo00D007ooOomoo`0000aoo`<002=oo`03001oogoo01Aoo`00>7oo0P007goo
00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00
Oomoogoo00002goo00<007ooOol06Woo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00
Oomoo`19Ool2000OOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03
001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007oo
Oomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000]oo`05001o
ogooOol0000GOol01@00Oomoogoo00003Goo0P0067oo00D007ooOomoo`0000aoo`03001oogoo01Uo
o`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol07Woo00D0
07ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00003Goo0P0067oo00D007ooOomo
o`0000aoo`03001oogoo01Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0
57oo000hOol00`00Oomoo`0OOol3000=Ool3000IOol3000?Ool00`00Oomoo`0GOol3000>Ool3000I
Ool3000=Ool3000QOol3001;Ool00`00Oomoo`0OOol3000=Ool3000IOol3000?Ool00`00Oomoo`0G
Ool3000>Ool3000HOol3000=Ool3000QOol3000FOol003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`03001oogoo0?moobMoo`03001oogoo0?1oo`00<Wooj@00@7ooj@0047oo000hOol00`00Ool00008
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Ool0001;
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`0DOol003Qoo`04001oogoo000XOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00
Oomoo`0ZOol00`00Oomoo`0VOol01000Oomoo`00Bgoo00<007ooOol0:Goo00<007ooOol0:Goo00<0
07ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol057oo000hOol01000Oomoogoo
0P00dWoo0P00Cgoo00<007ooOol0l7oo000hOol20004Ool00`00Oomoo`3>Ool00`00Oomoo`1?Ool2
003aOol003Qoo`03001oogoo00Aoo`03001oogoo0<aoo`03001oogoo051oo`03001oogoo0?1oo`00
>7oo00<007ooOol01Goo00<007ooOol0bWoo00<007ooOol0DGoo00<007ooOol0l7oo000hOol20007
Ool20038Ool2001DOol2003aOol003Qoo`03001oogoo00Qoo`03001oogoo0<=oo`8005Ioo`03001o
ogoo0?1oo`00>7oo00<007ooOol02Goo0P00`Woo00<007ooOol0EWoo00<007ooOol0l7oo000hOol0
0`00Oomoo`0;Ool00`00Oomoo`2mOol2001IOol00`00Oomoo`3`Ool003Qoo`8000eoo`03001oogoo
0;Yoo`8005]oo`800?5oo`00>7oo00<007ooOol03Goo0P00^Goo00<007ooOol0Fgoo00<007ooOol0
l7oo000hOol00`00Oomoo`0?Ool00`00Oomoo`2dOol2001NOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo011oo`800;=oo`03001oogoo05ioo`03001oogoo0?1oo`00>7oo0P004goo00<007ooOol0[Woo
0P00HGoo0P00lGoo000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`0COol2002]Ool0
0`00Oomoo`10Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogoo
Ool00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol05Goo00<007ooOol0
Z7oo0P00@Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00
Oomoo`3`Ool001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000GOol2
002WOol00`00Oomoo`12Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P00
lGoo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol067oo
00<007ooOol0XWoo0P00AGoo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03
001oogoo0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo01Uo
o`800:5oo`03001oogoo04Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomo
o`3`Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0K
Ool00`00Oomoo`2LOol20018Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol0l7oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Io
o`8001eoo`8009]oo`03001oogoo04Qoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<0
07ooOol01Woo0P00lGoo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`0NOol00`00Oomoo`2F
Ool2001<Ool3000=Ool30005Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo01moo`8009Eo
o`03001oogoo06eoo`03001oogoo0?1oo`00>7oo0P008Woo00<007ooOol0T7oo0P00L7oo0P00lGoo
000hOol00`00Oomoo`0ROol2002?Ool00`00Oomoo`1`Ool00`00Oomoo`3`Ool003Qoo`03001oogoo
02Aoo`8008]oo`8007=oo`03001oogoo0?1oo`00>7oo00<007ooOol09Woo0P00R7oo00<007ooOol0
Lgoo00<007ooOol0l7oo000hOol2000YOol00`00Oomoo`23Ool2001fOol2003aOol003Qoo`03001o
ogoo02Uoo`80089oo`03001oogoo07Ioo`03001oogoo0?1oo`00>7oo00<007ooOol0:goo0P00OWoo
0P00NGoo00<007ooOol0l7oo000hOol2000^Ool2001jOol2001kOol2003aOol003Qoo`03001oogoo
02moo`8007Ioo`8007eoo`03001oogoo0?1oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0
<Goo00<007ooOol0LWoo00<007ooOol0I7oo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000N
Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0<Woo0P00L7oo0P00IWoo
00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`007Woo00D007ooOomo
o`00011oo`03001oogoo009oo`8003Eoo`8006aoo`8006Qoo`05001oogooOol0000@Ool00`00Oomo
o`02Ool2003aOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0fOol2001W
Ool3001ZOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0l7oo000NOol01@00Oomo
ogoo000037oo10001Goo00<007ooOol0>7oo0P00Hgoo0P00KGoo00D007ooOomoo`0000aoo`@000Eo
o`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo03Yoo`80
05ioo`<006moo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool2000mOol2001JOol2001bOol01@00Oomoogoo000037oo00<0
07ooOol01Woo0P00lGoo000OOol3000=Ool40005Ool00`00Oomoo`0nOol3001EOol2001eOol3000=
Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo045oo`<0051oo`80091oo`03001oogoo0?1o
o`00>7oo0P00AGoo0`00Bgoo0P00TWoo0P00lGoo000hOol00`00Oomoo`17Ool30015Ool3002DOol0
0`00Oomoo`3`Ool003Qoo`03001oogoo04Yoo`<003moo`<009Moo`03001oogoo0?1oo`00>7oo00<0
07ooOol0CGoo0`00>Goo0`00VWoo00<007ooOol0l7oo000hOol2001AOol3000bOol4002MOol2003a
Ool003Qoo`03001oogoo05=oo`D002Qoo`D00:5oo`03001oogoo0?1oo`00>7oo00<007ooOol0F7oo
1@007goo1000YWoo00<007ooOol0l7oo000hOol2001NOol7000?Ool9002ZOol2003aOol001Moo`<0
00Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo06Aoo`l0099oo`<000Ioo`8000Ioo`03
001oogoo00Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80
0?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05
001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0
000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo
00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00002goo00D0
07ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000;Ool01@00
Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0l7oo000GOol3000<Ool50004Ool40005Ool2
003oOol7Ool3000<Ool50004Ool40005Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qo
o`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`800?moobQoo`800?5oo`00;goo1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo
000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035o
o`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<0
07ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00
Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo
00<007ooOol0mgoo000_Ool3003oOolWOol3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3
000017oo0000000067oo1@00ogoo1Goo0`0000Aoo`00000001Moo`D007Aoo`00UWoo00D007ooOomo
o`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000:Ool01000Oomoo`00
M7oo002FOol01@00Oomoogoo00006goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001Yoo`03001o
ogoo07Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol0
0009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool0
1@00Oomoogoo000077oo00<007ooOol0LWoo002EOol5000LOol00`00Oomoo`3oOol5Ool5000MOol0
0`00Oomoo`1bOol00;Ioo`03001oogoo0?moob=oo`05001oogooOol0001dOol00;Aoo`<00?moobIo
o`<007Eoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomF
Ool00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .19937 L
.08255 .14763 L
.10458 .09833 L
.12507 .06139 L
.14415 .03608 L
.14918 .03099 L
.15465 .02625 L
.15946 .02275 L
.16457 .01976 L
.16917 .01769 L
.17178 .01679 L
.17423 .01612 L
.17538 .01586 L
.17647 .01565 L
.17746 .01549 L
.17852 .01536 L
.17967 .01524 L
.18073 .01517 L
.182 .01513 L
.18314 .01513 L
.18435 .01517 L
.18547 .01525 L
.1867 .01537 L
.18802 .01556 L
.19071 .01609 L
.19317 .01675 L
.1979 .01852 L
.20239 .02078 L
.21236 .02783 L
.22321 .03861 L
.24299 .06615 L
.26399 .10554 L
.30174 .19697 L
.34195 .31099 L
.38063 .42063 L
.40028 .47106 L
.42177 .51916 L
.44253 .55666 L
.4614 .58173 L
.47149 .59129 L
.47611 .59474 L
.48101 .59773 L
.4835 .599 L
.48624 .60019 L
.48876 .60109 L
.49106 .60176 L
.49378 .60235 L
.49527 .60259 L
.49596 .60267 L
Mistroke
.49669 .60275 L
.498 .60285 L
.49921 .6029 L
.49996 .60291 L
.50065 .6029 L
.50196 .60285 L
.50313 .60277 L
.50438 .60263 L
.50556 .60247 L
.50663 .60228 L
.50926 .60168 L
.51175 .60093 L
.5167 .59891 L
.52208 .59592 L
.53169 .58858 L
.54056 .57955 L
.55926 .5538 L
.57988 .51577 L
.62014 .41855 L
.65888 .30859 L
.70007 .19212 L
.72063 .14003 L
.73974 .09784 L
.75939 .06234 L
.77791 .03735 L
.78775 .02774 L
.79293 .02374 L
.7984 .02034 L
.80302 .01812 L
.80546 .01719 L
.80809 .01639 L
.8105 .01582 L
.8127 .01545 L
.81375 .01532 L
.81491 .01522 L
.81599 .01516 L
.817 .01513 L
.81818 .01513 L
.81941 .01518 L
.82047 .01525 L
.82163 .01537 L
.82287 .01555 L
.82421 .01578 L
.82661 .01633 L
.82905 .01705 L
.83134 .01789 L
.83564 .01987 L
.84078 .02292 L
.84552 .02638 L
.85624 .0365 L
Mistroke
.87498 .06146 L
.89561 .09871 L
.93591 .19496 L
.97471 .3047 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .18702 L
.08255 .13407 L
.0932 .1108 L
.10458 .09023 L
.11009 .08202 L
.11531 .07535 L
.12038 .06993 L
.12507 .06587 L
.12951 .06288 L
.13178 .06168 L
.13422 .06064 L
.13549 .0602 L
.13666 .05985 L
.13784 .05956 L
.13895 .05935 L
.14022 .05917 L
.1409 .0591 L
.14161 .05905 L
.1423 .05902 L
.14295 .05902 L
.14415 .05905 L
.14531 .05915 L
.14656 .05932 L
.14773 .05953 L
.14881 .05979 L
.15143 .06061 L
.15392 .06167 L
.15886 .06457 L
.16423 .06889 L
.17383 .0796 L
.1827 .09278 L
.20137 .12989 L
.22197 .18329 L
.26217 .3099 L
.30086 .43193 L
.32051 .48363 L
.3309 .50645 L
.342 .52672 L
.35275 .54191 L
.35784 .54748 L
.36253 .55166 L
.36724 .55494 L
.36972 .55628 L
.37235 .55741 L
.37463 .55815 L
.37573 .55842 L
.37677 .55864 L
.37799 .55883 L
.37911 .55894 L
Mistroke
.38031 .55901 L
.38162 .55901 L
.38227 .55898 L
.38296 .55893 L
.38419 .55879 L
.38551 .55857 L
.38695 .55823 L
.38955 .55741 L
.39197 .55638 L
.39649 .55378 L
.40134 .55003 L
.40698 .54442 L
.41232 .53791 L
.42232 .52269 L
.44227 .48156 L
.4607 .43291 L
.50002 .30895 L
.53782 .18936 L
.55884 .13385 L
.56803 .11355 L
.57808 .09466 L
.58722 .08075 L
.59696 .06956 L
.60236 .06505 L
.60726 .06204 L
.60962 .06095 L
.61086 .06047 L
.61218 .06004 L
.61333 .05973 L
.61459 .05945 L
.61574 .05925 L
.61682 .05913 L
.61808 .05904 L
.61871 .05902 L
.61941 .05902 L
.62065 .05907 L
.62181 .05918 L
.62248 .05927 L
.62318 .05939 L
.62443 .05965 L
.62578 .06 L
.62725 .06048 L
.62973 .0615 L
.63238 .06287 L
.63715 .06611 L
.64214 .07053 L
.64686 .07566 L
.6557 .08768 L
.67568 .12564 L
.69413 .17199 L
Mistroke
.7335 .29387 L
.77136 .41524 L
.79241 .47323 L
.81166 .51534 L
.82118 .53139 L
.8262 .53847 L
.83155 .5449 L
.8367 .54998 L
.84136 .55361 L
.84361 .55504 L
.84604 .55634 L
.84835 .55734 L
.85045 .55804 L
.85159 .55835 L
.85283 .55861 L
.85414 .55882 L
.85538 .55895 L
.85653 .55901 L
.85776 .55901 L
.85881 .55896 L
.85997 .55884 L
.86063 .55875 L
.86132 .55864 L
.86256 .55838 L
.86535 .55755 L
.86777 .55656 L
.87041 .5552 L
.87569 .55157 L
.88133 .5464 L
.89148 .5338 L
.90173 .51699 L
.91284 .49449 L
.933 .44391 L
.97393 .31646 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .3321 L
.10458 .35684 L
.14415 .37924 L
.18221 .39966 L
.22272 .41982 L
.26171 .43737 L
.30316 .45369 L
.34309 .46686 L
.3815 .47695 L
.40095 .48104 L
.42237 .48473 L
.44268 .48742 L
.45178 .48836 L
.46172 .48921 L
.4671 .48958 L
.4721 .48988 L
.47727 .49014 L
.48196 .49033 L
.48658 .49047 L
.4887 .49053 L
.49093 .49057 L
.49332 .49061 L
.49438 .49062 L
.49552 .49063 L
.49675 .49064 L
.49789 .49065 L
.49859 .49065 L
.49925 .49065 L
.50049 .49065 L
.50163 .49065 L
.50286 .49064 L
.50401 .49064 L
.50508 .49063 L
.50754 .4906 L
.51014 .49055 L
.51268 .49049 L
.51504 .49043 L
.5204 .49024 L
.5293 .4898 L
.53882 .48917 L
.54906 .48828 L
.56016 .48709 L
.58032 .48432 L
.62123 .47632 L
.66064 .46574 L
.69852 .45308 L
.73886 .43713 L
.77769 .41963 L
.81897 .39905 L
Mistroke
.85873 .37765 L
.89697 .35594 L
.93767 .33204 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28494 L
.10458 .26051 L
.14415 .24092 L
.18221 .22642 L
.20178 .22094 L
.21267 .21852 L
.22272 .2167 L
.23293 .21526 L
.23832 .21468 L
.24402 .21419 L
.24641 .21402 L
.24897 .21387 L
.25119 .21376 L
.25361 .21367 L
.25507 .21362 L
.25643 .21359 L
.25773 .21356 L
.2584 .21355 L
.25912 .21354 L
.25983 .21353 L
.26048 .21353 L
.26176 .21353 L
.26293 .21353 L
.26416 .21354 L
.26538 .21355 L
.26607 .21356 L
.26671 .21357 L
.26912 .21363 L
.27131 .21371 L
.27364 .21381 L
.27847 .2141 L
.2838 .21452 L
.29326 .21556 L
.30213 .21687 L
.32232 .22101 L
.34082 .22618 L
.38045 .24127 L
.41855 .26014 L
.45912 .28357 L
.49816 .30786 L
.53966 .33372 L
.57964 .35691 L
.61811 .37612 L
.63759 .38428 L
.65902 .39181 L
.67938 .39743 L
.69843 .40126 L
.70884 .40273 L
.71396 .4033 L
Mistroke
.71872 .40373 L
.72301 .40404 L
.72758 .40428 L
.7302 .40438 L
.73148 .40442 L
.73266 .40445 L
.73371 .40447 L
.73487 .40449 L
.73603 .4045 L
.73725 .40451 L
.73856 .40451 L
.73977 .4045 L
.7404 .4045 L
.7411 .40449 L
.74251 .40447 L
.74375 .40444 L
.74508 .40441 L
.74748 .40433 L
.74985 .40422 L
.75235 .40409 L
.7568 .40378 L
.76198 .40332 L
.7668 .4028 L
.77773 .40126 L
.78828 .39932 L
.79823 .39709 L
.81683 .39191 L
.85534 .37734 L
.89632 .35704 L
.93577 .33418 L
.97371 .31058 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P0087oo1`00
Rgoo2000IWoo00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`0LOol30007Ool20028
Ool00`00Oomoo`06Ool2001ROol30006Ool00`00Oomoo`3`Ool003Qoo`03001oogoo01]oo`03001o
ogoo00Yoo`03001oogoo08Aoo`03001oogoo00Uoo`03001oogoo06Qoo`03001oogoo0?1oo`00>7oo
0P006goo00<007ooOol037oo00<007ooOol0PWoo00<007ooOol02goo00<007ooOol0Igoo0P00lGoo
000hOol00`00Oomoo`0JOol00`00Oomoo`0=Ool00`00Oomoo`20Ool00`00Oomoo`0=Ool00`00Oomo
o`1VOol00`00Oomoo`3`Ool003Qoo`03001oogoo01Uoo`03001oogoo00moo`03001oogoo07ioo`03
001oogoo00moo`03001oogoo06Eoo`03001oogoo0?1oo`00>7oo00<007ooOol067oo00<007ooOol0
47oo00<007ooOol0OWoo00<007ooOol03goo00<007ooOol0IGoo00<007ooOol0l7oo000hOol2000H
Ool00`00Oomoo`0BOol00`00Oomoo`1lOol00`00Oomoo`0AOol00`00Oomoo`1TOol2003aOol003Qo
o`03001oogoo01Ioo`03001oogoo01Aoo`03001oogoo07Yoo`03001oogoo01=oo`03001oogoo06=o
o`03001oogoo0?1oo`00>7oo00<007ooOol05Goo00<007ooOol05Woo00<007ooOol0N7oo00<007oo
Ool05Goo00<007ooOol0HWoo00<007ooOol0l7oo000hOol00`00Oomoo`0DOol00`00Oomoo`0GOol0
0`00Oomoo`1gOol00`00Oomoo`0GOol00`00Oomoo`1QOol00`00Oomoo`0FOol6001YOol5001VOol0
03Qoo`8001Eoo`03001oogoo01Qoo`03001oogoo07Eoo`03001oogoo01Qoo`03001oogoo065oo`80
01Eoo`8000Ioo`03001oogoo06Aoo`8000Eoo`03001oogoo06=oo`005goo0`001Woo0P001Woo00<0
07ooOol017oo10001Goo00<007ooOol04goo00<007ooOol06Woo00<007ooOol0M7oo00<007ooOol0
6Goo00<007ooOol0?goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol04goo00<0
07ooOol01goo00<007ooOol0HWoo00<007ooOol01Woo00<007ooOol0HWoo000FOol01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol04goo00<007ooOol06Woo
00<007ooOol0Lgoo00<007ooOol06Woo00<007ooOol0?Woo00D007ooOomoo`0000Eoo`8000Ioo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo061oo`03
001oogoo00Qoo`03001oogoo065oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`8001=oo`03001oogoo01aoo`03001oogoo079oo`03001oogoo01]oo`03001o
ogoo03Eoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000COol0
0`00Oomoo`0:Ool00`00Oomoo`1NOol00`00Oomoo`0:Ool00`00Oomoo`1POol001Ioo`05001oogoo
Ool0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`0LOol00`00
Oomoo`1aOol00`00Oomoo`0MOol00`00Oomoo`0lOol01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol04Goo00<007ooOol037oo00<007ooOol0G7oo00<007ooOol02goo
00<007ooOol0H7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0
4Woo00<007ooOol07Goo00<007ooOol0L7oo00<007ooOol07Goo00<007ooOol0?7oo00D007ooOomo
o`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo011oo`03001oogoo00eoo`03001oogoo05ao
o`03001oogoo00aoo`03001oogoo05moo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo015oo`03001oogoo01moo`03001oogoo06ioo`03001oogoo01moo`03
001oogoo03]oo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0?
Ool00`00Oomoo`0?Ool00`00Oomoo`1JOol00`00Oomoo`0>Ool00`00Oomoo`1NOol001Ioo`05001o
ogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P004Woo00<007ooOol07goo00<0
07ooOol0KWoo00<007ooOol07goo00<007ooOol0>goo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool2000@Ool00`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0?Ool0
0`00Oomoo`1NOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo011oo`03001oogoo025oo`03
001oogoo06aoo`03001oogoo025oo`03001oogoo03]oo`<000aoo`D000Aoo`@000Eoo`03001oogoo
00ioo`03001oogoo015oo`03001oogoo05Qoo`03001oogoo011oo`03001oogoo05eoo`00>7oo00<0
07ooOol047oo00<007ooOol08Goo00<007ooOol0K7oo00<007ooOol08Goo00<007ooOol0G7oo00<0
07ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0G7oo000h
Ool2000@Ool00`00Oomoo`0SOol00`00Oomoo`1ZOol00`00Oomoo`0SOol00`00Oomoo`1KOol2000?
Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol00`00Oomoo`1LOol003Qoo`03001o
ogoo00moo`03001oogoo02=oo`03001oogoo06Yoo`03001oogoo02=oo`03001oogoo05]oo`03001o
ogoo00eoo`03001oogoo01Aoo`03001oogoo05Eoo`03001oogoo01=oo`03001oogoo05]oo`00>7oo
00<007ooOol03Woo00<007ooOol09Goo00<007ooOol0J7oo00<007ooOol097oo00<007ooOol0Fgoo
00<007ooOol03Goo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol057oo00<007ooOol0Fgoo
000hOol00`00Oomoo`0>Ool00`00Oomoo`0UOol00`00Oomoo`1XOol00`00Oomoo`0UOol00`00Oomo
o`1JOol00`00Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomoo`1COol00`00Oomoo`0EOol00`00Oomo
o`1JOol003Qoo`8000ioo`03001oogoo02Ioo`03001oogoo06Moo`03001oogoo02Ioo`03001oogoo
05Yoo`8000aoo`03001oogoo01Moo`03001oogoo059oo`03001oogoo01Moo`03001oogoo05Uoo`00
>7oo00<007ooOol03Goo00<007ooOol09goo00<007ooOol0IWoo00<007ooOol09goo00<007ooOol0
FGoo00<007ooOol02goo00<007ooOol067oo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol0
FGoo000hOol00`00Oomoo`0=Ool00`00Oomoo`0WOol00`00Oomoo`1UOol00`00Oomoo`0XOol00`00
Oomoo`1IOol00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00
Oomoo`1HOol003Qoo`8000eoo`03001oogoo02Qoo`03001oogoo06Eoo`03001oogoo02Qoo`03001o
ogoo05Uoo`8000]oo`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo05Qo
o`007goo0`001Woo0P001Goo10001Goo00<007ooOol037oo00<007ooOol0:Goo00<007ooOol0Hgoo
00<007ooOol0:Woo00<007ooOol0?goo0`001Woo0P001Goo10001Goo00<007ooOol02Woo00<007oo
Ool06Woo00<007ooOol0CWoo00<007ooOol06Woo00<007ooOol0F7oo000NOol01@00Oomoogoo0000
1Goo0P002Goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol0:Woo00<007ooOol0Hgoo00<0
07ooOol0:Woo00<007ooOol0?Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001o
ogoo00Uoo`03001oogoo01]oo`03001oogoo04ioo`03001oogoo01]oo`03001oogoo05Moo`005Woo
1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo00]oo`03001oogoo02]oo`03
001oogoo065oo`03001oogoo02aoo`03001oogoo03Eoo`H0009oo`05001oogooOol0000@Ool00`00
Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0LOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00
Oomoo`1GOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000;Ool00`00Oomoo`0/Ool0
0`00Oomoo`1QOol00`00Oomoo`0/Ool00`00Oomoo`0mOol01@00Oomoogoo000047oo00<007ooOol0
0Woo0P002Woo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol0Egoo000N
Ool01@00Oomoogoo000037oo10001Goo00<007ooOol02Woo00<007ooOol0;7oo00<007ooOol0HGoo
00<007ooOol0;Goo00<007ooOol0?7oo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo00Qoo`03
001oogoo01ioo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo05Ioo`007Woo00D007ooOomo
o`0000aoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo02eoo`03001oogoo05moo`03001o
ogoo02ioo`03001oogoo03aoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`1FOol001ioo`05001oogoo
Ool0000<Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0^Ool00`00Oomoo`1OOol00`00
Oomoo`0^Ool00`00Oomoo`0lOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol027oo
00<007ooOol07Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000OOol3000=Ool4
0005Ool2000:Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool00`00Oomoo`0lOol3
000=Ool40005Ool20008Ool00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomo
o`1EOol003Qoo`03001oogoo00Qoo`03001oogoo031oo`03001oogoo05eoo`03001oogoo031oo`03
001oogoo05Eoo`03001oogoo00Moo`03001oogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03
001oogoo05Eoo`00>7oo00<007ooOol027oo00<007ooOol0<7oo00<007ooOol0GGoo00<007ooOol0
<Goo00<007ooOol0E7oo00<007ooOol01goo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol0
87oo00<007ooOol0EGoo000hOol20008Ool00`00Oomoo`0bOol00`00Oomoo`1LOol00`00Oomoo`0a
Ool00`00Oomoo`1DOol20007Ool00`00Oomoo`0ROol00`00Oomoo`17Ool00`00Oomoo`0QOol00`00
Oomoo`1DOol003Qoo`03001oogoo00Moo`03001oogoo039oo`03001oogoo05]oo`03001oogoo039o
o`03001oogoo05Aoo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo04Ioo`03001oogoo029o
o`03001oogoo05Aoo`00>7oo00<007ooOol01goo00<007ooOol0<Woo00<007ooOol0Fgoo00<007oo
Ool0<goo00<007ooOol0Dgoo00<007ooOol01Woo00<007ooOol08Woo00<007ooOol0AWoo00<007oo
Ool08Woo00<007ooOol0E7oo000hOol00`00Oomoo`06Ool00`00Oomoo`0dOol00`00Oomoo`1JOol0
0`00Oomoo`0cOol00`00Oomoo`1COol00`00Oomoo`06Ool00`00Oomoo`0SOol00`00Oomoo`15Ool0
0`00Oomoo`0SOol00`00Oomoo`1COol003Qoo`8000Moo`03001oogoo03Aoo`03001oogoo05Uoo`03
001oogoo03Eoo`03001oogoo059oo`8000Ioo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo
02Aoo`03001oogoo05=oo`00>7oo00<007ooOol01Goo00<007ooOol0=Woo00<007ooOol0F7oo00<0
07ooOol0=Goo00<007ooOol0DWoo00<007ooOol01Goo00<007ooOol097oo00<007ooOol0A7oo00<0
07ooOol097oo00<007ooOol0Dgoo000hOol00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`1H
Ool00`00Oomoo`0eOol00`00Oomoo`1BOol00`00Oomoo`05Ool00`00Oomoo`0UOol00`00Oomoo`13
Ool00`00Oomoo`0UOol00`00Oomoo`1BOol003Qoo`8000Ioo`03001oogoo03Ioo`03001oogoo05Mo
o`03001oogoo03Moo`03001oogoo055oo`8000Eoo`03001oogoo02Ioo`03001oogoo049oo`03001o
ogoo02Ioo`03001oogoo059oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol017oo
00<007ooOol0>7oo00<007ooOol0EWoo00<007ooOol0=goo00<007ooOol0<7oo0`001Woo0P0017oo
1@0017oo10001Goo00<007ooOol017oo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo
00<007ooOol0DWoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo
009oo`03001oogoo00Aoo`03001oogoo03Qoo`03001oogoo05Ioo`03001oogoo03Moo`03001oogoo
02moo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol09goo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol0DGoo000>Ool60002
Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool0>Goo00<007ooOol0E7oo00<007ooOol0>Goo00<007ooOol09Woo1P000Woo00D007ooOomoo`00
00eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo
041oo`03001oogoo02Qoo`03001oogoo055oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`8000Aoo`03001oogoo03Yoo`03001oogoo05Aoo`03001oogoo03Uoo`03001o
ogoo02ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20004Ool00`00Oomo
o`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`1AOol001Ioo`05001oogooOol0000?
Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`03Ool00`00Oomoo`0jOol00`00Oomoo`1COol00`00
Oomoo`0jOol00`00Oomoo`0^Ool01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007oo
Ool00goo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol0D7oo000FOol0
1@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0
>goo00<007ooOol0DWoo00<007ooOol0>goo00<007ooOol0;Goo00D007ooOomoo`0000moo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03ioo`03001o
ogoo02Yoo`03001oogoo051oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool20003Ool00`00Oomoo`0lOol00`00Oomoo`1BOol00`00Oomoo`0kOol00`00Oomoo`0]
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000=oo`03001oogoo
02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo051oo`005goo0`003Goo0`001Goo1000
1Goo00<007ooOol00Woo00<007ooOol0?7oo00<007ooOol0DGoo00<007ooOol0?7oo00<007ooOol0
;Woo0`003Goo0`001Goo10001Goo00<007ooOol00Woo00<007ooOol0:goo00<007ooOol0?Goo00<0
07ooOol0:goo00<007ooOol0Cgoo000hOol00`00Oomoo`02Ool00`00Oomoo`0mOol00`00Oomoo`1@
Ool00`00Oomoo`0mOol00`00Oomoo`1>Ool01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007oo
Ool0;7oo00<007ooOol0Cgoo000hOol01@00Oomoogoo00007Goo0`001Woo0P0017oo1@003goo00<0
07ooOol01Woo0`001Woo0P001Woo0`0067oo0`001Woo0P001Goo0`002goo00<007ooOol037oo0`00
1Woo0P001Goo0`007Woo00<007ooOol01@00BGoo00D007ooOomoo`0001eoo`<000Ioo`8000Aoo`D0
01Qoo`<000Ioo`8000Ioo`<0011oo`03001oogoo00Eoo`<000Ioo`8000Eoo`<001Aoo`03001oogoo
009oo`<000Ioo`8000Eoo`<0025oo`D001Aoo`00>7oo0P000Woo00<007ooOol06Woo00D007ooOomo
o`0000Eoo`8000Eoo`04001oogoo000@Ool00`00Oomoo`04Ool01@00Oomoogoo00001Goo0P001goo
00<007ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol00009Ool00`00Oomoo`0<
Ool01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001eoo`03001oogoo009oo`03001oogoo
04Uoo`80009oo`03001oogoo01Yoo`05001oogooOol00005Ool20005Ool200000goo001oo`0FOol0
1@00Oomoogoo00001Goo0P001goo00<007ooOol03goo00<007ooOol017oo00D007ooOomoo`0000Eo
o`8000Aoo`05001oogooOol0000DOol01000Oomoo`000goo00<007ooOol00goo0P0017oo00D007oo
Oomoo`00029oo`03001oogoo01Aoo`00>7oo00D007ooOomoo`0001aoo`05001oogooOol0000=Ool0
0`00Oomoo`0@Ool00`00Oomoo`04Ool01@00Oomoogoo00002goo1@005goo00D007ooOomoo`0000]o
o`05001oogooOol00009Ool00`00Oomoo`0<Ool01@00Oomoogoo00002goo00D007ooOomoo`0001io
o`05001oogooOol0001;Ool01000Oomoo`007Goo00D007ooOomoo`0000eoo`8001Qoo`05001oogoo
Ool0000;Ool5000?Ool00`00Oomoo`05Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Aoo`04
001oogoo0003Ool00`00Oomoo`09Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol01000
Oomoo`007Goo00D007ooOomoo`0000ioo`03001oogoo00moo`03001oogoo00Aoo`05001oogooOol0
000;Ool01000Oomoo`0067oo00D007ooOomoo`0000]oo`05001oogooOol00009Ool00`00Oomoo`0<
Ool01@00Oomoogoo00002goo00D007ooOomoo`0001ioo`05001oogooOol0001;Ool01000Oomoo`00
7Goo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000Oomoo`0047oo
00<007ooOol01Goo00D007ooOomoo`0000]oo`05001oogooOol0000DOol01000Oomoo`000goo00<0
07ooOol02Goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00@007ooOol001eoo`05001o
ogooOol0000?Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool01@00Oomoogoo000037oo00<007oo0000
67oo00D007ooOomoo`0000]oo`@000Uoo`03001oogoo00eoo`05001oogooOol0000<Ool3000OOol0
1@00Oomoogoo0000Bgoo00@007ooOol001eoo`05001oogooOol0000>Ool2000GOol01@00Oomoogoo
000037oo00<007oo000047oo00<007ooOol01Goo00D007ooOomoo`0000]oo`@001Ioo`03001oo`00
00=oo`03001oogoo00Yoo`<002=oo`03001oogoo01Aoo`00>7oo0P0000=oo`00Ool077oo00D007oo
Oomoo`0000moo`03001oogoo00moo`03001oogoo00=oo`05001oogooOol0000<Ool00`00Ool0000H
Ool01@00Oomoogoo00002goo00<007ooOol02Woo00<007ooOol03Goo00D007ooOomoo`0000]oo`05
001oogooOol0000OOol01000Oomoo`00Bgoo0`007Woo00D007ooOomoo`0000moo`03001oogoo01Eo
o`05001oogooOol0000<Ool00`00Ool0000?Ool00`00Oomoo`06Ool01@00Oomoogoo00002goo00<0
07ooOol05goo00<007oo00000goo00<007ooOol02Goo00D007ooOomoo`00029oo`03001oogoo01Ao
o`00>7oo00<007oo00007Woo00D007ooOomoo`0000]oo`05001oogooOol0000BOol00`00Oomoo`02
Ool01@00Oomoogoo00003Goo0P0067oo00D007ooOomoo`0000aoo`03001oogoo00Qoo`03001oogoo
00ioo`05001oogooOol0000;Ool01@00Oomoogoo00007goo00@007ooOol004]oo`03001oo`0001io
o`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8000moo`03001o
ogoo00Ioo`05001oogooOol0000<Ool00`00Oomoo`0FOol00`00Ool00003Ool00`00Oomoo`09Ool0
1@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Ool0000OOol3000=Ool3000COol00`00
Oomoo`03Ool3000?Ool00`00Oomoo`0GOol3000>Ool30007Ool00`00Oomoo`0?Ool3000=Ool3000P
Ool4001;Ool00`00Ool0000OOol3000=Ool4000HOol3000?Ool00`00Oomoo`0=Ool00`00Oomoo`07
Ool3000>Ool3000FOol00`00Ool00002000=Ool3000QOol3000FOol003Qoo`<004Eoo`03001oogoo
04Yoo`03001oogoo04=oo`03001oogoo04]oo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03
001oogoo04aoo`00>7oo0P00Agoo00<007ooOol0B7oo00<007ooOol0A7oo00<007ooOol0Bgoo0P00
=7oo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol0C7oo000hOol20017Ool00`00Oomoo`18
Ool00`00Oomoo`14Ool00`00Oomoo`1;Ool2000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00
Oomoo`1<Ool003Qoo`8004Moo`03001oogoo04Qoo`03001oogoo04Eoo`03001oogoo04Yoo`03001o
ogoo03Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo04]oo`00<Wooj@00@7ooj@0047oo
000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`05Ool01000Oomoo`002Woo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00D007ooOomoo`0000Ioo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo04Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo00<007ooOol0B7oo00<007ooOol0
A7oo00<007ooOol0U7oo00<007ooOol0=7oo00<007ooOol0=7oo00<007ooOol0=Goo00<007ooOol0
<goo00<007ooOol057oo000hOol20019Ool00`00Oomoo`14Ool00`00Oomoo`2DOol2000fOol00`00
Oomoo`0bOol00`00Oomoo`0fOol00`00Oomoo`0cOol00`00Oomoo`0DOol003Qoo`03001oogoo04Qo
o`03001oogoo04Aoo`03001oogoo09Aoo`03001oogoo03Eoo`03001oogoo039oo`03001oogoo03Io
o`03001oogoo039oo`03001oogoo01Eoo`00>7oo00<007ooOol0BGoo00<007ooOol0@Woo00<007oo
Ool0UGoo00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=goo00<007ooOol0<Goo00<007oo
Ool05Goo000hOol00`00Oomoo`19Ool00`00Oomoo`12Ool00`00Oomoo`2EOol00`00Oomoo`0fOol0
0`00Oomoo`0`Ool00`00Oomoo`0hOol00`00Oomoo`0aOol00`00Oomoo`0EOol003Qoo`8004Yoo`03
001oogoo049oo`03001oogoo09Eoo`8003Moo`03001oogoo031oo`03001oogoo03Qoo`03001oogoo
031oo`03001oogoo01Ioo`00>7oo00<007ooOol0BWoo00<007ooOol0@7oo00<007ooOol0UWoo00<0
07ooOol0=Woo00<007ooOol0<7oo00<007ooOol0>Goo00<007ooOol0;goo00<007ooOol05Woo000h
Ool00`00Oomoo`1:Ool00`00Oomoo`10Ool00`00Oomoo`2FOol00`00Oomoo`0gOol00`00Oomoo`0^
Ool00`00Oomoo`0jOol00`00Oomoo`0_Ool00`00Oomoo`0FOol003Qoo`03001oogoo04Yoo`03001o
ogoo041oo`03001oogoo09Ioo`03001oogoo03Moo`03001oogoo02ioo`03001oogoo03Yoo`03001o
ogoo02ioo`03001oogoo01Moo`00>7oo0P00C7oo00<007ooOol0?Woo00<007ooOol0Ugoo0P00>7oo
00<007ooOol0;Woo00<007ooOol0>goo00<007ooOol0;Goo00<007ooOol05goo000hOol00`00Oomo
o`1;Ool00`00Oomoo`0nOol00`00Oomoo`2GOol00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00Oomo
o`0lOol00`00Oomoo`0]Ool00`00Oomoo`0GOol003Qoo`03001oogoo04]oo`03001oogoo03eoo`03
001oogoo09Qoo`03001oogoo03Qoo`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02aoo`03
001oogoo01Qoo`00>7oo0P00CGoo00<007ooOol0?7oo00<007ooOol0V7oo0P00>Goo00<007ooOol0
;7oo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol067oo000GOol30006Ool20004Ool50004
Ool40005Ool00`00Oomoo`1<Ool00`00Oomoo`0lOol00`00Oomoo`1gOol30006Ool20004Ool50004
Ool40005Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0[Ool00`00
Oomoo`0HOol001Ioo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo
00<007ooOol0C7oo00<007ooOol0>goo00<007ooOol0Mgoo00D007ooOomoo`0000Eoo`8000Eoo`04
001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0nOol0
0`00Oomoo`0ZOol00`00Oomoo`0IOol001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00Oomoo`1gOol01@00Oomoogoo00003Goo
00<007ooOol027oo00<007ooOol00Woo00<007ooOol0>Goo00<007ooOol0:Woo00<007ooOol0?goo
00<007ooOol0:Goo00<007ooOol06Goo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P00CWoo00<007ooOol0>Woo00<007ooOol0Mgoo00D007ooOomoo`0000ioo`03001o
ogoo00Moo`03001oogoo009oo`8003]oo`03001oogoo02Uoo`03001oogoo03moo`03001oogoo02Uo
o`03001oogoo01Uoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo
04eoo`03001oogoo03Uoo`03001oogoo07Qoo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005
Ool00`00Oomoo`0jOol00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`0J
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`1>Ool0
0`00Oomoo`0hOol00`00Oomoo`1hOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
1Woo00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol0
6Woo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8004moo`03
001oogoo03Qoo`03001oogoo07Qoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P00?7oo00<007ooOol09goo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol06Woo
000GOol3000=Ool30005Ool40005Ool00`00Oomoo`1>Ool00`00Oomoo`0gOol00`00Oomoo`1jOol3
000=Ool30005Ool40005Ool00`00Oomoo`0kOol00`00Oomoo`0VOol00`00Oomoo`12Ool00`00Oomo
o`0VOol00`00Oomoo`0KOol003Qoo`03001oogoo04moo`03001oogoo03Ioo`03001oogoo09]oo`03
001oogoo03]oo`03001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03001oogoo01]oo`00
>7oo00<007ooOol0Cgoo00<007ooOol0=Woo00<007ooOol0Vgoo00<007ooOol0?7oo00<007ooOol0
9Goo00<007ooOol0@goo00<007ooOol09Goo00<007ooOol06goo000hOol2001@Ool00`00Oomoo`0e
Ool00`00Oomoo`2LOol2000mOol00`00Oomoo`0TOol00`00Oomoo`14Ool00`00Oomoo`0TOol00`00
Oomoo`0LOol003Qoo`03001oogoo051oo`03001oogoo03Aoo`03001oogoo09aoo`03001oogoo03ao
o`03001oogoo02Aoo`03001oogoo04Eoo`03001oogoo02=oo`03001oogoo01aoo`00>7oo00<007oo
Ool0D7oo00<007ooOol0<goo00<007ooOol0WGoo00<007ooOol0?Goo00<007ooOol08goo00<007oo
Ool0AGoo00<007ooOol08goo00<007ooOol077oo000hOol2001BOol00`00Oomoo`0bOol00`00Oomo
o`2MOol2000nOol00`00Oomoo`0ROol00`00Oomoo`16Ool00`00Oomoo`0ROol00`00Oomoo`0MOol0
03Qoo`03001oogoo055oo`03001oogoo039oo`03001oogoo09eoo`03001oogoo03eoo`03001oogoo
029oo`03001oogoo04Moo`03001oogoo025oo`03001oogoo01eoo`00>7oo00<007ooOol0DGoo00<0
07ooOol0<Goo00<007ooOol0WWoo00<007ooOol0?Woo00<007ooOol08Goo00<007ooOol0Agoo00<0
07ooOol08Goo00<007ooOol07Goo000hOol00`00Oomoo`1BOol00`00Oomoo`0`Ool00`00Oomoo`2N
Ool00`00Oomoo`0nOol00`00Oomoo`0POol00`00Oomoo`18Ool00`00Oomoo`0POol00`00Oomoo`0N
Ool003Qoo`8005=oo`03001oogoo02moo`03001oogoo09moo`8003moo`03001oogoo021oo`03001o
ogoo04Uoo`03001oogoo01moo`03001oogoo01ioo`007goo0`001Woo0P001Goo10001Goo00<007oo
Ool0DWoo00<007ooOol0;goo00<007ooOol0QWoo0`001Woo0P001Goo10001Goo00<007ooOol0?goo
00<007ooOol07goo00<007ooOol0BGoo00<007ooOol07Woo00<007ooOol07goo000NOol01@00Oomo
ogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0Dgoo00<007ooOol0;Woo00<007ooOol0
QGoo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo03moo`03001oogoo01io
o`03001oogoo04Yoo`03001oogoo01ioo`03001oogoo01moo`007Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo05=oo`03001oogoo02eoo`03001oogoo08Ioo`05001oogooOol0000@
Ool00`00Oomoo`02Ool00`00Oomoo`10Ool00`00Oomoo`0MOol00`00Oomoo`1;Ool00`00Oomoo`0M
Ool00`00Oomoo`0OOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2001DOol00`00Oomo
o`0]Ool00`00Oomoo`26Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00@Goo00<007ooOol0
7Goo00<007ooOol0Bgoo00<007ooOol077oo00<007ooOol087oo000NOol01@00Oomoogoo000037oo
10001Goo00<007ooOol0E7oo00<007ooOol0:goo00<007ooOol0Qgoo00D007ooOomoo`0000aoo`@0
00Eoo`03001oogoo045oo`03001oogoo01]oo`03001oogoo04aoo`03001oogoo01aoo`03001oogoo
021oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo05Aoo`03001oogoo02]o
o`03001oogoo08Moo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`11Ool00`00Oomo
o`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`0POol001ioo`05001oogooOol0000<
Ool00`00Oomoo`06Ool2001FOol00`00Oomoo`0ZOol00`00Oomoo`27Ool01@00Oomoogoo000037oo
00<007ooOol01Woo0P00@Woo00<007ooOol06goo00<007ooOol0CGoo00<007ooOol06Woo00<007oo
Ool08Goo000OOol3000=Ool40005Ool00`00Oomoo`1EOol00`00Oomoo`0YOol00`00Oomoo`29Ool3
000=Ool40005Ool00`00Oomoo`12Ool00`00Oomoo`0IOol00`00Oomoo`1?Ool00`00Oomoo`0IOol0
0`00Oomoo`0QOol003Qoo`03001oogoo05Eoo`03001oogoo02Uoo`03001oogoo0:9oo`03001oogoo
049oo`03001oogoo01Uoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025oo`00>7oo00<0
07ooOol0EWoo00<007ooOol0:7oo00<007ooOol0XWoo00<007ooOol0@goo00<007ooOol05goo00<0
07ooOol0D7oo00<007ooOol067oo00<007ooOol08Woo000hOol2001GOol00`00Oomoo`0WOol00`00
Oomoo`2SOol20014Ool00`00Oomoo`0GOol00`00Oomoo`1AOol00`00Oomoo`0GOol00`00Oomoo`0R
Ool003Qoo`03001oogoo05Moo`03001oogoo02Ioo`03001oogoo0:=oo`03001oogoo04=oo`03001o
ogoo01Ioo`03001oogoo059oo`03001oogoo01Moo`03001oogoo029oo`00>7oo00<007ooOol0Egoo
00<007ooOol09Goo00<007ooOol0Y7oo00<007ooOol0A7oo00<007ooOol057oo00<007ooOol0E7oo
00<007ooOol05Goo00<007ooOol08goo000hOol2001IOol00`00Oomoo`0TOol00`00Oomoo`2TOol2
0015Ool00`00Oomoo`0DOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`0TOol003Qoo`03
001oogoo05Qoo`03001oogoo02Aoo`03001oogoo0:Aoo`03001oogoo04Aoo`03001oogoo01=oo`03
001oogoo05Eoo`03001oogoo01Aoo`03001oogoo02Aoo`00>7oo00<007ooOol0F7oo00<007ooOol0
8goo00<007ooOol0YGoo00<007ooOol0AGoo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol0
4Woo00<007ooOol09Goo000hOol00`00Oomoo`1IOol00`00Oomoo`0ROol00`00Oomoo`2UOol00`00
Oomoo`16Ool00`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0AOol00`00Oomoo`0UOol003Qo
o`8005Yoo`03001oogoo025oo`03001oogoo0:Ioo`8004Qoo`03001oogoo00moo`03001oogoo05Uo
o`03001oogoo00moo`03001oogoo02Ioo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo
00<007ooOol0FWoo00<007ooOol087oo00<007ooOol0QGoo0`001Woo0P001Woo00<007ooOol017oo
10001Goo00<007ooOol0Agoo00<007ooOol03Woo00<007ooOol0Fgoo00<007ooOol03Woo00<007oo
Ool09Woo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<0
07ooOol0Fgoo00<007ooOol07Woo00<007ooOol0QGoo00D007ooOomoo`0000Eoo`8000Ioo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo04Qoo`03001oogoo00eoo`03001oogoo05]oo`03001o
ogoo00eoo`03001oogoo02Moo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo
009oo`03001oogoo05]oo`03001oogoo01eoo`03001oogoo08Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`18Ool00`00Oomoo`0<Ool00`00Oomoo`1MOol00`00
Oomoo`0<Ool00`00Oomoo`0WOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool2001MOol00`00Oomoo`0LOol00`00Oomoo`26Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo0P00BWoo00<007ooOol02Woo00<007ooOol0Ggoo00<007ooOol02Woo00<0
07ooOol0:7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0G7oo
00<007ooOol06goo00<007ooOol0Qgoo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03
001oogoo04Yoo`03001oogoo00Qoo`03001oogoo061oo`03001oogoo00Qoo`8002]oo`005Woo00D0
07ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo05eoo`03001oogoo01Yo
o`03001oogoo08Moo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`1;Ool00`00Oomoo`06Ool00`00Oomoo`1ROol20007Ool00`00Oomoo`0[Ool001Ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00Ggoo00<007ooOol067oo00<007oo
Ool0R7oo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001=Ool30003
Ool2001WOol20003Ool2000^Ool001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo05ioo`03001o
ogoo01Qoo`03001oogoo08Uoo`<000aoo`D000Aoo`@000Eoo`03001oogoo04ioo`@006Yoo`@0031o
o`00>7oo00<007ooOol0Ggoo00<007ooOol05Woo00<007ooOol0Zgoo00<007ooOol0l7oo000hOol0
0`00Oomoo`1POol00`00Oomoo`0DOol00`00Oomoo`2/Ool00`00Oomoo`3`Ool003Qoo`80065oo`03
001oogoo01=oo`03001oogoo0:eoo`800?5oo`00>7oo00<007ooOol0HGoo00<007ooOol04Goo00<0
07ooOol0[Woo00<007ooOol0l7oo000hOol00`00Oomoo`1ROol2000AOol00`00Oomoo`2^Ool00`00
Oomoo`3`Ool003Qoo`8006Eoo`03001oogoo00eoo`03001oogoo0:moo`800?5oo`00>7oo00<007oo
Ool0IGoo00<007ooOol02Woo0P00/Woo00<007ooOol0l7oo000hOol00`00Oomoo`1VOol00`00Oomo
o`07Ool2002dOol00`00Oomoo`3`Ool003Qoo`03001oogoo06Moo`<000Aoo`800;Ioo`03001oogoo
0?1oo`00>7oo0P00JWoo1@00^7oo0P00lGoo000_Ool50004Ool00`00Oomoo`3oOolNOol50004Ool0
0`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001o
ogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000aOol00`00
Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo
00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0
02moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<00004Ool00000000H
Ool3003oOol7Ool3000017oo000000006Goo0`00M7oo002FOol01@00Oomoogoo00002Goo1P002Goo
00D007ooOomoo`000?moo`Moo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05
001oogooOol0000LOol00`00Oomoo`3oOol5Ool01@00Oomoogoo000067oo1@00M7oo002FOol01@00
Oomoogoo00002Goo1P003Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Uoo`H000Uoo`04001o
ogoo001eOol009Ioo`05001oogooOol0000JOol2003oOol8Ool01@00Oomoogoo00006Goo00<007oo
0000MGoo002EOol5000MOol00`00Oomoo`3oOol4Ool5000JOol00`00Ool0001eOol00;=oo`05001o
ogooOol0003oOolVOol2001eOol00;Aoo`<00?moobQoo`03001oogoo07=oo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo000_Ool5003oOolU
Ool5003gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`009Woo1P001Goo00<007ooOol0
ogoo77oo1P001Goo00<007ooOol0mgoo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04
Ool2003aOol0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo
0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo
000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol002moo`<000Ioo`03001o
ogoo0?mooaioo`<000Ioo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00
ogoo:7oo0P00lGoo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6
Ool30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0
0005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0l7oo000>Ool60002Ool0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0o7oo1P000Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?1oo`005Woo00D007oo
Oomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`03
Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<0
07ooOol0l7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?1o
o`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool0
1@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?5oo`005goo0`0037oo
1@0017oo10001Goo00<007ooOol0ogoo1Woo0`0037oo1@0017oo10001Goo00<007ooOol0l7oo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03
001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol001moo`<000Ioo`8000Eoo`@0
00Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo0?1oo`007Woo00D007oo
Oomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol00005Ool2
0009Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`H0009oo`05001oogooOol0000@Ool00`00
Oomoo`02Ool2003oOol6Ool60002Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo000N
Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`00011o
o`03001oogoo009oo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo
0?moo`eoo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<
Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<0
07ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00ogoo3Woo00D007ooOomo
o`0000aoo`03001oogoo00Ioo`800?5oo`007goo0`003Goo10001Goo00<007ooOol0ogoo3Woo0`00
3Goo10001Goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03
001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo
:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMo
o`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0;Woo3@00]Goo000hOol2003o
OolXOol2000YOol6000=Ool6002_Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo
0?moo`Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo02Aoo`@001Uoo`@00:]oo`005Woo
00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo021o
o`@0025oo`<00:Qoo`003Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo
009oo`800?eoo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000N
Ool3000XOol2002VOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool06Woo0`00;Goo0`00Xgoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<0
07ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo01Qoo`80
03=oo`800:5oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0F
Ool2000gOol2002OOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol0
1Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000E
Ool2000kOol2002MOol001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo0?moo`Ioo`<000eoo`<0
00Eoo`@000Eoo`03001oogoo019oo`8003moo`<009Yoo`00>7oo00<007ooOol07goo0`001Woo0P00
17oo1@0067oo0`001Woo0P001Woo0`0067oo0`001Woo0P001Goo0`006Woo0`001Woo0P001Goo0`00
8Goo1@00BGoo00<007ooOol047oo0P003Goo0`001Woo0P0017oo1@0067oo0`001Woo100017oo0`00
67oo0`001Woo0P001Goo0`006Goo0`001Woo0P001Goo0`008Goo1@0057oo000hOol2000OOol01@00
Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00Oomo
o`0FOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Qoo`05001oogooOol00005Ool2
0004Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo0P003goo0P003Woo00D007ooOomoo`0000Eo
o`8000Eoo`04001oogoo000GOol01@00Oomoogoo00001Goo0P000Woo0P000goo00<007ooOol05Woo
00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000GOol01@00Oomoogoo00001Goo0P0017oo
00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000eo
o`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol0
3Goo00<007ooOol03Woo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5
000GOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomo
ogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Woo00<007oo
Ool05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol0
2goo0P004Goo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000Ool0
000067oo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00002goo00D007oo
Oomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000moo`03001o
ogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10006Goo00D0
07ooOomoo`0000aoo`<002=oo`03001oogoo04Uoo`03001oogoo00Yoo`03001oogoo015oo`05001o
ogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo00000P005Woo00D007oo
Oomoo`0000]oo`@001Qoo`05001oogooOol0000<Ool3000SOol00`00Oomoo`0DOol003Qoo`8001mo
o`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D0
07ooOomoo`0000]oo`03001oogoo01Yoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<0
07ooOol0BGoo0P002Goo0P0057oo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0
000<Ool00`00Ool00002Ool2000DOol01@00Oomoogoo00002goo00<007ooOol06Goo00D007ooOomo
o`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8001Qoo`05001oogooOol0000<
Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03
001oogoo00Moo`03001oogoo01Aoo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007oo
Oomoo`0000eoo`8000Aoo`80019oo`05001oogooOol0000<Ool00`00Oomoo`0HOol01@00Oomoogoo
00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07goo0`003Goo0`00
6Goo0`003goo00<007ooOol05goo0`003Woo0`006Goo0`003Goo0`008Goo0`00Bgoo00<007ooOol0
1Goo0P0067oo0`003Goo0`006Goo0`003goo00<007ooOol017oo00<007ooOol047oo0`003Woo0`00
67oo0`003Goo0`008Goo0`005Woo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`03Ool2001POol2
0029Ool003Qoo`800?moobQoo`80009oo`8006Aoo`03001oogoo08Ioo`00>7oo00<007ooOol0ogoo
9goo00@007ooOol006Moo`8008Ioo`00>7oo00<007ooOol0ogoo9goo0`00JWoo00<007ooOol0Pgoo
000bOooY0010OooY000@Ool003Qoo`03001oo`0000Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Ioo`03001oo`0004]oo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oo`0000Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`8001Ioo`00>7oo00<007ooOol00P009goo
00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol09Goo0P000Woo00<007oo
Ool0BGoo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol05Woo0P004Goo00<007ooOol0:Goo
00<007ooOol09Woo0P0000=oo`00Ool05Goo000hOol00`00Oomoo`02Ool00`00Oomoo`3@Ool00`00
Oomoo`1>Ool00`00Oomoo`1`Ool00`00Oomoo`1QOol2000JOol003Qoo`8000Aoo`800<ioo`80055o
o`80079oo`80061oo`03001oogoo01Yoo`00>7oo00<007ooOol01Goo00<007ooOol0bWoo00<007oo
Ool0DGoo00<007ooOol0Lgoo00<007ooOol0Fgoo0P007Goo000hOol00`00Oomoo`06Ool20038Ool2
001DOol00`00Oomoo`1dOol2001IOol2000OOol003Qoo`8000Uoo`800<Aoo`8005Ioo`8007Moo`80
05Eoo`80025oo`00>7oo00<007ooOol02Woo0P00`7oo0P00F7oo00<007ooOol0N7oo0P00DGoo0P00
8goo000hOol00`00Oomoo`0<Ool2002lOol2001JOol00`00Oomoo`1jOol2001>Ool00`00Oomoo`0S
Ool003Qoo`03001oogoo00ioo`800;Qoo`8005aoo`03001oogoo07aoo`8004Yoo`8002Ioo`00>7oo
0P004Goo0P00]7oo0P00GWoo0P00Ogoo0P00AWoo0P00:7oo000hOol00`00Oomoo`0BOol00`00Oomo
o`2_Ool2001POol00`00Oomoo`20Ool20012Ool2000ZOol003Qoo`03001oogoo01=oo`800:eoo`80
069oo`03001oogoo089oo`8003ioo`8002aoo`00>7oo00<007ooOol05Goo00<007ooOol0ZGoo00<0
07ooOol0HWoo00<007ooOol0Q7oo00<007ooOol0>Goo0P00;Woo000hOol2000GOol2002WOol2001U
Ool20026Ool2000gOol2000`Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo01Qo
o`03001oogoo0:9oo`8004Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo08Moo`8003=o
o`80039oo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol2002POol20017Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03
001oogoo009oo`03001oogoo08Uoo`8002ioo`<003Aoo`005Woo00D007ooOomoo`0000eoo`03001o
ogoo00Qoo`03001oogoo009oo`8001aoo`8009aoo`8004Uoo`05001oogooOol0000=Ool00`00Oomo
o`08Ool00`00Oomoo`02Ool2002<Ool4000WOol3000gOol001Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0MOol3002HOol00`00Oomoo`19Ool01@00Oomoogoo
00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0Sgoo0`008Woo0P00>Woo000FOol0
1@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol087oo0P00U7oo0P00C7oo00D0
07ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo099oo`<001aoo`<003aoo`005Woo
00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo029oo`80091oo`80
04ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`2EOol3000E
Ool4000oOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00
9Goo0P00S7oo0P00D7oo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2
002IOolE0013Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo02Ioo`8008Qoo`8005=oo`<0
00eoo`<000Eoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0:7oo00<007ooOol0Q7oo00<0
07ooOol0M7oo00<007ooOol0l7oo000hOol2000ZOol20022Ool2001gOol2003aOol003Qoo`03001o
ogoo02]oo`8007ioo`8007Uoo`03001oogoo0?1oo`00>7oo00<007ooOol0;Goo0P00NWoo0P00Ngoo
00<007ooOol0l7oo000hOol00`00Oomoo`0_Ool3001dOol3001mOol00`00Oomoo`3`Ool003Qoo`80
03=oo`80071oo`80081oo`800?5oo`00>7oo00<007ooOol0=7oo0P00K7oo0P00PWoo00<007ooOol0
l7oo000hOol00`00Oomoo`0fOol3001VOol30024Ool00`00Oomoo`3`Ool003Qoo`8003Yoo`80069o
o`8008Moo`800?5oo`00>7oo00<007ooOol0>goo0`00G7oo0`00RGoo00<007ooOol0l7oo000OOol3
0006Ool20005Ool40005Ool00`00Oomoo`0nOol3001GOol2001cOol30006Ool20005Ool40005Ool0
0`00Oomoo`3`Ool001ioo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`11
Ool3001AOol3001dOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0l7oo
000NOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00AGoo0`00Bgoo0`00Mgoo00D007ooOomo
o`00011oo`03001oogoo009oo`800?5oo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03
001oogoo04Moo`<004Eoo`<007Yoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3`
Ool001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`1:Ool5000kOol5001mOol01@00Oomo
ogoo000037oo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo
00<007ooOol0Cgoo1000<Woo1@00PWoo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo
0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`8005Aoo`D002Qoo`D008Moo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool2003aOol001moo`<000eoo`@000Eoo`03001oogoo05Qoo`D0
01moo`@008eoo`<000eoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0GGoo7`00ZWoo00<0
07ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo
0P001Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo
00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qo
o`03001oogoo009oo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00lGoo000F
Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000moo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo
000017oo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Moo`<000aoo`D000Aoo`@000Eoo`800?moo`Mo
o`<000aoo`D000Aoo`@000Eoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03
001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo
:7oo0P00lGoo000_Ool50004Ool00`00Oomoo`3oOolNOol50004Ool00`00Oomoo`3`Ool0035oo`03
001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007oo
Ool017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04
Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Mo
o`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomo
o`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<00004Ool0
0000000HOol5003oOol5Ool3000017oo000000005goo1@00M7oo002FOol01@00Oomoogoo00002Goo
1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H000Yoo`04001oogoo001dOol009Io
o`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo00006Woo00<007ooOol0M7oo
002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H0
00aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001]oo`03001oogoo0?moo`Ioo`05001oogoo
Ool0000LOol00`00Oomoo`1bOol009Eoo`D001aoo`03001oogoo0?moo`Eoo`D001eoo`03001oogoo
079oo`00]Woo00<007ooOol0ogoo8goo00D007ooOomoo`0007Aoo`00]7oo0`00ogoo9Woo0`00MGoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .19515 L
.08255 .14141 L
.10458 .09022 L
.12507 .05185 L
.14415 .02556 L
.14918 .02028 L
.15465 .01536 L
.15946 .01173 L
.16457 .00862 L
.16917 .00647 L
.17178 .00553 L
.17423 .00484 L
.17538 .00457 L
.17647 .00435 L
.17746 .00419 L
.17852 .00405 L
.17967 .00393 L
.18073 .00385 L
.182 .00381 L
.18314 .00381 L
.18435 .00385 L
.18547 .00393 L
.1867 .00406 L
.18802 .00425 L
.19071 .0048 L
.19317 .00549 L
.1979 .00733 L
.20239 .00968 L
.21236 .017 L
.22321 .02819 L
.24299 .0568 L
.26399 .09771 L
.30174 .19265 L
.34195 .31106 L
.38063 .42493 L
.40028 .4773 L
.42177 .52725 L
.44253 .56619 L
.4614 .59223 L
.47149 .60216 L
.47611 .60574 L
.48101 .60886 L
.4835 .61017 L
.48624 .6114 L
.48876 .61234 L
.49106 .61304 L
.49378 .61365 L
.49527 .6139 L
.49596 .61399 L
Mistroke
.49669 .61407 L
.498 .61417 L
.49921 .61422 L
.49996 .61423 L
.50065 .61422 L
.50196 .61417 L
.50313 .61408 L
.50438 .61394 L
.50556 .61377 L
.50663 .61357 L
.50926 .61295 L
.51175 .61217 L
.5167 .61007 L
.52208 .60697 L
.53169 .59935 L
.54056 .58997 L
.55926 .56323 L
.57988 .52373 L
.62014 .42277 L
.65888 .30858 L
.70007 .18761 L
.72063 .13352 L
.73974 .08971 L
.75939 .05284 L
.77791 .02689 L
.78775 .0169 L
.79293 .01276 L
.7984 .00922 L
.80302 .00692 L
.80546 .00595 L
.80809 .00512 L
.8105 .00453 L
.8127 .00414 L
.81375 .00401 L
.81491 .0039 L
.81599 .00384 L
.817 .00381 L
.81818 .00381 L
.81941 .00386 L
.82047 .00394 L
.82163 .00406 L
.82287 .00424 L
.82421 .00448 L
.82661 .00506 L
.82905 .00581 L
.83134 .00668 L
.83564 .00873 L
.84078 .0119 L
.84552 .0155 L
.85624 .026 L
Mistroke
.87498 .05192 L
.89561 .09061 L
.93591 .19056 L
.97471 .30454 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .26242 L
.08255 .24219 L
.0932 .2333 L
.10458 .22545 L
.11009 .22231 L
.11531 .21977 L
.12038 .21769 L
.12507 .21614 L
.12951 .215 L
.13178 .21454 L
.13422 .21415 L
.13549 .21398 L
.13666 .21384 L
.13784 .21373 L
.13895 .21365 L
.14022 .21358 L
.1409 .21356 L
.14161 .21354 L
.1423 .21353 L
.14295 .21353 L
.14415 .21354 L
.14531 .21358 L
.14656 .21364 L
.14773 .21372 L
.14881 .21382 L
.15143 .21414 L
.15392 .21454 L
.15886 .21565 L
.16423 .2173 L
.17383 .22139 L
.1827 .22642 L
.20137 .2406 L
.22197 .261 L
.26217 .30935 L
.30086 .35597 L
.32051 .37571 L
.3309 .38443 L
.342 .39217 L
.35275 .39797 L
.35784 .4001 L
.36253 .4017 L
.36724 .40295 L
.36972 .40346 L
.37235 .40389 L
.37463 .40418 L
.37573 .40428 L
.37677 .40436 L
.37799 .40444 L
.37911 .40448 L
Mistroke
.38031 .40451 L
.38162 .4045 L
.38227 .40449 L
.38296 .40448 L
.38419 .40442 L
.38551 .40434 L
.38695 .40421 L
.38955 .40389 L
.39197 .4035 L
.39649 .40251 L
.40134 .40108 L
.40698 .39893 L
.41232 .39645 L
.42232 .39063 L
.44227 .37492 L
.4607 .35634 L
.50002 .30899 L
.53782 .26331 L
.55884 .24211 L
.56803 .23435 L
.57808 .22714 L
.58722 .22183 L
.59696 .21755 L
.60236 .21583 L
.60726 .21468 L
.60962 .21426 L
.61086 .21408 L
.61218 .21392 L
.61333 .2138 L
.61459 .21369 L
.61574 .21362 L
.61682 .21357 L
.61808 .21353 L
.61871 .21353 L
.61941 .21353 L
.62065 .21355 L
.62181 .21359 L
.62248 .21362 L
.62318 .21367 L
.62443 .21377 L
.62578 .2139 L
.62725 .21408 L
.62973 .21447 L
.63238 .215 L
.63715 .21624 L
.64214 .21792 L
.64686 .21988 L
.6557 .22447 L
.67568 .23897 L
.69413 .25668 L
Mistroke
.7335 .30323 L
.77136 .34959 L
.79241 .37174 L
.81166 .38782 L
.82118 .39396 L
.8262 .39666 L
.83155 .39912 L
.8367 .40105 L
.84136 .40244 L
.84361 .40299 L
.84604 .40349 L
.84835 .40387 L
.85045 .40414 L
.85159 .40425 L
.85283 .40435 L
.85414 .40443 L
.85538 .40448 L
.85653 .40451 L
.85776 .40451 L
.85881 .40449 L
.85997 .40444 L
.86063 .40441 L
.86132 .40436 L
.86256 .40426 L
.86535 .40395 L
.86777 .40357 L
.87041 .40305 L
.87569 .40166 L
.88133 .39969 L
.89148 .39488 L
.90173 .38845 L
.91284 .37986 L
.933 .36054 L
.97393 .31186 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32685 L
.10458 .34595 L
.14415 .36326 L
.18221 .37903 L
.22272 .3946 L
.26171 .40815 L
.30316 .42076 L
.34309 .43093 L
.3815 .43873 L
.40095 .44189 L
.42237 .44473 L
.44268 .44681 L
.45178 .44754 L
.46172 .44819 L
.4671 .44848 L
.4721 .44871 L
.47727 .44891 L
.48196 .44906 L
.48658 .44917 L
.4887 .44921 L
.49093 .44924 L
.49332 .44927 L
.49438 .44928 L
.49552 .44929 L
.49675 .4493 L
.49789 .4493 L
.49859 .44931 L
.49925 .44931 L
.50049 .44931 L
.50163 .44931 L
.50286 .4493 L
.50401 .4493 L
.50508 .44929 L
.50754 .44926 L
.51014 .44923 L
.51268 .44919 L
.51504 .44914 L
.5204 .44899 L
.5293 .44865 L
.53882 .44816 L
.54906 .44747 L
.56016 .44655 L
.58032 .44441 L
.62123 .43824 L
.66064 .43007 L
.69852 .42029 L
.73886 .40797 L
.77769 .39445 L
.81897 .37856 L
Mistroke
.85873 .36203 L
.89697 .34526 L
.93767 .3268 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .26322 L
.10458 .21674 L
.14415 .17949 L
.18221 .15192 L
.20178 .14148 L
.21267 .13688 L
.22272 .13342 L
.23293 .13069 L
.23832 .12958 L
.24402 .12864 L
.24641 .12833 L
.24897 .12804 L
.25119 .12784 L
.25361 .12765 L
.25507 .12757 L
.25643 .1275 L
.25773 .12745 L
.2584 .12743 L
.25912 .12741 L
.25983 .1274 L
.26048 .12739 L
.26176 .12738 L
.26293 .12739 L
.26416 .1274 L
.26538 .12743 L
.26607 .12745 L
.26671 .12747 L
.26912 .12759 L
.27131 .12773 L
.27364 .12793 L
.27847 .12846 L
.2838 .12927 L
.29326 .13125 L
.30213 .13374 L
.32232 .14162 L
.34082 .15145 L
.38045 .18015 L
.41855 .21605 L
.45912 .26062 L
.49816 .30681 L
.53966 .356 L
.57964 .40012 L
.61811 .43665 L
.63759 .45217 L
.65902 .46649 L
.67938 .4772 L
.69843 .48447 L
.70884 .48728 L
.71396 .48836 L
Mistroke
.71872 .48917 L
.72301 .48975 L
.72758 .49022 L
.7302 .49041 L
.73148 .49048 L
.73266 .49054 L
.73371 .49058 L
.73487 .49061 L
.73603 .49064 L
.73725 .49065 L
.73856 .49065 L
.73977 .49064 L
.7404 .49063 L
.7411 .49062 L
.74251 .49058 L
.74375 .49053 L
.74508 .49046 L
.74748 .4903 L
.74985 .49011 L
.75235 .48985 L
.7568 .48927 L
.76198 .4884 L
.7668 .4874 L
.77773 .48448 L
.78828 .48079 L
.79823 .47655 L
.81683 .4667 L
.85534 .43897 L
.89632 .40036 L
.93577 .35688 L
.97371 .31199 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol07goo1P00SWoo1@00Igoo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00
Oomoo`04Ool00`00Oomoo`0MOol30005Ool30028Ool30005Ool2001UOol00`00Oomoo`04Ool00`00
Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo01aoo`03001oogoo00Uoo`03001oogoo08Ao
o`03001oogoo00Qoo`03001oogoo069oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007oo
Ool017oo0P0077oo00<007ooOol02goo00<007ooOol0PWoo00<007ooOol02Woo0P00HWoo00<007oo
Ool017oo0P00lGoo000_Ool30006Ool00`00Oomoo`0JOol00`00Oomoo`0<Ool00`00Oomoo`21Ool0
0`00Oomoo`0=Ool00`00Oomoo`1MOol30006Ool00`00Oomoo`3`Ool003Qoo`03001oogoo01Uoo`03
001oogoo00ioo`03001oogoo07moo`03001oogoo00moo`03001oogoo06Eoo`03001oogoo0?1oo`00
>7oo0P006Woo00<007ooOol03goo00<007ooOol0OWoo00<007ooOol03goo00<007ooOol0IGoo0P00
lGoo000hOol00`00Oomoo`0HOol00`00Oomoo`0@Ool00`00Oomoo`1mOol00`00Oomoo`0AOol00`00
Oomoo`1TOol00`00Oomoo`3`Ool003Qoo`03001oogoo01Moo`03001oogoo019oo`03001oogoo07]o
o`03001oogoo01=oo`03001oogoo06=oo`03001oogoo0?1oo`00>7oo00<007ooOol05Woo00<007oo
Ool057oo00<007ooOol0NGoo00<007ooOol057oo00<007ooOol0Hgoo00<007ooOol0l7oo000hOol2
000FOol00`00Oomoo`0FOol00`00Oomoo`1gOol00`00Oomoo`0FOol00`00Oomoo`1ROol2003aOol0
03Qoo`03001oogoo01Aoo`03001oogoo01Qoo`03001oogoo07Eoo`03001oogoo01Qoo`03001oogoo
065oo`03001oogoo0?1oo`00>7oo00<007ooOol057oo00<007ooOol06Goo00<007ooOol0M7oo00<0
07ooOol067oo00<007ooOol0HGoo00<007ooOol0l7oo000hOol00`00Oomoo`0COol00`00Oomoo`0J
Ool00`00Oomoo`1cOol00`00Oomoo`0JOol00`00Oomoo`1POol00`00Oomoo`3`Ool003Qoo`8001Ao
o`03001oogoo01]oo`03001oogoo079oo`03001oogoo01Yoo`03001oogoo061oo`800?5oo`005goo
0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol04Woo00<007ooOol077oo00<007oo
Ool0LGoo00<007ooOol077oo00<007ooOol0?Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo
00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol04Woo00<007ooOol07Goo00<007ooOol0L7oo00<007ooOol07Goo00<007ooOol0
?7oo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1o
o`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8001=oo`03
001oogoo01eoo`03001oogoo071oo`03001oogoo01eoo`03001oogoo03Aoo`H0009oo`05001oogoo
Ool0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`0OOol00`00Oomoo`1^Ool0
0`00Oomoo`0OOol00`00Oomoo`0kOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007oo
Ool04Goo00<007ooOol07goo00<007ooOol0KWoo00<007ooOol07goo00<007ooOol0>goo00D007oo
Oomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000mo
o`03001oogoo009oo`03001oogoo00Ioo`03001oogoo011oo`03001oogoo025oo`03001oogoo06ao
o`03001oogoo025oo`03001oogoo03Yoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P004Goo00<007ooOol08Goo00<007ooOol0K7oo00<007ooOol08Goo00<007ooOol0>Woo
00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003aOol001Moo`<000ao
o`D000Aoo`@000Eoo`03001oogoo00moo`03001oogoo02=oo`03001oogoo06Yoo`03001oogoo02=o
o`03001oogoo03Yoo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol03goo
00<007ooOol08goo00<007ooOol0JWoo00<007ooOol08goo00<007ooOol0Fgoo00<007ooOol0l7oo
000hOol2000@Ool00`00Oomoo`0TOol00`00Oomoo`1XOol00`00Oomoo`0TOol00`00Oomoo`1KOol2
003aOol003Qoo`03001oogoo00ioo`03001oogoo02Eoo`03001oogoo06Qoo`03001oogoo02Eoo`03
001oogoo05Yoo`03001oogoo0?1oo`00>7oo00<007ooOol03Woo00<007ooOol09Goo00<007ooOol0
Igoo00<007ooOol09Woo00<007ooOol0FWoo00<007ooOol0l7oo000hOol00`00Oomoo`0=Ool00`00
Oomoo`0WOol00`00Oomoo`1VOol00`00Oomoo`0WOol00`00Oomoo`1IOol00`00Oomoo`3`Ool003Qo
o`8000ioo`03001oogoo02Moo`03001oogoo06Eoo`03001oogoo02Qoo`03001oogoo05Uoo`800?5o
o`00>7oo00<007ooOol037oo00<007ooOol0:7oo00<007ooOol0IGoo00<007ooOol0:7oo00<007oo
Ool0FGoo00<007ooOol0l7oo000hOol00`00Oomoo`0<Ool00`00Oomoo`0YOol00`00Oomoo`1SOol0
0`00Oomoo`0ZOol00`00Oomoo`1HOol00`00Oomoo`3`Ool003Qoo`8000eoo`03001oogoo02Uoo`03
001oogoo06=oo`03001oogoo02Yoo`03001oogoo05Qoo`800?5oo`007goo0`001Woo0P001Goo1000
1Goo00<007ooOol02goo00<007ooOol0:Woo00<007ooOol0Hgoo00<007ooOol0:goo00<007ooOol0
?Woo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo
00<007ooOol00Woo00<007ooOol02goo00<007ooOol0:goo00<007ooOol0HGoo00<007ooOol0;7oo
00<007ooOol0?Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`00
5Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo02ao
o`03001oogoo065oo`03001oogoo02aoo`03001oogoo03Eoo`H0009oo`05001oogooOol0000@Ool0
0`00Oomoo`02Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000;
Ool00`00Oomoo`0]Ool00`00Oomoo`1POol00`00Oomoo`0]Ool00`00Oomoo`0lOol01@00Oomoogoo
000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0
2Woo00<007ooOol0;Goo00<007ooOol0Ggoo00<007ooOol0;Woo00<007ooOol0?7oo00D007ooOomo
o`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03
001oogoo00Uoo`03001oogoo02ioo`03001oogoo05moo`03001oogoo02ioo`03001oogoo03aoo`05
001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool0
0`00Oomoo`0kOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0l7oo000OOol3000=
Ool40005Ool20009Ool00`00Oomoo`0`Ool00`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomoo`0l
Ool3000=Ool40005Ool2003aOol003Qoo`03001oogoo00Qoo`03001oogoo031oo`03001oogoo05eo
o`03001oogoo035oo`03001oogoo05Aoo`03001oogoo0?1oo`00>7oo00<007ooOol01goo00<007oo
Ool0<Woo00<007ooOol0G7oo00<007ooOol0<Goo00<007ooOol0E7oo00<007ooOol0l7oo000hOol2
0008Ool00`00Oomoo`0bOol00`00Oomoo`1KOol00`00Oomoo`0bOol00`00Oomoo`1DOol2003aOol0
03Qoo`03001oogoo00Moo`03001oogoo039oo`03001oogoo05]oo`03001oogoo03=oo`03001oogoo
05=oo`03001oogoo0?1oo`00>7oo00<007ooOol01Woo00<007ooOol0=7oo00<007ooOol0FWoo00<0
07ooOol0<goo00<007ooOol0Dgoo00<007ooOol0l7oo000hOol00`00Oomoo`06Ool00`00Oomoo`0d
Ool00`00Oomoo`1IOol00`00Oomoo`0eOol00`00Oomoo`1BOol00`00Oomoo`3`Ool003Qoo`8000Io
o`03001oogoo03Ioo`03001oogoo05Qoo`03001oogoo03Eoo`03001oogoo059oo`800?5oo`00>7oo
00<007ooOol01Goo00<007ooOol0=Woo00<007ooOol0F7oo00<007ooOol0=Goo00<007ooOol0DWoo
00<007ooOol0l7oo000hOol00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`1GOol00`00Oomo
o`0gOol00`00Oomoo`1AOol00`00Oomoo`3`Ool003Qoo`8000Eoo`03001oogoo03Qoo`03001oogoo
05Ioo`03001oogoo03Moo`03001oogoo055oo`8001Eoo`T006Ioo`T006Aoo`005goo0`001Woo0P00
17oo1@0017oo10001Goo00<007ooOol017oo00<007ooOol0>7oo00<007ooOol0EWoo00<007ooOol0
=goo00<007ooOol0<7oo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol04Woo0P002Goo1000
H7oo0P002Goo0`00HGoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001o
ogoo009oo`03001oogoo00Aoo`03001oogoo03Qoo`03001oogoo05Eoo`03001oogoo03Uoo`03001o
ogoo02ioo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007oo
Ool03goo0`003goo00<007ooOol0FWoo0`003Woo0P00Ggoo000>Ool60002Ool01@00Oomoogoo0000
3Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0>Woo00<007ooOol0
E7oo00<007ooOol0>Goo00<007ooOol09Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qo
o`03001oogoo009oo`03001oogoo00ioo`03001oogoo015oo`8005Qoo`8001=oo`03001oogoo05ao
o`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000Aoo`03001oogoo
03Yoo`03001oogoo05Aoo`03001oogoo03Uoo`03001oogoo02ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool2000=Ool2000FOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00
Oomoo`1KOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`03Ool0
0`00Oomoo`0kOol00`00Oomoo`1BOol00`00Oomoo`0kOol00`00Oomoo`0]Ool01@00Oomoogoo0000
3goo00<007ooOol00Woo10001Goo00<007ooOol02goo00<007ooOol05goo00<007ooOol0DWoo00<0
07ooOol05Woo00<007ooOol0FWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol00Woo00<007ooOol0?7oo00<007ooOol0DWoo00<007ooOol0>goo00<007oo
Ool0;Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Yoo`03
001oogoo01Uoo`03001oogoo051oo`03001oogoo01Qoo`03001oogoo05Uoo`005Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20003Ool00`00Oomoo`0lOol00`00Oomo
o`1BOol00`00Oomoo`0kOol00`00Oomoo`0]Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Ao
o`03001oogoo00Ioo`8000]oo`03001oogoo01Yoo`03001oogoo04ioo`03001oogoo01Yoo`03001o
ogoo05Qoo`005goo0`003Goo0`001Goo10001Goo00<007ooOol00Woo00<007ooOol0?Goo00<007oo
Ool0D7oo00<007ooOol0?Goo00<007ooOol0;Goo0`003Goo0`001Goo10001Goo00<007ooOol02Goo
00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol0Egoo000hOol01@00Oomo
ogoo0000@7oo00<007ooOol0D7oo00<007ooOol0?Goo00<007ooOol0CWoo00<007ooOol027oo00<0
07ooOol07Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000hOol01@00Oomoogoo
00007Goo0`001Woo0P0017oo1@003goo00<007ooOol01Woo0`001Woo0P001Woo0`0067oo0`001Woo
0P001Goo0`002Woo00<007ooOol03Goo0`001Woo0P001Goo0`007Woo00<007ooOol01@00BGoo00<0
07ooOol01goo00<007ooOol05Goo0`001Woo0`000goo1@0067oo0`001Woo0P001Woo0`005Woo00<0
07oo00000P001Woo0P001Goo0`003Woo00<007ooOol027oo0`001Woo0P001Goo0`008Goo1@0057oo
000hOol20002Ool00`00Oomoo`0JOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol0011oo`03
001oogoo00Aoo`05001oogooOol00005Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo
0P0017oo00D007ooOomoo`0000Uoo`03001oogoo00aoo`05001oogooOol00005Ool20004Ool01@00
Oomoogoo00007Woo00D007ooOomoo`0004]oo`8000Moo`03001oogoo01Eoo`05001oogooOol00005
Ool200000goo001oo`02Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo
01Aoo`03001oo`0000=oo`03001oogoo00=oo`8000Aoo`05001oogooOol0000=Ool00`00Oomoo`07
Ool01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00@0
07ooOol001eoo`05001oogooOol0000=Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool01@00Oomoogoo
00002goo1@005goo00D007ooOomoo`0000]oo`05001oogooOol00009Ool00`00Oomoo`0<Ool01@00
Oomoogoo00002goo00D007ooOomoo`0001ioo`05001oogooOol0001;Ool00`00Oomoo`06Ool00`00
Oomoo`0EOol01@00Oomoogoo000027oo00<007ooOol00Woo00<007ooOol05goo00D007ooOomoo`00
00]oo`D001Eoo`03001oo`0000=oo`03001oogoo00Uoo`05001oogooOol0000>Ool00`00Oomoo`06
Ool01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00@007ooOol0
01eoo`05001oogooOol0000>Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool01@00Oomoogoo00002goo
00@007ooOol001Qoo`05001oogooOol0000;Ool01@00Oomoogoo000027oo00<007ooOol03Goo00D0
07ooOomoo`0000]oo`05001oogooOol0000NOol01@00Oomoogoo0000Bgoo00<007ooOol01Goo00<0
07ooOol05Woo00D007ooOomoo`0000Uoo`03001oogoo009oo`03001oogoo01Ioo`05001oogooOol0
000;Ool01000Oomoo`005Goo00@007ooOol000=oo`03001oogoo00Uoo`05001oogooOol0000?Ool0
0`00Oomoo`05Ool01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo
00@007ooOol001eoo`05001oogooOol0000?Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool01@00Oomo
ogoo000037oo00<007oo000067oo00D007ooOomoo`0000]oo`@000Uoo`03001oogoo00eoo`05001o
ogooOol0000<Ool3000POol01000Oomoo`00Bgoo00<007ooOol017oo00<007ooOol05goo00D007oo
Oomoo`0000Yoo`03001oogoo009oo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000D
Ool01@00Oomoogoo00000goo00<007ooOol02Goo10004Goo00<007ooOol017oo00D007ooOomoo`00
00aoo`<002=oo`03001oogoo01Aoo`00>7oo0`007Woo00D007ooOomoo`0000moo`03001oogoo00mo
o`03001oogoo00=oo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo00<0
07ooOol02Woo00<007ooOol03Goo00D007ooOomoo`0000]oo`05001oogooOol0000OOol01000Oomo
o`00Bgoo0P0017oo00<007ooOol067oo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00
Oomoogoo000037oo00<007oo00004goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo
01=oo`03001oogoo00=oo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo
000hOol00`00Ool0000NOol01@00Oomoogoo00002goo00D007ooOomoo`00019oo`03001oogoo009o
o`05001oogooOol0000=Ool2000HOol01@00Oomoogoo000037oo00<007ooOol027oo00<007ooOol0
3Woo00D007ooOomoo`0000]oo`05001oogooOol0000OOol01000Oomoo`00Bgoo00<007ooOol00Woo
00<007ooOol06Goo00D007ooOomoo`0000]oo`80009oo`03001oogoo01Eoo`05001oogooOol0000=
Ool2000BOol00`00Oomoo`03Ool01@00Oomoogoo000037oo00<007ooOol04goo00<007ooOol00Woo
00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oo`0001mo
o`<000eoo`<001=oo`03001oogoo00=oo`<000moo`03001oogoo01Moo`<000ioo`<000Moo`03001o
ogoo00moo`<000eoo`<0025oo`<004]oo`05001oogooOol0000MOol3000=Ool3000IOol3000?Ool0
0`00Oomoo`0?Ool00`00Oomoo`05Ool3000>Ool3000COol00`00Oomoo`02Ool3000=Ool3000QOol3
000FOol003Qoo`8004Ioo`03001oogoo04Yoo`03001oogoo04=oo`03001oogoo04]oo`80009oo`03
001oogoo02aoo`03001oogoo03aoo`03001oogoo02eoo`03001oogoo04ioo`00>7oo0P00Agoo00<0
07ooOol0B7oo00<007ooOol0A7oo00<007ooOol0Bgoo00@007ooOol0031oo`03001oogoo03Yoo`03
001oogoo02moo`03001oogoo04eoo`00>7oo0P00Agoo00<007ooOol0B7oo00<007ooOol0AGoo00<0
07ooOol0BWoo00<007oo0000<Woo00<007ooOol0>7oo00<007ooOol0<Goo00<007ooOol0C7oo000h
Ool00`00Oomoo`16Ool00`00Oomoo`18Ool00`00Oomoo`15Ool00`00Oomoo`1:Ool2000dOol00`00
Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`1<Ool0039oonT0041oonT0011oo`00>7oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol01Goo00@007ooOol000Yoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`05001oogooOol00006Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool20009Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`0DOol003Qoo`03001oogoo04Qoo`03001oogoo04Aoo`03001oogoo09Aoo`03
001oogoo03Eoo`03001oogoo039oo`03001oogoo03Moo`03001oogoo035oo`03001oogoo01Eoo`00
>7oo0P00BGoo00<007ooOol0A7oo00<007ooOol0U7oo0P00=goo00<007ooOol0<7oo00<007ooOol0
>Goo00<007ooOol0;goo00<007ooOol05Woo000hOol00`00Oomoo`18Ool00`00Oomoo`14Ool00`00
Oomoo`2DOol00`00Oomoo`0gOol00`00Oomoo`0^Ool00`00Oomoo`0kOol00`00Oomoo`0]Ool00`00
Oomoo`0GOol003Qoo`03001oogoo04Uoo`03001oogoo049oo`03001oogoo09Eoo`03001oogoo03Qo
o`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo01Qoo`00>7oo00<007oo
Ool0BGoo00<007ooOol0@Woo00<007ooOol0UGoo00<007ooOol0>Goo00<007ooOol0:Woo00<007oo
Ool0?Woo00<007ooOol0:Woo00<007ooOol06Goo000hOol2001:Ool00`00Oomoo`12Ool00`00Oomo
o`2EOol2000jOol00`00Oomoo`0ZOol00`00Oomoo`0oOol00`00Oomoo`0YOol00`00Oomoo`0IOol0
03Qoo`03001oogoo04Yoo`03001oogoo041oo`03001oogoo09Ioo`03001oogoo03Yoo`03001oogoo
02Qoo`03001oogoo045oo`03001oogoo02Moo`03001oogoo01Yoo`00>7oo00<007ooOol0BWoo00<0
07ooOol0@7oo00<007ooOol0UWoo00<007ooOol0>goo00<007ooOol09Woo00<007ooOol0@goo00<0
07ooOol09Goo00<007ooOol06goo000hOol00`00Oomoo`1:Ool00`00Oomoo`10Ool00`00Oomoo`2F
Ool00`00Oomoo`0lOol00`00Oomoo`0TOol00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`0L
Ool003Qoo`8004aoo`03001oogoo03ioo`03001oogoo09Moo`8003ioo`8002=oo`03001oogoo04Mo
o`03001oogoo025oo`03001oogoo01eoo`00>7oo00<007ooOol0Bgoo00<007ooOol0?Woo00<007oo
Ool0Ugoo00<007ooOol0?goo00<007ooOol07goo00<007ooOol0BGoo00<007ooOol07goo00<007oo
Ool07Woo000hOol00`00Oomoo`1;Ool00`00Oomoo`0nOol00`00Oomoo`2GOol00`00Oomoo`10Ool0
0`00Oomoo`0MOol00`00Oomoo`1;Ool00`00Oomoo`0MOol00`00Oomoo`0OOol003Qoo`8004eoo`03
001oogoo03aoo`03001oogoo09Qoo`80049oo`03001oogoo01]oo`03001oogoo04eoo`03001oogoo
01]oo`03001oogoo021oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0C7oo00<0
07ooOol0?7oo00<007ooOol0Mgoo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0@Woo00<0
07ooOol067oo0P00DGoo00<007ooOol06Goo00<007ooOol08Goo000FOol01@00Oomoogoo00001Goo
0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo04aoo`03001oogoo03aoo`03001o
ogoo07Ioo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007oo
Ool0@goo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05Woo0P0097oo000FOol01@00Oomo
ogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0CGoo00<007ooOol0>Woo00<0
07ooOol0Mgoo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04Ao
o`8001Eoo`03001oogoo05Aoo`03001oogoo01Aoo`03001oogoo02Aoo`005Woo00D007ooOomoo`00
00ioo`03001oogoo00Moo`03001oogoo009oo`8004ioo`03001oogoo03Yoo`03001oogoo07Moo`05
001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20017Ool00`00Oomoo`0AOol00`00
Oomoo`1FOol3000BOol00`00Oomoo`0UOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool4
0005Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00Oomoo`1gOol01@00Oomoogoo00003goo00<0
07ooOol00Woo10001Goo00<007ooOol0Agoo0P003goo0P00G7oo00<007ooOol03Woo00<007ooOol0
9Woo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0CWoo
00<007ooOol0>7oo00<007ooOol0N7oo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo
00Ioo`03001oogoo04Uoo`03001oogoo00]oo`03001oogoo05eoo`03001oogoo00]oo`8002Uoo`00
5Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001?Ool00`00Oomo
o`0hOol00`00Oomoo`1hOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Io
o`8004]oo`8000Moo`@0065oo`<000Moo`<002]oo`005goo0`003Goo0`001Goo10001Goo00<007oo
Ool0CWoo00<007ooOol0>7oo00<007ooOol0NGoo0`003Goo0`001Goo10001Goo00<007ooOol0C7oo
1`00J7oo1`00;Woo000hOol00`00Oomoo`1?Ool00`00Oomoo`0fOol00`00Oomoo`2KOol00`00Oomo
o`3`Ool003Qoo`03001oogoo04moo`03001oogoo03Ioo`03001oogoo09]oo`03001oogoo0?1oo`00
>7oo0P00D7oo00<007ooOol0=Woo00<007ooOol0Vgoo0P00lGoo000hOol00`00Oomoo`1@Ool00`00
Oomoo`0dOol00`00Oomoo`2LOol00`00Oomoo`3`Ool003Qoo`03001oogoo051oo`03001oogoo03Ao
o`03001oogoo09aoo`03001oogoo0?1oo`00>7oo0P00DGoo00<007ooOol0<goo00<007ooOol0WGoo
0P00lGoo000hOol00`00Oomoo`1AOol00`00Oomoo`0bOol00`00Oomoo`2MOol00`00Oomoo`3`Ool0
03Qoo`03001oogoo055oo`03001oogoo039oo`03001oogoo09eoo`03001oogoo0?1oo`00>7oo00<0
07ooOol0DGoo00<007ooOol0<Goo00<007ooOol0WWoo00<007ooOol0l7oo000hOol2001COol00`00
Oomoo`0`Ool00`00Oomoo`2NOol2003aOol001moo`<000Ioo`8000Eoo`@000Eoo`03001oogoo059o
o`03001oogoo031oo`03001oogoo08Eoo`<000Ioo`8000Eoo`@000Eoo`03001oogoo0?1oo`007Woo
00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo059oo`03001oogoo02moo`03
001oogoo08Eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001io
o`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`0^Ool00`00Oomo
o`25Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0l7oo000NOol01@00Oomoogoo
000047oo00<007ooOol00Woo0P00E7oo00<007ooOol0;Goo00<007ooOol0QWoo00D007ooOomoo`00
011oo`03001oogoo009oo`800?5oo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo05=o
o`03001oogoo02eoo`03001oogoo08Ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3`Ool0
01ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1DOol00`00Oomoo`0/Ool00`00
Oomoo`26Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0l7oo000NOol01@00Oomo
ogoo000037oo00<007ooOol01Woo0P00EGoo00<007ooOol0:goo00<007ooOol0Qgoo00D007ooOomo
o`0000aoo`03001oogoo00Ioo`800?5oo`007goo0`003Goo10001Goo00<007ooOol0E7oo00<007oo
Ool0:goo00<007ooOol0R7oo0`003Goo10001Goo00<007ooOol0l7oo000hOol00`00Oomoo`1EOol0
0`00Oomoo`0ZOol00`00Oomoo`2QOol00`00Oomoo`3`Ool003Qoo`03001oogoo05Eoo`03001oogoo
02Uoo`03001oogoo0:9oo`03001oogoo0?1oo`00>7oo0P00Egoo00<007ooOol0:7oo00<007ooOol0
XWoo0P00lGoo000hOol00`00Oomoo`1FOol00`00Oomoo`0WOol00`00Oomoo`2SOol00`00Oomoo`3`
Ool003Qoo`03001oogoo05Moo`03001oogoo02Ioo`03001oogoo0:=oo`03001oogoo0?1oo`00>7oo
0P00F7oo00<007ooOol09Woo00<007ooOol0Xgoo0P00lGoo000hOol00`00Oomoo`1GOol00`00Oomo
o`0UOol00`00Oomoo`2TOol00`00Oomoo`3`Ool003Qoo`03001oogoo05Qoo`03001oogoo02Aoo`03
001oogoo0:Aoo`03001oogoo0?1oo`00>7oo00<007ooOol0F7oo00<007ooOol097oo00<007ooOol0
Y7oo00<007ooOol0l7oo000hOol2001JOol00`00Oomoo`0ROol00`00Oomoo`2UOol2003aOol001Mo
o`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo05Uoo`03001oogoo029oo`03001o
ogoo08Aoo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007oo
Oomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo05Yoo`03001oogoo
021oo`03001oogoo08Aoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`1JOol00`00Oomoo`0POol00`00Oomoo`24Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo0P00G7oo00<007ooOol07Woo00<007ooOol0QGoo00D007ooOomoo`0000ioo`03
001oogoo00Moo`03001oogoo009oo`800?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=o
o`@000Eoo`03001oogoo05aoo`03001oogoo01aoo`03001oogoo08Ioo`05001oogooOol0000>Ool0
0`00Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`1LOol00`00Oomoo`0LOol00`00Oomoo`26Ool01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo0000
2goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8005ioo`03001oogoo01Yoo`03001oogoo08Mo
o`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00lGoo000GOol3000<
Ool50004Ool40005Ool00`00Oomoo`1MOol00`00Oomoo`0JOol00`00Oomoo`28Ool3000<Ool50004
Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo05ioo`03001oogoo01Qoo`03001oogoo0:Yo
o`03001oogoo0?1oo`00>7oo00<007ooOol0GWoo00<007ooOol067oo00<007ooOol0ZWoo00<007oo
Ool0l7oo000hOol2001POol00`00Oomoo`0FOol00`00Oomoo`2[Ool2003aOol003Qoo`03001oogoo
061oo`03001oogoo01Aoo`03001oogoo0:aoo`03001oogoo0?1oo`00>7oo00<007ooOol0H7oo00<0
07ooOol057oo00<007ooOol0[7oo00<007ooOol0l7oo000hOol2001ROol00`00Oomoo`0BOol00`00
Oomoo`2]Ool2003aOol003Qoo`03001oogoo069oo`03001oogoo011oo`03001oogoo0:ioo`03001o
ogoo0?1oo`00>7oo00<007ooOol0Hgoo00<007ooOol03Woo00<007ooOol0[goo00<007ooOol0l7oo
000hOol00`00Oomoo`1TOol00`00Oomoo`0;Ool2002bOol00`00Oomoo`3`Ool003Qoo`8006Ioo`03
001oogoo00Uoo`03001oogoo0;9oo`800?5oo`00;goo1@0017oo00<007ooOol0IWoo0P0027oo00<0
07ooOol0ZWoo1@0017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`1WOol9002_
Ool00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`8006aoo`800;9oo`03001o
ogoo00Aoo`800?5oo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3o
OolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007oo
Ool0ogoo9goo00<007ooOol0mgoo000_Ool3003oOolWOol3003iOol00?mooomooeIoo`00ogooogoo
EWoo002EOol3000017oo0000000067oo0`00ogoo1goo0`0000Aoo`00000001Uoo`<007Aoo`00UWoo
00D007ooOomoo`0000Uoo`H000Uoo`05001oogooOol0003oOol7Ool01@00Oomoogoo00002Goo1P00
37oo00<007ooOol0Lgoo002FOol01@00Oomoogoo000077oo00<007ooOol0ogoo1Goo00D007ooOomo
o`0001Qoo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000eoo`03001oogoo0?moo`Eoo`05001o
ogooOol00009Ool60009Ool01000Oomoo`00MGoo002FOol01@00Oomoogoo00006Woo0P00ogoo27oo
00D007ooOomoo`0001Uoo`03001oo`0007Eoo`00UGoo1@007Goo00<007ooOol0ogoo17oo1@006Woo
00<007oo0000MGoo002cOol01@00Oomoogoo0000ogoo9Woo0P00MGoo002dOol3003oOolXOol00`00
Oomoo`1cOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3g
Ool002Ioo`H000Eoo`03001oogoo0?mooaaoo`H000Eoo`03001oogoo0?Moo`00<Goo00<007ooOol0
17oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolP
Ool00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03
001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo
0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2
003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<0
07ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`03001oogoo0?aoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003o
Ool6Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00lGoo000FOol01@00
Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000io
o`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomo
o`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Ao
o`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0;goo2P00]goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`0/Ool3000:Ool4002cOol003Qoo`03001oogoo0?moobMoo`03001oogoo02Qo
o`@0015oo`@00:moo`00>7oo0P00ogoo:7oo0P009Woo0`006Goo0`00[7oo000OOol30006Ool20005
Ool40005Ool00`00Oomoo`3oOol>Ool30006Ool20005Ool40005Ool00`00Oomoo`0SOol2000OOol0
0`00Oomoo`2YOol001ioo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3o
Ool=Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol08Woo00<007ooOol0
87oo00<007ooOol0Z7oo000FOol60002Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00ogoo
1Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`80025oo`8002Aoo`800:Qoo`007Woo
00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool0
0`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`0VOol00`00Oomoo`2UOol001ioo`05001oogoo
Ool0000<Ool40005Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0
7Woo00<007ooOol0:7oo0P00YGoo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007oo
Ool0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo01aoo`8002eoo`03001o
ogoo0:9oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?moo`ioo`05001oogooOol0
000<Ool00`00Oomoo`06Ool2000LOol00`00Oomoo`0^Ool2002ROol001moo`<000eoo`@000Eoo`03
001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo01Yoo`03001oogoo035oo`03001oogoo09mo
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol067oo0P00=Goo00<007ooOol0WWoo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`0GOol00`00Oomoo`0fOol00`00Oomoo`2MOol003Qoo`800?moobQo
o`8001Moo`03001oogoo03Qoo`03001oogoo09aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
5Goo00<007ooOol0>Woo00<007ooOol0Vgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0DOol0
0`00Oomoo`0lOol00`00Oomoo`2JOol003Qoo`800?moobQoo`8001Aoo`03001oogoo03ioo`03001o
ogoo09Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol04Woo00<007ooOol0@7oo00<007ooOol0
V7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0AOol00`00Oomoo`12Ool00`00Oomoo`2GOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo011oo`03001oogoo04Aoo`03001oogoo09Ioo`00>7oo
0P00ogoo:7oo0P0047oo00<007ooOol0AWoo00<007ooOol0UGoo000GOol30006Ool20004Ool50004
Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`0?Ool0
0`00Oomoo`17Ool00`00Oomoo`2DOol001Ioo`05001oogooOol00005Ool20005Ool01000Oomoo`00
27oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo
0008Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`19Ool00`00Oomoo`2COol000ioo`H0
009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2003mOol60002Ool01@00
Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P003Woo00<007ooOol0Bgoo00<007oo
Ool0TWoo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00aoo`03
001oogoo04eoo`03001oogoo095oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eo
o`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`0;
Ool00`00Oomoo`1?Ool00`00Oomoo`2@Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol02Woo00<007ooOol0DGoo00<007ooOol0Sgoo000FOol01@00Oomoogoo0000
2goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00
Oomoogoo000017oo00<007ooOol01Woo0P002goo00<007ooOol0DWoo00<007ooOol0SWoo000GOol3
000=Ool30005Ool40005Ool00`00Oomoo`3oOol6Ool3000=Ool30005Ool40005Ool00`00Oomoo`09
Ool00`00Oomoo`1DOol00`00Oomoo`2=Ool003Qoo`03001oogoo01moo`<000Ioo`8000Aoo`D001Qo
o`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<001Yoo`<000Ioo`8000Eoo`<0025oo`D004Uo
o`03001oogoo00Qoo`03001oogoo01Aoo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<0009o
o`03001oogoo01=oo`<000Ioo`8000Eoo`<001Uoo`<000Ioo`8000Eoo`<0025oo`D001Aoo`00>7oo
0P007goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomoogoo00001Goo0P00
1goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000HOol01@00Oomo
ogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo04Uoo`8000Qoo`03001oogoo01Ao
o`05001oogooOol00005Ool20005Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03
001oogoo009oo`03001oogoo015oo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00005goo
00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001o
ogoo01ioo`05001oogooOol0000=Ool00`00Oomoo`0GOol01@00Oomoogoo00002goo1@005goo00D0
07ooOomoo`0000]oo`05001oogooOol0000HOol01@00Oomoogoo00002goo00D007ooOomoo`00029o
o`03001oogoo04Uoo`03001oogoo00Ioo`03001oogoo01Eoo`05001oogooOol0000=Ool00`00Oomo
o`0GOol01@00Oomoogoo00002goo1@000goo00<007ooOol04Goo00D007ooOomoo`0000]oo`05001o
ogooOol0000GOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo
00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000
Oomoo`0067oo00D007ooOomoo`0000]oo`05001oogooOol0000HOol01@00Oomoogoo00002goo00D0
07ooOomoo`00029oo`03001oogoo04Uoo`03001oogoo00Ioo`03001oogoo01Eoo`05001oogooOol0
000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol000Eoo`03001oogoo011oo`05
001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000]oo`05001oogooOol0000R
Ool00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol0
1@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`0000]oo`@001Uoo`05001oogooOol0
000<Ool3000SOol00`00Oomoo`19Ool00`00Oomoo`05Ool00`00Oomoo`0FOol01@00Oomoogoo0000
3goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0000Ioo`03001oogoo00moo`05001o
ogooOol0000;Ool4000HOol01@00Oomoogoo000037oo0`008goo00<007ooOol057oo000hOol2000O
Ool01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05
001oogooOol0000;Ool00`00Oomoo`0JOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03
001oogoo04Uoo`8000Eoo`03001oogoo01Moo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00
Oomoogoo000037oo00<007oo00001goo00<007ooOol03Woo00D007ooOomoo`0000]oo`03001oogoo
01Uoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomo
o`0NOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000=Ool2000HOol0
1@00Oomoogoo000037oo00<007ooOol06Goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol0
0`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Moo`05001oogooOol0000=Ool20008Ool00`00Oomoo`0=Ool01@00Oomoogoo000037oo00<0
07ooOol067oo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03
001oogoo01moo`<000eoo`<001Uoo`<000moo`03001oogoo01Moo`<000ioo`<001Uoo`<000eoo`<0
025oo`<004]oo`03001oogoo009oo`03001oogoo01Yoo`<000eoo`<001Uoo`<000moo`03001oogoo
00Moo`03001oogoo00eoo`<000ioo`<001Qoo`<000eoo`<0025oo`<001Ioo`00>7oo00<007ooOol0
ogoo9goo00D007ooOomoo`0006Eoo`03001oogoo08Ioo`00>7oo0P00ogoo:7oo0P0000=oo`00Ool0
IWoo00<007ooOol0QGoo000hOol00`00Oomoo`3oOolWOol00`00Ool0001YOol00`00Oomoo`24Ool0
03Qoo`03001oogoo0?moobMoo`8006]oo`03001oogoo08=oo`00<Wooj@00@7ooj@0047oo000hOol0
1000Ool000001goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol01Goo
0P0000=oo`00Ool0BWoo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol057oo000hOol01000Oomoogoo0`009Goo00<007ooOol0:Goo
00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol08goo0`000goo00<007ooOol0BGoo00<007oo
Ool0:Goo00<007ooOol0:Goo00<007ooOol057oo00<007ooOol04Woo00<007ooOol0:Goo00<007oo
Ool0:Goo00<007ooOol057oo000hOol00`00Oomoo`04Ool2003<Ool2001BOol00`00Oomoo`1]Ool0
0`00Oomoo`1XOol00`00Oomoo`0EOol003Qoo`8000Moo`800<Qoo`8005Aoo`8006moo`03001oogoo
06Ioo`03001oogoo01Ioo`00>7oo00<007ooOol027oo0P00a7oo0P00EWoo00<007ooOol0Kgoo00<0
07ooOol0I7oo00<007ooOol05goo000hOol00`00Oomoo`0:Ool20030Ool2001HOol00`00Oomoo`1`
Ool00`00Oomoo`1ROol00`00Oomoo`0HOol003Qoo`8000eoo`800;aoo`8005Yoo`80075oo`03001o
ogoo065oo`03001oogoo01Uoo`00>7oo00<007ooOol03Woo0P00^7oo0P00G7oo00<007ooOol0LGoo
00<007ooOol0Ggoo00<007ooOol06Woo000hOol00`00Oomoo`0@Ool2002dOol2001NOol00`00Oomo
o`1bOol00`00Oomoo`1MOol00`00Oomoo`0KOol003Qoo`03001oogoo019oo`800;1oo`80061oo`03
001oogoo07=oo`03001oogoo05]oo`03001oogoo01aoo`00>7oo0P005Goo0`00ZWoo0`00HWoo0P00
MGoo00<007ooOol0FGoo00<007ooOol07Goo000hOol00`00Oomoo`0GOol2002VOol2001UOol00`00
Oomoo`1eOol00`00Oomoo`1HOol00`00Oomoo`0MOol003Qoo`03001oogoo01Uoo`<00:5oo`8006Mo
o`03001oogoo07Ioo`03001oogoo05Ioo`03001oogoo01ioo`00>7oo00<007ooOol077oo0`00Vgoo
0`00JGoo00<007ooOol0Mgoo00<007ooOol0E7oo00<007ooOol07goo000hOol2000POol3002EOol3
001/Ool2001iOol00`00Oomoo`1BOol00`00Oomoo`0POol001Moo`<000Ioo`8000Aoo`D000Aoo`@0
00Eoo`03001oogoo029oo`80091oo`<004ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo
07Uoo`03001oogoo051oo`03001oogoo025oo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001o
ogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`0TOol2002<Ool2001@Ool01@00Oomoogoo00001Goo
0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo07Yoo`03001oogoo04ioo`03001o
ogoo029oo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8002Moo`<0
08Ioo`<0059oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2001lOol00`00
Oomoo`1<Ool00`00Oomoo`0SOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`0YOol20022Ool2001EOol01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol0O7oo00<007ooOol0BWoo00<007ooOol097oo000FOol01@00Oomoogoo
00003goo00<007ooOol00Woo10001Goo00<007ooOol0:goo0`00OGoo0P00Egoo00D007ooOomoo`00
00moo`03001oogoo009oo`@000Eoo`03001oogoo07eoo`03001oogoo04Qoo`03001oogoo02Eoo`00
5Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo02ioo`<007Mo
o`<005Uoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`1nOol0
0`00Oomoo`15Ool2000XOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P00<Woo0`00LGoo0`00G7oo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool20020Ool00`00Oomoo`13Ool00`00Oomoo`0XOol001Moo`<000eoo`<000Eoo`@000Eo
o`03001oogoo03Aoo`<006Yoo`@0061oo`<000eoo`<000Eoo`@000Eoo`03001oogoo081oo`03001o
ogoo045oo`03001oogoo02Uoo`00>7oo00<007ooOol0=goo0`00I7oo0`00QGoo00<007ooOol0PGoo
00<007ooOol0?goo00<007ooOol0:Woo000hOol2000kOol3001NOol30028Ool20023Ool00`00Oomo
o`0mOol00`00Oomoo`0[Ool003Qoo`03001oogoo03eoo`@005Ioo`@008]oo`03001oogoo08=oo`03
001oogoo03]oo`03001oogoo02aoo`00>7oo00<007ooOol0@Goo1@00CGoo1000Sgoo00<007ooOol0
Q7oo00<007ooOol0>Goo00<007ooOol0;Goo000hOol00`00Oomoo`16Ool40015Ool4002COol00`00
Oomoo`25Ool00`00Oomoo`0gOol00`00Oomoo`0^Ool003Qoo`8004]oo`D003]oo`D009Moo`8008Mo
o`03001oogoo03Eoo`03001oogoo02moo`00>7oo00<007ooOol0Cgoo1000<Woo1@00W7oo00<007oo
Ool0Qgoo0P00<goo0P00<Woo000hOol00`00Oomoo`1COol5000XOol5002QOol00`00Oomoo`29Ool0
0`00Oomoo`0_Ool00`00Oomoo`0bOol003Qoo`8005Uoo``000moo`d00:Ioo`8008]oo`03001oogoo
02eoo`03001oogoo03=oo`00>7oo00<007ooOol0I7oo3`00/goo00<007ooOol0Rgoo0P00;7oo00<0
07ooOol0=7oo000OOol30006Ool20005Ool40005Ool00`00Oomoo`3oOol>Ool30006Ool20005Ool4
0005Ool00`00Oomoo`2=Ool00`00Oomoo`0XOol00`00Oomoo`0eOol001ioo`05001oogooOol00005
Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol00Woo00<007ooOol0SWoo00<007ooOol09Woo00<007ooOol0=Woo000NOol01@00Oomoogoo
000047oo00<007ooOol00Woo0P00ogoo3Woo00D007ooOomoo`00011oo`03001oogoo009oo`80091o
o`03001oogoo02Aoo`03001oogoo03Moo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03
001oogoo0?moo`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`2@Ool2000ROol2
000jOol001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo0000
37oo10001Goo00<007ooOol0TWoo0`0077oo0`00?7oo000NOol01@00Oomoogoo000037oo00<007oo
Ool01Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo09Eo
o`8001Qoo`8003moo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?moo`ioo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool2002HOol2000DOol20011Ool001moo`<000eoo`@000Eoo`03
001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo09Uoo`<000ioo`<004=oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0W7oo3P00AWoo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`800?5oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`00
1Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo
0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eo
o`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`005Woo00D007ooOomoo`00
00ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P00lGoo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007oo
Ool0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo
00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Moo`<000aoo`D0
00Aoo`@000Eoo`800?moo`Moo`<000aoo`D000Aoo`@000Eoo`800?5oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00
lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000_Ool50004Ool00`00Oomoo`3oOolNOol50004Ool0
0`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001o
ogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0
l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001oogoo
0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00
Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOooo
OomFOol009Eoo`<00004Ool00000000HOol5003oOol5Ool3000017oo000000005goo1@00M7oo002F
Ool01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H000Yo
o`04001oogoo001dOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo
00006Woo00<007ooOol0M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo
00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001]oo`03001o
ogoo0?moo`Ioo`05001oogooOol0000LOol00`00Oomoo`1bOol009Eoo`D001aoo`03001oogoo0?mo
o`Eoo`D001eoo`03001oogoo079oo`00]Woo00<007ooOol0ogoo8goo00D007ooOomoo`0007Aoo`00
]7oo0`00ogoo9Woo0`00MGoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomF
Ool00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .21575 L
.08255 .17173 L
.10458 .1298 L
.12507 .09837 L
.14415 .07684 L
.14918 .07251 L
.15465 .06848 L
.15946 .06551 L
.16457 .06296 L
.16917 .0612 L
.17178 .06043 L
.17423 .05986 L
.17538 .05964 L
.17647 .05947 L
.17746 .05933 L
.17852 .05921 L
.17967 .05912 L
.18073 .05906 L
.182 .05902 L
.18314 .05902 L
.18435 .05906 L
.18547 .05912 L
.1867 .05923 L
.18802 .05938 L
.19071 .05983 L
.19317 .0604 L
.1979 .0619 L
.20239 .06383 L
.21236 .06983 L
.22321 .07899 L
.24299 .10243 L
.26399 .13593 L
.30174 .2137 L
.34195 .31069 L
.38063 .40396 L
.40028 .44686 L
.42177 .48778 L
.44253 .51967 L
.4614 .541 L
.47149 .54913 L
.47611 .55206 L
.48101 .55462 L
.4835 .55569 L
.48624 .5567 L
.48876 .55747 L
.49106 .55804 L
.49378 .55854 L
.49527 .55874 L
.49596 .55882 L
Mistroke
.49669 .55888 L
.498 .55897 L
.49921 .55901 L
.49996 .55902 L
.50065 .55901 L
.50196 .55897 L
.50313 .5589 L
.50438 .55878 L
.50556 .55864 L
.50663 .55848 L
.50926 .55797 L
.51175 .55733 L
.5167 .55561 L
.52208 .55307 L
.53169 .54683 L
.54056 .53915 L
.55926 .51724 L
.57988 .48489 L
.62014 .40219 L
.65888 .30866 L
.70007 .20958 L
.72063 .16527 L
.73974 .12938 L
.75939 .09918 L
.77791 .07793 L
.78775 .06975 L
.79293 .06635 L
.7984 .06345 L
.80302 .06157 L
.80546 .06078 L
.80809 .06009 L
.8105 .05961 L
.8127 .05929 L
.81375 .05919 L
.81491 .0591 L
.81599 .05904 L
.817 .05902 L
.81818 .05902 L
.81941 .05906 L
.82047 .05913 L
.82163 .05923 L
.82287 .05938 L
.82421 .05957 L
.82661 .06004 L
.82905 .06066 L
.83134 .06137 L
.83564 .06305 L
.84078 .06564 L
.84552 .06859 L
.85624 .0772 L
Mistroke
.87498 .09843 L
.89561 .13012 L
.93591 .21199 L
.97471 .30535 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35562 L
.08255 .37584 L
.0932 .38473 L
.10458 .39259 L
.11009 .39572 L
.11531 .39827 L
.12038 .40034 L
.12507 .40189 L
.12951 .40303 L
.13178 .40349 L
.13422 .40389 L
.13549 .40406 L
.13666 .40419 L
.13784 .4043 L
.13895 .40438 L
.14022 .40445 L
.1409 .40448 L
.14161 .4045 L
.1423 .40451 L
.14295 .40451 L
.14415 .40449 L
.14531 .40446 L
.14656 .40439 L
.14773 .40431 L
.14881 .40421 L
.15143 .4039 L
.15392 .40349 L
.15886 .40239 L
.16423 .40074 L
.17383 .39665 L
.1827 .39161 L
.20137 .37744 L
.22197 .35704 L
.26217 .30868 L
.30086 .26207 L
.32051 .24232 L
.3309 .23361 L
.342 .22586 L
.35275 .22006 L
.35784 .21793 L
.36253 .21633 L
.36724 .21508 L
.36972 .21457 L
.37235 .21414 L
.37463 .21386 L
.37573 .21375 L
.37677 .21367 L
.37799 .2136 L
.37911 .21355 L
Mistroke
.38031 .21353 L
.38162 .21353 L
.38227 .21354 L
.38296 .21356 L
.38419 .21361 L
.38551 .2137 L
.38695 .21382 L
.38955 .21414 L
.39197 .21453 L
.39649 .21553 L
.40134 .21696 L
.40698 .2191 L
.41232 .22159 L
.42232 .2274 L
.44227 .24311 L
.4607 .26169 L
.50002 .30904 L
.53782 .35472 L
.55884 .37593 L
.56803 .38368 L
.57808 .39089 L
.58722 .39621 L
.59696 .40048 L
.60236 .4022 L
.60726 .40336 L
.60962 .40377 L
.61086 .40395 L
.61218 .40412 L
.61333 .40424 L
.61459 .40434 L
.61574 .40442 L
.61682 .40447 L
.61808 .4045 L
.61871 .40451 L
.61941 .40451 L
.62065 .40449 L
.62181 .40444 L
.62248 .40441 L
.62318 .40437 L
.62443 .40427 L
.62578 .40413 L
.62725 .40395 L
.62973 .40356 L
.63238 .40304 L
.63715 .4018 L
.64214 .40011 L
.64686 .39815 L
.6557 .39356 L
.67568 .37906 L
.69413 .36136 L
Mistroke
.7335 .3148 L
.77136 .26844 L
.79241 .24629 L
.81166 .23021 L
.82118 .22408 L
.8262 .22137 L
.83155 .21892 L
.8367 .21698 L
.84136 .21559 L
.84361 .21504 L
.84604 .21455 L
.84835 .21417 L
.85045 .2139 L
.85159 .21378 L
.85283 .21368 L
.85414 .2136 L
.85538 .21355 L
.85653 .21353 L
.85776 .21353 L
.85881 .21355 L
.85997 .21359 L
.86063 .21363 L
.86132 .21367 L
.86256 .21377 L
.86535 .21409 L
.86777 .21446 L
.87041 .21498 L
.87569 .21637 L
.88133 .21835 L
.89148 .22316 L
.90173 .22958 L
.91284 .23817 L
.933 .25749 L
.97393 .30617 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32115 L
.10458 .33416 L
.14415 .34594 L
.18221 .35667 L
.22272 .36727 L
.26171 .3765 L
.30316 .38508 L
.34309 .392 L
.3815 .39731 L
.40095 .39946 L
.42237 .40139 L
.44268 .40281 L
.45178 .4033 L
.46172 .40375 L
.4671 .40395 L
.4721 .4041 L
.47727 .40424 L
.48196 .40434 L
.48658 .40441 L
.4887 .40444 L
.49093 .40447 L
.49332 .40449 L
.49438 .40449 L
.49552 .4045 L
.49675 .4045 L
.49789 .40451 L
.49859 .40451 L
.49925 .40451 L
.50049 .40451 L
.50163 .40451 L
.50286 .4045 L
.50401 .4045 L
.50508 .4045 L
.50754 .40448 L
.51014 .40446 L
.51268 .40442 L
.51504 .40439 L
.5204 .40429 L
.5293 .40406 L
.53882 .40373 L
.54906 .40326 L
.56016 .40263 L
.58032 .40118 L
.62123 .39697 L
.66064 .39141 L
.69852 .38475 L
.73886 .37637 L
.77769 .36717 L
.81897 .35635 L
Mistroke
.85873 .3451 L
.89697 .33369 L
.93767 .32112 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .24598 L
.10458 .18202 L
.14415 .13074 L
.18221 .09278 L
.20178 .07843 L
.21267 .07209 L
.22272 .06733 L
.23293 .06357 L
.23832 .06204 L
.24402 .06075 L
.24641 .06032 L
.24897 .05993 L
.25119 .05964 L
.25361 .05939 L
.25507 .05927 L
.25643 .05918 L
.25773 .05911 L
.2584 .05908 L
.25912 .05906 L
.25983 .05904 L
.26048 .05903 L
.26176 .05902 L
.26293 .05902 L
.26416 .05904 L
.26538 .05908 L
.26607 .05911 L
.26671 .05914 L
.26912 .0593 L
.27131 .0595 L
.27364 .05977 L
.27847 .06051 L
.2838 .06162 L
.29326 .06435 L
.30213 .06777 L
.32232 .07861 L
.34082 .09214 L
.38045 .13165 L
.41855 .18106 L
.45912 .2424 L
.49816 .30598 L
.53966 .37368 L
.57964 .43441 L
.61811 .48469 L
.63759 .50605 L
.65902 .52577 L
.67938 .5405 L
.69843 .5505 L
.70884 .55437 L
.71396 .55585 L
Mistroke
.71872 .55698 L
.72301 .55778 L
.72758 .55842 L
.7302 .55868 L
.73148 .55878 L
.73266 .55886 L
.73371 .55891 L
.73487 .55896 L
.73603 .55899 L
.73725 .55901 L
.73856 .55902 L
.73977 .559 L
.7404 .55899 L
.7411 .55897 L
.74251 .55891 L
.74375 .55884 L
.74508 .55875 L
.74748 .55854 L
.74985 .55827 L
.75235 .55791 L
.7568 .55712 L
.76198 .55592 L
.7668 .55455 L
.77773 .55052 L
.78828 .54544 L
.79823 .5396 L
.81683 .52604 L
.85534 .48788 L
.89632 .43474 L
.93577 .3749 L
.97371 .31311 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`0OOol6002<Ool8001]Ool00`00Oomoo`3`Ool003Qoo`8001eoo`<000Ioo`@008Moo`03
001oogoo00Ioo`8006]oo`800?5oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<0
07ooOol06goo00<007ooOol02goo00<007ooOol0PWoo0P002goo0P00B7oo0`001Woo0P001Woo00<0
07ooOol017oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol06Woo00<007ooOol03Goo00<007ooOol0P7oo00<007oo
Ool03Goo00<007ooOol0A7oo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001o
ogoo009oo`8001Yoo`03001oogoo00moo`03001oogoo07ioo`03001oogoo00moo`03001oogoo03]o
o`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05
001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`0@
Ool00`00Oomoo`1mOol00`00Oomoo`0@Ool00`00Oomoo`13Ool01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol0
0goo10001Goo00<007ooOol05goo00<007ooOol04Woo00<007ooOol0Ngoo00<007ooOol04Woo00<0
07ooOol0@Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo
00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01Ioo`03001oogoo
01Aoo`03001oogoo07Uoo`03001oogoo01Aoo`03001oogoo045oo`05001oogooOol0000?Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomo
ogoo000017oo00<007ooOol01Woo0P005Woo00<007ooOol05Woo00<007ooOol0Mgoo00<007ooOol0
5Woo00<007ooOol0@7oo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2
003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo01Aoo`03001oogoo01Qoo`03001oogoo
07Eoo`03001oogoo01Qoo`03001oogoo041oo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00
>7oo00<007ooOol057oo00<007ooOol06Goo00<007ooOol0M7oo00<007ooOol067oo00<007ooOol0
HGoo00<007ooOol0l7oo000hOol2000DOol00`00Oomoo`0JOol00`00Oomoo`1cOol00`00Oomoo`0J
Ool00`00Oomoo`1POol2003aOol003Qoo`03001oogoo01=oo`03001oogoo01]oo`03001oogoo079o
o`03001oogoo01]oo`03001oogoo05moo`03001oogoo0?1oo`00>7oo00<007ooOol04Woo00<007oo
Ool07Goo00<007ooOol0L7oo00<007ooOol07Goo00<007ooOol0GWoo00<007ooOol0l7oo000hOol0
0`00Oomoo`0AOol00`00Oomoo`0NOol00`00Oomoo`1_Ool00`00Oomoo`0NOol00`00Oomoo`1NOol0
0`00Oomoo`3`Ool003Qoo`80019oo`03001oogoo01moo`03001oogoo06ioo`03001oogoo01moo`03
001oogoo05eoo`800?5oo`00>7oo00<007ooOol047oo00<007ooOol087oo00<007ooOol0KGoo00<0
07ooOol08Goo00<007ooOol0G7oo00<007ooOol0l7oo000hOol00`00Oomoo`0@Ool00`00Oomoo`0Q
Ool00`00Oomoo`1/Ool00`00Oomoo`0QOol00`00Oomoo`1LOol00`00Oomoo`3`Ool003Qoo`80011o
o`03001oogoo02=oo`03001oogoo06Yoo`03001oogoo02=oo`03001oogoo05]oo`800?5oo`007goo
0`001Woo0P001Goo10001Goo00<007ooOol03goo00<007ooOol08goo00<007ooOol0JGoo00<007oo
Ool097oo00<007ooOol0@Woo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00Oomo
ogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol09Goo00<007ooOol0
J7oo00<007ooOol09Goo00<007ooOol0@7oo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009o
o`03001oogoo0?1oo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo
00ioo`03001oogoo02Eoo`03001oogoo06Moo`03001oogoo02Ioo`03001oogoo03Qoo`H0009oo`05
001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool0
0`00Oomoo`02Ool2000>Ool00`00Oomoo`0WOol00`00Oomoo`1VOol00`00Oomoo`0WOol00`00Oomo
o`0oOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomoogoo000037oo
10001Goo00<007ooOol03Goo00<007ooOol09goo00<007ooOol0IGoo00<007ooOol0:7oo00<007oo
Ool0?goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000ao
o`03001oogoo00Ioo`03001oogoo00aoo`03001oogoo02Qoo`03001oogoo06Aoo`03001oogoo02Yo
o`03001oogoo03ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05
001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`0YOol00`00Oomoo`1S
Ool00`00Oomoo`0ZOol00`00Oomoo`0nOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007oo
Ool0l7oo000OOol3000=Ool40005Ool2000<Ool00`00Oomoo`0ZOol00`00Oomoo`1ROol00`00Oomo
o`0/Ool00`00Oomoo`0nOol3000=Ool40005Ool2003aOol003Qoo`03001oogoo00]oo`03001oogoo
02]oo`03001oogoo065oo`03001oogoo02aoo`03001oogoo05Moo`03001oogoo0?1oo`00>7oo00<0
07ooOol02Woo00<007ooOol0;7oo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0Egoo00<0
07ooOol0l7oo000hOol2000;Ool00`00Oomoo`0]Ool00`00Oomoo`1OOol00`00Oomoo`0^Ool00`00
Oomoo`1FOol2003aOol003Qoo`03001oogoo00Uoo`03001oogoo02ioo`03001oogoo05moo`03001o
ogoo02ioo`03001oogoo05Ioo`03001oogoo0?1oo`00>7oo00<007ooOol02Goo00<007ooOol0;goo
00<007ooOol0GWoo00<007ooOol0;goo00<007ooOol0EGoo00<007ooOol0l7oo000hOol00`00Oomo
o`08Ool00`00Oomoo`0`Ool00`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomoo`1EOol00`00Oomo
o`3`Ool003Qoo`8000Uoo`03001oogoo031oo`03001oogoo05eoo`03001oogoo035oo`03001oogoo
05Aoo`800?5oo`00>7oo00<007ooOol01goo00<007ooOol0<Woo00<007ooOol0G7oo00<007ooOol0
<Goo00<007ooOol0E7oo00<007ooOol0l7oo000hOol00`00Oomoo`07Ool00`00Oomoo`0bOol00`00
Oomoo`1KOol00`00Oomoo`0cOol00`00Oomoo`1COol00`00Oomoo`3`Ool003Qoo`8000Moo`03001o
ogoo03Aoo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo05=oo`8004aoo`/006=oo`/002ao
o`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol01Woo00<007ooOol0=7oo00<007oo
Ool0FGoo00<007ooOol0=Goo00<007ooOol0<Goo0`001Woo0P0017oo1@0017oo10001Goo00<007oo
Ool0BGoo0P002goo00<007ooOol0GWoo0P002goo0P00:Woo000FOol01@00Oomoogoo00001Goo0P00
1Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo03Ioo`03001oogoo
05Qoo`03001oogoo03Eoo`03001oogoo031oo`05001oogooOol00005Ool20005Ool01000Oomoo`00
27oo00<007ooOol00Woo00<007ooOol0B7oo00<007ooOol037oo0P00G7oo0P003goo0P00:7oo000>
Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol01Goo
00<007ooOol0=Woo00<007ooOol0Egoo00<007ooOol0=Woo00<007ooOol0:7oo1P000Woo00D007oo
Oomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04Ioo`80015oo`8005Uoo`03
001oogoo015oo`8002Ioo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`8000Ioo`03001oogoo03Moo`03001oogoo05Ioo`03001oogoo03Moo`03001oogoo02moo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20015Ool2000EOol00`00Oomoo`1DOol2
000FOol00`00Oomoo`0SOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00
Oomoo`04Ool00`00Oomoo`0hOol00`00Oomoo`1FOol00`00Oomoo`0gOol00`00Oomoo`0_Ool01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0@goo00<007ooOol05Woo00<007oo
Ool0DWoo00<007ooOol05goo00<007ooOol08Woo000FOol01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0>Goo00<007ooOol0E7oo00<007ooOol0
>Goo00<007ooOol0;Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo049oo`03001oogoo01Qoo`03001oogoo051oo`03001oogoo01Qoo`03001oogoo029oo`005Woo
00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20004Ool00`00Oomoo`0j
Ool00`00Oomoo`1DOol00`00Oomoo`0iOol00`00Oomoo`0^Ool01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`80049oo`03001oogoo01Yoo`03001oogoo04ioo`03001oogoo
01Yoo`03001oogoo025oo`005goo0`003Goo0`001Goo10001Goo00<007ooOol00goo00<007ooOol0
>Woo00<007ooOol0Dgoo00<007ooOol0>Woo00<007ooOol0;goo0`003Goo0`001Goo10001Goo00<0
07ooOol0@7oo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol087oo000h
Ool00`00Oomoo`03Ool00`00Oomoo`0kOol00`00Oomoo`1BOol00`00Oomoo`0kOol00`00Oomoo`1?
Ool00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`0O
Ool003Qoo`03001oogoo009oo`03001oogoo01Yoo`<000Ioo`8000Aoo`D000ioo`03001oogoo00Mo
o`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<000]oo`03001oogoo00aoo`<000Ioo`8000Eo
o`<001eoo`04001oogooOol50019Ool00`00Oomoo`0OOol30006Ool20004Ool5000;Ool00`00Oomo
o`0:Ool30006Ool20006Ool30002Ool00`00Oomoo`0COol30006Ool20005Ool3000IOol30006Ool2
0005Ool3000IOol00`00Oomoo`05Ool5000DOol003Qoo`8000=oo`03001oogoo01Uoo`05001oogoo
Ool00005Ool20005Ool01000Oomoo`003goo00<007ooOol01Goo00D007ooOomoo`0000Eoo`8000Mo
o`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00002Woo00<007ooOol0
2goo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000MOol00`00Oomoo`02Ool00`00Oomo
o`19Ool2000OOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Yoo`03001oogoo00Yoo`05
001oogooOol00005Ool20007Ool00`00Oomoo`02Ool00`00Oomoo`0AOol01@00Oomoogoo00001Goo
0P0017oo00D007ooOomoo`0001Moo`05001oogooOol00004Ool30004Ool01@00Oomoogoo000067oo
00<007ooOol01goo00<007ooOol057oo000hOol01@00Oomoogoo000077oo00D007ooOomoo`0000eo
o`03001oogoo00moo`03001oogoo00Eoo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo0000
2goo00D007ooOomoo`0000Yoo`03001oogoo00]oo`05001oogooOol0000;Ool01@00Oomoogoo0000
7Goo00<007ooOol00Woo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000eoo`03001o
ogoo00Yoo`03001oogoo00Yoo`05001oogooOol0000;Ool50003Ool00`00Oomoo`0AOol01@00Oomo
ogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol00003Ool00`00Oomoo`05Ool01@00Oomo
ogoo00006Goo00<007ooOol01Woo00<007ooOol057oo000hOol01@00Oomoogoo000077oo00D007oo
Oomoo`0000ioo`03001oogoo00moo`03001oogoo00Aoo`05001oogooOol0000;Ool01000Oomoo`00
67oo00D007ooOomoo`0000]oo`05001oogooOol00009Ool00`00Oomoo`0<Ool01@00Oomoogoo0000
2goo00D007ooOomoo`0001ioo`05001oogooOol0001;Ool00`00Oomoo`0NOol01@00Oomoogoo0000
3Woo00<007ooOol027oo00<007ooOol02goo00D007ooOomoo`0000]oo`04001oogoo0005Ool00`00
Oomoo`0@Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol00003Ool00`00
Oomoo`05Ool01@00Oomoogoo00006Woo00<007ooOol01Goo00<007ooOol057oo000hOol01000Oomo
o`007Goo00D007ooOomoo`0000moo`03001oogoo00ioo`03001oogoo00Aoo`05001oogooOol0000<
Ool00`00Ool0000HOol01@00Oomoogoo00002goo10002Woo00<007ooOol037oo00D007ooOomoo`00
00aoo`<001moo`05001oogooOol0001;Ool00`00Oomoo`0NOol01@00Oomoogoo00003goo00<007oo
Ool01Woo00<007ooOol037oo00D007ooOomoo`0000aoo`03001oo`0000Ioo`03001oogoo00moo`05
001oogooOol0000;Ool4000HOol01@00Oomoogoo00000Woo00<007ooOol01goo0`0077oo00<007oo
Ool017oo00<007ooOol057oo000hOol200000goo001oo`0LOol01@00Oomoogoo00003goo00<007oo
Ool03goo00<007ooOol00goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;
Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool01@00Oomoogoo00002goo00D007ooOomoo`0001ioo`05
001oogooOol0001;Ool2000OOol01@00Oomoogoo00003goo00<007ooOol01Goo00<007ooOol03Goo
00D007ooOomoo`0000aoo`03001oo`0000Moo`03001oogoo00ioo`05001oogooOol0000;Ool00`00
Oomoo`0IOol01`00Oomoogoo001oo`0000Uoo`05001oogooOol0000LOol00`00Oomoo`03Ool00`00
Oomoo`0DOol003Qoo`04001oogoo000MOol01@00Oomoogoo00002goo00D007ooOomoo`00015oo`03
001oogoo00=oo`05001oogooOol0000=Ool2000HOol01@00Oomoogoo000037oo00<007ooOol02Goo
00<007ooOol03Goo00D007ooOomoo`0000]oo`05001oogooOol0000OOol01000Oomoo`00Bgoo00<0
07ooOol07Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool00`00Oomoo`0>Ool01@00Oomo
ogoo00003Goo0P0027oo00<007ooOol03Goo00D007ooOomoo`0000aoo`03001oogoo01Qoo`04001o
ogooOol2000:Ool01@00Oomoogoo00007Goo00<007ooOol00Woo00<007ooOol057oo000hOol00`00
Ool0000OOol3000=Ool3000COol00`00Oomoo`03Ool3000?Ool00`00Oomoo`0GOol3000>Ool30007
Ool00`00Oomoo`0?Ool3000=Ool3000POol4001;Ool00`00Oomoo`0OOol3000=Ool30006Ool00`00
Oomoo`0@Ool3000?Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool3000>Ool3000HOol4000<Ool3000O
Ool00`00Ool00002000FOol003Qoo`<004Eoo`03001oogoo04Yoo`03001oogoo04=oo`03001oogoo
04]oo`8003Uoo`03001oogoo02aoo`03001oogoo03]oo`03001oogoo02ioo`03001oogoo01Moo`00
>7oo0P00AWoo00<007ooOol0BWoo00<007ooOol0@goo00<007ooOol0Bgoo00<007ooOol0=goo00<0
07ooOol0;Woo00<007ooOol0>Woo00<007ooOol0;goo00<007ooOol05Woo000hOol20017Ool00`00
Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`1;Ool00`00Oomoo`0fOol00`00Oomoo`0`Ool00`00
Oomoo`0hOol00`00Oomoo`0aOol00`00Oomoo`0EOol003Qoo`8004Moo`03001oogoo04Qoo`03001o
ogoo04Eoo`03001oogoo04Yoo`03001oogoo03Eoo`03001oogoo039oo`03001oogoo03Ioo`03001o
ogoo03=oo`03001oogoo01Aoo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`05Ool01000Oomoo`002Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00D007ooOomoo`0000Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo04Uoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`80
00Yoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
01Aoo`00>7oo00<007ooOol0B7oo00<007ooOol0A7oo00<007ooOol0U7oo0P00=7oo00<007ooOol0
=Woo00<007ooOol0<Woo00<007ooOol0C7oo000hOol20019Ool00`00Oomoo`14Ool00`00Oomoo`2D
Ool3000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`1=Ool003Qoo`03001oogoo04Qo
o`03001oogoo04=oo`03001oogoo09Eoo`04001oogoo000`Ool00`00Oomoo`0jOol00`00Oomoo`0^
Ool00`00Oomoo`1>Ool003Qoo`03001oogoo04Uoo`03001oogoo049oo`03001oogoo09Eoo`05001o
ogooOol0000^Ool00`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`1?Ool003Qoo`03001oogoo
04Uoo`03001oogoo049oo`03001oogoo09Eoo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo
03ioo`03001oogoo02Yoo`03001oogoo051oo`00>7oo0P00Bgoo00<007ooOol0@7oo00<007ooOol0
UWoo0P000goo00<007ooOol0:Woo00<007ooOol0?goo00<007ooOol0:7oo00<007ooOol0DGoo000h
Ool00`00Oomoo`1:Ool00`00Oomoo`10Ool00`00Oomoo`2FOol00`00Oomoo`03Ool00`00Oomoo`0X
Ool00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`1AOol003Qoo`03001oogoo04Yoo`03001o
ogoo03moo`03001oogoo09Moo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo04=oo`03001o
ogoo02Eoo`03001oogoo059oo`00>7oo00<007ooOol0Bgoo00<007ooOol0?Woo00<007ooOol0Ugoo
00<007ooOol01Goo00<007ooOol097oo00<007ooOol0AGoo00<007ooOol08goo00<007ooOol0Dgoo
000hOol2001<Ool00`00Oomoo`0mOol00`00Oomoo`2HOol20007Ool00`00Oomoo`0ROol00`00Oomo
o`17Ool00`00Oomoo`0QOol00`00Oomoo`1DOol003Qoo`03001oogoo04aoo`03001oogoo03aoo`03
001oogoo09Qoo`03001oogoo00Moo`03001oogoo021oo`03001oogoo04Uoo`03001oogoo01moo`03
001oogoo05Eoo`00>7oo00<007ooOol0C7oo00<007ooOol0?7oo00<007ooOol0V7oo00<007ooOol0
27oo00<007ooOol07Woo00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol0EWoo000hOol2001>
Ool00`00Oomoo`0jOol00`00Oomoo`2IOol2000:Ool00`00Oomoo`0LOol00`00Oomoo`1=Ool00`00
Oomoo`0KOol00`00Oomoo`1GOol001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo04eo
o`03001oogoo03Yoo`03001oogoo07Qoo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Yo
o`8001]oo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo05Qoo`005Woo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool00`00Oomoo`0iOol0
0`00Oomoo`1hOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03
001oogoo00aoo`03001oogoo01Ioo`8005=oo`03001oogoo01Ioo`8005]oo`005Woo00D007ooOomo
o`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04ioo`03001oogoo03Qoo`03001o
ogoo07Qoo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool0
0`00Oomoo`0DOol00`00Oomoo`1DOol00`00Oomoo`0COol2001MOol001Ioo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2001?Ool00`00Oomoo`0gOol00`00Oomoo`1iOol01@00
Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P003goo00<007ooOol04Woo00<007oo
Ool0EWoo00<007ooOol04Goo00<007ooOol0GGoo000FOol01@00Oomoogoo00003goo00<007ooOol0
0Woo10001Goo00<007ooOol0Cgoo00<007ooOol0=Woo00<007ooOol0NGoo00D007ooOomoo`0000mo
o`03001oogoo009oo`@000Eoo`03001oogoo00moo`80011oo`8005Yoo`8000moo`80061oo`005Woo
00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo04moo`03001oogoo
03Ioo`03001oogoo07Uoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`0AOol2000<Ool2001NOol3000;Ool00`00Oomoo`1POol001Ioo`05001oogooOol0000;Ool0
1@00Oomoogoo000017oo00<007ooOol01Woo0P00D7oo00<007ooOol0=Goo00<007ooOol0NWoo00D0
07ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000DOol20007Ool3001SOol2
0007Ool2001SOol001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo051oo`03001oogoo03Aoo`03
001oogoo07]oo`<000eoo`<000Eoo`@000Eoo`03001oogoo01Eoo`L006Qoo`L006Eoo`00>7oo00<0
07ooOol0D7oo00<007ooOol0<goo00<007ooOol0WGoo00<007ooOol0l7oo000hOol00`00Oomoo`1A
Ool00`00Oomoo`0bOol00`00Oomoo`2MOol00`00Oomoo`3`Ool003Qoo`80059oo`03001oogoo035o
o`03001oogoo09ioo`800?5oo`00>7oo00<007ooOol0DGoo00<007ooOol0<Goo00<007ooOol0WWoo
00<007ooOol0l7oo000hOol00`00Oomoo`1BOol00`00Oomoo`0`Ool00`00Oomoo`2NOol00`00Oomo
o`3`Ool003Qoo`8005=oo`03001oogoo02moo`03001oogoo09moo`800?5oo`00>7oo00<007ooOol0
Dgoo00<007ooOol0;Woo00<007ooOol0Wgoo00<007ooOol0l7oo000hOol00`00Oomoo`1COol00`00
Oomoo`0]Ool00`00Oomoo`2POol00`00Oomoo`3`Ool003Qoo`03001oogoo05=oo`03001oogoo02eo
o`03001oogoo0:1oo`03001oogoo0?1oo`00>7oo0P00EGoo00<007ooOol0:goo00<007ooOol0XGoo
0P00lGoo000OOol30006Ool20005Ool40005Ool00`00Oomoo`1DOol00`00Oomoo`0[Ool00`00Oomo
o`28Ool30006Ool20005Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol00005Ool20009
Ool00`00Oomoo`02Ool00`00Oomoo`1EOol00`00Oomoo`0YOol00`00Oomoo`28Ool01@00Oomoogoo
00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000047oo00<0
07ooOol00Woo00<007ooOol0EGoo00<007ooOol0:Goo00<007ooOol0R7oo00D007ooOomoo`00011o
o`03001oogoo009oo`03001oogoo0?1oo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`80
05Moo`03001oogoo02Moo`03001oogoo08Uoo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003a
Ool001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`1GOol00`00Oomoo`0VOol00`00Oomo
o`29Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo
00<007ooOol01Woo00<007ooOol0Egoo00<007ooOol09Woo00<007ooOol0RGoo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Io
o`8005Uoo`03001oogoo02Aoo`03001oogoo08Yoo`05001oogooOol0000<Ool00`00Oomoo`06Ool2
003aOol001moo`<000eoo`@000Eoo`03001oogoo05Qoo`03001oogoo02Aoo`03001oogoo08]oo`<0
00eoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0FGoo00<007ooOol08Woo00<007ooOol0
YGoo00<007ooOol0l7oo000hOol00`00Oomoo`1IOol00`00Oomoo`0ROol00`00Oomoo`2UOol00`00
Oomoo`3`Ool003Qoo`8005]oo`03001oogoo021oo`03001oogoo0:Ioo`800?5oo`00>7oo00<007oo
Ool0Fgoo00<007ooOol07Woo00<007ooOol0Ygoo00<007ooOol0l7oo000hOol00`00Oomoo`1KOol0
0`00Oomoo`0MOol00`00Oomoo`2XOol00`00Oomoo`3`Ool003Qoo`8005eoo`03001oogoo01aoo`03
001oogoo0:Qoo`800?5oo`00>7oo00<007ooOol0G7oo00<007ooOol06goo00<007ooOol0ZGoo00<0
07ooOol0l7oo000hOol00`00Oomoo`1MOol00`00Oomoo`0IOol00`00Oomoo`2ZOol00`00Oomoo`3`
Ool003Qoo`03001oogoo05ioo`03001oogoo01Qoo`03001oogoo0:Yoo`03001oogoo0?1oo`00>7oo
0P00Ggoo00<007ooOol05goo00<007ooOol0Zgoo0P00lGoo000GOol30006Ool20006Ool00`00Oomo
o`04Ool40005Ool00`00Oomoo`1OOol00`00Oomoo`0EOol00`00Oomoo`2;Ool30006Ool20006Ool0
0`00Oomoo`04Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol00005Ool20006Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`1POol00`00Oomoo`0COol00`00Oomoo`2;Ool01@00
Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0l7oo000FOol0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0HGoo00<007ooOol0
4Goo00<007ooOol0S7oo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo0?1oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8006=oo`<0
00moo`03001oogoo08eoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003a
Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`1UOol00`00Oomo
o`0:Ool2002@Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0l7oo000F
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0IWoo00<007oo
Ool01goo0P00TWoo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
0?1oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001XOol3
0003Ool3002DOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?5o
o`005goo0`0037oo1@0017oo10001Goo00<007ooOol0JGoo1@00Ugoo0`0037oo1@0017oo10001Goo
00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?mo
obMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol002mo
o`D000Aoo`03001oogoo0?mooaioo`D000Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<0
07ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQ
Ool00`00Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<0
07ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035o
o`03001oogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00nGoo003oOoooOomFOol0
0?mooomooeIoo`00UGoo0`0000Aoo`00000001Qoo`<00?moo`Moo`<00004Ool00000000IOol3001d
Ool009Ioo`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000ogoo1goo00D007ooOomoo`00
00Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001aoo`03001oogoo0?moo`Eoo`05
001oogooOol0000HOol5001dOol009Ioo`05001oogooOol00009Ool6000=Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00002Goo1P002Goo00@007ooOol007Eoo`00UWoo00D007ooOomoo`0001Yoo`80
0?moo`Qoo`05001oogooOol0000IOol00`00Ool0001eOol009Eoo`D001eoo`03001oogoo0?moo`Ao
o`D001Yoo`03001oo`0007Eoo`00/goo00D007ooOomoo`000?moobIoo`8007Eoo`00]7oo0`00ogoo
:7oo00<007ooOol0Lgoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol002moo`D00?moobEoo`D00?Moo`00<Goo00<007ooOol0ogoo9goo00<0
07ooOol0mgoo000VOol60005Ool00`00Oomoo`3oOolLOol60005Ool00`00Oomoo`3gOol0035oo`03
001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol017oo00<007oo
Ool0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3o
OolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001o
ogoo00Aoo`800?5oo`00;goo0`001Woo00<007ooOol0ogoo7Woo0`001Woo00<007ooOol0l7oo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03
001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0<Goo1`00^7oo000hOol2003oOolXOol2000]Ool60006Ool3002eOol0
01Moo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@000Eoo`03001oogoo02Yoo`8000moo`@00;5oo`005Woo00D007ooOomoo`00
00Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0
0005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0XOol2000EOol2002_Ool0
00ioo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3l
Ool60002Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol09goo
00<007ooOol05goo00<007ooOol0[7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80
02Ioo`8001]oo`800:aoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001o
ogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`0SOol2000O
Ool00`00Oomoo`2YOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0
0`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool08Woo00<007ooOol087oo00<007ooOol0Z7oo000FOol01@00Oomoogoo00002goo00D007ooOomo
o`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol01Woo0P008Woo00<007ooOol08Woo00<007ooOol0Ygoo000GOol3000<Ool50004Ool4
0005Ool00`00Oomoo`3oOol6Ool3000<Ool50004Ool40005Ool00`00Oomoo`0QOol00`00Oomoo`0S
Ool00`00Oomoo`2VOol003Qoo`03001oogoo0?moobMoo`03001oogoo021oo`03001oogoo02Eoo`03
001oogoo0:Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol07goo00<007ooOol09goo00<007oo
Ool0Y7oo000hOol2003oOolXOol2000OOol00`00Oomoo`0YOol00`00Oomoo`2SOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo01eoo`03001oogoo02]oo`03001oogoo0:9oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol077oo00<007ooOol0;Goo00<007ooOol0XGoo000hOol2003oOolXOol2000L
Ool00`00Oomoo`0_Ool00`00Oomoo`2POol003Qoo`03001oogoo0?moobMoo`03001oogoo01Yoo`03
001oogoo035oo`03001oogoo09moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol06Goo00<007oo
Ool0<goo00<007ooOol0WWoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0IOol00`00Oomoo`0c
Ool00`00Oomoo`2NOol003Qoo`800?moobQoo`8001Uoo`03001oogoo03Eoo`03001oogoo09eoo`00
7goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007oo
Ool05goo00<007ooOol0=goo00<007ooOol0W7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03
001oogoo01Ioo`03001oogoo03Uoo`03001oogoo09]oo`005Woo1P000Woo00D007ooOomoo`00011o
o`03001oogoo009oo`800?moo`Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000F
Ool00`00Oomoo`0jOol00`00Oomoo`2KOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol057oo00<007oo
Ool0?7oo00<007ooOol0VWoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo
00D007ooOomoo`0000aoo`@000Eoo`03001oogoo01Aoo`03001oogoo03eoo`03001oogoo09Uoo`00
7Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<
Ool00`00Oomoo`06Ool00`00Oomoo`0COol00`00Oomoo`0oOol00`00Oomoo`2HOol001ioo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo
0P004goo00<007ooOol0@7oo00<007ooOol0V7oo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>
Ool3000=Ool40005Ool00`00Oomoo`0AOol00`00Oomoo`12Ool00`00Oomoo`2GOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo011oo`03001oogoo04Aoo`03001oogoo09Ioo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol03goo00<007ooOol0AWoo00<007ooOol0UGoo000hOol2003oOolXOol2000@
Ool00`00Oomoo`16Ool00`00Oomoo`2EOol003Qoo`03001oogoo0?moobMoo`03001oogoo00ioo`03
001oogoo04Qoo`03001oogoo09Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol03Goo00<007oo
Ool0BWoo00<007ooOol0Tgoo000hOol2003oOolXOol2000>Ool00`00Oomoo`1;Ool00`00Oomoo`2B
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00aoo`03001oogoo04aoo`03001oogoo099oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol037oo00<007ooOol0CGoo00<007ooOol0TGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`0;Ool00`00Oomoo`1?Ool00`00Oomoo`2@Ool003Qoo`800?mo
obQoo`8000]oo`03001oogoo051oo`03001oogoo091oo`005goo0`001Woo0P0017oo1@0017oo1000
1Goo00<007ooOol0ogoo1Woo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol02Woo00<007oo
Ool0DGoo00<007ooOol0Sgoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03
001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo
00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0Dgoo00<007ooOol0SWoo000>Ool60002Ool0
1@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P00oGoo1P000Woo00D007ooOomo
o`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8000Yoo`03001oogoo05Aoo`03001oogoo08eo
o`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eo
o`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomo
o`1EOol00`00Oomoo`2=Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00
Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol01goo00<0
07ooOol0Egoo00<007ooOol0S7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo05Qoo`03001oogoo08]oo`005Woo00D007ooOomoo`0000]oo`05
001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomo
o`0000Aoo`03001oogoo00Ioo`8000Moo`03001oogoo05Uoo`03001oogoo08]oo`005goo0`003Goo
0`001Goo10001Goo00<007ooOol0ogoo1Woo0`003Goo0`001Goo10001Goo00<007ooOol01Woo00<0
07ooOol0FWoo00<007ooOol0RWoo000hOol00`00Oomoo`0OOol30006Ool20004Ool5000HOol30006
Ool20006Ool3000HOol30006Ool20005Ool3000JOol30006Ool20005Ool3000QOol50019Ool00`00
Oomoo`05Ool00`00Oomoo`0GOol30006Ool20004Ool5000HOol30006Ool20006Ool30005Ool00`00
Oomoo`0@Ool30006Ool20005Ool3000IOol30006Ool20005Ool3000QOol5000DOol003Qoo`8001mo
o`05001oogooOol00005Ool20005Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03
001oogoo01Ioo`05001oogooOol00005Ool20004Ool01@00Oomoogoo000067oo00D007ooOomoo`00
00Eoo`8000Aoo`05001oogooOol0000ROol00`00Oomoo`19Ool20005Ool00`00Oomoo`0GOol01@00
Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00Oomo
o`04Ool00`00Oomoo`0?Ool01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Moo`05001o
ogooOol00005Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0N
Ool01@00Oomoogoo00003Goo00<007ooOol05goo00D007ooOomoo`0000]oo`D001Moo`05001oogoo
Ool0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00
Oomoo`19Ool00`00Oomoo`04Ool00`00Oomoo`0GOol01@00Oomoogoo00003Goo00<007ooOol05goo
00D007ooOomoo`0000]oo`D000Ioo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo
00005goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001o
ogoo01ioo`05001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol0
01Qoo`05001oogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogoo
Ool0000ROol00`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`0HOol01@00Oomoogoo00003Woo
00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo0007Ool00`00Oomoo`0>Ool01@00Oomo
ogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<0
07ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007oo
Oomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool4000IOol01@00Oomoogoo000037oo
0`008goo00<007ooOol0BGoo00<007ooOol00Woo00<007ooOol06Goo00D007ooOomoo`0000moo`03
001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool00008Ool00`00Oomoo`0=Ool01@00Oomoogoo
00002goo100067oo00D007ooOomoo`0000aoo`<002=oo`03001oogoo01Aoo`00>7oo0P007goo00D0
07ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomo
ogoo00002goo00<007ooOol06Woo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomo
o`19Ool20003Ool00`00Oomoo`0IOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomo
o`0000aoo`03001oo`0000Uoo`03001oogoo00aoo`05001oogooOol0000;Ool00`00Oomoo`0IOol0
1@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo
00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00003Goo0P0067oo00D007oo
Oomoo`0000aoo`03001oogoo01Uoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007oo
Ool0BGoo00D007ooOomoo`0001aoo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007oo
Oomoo`0000eoo`8000Uoo`03001oogoo00aoo`05001oogooOol0000<Ool00`00Oomoo`0HOol01@00
Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07goo0`00
3Goo0`006Goo0`003goo00<007ooOol05goo0`003Woo0`006Goo0`003Goo0`008Goo0`00Bgoo00D0
07ooOomoo`0001eoo`<000eoo`<001Uoo`<000moo`03001oogoo00Qoo`03001oogoo00aoo`<000io
o`<001Qoo`<000eoo`<0025oo`<001Ioo`00>7oo00<007ooOol0ogoo9goo00@007ooOol006Moo`03
001oogoo08Eoo`00>7oo0P00ogoo:7oo0`00JGoo00<007ooOol0Q7oo000hOol00`00Oomoo`3oOolW
Ool00`00Ool0001ZOol00`00Oomoo`23Ool003Qoo`03001oogoo0?moobMoo`8006]oo`03001oogoo
08=oo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`030005Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`04Ool300000goo001oo`1:Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0DOol003Qo
o`03001oogoo00=oo`<002=oo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Yoo`03001o
ogoo029oo`<000Aoo`03001oogoo04Uoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo01Ao
o`03001oogoo019oo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo01Aoo`00>7oo00<007oo
Ool01Woo0`00aWoo1000Dgoo00<007ooOol0KGoo00<007ooOol0J7oo00<007ooOol05Goo000hOol2
000:Ool30030Ool3001GOol2001^Ool00`00Oomoo`1WOol00`00Oomoo`0FOol003Qoo`03001oogoo
00aoo`<00;Yoo`<005Yoo`03001oogoo06ioo`03001oogoo06Ioo`03001oogoo01Ioo`00>7oo00<0
07ooOol03goo1000/goo0`00GGoo00<007ooOol0KWoo00<007ooOol0IGoo00<007ooOol05goo000h
Ool2000DOol3002]Ool3001POol2001`Ool00`00Oomoo`1TOol00`00Oomoo`0GOol003Qoo`03001o
ogoo01Ioo`<00:Moo`<006=oo`03001oogoo071oo`03001oogoo069oo`03001oogoo01Qoo`00>7oo
00<007ooOol06Goo0`00X7oo1000IWoo00<007ooOol0L7oo00<007ooOol0HGoo00<007ooOol06Goo
000hOol00`00Oomoo`0LOol5002FOol5001ZOol00`00Oomoo`1aOol00`00Oomoo`1POol00`00Oomo
o`0IOol003Qoo`80029oo`@008moo`<006moo`80079oo`03001oogoo05moo`03001oogoo01Yoo`00
>7oo00<007ooOol09Goo0`00RGoo0`00LWoo00<007ooOol0LWoo00<007ooOol0GWoo00<007ooOol0
6Woo000hOol00`00Oomoo`0XOol30023Ool3001eOol00`00Oomoo`1cOol00`00Oomoo`1LOol00`00
Oomoo`0KOol003Qoo`03001oogoo02]oo`<007aoo`@007Qoo`03001oogoo07=oo`03001oogoo05]o
o`03001oogoo01aoo`00>7oo0P00;goo1@00LWoo1@00O7oo0P00MGoo00<007ooOol0FWoo00<007oo
Ool077oo000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`0cOol5001YOol4001POol3
0006Ool20004Ool50004Ool40005Ool00`00Oomoo`1dOol00`00Oomoo`1IOol00`00Oomoo`0MOol0
01Ioo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0
>7oo1@00Ggoo1@00Hgoo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02
Ool00`00Oomoo`1eOol00`00Oomoo`1HOol00`00Oomoo`0MOol001Ioo`05001oogooOol0000=Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool2000nOol7001AOol7001XOol01@00Oomoogoo00003Goo00<0
07ooOol027oo00<007ooOol00Woo0P00Mgoo00<007ooOol0EWoo00<007ooOol07Woo000FOol01@00
Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0A7oo1P00AGoo1P00Kgoo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo07Moo`03001oogoo
05Aoo`03001oogoo01moo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001o
ogoo04Yoo`D003]oo`D007Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomo
o`1gOol00`00Oomoo`1DOol00`00Oomoo`0OOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`1?Ool9000[Ool7001jOol01@00Oomoogoo00003goo00<007oo
Ool00Woo00<007ooOol01Woo00<007ooOol0N7oo00<007ooOol0DWoo00<007ooOol087oo000FOol0
1@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8005Uoob/0085oo`05001o
ogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00NWoo00<007ooOol0D7oo00<0
07ooOol08Goo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`3oOol6Ool3000=Ool30005Ool4
0005Ool00`00Oomoo`1iOol00`00Oomoo`1?Ool00`00Oomoo`0ROol003Qoo`03001oogoo0?moobMo
o`03001oogoo07Yoo`03001oogoo04ioo`03001oogoo029oo`00>7oo0P00ogoo:7oo0P00O7oo00<0
07ooOol0C7oo00<007ooOol08goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1lOol00`00Oomo
o`1:Ool00`00Oomoo`0TOol003Qoo`03001oogoo0?moobMoo`03001oogoo07aoo`03001oogoo04Yo
o`03001oogoo02Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0OGoo00<007ooOol0B7oo00<0
07ooOol09Goo000hOol2003oOolXOol2001oOol00`00Oomoo`16Ool00`00Oomoo`0VOol003Qoo`03
001oogoo0?moobMoo`03001oogoo07ioo`03001oogoo04Ioo`03001oogoo02Ioo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0Ogoo00<007ooOol0A7oo00<007ooOol09goo000hOol2003oOolXOol2
0021Ool00`00Oomoo`12Ool00`00Oomoo`0XOol003Qoo`03001oogoo0?moobMoo`03001oogoo085o
o`03001oogoo041oo`03001oogoo02Uoo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo
3Woo0`001Woo0P001Goo10001Goo00<007ooOol0PGoo00<007ooOol0@7oo00<007ooOol0:Goo000N
Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomo
o`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo089oo`03001oogoo03ioo`03001oogoo02Yo
o`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`ioo`05001oogooOol0000@Ool0
0`00Oomoo`02Ool20024Ool00`00Oomoo`0lOol00`00Oomoo`0[Ool001ioo`05001oogooOol0000@
Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<0
07ooOol0Q7oo00<007ooOol0>Woo00<007ooOol0;7oo000NOol01@00Oomoogoo000037oo10001Goo
00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo08Aoo`03001oogoo03Uo
o`03001oogoo02eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eo
o`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`25Ool00`00Oomoo`0hOol00`00Oomo
o`0]Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomoogoo0000
37oo00<007ooOol01Woo0P00Qgoo00<007ooOol0=Woo00<007ooOol0;Woo000OOol3000=Ool40005
Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`27Ool00`00Oomoo`0dOol00`00Oomo
o`0_Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Moo`03001oogoo03=oo`03001oogoo031o
o`00>7oo0P00ogoo:7oo0P00RGoo00<007ooOol0<Woo00<007ooOol0<7oo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`29Ool00`00Oomoo`0`Ool00`00Oomoo`0aOol003Qoo`03001oogoo0?moobMo
o`03001oogoo08Yoo`03001oogoo02ioo`03001oogoo039oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0Rgoo0P00;Goo00<007ooOol0<goo000hOol2003oOolXOol2002>Ool00`00Oomoo`0YOol0
0`00Oomoo`0dOol003Qoo`03001oogoo0?moobMoo`03001oogoo08ioo`03001oogoo02Moo`03001o
ogoo03Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Sgoo00<007ooOol09Goo00<007ooOol0
=Woo000hOol2003oOolXOol2002AOol2000TOol00`00Oomoo`0gOol001Moo`<000Ioo`8000Ioo`03
001oogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eo
o`03001oogoo099oo`03001oogoo01moo`8003Yoo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`2COol00`00Oomoo`0LOol2000lOol001Ioo`05
001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomo
ogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0U7oo00<007ooOol06Woo00<0
07ooOol0?7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00ogoo
1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8009Ioo`8001Qoo`8003mo
o`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001o
ogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`2GOol2000DOol20011Ool001Ioo`05
001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomo
ogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0VGoo0`003Woo0`00@goo000F
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo0?moo`Eo
o`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0W7oo0P00
2Woo0P00AWoo000GOol3000<Ool50004Ool40005Ool2003oOol7Ool3000<Ool50004Ool40005Ool2
002OOol:0018Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00;goo
1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00
Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo
0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<0
07ooOol017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo
0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3003o
OolWOol3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo1@00ogoo
1Goo0`0000Aoo`00000001Moo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo
0?moo`Ioo`05001oogooOol00009Ool6000:Ool01000Oomoo`00M7oo002FOol01@00Oomoogoo0000
6goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001Yoo`03001oogoo07Aoo`00UWoo00D007ooOomo
o`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1c
Ool009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo000077oo00<007oo
Ool0LWoo002EOol5000LOol00`00Oomoo`3oOol5Ool5000MOol00`00Oomoo`1bOol00;Ioo`03001o
ogoo0?moob=oo`05001oogooOol0001dOol00;Aoo`<00?moobIoo`<007Eoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25668 L
.08255 .23198 L
.10458 .20845 L
.12507 .19081 L
.14415 .17873 L
.14918 .1763 L
.15465 .17404 L
.15946 .17237 L
.16457 .17094 L
.16917 .16995 L
.17178 .16952 L
.17423 .1692 L
.17538 .16908 L
.17647 .16898 L
.17746 .1689 L
.17852 .16884 L
.17967 .16878 L
.18073 .16875 L
.182 .16873 L
.18314 .16873 L
.18435 .16875 L
.18547 .16879 L
.1867 .16885 L
.18802 .16893 L
.19071 .16918 L
.19317 .1695 L
.1979 .17034 L
.20239 .17142 L
.21236 .17479 L
.22321 .17994 L
.24299 .19309 L
.26399 .21189 L
.30174 .25553 L
.34195 .30996 L
.38063 .3623 L
.40028 .38637 L
.42177 .40933 L
.44253 .42723 L
.4614 .4392 L
.47149 .44376 L
.47611 .44541 L
.48101 .44684 L
.4835 .44744 L
.48624 .44801 L
.48876 .44844 L
.49106 .44876 L
.49378 .44904 L
.49527 .44915 L
.49596 .4492 L
Mistroke
.49669 .44923 L
.498 .44928 L
.49921 .4493 L
.49996 .44931 L
.50065 .4493 L
.50196 .44928 L
.50313 .44924 L
.50438 .44918 L
.50556 .4491 L
.50663 .44901 L
.50926 .44872 L
.51175 .44836 L
.5167 .4474 L
.52208 .44597 L
.53169 .44247 L
.54056 .43816 L
.55926 .42586 L
.57988 .40771 L
.62014 .3613 L
.65888 .30881 L
.70007 .25321 L
.72063 .22835 L
.73974 .20821 L
.75939 .19126 L
.77791 .17934 L
.78775 .17475 L
.79293 .17284 L
.7984 .17121 L
.80302 .17016 L
.80546 .16971 L
.80809 .16933 L
.8105 .16906 L
.8127 .16888 L
.81375 .16882 L
.81491 .16877 L
.81599 .16874 L
.817 .16873 L
.81818 .16873 L
.81941 .16875 L
.82047 .16879 L
.82163 .16885 L
.82287 .16893 L
.82421 .16904 L
.82661 .1693 L
.82905 .16965 L
.83134 .17005 L
.83564 .17099 L
.84078 .17245 L
.84552 .1741 L
.85624 .17893 L
Mistroke
.87498 .19084 L
.89561 .20863 L
.93591 .25457 L
.97471 .30696 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .43101 L
.08255 .48397 L
.0932 .50724 L
.10458 .5278 L
.11009 .53602 L
.11531 .54268 L
.12038 .5481 L
.12507 .55216 L
.12951 .55515 L
.13178 .55635 L
.13422 .55739 L
.13549 .55784 L
.13666 .55818 L
.13784 .55847 L
.13895 .55868 L
.14022 .55887 L
.1409 .55893 L
.14161 .55898 L
.1423 .55901 L
.14295 .55902 L
.14415 .55898 L
.14531 .55889 L
.14656 .55872 L
.14773 .5585 L
.14881 .55825 L
.15143 .55742 L
.15392 .55636 L
.15886 .55347 L
.16423 .54914 L
.17383 .53844 L
.1827 .52525 L
.20137 .48814 L
.22197 .43474 L
.26217 .30814 L
.30086 .1861 L
.32051 .1344 L
.3309 .11159 L
.342 .09132 L
.35275 .07612 L
.35784 .07055 L
.36253 .06637 L
.36724 .0631 L
.36972 .06176 L
.37235 .06063 L
.37463 .05989 L
.37573 .05961 L
.37677 .0594 L
.37799 .05921 L
.37911 .05909 L
Mistroke
.38031 .05903 L
.38162 .05903 L
.38227 .05905 L
.38296 .0591 L
.38419 .05924 L
.38551 .05947 L
.38695 .0598 L
.38955 .06062 L
.39197 .06165 L
.39649 .06425 L
.40134 .068 L
.40698 .07361 L
.41232 .08012 L
.42232 .09535 L
.44227 .13647 L
.4607 .18512 L
.50002 .30909 L
.53782 .42867 L
.55884 .48419 L
.56803 .50449 L
.57808 .52337 L
.58722 .53729 L
.59696 .54848 L
.60236 .55298 L
.60726 .556 L
.60962 .55709 L
.61086 .55756 L
.61218 .55799 L
.61333 .55831 L
.61459 .55859 L
.61574 .55878 L
.61682 .55891 L
.61808 .559 L
.61871 .55901 L
.61941 .55901 L
.62065 .55896 L
.62181 .55885 L
.62248 .55876 L
.62318 .55865 L
.62443 .55839 L
.62578 .55803 L
.62725 .55755 L
.62973 .55654 L
.63238 .55516 L
.63715 .55192 L
.64214 .5475 L
.64686 .54237 L
.6557 .53035 L
.67568 .4924 L
.69413 .44605 L
Mistroke
.7335 .32417 L
.77136 .20279 L
.79241 .1448 L
.81166 .1027 L
.82118 .08664 L
.8262 .07956 L
.83155 .07313 L
.8367 .06806 L
.84136 .06442 L
.84361 .06299 L
.84604 .06169 L
.84835 .0607 L
.85045 .05999 L
.85159 .05969 L
.85283 .05942 L
.85414 .05921 L
.85538 .05908 L
.85653 .05903 L
.85776 .05903 L
.85881 .05908 L
.85997 .05919 L
.86063 .05928 L
.86132 .0594 L
.86256 .05966 L
.86535 .06048 L
.86777 .06147 L
.87041 .06284 L
.87569 .06646 L
.88133 .07164 L
.89148 .08424 L
.90173 .10105 L
.91284 .12354 L
.933 .17412 L
.97393 .30158 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31516 L
.10458 .32174 L
.14415 .32771 L
.18221 .33314 L
.22272 .33851 L
.26171 .34318 L
.30316 .34752 L
.34309 .35103 L
.3815 .35371 L
.40095 .3548 L
.42237 .35578 L
.44268 .3565 L
.45178 .35675 L
.46172 .35697 L
.4671 .35707 L
.4721 .35715 L
.47727 .35722 L
.48196 .35727 L
.48658 .35731 L
.4887 .35732 L
.49093 .35734 L
.49332 .35735 L
.49438 .35735 L
.49552 .35735 L
.49675 .35736 L
.49789 .35736 L
.49859 .35736 L
.49925 .35736 L
.50049 .35736 L
.50163 .35736 L
.50286 .35736 L
.50401 .35735 L
.50508 .35735 L
.50754 .35734 L
.51014 .35733 L
.51268 .35732 L
.51504 .3573 L
.5204 .35725 L
.5293 .35713 L
.53882 .35696 L
.54906 .35673 L
.56016 .35641 L
.58032 .35567 L
.62123 .35354 L
.66064 .35073 L
.69852 .34736 L
.73886 .34311 L
.77769 .33846 L
.81897 .33298 L
Mistroke
.85873 .32728 L
.89697 .32151 L
.93767 .31514 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .23492 L
.10458 .15972 L
.14415 .09944 L
.18221 .05482 L
.20178 .03794 L
.21267 .03049 L
.22272 .02489 L
.23293 .02048 L
.23832 .01868 L
.24402 .01717 L
.24641 .01666 L
.24897 .01619 L
.25119 .01586 L
.25361 .01556 L
.25507 .01542 L
.25643 .01532 L
.25773 .01524 L
.2584 .0152 L
.25912 .01517 L
.25983 .01515 L
.26048 .01514 L
.26176 .01512 L
.26293 .01513 L
.26416 .01516 L
.26538 .0152 L
.26607 .01524 L
.26671 .01527 L
.26912 .01546 L
.27131 .01569 L
.27364 .016 L
.27847 .01688 L
.2838 .01819 L
.29326 .02139 L
.30213 .02541 L
.32232 .03816 L
.34082 .05406 L
.38045 .10051 L
.41855 .15859 L
.45912 .2307 L
.49816 .30545 L
.53966 .38504 L
.57964 .45642 L
.61811 .51554 L
.63759 .54064 L
.65902 .56382 L
.67938 .58114 L
.69843 .5929 L
.70884 .59745 L
.71396 .59919 L
Mistroke
.71872 .60051 L
.72301 .60146 L
.72758 .6022 L
.7302 .60251 L
.73148 .60263 L
.73266 .60272 L
.73371 .60279 L
.73487 .60284 L
.73603 .60288 L
.73725 .60291 L
.73856 .60291 L
.73977 .60289 L
.7404 .60288 L
.7411 .60285 L
.74251 .60278 L
.74375 .60271 L
.74508 .6026 L
.74748 .60235 L
.74985 .60203 L
.75235 .60161 L
.7568 .60067 L
.76198 .59927 L
.7668 .59765 L
.77773 .59292 L
.78828 .58695 L
.79823 .58009 L
.81683 .56415 L
.85534 .51928 L
.89632 .45682 L
.93577 .38646 L
.97371 .31383 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`1=Ool6001XOol6000_Ool003Qoo`800?moobQoo`8004eoo`03
001oogoo00Aoo`03001oogoo06Aoo`8000Eoo`03001oogoo02aoo`005goo0`001Woo0P001Woo00<0
07ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo
00<007ooOol0Bgoo00<007ooOol01Woo0P00Hgoo00<007ooOol01Woo0P00;7oo000FOol01@00Oomo
ogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007oo
Oomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04Yoo`03001oogoo
00Uoo`03001oogoo05moo`03001oogoo00Uoo`03001oogoo02Uoo`003Woo1P000Woo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool2001:Ool00`00Oomoo`0:Ool00`00Oomoo`1OOol00`00Oomo
o`09Ool00`00Oomoo`0YOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol0BGoo00<007ooOol02goo00<007ooOol0GGoo00<007ooOol02goo00<007ooOol0:7oo000F
Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo04Qoo`03001oogoo00aoo`03001oogoo05ao
o`03001oogoo00eoo`03001oogoo02Moo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`17Ool00`00Oomoo`0>Ool00`00Oomoo`1KOol00`00Oomoo`0=Ool00`00Oomo
o`0WOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo
1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20018Ool00`00Oomo
o`0?Ool00`00Oomoo`1IOol00`00Oomoo`0?Ool00`00Oomoo`0VOol001Moo`<000aoo`D000Aoo`@0
00Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo04Ioo`03001oogoo011o
o`03001oogoo05Qoo`03001oogoo011oo`03001oogoo02Ioo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0AGoo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol09Goo000h
Ool2003oOolXOol20016Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol00`00Oomo
o`0UOol003Qoo`03001oogoo0?moobMoo`03001oogoo04Aoo`03001oogoo01Aoo`03001oogoo05Ao
o`03001oogoo01Aoo`03001oogoo02Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0A7oo00<0
07ooOol057oo00<007ooOol0E7oo00<007ooOol05Goo00<007ooOol08goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`13Ool00`00Oomoo`0FOol00`00Oomoo`1COol00`00Oomoo`0EOol00`00Oomo
o`0SOol003Qoo`800?moobQoo`8004Aoo`03001oogoo01Ioo`03001oogoo059oo`03001oogoo01Mo
o`03001oogoo029oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0@goo00<007ooOol05goo00<0
07ooOol0DGoo00<007ooOol05goo00<007ooOol08Woo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`12Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`0QOol003Qoo`80
0?moobQoo`8004=oo`03001oogoo01Uoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025o
o`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<0
07ooOol0@Goo00<007ooOol06Woo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol08Goo000N
Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomo
o`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo045oo`03001oogoo01]oo`03001oogoo04eo
o`03001oogoo01]oo`03001oogoo021oo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo
009oo`03001oogoo0?moo`Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomo
o`11Ool00`00Oomoo`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`0POol001ioo`05
001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<007ooOol0
0Woo0P00@Goo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol087oo000N
Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eo
o`03001oogoo041oo`03001oogoo01eoo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo01mo
o`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0
000<Ool00`00Oomoo`06Ool00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1;Ool00`00Oomo
o`0MOol00`00Oomoo`0OOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0O
Ool6002>Ool5001DOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0?goo00<007oo
Ool07Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol07goo000OOol3000=Ool40005Ool2
000MOol40005Ool40026Ool40005Ool3001BOol3000=Ool40005Ool2000oOol00`00Oomoo`0POol0
0`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`0NOol003Qoo`03001oogoo01Yoo`8000eoo`80
089oo`8000aoo`<006Qoo`03001oogoo03ioo`03001oogoo021oo`03001oogoo04Qoo`03001oogoo
021oo`03001oogoo01ioo`00>7oo00<007ooOol067oo0P004Goo0P00OWoo0P004Goo0P00IWoo00<0
07ooOol0?Woo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol087oo00<007ooOol07Woo000h
Ool2000FOol3000EOol2001jOol2000EOol2001TOol2000nOol00`00Oomoo`0ROol00`00Oomoo`17
Ool00`00Oomoo`0QOol00`00Oomoo`0MOol003Qoo`03001oogoo01Aoo`03001oogoo01Qoo`03001o
ogoo07Ioo`03001oogoo01Moo`03001oogoo065oo`03001oogoo03eoo`03001oogoo029oo`03001o
ogoo04Ioo`03001oogoo029oo`03001oogoo01eoo`00>7oo00<007ooOol04goo00<007ooOol06Woo
0P00M7oo0P006goo00<007ooOol0H7oo00<007ooOol0?Goo00<007ooOol08Woo00<007ooOol0AWoo
00<007ooOol08Woo00<007ooOol07Goo000hOol00`00Oomoo`0BOol00`00Oomoo`0MOol00`00Oomo
o`1`Ool00`00Oomoo`0LOol00`00Oomoo`1OOol00`00Oomoo`0lOol00`00Oomoo`0TOol00`00Oomo
o`15Ool00`00Oomoo`0SOol00`00Oomoo`0LOol003Qoo`80019oo`03001oogoo01moo`03001oogoo
06ioo`03001oogoo01ioo`03001oogoo05ioo`8003eoo`03001oogoo02Aoo`03001oogoo04Aoo`03
001oogoo02Aoo`03001oogoo01aoo`00>7oo00<007ooOol047oo00<007ooOol08Goo00<007ooOol0
K7oo00<007ooOol087oo00<007ooOol0GGoo00<007ooOol0?7oo00<007ooOol097oo00<007ooOol0
A7oo00<007ooOol097oo00<007ooOol077oo000hOol00`00Oomoo`0@Ool00`00Oomoo`0ROol00`00
Oomoo`1ZOol00`00Oomoo`0ROol00`00Oomoo`1LOol00`00Oomoo`0kOol00`00Oomoo`0VOol00`00
Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`0KOol003Qoo`80011oo`03001oogoo02=oo`03001o
ogoo06Uoo`03001oogoo02=oo`03001oogoo05aoo`8003aoo`03001oogoo02Ioo`03001oogoo049o
o`03001oogoo02Ioo`03001oogoo01]oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007oo
Ool03Woo00<007ooOol09Goo00<007ooOol0Igoo00<007ooOol09Goo00<007ooOol0>Woo0`001Woo
0P0017oo1@0017oo10001Goo00<007ooOol0>goo00<007ooOol09Woo00<007ooOol0@Woo00<007oo
Ool09Woo00<007ooOol06goo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03
001oogoo009oo`03001oogoo00eoo`03001oogoo02Moo`03001oogoo06Eoo`03001oogoo02Moo`03
001oogoo03Qoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<0
07ooOol0>Woo00<007ooOol0:7oo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol06Woo000>
Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol037oo
00<007ooOol0:Goo00<007ooOol0Hgoo00<007ooOol0:Goo00<007ooOol0;goo1P000Woo00D007oo
Oomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo03Yoo`03001oogoo02Qoo`03
001oogoo041oo`03001oogoo02Qoo`03001oogoo01Yoo`005Woo00D007ooOomoo`0000ioo`03001o
ogoo00Moo`03001oogoo009oo`8000aoo`03001oogoo02]oo`03001oogoo069oo`03001oogoo02Yo
o`03001oogoo03Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000kOol0
0`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`0JOol001Ioo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`0;Ool00`00Oomoo`0[Ool00`00Oomoo`1Q
Ool00`00Oomoo`0/Ool00`00Oomoo`0eOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo
00<007ooOol0>Goo00<007ooOol0:Woo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol06Goo
000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol02Woo00<0
07ooOol0;Goo00<007ooOol0Ggoo00<007ooOol0;Woo00<007ooOol0=7oo00D007ooOomoo`0000mo
o`03001oogoo009oo`03001oogoo00Ioo`03001oogoo03Uoo`03001oogoo02Yoo`03001oogoo03io
o`03001oogoo02Yoo`03001oogoo01Uoo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004
Ool00`00Oomoo`06Ool2000:Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool00`00
Oomoo`0cOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8003Yoo`03
001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo01Uoo`005goo0`003Goo0`00
1Goo10001Goo00<007ooOol027oo00<007ooOol0<Goo00<007ooOol0G7oo00<007ooOol0<Goo00<0
07ooOol0<goo0`003Goo0`001Goo10001Goo00<007ooOol0>7oo00<007ooOol0;7oo00<007ooOol0
?Goo00<007ooOol0:goo00<007ooOol067oo000hOol00`00Oomoo`07Ool00`00Oomoo`0cOol00`00
Oomoo`1JOol00`00Oomoo`0cOol00`00Oomoo`1COol00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00
Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`0HOol003Qoo`03001oogoo00Ioo`03001oogoo01Io
o`<000Ioo`8000Aoo`D000Yoo`03001oogoo00]oo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eo
o`<0011oo`03001oogoo00Moo`<000Ioo`8000Eoo`<001Uoo`03001oogoo00Eoo`D004Uoo`03001o
ogoo01moo`<000Ioo`8000Aoo`D000Eoo`03001oogoo011oo`<000Ioo`8000Ioo`<000Qoo`03001o
ogoo00eoo`<000Ioo`8000Eoo`<001Uoo`@000Eoo`8000Eoo`<001moo`03001oo`0000@001Aoo`00
>7oo0P001goo00<007ooOol05Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000;Ool00`00
Oomoo`09Ool01@00Oomoogoo00001Goo0P001goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`80
00Aoo`05001oogooOol0000>Ool00`00Oomoo`07Ool01@00Oomoogoo00001Goo0P0017oo00D007oo
Oomoo`0001Uoo`03001oogoo00Ioo`03001oogoo04Uoo`8001moo`05001oogooOol00005Ool20005
Ool01000Oomoo`001Goo00<007ooOol03goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo00Mo
o`03001oogoo00aoo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00005goo00D007ooOomo
o`0000Eoo`8000Aoo`05001oogooOol0000OOol01000Oomoo`005Woo000hOol00`00Oomoo`05Ool0
0`00Oomoo`0FOol01@00Oomoogoo00003Goo00<007ooOol037oo00<007ooOol027oo00D007ooOomo
o`0000]oo`D001Moo`05001oogooOol0000;Ool01@00Oomoogoo00003Goo00<007ooOol027oo00D0
07ooOomoo`0000]oo`05001oogooOol0000JOol00`00Oomoo`05Ool00`00Oomoo`19Ool00`00Oomo
o`0NOol01@00Oomoogoo00003Goo00<007ooOol017oo00<007ooOol047oo00D007ooOomoo`0000]o
o`D000Uoo`03001oogoo00]oo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00<007ooOol0
0P002goo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`03001oogoo00Aoo`03001oogoo
01Moo`05001oogooOol0000>Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool01@00Oomoogoo00002goo
00@007ooOol001Qoo`05001oogooOol0000;Ool01@00Oomoogoo000037oo00<007ooOol02Goo00D0
07ooOomoo`0000]oo`05001oogooOol0000KOol00`00Oomoo`04Ool00`00Oomoo`19Ool00`00Oomo
o`0NOol01@00Oomoogoo00003Woo00<007ooOol00goo00<007ooOol047oo00D007ooOomoo`0000]o
o`04001oogoo000:Ool00`00Oomoo`0;Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`03
001oogoo008000]oo`05001oogooOol0000OOol01000Oomoo`005Woo000hOol00`00Oomoo`03Ool0
0`00Oomoo`0HOol01@00Oomoogoo00003goo00<007ooOol02goo00<007ooOol01goo00D007ooOomo
o`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool4000=Ool00`00Oomoo`09Ool01@00Oomo
ogoo000037oo0`0077oo00<007ooOol017oo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomo
o`0000moo`03001oogoo009oo`03001oogoo011oo`05001oogooOol0000<Ool00`00Ool0000:Ool0
0`00Oomoo`0;Ool01@00Oomoogoo00002goo100067oo00<007ooOol00P0037oo0`008Goo00<007oo
00005Woo000hOol20004Ool00`00Oomoo`0HOol01@00Oomoogoo00003goo00<007ooOol037oo00<0
07ooOol01Woo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomo
o`0=Ool00`00Oomoo`0:Ool01@00Oomoogoo00002goo00D007ooOomoo`0001aoo`03001oogoo00=o
o`03001oogoo04Uoo`8001moo`05001oogooOol0000?Ool01@00Oomoogoo00004goo00D007ooOomo
o`0000aoo`03001oo`0000]oo`03001oogoo00Yoo`05001oogooOol0000;Ool00`00Oomoo`0IOol0
1@00Ool007oo00002goo00D007ooOomoo`00021oo`03001oo`0001Ioo`00>7oo00<007ooOol00Woo
00<007ooOol06Goo00D007ooOomoo`0000]oo`05001oogooOol0000?Ool00`00Oomoo`05Ool01@00
Oomoogoo00003Goo0P0067oo00D007ooOomoo`0000aoo`03001oogoo00]oo`03001oogoo00]oo`05
001oogooOol0000;Ool01@00Oomoogoo00007Goo00<007ooOol00Woo00<007ooOol0BGoo00<007oo
Ool07Woo00D007ooOomoo`0000]oo`05001oogooOol00003Ool00`00Oomoo`0AOol01@00Oomoogoo
00003Goo0P002goo00<007ooOol02Woo00D007ooOomoo`0000aoo`03001oogoo01Qoo`05001oo`00
Ool0000;Ool01@00Oomoogoo000087oo00<007oo00005Woo000hOol01@00Oomoogoo00007Goo0`00
3Goo0`004Goo00<007ooOol01Goo0`003goo00<007ooOol05goo0`003Woo0`002Goo00<007ooOol0
3Goo0`003Goo0`007goo00<007oo00000P00Bgoo00<007ooOol07goo0`003Goo0`0017oo00<007oo
Ool04Woo0`003goo00<007ooOol02Goo00<007ooOol02goo0`003Woo0`0067oo0`003Goo0`008Goo
0`005Woo000hOol200000goo001oo`12Ool00`00Oomoo`1<Ool00`00Oomoo`10Ool00`00Oomoo`1=
Ool2000fOol00`00Oomoo`0bOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`0EOol003Qo
o`04001oogoo0013Ool00`00Oomoo`1<Ool00`00Oomoo`11Ool00`00Oomoo`1<Ool00`00Oomoo`0e
Ool00`00Oomoo`0bOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`0EOol003Qoo`03001o
o`0004Eoo`03001oogoo04Yoo`03001oogoo04=oo`03001oogoo04]oo`03001oogoo03Eoo`03001o
ogoo039oo`03001oogoo03Ioo`03001oogoo03=oo`03001oogoo01Aoo`00>7oo0P00Agoo00<007oo
Ool0B7oo00<007ooOol0AGoo00<007ooOol0BWoo00<007ooOol0=7oo00<007ooOol0=7oo00<007oo
Ool0=7oo00<007ooOol0=7oo00<007ooOol057oo000bOooY0010OooY000@Ool003Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Eoo`04001oogoo000:Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool01@00Oomoogoo00001Woo00<007ooOol027oo00<0
07ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol0BGoo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol057oo000hOol00`00Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`2D
Ool00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0cOol00`00Oomoo`1<Ool003Qoo`8004Yo
o`03001oogoo049oo`03001oogoo09Eoo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03001o
ogoo04aoo`00>7oo00<007ooOol0BWoo00<007ooOol0@7oo00<007ooOol0UWoo0P00=7oo00<007oo
Ool0=Woo00<007ooOol0<Woo00<007ooOol0C7oo000hOol00`00Oomoo`1:Ool00`00Oomoo`10Ool0
0`00Oomoo`2FOol2000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`1<Ool003Qoo`03
001oogoo04]oo`03001oogoo03ioo`03001oogoo09Moo`03001oo`00039oo`03001oogoo03Qoo`03
001oogoo031oo`03001oogoo04eoo`00>7oo0P00CGoo00<007ooOol0?7oo00<007ooOol0V7oo0`00
<Woo00<007ooOol0>7oo00<007ooOol0<7oo00<007ooOol0CGoo000hOol00`00Oomoo`1=Ool00`00
Oomoo`0jOol00`00Oomoo`2IOol00`00Ool0000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00
Oomoo`1=Ool003Qoo`03001oogoo04eoo`03001oogoo03Yoo`03001oogoo09Uoo`04001oogoo000`
Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`1>Ool003Qoo`03001oogoo04ioo`03001o
ogoo03Qoo`03001oogoo09Yoo`04001oogoo000`Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00
Oomoo`1>Ool003Qoo`80051oo`03001oogoo03Ioo`03001oogoo09]oo`800003Ool007oo02moo`03
001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo00<007ooOol0D7oo00<007ooOol0
=7oo00<007ooOol0W7oo00D007ooOomoo`0002ioo`03001oogoo03aoo`03001oogoo02aoo`03001o
ogoo04moo`00>7oo00<007ooOol0D7oo00<007ooOol0=7oo00<007ooOol0W7oo00D007ooOomoo`00
02ioo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo04moo`00>7oo0P00DWoo00<007ooOol0
<Woo00<007ooOol0WGoo0P000Woo00<007ooOol0;7oo00<007ooOol0?7oo00<007ooOol0;7oo00<0
07ooOol0Cgoo000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`1BOol00`00Oomoo`0`
Ool00`00Oomoo`1mOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`02Ool00`00Oomoo`0Z
Ool00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05001oogooOol00005Ool2
0005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0DWoo00<007ooOol0;goo00<007oo
Ool0OGoo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05
001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`0]
Ool00`00Oomoo`1nOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol0:Woo00<007ooOol0?Woo00<007ooOol0:Woo00<007ooOol0D7oo000FOol0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00EGoo00<007ooOol0:goo00<0
07ooOol0Ogoo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000Aoo`03001o
ogoo02Uoo`03001oogoo03moo`03001oogoo02Qoo`03001oogoo055oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`@000Eoo`03001oogoo05Eoo`03001oogoo02Yoo`03001oogoo07moo`05
001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`03Ool00`00Oomoo`0XOol00`00
Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`1AOol001Ioo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`1FOol00`00Oomoo`0XOol00`00Oomoo`20Ool01@00Oomo
ogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0:7oo00<0
07ooOol0@7oo00<007ooOol0:7oo00<007ooOol0DGoo000FOol01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`8005Qoo`03001oogoo02Ioo`03001oogoo085oo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P001Goo00<007ooOol09goo00<007oo
Ool0@Goo00<007ooOol09goo00<007ooOol0DGoo000GOol3000=Ool30005Ool40005Ool00`00Oomo
o`1HOol00`00Oomoo`0TOol00`00Oomoo`23Ool3000=Ool30005Ool40005Ool00`00Oomoo`04Ool0
0`00Oomoo`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomoo`1BOol003Qoo`03001oogoo
05Uoo`80029oo`800:Moo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo
02Ioo`03001oogoo059oo`00>7oo00<007ooOol0Fgoo00<007ooOol07Woo00<007ooOol0Ygoo00<0
07ooOol01Goo00<007ooOol09Goo00<007ooOol0@goo00<007ooOol09Goo00<007ooOol0DWoo000h
Ool2001MOol00`00Oomoo`0LOol00`00Oomoo`2XOol20006Ool00`00Oomoo`0TOol00`00Oomoo`14
Ool00`00Oomoo`0TOol00`00Oomoo`1COol003Qoo`03001oogoo05eoo`03001oogoo01Yoo`03001o
ogoo0:Uoo`03001oogoo00Eoo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001o
ogoo05=oo`00>7oo00<007ooOol0GWoo0P0067oo0P00[7oo00<007ooOol01Woo00<007ooOol08goo
00<007ooOol0AGoo00<007ooOol08goo00<007ooOol0Dgoo000hOol2001QOol00`00Oomoo`0DOol0
0`00Oomoo`2/Ool20007Ool00`00Oomoo`0ROol00`00Oomoo`16Ool00`00Oomoo`0ROol00`00Oomo
o`1DOol003Qoo`03001oogoo065oo`03001oogoo019oo`03001oogoo0:eoo`03001oogoo00Ioo`03
001oogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo05Aoo`00>7oo00<007ooOol0
HWoo0`003goo0P00/7oo00<007ooOol01goo00<007ooOol08Goo00<007ooOol0Agoo00<007ooOol0
8Goo00<007ooOol0E7oo000hOol00`00Oomoo`1UOol2000;Ool2002bOol00`00Oomoo`07Ool00`00
Oomoo`0POol00`00Oomoo`18Ool00`00Oomoo`0POol00`00Oomoo`1EOol003Qoo`8006Qoo`/00;Ao
o`8000Qoo`03001oogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001oogoo05Eoo`007goo
0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0
27oo00<007ooOol07goo00<007ooOol0BGoo00<007ooOol07goo00<007ooOol0EGoo000NOol01@00
Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eo
o`8000Uoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo01ioo`03001oogoo04Yoo`03001o
ogoo01ioo`03001oogoo05Ioo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo
0?moo`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`0NOol0
0`00Oomoo`1;Ool00`00Oomoo`0MOol00`00Oomoo`1FOol001ioo`05001oogooOol0000@Ool00`00
Oomoo`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P002Woo00<007ooOol0
77oo00<007ooOol0C7oo00<007ooOol07Goo00<007ooOol0EWoo000NOol01@00Oomoogoo000037oo
10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo00Uoo`03001o
ogoo01aoo`03001oogoo04eoo`03001oogoo01]oo`03001oogoo05Moo`007Woo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool0
0`00Oomoo`09Ool00`00Oomoo`0KOol00`00Oomoo`1>Ool00`00Oomoo`0KOol00`00Oomoo`1GOol0
01ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<0
07ooOol01Woo0P002goo00<007ooOol06Woo00<007ooOol0CWoo00<007ooOol06Woo00<007ooOol0
F7oo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`0:Ool0
0`00Oomoo`0JOol00`00Oomoo`1?Ool00`00Oomoo`0IOol00`00Oomoo`1HOol003Qoo`03001oogoo
0?moobMoo`03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo051oo`03001oogoo01Uoo`03001o
ogoo05Qoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol02goo00<007ooOol067oo00<007ooOol0
DGoo00<007ooOol05goo00<007ooOol0FGoo000hOol2003oOolXOol2000<Ool00`00Oomoo`0GOol0
0`00Oomoo`1BOol00`00Oomoo`0GOol00`00Oomoo`1IOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo00aoo`03001oogoo01Ioo`03001oogoo059oo`03001oogoo01Ioo`03001oogoo05Yoo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol037oo00<007ooOol05Goo00<007ooOol0E7oo00<007ooOol0
5Goo00<007ooOol0FWoo000hOol2003oOolXOol2000>Ool00`00Oomoo`0DOol00`00Oomoo`1DOol0
0`00Oomoo`0DOol00`00Oomoo`1KOol003Qoo`03001oogoo0?moobMoo`03001oogoo00eoo`03001o
ogoo01Aoo`03001oogoo05Eoo`03001oogoo019oo`03001oogoo05aoo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0
G7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`1GOol0
0`00Oomoo`0@Ool00`00Oomoo`1MOol003Qoo`800?moobQoo`8000moo`03001oogoo015oo`03001o
ogoo05Qoo`03001oogoo011oo`03001oogoo05eoo`005goo0`001Woo0P001Woo00<007ooOol017oo
10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0
3goo0P004Goo00<007ooOol0FGoo00<007ooOol03Woo00<007ooOol0GWoo000FOol01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo015oo`03001oogoo00eo
o`03001oogoo05Yoo`03001oogoo00ioo`03001oogoo05ioo`005Woo00D007ooOomoo`0000ioo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`0;Ool2001NOol2000=Ool00`00Oomo
o`1OOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P004goo00<007ooOol02Goo00<0
07ooOol0H7oo00<007ooOol02Goo00<007ooOol0H7oo000FOol01@00Oomoogoo00003Woo00<007oo
Ool00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eo
o`03001oogoo01=oo`03001oogoo00Moo`03001oogoo069oo`03001oogoo00Moo`03001oogoo065o
o`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eo
o`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0DOol00`00Oomo
o`05Ool00`00Oomoo`1TOol00`00Oomoo`05Ool00`00Oomoo`1ROol001Ioo`05001oogooOol0000;
Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001o
ogooOol00004Ool00`00Oomoo`06Ool2000FOol30002Ool2001XOol20003Ool2001UOol001Moo`<0
00aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo01Mo
o`@006Yoo`@006Moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000_
Ool50004Ool00`00Oomoo`3oOolNOol50004Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03
001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo
8Goo00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03
001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000a
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo
003oOoooOomFOol009Eoo`<00004Ool00000000HOol3003oOol7Ool3000017oo000000006Goo0`00
M7oo002FOol01@00Oomoogoo00002Goo1P002Goo00D007ooOomoo`000?moo`Moo`05001oogooOol0
0009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05001oogooOol0000LOol00`00Oomoo`3oOol5Ool0
1@00Oomoogoo000067oo1@00M7oo002FOol01@00Oomoogoo00002Goo1P003Goo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000Uoo`H000Uoo`04001oogoo001eOol009Ioo`05001oogooOol0000JOol2
003oOol8Ool01@00Oomoogoo00006Goo00<007oo0000MGoo002EOol5000MOol00`00Oomoo`3oOol4
Ool5000JOol00`00Ool0001eOol00;=oo`05001oogooOol0003oOolVOol2001eOol00;Aoo`<00?mo
obQoo`03001oogoo07=oo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo000_Ool5003oOolUOol5003gOol0035oo`03001oogoo0?moobMoo`03
001oogoo0?Moo`009Woo1P001Goo00<007ooOol0ogoo77oo1P001Goo00<007ooOol0mgoo000aOol0
0`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0
ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00
Oomoo`04Ool2000aOol8002hOol002moo`<000Ioo`03001oogoo0?mooaioo`<000Ioo`03001oogoo
02aoo`D000Moo`<00;Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0:goo00<007ooOol03Goo
0P00/goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0ZOol00`00Oomoo`0@Ool2002aOol003Qo
o`800?moobQoo`8002Uoo`8001Eoo`<00:ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol09Goo
0`006Woo00<007ooOol0Zgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0TOol00`00Oomoo`0L
Ool00`00Oomoo`2ZOol003Qoo`800?moobQoo`8002Aoo`03001oogoo01ioo`03001oogoo0:Uoo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol08Woo00<007ooOol087oo00<007ooOol0Z7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`0QOol00`00Oomoo`0ROol00`00Oomoo`2WOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo025oo`03001oogoo029oo`03001oogoo0:Moo`00>7oo0P00ogoo:7oo
0P008Goo00<007ooOol097oo00<007ooOol0YWoo000GOol30006Ool20006Ool00`00Oomoo`04Ool4
0005Ool00`00Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`0O
Ool00`00Oomoo`0VOol00`00Oomoo`2UOol001Ioo`05001oogooOol00005Ool20006Ool00`00Oomo
o`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Woo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol0:7oo00<007ooOol0Y7oo000>Ool6
0002Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0o7oo1P00
0Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo01ioo`03001o
ogoo02Uoo`03001oogoo0:=oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo
009oo`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000NOol0
0`00Oomoo`0[Ool00`00Oomoo`2ROol001Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0
77oo00<007ooOol0;7oo00<007ooOol0XWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001o
ogoo00Ioo`03001oogoo01aoo`03001oogoo02eoo`03001oogoo0:5oo`005Woo00D007ooOomoo`00
00]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D0
07ooOomoo`0000Aoo`03001oogoo00Ioo`8001aoo`03001oogoo02moo`03001oogoo0:1oo`005goo
0`0037oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`0037oo1@0017oo10001Goo00<007ooOol0
6Woo00<007ooOol0<Goo00<007ooOol0Wgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0IOol0
0`00Oomoo`0cOol00`00Oomoo`2NOol003Qoo`03001oogoo0?moobMoo`03001oogoo01Uoo`03001o
ogoo03=oo`03001oogoo09ioo`00>7oo0P00ogoo:7oo0P006Goo00<007ooOol0=Goo00<007ooOol0
WGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0GOol00`00Oomoo`0gOol00`00Oomoo`2LOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo01Ioo`03001oogoo03Qoo`03001oogoo09aoo`00>7oo
0P00ogoo:7oo0P005goo00<007ooOol0>Goo00<007ooOol0Vgoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0EOol00`00Oomoo`0kOol00`00Oomoo`2JOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo01Aoo`03001oogoo03eoo`03001oogoo09Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
57oo00<007ooOol0?Goo00<007ooOol0VGoo000hOol2003oOolXOol2000DOol00`00Oomoo`0oOol0
0`00Oomoo`2HOol001moo`<000Ioo`8000Eoo`@000Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eo
o`@000Eoo`03001oogoo019oo`03001oogoo045oo`03001oogoo09Moo`007Woo00D007ooOomoo`00
00Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol00005Ool20009Ool0
0`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`12Ool00`00Oomoo`2GOol001Ioo`H0009oo`05
001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol6Ool60002Ool01@00Oomoogoo000047oo00<0
07ooOol00Woo0P004Woo00<007ooOol0@goo00<007ooOol0UWoo000NOol01@00Oomoogoo000047oo
00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`00011oo`03001oogoo009oo`03001o
ogoo011oo`03001oogoo04Eoo`03001oogoo09Eoo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03
001oogoo0?moo`eoo`05001oogooOol0000<Ool40005Ool00`00Oomoo`0?Ool00`00Oomoo`16Ool0
0`00Oomoo`2EOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool0
1@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol03goo00<007ooOol0Agoo00<007ooOol0
U7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00ogoo3Woo00D007ooOomoo`0000ao
o`03001oogoo00Ioo`8000moo`03001oogoo04Qoo`03001oogoo09Aoo`007goo0`003Goo10001Goo
00<007ooOol0ogoo3Woo0`003Goo10001Goo00<007ooOol03Woo00<007ooOol0BGoo00<007ooOol0
Tgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0=Ool00`00Oomoo`1;Ool00`00Oomoo`2BOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo00eoo`03001oogoo04]oo`03001oogoo099oo`00>7oo
0P00ogoo:7oo0P003Goo00<007ooOol0CGoo00<007ooOol0TGoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0<Ool00`00Oomoo`1=Ool00`00Oomoo`2AOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo00]oo`03001oogoo04moo`03001oogoo091oo`00>7oo0P00ogoo:7oo0P002goo00<007ooOol0
DGoo00<007ooOol0Sgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0:Ool00`00Oomoo`1AOol0
0`00Oomoo`2?Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Uoo`03001oogoo05=oo`03001o
ogoo08ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol02Goo00<007ooOol0Dgoo00<007ooOol0
SWoo000hOol2003oOolXOol20009Ool00`00Oomoo`1EOol00`00Oomoo`2=Ool001Moo`<000Ioo`80
00Aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001o
ogoo00Qoo`03001oogoo05Ioo`03001oogoo08aoo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04
001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Goo
00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo05Moo`03001oogoo08ao
o`003Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`800?eoo`H0
009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`1H
Ool00`00Oomoo`2;Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol0FGoo00<007ooOol0Rgoo000FOol01@00Oomoogoo00003goo00<007ooOol0
0Woo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03
001oogoo00Ioo`03001oogoo05Yoo`03001oogoo08Yoo`005Woo00D007ooOomoo`0000moo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`1KOol00`00Oomoo`2:Ool001Ioo`05001o
ogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`00
00]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20006Ool00`00Oomoo`1LOol00`00Oomoo`29
Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo0?moo`Ioo`<000eoo`<000Eoo`@000Eoo`03
001oogoo00Aoo`03001oogoo05eoo`03001oogoo08Uoo`00>7oo00<007ooOol07goo0`001Woo0P00
17oo1@0067oo0`001Woo0P001Woo0`0067oo0`001Woo0P001Goo0`006Woo0`001Woo0P001Goo0`00
8Goo1@00BGoo00<007ooOol017oo00<007ooOol067oo0`001Woo0P0017oo1@0067oo0`001Woo0P00
1Woo0`001Woo00<007ooOol03goo0`001Woo0P001Goo0`006Goo0`001Woo0P001Goo0`008Goo1@00
57oo000hOol2000OOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol0
0005Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Qo
o`05001oogooOol00005Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo0P0017oo00<0
07ooOol067oo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomoogoo00001Goo
0P001goo00<007ooOol01Goo00<007ooOol03Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogoo
Ool0000GOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo01Aoo`00
>7oo00<007ooOol07Woo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5
000GOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomo
ogoo00008Woo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol067oo00D007ooOomoo`0000eo
o`03001oogoo01Moo`05001oogooOol0000;Ool50007Ool00`00Oomoo`0=Ool01@00Oomoogoo0000
2goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0
57oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`00
00]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0
000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol00Woo00<007ooOol06Goo00D0
07ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000Oomoo`002Goo00<007oo
Ool037oo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00002goo00D007oo
Oomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000moo`03001o
ogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10006Goo00D0
07ooOomoo`0000aoo`<002=oo`03001oogoo04Uoo`05001oogooOol0000LOol01@00Oomoogoo0000
3goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0000Uoo`03001oogoo00aoo`05001o
ogooOol0000;Ool4000HOol01@00Oomoogoo000037oo0`008goo00<007ooOol057oo000hOol2000O
Ool01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05
001oogooOol0000;Ool00`00Oomoo`0JOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03
001oogoo04Uoo`80009oo`03001oogoo01Yoo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00
Oomoogoo000037oo00<007oo00002Woo00<007ooOol02goo00D007ooOomoo`0000]oo`03001oogoo
01Uoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomo
o`0NOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000=Ool2000HOol0
1@00Oomoogoo000037oo00<007ooOol06Goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol0
0`00Oomoo`19Ool01000Oomoo`007Goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00
Oomoogoo00003Goo0P002Woo00<007ooOol02goo00D007ooOomoo`0000aoo`03001oogoo01Qoo`05
001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0OOol3
000=Ool3000IOol3000?Ool00`00Oomoo`0GOol3000>Ool3000IOol3000=Ool3000QOol3001;Ool0
1000Oomoo`007Woo0`003Goo0`006Goo0`003goo00<007ooOol02Goo00<007ooOol02goo0`003Woo
0`0067oo0`003Goo0`008Goo0`005Woo000hOol00`00Oomoo`3oOolWOol00`00Ool0001YOol00`00
Oomoo`24Ool003Qoo`800?moobQoo`<006Yoo`03001oogoo08=oo`00>7oo00<007ooOol0ogoo9goo
0P00Jgoo00<007ooOol0Pgoo000hOol00`00Oomoo`3oOolWOol2001/Ool00`00Oomoo`22Ool0039o
onT0041oonT0011oo`00>7oo00<007ooOol01@000goo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00@007ooOomoo`D0009oo`03001oogoo04Uoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`8000Uoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo00<007ooOol01Goo
1`007Goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol06goo1`001goo
00<007ooOol0BGoo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol057oo00<007ooOol04Woo
00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol057oo000hOol00`00Oomoo`0<Ool7002`Ool9
001JOol00`00Oomoo`1]Ool00`00Oomoo`1XOol00`00Oomoo`0EOol003Qoo`8001Aoo`D00:Aoo`L0
06=oo`8006ioo`03001oogoo06Qoo`03001oogoo01Eoo`00>7oo00<007ooOol067oo1`00V7oo1@00
JWoo00<007ooOol0KWoo00<007ooOol0IWoo00<007ooOol05Woo000hOol00`00Oomoo`0OOol90029
Ool6001_Ool00`00Oomoo`1^Ool00`00Oomoo`1VOol00`00Oomoo`0FOol003Qoo`8002Uoo`T007Mo
o`T007Eoo`80071oo`03001oogoo06Aoo`03001oogoo01Moo`00>7oo00<007ooOol0<Goo2@00I7oo
2P00OWoo00<007ooOol0Kgoo00<007ooOol0I7oo00<007ooOol05goo000hOol00`00Oomoo`0jOol:
001AOol90028Ool00`00Oomoo`1`Ool00`00Oomoo`1ROol00`00Oomoo`0HOol003Qoo`03001oogoo
04Aoo`T003moo`T0095oo`03001oogoo071oo`03001oogoo065oo`03001oogoo01Uoo`00>7oo0P00
CWoo?`00VWoo0P00LGoo00<007ooOol0HGoo00<007ooOol06Goo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`1aOol00`00Oomoo`1OOol00`00Oomoo`0JOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo075oo`03001oogoo05moo`03001oogoo01Yoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
LWoo00<007ooOol0GGoo00<007ooOol06goo000hOol2003oOolXOol2001cOol00`00Oomoo`1MOol0
0`00Oomoo`0KOol001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Io
o`8000Aoo`D000Aoo`@000Eoo`03001oogoo07=oo`03001oogoo05]oo`03001oogoo01aoo`005Woo
00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo07=o
o`03001oogoo05]oo`03001oogoo01aoo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03
001oogoo009oo`800?moo`Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2
001eOol00`00Oomoo`1IOol00`00Oomoo`0MOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol0M7oo00<007ooOol0FGoo00<007ooOol07Goo000FOol01@00Oomoogoo
00003goo00<007ooOol00Woo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001o
ogoo009oo`@000Eoo`03001oogoo07Eoo`03001oogoo05Moo`03001oogoo01ioo`005Woo00D007oo
Oomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0
000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`1fOol00`00Oomoo`1FOol00`00Oomo
o`0NOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo
1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001gOol00`00Oomo
o`1EOol00`00Oomoo`0OOol001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo0?moo`Ioo`<000eo
o`<000Eoo`@000Eoo`03001oogoo07Moo`03001oogoo05=oo`03001oogoo021oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0Mgoo00<007ooOol0Dgoo00<007ooOol087oo000hOol2003oOolXOol2
001iOol00`00Oomoo`1AOol00`00Oomoo`0QOol003Qoo`03001oogoo0?moobMoo`03001oogoo07Uo
o`03001oogoo051oo`03001oogoo025oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0NGoo00<0
07ooOol0Cgoo00<007ooOol08Woo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1jOol00`00Oomo
o`1>Ool00`00Oomoo`0ROol003Qoo`800?moobQoo`8007aoo`03001oogoo04aoo`03001oogoo02=o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Ngoo00<007ooOol0C7oo00<007ooOol08goo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`1lOol00`00Oomoo`1:Ool00`00Oomoo`0TOol003Qoo`80
0?moobQoo`8007eoo`03001oogoo04Uoo`03001oogoo02Eoo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0OGoo00<007ooOol0B7oo00<007ooOol09Goo000OOol30006Ool20005Ool40005Ool00`00
Oomoo`3oOol>Ool30006Ool20005Ool40005Ool00`00Oomoo`1nOol00`00Oomoo`16Ool00`00Oomo
o`0VOol001ioo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool0
1@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0OWoo00<007ooOol0AWoo00<0
07ooOol09Woo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00ogoo3Woo00D007ooOomo
o`00011oo`03001oogoo009oo`80081oo`03001oogoo04Aoo`03001oogoo02Moo`007Woo00D007oo
Oomoo`00011oo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool00`00Oomo
o`02Ool00`00Oomoo`20Ool00`00Oomoo`12Ool00`00Oomoo`0XOol001ioo`05001oogooOol0000<
Ool40005Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0P7oo00<0
07ooOol0@Woo00<007ooOol0:7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007oo
Ool0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo085oo`03001oogoo041o
o`03001oogoo02Uoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?moo`ioo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool20023Ool00`00Oomoo`0nOol00`00Oomoo`0ZOol001moo`<0
00eoo`@000Eoo`03001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo089oo`03001oogoo03io
o`03001oogoo02Yoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Pgoo00<007ooOol0?7oo00<0
07ooOol0:goo000hOol2003oOolXOol20024Ool00`00Oomoo`0kOol00`00Oomoo`0/Ool003Qoo`03
001oogoo0?moobMoo`03001oogoo08Aoo`03001oogoo03Yoo`03001oogoo02aoo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0QGoo00<007ooOol0>7oo00<007ooOol0;Goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`25Ool00`00Oomoo`0gOol00`00Oomoo`0^Ool003Qoo`800?moobQoo`8008Mo
o`03001oogoo03Ioo`03001oogoo02ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Qgoo00<0
07ooOol0=7oo00<007ooOol0;goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`27Ool00`00Oomo
o`0cOol00`00Oomoo`0`Ool003Qoo`800?moobQoo`8008Uoo`03001oogoo039oo`03001oogoo031o
o`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P00
1Woo00<007ooOol017oo10001Goo00<007ooOol0RGoo00<007ooOol0<7oo00<007ooOol0<Goo000F
Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo08Uo
o`03001oogoo02moo`03001oogoo039oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`2:Ool00`00Oomoo`0]Ool00`00Oomoo`0cOol001Ioo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo0P00S7oo00<007ooOol0:goo00<007ooOol0=7oo000FOol01@00Oomoogoo
00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001o
ogoo00=oo`@000Eoo`03001oogoo08aoo`03001oogoo02Yoo`03001oogoo03Aoo`005Woo00D007oo
Oomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0
000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`2=Ool00`00Oomoo`0XOol00`00Oomo
o`0eOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007oo
Ool0ogoo1Goo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomo
o`2>Ool00`00Oomoo`0VOol00`00Oomoo`0fOol001Moo`<000aoo`D000Aoo`@000Eoo`800?moo`Mo
o`<000aoo`D000Aoo`@000Eoo`80091oo`03001oogoo02Aoo`03001oogoo03Moo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0T7oo0P008Woo0P00>Woo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`2BOol00`00Oomoo`0NOol00`00Oomoo`0jOol003Qoo`800?moobQoo`8009Aoo`03001oogoo01ao
o`03001oogoo03]oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0U7oo00<007ooOol06Woo00<0
07ooOol0?7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2EOol2000IOol00`00Oomoo`0mOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo09Moo`03001oogoo01Eoo`03001oogoo03ioo`00>7oo
0P00ogoo:7oo0P00VGoo00<007ooOol04Woo0P00@Goo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`2IOol3000>Ool30013Ool003Qoo`03001oogoo0?moobMoo`03001oogoo09aoo`8000]oo`03001o
ogoo04Aoo`00>7oo0P00ogoo:7oo0P00Wgoo2`00Agoo000_Ool50004Ool00`00Oomoo`3oOolNOol5
0004Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Ao
o`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<0
07ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03
001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000a
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo
003oOoooOomFOol009Eoo`<00004Ool00000000HOol5003oOol5Ool3000017oo000000005goo1@00
M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uo
o`H000Yoo`04001oogoo001dOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00
Oomoogoo00006Woo00<007ooOol0M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0
ogoo1Woo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001]o
o`03001oogoo0?moo`Ioo`05001oogooOol0000LOol00`00Oomoo`1bOol009Eoo`D001aoo`03001o
ogoo0?moo`Eoo`D001eoo`03001oogoo079oo`00]Woo00<007ooOol0ogoo8goo00D007ooOomoo`00
07Aoo`00]7oo0`00ogoo9Woo0`00MGoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.14918 .30902 L
.15465 .30902 L
.15946 .30902 L
.16457 .30902 L
.16917 .30902 L
.17178 .30902 L
.17423 .30902 L
.17538 .30902 L
.17647 .30902 L
.17746 .30902 L
.17852 .30902 L
.17967 .30902 L
.18073 .30902 L
.182 .30902 L
.18314 .30902 L
.18435 .30902 L
.18547 .30902 L
.1867 .30902 L
.18802 .30902 L
.19071 .30902 L
.19317 .30902 L
.1979 .30902 L
.20239 .30902 L
.21236 .30902 L
.22321 .30902 L
.24299 .30902 L
.26399 .30902 L
.30174 .30902 L
.34195 .30902 L
.38063 .30902 L
.40028 .30902 L
.42177 .30902 L
.44253 .30902 L
.4614 .30902 L
.47149 .30902 L
.47611 .30902 L
.48101 .30902 L
.4835 .30902 L
.48624 .30902 L
.48876 .30902 L
.49106 .30902 L
.49378 .30902 L
.49527 .30902 L
.49596 .30902 L
Mistroke
.49669 .30902 L
.498 .30902 L
.49921 .30902 L
.49996 .30902 L
.50065 .30902 L
.50196 .30902 L
.50313 .30902 L
.50438 .30902 L
.50556 .30902 L
.50663 .30902 L
.50926 .30902 L
.51175 .30902 L
.5167 .30902 L
.52208 .30902 L
.53169 .30902 L
.54056 .30902 L
.55926 .30902 L
.57988 .30902 L
.62014 .30902 L
.65888 .30902 L
.70007 .30902 L
.72063 .30902 L
.73974 .30902 L
.75939 .30902 L
.77791 .30902 L
.78775 .30902 L
.79293 .30902 L
.7984 .30902 L
.80302 .30902 L
.80546 .30902 L
.80809 .30902 L
.8105 .30902 L
.8127 .30902 L
.81375 .30902 L
.81491 .30902 L
.81599 .30902 L
.817 .30902 L
.81818 .30902 L
.81941 .30902 L
.82047 .30902 L
.82163 .30902 L
.82287 .30902 L
.82421 .30902 L
.82661 .30902 L
.82905 .30902 L
.83134 .30902 L
.83564 .30902 L
.84078 .30902 L
.84552 .30902 L
.85624 .30902 L
Mistroke
.87498 .30902 L
.89561 .30902 L
.93591 .30902 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .45981 L
.08255 .52527 L
.0932 .55403 L
.10458 .57945 L
.11009 .58961 L
.11531 .59784 L
.12038 .60454 L
.12507 .60956 L
.12951 .61325 L
.13178 .61474 L
.13422 .61603 L
.13549 .61658 L
.13666 .617 L
.13784 .61736 L
.13895 .61762 L
.14022 .61785 L
.1409 .61793 L
.14161 .61799 L
.1423 .61803 L
.14295 .61803 L
.14415 .61799 L
.14531 .61787 L
.14656 .61767 L
.14773 .61739 L
.14881 .61708 L
.15143 .61606 L
.15392 .61475 L
.15886 .61117 L
.16423 .60583 L
.17383 .59259 L
.1827 .5763 L
.20137 .53043 L
.22197 .46442 L
.26217 .30793 L
.30086 .15709 L
.32051 .09318 L
.3309 .06498 L
.342 .03993 L
.35275 .02114 L
.35784 .01426 L
.36253 .00909 L
.36724 .00504 L
.36972 .00339 L
.37235 .00199 L
.37463 .00107 L
.37573 .00073 L
.37677 .00047 L
.37799 .00024 L
.37911 9e-05 L
Mistroke
.38031 1e-05 L
.38162 1e-05 L
.38227 5e-05 L
.38296 .00011 L
.38419 .00028 L
.38551 .00056 L
.38695 .00097 L
.38955 .00199 L
.39197 .00326 L
.39649 .00647 L
.40134 .01111 L
.40698 .01804 L
.41232 .02609 L
.42232 .0449 L
.44227 .09574 L
.4607 .15587 L
.50002 .3091 L
.53782 .45692 L
.55884 .52554 L
.56803 .55063 L
.57808 .57397 L
.58722 .59118 L
.59696 .60501 L
.60236 .61057 L
.60726 .6143 L
.60962 .61565 L
.61086 .61623 L
.61218 .61677 L
.61333 .61715 L
.61459 .6175 L
.61574 .61774 L
.61682 .6179 L
.61808 .61801 L
.61871 .61803 L
.61941 .61803 L
.62065 .61796 L
.62181 .61783 L
.62248 .61772 L
.62318 .61757 L
.62443 .61725 L
.62578 .61682 L
.62725 .61622 L
.62973 .61497 L
.63238 .61327 L
.63715 .60926 L
.64214 .6038 L
.64686 .59746 L
.6557 .5826 L
.67568 .53569 L
.69413 .4784 L
Mistroke
.7335 .32774 L
.77136 .17771 L
.79241 .10603 L
.81166 .05399 L
.82118 .03415 L
.8262 .0254 L
.83155 .01745 L
.8367 .01118 L
.84136 .00668 L
.84361 .00491 L
.84604 .00331 L
.84835 .00208 L
.85045 .0012 L
.85159 .00083 L
.85283 .0005 L
.85414 .00024 L
.85538 8e-05 L
.85653 1e-05 L
.85776 1e-05 L
.85881 7e-05 L
.85997 .00021 L
.86063 .00033 L
.86132 .00047 L
.86256 .00079 L
.86535 .00181 L
.86777 .00303 L
.87041 .00472 L
.87569 .00921 L
.88133 .0156 L
.89148 .03117 L
.90173 .05195 L
.91284 .07976 L
.933 .14228 L
.97393 .29982 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.44268 .30902 L
.45178 .30902 L
.46172 .30902 L
.4671 .30902 L
.4721 .30902 L
.47727 .30902 L
.48196 .30902 L
.48658 .30902 L
.4887 .30902 L
.49093 .30902 L
.49332 .30902 L
.49438 .30902 L
.49552 .30902 L
.49675 .30902 L
.49789 .30902 L
.49859 .30902 L
.49925 .30902 L
.50049 .30902 L
.50163 .30902 L
.50286 .30902 L
.50401 .30902 L
.50508 .30902 L
.50754 .30902 L
.51014 .30902 L
.51268 .30902 L
.51504 .30902 L
.5204 .30902 L
.5293 .30902 L
.53882 .30902 L
.54906 .30902 L
.56016 .30902 L
.58032 .30902 L
.62123 .30902 L
.66064 .30902 L
.69852 .30902 L
.73886 .30902 L
.77769 .30902 L
.81897 .30902 L
Mistroke
.85873 .30902 L
.89697 .30902 L
.93767 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .2311 L
.10458 .15203 L
.14415 .08865 L
.18221 .04174 L
.20178 .02399 L
.21267 .01616 L
.22272 .01027 L
.23293 .00563 L
.23832 .00373 L
.24402 .00215 L
.24641 .00161 L
.24897 .00112 L
.25119 .00077 L
.25361 .00046 L
.25507 .00031 L
.25643 .0002 L
.25773 .00012 L
.2584 8e-05 L
.25912 5e-05 L
.25983 3e-05 L
.26048 1e-05 L
.26176 0 L
.26293 1e-05 L
.26416 3e-05 L
.26538 8e-05 L
.26607 .00012 L
.26671 .00016 L
.26912 .00035 L
.27131 .00059 L
.27364 .00093 L
.27847 .00184 L
.2838 .00322 L
.29326 .00659 L
.30213 .01082 L
.32232 .02422 L
.34082 .04094 L
.38045 .08978 L
.41855 .15085 L
.45912 .22667 L
.49816 .30527 L
.53966 .38895 L
.57964 .46401 L
.61811 .52616 L
.63759 .55256 L
.65902 .57693 L
.67938 .59514 L
.69843 .60751 L
.70884 .61229 L
.71396 .61413 L
Mistroke
.71872 .61551 L
.72301 .61651 L
.72758 .61729 L
.7302 .61761 L
.73148 .61774 L
.73266 .61784 L
.73371 .6179 L
.73487 .61796 L
.73603 .61801 L
.73725 .61803 L
.73856 .61803 L
.73977 .61802 L
.7404 .618 L
.7411 .61797 L
.74251 .6179 L
.74375 .61782 L
.74508 .61771 L
.74748 .61744 L
.74985 .6171 L
.75235 .61667 L
.7568 .61568 L
.76198 .6142 L
.7668 .61251 L
.77773 .60753 L
.78828 .60125 L
.79823 .59404 L
.81683 .57728 L
.85534 .5301 L
.89632 .46443 L
.93577 .39045 L
.97371 .31407 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`8004moo`@006Yoo`@0031oo`00
<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0C7oo0`000goo
00<007ooOol0IWoo0P000goo0P00;Woo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00
Oomoo`04Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool00`00Oomoo`1TOol00`00Oomoo`05Ool00`00
Oomoo`0[Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo
04Yoo`03001oogoo00Moo`8006=oo`03001oogoo00Moo`03001oogoo02Yoo`00<Goo00<007ooOol0
17oo0P00ogoo8Goo00<007ooOol017oo0P00Bgoo00<007ooOol02Goo00<007ooOol0Ggoo00<007oo
Ool02Goo00<007ooOol0:Goo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`19
Ool00`00Oomoo`0:Ool00`00Oomoo`1OOol00`00Oomoo`09Ool00`00Oomoo`0YOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo04Uoo`03001oogoo00]oo`03001oogoo05eoo`03001oogoo00]oo`03
001oogoo02Qoo`00>7oo0P00ogoo:7oo0P00BGoo00<007ooOol037oo00<007ooOol0GGoo00<007oo
Ool037oo00<007ooOol09goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`18Ool00`00Oomoo`0=
Ool00`00Oomoo`1KOol00`00Oomoo`0=Ool00`00Oomoo`0WOol003Qoo`03001oogoo0?moobMoo`03
001oogoo04Moo`03001oogoo00ioo`03001oogoo05]oo`03001oogoo00ioo`03001oogoo02Ioo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0Agoo00<007ooOol03Woo00<007ooOol0FWoo00<007oo
Ool03goo00<007ooOol09Woo000hOol2003oOolXOol20017Ool00`00Oomoo`0@Ool00`00Oomoo`1H
Ool00`00Oomoo`0@Ool00`00Oomoo`0VOol003Qoo`03001oogoo0?moobMoo`03001oogoo04Ioo`03
001oogoo011oo`03001oogoo05Qoo`03001oogoo015oo`03001oogoo02Eoo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0AGoo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007oo
Ool09Goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`15Ool00`00Oomoo`0BOol00`00Oomoo`1F
Ool00`00Oomoo`0COol00`00Oomoo`0TOol003Qoo`800?moobQoo`8004Eoo`03001oogoo01Aoo`03
001oogoo05Aoo`03001oogoo01Aoo`03001oogoo02Aoo`005goo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool0A7oo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol05Goo00<007ooOol08goo000FOol0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04Aoo`03
001oogoo01Eoo`03001oogoo05=oo`03001oogoo01Eoo`03001oogoo02=oo`003Woo1P000Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20014Ool00`00Oomoo`0FOol00`00Oomoo`1BOol0
0`00Oomoo`0FOol00`00Oomoo`0SOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol0@goo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05goo00<007ooOol0
8Woo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo04=oo`03001oogoo01Moo`03001o
ogoo055oo`03001oogoo01Moo`03001oogoo029oo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`12Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0HOol0
0`00Oomoo`0ROol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo
0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20013Ool0
0`00Oomoo`0IOol00`00Oomoo`1?Ool00`00Oomoo`0IOol00`00Oomoo`0QOol001Moo`<000aoo`D0
00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo049oo`03001o
ogoo01Uoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0@Goo00<007ooOol06Woo00<007ooOol0CWoo00<007ooOol06Woo00<007ooOol0
8Goo000hOol2003oOolXOol20012Ool00`00Oomoo`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol0
0`00Oomoo`0POol003Qoo`03001oogoo0?moobMoo`03001oogoo045oo`03001oogoo01]oo`03001o
ogoo04eoo`03001oogoo01]oo`03001oogoo021oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
@7oo00<007ooOol077oo00<007ooOol0CGoo00<007ooOol06goo00<007ooOol087oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`10Ool00`00Oomoo`0MOol00`00Oomoo`1;Ool00`00Oomoo`0LOol0
0`00Oomoo`0POol003Qoo`800?moobQoo`80045oo`03001oogoo01eoo`03001oogoo04]oo`03001o
ogoo01eoo`03001oogoo01moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0?goo00<007ooOol0
7Woo00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol07goo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`0OOol0
03Qoo`800?moobQoo`80041oo`03001oogoo01moo`03001oogoo04Uoo`03001oogoo01moo`03001o
ogoo01ioo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo1000
1Goo00<007ooOol0?Woo00<007ooOol087oo00<007ooOol0BGoo00<007ooOol07goo00<007ooOol0
7Woo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo03ioo`03001oogoo021oo`03001o
ogoo04Qoo`03001oogoo021oo`03001oogoo01ioo`005Woo1P000Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo0?moo`Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`0nOol00`00Oomoo`0QOol00`00Oomoo`17Ool00`00Oomoo`0POol00`00Oomoo`0NOol0
01ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<0
07ooOol00Woo0P00?Woo00<007ooOol08Woo00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol0
7Goo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000ao
o`@000Eoo`03001oogoo03eoo`03001oogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001o
ogoo01eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0mOol00`00Oomoo`0ROol00`00Oomoo`16Ool0
0`00Oomoo`0ROol00`00Oomoo`0MOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00
Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0?Goo00<007ooOol0
8goo00<007ooOol0AGoo00<007ooOol08Woo00<007ooOol07Goo000OOol3000=Ool40005Ool2003o
Ool?Ool3000=Ool40005Ool2000mOol00`00Oomoo`0TOol00`00Oomoo`14Ool00`00Oomoo`0TOol0
0`00Oomoo`0LOol003Qoo`03001oogoo0?moobMoo`03001oogoo03aoo`03001oogoo02Aoo`03001o
ogoo04Aoo`03001oogoo02Aoo`03001oogoo01aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
?7oo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol077oo000hOol2003o
OolXOol2000mOol00`00Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`0KOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo03]oo`03001oogoo02Ioo`03001oogoo049oo`03001o
ogoo02Ioo`03001oogoo01]oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0>goo00<007ooOol0
9Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol06goo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0kOol00`00Oomoo`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomoo`0KOol0
03Qoo`800?moobQoo`8003aoo`03001oogoo02Moo`03001oogoo045oo`03001oogoo02Moo`03001o
ogoo01Yoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol0
@7oo00<007ooOol0:7oo00<007ooOol06Woo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0jOol0
0`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`0JOol003Qoo`800?moobQo
o`8003]oo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo01Yoo`005goo
0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P0017oo1@0017oo1000
1Goo00<007ooOol0>Woo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol0
6Goo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001o
ogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<0
07ooOol0>Goo00<007ooOol0:Woo00<007ooOol0?Woo00<007ooOol0:Woo00<007ooOol06Goo000>
Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0o7oo
1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo03Uoo`03
001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo01Uoo`005Woo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool2000jOol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0[
Ool00`00Oomoo`0HOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomo
o`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0>7oo00<007oo
Ool0;7oo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol067oo000FOol01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo03Qoo`03001oogoo02aoo`03001oogoo03aoo`03
001oogoo02aoo`03001oogoo01Qoo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool0
0`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo
00Ioo`8003Uoo`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo01Qoo`00
5goo0`003Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo0`003Goo0`001Goo10001Goo00<007oo
Ool0>7oo00<007ooOol0;7oo00<007ooOol0?7oo00<007ooOol0;Goo00<007ooOol05goo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`0gOol00`00Oomoo`0^Ool00`00Oomoo`0jOol00`00Oomoo`0^
Ool00`00Oomoo`0GOol003Qoo`03001oogoo01moo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Io
o`<001Qoo`<000Ioo`8000Eoo`<001Yoo`<000Ioo`8000Eoo`<0025oo`D004Uoo`03001oogoo01mo
o`<000Ioo`8000Aoo`D000Aoo`03001oogoo015oo`<000Ioo`8000Ioo`<000Uoo`03001oogoo00ao
o`<000Ioo`8000Eoo`<001Uoo`<000Ioo`8000Eoo`<0021oo`H001Aoo`00>7oo0P007goo00D007oo
Oomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomoogoo00001Goo0P001goo00<007ooOol0
5Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000HOol01@00Oomoogoo00001Goo0P00
17oo00D007ooOomoo`00029oo`03001oogoo04Uoo`8001moo`05001oogooOol00005Ool20005Ool0
1000Oomoo`0017oo00<007ooOol047oo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo00Qoo`03
001oogoo00]oo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00005goo00<007ooOol00P00
1Goo0P0017oo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`03001oogoo01ioo`05001o
ogooOol0000=Ool00`00Oomoo`0GOol01@00Oomoogoo00002goo1@005goo00D007ooOomoo`0000]o
o`05001oogooOol0000HOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uo
o`03001oogoo01ioo`05001oogooOol0000=Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool01@00Oomo
ogoo00002goo1@002Goo00<007ooOol02goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol0
0`00Oomoo`02000;Ool01@00Oomoogoo000087oo00<007oo00005Woo000hOol00`00Oomoo`0NOol0
1@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00
Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo
00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo009oo`03001oogoo
015oo`05001oogooOol0000;Ool01000Oomoo`002goo00<007ooOol02Woo00D007ooOomoo`0000]o
o`05001oogooOol0000GOol01@00Ool007oo00002goo00D007ooOomoo`00021oo`03001oo`0001Io
o`00>7oo00<007ooOol07Woo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<
Ool00`00Ool0000HOol01@00Oomoogoo00002goo10006Goo00D007ooOomoo`0000aoo`<002=oo`03
001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000?Ool01@00Oomoogoo00004goo00D007oo
Oomoo`0000aoo`03001oo`0000]oo`03001oogoo00Yoo`05001oogooOol0000;Ool4000HOol01@00
Ool007oo000037oo0`008Goo00<007oo00005Woo000hOol2000OOol01@00Oomoogoo00003goo00<0
07ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomo
o`0JOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`8001moo`05001o
ogooOol0000?Ool01@00Oomoogoo00004goo00D007ooOomoo`0000aoo`03001oo`0000]oo`03001o
ogoo00Yoo`05001oogooOol0000;Ool00`00Oomoo`0IOol01@00Ool007oo00002goo00D007ooOomo
o`00025oo`8001Ioo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000]oo`05001oogooOol0000G
Ool01@00Oomoogoo00003Goo0P0067oo00D007ooOomoo`0000aoo`03001oogoo01Uoo`05001oogoo
Ool0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`00
00]oo`05001oogooOol00003Ool00`00Oomoo`0AOol01@00Oomoogoo00003Goo0P002goo00<007oo
Ool02Woo00D007ooOomoo`0000aoo`03001oogoo01Qoo`05001oo`00Ool0000;Ool01@00Oomoogoo
00008Goo0P005Woo000hOol00`00Oomoo`0OOol3000=Ool3000IOol3000?Ool00`00Oomoo`0GOol3
000>Ool3000IOol3000=Ool3000QOol3001;Ool00`00Oomoo`0OOol3000=Ool30003Ool00`00Oomo
o`0COol3000?Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool3000>Ool3000HOol3000=Ool3000QOol3
000FOol003Qoo`800?moobQoo`8003Ioo`03001oogoo039oo`03001oogoo03Ioo`03001oogoo039o
o`03001oogoo01Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0=Goo00<007ooOol0<Woo00<0
07ooOol0=Woo00<007ooOol0<goo00<007ooOol057oo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`0eOol00`00Oomoo`0bOol00`00Oomoo`0fOol00`00Oomoo`0cOol00`00Oomoo`0DOol003Qoo`03
001oogoo0?moobMoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo03Ao
o`03001oogoo01Aoo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`19Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0DOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001o
ogoo04]oo`00>7oo0P00ogoo:7oo0P00=7oo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol0
C7oo000hOol00`00Oomoo`3oOolWOol2000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomo
o`1<Ool003Qoo`03001oogoo0?moobMoo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03001o
ogoo04aoo`00>7oo00<007ooOol0ogoo9goo0P00=7oo00<007ooOol0=Woo00<007ooOol0<Woo00<0
07ooOol0C7oo000hOol2003oOolXOol3000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomo
o`1=Ool003Qoo`03001oogoo0?moobMoo`03001oo`00039oo`03001oogoo03Qoo`03001oogoo031o
o`03001oogoo04eoo`00>7oo00<007ooOol0ogoo9goo00<007oo0000<Woo00<007ooOol0>7oo00<0
07ooOol0<7oo00<007ooOol0CGoo000hOol00`00Oomoo`3oOolWOol00`00Ool0000bOol00`00Oomo
o`0iOol00`00Oomoo`0_Ool00`00Oomoo`1=Ool003Qoo`800?moobQoo`800003Ool007oo02moo`03
001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo00<007ooOol0ogoo9goo00@007oo
Ool0031oo`03001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo00<007ooOol0ogoo
9goo00@007ooOol0031oo`03001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo0P00
ogoo:7oo0P0000=oo`00Ool0;goo00<007ooOol0>goo00<007ooOol0;Goo00<007ooOol0CWoo000G
Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20004Ool50004Ool4
0005Ool01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo000F
Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo0?mo
o`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00D007ooOomo
o`0002ioo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo04moo`005Woo00D007ooOomoo`00
00eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000=Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007ooOol0
;7oo00<007ooOol0Cgoo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo
0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000=oo`03001o
ogoo02]oo`03001oogoo03eoo`03001oogoo02]oo`03001oogoo04moo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomo
o`02Ool40005Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol0
0`00Oomoo`1@Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
0Woo00<007ooOol0:Woo00<007ooOol0?Woo00<007ooOol0:Woo00<007ooOol0D7oo000FOol01@00
Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0
000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P000goo00<007ooOol0:Woo00<007ooOol0
?Woo00<007ooOol0:Woo00<007ooOol0D7oo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`3o
Ool6Ool3000=Ool30005Ool40005Ool00`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomoo`0oOol0
0`00Oomoo`0XOol00`00Oomoo`1AOol003Qoo`03001oogoo0?moobMoo`03001oogoo00=oo`03001o
ogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo055oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol00goo00<007ooOol0:7oo00<007ooOol0@7oo00<007ooOol0:7oo00<007ooOol0
DGoo000hOol2003oOolXOol20004Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol0
0`00Oomoo`1AOol003Qoo`03001oogoo0?moobMoo`03001oogoo00Aoo`03001oogoo02Moo`03001o
ogoo045oo`03001oogoo02Ioo`03001oogoo059oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
17oo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol0DWoo000hOol2003o
OolXOol20005Ool00`00Oomoo`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomoo`1BOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo04=oo`03001o
ogoo02Eoo`03001oogoo059oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol01Goo00<007ooOol0
9Goo00<007ooOol0@goo00<007ooOol097oo00<007ooOol0Dgoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`05Ool00`00Oomoo`0TOol00`00Oomoo`14Ool00`00Oomoo`0TOol00`00Oomoo`1COol0
03Qoo`800?moobQoo`8000Ioo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001o
ogoo05=oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo1000
1Goo00<007ooOol01Goo00<007ooOol097oo00<007ooOol0AGoo00<007ooOol08goo00<007ooOol0
Dgoo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo02=oo`03001o
ogoo04Eoo`03001oogoo029oo`03001oogoo05Aoo`007Woo00D007ooOomoo`00011oo`03001oogoo
009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0
0`00Oomoo`0ROol00`00Oomoo`16Ool00`00Oomoo`0ROol00`00Oomoo`1DOol001ioo`05001oogoo
Ool0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00
1goo00<007ooOol08Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol0E7oo000NOol01@00
Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001o
ogoo00Ioo`03001oogoo029oo`03001oogoo04Moo`03001oogoo025oo`03001oogoo05Aoo`007Woo
00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0POol00`00Oomoo`18Ool00`00Oomoo`0POol0
0`00Oomoo`1EOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomo
ogoo000037oo00<007ooOol01Woo0P0027oo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol0
87oo00<007ooOol0EGoo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool0
0`00Oomoo`07Ool00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`1EOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo00Moo`03001oogoo01moo`03001oogoo04Yoo`03001o
ogoo01moo`03001oogoo05Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol027oo00<007ooOol0
7Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000hOol2003oOolXOol20009Ool0
0`00Oomoo`0NOol00`00Oomoo`1;Ool00`00Oomoo`0MOol00`00Oomoo`1FOol003Qoo`03001oogoo
0?moobMoo`03001oogoo00Qoo`03001oogoo01eoo`03001oogoo04aoo`03001oogoo01eoo`03001o
ogoo05Ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol02Goo00<007ooOol077oo00<007ooOol0
C7oo00<007ooOol077oo00<007ooOol0Egoo000hOol2003oOolXOol2000:Ool00`00Oomoo`0LOol0
0`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`1GOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo00Uoo`03001oogoo01]oo`03001oogoo04ioo`03001oogoo01]oo`03001oogoo05Moo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol02Goo00<007ooOol06goo00<007ooOol0CWoo00<007ooOol0
6Woo00<007ooOol0F7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0:Ool00`00Oomoo`0JOol0
0`00Oomoo`1?Ool00`00Oomoo`0IOol00`00Oomoo`1HOol003Qoo`800?moobQoo`8000]oo`03001o
ogoo01Uoo`03001oogoo051oo`03001oogoo01Uoo`03001oogoo05Qoo`005goo0`001Woo0P001Woo
00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo1000
1Goo00<007ooOol02Woo00<007ooOol06Goo00<007ooOol0D7oo00<007ooOol067oo00<007ooOol0
FGoo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007oo
Ool0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001o
ogoo00]oo`03001oogoo01Qoo`03001oogoo055oo`03001oogoo01Moo`03001oogoo05Uoo`005Woo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0GOol0
0`00Oomoo`1BOol00`00Oomoo`0GOol00`00Oomoo`1IOol001Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P003Goo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05Woo00<007ooOol0
FWoo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo00aoo`03001oogoo01Ioo`03001o
ogoo05=oo`03001oogoo01Eoo`03001oogoo05Yoo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`0EOol00`00Oomoo`1DOol00`00Oomoo`0DOol0
0`00Oomoo`1KOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo
0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000>Ool0
0`00Oomoo`0DOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`1KOol001Moo`<000aoo`D0
00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo00eoo`03001o
ogoo01Aoo`03001oogoo05Eoo`03001oogoo019oo`03001oogoo05aoo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0
G7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`1FOol0
0`00Oomoo`0BOol00`00Oomoo`1LOol003Qoo`800?moobQoo`8000moo`03001oogoo019oo`03001o
ogoo05Moo`03001oogoo011oo`03001oogoo05eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol0F7oo00<007ooOol047oo00<007ooOol0GGoo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`1IOol00`00Oomoo`0>Ool0
0`00Oomoo`1NOol003Qoo`800?moobQoo`80015oo`03001oogoo00ioo`03001oogoo05Yoo`03001o
ogoo00ioo`03001oogoo05ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol04Goo00<007ooOol0
3Goo00<007ooOol0Fgoo00<007ooOol037oo00<007ooOol0Ggoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0AOol00`00Oomoo`0<Ool00`00Oomoo`1MOol00`00Oomoo`0;Ool00`00Oomoo`1OOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo019oo`03001oogoo00Yoo`03001oogoo05moo`03001o
ogoo00Uoo`03001oogoo061oo`00>7oo0P00ogoo:7oo0P0057oo00<007ooOol027oo00<007ooOol0
HGoo00<007ooOol01goo00<007ooOol0HGoo000_Ool50004Ool00`00Oomoo`3oOolNOol50004Ool0
0`00Oomoo`0DOol00`00Oomoo`06Ool00`00Oomoo`1ROol00`00Oomoo`06Ool00`00Oomoo`1ROol0
035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo01Eoo`03001o
ogoo00Aoo`03001oogoo06Aoo`03001oogoo00Aoo`03001oogoo06=oo`00<Goo00<007ooOol017oo
0P00ogoo8Goo00<007ooOol017oo0P005goo1P00J7oo1P00IWoo000aOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo
9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMo
o`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<00004Ool00000000HOol3003oOol7Ool3
000017oo000000006Goo0`00M7oo002FOol01@00Oomoogoo00002Goo1P002Goo00D007ooOomoo`00
0?moo`Moo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05001oogooOol0000L
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo000067oo1@00M7oo002FOol01@00Oomoogoo00002Goo
1P003Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Uoo`H000Uoo`04001oogoo001eOol009Io
o`05001oogooOol0000JOol2003oOol8Ool01@00Oomoogoo00006Goo00<007oo0000MGoo002EOol5
000MOol00`00Oomoo`3oOol4Ool5000JOol00`00Ool0001eOol00;=oo`05001oogooOol0003oOolV
Ool2001eOol00;Aoo`<00?moobQoo`03001oogoo07=oo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomF
Ool00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo000_Ool5003oOolUOol5003gOol0035o
o`03001oogoo0?moobMoo`03001oogoo0?Moo`009Woo1P001Goo00<007ooOol0ogoo77oo1P001Goo
00<007ooOol0mgoo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2000_Ool=002e
Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo02aoo`80
00eoo`800;=oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007oo
Ool0:Woo0P004Goo0P00/Goo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2000Y
Ool2000EOol2002_Ool002moo`<000Ioo`03001oogoo0?mooaioo`<000Ioo`03001oogoo02Moo`03
001oogoo01Moo`03001oogoo0:aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol09Goo0P006goo
00<007ooOol0Zgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0TOol00`00Oomoo`0LOol00`00
Oomoo`2ZOol003Qoo`800?moobQoo`8002Aoo`03001oogoo01ioo`03001oogoo0:Uoo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol08Woo00<007ooOol087oo00<007ooOol0Z7oo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`0QOol00`00Oomoo`0ROol00`00Oomoo`2WOol003Qoo`800?moobQoo`80
029oo`03001oogoo029oo`03001oogoo0:Moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol087oo
00<007ooOol097oo00<007ooOol0YWoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0OOol00`00
Oomoo`0VOol00`00Oomoo`2UOol003Qoo`03001oogoo0?moobMoo`03001oogoo01ioo`03001oogoo
02Qoo`03001oogoo0:Aoo`00>7oo0P00ogoo:7oo0P007goo00<007ooOol0:Goo00<007ooOol0Xgoo
000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20006
Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`0MOol00`00Oomoo`0[Ool00`00Oomoo`2ROol001Io
o`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol077oo
00<007ooOol0;7oo00<007ooOol0XWoo000>Ool60002Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol0o7oo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo01aoo`03001oogoo02eoo`03001oogoo0:5oo`005Woo00D007oo
Oomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool2000LOol00`00Oomoo`0_Ool00`00Oomoo`2POol001Ioo`05
001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo0000
3Woo00<007ooOol00goo10001Goo00<007ooOol06Woo00<007ooOol0<Goo00<007ooOol0Wgoo000F
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01Uoo`03001oogoo03=o
o`03001oogoo09ioo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06
Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8001Yo
o`03001oogoo03=oo`03001oogoo09ioo`005goo0`0037oo1@0017oo10001Goo00<007ooOol0ogoo
1Woo0`0037oo1@0017oo10001Goo00<007ooOol067oo00<007ooOol0=Goo00<007ooOol0WGoo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`0GOol00`00Oomoo`0gOol00`00Oomoo`2LOol003Qoo`03
001oogoo0?moobMoo`03001oogoo01Moo`03001oogoo03Moo`03001oogoo09aoo`00>7oo0P00ogoo
:7oo0P005goo00<007ooOol0>Goo00<007ooOol0Vgoo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`0EOol00`00Oomoo`0jOol00`00Oomoo`2KOol003Qoo`03001oogoo0?moobMoo`03001oogoo01Eo
o`03001oogoo03]oo`03001oogoo09Yoo`00>7oo0P00ogoo:7oo0P005Goo00<007ooOol0?Goo00<0
07ooOol0VGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0COol00`00Oomoo`0nOol00`00Oomo
o`2IOol003Qoo`03001oogoo0?moobMoo`03001oogoo01=oo`03001oogoo03moo`03001oogoo09Qo
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol04Woo00<007ooOol0@7oo00<007ooOol0V7oo000h
Ool2003oOolXOol2000BOol00`00Oomoo`12Ool00`00Oomoo`2GOol001moo`<000Ioo`8000Eoo`@0
00Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo015oo`03001oogoo04=o
o`03001oogoo09Ioo`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo
0?moo`eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomo
o`14Ool00`00Oomoo`2FOol001Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003o
Ool6Ool60002Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P0047oo00<007ooOol0AWoo00<0
07ooOol0UGoo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`00011oo`03001oogoo009oo`03001oogoo00moo`03001oogoo04Ioo`03001oogoo09Eo
o`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool4
0005Ool00`00Oomoo`0>Ool00`00Oomoo`18Ool00`00Oomoo`2DOol001ioo`05001oogooOol0000<
Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<0
07ooOol03Woo00<007ooOol0B7oo00<007ooOol0U7oo000NOol01@00Oomoogoo000037oo00<007oo
Ool01Woo0P00ogoo3Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`8000ioo`03001oogoo04Yo
o`03001oogoo09=oo`007goo0`003Goo10001Goo00<007ooOol0ogoo3Woo0`003Goo10001Goo00<0
07ooOol03Goo00<007ooOol0Bgoo00<007ooOol0TWoo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`0<Ool00`00Oomoo`1<Ool00`00Oomoo`2BOol003Qoo`03001oogoo0?moobMoo`03001oogoo00ao
o`03001oogoo04eoo`03001oogoo095oo`00>7oo0P00ogoo:7oo0P0037oo00<007ooOol0CWoo00<0
07ooOol0TGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0;Ool00`00Oomoo`1?Ool00`00Oomo
o`2@Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Yoo`03001oogoo055oo`03001oogoo08mo
o`00>7oo0P00ogoo:7oo0P002goo00<007ooOol0DGoo00<007ooOol0Sgoo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`09Ool00`00Oomoo`1COol00`00Oomoo`2>Ool003Qoo`03001oogoo0?moobMo
o`03001oogoo00Uoo`03001oogoo05=oo`03001oogoo08ioo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol027oo00<007ooOol0EGoo00<007ooOol0SGoo000hOol2003oOolXOol20009Ool00`00Oomo
o`1FOol00`00Oomoo`2<Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Io
o`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Moo`03001oogoo05Moo`03001oogoo08ao
o`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomo
o`3oOol5Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001o
ogoo00Moo`03001oogoo05Qoo`03001oogoo08]oo`003Woo1P000Woo00D007ooOomoo`0000eoo`03
001oogoo00Qoo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`1IOol00`00Oomoo`2;Ool001Ioo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0FWoo00<007ooOol0RWoo
000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0ogoo1Goo00D007oo
Oomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00Eoo`03001oogoo05]oo`03001oogoo
08Yoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?mo
o`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`1LOol00`00Oomoo`29Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<0
07ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06
Ool20005Ool00`00Oomoo`1MOol00`00Oomoo`29Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001o
ogoo0?moo`Ioo`<000eoo`<000Eoo`@000Eoo`03001oogoo00Aoo`03001oogoo05ioo`03001oogoo
08Qoo`00>7oo00<007ooOol07goo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`0067oo0`00
1Woo0P001Goo0`006Woo0`001Woo0P001Goo0`008Goo1@00BGoo00<007ooOol00goo00<007ooOol0
6Goo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`001Woo00<007ooOol03goo0`001Woo0P00
1Goo0`006Goo0`001Woo0P001Goo0`008Goo1@0057oo000hOol2000OOol01@00Oomoogoo00001Goo
0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00Oomoo`0FOol01@00Oomo
ogoo00001Goo0P0017oo00D007ooOomoo`0001Qoo`05001oogooOol00005Ool20004Ool01@00Oomo
ogoo00008Woo00<007ooOol0BGoo0P0017oo00<007ooOol067oo00D007ooOomoo`0000Eoo`8000Eo
o`04001oogoo000GOol01@00Oomoogoo00001Goo0P001goo00<007ooOol01Woo00<007ooOol03Goo
00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000GOol01@00Oomoogoo00001Goo0P0017oo
00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000eo
o`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol0
0Woo00<007ooOol06Goo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5
0007Ool00`00Oomoo`0=Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0
000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo
00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo0000
2goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0
BGoo00<007ooOol00Woo00<007ooOol06Goo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001o
ogooOol0000;Ool01000Oomoo`002Goo00<007ooOol037oo00D007ooOomoo`0000]oo`05001oogoo
Ool0000GOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<0
07ooOol07Woo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0
000HOol01@00Oomoogoo00002goo10006Goo00D007ooOomoo`0000aoo`<002=oo`03001oogoo04Uo
o`05001oogooOol0000LOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000ao
o`03001oo`0000Uoo`03001oogoo00aoo`05001oogooOol0000;Ool4000HOol01@00Oomoogoo0000
37oo0`008goo00<007ooOol057oo000hOol2000OOol01@00Oomoogoo00003goo00<007ooOol05Goo
00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`0JOol01@00
Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`80009oo`03001oogoo01Yoo`05
001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo00002Woo00<007oo
Ool02goo00D007ooOomoo`0000]oo`03001oogoo01Uoo`05001oogooOol0000;Ool01@00Oomoogoo
00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Moo`05001oogooOol0000=Ool2000HOol01@00Oomoogoo000037oo00<007ooOol06Goo00D0
07ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool01000Oomoo`007Goo00D007oo
Oomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00003Goo0P002Woo00<007ooOol02goo
00D007ooOomoo`0000aoo`03001oogoo01Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo
00<007ooOol057oo000hOol00`00Oomoo`0OOol3000=Ool3000IOol3000?Ool00`00Oomoo`0GOol3
000>Ool3000IOol3000=Ool3000QOol3001;Ool01000Oomoo`007Woo0`003Goo0`006Goo0`003goo
00<007ooOol02Goo00<007ooOol02goo0`003Woo0`0067oo0`003Goo0`008Goo0`005Woo000hOol0
0`00Oomoo`3oOolWOol00`00Ool0001YOol00`00Oomoo`24Ool003Qoo`800?moobQoo`<006Yoo`03
001oogoo08=oo`00>7oo00<007ooOol0ogoo9goo0P00Jgoo00<007ooOol0Pgoo000hOol00`00Oomo
o`3oOolWOol2001/Ool00`00Oomoo`22Ool0039oonT0041oonT0011oo`00>7oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0BGoo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
0P002Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool057oo000hOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0ZOol0
0`00Oomoo`0YOol00`00Oomoo`19Ool00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0DOol0
0`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0DOol003Qoo`03001oogoo
0?moobMoo`03001oogoo06eoo`03001oogoo06Qoo`03001oogoo01Eoo`00>7oo0P00ogoo:7oo0P00
KWoo00<007ooOol0J7oo00<007ooOol05Goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1]Ool0
0`00Oomoo`1WOol00`00Oomoo`0FOol003Qoo`03001oogoo0?moobMoo`03001oogoo06ioo`03001o
ogoo06Ioo`03001oogoo01Ioo`00>7oo0P00ogoo:7oo0P00Kgoo00<007ooOol0IGoo00<007ooOol0
5goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1_Ool00`00Oomoo`1TOol00`00Oomoo`0GOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo06moo`03001oogoo06=oo`03001oogoo01Qoo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0L7oo00<007ooOol0HWoo00<007ooOol067oo000hOol2003o
OolXOol2001aOol00`00Oomoo`1QOol00`00Oomoo`0IOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo075oo`03001oogoo061oo`03001oogoo01Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
LGoo00<007ooOol0Ggoo00<007ooOol06Woo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1bOol0
0`00Oomoo`1NOol00`00Oomoo`0JOol003Qoo`800?moobQoo`8007=oo`03001oogoo05eoo`03001o
ogoo01]oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P00
17oo1@0017oo10001Goo00<007ooOol0LWoo00<007ooOol0GGoo00<007ooOol06goo000FOol01@00
Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05
001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0Lgoo00<0
07ooOol0Fgoo00<007ooOol077oo000FOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007oo
Ool00Woo0P00ogoo1Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8007Ao
o`03001oogoo05]oo`03001oogoo01aoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`1dOol00`00Oomoo`1IOol00`00Oomoo`0MOol001Ioo`05001oogooOol0000?
Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol0
0Woo10001Goo00<007ooOol0M7oo00<007ooOol0FGoo00<007ooOol07Goo000FOol01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000mo
o`03001oogoo009oo`03001oogoo00Ioo`03001oogoo07Eoo`03001oogoo05Moo`03001oogoo01io
o`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool0
1@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8007Ioo`03001oogoo05Mo
o`03001oogoo01ioo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo0`003Goo0`00
1Goo10001Goo00<007ooOol0MWoo00<007ooOol0EGoo00<007ooOol07goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`1gOol00`00Oomoo`1DOol00`00Oomoo`0OOol003Qoo`800?moobQoo`8007Qo
o`03001oogoo05=oo`03001oogoo021oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0N7oo00<0
07ooOol0DWoo00<007ooOol087oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1hOol00`00Oomo
o`1AOol00`00Oomoo`0QOol003Qoo`03001oogoo0?moobMoo`03001oogoo07Uoo`03001oogoo04mo
o`03001oogoo029oo`00>7oo0P00ogoo:7oo0P00Ngoo00<007ooOol0CWoo00<007ooOol08Woo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`1jOol00`00Oomoo`1=Ool00`00Oomoo`0SOol003Qoo`03
001oogoo0?moobMoo`03001oogoo07]oo`03001oogoo04aoo`03001oogoo02=oo`00>7oo0P00ogoo
:7oo0P00O7oo00<007ooOol0Bgoo00<007ooOol097oo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`1lOol00`00Oomoo`1:Ool00`00Oomoo`0TOol001moo`<000Ioo`8000Eoo`@000Eoo`03001oogoo
0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo07eoo`03001oogoo04Qoo`03001oogoo02Eo
o`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?moo`eoo`05001o
ogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`1mOol00`00Oomoo`18Ool00`00Oomo
o`0UOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomoogoo0000
47oo00<007ooOol00Woo0P00Ogoo00<007ooOol0AWoo00<007ooOol09Woo000NOol01@00Oomoogoo
000047oo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`00011oo`03001oogoo009o
o`03001oogoo07ioo`03001oogoo04Ioo`03001oogoo02Ioo`007Woo00D007ooOomoo`0000aoo`@0
00Eoo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool40005Ool00`00Oomoo`1oOol00`00Oomo
o`14Ool00`00Oomoo`0WOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3o
Ool=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0P7oo00<007ooOol0@Woo00<0
07ooOol0:7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00ogoo3Woo00D007ooOomo
o`0000aoo`03001oogoo00Ioo`80085oo`03001oogoo049oo`03001oogoo02Qoo`007goo0`003Goo
10001Goo00<007ooOol0ogoo3Woo0`003Goo10001Goo00<007ooOol0PGoo00<007ooOol0@7oo00<0
07ooOol0:Goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`21Ool00`00Oomoo`0oOol00`00Oomo
o`0ZOol003Qoo`800?moobQoo`8008=oo`03001oogoo03ioo`03001oogoo02Yoo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0Pgoo00<007ooOol0?7oo00<007ooOol0:goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`23Ool00`00Oomoo`0kOol00`00Oomoo`0/Ool003Qoo`03001oogoo0?moobMo
o`03001oogoo08Aoo`03001oogoo03Yoo`03001oogoo02aoo`00>7oo0P00ogoo:7oo0P00QGoo00<0
07ooOol0>Goo00<007ooOol0;Goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`25Ool00`00Oomo
o`0gOol00`00Oomoo`0^Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Ioo`03001oogoo03Io
o`03001oogoo02ioo`00>7oo0P00ogoo:7oo0P00Qgoo00<007ooOol0=Goo00<007ooOol0;goo000G
Ool30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20006Ool0
0`00Oomoo`04Ool40005Ool00`00Oomoo`27Ool00`00Oomoo`0cOol00`00Oomoo`0`Ool001Ioo`05
001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0Qgoo00<0
07ooOol0<goo00<007ooOol0<7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`03001oogoo08Qoo`03001oogoo035oo`03001oogoo035oo`005Woo00D007ooOomoo`0000ioo`03
001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool2002:Ool00`00Oomoo`0_Ool00`00Oomoo`0bOol001Ioo`05001oogooOol0000>
Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol0
0goo10001Goo00<007ooOol0RGoo00<007ooOol0;Woo00<007ooOol0<goo000FOol01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000mo
o`03001oogoo009oo`03001oogoo00Ioo`03001oogoo08Yoo`03001oogoo02eoo`03001oogoo03=o
o`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`3o
Ool5Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo08]o
o`03001oogoo02]oo`03001oogoo03Aoo`005goo0`0037oo1@0017oo10001Goo0P00ogoo1goo0`00
37oo1@0017oo10001Goo0P00SGoo00<007ooOol0:Goo00<007ooOol0=Goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`2=Ool00`00Oomoo`0XOol00`00Oomoo`0eOol003Qoo`03001oogoo0?moobMo
o`03001oogoo08ioo`03001oogoo02Ioo`03001oogoo03Ioo`00>7oo0P00ogoo:7oo0P00T7oo00<0
07ooOol097oo00<007ooOol0=goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2@Ool00`00Oomo
o`0QOol2000jOol003Qoo`03001oogoo0?moobMoo`03001oogoo095oo`03001oogoo01moo`03001o
ogoo03Yoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0TWoo00<007ooOol07Goo00<007ooOol0
>goo000hOol2003oOolXOol2002DOol00`00Oomoo`0KOol00`00Oomoo`0lOol003Qoo`03001oogoo
0?moobMoo`03001oogoo09Aoo`03001oogoo01Uoo`03001oogoo03eoo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0UGoo0P0067oo00<007ooOol0?Woo000hOol2003oOolXOol2002HOol2000DOol2
0011Ool002moo`D000Aoo`03001oogoo0?mooaioo`D000Aoo`03001oogoo09Uoo`80011oo`8004=o
o`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0Vgoo00<0
07ooOol037oo00<007ooOol0@goo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomo
o`04Ool00`00Oomoo`2LOol40007Ool30016Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001o
ogoo00Aoo`800:5oo`L004Uoo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00
Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00;goo
0`00ogoo9goo0`00nGoo003oOoooOomFOol00?mooomooeIoo`00UGoo0`0000Aoo`00000001Qoo`D0
0?moo`Eoo`<00004Ool00000000GOol5001dOol009Ioo`05001oogooOol00009Ool6000<Ool00`00
Oomoo`3oOol6Ool01@00Oomoogoo00002Goo1P002Woo00@007ooOol007Aoo`00UWoo00D007ooOomo
o`0001]oo`03001oogoo0?moo`Ioo`05001oogooOol0000JOol00`00Oomoo`1dOol009Ioo`05001o
ogooOol00009Ool6000<Ool00`00Oomoo`3oOol6Ool01@00Oomoogoo00002Goo1P0037oo00<007oo
Ool0Lgoo002FOol01@00Oomoogoo00006goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001aoo`03
001oogoo079oo`00UGoo1@0077oo00<007ooOol0ogoo1Goo1@007Goo00<007ooOol0LWoo002fOol0
0`00Oomoo`3oOolSOol01@00Oomoogoo0000M7oo002dOol3003oOolVOol3001eOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomF
Ool00001\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36136 L
.08255 .38606 L
.10458 .40959 L
.12507 .42722 L
.14415 .43931 L
.14918 .44173 L
.15465 .444 L
.15946 .44567 L
.16457 .4471 L
.16917 .44808 L
.17178 .44851 L
.17423 .44883 L
.17538 .44896 L
.17647 .44905 L
.17746 .44913 L
.17852 .4492 L
.17967 .44925 L
.18073 .44929 L
.182 .44931 L
.18314 .44931 L
.18435 .44929 L
.18547 .44925 L
.1867 .44919 L
.18802 .4491 L
.19071 .44885 L
.19317 .44853 L
.1979 .44769 L
.20239 .44661 L
.21236 .44324 L
.22321 .4381 L
.24299 .42495 L
.26399 .40615 L
.30174 .3625 L
.34195 .30808 L
.38063 .25574 L
.40028 .23167 L
.42177 .2087 L
.44253 .19081 L
.4614 .17884 L
.47149 .17427 L
.47611 .17263 L
.48101 .1712 L
.4835 .17059 L
.48624 .17002 L
.48876 .16959 L
.49106 .16927 L
.49378 .16899 L
.49527 .16888 L
.49596 .16884 L
Mistroke
.49669 .1688 L
.498 .16875 L
.49921 .16873 L
.49996 .16873 L
.50065 .16873 L
.50196 .16875 L
.50313 .16879 L
.50438 .16886 L
.50556 .16894 L
.50663 .16903 L
.50926 .16931 L
.51175 .16967 L
.5167 .17064 L
.52208 .17206 L
.53169 .17557 L
.54056 .17988 L
.55926 .19217 L
.57988 .21032 L
.62014 .25673 L
.65888 .30922 L
.70007 .36482 L
.72063 .38968 L
.73974 .40982 L
.75939 .42677 L
.77791 .4387 L
.78775 .44329 L
.79293 .44519 L
.7984 .44682 L
.80302 .44788 L
.80546 .44832 L
.80809 .4487 L
.8105 .44897 L
.8127 .44915 L
.81375 .44921 L
.81491 .44926 L
.81599 .44929 L
.817 .44931 L
.81818 .4493 L
.81941 .44928 L
.82047 .44925 L
.82163 .44919 L
.82287 .44911 L
.82421 .449 L
.82661 .44873 L
.82905 .44839 L
.83134 .44799 L
.83564 .44704 L
.84078 .44559 L
.84552 .44393 L
.85624 .43911 L
Mistroke
.87498 .42719 L
.89561 .40941 L
.93591 .36346 L
.97471 .31108 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .43101 L
.08255 .48397 L
.0932 .50724 L
.10458 .5278 L
.11009 .53602 L
.11531 .54268 L
.12038 .5481 L
.12507 .55216 L
.12951 .55515 L
.13178 .55635 L
.13422 .55739 L
.13549 .55784 L
.13666 .55818 L
.13784 .55847 L
.13895 .55868 L
.14022 .55887 L
.1409 .55893 L
.14161 .55898 L
.1423 .55901 L
.14295 .55902 L
.14415 .55898 L
.14531 .55889 L
.14656 .55872 L
.14773 .5585 L
.14881 .55825 L
.15143 .55742 L
.15392 .55636 L
.15886 .55347 L
.16423 .54914 L
.17383 .53844 L
.1827 .52525 L
.20137 .48814 L
.22197 .43474 L
.26217 .30814 L
.30086 .1861 L
.32051 .1344 L
.3309 .11159 L
.342 .09132 L
.35275 .07612 L
.35784 .07055 L
.36253 .06637 L
.36724 .0631 L
.36972 .06176 L
.37235 .06063 L
.37463 .05989 L
.37573 .05961 L
.37677 .0594 L
.37799 .05921 L
.37911 .05909 L
Mistroke
.38031 .05903 L
.38162 .05903 L
.38227 .05905 L
.38296 .0591 L
.38419 .05924 L
.38551 .05947 L
.38695 .0598 L
.38955 .06062 L
.39197 .06165 L
.39649 .06425 L
.40134 .068 L
.40698 .07361 L
.41232 .08012 L
.42232 .09535 L
.44227 .13647 L
.4607 .18512 L
.50002 .30909 L
.53782 .42867 L
.55884 .48419 L
.56803 .50449 L
.57808 .52337 L
.58722 .53729 L
.59696 .54848 L
.60236 .55298 L
.60726 .556 L
.60962 .55709 L
.61086 .55756 L
.61218 .55799 L
.61333 .55831 L
.61459 .55859 L
.61574 .55878 L
.61682 .55891 L
.61808 .559 L
.61871 .55901 L
.61941 .55901 L
.62065 .55896 L
.62181 .55885 L
.62248 .55876 L
.62318 .55865 L
.62443 .55839 L
.62578 .55803 L
.62725 .55755 L
.62973 .55654 L
.63238 .55516 L
.63715 .55192 L
.64214 .5475 L
.64686 .54237 L
.6557 .53035 L
.67568 .4924 L
.69413 .44605 L
Mistroke
.7335 .32417 L
.77136 .20279 L
.79241 .1448 L
.81166 .1027 L
.82118 .08664 L
.8262 .07956 L
.83155 .07313 L
.8367 .06806 L
.84136 .06442 L
.84361 .06299 L
.84604 .06169 L
.84835 .0607 L
.85045 .05999 L
.85159 .05969 L
.85283 .05942 L
.85414 .05921 L
.85538 .05908 L
.85653 .05903 L
.85776 .05903 L
.85881 .05908 L
.85997 .05919 L
.86063 .05928 L
.86132 .0594 L
.86256 .05966 L
.86535 .06048 L
.86777 .06147 L
.87041 .06284 L
.87569 .06646 L
.88133 .07164 L
.89148 .08424 L
.90173 .10105 L
.91284 .12354 L
.933 .17412 L
.97393 .30158 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30287 L
.10458 .29629 L
.14415 .29033 L
.18221 .28489 L
.22272 .27953 L
.26171 .27486 L
.30316 .27051 L
.34309 .26701 L
.3815 .26432 L
.40095 .26323 L
.42237 .26225 L
.44268 .26154 L
.45178 .26129 L
.46172 .26106 L
.4671 .26096 L
.4721 .26088 L
.47727 .26081 L
.48196 .26076 L
.48658 .26072 L
.4887 .26071 L
.49093 .2607 L
.49332 .26069 L
.49438 .26068 L
.49552 .26068 L
.49675 .26068 L
.49789 .26068 L
.49859 .26068 L
.49925 .26068 L
.50049 .26068 L
.50163 .26068 L
.50286 .26068 L
.50401 .26068 L
.50508 .26068 L
.50754 .26069 L
.51014 .2607 L
.51268 .26072 L
.51504 .26074 L
.5204 .26079 L
.5293 .2609 L
.53882 .26107 L
.54906 .26131 L
.56016 .26162 L
.58032 .26236 L
.62123 .26449 L
.66064 .26731 L
.69852 .27068 L
.73886 .27492 L
.77769 .27958 L
.81897 .28505 L
Mistroke
.85873 .29075 L
.89697 .29653 L
.93767 .30289 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .23492 L
.10458 .15972 L
.14415 .09944 L
.18221 .05482 L
.20178 .03794 L
.21267 .03049 L
.22272 .02489 L
.23293 .02048 L
.23832 .01868 L
.24402 .01717 L
.24641 .01666 L
.24897 .01619 L
.25119 .01586 L
.25361 .01556 L
.25507 .01542 L
.25643 .01532 L
.25773 .01524 L
.2584 .0152 L
.25912 .01517 L
.25983 .01515 L
.26048 .01514 L
.26176 .01512 L
.26293 .01513 L
.26416 .01516 L
.26538 .0152 L
.26607 .01524 L
.26671 .01527 L
.26912 .01546 L
.27131 .01569 L
.27364 .016 L
.27847 .01688 L
.2838 .01819 L
.29326 .02139 L
.30213 .02541 L
.32232 .03816 L
.34082 .05406 L
.38045 .10051 L
.41855 .15859 L
.45912 .2307 L
.49816 .30545 L
.53966 .38504 L
.57964 .45642 L
.61811 .51554 L
.63759 .54064 L
.65902 .56382 L
.67938 .58114 L
.69843 .5929 L
.70884 .59745 L
.71396 .59919 L
Mistroke
.71872 .60051 L
.72301 .60146 L
.72758 .6022 L
.7302 .60251 L
.73148 .60263 L
.73266 .60272 L
.73371 .60279 L
.73487 .60284 L
.73603 .60288 L
.73725 .60291 L
.73856 .60291 L
.73977 .60289 L
.7404 .60288 L
.7411 .60285 L
.74251 .60278 L
.74375 .60271 L
.74508 .6026 L
.74748 .60235 L
.74985 .60203 L
.75235 .60161 L
.7568 .60067 L
.76198 .59927 L
.7668 .59765 L
.77773 .59292 L
.78828 .58695 L
.79823 .58009 L
.81683 .56415 L
.85534 .51928 L
.89632 .45682 L
.93577 .38646 L
.97371 .31383 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`1=Ool6001XOol6000_Ool003Qoo`800?moobQoo`8004eoo`03
001oogoo00Aoo`03001oogoo06Aoo`8000Eoo`03001oogoo02aoo`005goo0`001Woo0P001Woo00<0
07ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo
00<007ooOol0Bgoo00<007ooOol01Woo0P00Hgoo00<007ooOol01Woo0P00;7oo000FOol01@00Oomo
ogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007oo
Oomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04Yoo`03001oogoo
00Uoo`03001oogoo05moo`03001oogoo00Uoo`03001oogoo02Uoo`003Woo1P000Woo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool2001:Ool00`00Oomoo`0:Ool00`00Oomoo`1OOol00`00Oomo
o`09Ool00`00Oomoo`0YOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol0BGoo00<007ooOol02goo00<007ooOol0GGoo00<007ooOol02goo00<007ooOol0:7oo000F
Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo04Qoo`03001oogoo00aoo`03001oogoo05ao
o`03001oogoo00eoo`03001oogoo02Moo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`17Ool00`00Oomoo`0>Ool00`00Oomoo`1KOol00`00Oomoo`0=Ool00`00Oomo
o`0WOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo
1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20018Ool00`00Oomo
o`0?Ool00`00Oomoo`1IOol00`00Oomoo`0?Ool00`00Oomoo`0VOol001Moo`<000aoo`D000Aoo`@0
00Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo04Ioo`03001oogoo011o
o`03001oogoo05Qoo`03001oogoo011oo`03001oogoo02Ioo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0AGoo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol09Goo000h
Ool2003oOolXOol20016Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol00`00Oomo
o`0UOol003Qoo`03001oogoo0?moobMoo`03001oogoo04Aoo`03001oogoo01Aoo`03001oogoo05Ao
o`03001oogoo01Aoo`03001oogoo02Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0A7oo00<0
07ooOol057oo00<007ooOol0E7oo00<007ooOol05Goo00<007ooOol08goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`13Ool00`00Oomoo`0FOol00`00Oomoo`1COol00`00Oomoo`0EOol00`00Oomo
o`0SOol003Qoo`800?moobQoo`8004Aoo`03001oogoo01Ioo`03001oogoo059oo`03001oogoo01Mo
o`03001oogoo029oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0@goo00<007ooOol05goo00<0
07ooOol0DGoo00<007ooOol05goo00<007ooOol08Woo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`12Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`0QOol003Qoo`80
0?moobQoo`8004=oo`03001oogoo01Uoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025o
o`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<0
07ooOol0@Goo00<007ooOol06Woo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol08Goo000N
Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomo
o`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo045oo`03001oogoo01]oo`03001oogoo04eo
o`03001oogoo01]oo`03001oogoo021oo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo
009oo`03001oogoo0?moo`Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomo
o`11Ool00`00Oomoo`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`0POol001ioo`05
001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<007ooOol0
0Woo0P00@Goo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol087oo000N
Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eo
o`03001oogoo041oo`03001oogoo01eoo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo01mo
o`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0
000<Ool00`00Oomoo`06Ool00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1;Ool00`00Oomo
o`0MOol00`00Oomoo`0OOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1Y
Ool5002NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0?goo00<007ooOol07Woo
00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol07goo000OOol3000=Ool40005Ool2001WOol3
0005Ool5002JOol3000=Ool40005Ool2000oOol00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomo
o`0OOol00`00Oomoo`0NOol003Qoo`03001oogoo06Aoo`8000eoo`800;5oo`03001oogoo03ioo`03
001oogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001oogoo01ioo`00>7oo00<007ooOol0
HGoo0`004Goo0P00[goo00<007ooOol0?Woo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol0
87oo00<007ooOol07Woo000hOol2001POol2000FOol00`00Oomoo`2/Ool2000nOol00`00Oomoo`0R
Ool00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`0MOol003Qoo`03001oogoo05ioo`03001o
ogoo01Moo`03001oogoo0:]oo`03001oogoo03eoo`03001oogoo029oo`03001oogoo04Ioo`03001o
ogoo029oo`03001oogoo01eoo`00>7oo00<007ooOol0GGoo00<007ooOol06Goo0P00Zgoo00<007oo
Ool0?Goo00<007ooOol08Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol07Goo000hOol0
0`00Oomoo`1LOol00`00Oomoo`0LOol00`00Oomoo`2XOol00`00Oomoo`0lOol00`00Oomoo`0TOol0
0`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`0LOol003Qoo`8005aoo`03001oogoo01ioo`03
001oogoo0:Moo`8003eoo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo
01aoo`00>7oo00<007ooOol0FWoo00<007ooOol087oo00<007ooOol0YWoo00<007ooOol0?7oo00<0
07ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol077oo000hOol00`00Oomoo`1I
Ool00`00Oomoo`0ROol00`00Oomoo`2UOol00`00Oomoo`0kOol00`00Oomoo`0VOol00`00Oomoo`13
Ool00`00Oomoo`0UOol00`00Oomoo`0KOol003Qoo`8005Uoo`03001oogoo02=oo`03001oogoo0:Eo
o`8003aoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01]oo`005goo
0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0Egoo00<007ooOol09Goo00<007ooOol0Pgoo
0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0>goo00<007ooOol09Woo00<007ooOol0@Woo
00<007ooOol09Woo00<007ooOol06goo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol0
00Qoo`03001oogoo009oo`03001oogoo05Ioo`03001oogoo02Moo`03001oogoo085oo`05001oogoo
Ool00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol0
:7oo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol06Woo000>Ool60002Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0EGoo00<007ooOol0:Goo00<007oo
Ool0N7oo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo
03Yoo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo01Yoo`005Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8005Eoo`03001oogoo02]oo`03001o
ogoo07moo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000kOol00`00Oomo
o`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`0JOol001Ioo`05001oogooOol0000?
Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1DOol00`00Oomoo`0/Ool00`00Oomoo`1nOol01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0>Goo00<007ooOol0:Woo00<007oo
Ool0?goo00<007ooOol0:Goo00<007ooOol06Goo000FOol01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol0Dgoo00<007ooOol0;Goo00<007ooOol0OWoo00D007ooOomo
o`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo03Uoo`03001oogoo02Yoo`03001o
ogoo03ioo`03001oogoo02Yoo`03001oogoo01Uoo`005Woo00D007ooOomoo`0000]oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool2001COol00`00Oomoo`0_Ool00`00Oomoo`1mOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8003Yoo`03001oogoo02Yoo`03001oogoo
03ioo`03001oogoo02Yoo`03001oogoo01Uoo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0
DGoo00<007ooOol0<Goo00<007ooOol0OGoo0`003Goo0`001Goo10001Goo00<007ooOol0>7oo00<0
07ooOol0;7oo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol067oo000hOol00`00Oomoo`1@
Ool00`00Oomoo`0cOol00`00Oomoo`2MOol00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00Oomoo`0l
Ool00`00Oomoo`0/Ool00`00Oomoo`0HOol003Qoo`03001oogoo01moo`<000Ioo`8000Aoo`D001Qo
o`<0009oo`04001oogooOol20006Ool3000HOol30006Ool20005Ool3000JOol30006Ool20005Ool3
000QOol50019Ool00`00Oomoo`0OOol30006Ool20004Ool50005Ool00`00Oomoo`0@Ool30006Ool2
0006Ool30008Ool00`00Oomoo`0=Ool30006Ool20005Ool3000IOol40005Ool20005Ool3000OOol0
0`00Ool00004000DOol003Qoo`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`005goo
00@007ooOomoo`8000Aoo`8000Moo`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool20002
Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo
04Uoo`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`001Goo00<007ooOol03goo00D0
07ooOomoo`0000Eoo`8000Moo`03001oogoo00Moo`03001oogoo00aoo`05001oogooOol00005Ool2
0004Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000OOol0
1000Oomoo`005Woo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol05goo00D0
07ooOomoo`0000]oo`D001Moo`05001oogooOol0000;Ool01@00Ool007oo000067oo00D007ooOomo
o`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo0000
3Goo00<007ooOol017oo00<007ooOol047oo00D007ooOomoo`0000]oo`D000Uoo`03001oogoo00]o
o`05001oogooOol0000;Ool01@00Oomoogoo00005goo00<007ooOol00P002goo00D007ooOomoo`00
01moo`04001oogoo000FOol003Qoo`03001oogoo01ioo`05001oogooOol0000>Ool00`00Oomoo`0F
Ool01@00Oomoogoo00002goo00@007ooOol001Qoo`05001oogooOol0000;Ool00`00Oomoo`02000H
Ool01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03001oogoo01ioo`05
001oogooOol0000>Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool01@00Oomoogoo00002goo00@007oo
Ool000Yoo`03001oogoo00]oo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00<007ooOol0
0P002goo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`03001oogoo01ioo`05001oogoo
Ool0000?Ool00`00Oomoo`0EOol00`00Oomoo`02000<Ool00`00Ool0000HOol01@00Oomoogoo0000
2goo1@0067oo00D007ooOomoo`0000aoo`<002=oo`03001oogoo04Uoo`03001oogoo01ioo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool01@00Oomoogoo000037oo00<007oo0000
2Woo00<007ooOol02goo00D007ooOomoo`0000]oo`@001Qoo`03001oogoo008000aoo`<0025oo`03
001oo`0001Ioo`00>7oo0P007goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oo`00Ool0
000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0
000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo0P007goo00D007ooOomoo`0000moo`05001o
ogooOol0000COol01@00Oomoogoo000037oo00<007oo00002goo00<007ooOol02Woo00D007ooOomo
o`0000]oo`03001oogoo01Uoo`05001oo`00Ool0000;Ool01@00Oomoogoo000087oo00<007oo0000
5Woo000hOol00`00Oomoo`0NOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`80009oo`03
001oogoo00]oo`8001Qoo`05001oogooOol0000<Ool01@00Oomoogoo00005goo00D007ooOomoo`00
00]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00002goo
00D007ooOomoo`0000=oo`03001oogoo015oo`05001oogooOol0000=Ool2000;Ool00`00Oomoo`0:
Ool01@00Oomoogoo000037oo00<007ooOol067oo00D007oo001oo`0000]oo`05001oogooOol0000P
Ool00`00Ool0000FOol003Qoo`03001oogoo01moo`<000eoo`<001Uoo`<000moo`03001oogoo01Mo
o`<000ioo`<00003Ool007oo01Ioo`<000eoo`<0025oo`<004]oo`03001oogoo01moo`<000eoo`<0
00Aoo`03001oogoo019oo`<000moo`03001oogoo00Uoo`03001oogoo00]oo`<000ioo`<001Qoo`<0
00eoo`<0025oo`<001Ioo`00>7oo0P00Bgoo00<007ooOol0@7oo00<007ooOol0UWoo0P00=Woo00<0
07ooOol0<Woo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol05Goo000hOol00`00Oomoo`19
Ool00`00Oomoo`11Ool00`00Oomoo`2FOol00`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomoo`0f
Ool00`00Oomoo`0bOol00`00Oomoo`0EOol003Qoo`03001oogoo04Uoo`03001oogoo049oo`03001o
ogoo09Eoo`03001oogoo03Eoo`03001oogoo039oo`03001oogoo03Ioo`03001oogoo03=oo`03001o
ogoo01Aoo`00>7oo00<007ooOol0B7oo00<007ooOol0A7oo00<007ooOol0U7oo00<007ooOol0=7oo
00<007ooOol0=7oo00<007ooOol0=7oo00<007ooOol0=7oo00<007ooOol057oo000bOooY0010OooY
000@Ool003Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Eoo`04001oogoo000:Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool01@00Oomoogoo0000
1Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01goo0P00Bgoo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol057oo000hOol20017Ool00`00Oomoo`18Ool00`00
Oomoo`14Ool00`00Oomoo`1;Ool00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0cOol00`00
Oomoo`1<Ool003Qoo`<004Eoo`03001oogoo04Yoo`03001oogoo049oo`03001oogoo04aoo`8003Ao
o`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo00@007ooOol004=oo`03001o
ogoo04aoo`03001oogoo041oo`03001oogoo04eoo`8003Aoo`03001oogoo03Ioo`03001oogoo039o
o`03001oogoo04aoo`00>7oo00@007ooOol0049oo`03001oogoo04eoo`03001oogoo041oo`03001o
ogoo04eoo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo00D007oo
Oomoo`00041oo`03001oogoo04moo`03001oogoo03ioo`03001oogoo04ioo`03001oo`00039oo`03
001oogoo03Qoo`03001oogoo031oo`03001oogoo04eoo`00>7oo0P000goo00<007ooOol0?Goo00<0
07ooOol0D7oo00<007ooOol0?7oo00<007ooOol0Cgoo0`00<Woo00<007ooOol0>7oo00<007ooOol0
<7oo00<007ooOol0CGoo000hOol00`00Oomoo`03Ool00`00Oomoo`0kOol00`00Oomoo`1BOol00`00
Oomoo`0jOol00`00Oomoo`1@Ool00`00Ool0000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00
Oomoo`1=Ool003Qoo`03001oogoo00=oo`03001oogoo03Yoo`03001oogoo05Aoo`03001oogoo03Uo
o`03001oogoo051oo`04001oogoo000`Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`1>
Ool003Qoo`03001oogoo00Aoo`03001oogoo03Qoo`03001oogoo05Eoo`03001oogoo03Qoo`03001o
ogoo055oo`04001oogoo000`Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`1>Ool003Qo
o`8000Ioo`03001oogoo03Ioo`03001oogoo05Moo`03001oogoo03Ioo`03001oogoo059oo`800003
Ool007oo02moo`03001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo00<007ooOol0
1Woo00<007ooOol0=7oo00<007ooOol0FGoo00<007ooOol0=7oo00<007ooOol0Dgoo00D007ooOomo
o`0002ioo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo04moo`00>7oo00<007ooOol01Woo
00<007ooOol0=7oo00<007ooOol0FWoo00<007ooOol0<goo00<007ooOol0Dgoo00D007ooOomoo`00
02ioo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo04moo`00>7oo0P0027oo00<007ooOol0
<Woo00<007ooOol0Fgoo00<007ooOol0<Woo00<007ooOol0E7oo0P000Woo00<007ooOol0;7oo00<0
07ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo000GOol30006Ool20004Ool50004Ool40005
Ool00`00Oomoo`08Ool00`00Oomoo`0`Ool00`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomoo`0d
Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`0n
Ool00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05001oogooOol00005Ool20005Ool01000Oomo
o`0027oo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0;Woo00<007ooOol0Ggoo00<007oo
Ool0;Woo00<007ooOol0=7oo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00Oomo
o`1@Ool001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool00`00Oomoo`0/Ool00`00Oomoo`1QOol00`00Oomoo`0/Ool00`00Oomoo`0eOol01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0:Woo00<007oo
Ool0?Woo00<007ooOol0:Woo00<007ooOol0D7oo000FOol01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo0P0037oo00<007ooOol0:goo00<007ooOol0HWoo00<007ooOol0:Woo00<0
07ooOol0=Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000Aoo`03001o
ogoo02Uoo`03001oogoo03moo`03001oogoo02Qoo`03001oogoo055oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`@000Eoo`03001oogoo00aoo`03001oogoo02Uoo`03001oogoo06Aoo`03
001oogoo02Uoo`03001oogoo03Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00
Oomoo`03Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`1AOol001Io
o`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0=Ool00`00Oomo
o`0WOol00`00Oomoo`1VOol00`00Oomoo`0WOol00`00Oomoo`0gOol01@00Oomoogoo00003goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0:7oo00<007ooOol0@7oo00<0
07ooOol0:7oo00<007ooOol0DGoo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03
001oogoo00Ioo`8000moo`03001oogoo02Eoo`03001oogoo06Qoo`03001oogoo02Eoo`03001oogoo
03Qoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P001Goo00<007oo
Ool09goo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol0DGoo000GOol3000=Ool30005Ool4
0005Ool00`00Oomoo`0?Ool00`00Oomoo`0SOol00`00Oomoo`1ZOol00`00Oomoo`0SOol00`00Oomo
o`0jOol3000=Ool30005Ool40005Ool00`00Oomoo`04Ool00`00Oomoo`0VOol00`00Oomoo`12Ool0
0`00Oomoo`0VOol00`00Oomoo`1BOol003Qoo`03001oogoo011oo`03001oogoo025oo`03001oogoo
06aoo`03001oogoo021oo`8005ioo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo049oo`03
001oogoo02Ioo`03001oogoo059oo`00>7oo00<007ooOol04Goo00<007ooOol07goo00<007ooOol0
KWoo00<007ooOol07Woo00<007ooOol0GWoo00<007ooOol01Goo00<007ooOol09Goo00<007ooOol0
@goo00<007ooOol09Goo00<007ooOol0DWoo000hOol2000COol00`00Oomoo`0MOol00`00Oomoo`1`
Ool00`00Oomoo`0LOol00`00Oomoo`1OOol20006Ool00`00Oomoo`0TOol00`00Oomoo`14Ool00`00
Oomoo`0TOol00`00Oomoo`1COol003Qoo`03001oogoo01=oo`03001oogoo01]oo`03001oogoo079o
o`03001oogoo01Yoo`03001oogoo061oo`03001oogoo00Eoo`03001oogoo02Aoo`03001oogoo04Ao
o`03001oogoo02Aoo`03001oogoo05=oo`00>7oo00<007ooOol057oo0P006Goo0P00MWoo0P0067oo
0P00Hgoo00<007ooOol01Woo00<007ooOol08goo00<007ooOol0AGoo00<007ooOol08goo00<007oo
Ool0Dgoo000hOol2000GOol2000EOol2001jOol2000EOol00`00Oomoo`1SOol20007Ool00`00Oomo
o`0ROol00`00Oomoo`16Ool00`00Oomoo`0ROol00`00Oomoo`1DOol003Qoo`03001oogoo01Qoo`03
001oogoo015oo`03001oogoo07aoo`03001oogoo015oo`03001oogoo06Aoo`03001oogoo00Ioo`03
001oogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo05Aoo`00>7oo00<007ooOol0
6Goo00<007ooOol03Woo0P00P7oo0P003goo0P00Igoo00<007ooOol01goo00<007ooOol08Goo00<0
07ooOol0Agoo00<007ooOol08Goo00<007ooOol0E7oo000hOol00`00Oomoo`0JOol4000:Ool20024
Ool2000:Ool3001YOol00`00Oomoo`07Ool00`00Oomoo`0POol00`00Oomoo`18Ool00`00Oomoo`0P
Ool00`00Oomoo`1EOol003Qoo`8001moo`X008Qoo`X006aoo`8000Qoo`03001oogoo021oo`03001o
ogoo04Qoo`03001oogoo021oo`03001oogoo05Eoo`007goo0`001Woo0P001Goo10001Goo00<007oo
Ool0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol027oo00<007ooOol07goo00<007ooOol0
BGoo00<007ooOol07goo00<007ooOol0EGoo000NOol01@00Oomoogoo00001Goo0P002Goo00<007oo
Ool00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo01ioo`03001oogoo04Yoo`03001oogoo01ioo`03001oogoo05Ioo`007Woo
00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool0
0`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`0NOol00`00Oomoo`1;Ool00`00Oomoo`0MOol0
0`00Oomoo`1FOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomo
ogoo000047oo00<007ooOol00Woo0P002Woo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol0
7Goo00<007ooOol0EWoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D0
07ooOomoo`0000aoo`@000Eoo`03001oogoo00Uoo`03001oogoo01aoo`03001oogoo04eoo`03001o
ogoo01]oo`03001oogoo05Moo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo
0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0KOol0
0`00Oomoo`1>Ool00`00Oomoo`0KOol00`00Oomoo`1GOol001ioo`05001oogooOol0000<Ool00`00
Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P002goo00<007ooOol0
6Woo00<007ooOol0CWoo00<007ooOol06Woo00<007ooOol0F7oo000OOol3000=Ool40005Ool00`00
Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`0:Ool00`00Oomoo`0JOol00`00Oomoo`1?Ool0
0`00Oomoo`0IOol00`00Oomoo`1HOol003Qoo`03001oogoo0?moobMoo`03001oogoo00Yoo`03001o
ogoo01Uoo`03001oogoo051oo`03001oogoo01Uoo`03001oogoo05Qoo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol02goo00<007ooOol067oo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol0
FGoo000hOol2003oOolXOol2000<Ool00`00Oomoo`0GOol00`00Oomoo`1BOol00`00Oomoo`0GOol0
0`00Oomoo`1IOol003Qoo`03001oogoo0?moobMoo`03001oogoo00aoo`03001oogoo01Ioo`03001o
ogoo059oo`03001oogoo01Ioo`03001oogoo05Yoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
37oo00<007ooOol05Goo00<007ooOol0E7oo00<007ooOol05Goo00<007ooOol0FWoo000hOol2003o
OolXOol2000>Ool00`00Oomoo`0DOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`1KOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo00eoo`03001oogoo01Aoo`03001oogoo05Eoo`03001o
ogoo019oo`03001oogoo05aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol03Woo00<007ooOol0
4Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0G7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`1GOol00`00Oomoo`0@Ool00`00Oomoo`1MOol0
03Qoo`800?moobQoo`8000moo`03001oogoo015oo`03001oogoo05Qoo`03001oogoo011oo`03001o
ogoo05eoo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`00
1Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol03goo0P004Goo00<007ooOol0FGoo00<0
07ooOol03Woo00<007ooOol0GWoo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo
00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qo
o`03001oogoo009oo`03001oogoo015oo`03001oogoo00eoo`03001oogoo05Yoo`03001oogoo00io
o`03001oogoo05ioo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03
001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomo
o`0AOol00`00Oomoo`0;Ool2001NOol2000=Ool00`00Oomoo`1OOol001Ioo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo0P004goo00<007ooOol02Goo00<007ooOol0H7oo00<007ooOol02Goo00<0
07ooOol0H7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo01=oo`03001oogoo00Mo
o`03001oogoo069oo`03001oogoo00Moo`03001oogoo065oo`005Woo00D007ooOomoo`0000moo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`0DOol00`00Oomoo`05Ool00`00Oomoo`1TOol00`00Oomo
o`05Ool00`00Oomoo`1ROol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2
000FOol30002Ool2001XOol20003Ool2001UOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo
0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo01Moo`@006Yoo`@006Moo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`80
0?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMo
o`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000_Ool50004Ool00`00Oomoo`3oOolNOol5
0004Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Ao
o`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000a
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Mo
o`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomo
o`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<00004Ool0
0000000HOol3003oOol7Ool3000017oo000000006Goo0`00M7oo002FOol01@00Oomoogoo00002Goo
1P002Goo00D007ooOomoo`000?moo`Moo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1cOol0
09Ioo`05001oogooOol0000LOol00`00Oomoo`3oOol5Ool01@00Oomoogoo000067oo1@00M7oo002F
Ool01@00Oomoogoo00002Goo1P003Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Uoo`H000Uo
o`04001oogoo001eOol009Ioo`05001oogooOol0000JOol2003oOol8Ool01@00Oomoogoo00006Goo
00<007oo0000MGoo002EOol5000MOol00`00Oomoo`3oOol4Ool5000JOol00`00Ool0001eOol00;=o
o`05001oogooOol0003oOolVOol2001eOol00;Aoo`<00?moobQoo`03001oogoo07=oo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo000_Ool5
003oOolUOol5003gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`009Woo1P001Goo00<0
07ooOol0ogoo77oo1P001Goo00<007ooOol0mgoo000aOol00`00Oomoo`04Ool2003oOolQOol00`00
Oomoo`04Ool2003aOol0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03
001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007oo
Ool0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2000aOol8002hOol002mo
o`<000Ioo`03001oogoo0?mooaioo`<000Ioo`03001oogoo02aoo`D000Moo`<00;Eoo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0:goo00<007ooOol03Goo0P00/goo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`0ZOol00`00Oomoo`0@Ool2002aOol003Qoo`800?moobQoo`8002Uoo`8001Eoo`<0
0:ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol09Goo0`006Woo00<007ooOol0Zgoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`0TOol00`00Oomoo`0LOol00`00Oomoo`2ZOol003Qoo`800?mo
obQoo`8002Aoo`03001oogoo01ioo`03001oogoo0:Uoo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool08Woo00<007ooOol087oo00<007ooOol0Z7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0Q
Ool00`00Oomoo`0ROol00`00Oomoo`2WOol003Qoo`03001oogoo0?moobMoo`03001oogoo025oo`03
001oogoo029oo`03001oogoo0:Moo`00>7oo0P00ogoo:7oo0P008Goo00<007ooOol097oo00<007oo
Ool0YWoo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool30006
Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`0OOol00`00Oomoo`0VOol00`00Oomoo`2U
Ool001Ioo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomo
o`3oOol5Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007oo
Ool07Woo00<007ooOol0:7oo00<007ooOol0Y7oo000>Ool60002Ool01@00Oomoogoo00003Woo00<0
07ooOol01goo00<007ooOol00Woo00<007ooOol0o7oo1P000Woo00D007ooOomoo`0000ioo`03001o
ogoo00Moo`03001oogoo009oo`03001oogoo01ioo`03001oogoo02Uoo`03001oogoo0:=oo`005Woo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000NOol00`00Oomoo`0[Ool00`00Oomoo`2ROol0
01Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomo
ogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol077oo00<007ooOol0;7oo00<007ooOol0
XWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01aoo`03001o
ogoo02eoo`03001oogoo0:5oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Io
o`8001aoo`03001oogoo02moo`03001oogoo0:1oo`005goo0`0037oo1@0017oo10001Goo00<007oo
Ool0ogoo1Woo0`0037oo1@0017oo10001Goo00<007ooOol06Woo00<007ooOol0<Goo00<007ooOol0
Wgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0IOol00`00Oomoo`0cOol00`00Oomoo`2NOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo01Uoo`03001oogoo03=oo`03001oogoo09ioo`00>7oo
0P00ogoo:7oo0P006Goo00<007ooOol0=Goo00<007ooOol0WGoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0GOol00`00Oomoo`0gOol00`00Oomoo`2LOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo01Ioo`03001oogoo03Qoo`03001oogoo09aoo`00>7oo0P00ogoo:7oo0P005goo00<007ooOol0
>Goo00<007ooOol0Vgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0EOol00`00Oomoo`0kOol0
0`00Oomoo`2JOol003Qoo`03001oogoo0?moobMoo`03001oogoo01Aoo`03001oogoo03eoo`03001o
ogoo09Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol057oo00<007ooOol0?Goo00<007ooOol0
VGoo000hOol2003oOolXOol2000DOol00`00Oomoo`0oOol00`00Oomoo`2HOol001moo`<000Ioo`80
00Eoo`@000Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo019oo`03001o
ogoo045oo`03001oogoo09Moo`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03
001oogoo0?moo`eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`12Ool00`00Oomoo`2GOol001Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02
Ool2003oOol6Ool60002Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P004Woo00<007ooOol0
@goo00<007ooOol0UWoo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0ogoo
3Goo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo011oo`03001oogoo04Eoo`03001o
ogoo09Eoo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?moo`eoo`05001oogooOol0
000<Ool40005Ool00`00Oomoo`0?Ool00`00Oomoo`16Ool00`00Oomoo`2EOol001ioo`05001oogoo
Ool0000<Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol0
1Woo00<007ooOol03goo00<007ooOol0Agoo00<007ooOol0U7oo000NOol01@00Oomoogoo000037oo
00<007ooOol01Woo0P00ogoo3Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`8000moo`03001o
ogoo04Qoo`03001oogoo09Aoo`007goo0`003Goo10001Goo00<007ooOol0ogoo3Woo0`003Goo1000
1Goo00<007ooOol03Woo00<007ooOol0BGoo00<007ooOol0Tgoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0=Ool00`00Oomoo`1;Ool00`00Oomoo`2BOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo00eoo`03001oogoo04]oo`03001oogoo099oo`00>7oo0P00ogoo:7oo0P003Goo00<007ooOol0
CGoo00<007ooOol0TGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0<Ool00`00Oomoo`1=Ool0
0`00Oomoo`2AOol003Qoo`03001oogoo0?moobMoo`03001oogoo00]oo`03001oogoo04moo`03001o
ogoo091oo`00>7oo0P00ogoo:7oo0P002goo00<007ooOol0DGoo00<007ooOol0Sgoo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`0:Ool00`00Oomoo`1AOol00`00Oomoo`2?Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo00Uoo`03001oogoo05=oo`03001oogoo08ioo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol02Goo00<007ooOol0Dgoo00<007ooOol0SWoo000hOol2003oOolXOol20009Ool0
0`00Oomoo`1EOol00`00Oomoo`2=Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo
0?moo`Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Qoo`03001oogoo05Ioo`03001o
ogoo08aoo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009o
o`03001oogoo00Moo`03001oogoo05Moo`03001oogoo08aoo`003Woo1P000Woo00D007ooOomoo`00
00eoo`03001oogoo00Qoo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000=Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`1HOol00`00Oomoo`2;Ool001Ioo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0FGoo00<007oo
Ool0Rgoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00Ioo`03001oogoo05Yoo`03
001oogoo08Yoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool00`00Oomoo`1KOol00`00Oomoo`2:Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool20006Ool00`00Oomoo`1LOol00`00Oomoo`29Ool001Moo`<000eoo`<000Eoo`@000Eo
o`03001oogoo0?moo`Ioo`<000eoo`<000Eoo`@000Eoo`03001oogoo00Aoo`03001oogoo05eoo`03
001oogoo08Uoo`00>7oo00<007ooOol07goo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`00
67oo0`001Woo0P001Goo0`006Woo0`001Woo0P001Goo0`008Goo1@00BGoo00<007ooOol017oo00<0
07ooOol067oo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`001Woo00<007ooOol03goo0`00
1Woo0P001Goo0`006Goo0`001Woo0P001Goo0`008Goo1@0057oo000hOol2000OOol01@00Oomoogoo
00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool200000goo0000000[0002Ool0
1@00Oomoogoo000067oo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000ROol00`00Oomo
o`19Ool20004Ool00`00Oomoo`0HOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05
001oogooOol00005Ool20007Ool00`00Oomoo`05Ool00`00Oomoo`0>Ool01@00Oomoogoo00001Goo
0P0017oo00D007ooOomoo`0001Moo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00008Woo
00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol05goo00<0
07oo00002P000goo1@005goo00D007ooOomoo`0000Uoo`T001Ioo`05001oogooOol0000;Ool01@00
Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol067oo00D007ooOomoo`00
00eoo`03001oogoo01Moo`05001oogooOol0000;Ool50007Ool00`00Oomoo`0=Ool01@00Oomoogoo
00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007oo
Ool057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Woo00<007ooOol01Goo4`000Woo00<0
07ooOol02Goo00@007ooOol001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00000Woo4P0017oo
00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`02Ool00`00
Oomoo`0IOol01@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo
0009Ool00`00Oomoo`0<Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0
000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo
00003Goo2@004Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool4000E
Ool:000;Ool3000SOol00`00Oomoo`19Ool01@00Oomoogoo000077oo00D007ooOomoo`0000moo`03
001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool00009Ool00`00Oomoo`0<Ool01@00Oomoogoo
00002goo100067oo00D007ooOomoo`0000aoo`<002=oo`03001oogoo01Aoo`00>7oo0P007goo00D0
07ooOomoo`0000Ioo`L0009oo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol0
1@00Oomoogoo00002goo00<007ooOol06Woo00H007ooOomoo`00Ool60004Ool01@00Oomoogoo0000
8Woo00<007ooOol0BGoo0P000Woo00<007ooOol06Woo00D007ooOomoo`0000moo`03001oogoo01Eo
o`05001oogooOol0000<Ool00`00Ool0000:Ool00`00Oomoo`0;Ool01@00Oomoogoo00002goo00<0
07ooOol06Goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03
001oogoo01ioo`06001oogooOol007oo1@001Goo00D007ooOomoo`0001Moo`05001oogooOol0000=
Ool2000HOol01@00Oomoogoo000037oo00<007ooOol06Goo00D007ooOomoo`0000Moo`D000=oo`03
001oogoo021oo`03001oogoo04Uoo`04001oogoo000MOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Moo`05001oogooOol0000=Ool2000:Ool00`00Oomoo`0;Ool01@00Oomoogoo000037oo00<0
07ooOol067oo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03
001oogoo01ioo`H000]oo`<001Uoo`<000moo`03001oogoo01Moo`<000ioo`<001Uoo`<000eoo`L0
01eoo`<004]oo`04001oogoo000NOol3000=Ool3000IOol3000?Ool00`00Oomoo`09Ool00`00Oomo
o`0;Ool3000>Ool3000HOol3000=Ool3000QOol3000FOol003Qoo`03001oogoo01Eoo`T009eoo`T0
069oo`03001oo`0006Uoo`03001oogoo08Aoo`00>7oo0P003goo1`00[goo1`00Fgoo0`00JWoo00<0
07ooOol0Pgoo000hOol00`00Oomoo`09Ool5002mOol5001FOol2001[Ool00`00Oomoo`23Ool003Qo
o`03001oogoo009oo`L00<Moo`L004moo`8006aoo`03001oogoo089oo`00<Wooj@00@7ooj@0047oo
000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool20009Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`0DOol003Qoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo
02Uoo`03001oogoo02Yoo`03001oogoo02Uoo`03001oogoo04Uoo`03001oogoo02Uoo`03001oogoo
02Uoo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo
01Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0KGoo00<007ooOol0J7oo00<007ooOol05Goo
000hOol2003oOolXOol2001^Ool00`00Oomoo`1XOol00`00Oomoo`0EOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo06ioo`03001oogoo06Ioo`03001oogoo01Ioo`00>7oo00<007ooOol0ogoo9goo
00<007ooOol0KWoo00<007ooOol0IWoo00<007ooOol05Woo000hOol2003oOolXOol2001`Ool00`00
Oomoo`1TOol00`00Oomoo`0GOol003Qoo`03001oogoo0?moobMoo`03001oogoo06moo`03001oogoo
06Aoo`03001oogoo01Moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0L7oo00<007ooOol0HWoo
00<007ooOol067oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1`Ool00`00Oomoo`1QOol00`00
Oomoo`0IOol003Qoo`800?moobQoo`80075oo`03001oogoo065oo`03001oogoo01Uoo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0LGoo00<007ooOol0Ggoo00<007ooOol06Woo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`1aOol00`00Oomoo`1OOol00`00Oomoo`0JOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo079oo`03001oogoo05eoo`03001oogoo01]oo`00>7oo0P00ogoo:7oo0P00Lgoo
00<007ooOol0GGoo00<007ooOol06goo000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomo
o`3oOol6Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`1cOol00`00Oomoo`1KOol00`00
Oomoo`0LOol001Ioo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo
00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02
Ool00`00Oomoo`1cOol00`00Oomoo`1KOol00`00Oomoo`0LOol001Ioo`05001oogooOol0000=Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Goo00<007ooOol027oo
00<007ooOol00Woo0P00MGoo00<007ooOol0FGoo00<007ooOol07Goo000FOol01@00Oomoogoo0000
3Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo07Aoo`03001oogoo05Uoo`03001oogoo01eoo`00
5Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1eOol00`00Oomoo`1GOol00`00Oomoo`0N
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0MWoo00<007oo
Ool0EWoo00<007ooOol07Woo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001o
ogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo
0P00Mgoo00<007ooOol0EGoo00<007ooOol07goo000GOol3000=Ool30005Ool40005Ool00`00Oomo
o`3oOol6Ool3000=Ool30005Ool40005Ool00`00Oomoo`1gOol00`00Oomoo`1COol00`00Oomoo`0P
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo07Moo`03001oogoo05=oo`03001oogoo021oo`00
>7oo0P00ogoo:7oo0P00NGoo00<007ooOol0DGoo00<007ooOol08Goo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`1iOol00`00Oomoo`1@Ool00`00Oomoo`0QOol003Qoo`03001oogoo0?moobMoo`03
001oogoo07Uoo`03001oogoo04moo`03001oogoo029oo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0NWoo00<007ooOol0CWoo00<007ooOol08Woo000hOol2003oOolXOol2001lOol00`00Oomoo`1<
Ool00`00Oomoo`0SOol003Qoo`03001oogoo0?moobMoo`03001oogoo07]oo`03001oogoo04aoo`03
001oogoo02=oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0O7oo00<007ooOol0BWoo00<007oo
Ool097oo000hOol2003oOolXOol2001mOol00`00Oomoo`19Ool00`00Oomoo`0UOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo07eoo`03001oogoo04Qoo`03001oogoo02Eoo`007goo0`001Woo0P00
1Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0OWoo00<007oo
Ool0AWoo00<007ooOol09Woo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<0
07ooOol0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo07ioo`03
001oogoo04Ioo`03001oogoo02Ioo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?mo
o`ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool20020Ool00`00Oomoo`14Ool00`00Oomoo`0W
Ool001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo
000047oo00<007ooOol00Woo00<007ooOol0P7oo00<007ooOol0@Woo00<007ooOol0:7oo000NOol0
1@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03
001oogoo081oo`03001oogoo049oo`03001oogoo02Qoo`007Woo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`21
Ool00`00Oomoo`10Ool00`00Oomoo`0YOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2
003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P00Pgoo00<007ooOol0?Woo00<007oo
Ool0:Woo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`22
Ool00`00Oomoo`0nOol00`00Oomoo`0ZOol003Qoo`03001oogoo0?moobMoo`03001oogoo08=oo`03
001oogoo03aoo`03001oogoo02]oo`00>7oo0P00ogoo:7oo0P00Q7oo00<007ooOol0>goo00<007oo
Ool0;7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`24Ool00`00Oomoo`0jOol00`00Oomoo`0/
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Eoo`03001oogoo03Qoo`03001oogoo02eoo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0QGoo00<007ooOol0=goo00<007ooOol0;Woo000hOol2
003oOolXOol20027Ool00`00Oomoo`0fOol00`00Oomoo`0^Ool003Qoo`03001oogoo0?moobMoo`03
001oogoo08Moo`03001oogoo03Aoo`03001oogoo02moo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0Qgoo00<007ooOol0<goo00<007ooOol0<7oo000hOol2003oOolXOol20029Ool00`00Oomoo`0b
Ool00`00Oomoo`0`Ool001Moo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?mo
o`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo08Uoo`03001oogoo031oo`03
001oogoo035oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009o
o`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`29Ool00`00Oomoo`0_Ool00`00Oomoo`0bOol001Ioo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol0RWoo00<007ooOol0;Goo00<007ooOol0<goo000FOol0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00ogoo1Woo00D007ooOomoo`00
00ioo`03001oogoo00Moo`03001oogoo009oo`8008aoo`03001oogoo02]oo`03001oogoo03Aoo`00
5Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogoo
Ool0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`2<Ool00`00Oomoo`0ZOol00`00Oomoo`0d
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0SGoo00<007oo
Ool0:7oo00<007ooOol0=Goo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001o
ogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo00<007ooOol0SWoo00<007ooOol09Woo00<007ooOol0=Woo000GOol3000<Ool50004Ool4
0005Ool2003oOol7Ool3000<Ool50004Ool40005Ool2002@Ool00`00Oomoo`0TOol00`00Oomoo`0g
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo091oo`80029oo`8003Yoo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0TWoo00<007ooOol07Woo00<007ooOol0>Woo000hOol2003oOolXOol2002D
Ool00`00Oomoo`0LOol00`00Oomoo`0kOol003Qoo`03001oogoo0?moobMoo`03001oogoo09Aoo`03
001oogoo01Yoo`03001oogoo03aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0UGoo0P006Goo
00<007ooOol0?Goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2GOol00`00Oomoo`0EOol00`00
Oomoo`0nOol003Qoo`800?moobQoo`8009Uoo`03001oogoo019oo`80045oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0VGoo0`003Woo0`00@goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2L
Ool2000;Ool00`00Oomoo`14Ool003Qoo`800?moobQoo`8009moo`/004Moo`00;goo1@0017oo00<0
07ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolP
Ool00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03
001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo
0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03
001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3003oOolWOol3003i
Ool00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo1@00ogoo1Goo0`0000Ao
o`00000001Moo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05
001oogooOol00009Ool6000:Ool01000Oomoo`00M7oo002FOol01@00Oomoogoo00006goo00<007oo
Ool0ogoo1Woo00D007ooOomoo`0001Yoo`03001oogoo07Aoo`00UWoo00D007ooOomoo`0000Uoo`H0
00aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05
001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo000077oo00<007ooOol0LWoo002E
Ool5000LOol00`00Oomoo`3oOol5Ool5000MOol00`00Oomoo`1bOol00;Ioo`03001oogoo0?moob=o
o`05001oogooOol0001dOol00;Aoo`<00?moobIoo`<007Eoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .40229 L
.08255 .4463 L
.10458 .48823 L
.12507 .51966 L
.14415 .54119 L
.14918 .54552 L
.15465 .54955 L
.15946 .55253 L
.16457 .55507 L
.16917 .55683 L
.17178 .5576 L
.17423 .55817 L
.17538 .55839 L
.17647 .55857 L
.17746 .5587 L
.17852 .55882 L
.17967 .55892 L
.18073 .55898 L
.182 .55901 L
.18314 .55901 L
.18435 .55898 L
.18547 .55891 L
.1867 .55881 L
.18802 .55865 L
.19071 .5582 L
.19317 .55764 L
.1979 .55613 L
.20239 .55421 L
.21236 .54821 L
.22321 .53904 L
.24299 .51561 L
.26399 .4821 L
.30174 .40433 L
.34195 .30734 L
.38063 .21407 L
.40028 .17118 L
.42177 .13026 L
.44253 .09836 L
.4614 .07704 L
.47149 .0689 L
.47611 .06597 L
.48101 .06342 L
.4835 .06234 L
.48624 .06133 L
.48876 .06056 L
.49106 .05999 L
.49378 .05949 L
.49527 .05929 L
.49596 .05922 L
Mistroke
.49669 .05915 L
.498 .05907 L
.49921 .05902 L
.49996 .05902 L
.50065 .05902 L
.50196 .05906 L
.50313 .05914 L
.50438 .05925 L
.50556 .05939 L
.50663 .05955 L
.50926 .06007 L
.51175 .0607 L
.5167 .06242 L
.52208 .06496 L
.53169 .07121 L
.54056 .07889 L
.55926 .10079 L
.57988 .13315 L
.62014 .21584 L
.65888 .30938 L
.70007 .40846 L
.72063 .45277 L
.73974 .48866 L
.75939 .51886 L
.77791 .54011 L
.78775 .54829 L
.79293 .55168 L
.7984 .55458 L
.80302 .55647 L
.80546 .55726 L
.80809 .55794 L
.8105 .55842 L
.8127 .55874 L
.81375 .55885 L
.81491 .55894 L
.81599 .55899 L
.817 .55901 L
.81818 .55901 L
.81941 .55897 L
.82047 .55891 L
.82163 .5588 L
.82287 .55866 L
.82421 .55846 L
.82661 .55799 L
.82905 .55738 L
.83134 .55666 L
.83564 .55498 L
.84078 .55239 L
.84552 .54944 L
.85624 .54084 L
Mistroke
.87498 .5196 L
.89561 .48791 L
.93591 .40604 L
.97471 .31269 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35562 L
.08255 .37584 L
.0932 .38473 L
.10458 .39259 L
.11009 .39572 L
.11531 .39827 L
.12038 .40034 L
.12507 .40189 L
.12951 .40303 L
.13178 .40349 L
.13422 .40389 L
.13549 .40406 L
.13666 .40419 L
.13784 .4043 L
.13895 .40438 L
.14022 .40445 L
.1409 .40448 L
.14161 .4045 L
.1423 .40451 L
.14295 .40451 L
.14415 .40449 L
.14531 .40446 L
.14656 .40439 L
.14773 .40431 L
.14881 .40421 L
.15143 .4039 L
.15392 .40349 L
.15886 .40239 L
.16423 .40074 L
.17383 .39665 L
.1827 .39161 L
.20137 .37744 L
.22197 .35704 L
.26217 .30868 L
.30086 .26207 L
.32051 .24232 L
.3309 .23361 L
.342 .22586 L
.35275 .22006 L
.35784 .21793 L
.36253 .21633 L
.36724 .21508 L
.36972 .21457 L
.37235 .21414 L
.37463 .21386 L
.37573 .21375 L
.37677 .21367 L
.37799 .2136 L
.37911 .21355 L
Mistroke
.38031 .21353 L
.38162 .21353 L
.38227 .21354 L
.38296 .21356 L
.38419 .21361 L
.38551 .2137 L
.38695 .21382 L
.38955 .21414 L
.39197 .21453 L
.39649 .21553 L
.40134 .21696 L
.40698 .2191 L
.41232 .22159 L
.42232 .2274 L
.44227 .24311 L
.4607 .26169 L
.50002 .30904 L
.53782 .35472 L
.55884 .37593 L
.56803 .38368 L
.57808 .39089 L
.58722 .39621 L
.59696 .40048 L
.60236 .4022 L
.60726 .40336 L
.60962 .40377 L
.61086 .40395 L
.61218 .40412 L
.61333 .40424 L
.61459 .40434 L
.61574 .40442 L
.61682 .40447 L
.61808 .4045 L
.61871 .40451 L
.61941 .40451 L
.62065 .40449 L
.62181 .40444 L
.62248 .40441 L
.62318 .40437 L
.62443 .40427 L
.62578 .40413 L
.62725 .40395 L
.62973 .40356 L
.63238 .40304 L
.63715 .4018 L
.64214 .40011 L
.64686 .39815 L
.6557 .39356 L
.67568 .37906 L
.69413 .36136 L
Mistroke
.7335 .3148 L
.77136 .26844 L
.79241 .24629 L
.81166 .23021 L
.82118 .22408 L
.8262 .22137 L
.83155 .21892 L
.8367 .21698 L
.84136 .21559 L
.84361 .21504 L
.84604 .21455 L
.84835 .21417 L
.85045 .2139 L
.85159 .21378 L
.85283 .21368 L
.85414 .2136 L
.85538 .21355 L
.85653 .21353 L
.85776 .21353 L
.85881 .21355 L
.85997 .21359 L
.86063 .21363 L
.86132 .21367 L
.86256 .21377 L
.86535 .21409 L
.86777 .21446 L
.87041 .21498 L
.87569 .21637 L
.88133 .21835 L
.89148 .22316 L
.90173 .22958 L
.91284 .23817 L
.933 .25749 L
.97393 .30617 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .29688 L
.10458 .28387 L
.14415 .2721 L
.18221 .26136 L
.22272 .25076 L
.26171 .24154 L
.30316 .23296 L
.34309 .22603 L
.3815 .22073 L
.40095 .21858 L
.42237 .21664 L
.44268 .21523 L
.45178 .21473 L
.46172 .21429 L
.4671 .21409 L
.4721 .21393 L
.47727 .21379 L
.48196 .21369 L
.48658 .21362 L
.4887 .21359 L
.49093 .21357 L
.49332 .21355 L
.49438 .21354 L
.49552 .21354 L
.49675 .21353 L
.49789 .21353 L
.49859 .21353 L
.49925 .21353 L
.50049 .21353 L
.50163 .21353 L
.50286 .21353 L
.50401 .21353 L
.50508 .21354 L
.50754 .21356 L
.51014 .21358 L
.51268 .21361 L
.51504 .21364 L
.5204 .21374 L
.5293 .21397 L
.53882 .21431 L
.54906 .21477 L
.56016 .2154 L
.58032 .21686 L
.62123 .22106 L
.66064 .22662 L
.69852 .23328 L
.73886 .24167 L
.77769 .25086 L
.81897 .26168 L
Mistroke
.85873 .27294 L
.89697 .28435 L
.93767 .29692 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .24598 L
.10458 .18202 L
.14415 .13074 L
.18221 .09278 L
.20178 .07843 L
.21267 .07209 L
.22272 .06733 L
.23293 .06357 L
.23832 .06204 L
.24402 .06075 L
.24641 .06032 L
.24897 .05993 L
.25119 .05964 L
.25361 .05939 L
.25507 .05927 L
.25643 .05918 L
.25773 .05911 L
.2584 .05908 L
.25912 .05906 L
.25983 .05904 L
.26048 .05903 L
.26176 .05902 L
.26293 .05902 L
.26416 .05904 L
.26538 .05908 L
.26607 .05911 L
.26671 .05914 L
.26912 .0593 L
.27131 .0595 L
.27364 .05977 L
.27847 .06051 L
.2838 .06162 L
.29326 .06435 L
.30213 .06777 L
.32232 .07861 L
.34082 .09214 L
.38045 .13165 L
.41855 .18106 L
.45912 .2424 L
.49816 .30598 L
.53966 .37368 L
.57964 .43441 L
.61811 .48469 L
.63759 .50605 L
.65902 .52577 L
.67938 .5405 L
.69843 .5505 L
.70884 .55437 L
.71396 .55585 L
Mistroke
.71872 .55698 L
.72301 .55778 L
.72758 .55842 L
.7302 .55868 L
.73148 .55878 L
.73266 .55886 L
.73371 .55891 L
.73487 .55896 L
.73603 .55899 L
.73725 .55901 L
.73856 .55902 L
.73977 .559 L
.7404 .55899 L
.7411 .55897 L
.74251 .55891 L
.74375 .55884 L
.74508 .55875 L
.74748 .55854 L
.74985 .55827 L
.75235 .55791 L
.7568 .55712 L
.76198 .55592 L
.7668 .55455 L
.77773 .55052 L
.78828 .54544 L
.79823 .5396 L
.81683 .52604 L
.85534 .48788 L
.89632 .43474 L
.93577 .3749 L
.97371 .31311 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`1XOol7002gOol00`00Oomoo`3`Ool003Qoo`8006Moo`8000Moo`<00;Aoo`800?5oo`00
5goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0I7oo0P0037oo00<007ooOol0
T7oo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0Hgoo00<007ooOol03Goo
0P00Sgoo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo
0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8006=o
o`03001oogoo011oo`03001oogoo08Aoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`1ROol00`00Oomoo`0@Ool00`00Oomoo`2<Ool01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol0
0goo10001Goo00<007ooOol0HGoo00<007ooOol04Woo00<007ooOol0Rgoo00D007ooOomoo`0000io
o`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo061oo`03001oogoo01Aoo`03001oogoo08Yoo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0
000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00H7oo00<007ooOol05Goo00<007ooOol0
RWoo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003aOol001Moo`<0
00aoo`D000Aoo`@000Eoo`03001oogoo05ioo`03001oogoo01Moo`03001oogoo08Yoo`<000aoo`D0
00Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0GWoo00<007ooOol067oo00<007ooOol0
ZWoo00<007ooOol0l7oo000hOol2001NOol00`00Oomoo`0IOol00`00Oomoo`2ZOol2003aOol003Qo
o`03001oogoo05aoo`03001oogoo01]oo`03001oogoo0:Uoo`03001oogoo0?1oo`00>7oo00<007oo
Ool0Fgoo00<007ooOol07Goo00<007ooOol0Z7oo00<007ooOol0l7oo000hOol00`00Oomoo`1KOol0
0`00Oomoo`0NOol00`00Oomoo`2WOol00`00Oomoo`3`Ool003Qoo`8005]oo`03001oogoo01moo`03
001oogoo0:Moo`800?5oo`00>7oo00<007ooOol0FGoo00<007ooOol08Goo00<007ooOol0YWoo00<0
07ooOol0l7oo000hOol00`00Oomoo`1IOol00`00Oomoo`0ROol00`00Oomoo`2UOol00`00Oomoo`3`
Ool003Qoo`8005Uoo`03001oogoo02=oo`03001oogoo0:Eoo`800?5oo`007goo0`001Woo0P001Goo
10001Goo00<007ooOol0F7oo00<007ooOol097oo00<007ooOol0Rgoo0`001Woo0P001Goo10001Goo
00<007ooOol0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0
Egoo00<007ooOol09Goo00<007ooOol0RWoo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009o
o`03001oogoo0?1oo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo
05Moo`03001oogoo02Ioo`03001oogoo085oo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02
Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2001GOol00`00Oomo
o`0WOol00`00Oomoo`29Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00
Oomoogoo000037oo10001Goo00<007ooOol0EWoo00<007ooOol0:7oo00<007ooOol0R7oo00D007oo
Oomoo`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Io
o`03001oogoo05Eoo`03001oogoo02Uoo`03001oogoo08Qoo`05001oogooOol0000<Ool00`00Oomo
o`06Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1E
Ool00`00Oomoo`0ZOol00`00Oomoo`27Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007oo
Ool0l7oo000OOol3000=Ool40005Ool2001EOol00`00Oomoo`0[Ool00`00Oomoo`28Ool3000=Ool4
0005Ool2003aOol003Qoo`03001oogoo05Aoo`03001oogoo02aoo`03001oogoo0:1oo`03001oogoo
0?1oo`00>7oo00<007ooOol0Dgoo00<007ooOol0;Goo00<007ooOol0X7oo00<007ooOol0l7oo000h
Ool2001DOol00`00Oomoo`0]Ool00`00Oomoo`2POol2003aOol003Qoo`03001oogoo05=oo`03001o
ogoo02ioo`03001oogoo09moo`03001oogoo0?1oo`00>7oo00<007ooOol0DWoo00<007ooOol0;goo
00<007ooOol0Wgoo00<007ooOol0l7oo000hOol00`00Oomoo`1BOol00`00Oomoo`0`Ool00`00Oomo
o`2NOol00`00Oomoo`3`Ool003Qoo`80059oo`03001oogoo035oo`03001oogoo09ioo`800?5oo`00
>7oo00<007ooOol0DGoo00<007ooOol0<Woo00<007ooOol0WGoo00<007ooOol0l7oo000hOol00`00
Oomoo`1AOol00`00Oomoo`0bOol00`00Oomoo`2MOol00`00Oomoo`3`Ool003Qoo`80055oo`03001o
ogoo03Aoo`03001oogoo09aoo`8004aoo`/006=oo`/002aoo`005goo0`001Woo0P0017oo1@0017oo
10001Goo00<007ooOol0D7oo00<007ooOol0=7oo00<007ooOol0Ngoo0`001Woo0P0017oo1@0017oo
10001Goo00<007ooOol0BGoo0P002goo00<007ooOol0GWoo0P002goo0P00:Woo000FOol01@00Oomo
ogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo04moo`03001oogoo
03Ioo`03001oogoo07Uoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol0
0Woo00<007ooOol0B7oo00<007ooOol037oo0P00G7oo0P003goo0P00:7oo000>Ool60002Ool01@00
Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0Cgoo00<007ooOol0=Woo
00<007ooOol0LGoo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo04Ioo`80015oo`8005Uoo`03001oogoo015oo`8002Ioo`005Woo00D007ooOomoo`0000io
o`03001oogoo00Moo`03001oogoo009oo`8004moo`03001oogoo03Moo`03001oogoo07Uoo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20015Ool2000EOol00`00Oomoo`1DOol2
000FOol00`00Oomoo`0SOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00
Oomoo`1>Ool00`00Oomoo`0hOol00`00Oomoo`1hOol01@00Oomoogoo00003goo00<007ooOol00Woo
10001Goo00<007ooOol0@goo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05goo00<007oo
Ool08Woo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
CWoo00<007ooOol0>7oo00<007ooOol0N7oo00D007ooOomoo`0000moo`03001oogoo009oo`03001o
ogoo00Ioo`03001oogoo049oo`03001oogoo01Qoo`03001oogoo051oo`03001oogoo01Qoo`03001o
ogoo029oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001>
Ool00`00Oomoo`0jOol00`00Oomoo`1gOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03
001oogoo00Ioo`80049oo`03001oogoo01Yoo`03001oogoo04ioo`03001oogoo01Yoo`03001oogoo
025oo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0CGoo00<007ooOol0>Woo00<007ooOol0
N7oo0`003Goo0`001Goo10001Goo00<007ooOol0@7oo00<007ooOol077oo00<007ooOol0C7oo00<0
07ooOol077oo00<007ooOol087oo000hOol00`00Oomoo`1<Ool00`00Oomoo`0kOol00`00Oomoo`2I
Ool00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`0O
Ool003Qoo`03001oogoo01moo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Io
o`8000Eoo`<00003Ool007oo01Moo`<000Ioo`8000Eoo`<0025oo`D004Uoo`03001oogoo01moo`<0
00Ioo`8000Aoo`D000]oo`03001oogoo00Yoo`<000Ioo`8000Ioo`<0009oo`03001oogoo01=oo`<0
00Ioo`8000Eoo`<001Uoo`<000Ioo`8000Eoo`<001Uoo`03001oogoo00Eoo`D001Aoo`00>7oo0P00
7goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol20002Ool00`00Oomoo`03Ool20007
Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00@007ooOomoo`8001Moo`05001oogoo
Ool00005Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo0P007goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo000:Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P001goo00<0
07ooOol00Woo00<007ooOol04Goo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000GOol0
1@00Oomoogoo000017oo0`0017oo00D007ooOomoo`0001Qoo`03001oogoo00Moo`03001oogoo01Ao
o`00>7oo00<007ooOol07Woo00D007ooOomoo`0000eoo`03001oogoo01Moo`80009oo`03001oogoo
00Uoo`D001Moo`05001oogooOol0000;Ool01`00Oomoogoo001oo`0001Ioo`05001oogooOol0000;
Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000eoo`03
001oogoo00Yoo`03001oogoo00Yoo`05001oogooOol0000;Ool50003Ool00`00Oomoo`0AOol01@00
Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol00003Ool00`00Oomoo`05Ool01@00
Oomoogoo00006Goo00<007ooOol01Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomo
ogoo00003Woo00<007ooOol05Woo0P000Woo00<007ooOol02Goo00@007ooOol001Qoo`05001oogoo
Ool0000;Ool01`00Oomoogoo001oo`0001Ioo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo
00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo00Qoo`03001oogoo
00]oo`05001oogooOol0000;Ool01000Oomoo`001Goo00<007ooOol047oo00D007ooOomoo`0000]o
o`05001oogooOol0000GOol01@00Oomoogoo00000goo00<007ooOol01Goo00D007ooOomoo`0001Yo
o`03001oogoo00Eoo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000moo`03
001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10000goo
00<007ooOol04goo00D007ooOomoo`0000aoo`<002=oo`03001oogoo04Uoo`03001oogoo01ioo`05
001oogooOol0000?Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool01@00Oomoogoo000037oo00<007oo
00001Woo00<007ooOol03goo00D007ooOomoo`0000]oo`@001Qoo`05001oogooOol00002Ool00`00
Oomoo`07Ool3000LOol00`00Oomoo`04Ool00`00Oomoo`0DOol003Qoo`8001moo`05001oogooOol0
000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`0000]o
o`03001oogoo00Aoo`03001oogoo01=oo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<0
07ooOol0BGoo0P007goo00D007ooOomoo`0000moo`03001oogoo00Eoo`03001oogoo00eoo`05001o
ogooOol0000<Ool00`00Ool00007Ool00`00Oomoo`0>Ool01@00Oomoogoo00002goo00<007ooOol0
6Goo00L007ooOomoo`00Ool00009Ool01@00Oomoogoo000077oo00<007ooOol00goo00<007ooOol0
57oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00002goo00D007ooOomoo`0001Ioo`8000=oo`03
001oogoo00]oo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`03Ool00`00Oomoo`0COol01@00
Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03001oogoo01ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo00001Woo00<007ooOol03Woo00D007ooOomoo`0000eoo`8000Qoo`03
001oogoo00eoo`05001oogooOol0000<Ool00`00Oomoo`0HOol01000Oomoogoo0P002Woo00D007oo
Oomoo`0001eoo`03001oogoo009oo`03001oogoo01Aoo`00>7oo00<007ooOol07goo0`003Goo0`00
5goo00<007oo00000P003goo00<007ooOol05goo0`003Woo0`000goo00<007ooOol04goo0`003Goo
0`008Goo0`00Bgoo00<007ooOol07goo0`003Goo0`001Woo00<007ooOol047oo0`003goo00<007oo
Ool01goo00<007ooOol03Goo0`003Woo0`0067oo100037oo0`007goo00<007oo00000P005Woo000h
Ool20019Ool00`00Oomoo`13Ool00`00Oomoo`2EOol2000iOol00`00Oomoo`0/Ool00`00Oomoo`0k
Ool00`00Oomoo`0^Ool00`00Oomoo`0GOol003Qoo`03001oogoo04Qoo`03001oogoo04Aoo`03001o
ogoo09Aoo`03001oogoo03Moo`03001oogoo02ioo`03001oogoo03Yoo`03001oogoo02moo`03001o
ogoo01Ioo`00>7oo00<007ooOol0B7oo00<007ooOol0A7oo00<007ooOol0U7oo00<007ooOol0=Woo
00<007ooOol0<7oo00<007ooOol0>7oo00<007ooOol0<Goo00<007ooOol05Goo000hOol00`00Oomo
o`17Ool00`00Oomoo`15Ool00`00Oomoo`2DOol00`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomo
o`0fOol00`00Oomoo`0cOol00`00Oomoo`0DOol0039oonT0041oonT0011oo`00>7oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol017oo00D007ooOomoo`0000Yoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`05001oogooOol00006Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool2
001;Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool2000:Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`0DOol003Qoo`8004Moo`03001oogoo04Qoo`03001oogoo04Eoo`03001oogoo04Yoo`80
03Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo0P00AWoo00<007ooOol0
BGoo00<007ooOol0A7oo00<007ooOol0Bgoo0`00<Woo00<007ooOol0>7oo00<007ooOol0<7oo00<0
07ooOol0CGoo000hOol00`00Ool00015Ool00`00Oomoo`1:Ool00`00Oomoo`13Ool00`00Oomoo`1;
Ool01000Oomoo`00<7oo00<007ooOol0>Woo00<007ooOol0;Woo00<007ooOol0CWoo000hOol00`00
Ool00015Ool00`00Oomoo`1:Ool00`00Oomoo`12Ool00`00Oomoo`1<Ool01@00Oomoogoo0000;Woo
00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo000hOol00`00Ool00014Ool00`00Oomo
o`1;Ool00`00Oomoo`12Ool00`00Oomoo`1<Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomo
o`0nOol00`00Oomoo`0ZOol00`00Oomoo`1@Ool003Qoo`800003Ool007oo049oo`03001oogoo04ao
o`03001oogoo045oo`03001oogoo04aoo`8000=oo`03001oogoo02Yoo`03001oogoo03moo`03001o
ogoo02Qoo`03001oogoo055oo`00>7oo00@007ooOol0049oo`03001oogoo04eoo`03001oogoo041o
o`03001oogoo04eoo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo045oo`03001oogoo02Mo
o`03001oogoo055oo`00>7oo00D007ooOomoo`00045oo`03001oogoo04ioo`03001oogoo03moo`03
001oogoo04eoo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03
001oogoo059oo`00>7oo00D007ooOomoo`00041oo`03001oogoo04moo`03001oogoo03ioo`03001o
ogoo04ioo`03001oogoo00Eoo`03001oogoo02Aoo`03001oogoo04Eoo`03001oogoo02=oo`03001o
ogoo05=oo`00>7oo0P000goo00<007ooOol0?Goo00<007ooOol0D7oo00<007ooOol0?Goo00<007oo
Ool0CWoo0P001goo00<007ooOol08Woo00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol0E7oo
000hOol00`00Oomoo`02Ool00`00Oomoo`0mOol00`00Oomoo`1@Ool00`00Oomoo`0lOol00`00Oomo
o`1?Ool00`00Oomoo`07Ool00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomo
o`1EOol003Qoo`03001oogoo009oo`03001oogoo03aoo`03001oogoo055oo`03001oogoo03aoo`03
001oogoo04moo`03001oogoo00Qoo`03001oogoo01ioo`03001oogoo04]oo`03001oogoo01eoo`03
001oogoo05Ioo`00>7oo0P0017oo00<007ooOol0>goo00<007ooOol0DWoo00<007ooOol0>goo00<0
07ooOol0Cgoo0P002Woo00<007ooOol077oo00<007ooOol0CGoo00<007ooOol06goo00<007ooOol0
Egoo000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`03Ool00`00Oomoo`0jOol00`00
Oomoo`1COol00`00Oomoo`0jOol00`00Oomoo`0_Ool30006Ool20004Ool50004Ool40005Ool00`00
Oomoo`0:Ool2000KOol00`00Oomoo`1?Ool00`00Oomoo`0IOol00`00Oomoo`1HOol001Ioo`05001o
ogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool0>Goo00<007ooOol0E7oo00<007ooOol0>Goo00<007ooOol0;Woo00D007ooOomoo`0000Eoo`80
00Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0FOol2001COol0
0`00Oomoo`0FOol2001KOol001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Oomoo`0hOol00`00Oomoo`1EOol00`00Oomoo`0hOol00`00Oomoo`0_
Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol03Goo00<007oo
Ool057oo00<007ooOol0E7oo00<007ooOol04goo0P00GGoo000FOol01@00Oomoogoo00003Woo00<0
07ooOol01goo00<007ooOol00Woo0P001Woo00<007ooOol0=goo00<007ooOol0EWoo00<007ooOol0
=goo00<007ooOol0;goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000mo
o`03001oogoo019oo`03001oogoo05Ioo`03001oogoo015oo`03001oogoo05eoo`005Woo00D007oo
Oomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00Eoo`03001oogoo03Moo`03001oogoo
05Ioo`03001oogoo03Ioo`03001oogoo031oo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005
Ool00`00Oomoo`0?Ool2000@Ool2001JOol2000?Ool2001POol001Ioo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`1GOol0
0`00Oomoo`0fOol00`00Oomoo`0`Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
1Woo00<007ooOol04Goo0P0037oo0P00GWoo0`002goo00<007ooOol0H7oo000FOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000Moo`03001oogoo03Eoo`03001oogoo
05Qoo`03001oogoo03Eoo`03001oogoo031oo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol01Woo0P0057oo0P001goo0`00Hgoo0P001goo0P00Hgoo000GOol3000=Ool30005Ool4
0005Ool00`00Oomoo`06Ool00`00Oomoo`0dOol00`00Oomoo`1IOol00`00Oomoo`0dOol00`00Oomo
o`0bOol3000=Ool30005Ool40005Ool00`00Oomoo`0EOol7001XOol7001UOol003Qoo`03001oogoo
00Moo`03001oogoo03=oo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo05=oo`03001oogoo
0?1oo`00>7oo00<007ooOol01goo00<007ooOol0<Woo00<007ooOol0Fgoo00<007ooOol0<Woo00<0
07ooOol0E7oo00<007ooOol0l7oo000hOol20009Ool00`00Oomoo`0aOol00`00Oomoo`1LOol00`00
Oomoo`0aOol00`00Oomoo`1DOol2003aOol003Qoo`03001oogoo00Qoo`03001oogoo031oo`03001o
ogoo05eoo`03001oogoo031oo`03001oogoo05Eoo`03001oogoo0?1oo`00>7oo00<007ooOol02Goo
00<007ooOol0;goo00<007ooOol0GGoo00<007ooOol0<7oo00<007ooOol0EGoo00<007ooOol0l7oo
000hOol2000:Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0^Ool00`00Oomoo`1FOol2
003aOol003Qoo`03001oogoo00Uoo`03001oogoo02ioo`03001oogoo05moo`03001oogoo02ioo`03
001oogoo05Ioo`03001oogoo0?1oo`00>7oo00<007ooOol02Woo00<007ooOol0;Goo00<007ooOol0
H7oo00<007ooOol0;7oo00<007ooOol0Egoo00<007ooOol0l7oo000hOol00`00Oomoo`0:Ool00`00
Oomoo`0/Ool00`00Oomoo`1QOol00`00Oomoo`0/Ool00`00Oomoo`1GOol00`00Oomoo`3`Ool003Qo
o`8000aoo`03001oogoo02]oo`03001oogoo065oo`03001oogoo02]oo`03001oogoo05Qoo`800?5o
o`007goo0`001Woo0P001Goo10001Goo00<007ooOol02goo00<007ooOol0:Woo00<007ooOol0Hgoo
00<007ooOol0:Woo00<007ooOol0?goo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol0
1@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0:Goo00<0
07ooOol0Hgoo00<007ooOol0:Woo00<007ooOol0?Woo00D007ooOomoo`0000Eoo`8000Uoo`03001o
ogoo009oo`03001oogoo0?1oo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo
00aoo`03001oogoo02Qoo`03001oogoo06Eoo`03001oogoo02Qoo`03001oogoo03moo`05001oogoo
Ool0000@Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool00`00Oomo
o`02Ool2000>Ool00`00Oomoo`0WOol00`00Oomoo`1VOol00`00Oomoo`0WOol00`00Oomoo`0oOol0
1@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomoogoo000037oo10001Goo
00<007ooOol03Woo00<007ooOol09Woo00<007ooOol0IWoo00<007ooOol09Woo00<007ooOol0@7oo
00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`03001oogoo00ioo`03001oogoo02Eoo`03001oogoo06Qoo`03001oogoo02Eoo`03001o
ogoo041oo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001oogoo
Ool0000<Ool00`00Oomoo`06Ool2000@Ool00`00Oomoo`0TOol00`00Oomoo`1XOol00`00Oomoo`0T
Ool00`00Oomoo`11Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P00lGoo000OOol3000=Ool4
0005Ool00`00Oomoo`0?Ool00`00Oomoo`0SOol00`00Oomoo`1ZOol00`00Oomoo`0SOol00`00Oomo
o`12Ool3000=Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo011oo`03001oogoo029oo`03
001oogoo06]oo`03001oogoo025oo`03001oogoo05aoo`03001oogoo0?1oo`00>7oo00<007ooOol0
47oo00<007ooOol08Goo00<007ooOol0K7oo00<007ooOol08Goo00<007ooOol0G7oo00<007ooOol0
l7oo000hOol2000BOol00`00Oomoo`0OOol00`00Oomoo`1^Ool00`00Oomoo`0OOol00`00Oomoo`1M
Ool2003aOol003Qoo`03001oogoo015oo`03001oogoo01moo`03001oogoo06ioo`03001oogoo01io
o`03001oogoo05ioo`03001oogoo0?1oo`00>7oo00<007ooOol04Woo00<007ooOol07Goo00<007oo
Ool0L7oo00<007ooOol07Goo00<007ooOol0GWoo00<007ooOol0l7oo000hOol2000COol00`00Oomo
o`0MOol00`00Oomoo`1aOol00`00Oomoo`0KOol00`00Oomoo`1OOol2003aOol003Qoo`03001oogoo
01=oo`03001oogoo01]oo`03001oogoo079oo`03001oogoo01]oo`03001oogoo05moo`03001oogoo
0?1oo`00>7oo00<007ooOol04goo00<007ooOol06Woo00<007ooOol0M7oo00<007ooOol06Goo00<0
07ooOol0H7oo00<007ooOol0l7oo000hOol00`00Oomoo`0DOol00`00Oomoo`0HOol00`00Oomoo`1f
Ool00`00Oomoo`0GOol00`00Oomoo`1QOol00`00Oomoo`3`Ool003Qoo`8001Ioo`03001oogoo01Io
o`03001oogoo07Qoo`03001oogoo01Ioo`03001oogoo065oo`800?5oo`005goo0`001Woo0P001Woo
00<007ooOol017oo10001Goo00<007ooOol05Woo00<007ooOol057oo00<007ooOol0NWoo00<007oo
Ool057oo00<007ooOol0@Goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0l7oo
000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0
5goo00<007ooOol04Woo00<007ooOol0O7oo00<007ooOol04Woo00<007ooOol0@Goo00D007ooOomo
o`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`005Woo00D007oo
Oomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo01Qoo`03001oogoo011oo`03
001oogoo07ioo`03001oogoo011oo`03001oogoo049oo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool2000JOol00`00Oomoo`0>Ool00`00Oomoo`20Ool00`00Oomoo`0=Ool20015Ool0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00lGoo000FOol01@00Oomoogoo
00003Woo00<007ooOol00goo10001Goo00<007ooOol06Woo00<007ooOol02goo0P00Q7oo00<007oo
Ool02goo00<007ooOol0AGoo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo
0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01]o
o`<000Uoo`03001oogoo08Eoo`03001oogoo00Qoo`8004Qoo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo
000017oo00<007ooOol01Woo0P007goo0P0017oo0`00RGoo10000goo0`00BWoo00D007ooOomoo`00
00]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eo
o`03001oogoo021oo`D008ioo`@004ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000_Ool50004Ool00`00Oomoo`3o
OolNOol50004Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001o
ogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00
lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001o
ogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<0
0004Ool00000000HOol3003oOol7Ool3000017oo000000006Goo0`00M7oo002FOol01@00Oomoogoo
00002Goo1P002Goo00D007ooOomoo`000?moo`Moo`05001oogooOol00009Ool6000<Ool00`00Oomo
o`1cOol009Ioo`05001oogooOol0000LOol00`00Oomoo`3oOol5Ool01@00Oomoogoo000067oo1@00
M7oo002FOol01@00Oomoogoo00002Goo1P003Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Uo
o`H000Uoo`04001oogoo001eOol009Ioo`05001oogooOol0000JOol2003oOol8Ool01@00Oomoogoo
00006Goo00<007oo0000MGoo002EOol5000MOol00`00Oomoo`3oOol4Ool5000JOol00`00Ool0001e
Ool00;=oo`05001oogooOol0003oOolVOol2001eOol00;Aoo`<00?moobQoo`03001oogoo07=oo`00
ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
000_Ool5003oOolUOol5003gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`009Woo1P00
1Goo00<007ooOol0ogoo77oo1P001Goo00<007ooOol0mgoo000aOol00`00Oomoo`04Ool2003oOolQ
Ool00`00Oomoo`04Ool2003aOol0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo
00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo
00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol002mo
o`<000Ioo`03001oogoo0?mooaioo`<000Ioo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo
00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`80
0?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo
035oo`L00;Qoo`00>7oo0P00ogoo:7oo0P00;Goo1P001Woo0`00]Goo000GOol30006Ool20006Ool0
0`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomoo`04Ool40005
Ool00`00Oomoo`0ZOol2000?Ool4002aOol001Ioo`05001oogooOol00005Ool20006Ool00`00Oomo
o`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Woo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol0:7oo0P005Goo0P00[goo000>Ool60002Ool01@00Oomo
ogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0o7oo1P000Woo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo02Moo`03001oogoo01Moo`03001o
ogoo0:aoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Io
o`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000VOol2000KOol2002/Ool0
01Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomo
ogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol08goo0P007goo00<007ooOol0ZGoo000F
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo021o
o`03001oogoo0:Qoo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06
Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`80029o
o`03001oogoo029oo`03001oogoo0:Moo`005goo0`0037oo1@0017oo10001Goo00<007ooOol0ogoo
1Woo0`0037oo1@0017oo10001Goo00<007ooOol08Goo00<007ooOol08goo00<007ooOol0YWoo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`0POol00`00Oomoo`0UOol00`00Oomoo`2UOol003Qoo`03
001oogoo0?moobMoo`03001oogoo01moo`03001oogoo02Moo`03001oogoo0:Aoo`00>7oo0P00ogoo
:7oo0P007goo00<007ooOol0:Goo00<007ooOol0Xgoo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`0MOol00`00Oomoo`0[Ool00`00Oomoo`2ROol003Qoo`03001oogoo0?moobMoo`03001oogoo01ao
o`03001oogoo02eoo`03001oogoo0:5oo`00>7oo0P00ogoo:7oo0P0077oo00<007ooOol0;goo00<0
07ooOol0X7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0JOol00`00Oomoo`0aOol00`00Oomo
o`2OOol003Qoo`03001oogoo0?moobMoo`03001oogoo01Uoo`03001oogoo03=oo`03001oogoo09io
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol06Goo00<007ooOol0<goo00<007ooOol0WWoo000h
Ool2003oOolXOol2000IOol00`00Oomoo`0eOol00`00Oomoo`2MOol001moo`<000Ioo`8000Eoo`@0
00Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo01Moo`03001oogoo03Mo
o`03001oogoo09aoo`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo
0?moo`eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0FOol00`00Oomo
o`0iOol00`00Oomoo`2KOol001Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003o
Ool6Ool60002Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P005Woo00<007ooOol0>Woo00<0
07ooOol0Vgoo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`00011oo`03001oogoo009oo`03001oogoo01Aoo`03001oogoo03aoo`03001oogoo09Yo
o`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool4
0005Ool00`00Oomoo`0DOol00`00Oomoo`0mOol00`00Oomoo`2IOol001ioo`05001oogooOol0000<
Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<0
07ooOol04goo00<007ooOol0?goo00<007ooOol0V7oo000NOol01@00Oomoogoo000037oo00<007oo
Ool01Woo0P00ogoo3Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`8001=oo`03001oogoo041o
o`03001oogoo09Qoo`007goo0`003Goo10001Goo00<007ooOol0ogoo3Woo0`003Goo10001Goo00<0
07ooOol04Goo00<007ooOol0@Woo00<007ooOol0Ugoo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`0@Ool00`00Oomoo`14Ool00`00Oomoo`2FOol003Qoo`03001oogoo0?moobMoo`03001oogoo00mo
o`03001oogoo04Ioo`03001oogoo09Eoo`00>7oo0P00ogoo:7oo0P0047oo00<007ooOol0AWoo00<0
07ooOol0UGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0>Ool00`00Oomoo`18Ool00`00Oomo
o`2DOol003Qoo`03001oogoo0?moobMoo`03001oogoo00eoo`03001oogoo04Yoo`03001oogoo09=o
o`00>7oo0P00ogoo:7oo0P003Woo00<007ooOol0Bgoo00<007ooOol0TWoo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`0<Ool00`00Oomoo`1<Ool00`00Oomoo`2BOol003Qoo`03001oogoo0?moobMo
o`03001oogoo00aoo`03001oogoo04eoo`03001oogoo095oo`00>7oo00<007ooOol0Ggoo6P00[Goo
00<007ooOol02goo00<007ooOol0Cgoo00<007ooOol0T7oo000hOol2001COol=000JOol;002ROol2
000;Ool00`00Oomoo`1@Ool00`00Oomoo`2@Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03
001oogoo04aoo`H0039oo`T007Qoo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Yoo`03
001oogoo055oo`03001oogoo08moo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008
Ool00`00Oomoo`02Ool00`00Oomoo`15Ool70011Ool7001`Ool01@00Oomoogoo00001Goo0P001Goo
00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo05=oo`03001oogoo08io
o`003Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`80045oo`D0
04moo`@006Aoo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000:
Ool00`00Oomoo`1DOol00`00Oomoo`2=Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`0lOol4001HOol5001WOol01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0EGoo00<007ooOol0SGoo000FOol01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0=goo1@00HGoo1@00HWoo00D007oo
Oomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00Moo`03001oogoo05Moo`03001oogoo
08aoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo039o
o`D006]oo`@005ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`1HOol00`00Oomoo`2;Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo
000017oo00<007ooOol01Woo0P00;Woo1@00M7oo1@00FGoo00D007ooOomoo`0000]oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool20007Ool00`00Oomoo`1IOol00`00Oomoo`2;Ool001Moo`<000eo
o`<000Eoo`@000Eoo`03001oogoo02Uoo`@007ioo`@005Ioo`<000eoo`<000Eoo`@000Eoo`03001o
ogoo00Ioo`03001oogoo05Yoo`03001oogoo08Yoo`00>7oo00<007ooOol07goo0`000Woo1P0017oo
1@0067oo0`001Woo0P001Woo0`0067oo0`001Woo0P001Goo0`006Woo0`001Woo2P008Goo1@00BGoo
00<007ooOol01Goo00<007ooOol05goo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`001Goo
00<007ooOol047oo0`001Woo0P001Goo0`006Goo0`001Woo0P001Goo0`008Goo1@0057oo000hOol2
000OOol00`00Oomoo`030004Ool20005Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Mo
o`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool01@00Oomoogoo000067oo00D007ooOomo
o`0000Eoo`8000Aoo`D0029oo`03001oogoo04Uoo`8000Eoo`03001oogoo01Moo`05001oogooOol0
0005Ool20005Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo00Aoo`03
001oogoo00moo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00005goo00D007ooOomoo`00
00Eoo`8000Aoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`<00003
Ool007oo00aoo`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo
00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01000Oomoogoo10007goo00<007ooOol0BGoo
00<007ooOol017oo00<007ooOol05goo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogoo
Ool0000;Ool50006Ool00`00Oomoo`0>Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05
001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0KOol4
0003Ool00`00Oomoo`0<Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol001Qoo`05
001oogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogooOol00003
Ool3000LOol00`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`0HOol01@00Oomoogoo00003Woo
00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo0007Ool00`00Oomoo`0>Ool01@00Oomo
ogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<0
07ooOol057oo000hOol00`00Oomoo`0GOol40003Ool01@00Oomoogoo00003goo00<007ooOol05Goo
00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool4000IOol01@00Oomoogoo
000037oo0`001goo0`006Goo00<007ooOol0BGoo00<007ooOol00Woo00<007ooOol06Goo00D007oo
Oomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool00008Ool00`00Oomoo`0=
Ool01@00Oomoogoo00002goo100067oo00D007ooOomoo`0000aoo`<002=oo`03001oogoo01Aoo`00
>7oo0P004goo1@001goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool0
0`00Ool0000HOol01@00Oomoogoo00002goo00<007ooOol06Woo00D007ooOomoo`0000]oo`05001o
ogooOol00009Ool3000FOol00`00Oomoo`19Ool20003Ool00`00Oomoo`0IOol01@00Oomoogoo0000
3goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0000Uoo`03001oogoo00aoo`05001o
ogooOol0000;Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001o
ogoo01Aoo`00>7oo00<007ooOol03Woo100037oo00D007ooOomoo`0000]oo`05001oogooOol0000G
Ool01@00Oomoogoo00003Goo0P0067oo00D007ooOomoo`0000aoo`03001oogoo01Uoo`05001oogoo
Ool0000;Ool01@00Oomoogoo000037oo0`004goo00<007ooOol0BGoo00D007ooOomoo`0001aoo`05
001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8000Uoo`03001oogoo
00aoo`05001oogooOol0000<Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007ooOomoo`00
029oo`03001oogoo01Aoo`00>7oo00<007ooOol02goo0`004Goo0`003Goo0`006Goo0`003goo00<0
07ooOol05goo0`003Woo0`006Goo0`003Goo0`0047oo10003Goo0`00Bgoo00D007ooOomoo`0001eo
o`<000eoo`<001Uoo`<000moo`03001oogoo00Qoo`03001oogoo00aoo`<000ioo`<001Qoo`<000eo
o`<0025oo`<001Ioo`00>7oo00<007ooOol027oo0`00`7oo1@00EWoo00@007ooOol006Moo`03001o
ogoo08Eoo`00>7oo0P001Woo0`00b7oo1000DWoo0`00JGoo00<007ooOol0Q7oo000hOol00`00Oomo
o`02Ool3003?Ool3001?Ool00`00Ool0001ZOol00`00Oomoo`23Ool003Qoo`03001oo`0000800=Eo
o`<004aoo`8006]oo`03001oogoo08=oo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`19Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`0DOol003Qoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo
02Yoo`03001oogoo02Uoo`03001oogoo04Uoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo
01Aoo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo01Aoo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0KGoo00<007ooOol0J7oo00<007ooOol05Goo000hOol2003oOolX
Ool2001^Ool00`00Oomoo`1WOol00`00Oomoo`0FOol003Qoo`03001oogoo0?moobMoo`03001oogoo
06ioo`03001oogoo06Ioo`03001oogoo01Ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0KWoo
00<007ooOol0IGoo00<007ooOol05goo000hOol2003oOolXOol2001`Ool00`00Oomoo`1TOol00`00
Oomoo`0GOol003Qoo`03001oogoo0?moobMoo`03001oogoo071oo`03001oogoo069oo`03001oogoo
01Qoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0L7oo00<007ooOol0HGoo00<007ooOol06Goo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1aOol00`00Oomoo`1POol00`00Oomoo`0IOol003Qo
o`800?moobQoo`80079oo`03001oogoo05moo`03001oogoo01Yoo`00>7oo00<007ooOol0ogoo9goo
00<007ooOol0LWoo00<007ooOol0GWoo00<007ooOol06Woo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`1cOol00`00Oomoo`1LOol00`00Oomoo`0KOol003Qoo`03001oogoo0?moobMoo`03001oogoo
07=oo`03001oogoo05]oo`03001oogoo01aoo`00>7oo0P00ogoo:7oo0P00MGoo00<007ooOol0FWoo
00<007ooOol077oo000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool30006
Ool20004Ool50004Ool40005Ool00`00Oomoo`1dOol00`00Oomoo`1IOol00`00Oomoo`0MOol001Io
o`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`1e
Ool00`00Oomoo`1HOol00`00Oomoo`0MOol001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool0
0`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo
0P00Mgoo00<007ooOol0EWoo00<007ooOol07Woo000FOol01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo07Moo`03001oogoo05Aoo`03001oogoo01moo`005Woo00D007ooOomo
o`0000moo`03001oogoo009oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00
Oomoo`02Ool40005Ool00`00Oomoo`1gOol00`00Oomoo`1DOol00`00Oomoo`0OOol001Ioo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0N7oo00<007ooOol0DWoo00<007oo
Ool087oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?mo
o`Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00NWoo00<007oo
Ool0D7oo00<007ooOol08Goo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`3oOol6Ool3000=
Ool30005Ool40005Ool00`00Oomoo`1iOol00`00Oomoo`1?Ool00`00Oomoo`0ROol003Qoo`03001o
ogoo0?moobMoo`03001oogoo07Yoo`03001oogoo04ioo`03001oogoo029oo`00>7oo0P00ogoo:7oo
0P00O7oo00<007ooOol0C7oo00<007ooOol08goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1l
Ool00`00Oomoo`1:Ool00`00Oomoo`0TOol003Qoo`03001oogoo0?moobMoo`03001oogoo07aoo`03
001oogoo04Yoo`03001oogoo02Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0OGoo00<007oo
Ool0B7oo00<007ooOol09Goo000hOol2003oOolXOol2001oOol00`00Oomoo`16Ool00`00Oomoo`0V
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo07ioo`03001oogoo04Ioo`03001oogoo02Ioo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0Ogoo00<007ooOol0A7oo00<007ooOol09goo000hOol2
003oOolXOol20021Ool00`00Oomoo`12Ool00`00Oomoo`0XOol003Qoo`03001oogoo0?moobMoo`03
001oogoo085oo`03001oogoo041oo`03001oogoo02Uoo`007goo0`001Woo0P001Goo10001Goo00<0
07ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0PGoo00<007ooOol0@7oo00<007oo
Ool0:Goo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo
00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo089oo`03001oogoo03ioo`03
001oogoo02Yoo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`ioo`05001oogoo
Ool0000@Ool00`00Oomoo`02Ool20024Ool00`00Oomoo`0lOol00`00Oomoo`0[Ool001ioo`05001o
ogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007oo
Ool00Woo00<007ooOol0Q7oo00<007ooOol0>Woo00<007ooOol0;7oo000NOol01@00Oomoogoo0000
37oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo08Aoo`03
001oogoo03Uoo`03001oogoo02eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001o
ogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`25Ool00`00Oomoo`0h
Ool00`00Oomoo`0]Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00
Oomoogoo000037oo00<007ooOol01Woo0P00Qgoo00<007ooOol0=Woo00<007ooOol0;Woo000OOol3
000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`27Ool00`00Oomoo`0d
Ool00`00Oomoo`0_Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Moo`03001oogoo03=oo`03
001oogoo031oo`00>7oo0P00ogoo:7oo0P00RGoo00<007ooOol0<Woo00<007ooOol0<7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`29Ool00`00Oomoo`0`Ool00`00Oomoo`0aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo08Yoo`03001oogoo02ioo`03001oogoo039oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0Rgoo0P00;Goo00<007ooOol0<goo000hOol2003oOolXOol2002>Ool00`00
Oomoo`0YOol00`00Oomoo`0dOol003Qoo`03001oogoo0?moobMoo`03001oogoo08ioo`03001oogoo
02Moo`03001oogoo03Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Sgoo00<007ooOol09Goo
00<007ooOol0=Woo000hOol2003oOolXOol2002AOol2000TOol00`00Oomoo`0gOol001Moo`<000Io
o`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo
00Aoo`@000Eoo`03001oogoo099oo`03001oogoo01moo`8003Yoo`005Woo00D007ooOomoo`0000Eo
o`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005
Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`2COol00`00Oomoo`0LOol2000l
Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0U7oo00<007oo
Ool06Woo00<007ooOol0?7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8009Ioo`80
01Qoo`8003moo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?mo
o`Eoo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`2GOol2000DOol20011
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0VGoo0`003Woo
0`00@goo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001o
ogoo0?moo`Eoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007oo
Ool0W7oo0P002Woo0P00AWoo000GOol3000<Ool50004Ool40005Ool2003oOol7Ool3000<Ool50004
Ool40005Ool2002OOol:0018Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo
00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`80
0?5oo`00;goo1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo000aOol00`00Oomo
o`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Ao
o`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00
ogoo8Goo00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035o
o`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo
000_Ool3003oOolWOol3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo00000000
67oo1@00ogoo1Goo0`0000Aoo`00000001Moo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000ao
o`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000:Ool01000Oomoo`00M7oo002FOol01@00
Oomoogoo00006goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001Yoo`03001oogoo07Aoo`00UWoo
00D007ooOomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000<Ool0
0`00Oomoo`1cOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo0000
77oo00<007ooOol0LWoo002EOol5000LOol00`00Oomoo`3oOol5Ool5000MOol00`00Oomoo`1bOol0
0;Ioo`03001oogoo0?moob=oo`05001oogooOol0001dOol00;Aoo`<00?moobIoo`<007Eoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .42289 L
.08255 .47662 L
.10458 .52781 L
.12507 .56618 L
.14415 .59247 L
.14918 .59775 L
.15465 .60268 L
.15946 .60631 L
.16457 .60942 L
.16917 .61156 L
.17178 .6125 L
.17423 .6132 L
.17538 .61346 L
.17647 .61368 L
.17746 .61384 L
.17852 .61399 L
.17967 .61411 L
.18073 .61418 L
.182 .61423 L
.18314 .61422 L
.18435 .61418 L
.18547 .6141 L
.1867 .61397 L
.18802 .61378 L
.19071 .61323 L
.19317 .61254 L
.1979 .61071 L
.20239 .60836 L
.21236 .60103 L
.22321 .58984 L
.24299 .56123 L
.26399 .52033 L
.30174 .42538 L
.34195 .30697 L
.38063 .1931 L
.40028 .14074 L
.42177 .09078 L
.44253 .05184 L
.4614 .0258 L
.47149 .01588 L
.47611 .01229 L
.48101 .00918 L
.4835 .00786 L
.48624 .00663 L
.48876 .00569 L
.49106 .005 L
.49378 .00438 L
.49527 .00414 L
.49596 .00405 L
Mistroke
.49669 .00397 L
.498 .00386 L
.49921 .00381 L
.49996 .0038 L
.50065 .00381 L
.50196 .00386 L
.50313 .00395 L
.50438 .00409 L
.50556 .00427 L
.50663 .00446 L
.50926 .00509 L
.51175 .00587 L
.5167 .00796 L
.52208 .01106 L
.53169 .01869 L
.54056 .02807 L
.55926 .05481 L
.57988 .0943 L
.62014 .19526 L
.65888 .30946 L
.70007 .43042 L
.72063 .48452 L
.73974 .52833 L
.75939 .5652 L
.77791 .59114 L
.78775 .60113 L
.79293 .60528 L
.7984 .60882 L
.80302 .61112 L
.80546 .61208 L
.80809 .61292 L
.8105 .6135 L
.8127 .61389 L
.81375 .61402 L
.81491 .61413 L
.81599 .6142 L
.817 .61423 L
.81818 .61422 L
.81941 .61417 L
.82047 .61409 L
.82163 .61397 L
.82287 .61379 L
.82421 .61355 L
.82661 .61298 L
.82905 .61223 L
.83134 .61135 L
.83564 .6093 L
.84078 .60614 L
.84552 .60254 L
.85624 .59203 L
Mistroke
.87498 .56611 L
.89561 .52742 L
.93591 .42747 L
.97471 .3135 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .26242 L
.08255 .24219 L
.0932 .2333 L
.10458 .22545 L
.11009 .22231 L
.11531 .21977 L
.12038 .21769 L
.12507 .21614 L
.12951 .215 L
.13178 .21454 L
.13422 .21415 L
.13549 .21398 L
.13666 .21384 L
.13784 .21373 L
.13895 .21365 L
.14022 .21358 L
.1409 .21356 L
.14161 .21354 L
.1423 .21353 L
.14295 .21353 L
.14415 .21354 L
.14531 .21358 L
.14656 .21364 L
.14773 .21372 L
.14881 .21382 L
.15143 .21414 L
.15392 .21454 L
.15886 .21565 L
.16423 .2173 L
.17383 .22139 L
.1827 .22642 L
.20137 .2406 L
.22197 .261 L
.26217 .30935 L
.30086 .35597 L
.32051 .37571 L
.3309 .38443 L
.342 .39217 L
.35275 .39797 L
.35784 .4001 L
.36253 .4017 L
.36724 .40295 L
.36972 .40346 L
.37235 .40389 L
.37463 .40418 L
.37573 .40428 L
.37677 .40436 L
.37799 .40444 L
.37911 .40448 L
Mistroke
.38031 .40451 L
.38162 .4045 L
.38227 .40449 L
.38296 .40448 L
.38419 .40442 L
.38551 .40434 L
.38695 .40421 L
.38955 .40389 L
.39197 .4035 L
.39649 .40251 L
.40134 .40108 L
.40698 .39893 L
.41232 .39645 L
.42232 .39063 L
.44227 .37492 L
.4607 .35634 L
.50002 .30899 L
.53782 .26331 L
.55884 .24211 L
.56803 .23435 L
.57808 .22714 L
.58722 .22183 L
.59696 .21755 L
.60236 .21583 L
.60726 .21468 L
.60962 .21426 L
.61086 .21408 L
.61218 .21392 L
.61333 .2138 L
.61459 .21369 L
.61574 .21362 L
.61682 .21357 L
.61808 .21353 L
.61871 .21353 L
.61941 .21353 L
.62065 .21355 L
.62181 .21359 L
.62248 .21362 L
.62318 .21367 L
.62443 .21377 L
.62578 .2139 L
.62725 .21408 L
.62973 .21447 L
.63238 .215 L
.63715 .21624 L
.64214 .21792 L
.64686 .21988 L
.6557 .22447 L
.67568 .23897 L
.69413 .25668 L
Mistroke
.7335 .30323 L
.77136 .34959 L
.79241 .37174 L
.81166 .38782 L
.82118 .39396 L
.8262 .39666 L
.83155 .39912 L
.8367 .40105 L
.84136 .40244 L
.84361 .40299 L
.84604 .40349 L
.84835 .40387 L
.85045 .40414 L
.85159 .40425 L
.85283 .40435 L
.85414 .40443 L
.85538 .40448 L
.85653 .40451 L
.85776 .40451 L
.85881 .40449 L
.85997 .40444 L
.86063 .40441 L
.86132 .40436 L
.86256 .40426 L
.86535 .40395 L
.86777 .40357 L
.87041 .40305 L
.87569 .40166 L
.88133 .39969 L
.89148 .39488 L
.90173 .38845 L
.91284 .37986 L
.933 .36054 L
.97393 .31186 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .29119 L
.10458 .27208 L
.14415 .25478 L
.18221 .239 L
.22272 .22343 L
.26171 .20988 L
.30316 .19728 L
.34309 .1871 L
.3815 .17931 L
.40095 .17615 L
.42237 .1733 L
.44268 .17123 L
.45178 .1705 L
.46172 .16984 L
.4671 .16955 L
.4721 .16932 L
.47727 .16912 L
.48196 .16897 L
.48658 .16886 L
.4887 .16882 L
.49093 .16879 L
.49332 .16876 L
.49438 .16875 L
.49552 .16874 L
.49675 .16873 L
.49789 .16873 L
.49859 .16873 L
.49925 .16873 L
.50049 .16873 L
.50163 .16873 L
.50286 .16873 L
.50401 .16874 L
.50508 .16875 L
.50754 .16877 L
.51014 .1688 L
.51268 .16885 L
.51504 .1689 L
.5204 .16904 L
.5293 .16938 L
.53882 .16987 L
.54906 .17056 L
.56016 .17148 L
.58032 .17362 L
.62123 .1798 L
.66064 .18797 L
.69852 .19775 L
.73886 .21007 L
.77769 .22358 L
.81897 .23948 L
Mistroke
.85873 .25601 L
.89697 .27277 L
.93767 .29124 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .26322 L
.10458 .21674 L
.14415 .17949 L
.18221 .15192 L
.20178 .14148 L
.21267 .13688 L
.22272 .13342 L
.23293 .13069 L
.23832 .12958 L
.24402 .12864 L
.24641 .12833 L
.24897 .12804 L
.25119 .12784 L
.25361 .12765 L
.25507 .12757 L
.25643 .1275 L
.25773 .12745 L
.2584 .12743 L
.25912 .12741 L
.25983 .1274 L
.26048 .12739 L
.26176 .12738 L
.26293 .12739 L
.26416 .1274 L
.26538 .12743 L
.26607 .12745 L
.26671 .12747 L
.26912 .12759 L
.27131 .12773 L
.27364 .12793 L
.27847 .12846 L
.2838 .12927 L
.29326 .13125 L
.30213 .13374 L
.32232 .14162 L
.34082 .15145 L
.38045 .18015 L
.41855 .21605 L
.45912 .26062 L
.49816 .30681 L
.53966 .356 L
.57964 .40012 L
.61811 .43665 L
.63759 .45217 L
.65902 .46649 L
.67938 .4772 L
.69843 .48447 L
.70884 .48728 L
.71396 .48836 L
Mistroke
.71872 .48917 L
.72301 .48975 L
.72758 .49022 L
.7302 .49041 L
.73148 .49048 L
.73266 .49054 L
.73371 .49058 L
.73487 .49061 L
.73603 .49064 L
.73725 .49065 L
.73856 .49065 L
.73977 .49064 L
.7404 .49063 L
.7411 .49062 L
.74251 .49058 L
.74375 .49053 L
.74508 .49046 L
.74748 .4903 L
.74985 .49011 L
.75235 .48985 L
.7568 .48927 L
.76198 .4884 L
.7668 .4874 L
.77773 .48448 L
.78828 .48079 L
.79823 .47655 L
.81683 .4667 L
.85534 .43897 L
.89632 .40036 L
.93577 .35688 L
.97371 .31199 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0JGoo1@00/Goo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04
Ool00`00Oomoo`1WOol30004Ool2002_Ool00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001o
ogoo00Aoo`03001oogoo06Ioo`03001oogoo00Moo`800:eoo`03001oogoo00Aoo`03001oogoo0?1o
o`00<Goo00<007ooOol017oo0P00IGoo0P0037oo00<007ooOol0ZWoo00<007ooOol017oo0P00lGoo
000_Ool30006Ool00`00Oomoo`1SOol00`00Oomoo`0=Ool00`00Oomoo`2WOol30006Ool00`00Oomo
o`3`Ool003Qoo`03001oogoo069oo`03001oogoo00moo`03001oogoo0:moo`03001oogoo0?1oo`00
>7oo0P00Hgoo00<007ooOol047oo00<007ooOol0[Woo0P00lGoo000hOol00`00Oomoo`1QOol00`00
Oomoo`0AOol00`00Oomoo`2^Ool00`00Oomoo`3`Ool003Qoo`03001oogoo061oo`03001oogoo01=o
o`03001oogoo0:eoo`03001oogoo0?1oo`00>7oo00<007ooOol0H7oo00<007ooOol057oo00<007oo
Ool0[7oo00<007ooOol0l7oo000hOol2001POol00`00Oomoo`0EOol00`00Oomoo`2/Ool2003aOol0
03Qoo`03001oogoo05ioo`03001oogoo01Moo`03001oogoo0:]oo`03001oogoo0?1oo`00>7oo00<0
07ooOol0GWoo00<007ooOol067oo00<007ooOol0ZWoo00<007ooOol0l7oo000hOol00`00Oomoo`1M
Ool00`00Oomoo`0IOol00`00Oomoo`2ZOol00`00Oomoo`3`Ool003Qoo`8005ioo`03001oogoo01Yo
o`03001oogoo0:Uoo`800?5oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool0G7oo00<007ooOol06goo00<007ooOol0R7oo0`001Woo0P001Woo00<007ooOol017oo10001Goo
00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol0Fgoo00<007ooOol07Goo00<007ooOol0QWoo00D007ooOomoo`0000Eoo`8000Io
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`00
00ioo`03001oogoo00Moo`03001oogoo009oo`8005aoo`03001oogoo01ioo`03001oogoo07eoo`H0
009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`1JOol00`00Oomoo`0OOol0
0`00Oomoo`25Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0FWoo00<007oo
Ool087oo00<007ooOol0Q7oo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo
0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo05Uo
o`03001oogoo025oo`03001oogoo08Aoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P00FWoo00<007ooOol08Woo00<007ooOol0Pgoo00D007ooOomoo`0000]oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo05Qo
o`03001oogoo02=oo`03001oogoo08Aoo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo
00<007ooOol0F7oo00<007ooOol097oo00<007ooOol0Y7oo00<007ooOol0l7oo000hOol2001IOol0
0`00Oomoo`0TOol00`00Oomoo`2TOol2003aOol003Qoo`03001oogoo05Moo`03001oogoo02Eoo`03
001oogoo0:Aoo`03001oogoo0?1oo`00>7oo00<007ooOol0Egoo00<007ooOol09Woo00<007ooOol0
Xgoo00<007ooOol0l7oo000hOol00`00Oomoo`1FOol00`00Oomoo`0WOol00`00Oomoo`2SOol00`00
Oomoo`3`Ool003Qoo`8005Moo`03001oogoo02Qoo`03001oogoo0:9oo`800?5oo`00>7oo00<007oo
Ool0EGoo00<007ooOol0:Goo00<007ooOol0XWoo00<007ooOol0l7oo000hOol00`00Oomoo`1EOol0
0`00Oomoo`0YOol00`00Oomoo`2ROol00`00Oomoo`3`Ool003Qoo`8005Ioo`03001oogoo02Yoo`03
001oogoo0:5oo`800?5oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0E7oo00<007ooOol0
:goo00<007ooOol0R7oo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo
00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol0;7oo00<007ooOol0QWoo
00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`005Woo1P000Woo00D0
07ooOomoo`00011oo`03001oogoo009oo`03001oogoo05=oo`03001oogoo02eoo`03001oogoo07io
o`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001ioo`05001oogoo
Ool0000@Ool00`00Oomoo`02Ool2001DOol00`00Oomoo`0]Ool00`00Oomoo`26Ool01@00Oomoogoo
000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0
Dgoo00<007ooOol0;Woo00<007ooOol0QGoo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1o
o`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo059oo`03001oogoo02moo`03
001oogoo08Eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1BOol00`00Oomoo`0_Ool00`00Oomoo`25Ool0
1@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0l7oo000OOol3000=Ool40005Ool2001C
Ool00`00Oomoo`0`Ool00`00Oomoo`25Ool3000=Ool40005Ool2003aOol003Qoo`03001oogoo055o
o`03001oogoo035oo`03001oogoo09ioo`03001oogoo0?1oo`00>7oo00<007ooOol0DGoo00<007oo
Ool0<Woo00<007ooOol0WGoo00<007ooOol0l7oo000hOol2001BOol00`00Oomoo`0bOol00`00Oomo
o`2MOol2003aOol003Qoo`03001oogoo051oo`03001oogoo03=oo`03001oogoo09eoo`03001oogoo
0?1oo`00>7oo00<007ooOol0D7oo00<007ooOol0=7oo00<007ooOol0W7oo00<007ooOol0l7oo000h
Ool00`00Oomoo`1@Ool00`00Oomoo`0dOol00`00Oomoo`2LOol00`00Oomoo`3`Ool003Qoo`80051o
o`03001oogoo03Ioo`03001oogoo09]oo`800?5oo`00>7oo00<007ooOol0Cgoo00<007ooOol0=Woo
00<007ooOol0Vgoo00<007ooOol0l7oo000hOol00`00Oomoo`1?Ool00`00Oomoo`0fOol00`00Oomo
o`2KOol00`00Oomoo`3`Ool003Qoo`8004moo`03001oogoo03Qoo`03001oogoo09Yoo`8001Eoo`T0
06Ioo`T006Aoo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0CWoo00<007ooOol0
>7oo00<007ooOol0NGoo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol04Woo0P002Goo1000
H7oo0P002Goo0`00HGoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001o
ogoo009oo`03001oogoo04ioo`03001oogoo03Qoo`03001oogoo07Qoo`05001oogooOol00005Ool2
0005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol03goo0`003goo00<007ooOol0FWoo
0`003Woo0P00Ggoo000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol0CGoo00<007ooOol0>Woo00<007ooOol0Kgoo1P000Woo00D007ooOomoo`0000eo
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo015oo`8005Qoo`8001=o
o`03001oogoo05aoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80
04ioo`03001oogoo03Yoo`03001oogoo07Moo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool2000=Ool2000FOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`1KOol001Io
o`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol0
0`00Oomoo`1gOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol02goo00<0
07ooOol05goo00<007ooOol0DWoo00<007ooOol05Woo00<007ooOol0FWoo000FOol01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0C7oo00<007ooOol0?7oo00<007oo
Ool0MWoo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Yoo`03
001oogoo01Uoo`03001oogoo051oo`03001oogoo01Qoo`03001oogoo05Uoo`005Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001=Ool00`00Oomoo`0lOol00`00Oomo
o`1fOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000]oo`03001o
ogoo01Yoo`03001oogoo04ioo`03001oogoo01Yoo`03001oogoo05Qoo`005goo0`003Goo0`001Goo
10001Goo00<007ooOol0C7oo00<007ooOol0?7oo00<007ooOol0Mgoo0`003Goo0`001Goo10001Goo
00<007ooOol02Goo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol0Egoo
000hOol00`00Oomoo`1;Ool00`00Oomoo`0nOol00`00Oomoo`2GOol00`00Oomoo`08Ool00`00Oomo
o`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`1FOol003Qoo`03001oogoo01moo`<0
00Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<0009oo`03001oogoo
01Eoo`<000Ioo`8000Eoo`<0025oo`D004Uoo`03001oogoo00Moo`03001oogoo01Eoo`<000Ioo`<0
00=oo`D001Qoo`<000Ioo`8000Ioo`<001Ioo`03001oo`00008000Ioo`8000Eoo`<000ioo`03001o
ogoo00Qoo`<000Ioo`8000Eoo`<0025oo`D001Aoo`00>7oo0P007goo00D007ooOomoo`0000Eoo`80
00Eoo`04001oogoo000GOol20002Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`0FOol01@00Oomo
ogoo00001Goo0P0017oo00L007ooOomoo`00Ool0000FOol01@00Oomoogoo00001Goo0P0017oo00D0
07ooOomoo`00029oo`03001oogoo04Uoo`8000Moo`03001oogoo01Eoo`05001oogooOol00005Ool2
00000goo001oo`02Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo01Ao
o`03001oo`0000=oo`03001oogoo00=oo`8000Aoo`05001oogooOol0000=Ool00`00Oomoo`07Ool0
1@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007oo
Ool07Woo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol01@00
Oomoogoo00002goo00D007ooOomoo`00009oo`03001oogoo01=oo`05001oogooOol0000;Ool01@00
Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol01Woo00<007ooOol05Goo00D007ooOomoo`00
00Qoo`03001oogoo009oo`03001oogoo01Moo`05001oogooOol0000;Ool5000EOol00`00Ool00003
Ool00`00Oomoo`09Ool01@00Oomoogoo00003Woo00<007ooOol01Woo00D007ooOomoo`0000]oo`05
001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogooOol0000>Ool0
0`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol001Qoo`05001oogooOol0000;Ool01@00
Oomoogoo00000Woo00<007ooOol04goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00
Oomoo`19Ool00`00Oomoo`05Ool00`00Oomoo`0FOol01@00Oomoogoo00002Goo00<007ooOol00Woo
00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000EOol01000Oomoo`000goo00<007oo
Ool02Goo00D007ooOomoo`0000moo`03001oogoo00Eoo`05001oogooOol0000;Ool01@00Oomoogoo
00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003goo00<007ooOol0
5Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool40003Ool00`00Oomo
o`0COol01@00Oomoogoo000037oo0`008goo00<007ooOol0BGoo00<007ooOol017oo00<007ooOol0
5goo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo01Eoo`05001oogooOol0000<Ool0
0`00Ool0000DOol01@00Oomoogoo00000goo00<007ooOol02Goo10004Goo00<007ooOol017oo00D0
07ooOomoo`0000aoo`<002=oo`03001oogoo01Aoo`00>7oo0P007goo00D007ooOomoo`0000moo`03
001oogoo01Aoo`8000=oo`03001oogoo00Yoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00
Oomoo`05Ool00`00Oomoo`0BOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo
04Uoo`8000Aoo`03001oogoo01Qoo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007oo
Oomoo`0000aoo`03001oo`0001=oo`03001oogoo009oo`05001oogooOol0000;Ool00`00Oomoo`0C
Ool00`00Oomoo`03Ool01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00
>7oo00<007ooOol07Woo00D007ooOomoo`0000]oo`05001oogooOol0000FOol20003Ool00`00Oomo
o`0;Ool2000HOol01@00Oomoogoo000037oo00<007ooOol017oo00<007ooOol04Woo00D007ooOomo
o`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`02Ool00`00Oomoo`0IOol0
1@00Oomoogoo00002goo0P000Woo00<007ooOol05Goo00D007ooOomoo`0000eoo`80019oo`03001o
ogoo00=oo`05001oogooOol0000<Ool00`00Oomoo`0COol00`00Oomoo`02Ool01@00Oomoogoo0000
2goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07goo0`003Goo0`005goo
00<007oo00000P003goo00<007ooOol05goo0`003Woo0`000goo00<007ooOol04goo0`003Goo0`00
8Goo0`00Bgoo00D007ooOomoo`0001eoo`<000eoo`<001Uoo`<000moo`03001oogoo00moo`03001o
ogoo00Eoo`<000ioo`<001=oo`03001oogoo009oo`<000eoo`<0025oo`<001Ioo`00>7oo0P00BGoo
00<007ooOol0A7oo00<007ooOol0U7oo0P000Woo00<007ooOol0;7oo00<007ooOol0?7oo00<007oo
Ool0;Goo00<007ooOol0CWoo000hOol00`00Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`2DOol0
1000Oomoo`00<7oo00<007ooOol0>Woo00<007ooOol0;goo00<007ooOol0CGoo000hOol00`00Oomo
o`18Ool00`00Oomoo`14Ool00`00Oomoo`2DOol00`00Ool0000bOol00`00Oomoo`0hOol00`00Oomo
o`0aOol00`00Oomoo`1<Ool003Qoo`03001oogoo04Moo`03001oogoo04Ioo`03001oogoo09=oo`80
03Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00<Wooj@00@7ooj@0047oo000h
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`04Ool01@00Oomoogoo00002Woo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00D007ooOomoo`0000Ioo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Moo`8004]oo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`8000Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo01Aoo`00>7oo0P00Agoo00<007ooOol0B7oo00<007ooOol0AGoo00<0
07ooOol0BWoo00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=goo00<007ooOol0<Goo00<0
07ooOol05Goo000hOol20017Ool00`00Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`1;Ool2000g
Ool00`00Oomoo`0`Ool00`00Oomoo`0iOol00`00Oomoo`0_Ool00`00Oomoo`0FOol003Qoo`8004Io
o`03001oogoo04Uoo`03001oogoo04Aoo`03001oogoo04]oo`03001oogoo03Moo`03001oogoo02io
o`03001oogoo03]oo`03001oogoo02eoo`03001oogoo01Moo`00>7oo00<007oo0000AGoo00<007oo
Ool0BWoo00<007ooOol0@goo00<007ooOol0Bgoo00<007ooOol0>7oo00<007ooOol0;7oo00<007oo
Ool0?7oo00<007ooOol0;7oo00<007ooOol067oo000hOol00`00Ool00015Ool00`00Oomoo`1:Ool0
0`00Oomoo`12Ool00`00Oomoo`1<Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0nOol0
0`00Oomoo`0ZOol00`00Oomoo`0IOol003Qoo`<004Aoo`03001oogoo04]oo`03001oogoo049oo`03
001oogoo04aoo`8003Yoo`03001oogoo02Yoo`03001oogoo03moo`03001oogoo02Uoo`03001oogoo
01Uoo`00>7oo00@007ooOol004=oo`03001oogoo04aoo`03001oogoo045oo`03001oogoo04aoo`03
001oogoo03Yoo`03001oogoo02Qoo`03001oogoo045oo`03001oogoo02Moo`03001oogoo01Yoo`00
>7oo00@007ooOol004=oo`03001oogoo04aoo`03001oogoo041oo`03001oogoo04eoo`03001oogoo
03]oo`03001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03001oogoo01]oo`00>7oo00@0
07ooOol0049oo`03001oogoo04eoo`03001oogoo041oo`03001oogoo04eoo`03001oogoo03aoo`03
001oogoo02Aoo`03001oogoo04Eoo`03001oogoo02=oo`03001oogoo01aoo`00>7oo0P000Woo00<0
07ooOol0?goo00<007ooOol0CWoo00<007ooOol0?goo00<007ooOol0CGoo0P00?Woo0P008goo00<0
07ooOol0Agoo00<007ooOol08Goo00<007ooOol07Goo000hOol01@00Oomoogoo0000@Goo00<007oo
Ool0CWoo00<007ooOol0?Woo00<007ooOol0CWoo00<007ooOol0?goo00<007ooOol07goo00<007oo
Ool0BGoo00<007ooOol07goo00<007ooOol07Woo000hOol01@00Oomoogoo0000@7oo00<007ooOol0
Cgoo00<007ooOol0?Woo00<007ooOol0CWoo00<007ooOol0@7oo00<007ooOol07Goo00<007ooOol0
Bgoo00<007ooOol07Goo00<007ooOol07goo000hOol20003Ool00`00Oomoo`0mOol00`00Oomoo`1@
Ool00`00Oomoo`0mOol00`00Oomoo`1>Ool20012Ool00`00Oomoo`0KOol00`00Oomoo`1=Ool00`00
Oomoo`0KOol00`00Oomoo`0POol001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo009o
o`03001oogoo03aoo`03001oogoo055oo`03001oogoo03aoo`03001oogoo02ioo`<000Ioo`8000Ao
o`D000Aoo`@000Eoo`03001oogoo049oo`03001oogoo01Qoo`80055oo`03001oogoo01Uoo`03001o
ogoo025oo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`0lOol00`00Oomoo`1BOol00`00Oomoo`0kOol00`00Oomoo`0]Ool0
1@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo04=oo`03
001oogoo01Ioo`03001oogoo059oo`03001oogoo01Ioo`8002Aoo`005Woo00D007ooOomoo`0000eo
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo03]oo`03001oogoo059o
o`03001oogoo03]oo`03001oogoo02eoo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool00`00Oomoo`14Ool2000EOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`0TOol0
01Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`0j
Ool00`00Oomoo`1COol00`00Oomoo`0jOol00`00Oomoo`0^Ool01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo0P00Agoo00<007ooOol04Goo00<007ooOol0EWoo0`004Woo00<007oo
Ool09Goo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol00goo00<0
07ooOol0>Woo00<007ooOol0E7oo00<007ooOol0>Goo00<007ooOol0;Woo00D007ooOomoo`0000mo
o`03001oogoo009oo`@000Eoo`03001oogoo04Moo`8000moo`8005aoo`03001oogoo00ioo`03001o
ogoo02Ioo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
00Aoo`03001oogoo03Uoo`03001oogoo05Aoo`03001oogoo03Uoo`03001oogoo02ioo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`19Ool00`00Oomoo`0;Ool00`00
Oomoo`1MOol00`00Oomoo`0;Ool2000YOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P001Goo00<007ooOol0>7oo00<007ooOol0EGoo00<007ooOol0>7oo00<0
07ooOol0;goo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001;Ool2
0007Ool4001QOol30007Ool3000[Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo00Aoo`03
001oogoo03Qoo`03001oogoo05Ioo`03001oogoo03Moo`03001oogoo031oo`<000eoo`<000Eoo`@0
00Eoo`03001oogoo04aoo`L006Qoo`L002ioo`00>7oo00<007ooOol01Goo00<007ooOol0=goo00<0
07ooOol0EWoo00<007ooOol0=goo00<007ooOol0DGoo00<007ooOol0l7oo000hOol00`00Oomoo`05
Ool00`00Oomoo`0fOol00`00Oomoo`1GOol00`00Oomoo`0fOol00`00Oomoo`1BOol00`00Oomoo`3`
Ool003Qoo`8000Ioo`03001oogoo03Ioo`03001oogoo05Qoo`03001oogoo03Eoo`03001oogoo059o
o`800?5oo`00>7oo00<007ooOol01Woo00<007ooOol0=Goo00<007ooOol0F7oo00<007ooOol0=Goo
00<007ooOol0DWoo00<007ooOol0l7oo000hOol00`00Oomoo`06Ool00`00Oomoo`0dOol00`00Oomo
o`1IOol00`00Oomoo`0dOol00`00Oomoo`1COol00`00Oomoo`3`Ool003Qoo`8000Qoo`03001oogoo
03=oo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo05=oo`800?5oo`00>7oo00<007ooOol0
1goo00<007ooOol0<Woo00<007ooOol0Fgoo00<007ooOol0<Woo00<007ooOol0E7oo00<007ooOol0
l7oo000hOol00`00Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`1LOol00`00Oomoo`0aOol00`00
Oomoo`1DOol00`00Oomoo`3`Ool003Qoo`03001oogoo00Qoo`03001oogoo035oo`03001oogoo05ao
o`03001oogoo035oo`03001oogoo05Aoo`03001oogoo0?1oo`00>7oo0P002Goo00<007ooOol0<7oo
00<007ooOol0GGoo00<007ooOol0<7oo00<007ooOol0EGoo0P00lGoo000OOol30006Ool20005Ool4
0005Ool00`00Oomoo`09Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool00`00Oomo
o`0lOol30006Ool20005Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol00005Ool20009
Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0^
Ool00`00Oomoo`0lOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0l7oo
000NOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0;Woo00<0
07ooOol0Ggoo00<007ooOol0;Woo00<007ooOol0?7oo00D007ooOomoo`00011oo`03001oogoo009o
o`03001oogoo0?1oo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`8000]oo`03001oogoo
02eoo`03001oogoo061oo`03001oogoo02eoo`03001oogoo03aoo`05001oogooOol0000@Ool00`00
Oomoo`02Ool2003aOol001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`0:Ool00`00Oomo
o`0]Ool00`00Oomoo`1POol00`00Oomoo`0/Ool00`00Oomoo`0mOol01@00Oomoogoo000037oo1000
1Goo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol02Woo
00<007ooOol0;7oo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0?Goo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Io
o`8000aoo`03001oogoo02]oo`03001oogoo069oo`03001oogoo02Yoo`03001oogoo03ioo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool2003aOol001moo`<000eoo`@000Eoo`03001oogoo00]oo`03
001oogoo02Yoo`03001oogoo06=oo`03001oogoo02Yoo`03001oogoo03moo`<000eoo`@000Eoo`03
001oogoo0?1oo`00>7oo00<007ooOol037oo00<007ooOol0:Goo00<007ooOol0Hgoo00<007ooOol0
:Woo00<007ooOol0F7oo00<007ooOol0l7oo000hOol00`00Oomoo`0<Ool00`00Oomoo`0YOol00`00
Oomoo`1TOol00`00Oomoo`0XOol00`00Oomoo`1IOol00`00Oomoo`3`Ool003Qoo`8000eoo`03001o
ogoo02Qoo`03001oogoo06Eoo`03001oogoo02Qoo`03001oogoo05Uoo`800?5oo`00>7oo00<007oo
Ool03Goo00<007ooOol09goo00<007ooOol0IWoo00<007ooOol09goo00<007ooOol0FGoo00<007oo
Ool0l7oo000hOol00`00Oomoo`0=Ool00`00Oomoo`0WOol00`00Oomoo`1VOol00`00Oomoo`0VOol0
0`00Oomoo`1JOol00`00Oomoo`3`Ool003Qoo`8000moo`03001oogoo02Eoo`03001oogoo06Qoo`03
001oogoo02Eoo`03001oogoo05Yoo`800?5oo`00>7oo00<007ooOol03Woo00<007ooOol09Goo00<0
07ooOol0J7oo00<007ooOol097oo00<007ooOol0Fgoo00<007ooOol0l7oo000hOol00`00Oomoo`0?
Ool00`00Oomoo`0TOol00`00Oomoo`1XOol00`00Oomoo`0TOol00`00Oomoo`1KOol00`00Oomoo`3`
Ool003Qoo`03001oogoo00moo`03001oogoo02=oo`03001oogoo06Yoo`03001oogoo02=oo`03001o
ogoo05]oo`03001oogoo0?1oo`00>7oo0P0047oo00<007ooOol08goo00<007ooOol0JWoo00<007oo
Ool08Woo00<007ooOol0G7oo0P00lGoo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool0
0`00Oomoo`0@Ool00`00Oomoo`0QOol00`00Oomoo`1/Ool00`00Oomoo`0QOol00`00Oomoo`0kOol3
0006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol00005
Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`0QOol00`00
Oomoo`1/Ool00`00Oomoo`0POol00`00Oomoo`0kOol01@00Oomoogoo00001Goo0P001Woo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol07goo00<007ooOol0KWoo00<007ooOol0
7goo00<007ooOol0>goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo0?1oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80019oo`03
001oogoo01ioo`03001oogoo06moo`03001oogoo01ioo`03001oogoo03aoo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomo
o`03Ool40005Ool00`00Oomoo`0BOol00`00Oomoo`0MOol00`00Oomoo`1`Ool00`00Oomoo`0LOol0
0`00Oomoo`0mOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0l7oo000F
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol04Woo00<007oo
Ool077oo00<007ooOol0LGoo00<007ooOol077oo00<007ooOol0?Goo00D007ooOomoo`0000moo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000]oo`05001o
ogooOol00004Ool00`00Oomoo`06Ool2000DOol00`00Oomoo`0KOol00`00Oomoo`1bOol00`00Oomo
o`0JOol00`00Oomoo`0nOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Io
o`800?5oo`005goo0`0037oo1@0017oo10001Goo00<007ooOol04goo00<007ooOol06Woo00<007oo
Ool0Lgoo00<007ooOol06Woo00<007ooOol0?goo0`0037oo1@0017oo10001Goo00<007ooOol0l7oo
000hOol00`00Oomoo`0DOol00`00Oomoo`0IOol00`00Oomoo`1dOol00`00Oomoo`0HOol00`00Oomo
o`1QOol00`00Oomoo`3`Ool003Qoo`03001oogoo01Aoo`03001oogoo01Qoo`03001oogoo07Eoo`03
001oogoo01Qoo`03001oogoo065oo`03001oogoo0?1oo`00>7oo0P005Woo00<007ooOol05Woo00<0
07ooOol0Mgoo00<007ooOol05Woo00<007ooOol0HWoo0P00lGoo000hOol00`00Oomoo`0FOol00`00
Oomoo`0DOol00`00Oomoo`1iOol00`00Oomoo`0DOol00`00Oomoo`1SOol00`00Oomoo`3`Ool003Qo
o`03001oogoo01Moo`03001oogoo01=oo`03001oogoo07Yoo`03001oogoo01=oo`03001oogoo06=o
o`03001oogoo0?1oo`00>7oo0P006Goo00<007ooOol04Goo00<007ooOol0O7oo00<007ooOol04Goo
00<007ooOol0I7oo0P00lGoo000hOol00`00Oomoo`0IOol00`00Oomoo`0?Ool00`00Oomoo`1nOol0
0`00Oomoo`0?Ool00`00Oomoo`1UOol00`00Oomoo`3`Ool003Qoo`03001oogoo01Uoo`03001oogoo
00ioo`03001oogoo081oo`03001oogoo00eoo`03001oogoo06Ioo`03001oogoo0?1oo`00>7oo00<0
07ooOol06Woo00<007ooOol02goo0P00Q7oo00<007ooOol02goo00<007ooOol0Igoo00<007ooOol0
l7oo000hOol2000LOol00`00Oomoo`09Ool00`00Oomoo`25Ool00`00Oomoo`09Ool00`00Oomoo`1X
Ool2003aOol002moo`D000Aoo`03001oogoo01aoo`<000Moo`03001oogoo08Moo`8000Moo`80069o
o`D000Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol07goo0`0000Aoo`000000
08aoo`<00004Ool00000001VOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Ao
o`80029oo`80095oo`8006Uoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0ogoo9goo00<0
07ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMo
o`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3003oOolWOol3
003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo0`00ogoo1goo0`00
00Aoo`00000001Uoo`<007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000Uoo`05001oogooOol0003o
Ool7Ool01@00Oomoogoo00002Goo1P0037oo00<007ooOol0Lgoo002FOol01@00Oomoogoo000077oo
00<007ooOol0ogoo1Goo00D007ooOomoo`0001Qoo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H0
00eoo`03001oogoo0?moo`Eoo`05001oogooOol00009Ool60009Ool01000Oomoo`00MGoo002FOol0
1@00Oomoogoo00006Woo0P00ogoo27oo00D007ooOomoo`0001Uoo`03001oo`0007Eoo`00UGoo1@00
7Goo00<007ooOol0ogoo17oo1@006Woo00<007oo0000MGoo002cOol01@00Oomoogoo0000ogoo9Woo
0P00MGoo002dOol3003oOolXOol00`00Oomoo`1cOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00;goo1@00ogoo9Goo1@00mgoo000aOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eoo`03001oogoo0?mooaaoo`H000Eoo`03
001oogoo0?Moo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000aOol0
0`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001o
ogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol0
17oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006
Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003a
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00
5goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo
00<007ooOol017oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<0
07ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000io
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?aoo`H0009oo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P00lGoo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007oo
Ool0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo
00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]o
o`05001oogooOol00004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03
001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
;goo2P00]goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0/Ool3000:Ool4002cOol003Qoo`03
001oogoo0?moobMoo`03001oogoo02Qoo`@0015oo`@00:moo`00>7oo0P00ogoo:7oo0P009Woo0`00
6Goo0`00[7oo000OOol30006Ool20005Ool40005Ool00`00Oomoo`3oOol>Ool30006Ool20005Ool4
0005Ool00`00Oomoo`0SOol2000OOol00`00Oomoo`2YOol001ioo`05001oogooOol00005Ool20009
Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0Woo00<007ooOol08Woo00<007ooOol087oo00<007ooOol0Z7oo000FOol60002Ool01@00Oomoogoo
000047oo00<007ooOol00Woo0P00ogoo1Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009o
o`80025oo`8002Aoo`800:Qoo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo
0?moo`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`0VOol0
0`00Oomoo`2UOol001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3oOol=Ool01@00Oomo
ogoo000037oo10001Goo00<007ooOol07Woo00<007ooOol0:7oo0P00YGoo000NOol01@00Oomoogoo
000037oo00<007ooOol01Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo00Io
o`03001oogoo01aoo`8002eoo`03001oogoo0:9oo`007Woo00D007ooOomoo`0000aoo`03001oogoo
00Ioo`8005eoob4008moo`05001oogooOol0000<Ool00`00Oomoo`06Ool2000LOol00`00Oomoo`0^
Ool2002ROol001moo`<000eoo`@000Eoo`03001oogoo059oo`X0025oo`L008Uoo`<000eoo`@000Eo
o`03001oogoo01Yoo`03001oogoo035oo`03001oogoo09moo`00>7oo00<007ooOol0CWoo1000<Woo
1`00Vgoo00<007ooOol067oo0P00=Goo00<007ooOol0WWoo000hOol00`00Oomoo`19Ool5000mOol5
002FOol00`00Oomoo`0GOol00`00Oomoo`0fOol00`00Oomoo`2MOol003Qoo`8004Ioo`@004Moo`@0
099oo`8001Moo`03001oogoo03Qoo`03001oogoo09aoo`00>7oo00<007ooOol0@7oo1@00Cgoo1000
SWoo00<007ooOol05Goo00<007ooOol0>Woo00<007ooOol0Vgoo000hOol00`00Oomoo`0lOol4001H
Ool4002:Ool00`00Oomoo`0DOol00`00Oomoo`0lOol00`00Oomoo`2JOol003Qoo`8003Yoo`<0061o
o`<008Moo`8001Aoo`03001oogoo03ioo`03001oogoo09Uoo`00>7oo00<007ooOol0=Woo0`00IWoo
0`00Q7oo00<007ooOol04Woo00<007ooOol0@7oo00<007ooOol0V7oo000hOol00`00Oomoo`0cOol3
001/Ool40020Ool00`00Oomoo`0AOol00`00Oomoo`12Ool00`00Oomoo`2GOol003Qoo`03001oogoo
031oo`<007=oo`<007eoo`03001oogoo011oo`03001oogoo04Aoo`03001oogoo09Ioo`00>7oo0P00
;Woo0`00NGoo0`00NWoo0P0047oo00<007ooOol0AWoo00<007ooOol0UGoo000GOol30006Ool20004
Ool50004Ool40005Ool00`00Oomoo`0ZOol3001oOol2001GOol30006Ool20004Ool50004Ool40005
Ool00`00Oomoo`0?Ool00`00Oomoo`17Ool00`00Oomoo`2DOol001Ioo`05001oogooOol00005Ool2
0005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0:7oo0P00Q7oo0P00E7oo00D007oo
Oomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomo
o`19Ool00`00Oomoo`2COol000ioo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool2000VOol30028Ool30019Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo
00<007ooOol00Woo0P003Woo00<007ooOol0Bgoo00<007ooOol0TWoo000FOol01@00Oomoogoo0000
3Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol08goo0P00SWoo0P00Cgoo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00aoo`03001oogoo04eoo`03001o
ogoo095oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo025oo`80
099oo`8004eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`0;Ool00`00
Oomoo`1?Ool00`00Oomoo`2@Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`0OOol2002FOol2001;Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol02Woo00<007ooOol0DGoo00<007ooOol0Sgoo000FOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8001eoo`<009Yoo`<004Qoo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P002goo00<007ooOol0DWoo00<007oo
Ool0SWoo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`0JOol2002POol20017Ool3000=Ool3
0005Ool40005Ool00`00Oomoo`09Ool00`00Oomoo`1DOol00`00Oomoo`2=Ool003Qoo`03001oogoo
01Qoo`8000Eoo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<0
01Yoo`<000Ioo`8000Eoo`<000Moo`8001Qoo`D004Uoo`03001oogoo00Qoo`03001oogoo01Aoo`<0
00Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<0009oo`03001oogoo01=oo`<000Ioo`8000Eoo`<0
01Uoo`<000Ioo`8000Eoo`<0025oo`D001Aoo`00>7oo0P005goo0P001Woo00D007ooOomoo`0000Eo
o`8000Eoo`04001oogoo000GOol01@00Oomoogoo00001Goo0P001goo00<007ooOol05Woo00D007oo
Oomoo`0000Eoo`8000Aoo`05001oogooOol0000HOol01@00Oomoogoo00001Goo0P0017oo00D007oo
Oomoo`0000Qoo`8001Qoo`03001oogoo04Uoo`8000Qoo`03001oogoo01Aoo`05001oogooOol00005
Ool20005Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo009oo`03001o
ogoo015oo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Eo
o`8000Aoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo01=oo`<000Qoo`05
001oogooOol0000=Ool00`00Oomoo`0GOol01@00Oomoogoo00002goo1@005goo00D007ooOomoo`00
00]oo`05001oogooOol0000HOol01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`<001Eoo`03
001oogoo04Uoo`03001oogoo00Ioo`03001oogoo01Eoo`05001oogooOol0000=Ool00`00Oomoo`0G
Ool01@00Oomoogoo00002goo1@000goo00<007ooOol04Goo00D007ooOomoo`0000]oo`05001oogoo
Ool0000GOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<0
07ooOol04Goo0P002goo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool0
1000Oomoo`0067oo00D007ooOomoo`0000]oo`05001oogooOol0000HOol01@00Oomoogoo00002goo
00D007ooOomoo`0000eoo`8001=oo`03001oogoo04Uoo`03001oogoo00Ioo`03001oogoo01Eoo`05
001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol000Eoo`03001o
ogoo011oo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000]oo`05001o
ogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo00moo`8000eoo`05001oogooOol0000?
Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`0000]oo`@0
01Uoo`05001oogooOol0000<Ool3000@Ool2000AOol00`00Oomoo`19Ool00`00Oomoo`05Ool00`00
Oomoo`0FOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`00
00Ioo`03001oogoo00moo`05001oogooOol0000;Ool4000HOol01@00Oomoogoo000037oo0`008goo
00<007ooOol057oo000hOol2000=Ool3000?Ool01@00Oomoogoo00003goo00<007ooOol05Goo00D0
07ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`0JOol01@00Oomo
ogoo00002goo00D007ooOomoo`00015oo`<000ioo`03001oogoo04Uoo`8000Eoo`03001oogoo01Mo
o`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo00001goo00<0
07ooOol03Woo00D007ooOomoo`0000]oo`03001oogoo01Uoo`05001oogooOol0000;Ool01@00Oomo
ogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0:Ool2000BOol01@00Oomoogoo00002goo
00D007ooOomoo`0001Moo`05001oogooOol0000=Ool2000HOol01@00Oomoogoo000037oo00<007oo
Ool06Goo00D007ooOomoo`0000]oo`05001oogooOol0000DOol2000<Ool00`00Oomoo`19Ool00`00
Oomoo`03Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogoo
Ool0000=Ool20008Ool00`00Oomoo`0=Ool01@00Oomoogoo000037oo00<007ooOol067oo00D007oo
Oomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo00Moo`<001Eo
o`<000eoo`<001Uoo`<000moo`03001oogoo01Moo`<000ioo`<001Uoo`<000eoo`<001Moo`<000Mo
o`<004]oo`03001oogoo009oo`03001oogoo01Yoo`<000eoo`<001Uoo`<000moo`03001oogoo00Mo
o`03001oogoo00eoo`<000ioo`<001Qoo`<000eoo`<0025oo`<001Ioo`00>7oo00<007ooOol01Goo
0P00bWoo0P00Dgoo00D007ooOomoo`0006Eoo`03001oogoo08Ioo`00>7oo0P0017oo0P00cWoo0P00
DGoo0P0000=oo`00Ool0IWoo00<007ooOol0QGoo000hOol00`00Oomoo`03003BOol3001>Ool00`00
Ool0001YOol00`00Oomoo`24Ool003Qoo`<00=Qoo`8004aoo`8006]oo`03001oogoo08=oo`00<Woo
j@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0DOol003Qoo`03001oogoo02Uoo`03
001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo02Uoo`03001oogoo04Uoo`03
001oogoo02Uoo`03001oogoo02Uoo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo02Uoo`03
001oogoo02Uoo`03001oogoo01Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0KGoo00<007oo
Ool0J7oo00<007ooOol05Goo000hOol2003oOolXOol2001_Ool00`00Oomoo`1VOol00`00Oomoo`0F
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo06moo`03001oogoo06Aoo`03001oogoo01Moo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0L7oo00<007ooOol0HWoo00<007ooOol067oo000hOol2
003oOolXOol2001aOol00`00Oomoo`1QOol00`00Oomoo`0IOol003Qoo`03001oogoo0?moobMoo`03
001oogoo075oo`03001oogoo05moo`03001oogoo01Yoo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0LWoo00<007ooOol0GGoo00<007ooOol06goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1c
Ool00`00Oomoo`1KOol00`00Oomoo`0LOol003Qoo`800?moobQoo`8007Eoo`03001oogoo05Uoo`03
001oogoo01eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0MGoo00<007ooOol0F7oo00<007oo
Ool07Goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1fOol00`00Oomoo`1FOol00`00Oomoo`0N
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo07Moo`03001oogoo05Aoo`03001oogoo01moo`00
>7oo0P00ogoo:7oo0P00NGoo00<007ooOol0DWoo00<007ooOol087oo000GOol30006Ool20004Ool5
0004Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`1i
Ool00`00Oomoo`1@Ool00`00Oomoo`0QOol001Ioo`05001oogooOol00005Ool20005Ool01000Oomo
o`0027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Eoo`04001o
ogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`1jOol00`00Oomoo`1>Ool00`00Oomoo`0ROol001Io
o`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo0P00O7oo00<007ooOol0C7oo00<007ooOol08goo
000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo07aoo`03001oogoo
04Yoo`03001oogoo02Aoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001o
ogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1mOol00`00
Oomoo`18Ool00`00Oomoo`0UOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol0OWoo00<007ooOol0AGoo0P00:7oo000FOol01@00Oomoogoo00002goo00D007ooOomo
o`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol01Woo0P00P7oo00<007ooOol0@goo00<007ooOol0:7oo000GOol3000=Ool30005Ool4
0005Ool00`00Oomoo`3oOol6Ool3000=Ool30005Ool40005Ool00`00Oomoo`20Ool00`00Oomoo`11
Ool00`00Oomoo`0YOol003Qoo`03001oogoo0?moobMoo`03001oogoo085oo`03001oogoo03moo`03
001oogoo02Yoo`00>7oo0P00ogoo:7oo0P00Pgoo00<007ooOol0?Goo00<007ooOol0:goo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`23Ool00`00Oomoo`0kOol00`00Oomoo`0/Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo08Aoo`03001oogoo03Uoo`03001oogoo02eoo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0QGoo00<007ooOol0=goo00<007ooOol0;Woo000hOol2003oOolXOol20027
Ool00`00Oomoo`0eOol00`00Oomoo`0_Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Moo`80
03=oo`80039oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0RGoo00<007ooOol0;goo00<007oo
Ool0<Woo000hOol2003oOolXOol2002;Ool00`00Oomoo`0]Ool00`00Oomoo`0cOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo08]oo`8002aoo`03001oogoo03Aoo`007goo0`001Woo0P001Goo1000
1Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0SGoo00<007ooOol0:7oo
00<007ooOol0=Goo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0
ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo08ioo`03001oogoo
02Ioo`03001oogoo03Ioo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`ioo`05
001oogooOol0000@Ool00`00Oomoo`02Ool2002@Ool00`00Oomoo`0TOol00`00Oomoo`0gOol001io
o`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000047oo
00<007ooOol00Woo00<007ooOol0T7oo0P008Woo0P00>Woo000NOol01@00Oomoogoo000037oo1000
1Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo099oo`<001aoo`<0
03aoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogoo
Ool0000<Ool00`00Oomoo`06Ool00`00Oomoo`2EOol2000HOol2000oOol001ioo`05001oogooOol0
000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P00V7oo
0P0057oo0P00@Goo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00
Oomoo`2IOol3000>Ool30013Ool003Qoo`03001oogoo0?moobMoo`03001oogoo09aoo`h004Ioo`00
>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2
003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol001Moo`<000Ioo`8000Ioo`03001o
ogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03
001oogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009o
o`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00ogoo1Woo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?5oo`005Woo00D007ooOomo
o`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00
Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001o
ogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo00<007ooOol0l7oo000GOol3000<Ool50004Ool40005Ool2003oOol7Ool3000<Ool50004
Ool40005Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00
;goo1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001o
ogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3
003oOolWOol3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo1@00
ogoo1Goo0`0000Aoo`00000001Moo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001o
ogoo0?moo`Ioo`05001oogooOol00009Ool6000:Ool01000Oomoo`00M7oo002FOol01@00Oomoogoo
00006goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001Yoo`03001oogoo07Aoo`00UWoo00D007oo
Oomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000<Ool00`00Oomo
o`1cOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo000077oo00<0
07ooOol0LWoo002EOol5000LOol00`00Oomoo`3oOol5Ool5000MOol00`00Oomoo`1bOol00;Ioo`03
001oogoo0?moob=oo`05001oogooOol0001dOol00;Aoo`<00?moobIoo`<007Eoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .41866 L
.08255 .47041 L
.10458 .5197 L
.12507 .55664 L
.14415 .58196 L
.14918 .58704 L
.15465 .59178 L
.15946 .59528 L
.16457 .59827 L
.16917 .60034 L
.17178 .60124 L
.17423 .60192 L
.17538 .60217 L
.17647 .60238 L
.17746 .60254 L
.17852 .60268 L
.17967 .60279 L
.18073 .60286 L
.182 .60291 L
.18314 .6029 L
.18435 .60286 L
.18547 .60279 L
.1867 .60266 L
.18802 .60248 L
.19071 .60195 L
.19317 .60129 L
.1979 .59952 L
.20239 .59726 L
.21236 .5902 L
.22321 .57942 L
.24299 .55188 L
.26399 .51249 L
.30174 .42106 L
.34195 .30705 L
.38063 .1974 L
.40028 .14698 L
.42177 .09887 L
.44253 .06138 L
.4614 .03631 L
.47149 .02675 L
.47611 .0233 L
.48101 .0203 L
.4835 .01903 L
.48624 .01785 L
.48876 .01694 L
.49106 .01627 L
.49378 .01568 L
.49527 .01545 L
.49596 .01536 L
Mistroke
.49669 .01528 L
.498 .01518 L
.49921 .01513 L
.49996 .01512 L
.50065 .01513 L
.50196 .01518 L
.50313 .01527 L
.50438 .0154 L
.50556 .01557 L
.50663 .01576 L
.50926 .01636 L
.51175 .01711 L
.5167 .01913 L
.52208 .02211 L
.53169 .02945 L
.54056 .03849 L
.55926 .06424 L
.57988 .10227 L
.62014 .19948 L
.65888 .30944 L
.70007 .42592 L
.72063 .47801 L
.73974 .52019 L
.75939 .5557 L
.77791 .58068 L
.78775 .5903 L
.79293 .59429 L
.7984 .5977 L
.80302 .59991 L
.80546 .60084 L
.80809 .60165 L
.8105 .60221 L
.8127 .60258 L
.81375 .60271 L
.81491 .60282 L
.81599 .60288 L
.817 .60291 L
.81818 .6029 L
.81941 .60285 L
.82047 .60278 L
.82163 .60266 L
.82287 .60249 L
.82421 .60225 L
.82661 .6017 L
.82905 .60098 L
.83134 .60014 L
.83564 .59816 L
.84078 .59512 L
.84552 .59165 L
.85624 .58154 L
Mistroke
.87498 .55658 L
.89561 .51932 L
.93591 .42308 L
.97471 .31333 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .18702 L
.08255 .13407 L
.0932 .1108 L
.10458 .09023 L
.11009 .08202 L
.11531 .07535 L
.12038 .06993 L
.12507 .06587 L
.12951 .06288 L
.13178 .06168 L
.13422 .06064 L
.13549 .0602 L
.13666 .05985 L
.13784 .05956 L
.13895 .05935 L
.14022 .05917 L
.1409 .0591 L
.14161 .05905 L
.1423 .05902 L
.14295 .05902 L
.14415 .05905 L
.14531 .05915 L
.14656 .05932 L
.14773 .05953 L
.14881 .05979 L
.15143 .06061 L
.15392 .06167 L
.15886 .06457 L
.16423 .06889 L
.17383 .0796 L
.1827 .09278 L
.20137 .12989 L
.22197 .18329 L
.26217 .3099 L
.30086 .43193 L
.32051 .48363 L
.3309 .50645 L
.342 .52672 L
.35275 .54191 L
.35784 .54748 L
.36253 .55166 L
.36724 .55494 L
.36972 .55628 L
.37235 .55741 L
.37463 .55815 L
.37573 .55842 L
.37677 .55864 L
.37799 .55883 L
.37911 .55894 L
Mistroke
.38031 .55901 L
.38162 .55901 L
.38227 .55898 L
.38296 .55893 L
.38419 .55879 L
.38551 .55857 L
.38695 .55823 L
.38955 .55741 L
.39197 .55638 L
.39649 .55378 L
.40134 .55003 L
.40698 .54442 L
.41232 .53791 L
.42232 .52269 L
.44227 .48156 L
.4607 .43291 L
.50002 .30895 L
.53782 .18936 L
.55884 .13385 L
.56803 .11355 L
.57808 .09466 L
.58722 .08075 L
.59696 .06956 L
.60236 .06505 L
.60726 .06204 L
.60962 .06095 L
.61086 .06047 L
.61218 .06004 L
.61333 .05973 L
.61459 .05945 L
.61574 .05925 L
.61682 .05913 L
.61808 .05904 L
.61871 .05902 L
.61941 .05902 L
.62065 .05907 L
.62181 .05918 L
.62248 .05927 L
.62318 .05939 L
.62443 .05965 L
.62578 .06 L
.62725 .06048 L
.62973 .0615 L
.63238 .06287 L
.63715 .06611 L
.64214 .07053 L
.64686 .07566 L
.6557 .08768 L
.67568 .12564 L
.69413 .17199 L
Mistroke
.7335 .29387 L
.77136 .41524 L
.79241 .47323 L
.81166 .51534 L
.82118 .53139 L
.8262 .53847 L
.83155 .5449 L
.8367 .54998 L
.84136 .55361 L
.84361 .55504 L
.84604 .55634 L
.84835 .55734 L
.85045 .55804 L
.85159 .55835 L
.85283 .55861 L
.85414 .55882 L
.85538 .55895 L
.85653 .55901 L
.85776 .55901 L
.85881 .55896 L
.85997 .55884 L
.86063 .55875 L
.86132 .55864 L
.86256 .55838 L
.86535 .55755 L
.86777 .55656 L
.87041 .5552 L
.87569 .55157 L
.88133 .5464 L
.89148 .5338 L
.90173 .51699 L
.91284 .49449 L
.933 .44391 L
.97393 .31646 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28593 L
.10458 .26119 L
.14415 .23879 L
.18221 .21837 L
.22272 .19821 L
.26171 .18066 L
.30316 .16435 L
.34309 .15117 L
.3815 .14108 L
.40095 .13699 L
.42237 .1333 L
.44268 .13062 L
.45178 .12967 L
.46172 .12883 L
.4671 .12845 L
.4721 .12815 L
.47727 .12789 L
.48196 .1277 L
.48658 .12756 L
.4887 .12751 L
.49093 .12746 L
.49332 .12743 L
.49438 .12741 L
.49552 .1274 L
.49675 .12739 L
.49789 .12739 L
.49859 .12738 L
.49925 .12738 L
.50049 .12738 L
.50163 .12738 L
.50286 .12739 L
.50401 .1274 L
.50508 .12741 L
.50754 .12744 L
.51014 .12748 L
.51268 .12754 L
.51504 .1276 L
.5204 .12779 L
.5293 .12823 L
.53882 .12887 L
.54906 .12975 L
.56016 .13095 L
.58032 .13372 L
.62123 .14171 L
.66064 .15229 L
.69852 .16496 L
.73886 .18091 L
.77769 .1984 L
.81897 .21898 L
Mistroke
.85873 .24039 L
.89697 .26209 L
.93767 .286 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28494 L
.10458 .26051 L
.14415 .24092 L
.18221 .22642 L
.20178 .22094 L
.21267 .21852 L
.22272 .2167 L
.23293 .21526 L
.23832 .21468 L
.24402 .21419 L
.24641 .21402 L
.24897 .21387 L
.25119 .21376 L
.25361 .21367 L
.25507 .21362 L
.25643 .21359 L
.25773 .21356 L
.2584 .21355 L
.25912 .21354 L
.25983 .21353 L
.26048 .21353 L
.26176 .21353 L
.26293 .21353 L
.26416 .21354 L
.26538 .21355 L
.26607 .21356 L
.26671 .21357 L
.26912 .21363 L
.27131 .21371 L
.27364 .21381 L
.27847 .2141 L
.2838 .21452 L
.29326 .21556 L
.30213 .21687 L
.32232 .22101 L
.34082 .22618 L
.38045 .24127 L
.41855 .26014 L
.45912 .28357 L
.49816 .30786 L
.53966 .33372 L
.57964 .35691 L
.61811 .37612 L
.63759 .38428 L
.65902 .39181 L
.67938 .39743 L
.69843 .40126 L
.70884 .40273 L
.71396 .4033 L
Mistroke
.71872 .40373 L
.72301 .40404 L
.72758 .40428 L
.7302 .40438 L
.73148 .40442 L
.73266 .40445 L
.73371 .40447 L
.73487 .40449 L
.73603 .4045 L
.73725 .40451 L
.73856 .40451 L
.73977 .4045 L
.7404 .4045 L
.7411 .40449 L
.74251 .40447 L
.74375 .40444 L
.74508 .40441 L
.74748 .40433 L
.74985 .40422 L
.75235 .40409 L
.7568 .40378 L
.76198 .40332 L
.7668 .4028 L
.77773 .40126 L
.78828 .39932 L
.79823 .39709 L
.81683 .39191 L
.85534 .37734 L
.89632 .35704 L
.93577 .33418 L
.97371 .31058 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00JGoo1`00
/7oo00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`1WOol00`00Oomoo`05Ool3002[
Ool30006Ool00`00Oomoo`3`Ool003Qoo`03001oogoo06Eoo`8000]oo`03001oogoo0;5oo`03001o
ogoo0?1oo`00>7oo0P00IGoo00<007ooOol037oo00<007ooOol0/7oo0P00lGoo000hOol00`00Oomo
o`1SOol00`00Oomoo`0>Ool00`00Oomoo`2_Ool00`00Oomoo`3`Ool003Qoo`03001oogoo069oo`03
001oogoo011oo`03001oogoo0:ioo`03001oogoo0?1oo`00>7oo00<007ooOol0HWoo00<007ooOol0
47oo00<007ooOol0[Woo00<007ooOol0l7oo000hOol2001ROol00`00Oomoo`0BOol00`00Oomoo`2]
Ool2003aOol003Qoo`03001oogoo061oo`03001oogoo01Aoo`03001oogoo0:aoo`03001oogoo0?1o
o`00>7oo00<007ooOol0Ggoo00<007ooOol05Goo00<007ooOol0[7oo00<007ooOol0l7oo000hOol0
0`00Oomoo`1NOol00`00Oomoo`0GOol00`00Oomoo`2[Ool00`00Oomoo`0FOol6001YOol5001VOol0
03Qoo`8005moo`03001oogoo01Qoo`03001oogoo0:Yoo`8001Eoo`8000Ioo`03001oogoo06Aoo`80
00Eoo`03001oogoo06=oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0
GGoo00<007ooOol06Goo00<007ooOol0RGoo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<0
07ooOol04goo00<007ooOol01goo00<007ooOol0HWoo00<007ooOol01Woo00<007ooOol0HWoo000F
Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0GGoo
00<007ooOol06Woo00<007ooOol0Qgoo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo061oo`03001oogoo00Qoo`03
001oogoo065oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`8005eoo`03001oogoo01]oo`03001oogoo07moo`H0009oo`05001oogooOol0000>Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool2000COol00`00Oomoo`0:Ool00`00Oomoo`1NOol00`00Oomoo`0:Ool0
0`00Oomoo`1POol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`1KOol00`00Oomoo`0MOol00`00Oomoo`26Ool01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol04Goo00<007ooOol037oo00<007ooOol0G7oo00<007ooOol02goo
00<007ooOol0H7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0
Fgoo00<007ooOol07Woo00<007ooOol0QGoo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eo
o`03001oogoo011oo`03001oogoo00eoo`03001oogoo05aoo`03001oogoo00aoo`03001oogoo05mo
o`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo05Yoo`03
001oogoo01moo`03001oogoo08Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`1JOol00`00Oomoo`0>Ool00`00Oomoo`1N
Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00Fgoo00<0
07ooOol087oo00<007ooOol0Q7oo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomo
o`06Ool2000@Ool00`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0?Ool00`00Oomoo`1NOol0
01Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo05Uoo`03001oogoo025oo`03001oogoo08Eoo`<0
00aoo`D000Aoo`@000Eoo`03001oogoo00ioo`03001oogoo015oo`03001oogoo05Qoo`03001oogoo
011oo`03001oogoo05eoo`00>7oo00<007ooOol0FGoo00<007ooOol08Woo00<007ooOol0YGoo00<0
07ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0G7oo000h
Ool2001IOol00`00Oomoo`0SOol00`00Oomoo`2UOol2000?Ool00`00Oomoo`0BOol00`00Oomoo`1F
Ool00`00Oomoo`0BOol00`00Oomoo`1LOol003Qoo`03001oogoo05Qoo`03001oogoo02Aoo`03001o
ogoo0:Aoo`03001oogoo00eoo`03001oogoo01Aoo`03001oogoo05Eoo`03001oogoo01=oo`03001o
ogoo05]oo`00>7oo00<007ooOol0Egoo00<007ooOol09Goo00<007ooOol0Y7oo00<007ooOol03Goo
00<007ooOol057oo00<007ooOol0E7oo00<007ooOol057oo00<007ooOol0Fgoo000hOol00`00Oomo
o`1GOol00`00Oomoo`0UOol00`00Oomoo`2TOol00`00Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomo
o`1COol00`00Oomoo`0EOol00`00Oomoo`1JOol003Qoo`8005Moo`03001oogoo02Moo`03001oogoo
0:=oo`8000aoo`03001oogoo01Moo`03001oogoo059oo`03001oogoo01Moo`03001oogoo05Uoo`00
>7oo00<007ooOol0EWoo00<007ooOol09goo00<007ooOol0Xgoo00<007ooOol02goo00<007ooOol0
67oo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol0FGoo000hOol00`00Oomoo`1FOol00`00
Oomoo`0XOol00`00Oomoo`2ROol00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`1@Ool00`00
Oomoo`0IOol00`00Oomoo`1HOol003Qoo`8005Ioo`03001oogoo02Uoo`03001oogoo0:9oo`8000]o
o`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo05Qoo`007goo0`001Woo
0P001Goo10001Goo00<007ooOol0EGoo00<007ooOol0:Goo00<007ooOol0RGoo0`001Woo0P001Goo
10001Goo00<007ooOol02Woo00<007ooOol06Woo00<007ooOol0CWoo00<007ooOol06Woo00<007oo
Ool0F7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0E7oo00<0
07ooOol0:goo00<007ooOol0Qgoo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001o
ogoo00Uoo`03001oogoo01]oo`03001oogoo04ioo`03001oogoo01]oo`03001oogoo05Moo`005Woo
1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo05Aoo`03001oogoo02]oo`03
001oogoo07moo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00
Oomoo`0LOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`1GOol001ioo`05001oogooOol0
000@Ool00`00Oomoo`02Ool2001DOol00`00Oomoo`0]Ool00`00Oomoo`26Ool01@00Oomoogoo0000
47oo00<007ooOol00Woo0P002Woo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<0
07ooOol0Egoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0Dgoo00<007ooOol0;Goo
00<007ooOol0QWoo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo00Qoo`03001oogoo01ioo`03
001oogoo04]oo`03001oogoo01eoo`03001oogoo05Ioo`007Woo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`03001oogoo05=oo`03001oogoo02ioo`03001oogoo08Eoo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol0
0`00Oomoo`1FOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1BOol00`00
Oomoo`0_Ool00`00Oomoo`25Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol027oo
00<007ooOol07Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000OOol3000=Ool4
0005Ool2001COol00`00Oomoo`0_Ool00`00Oomoo`26Ool3000=Ool40005Ool20008Ool00`00Oomo
o`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`1EOol003Qoo`03001oogoo059oo`03
001oogoo031oo`03001oogoo09ioo`03001oogoo00Moo`03001oogoo021oo`03001oogoo04Qoo`03
001oogoo021oo`03001oogoo05Eoo`00>7oo00<007ooOol0DGoo00<007ooOol0<Goo00<007ooOol0
WWoo00<007ooOol01goo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol087oo00<007ooOol0
EGoo000hOol2001BOol00`00Oomoo`0bOol00`00Oomoo`2MOol20007Ool00`00Oomoo`0ROol00`00
Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`1DOol003Qoo`03001oogoo055oo`03001oogoo039o
o`03001oogoo09eoo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo04Ioo`03001oogoo029o
o`03001oogoo05Aoo`00>7oo00<007ooOol0D7oo00<007ooOol0<goo00<007ooOol0WGoo00<007oo
Ool01Woo00<007ooOol08Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol0E7oo000hOol0
0`00Oomoo`1@Ool00`00Oomoo`0dOol00`00Oomoo`2LOol00`00Oomoo`06Ool00`00Oomoo`0SOol0
0`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`1COol003Qoo`80055oo`03001oogoo03Aoo`03
001oogoo09aoo`8000Ioo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo
05=oo`00>7oo00<007ooOol0Cgoo00<007ooOol0=Woo00<007ooOol0Vgoo00<007ooOol01Goo00<0
07ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol0Dgoo000hOol00`00Oomoo`1?
Ool00`00Oomoo`0fOol00`00Oomoo`2KOol00`00Oomoo`05Ool00`00Oomoo`0UOol00`00Oomoo`13
Ool00`00Oomoo`0UOol00`00Oomoo`1BOol003Qoo`80051oo`03001oogoo03Ioo`03001oogoo09]o
o`8000Eoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo059oo`005goo
0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0CWoo00<007ooOol0>7oo00<007ooOol0NGoo
0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol017oo00<007ooOol09Woo00<007ooOol0@Woo
00<007ooOol09Woo00<007ooOol0DWoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol0
00Qoo`03001oogoo009oo`03001oogoo04ioo`03001oogoo03Qoo`03001oogoo07Qoo`05001oogoo
Ool00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
9goo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol0DGoo000>Ool60002Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0CWoo00<007ooOol0>7oo00<007oo
Ool0L7oo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo055oo`005Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8004ioo`03001oogoo03Yoo`03001o
ogoo07Moo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20004Ool00`00Oomo
o`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`1AOol001Ioo`05001oogooOol0000?
Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00Oomoo`1gOol01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol00goo00<007ooOol0:Goo00<007oo
Ool0?goo00<007ooOol0:Goo00<007ooOol0D7oo000FOol01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol0CGoo00<007ooOol0>Woo00<007ooOol0Mgoo00D007ooOomo
o`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo02Yoo`03001o
ogoo03ioo`03001oogoo02Yoo`03001oogoo051oo`005Woo00D007ooOomoo`0000]oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool2001=Ool00`00Oomoo`0lOol00`00Oomoo`1fOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000=oo`03001oogoo02Yoo`03001oogoo
03ioo`03001oogoo02Yoo`03001oogoo051oo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0
C7oo00<007ooOol0?7oo00<007ooOol0Mgoo0`003Goo0`001Goo10001Goo00<007ooOol00Woo00<0
07ooOol0:goo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol0Cgoo000hOol00`00Oomoo`1;
Ool00`00Oomoo`0mOol00`00Oomoo`2HOol01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007oo
Ool0;7oo00<007ooOol0Cgoo000hOol00`00Oomoo`0OOol30006Ool20004Ool5000HOol30006Ool2
0006Ool3000HOol30006Ool20005Ool30002Ool00`00Oomoo`0EOol30006Ool20005Ool3000QOol5
0019Ool01@00Oomoogoo00007Goo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`0047oo00<0
07ooOol01Goo0`001Woo0P001Goo0`0057oo00<007ooOol00Woo0`001Woo0P001Goo0`008Goo1@00
57oo000hOol2000OOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`80009oo`03001o
ogoo00=oo`8000Moo`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool01`00Oomoogoo001o
o`0001Ioo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo0P00
0Woo00<007ooOol06Woo00D007ooOomoo`0000Eoo`8000Eoo`800003Ool007oo01Ioo`05001oogoo
Ool00005Ool20007Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool01@00Oomoogoo00001Goo0P0017oo
00D007ooOomoo`0001Aoo`04001oogoo0003Ool00`00Oomoo`03Ool20004Ool01@00Oomoogoo0000
8Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol05goo
00D007ooOomoo`0000]oo`D001Moo`05001oogooOol0000;Ool01`00Oomoogoo001oo`0001Ioo`05
001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00@007ooOol001eoo`05001o
ogooOol0000=Ool2000HOol01@00Oomoogoo00002goo1@003goo00<007ooOol01Goo00D007ooOomo
o`0000]oo`05001oogooOol0000DOol01000Oomoo`000goo00<007ooOol02Goo00D007ooOomoo`00
029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo01Io
o`05001oogooOol0000;Ool01000Oomoo`0067oo00D007ooOomoo`0000]oo`05001oogooOol00002
Ool00`00Oomoo`0COol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`04
001oogoo000MOol01@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001o
ogoo000@Ool00`00Oomoo`05Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Aoo`04001oogoo
0003Ool00`00Oomoo`09Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0N
Ool01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05
001oogooOol0000;Ool40003Ool00`00Oomoo`0COol01@00Oomoogoo000037oo0`008goo00<007oo
Ool0BGoo00@007ooOol001eoo`05001oogooOol0000>Ool2000GOol01@00Oomoogoo000037oo00<0
07oo000047oo00<007ooOol01Goo00D007ooOomoo`0000]oo`@001Ioo`03001oo`0000=oo`03001o
ogoo00Yoo`<002=oo`03001oogoo01Aoo`00>7oo0P007goo00D007ooOomoo`0000moo`03001oogoo
01Aoo`8000=oo`03001oogoo00Yoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`04
Ool00`00Oomoo`0COol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`<0
01ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo00003goo
00<007ooOol01Woo00D007ooOomoo`0000]oo`03001oogoo01Moo`03001oo`0000=oo`03001oogoo
00Uoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogooOol0
000;Ool01@00Oomoogoo00005Woo0P000goo00<007ooOol02goo0P0067oo00D007ooOomoo`0000ao
o`03001oogoo00Aoo`03001oogoo019oo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<0
07ooOol0BGoo00<007oo00007Woo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomo
ogoo00003Goo0P003goo00<007ooOol01Woo00D007ooOomoo`0000aoo`03001oogoo01Ioo`03001o
o`0000=oo`03001oogoo00Uoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo
01moo`<000eoo`<001Moo`03001oo`00008000moo`03001oogoo01Moo`<000ioo`<000=oo`03001o
ogoo01=oo`<000eoo`<0025oo`<004]oo`03001oo`0001moo`<000eoo`@001Qoo`<000moo`03001o
ogoo00eoo`03001oogoo00Moo`<000ioo`<001Ioo`03001oo`00008000eoo`<0025oo`<001Ioo`00
>7oo0P00BGoo00<007ooOol0@goo00<007ooOol0UGoo0P00=7oo00<007ooOol0=Woo00<007ooOol0
<Woo00<007ooOol0C7oo000hOol00`00Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`2DOol2000d
Ool00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`1<Ool003Qoo`03001oogoo04Qoo`03001o
ogoo04Aoo`03001oogoo09Aoo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04ao
o`00>7oo00<007ooOol0Agoo00<007ooOol0AGoo00<007ooOol0U7oo00<007ooOol0=7oo00<007oo
Ool0=7oo00<007ooOol0=7oo00<007ooOol0Bgoo000bOooY0010OooY000@Ool003Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Aoo`05001oogooOol0000:Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool01@00Oomoogoo00001Woo00<007ooOol027oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo
0P00Bgoo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol057oo000hOol20017Ool00`00Oomoo`18Ool00`00Oomoo`15Ool00`00Oomo
o`1:Ool00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0eOol00`00Oomoo`0cOol00`00Oomo
o`0DOol003Qoo`8004Moo`03001oogoo04Qoo`03001oogoo04Aoo`03001oogoo04]oo`8003Ioo`03
001oogoo039oo`03001oogoo03Ioo`03001oogoo03=oo`03001oogoo01Aoo`00>7oo0P00AWoo00<0
07ooOol0BGoo00<007ooOol0A7oo00<007ooOol0Bgoo00<007ooOol0=Goo00<007ooOol0<Woo00<0
07ooOol0=Woo00<007ooOol0<Woo00<007ooOol05Goo000hOol00`00Ool00015Ool00`00Oomoo`1:
Ool00`00Oomoo`13Ool00`00Oomoo`1;Ool00`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomoo`0g
Ool00`00Oomoo`0aOol00`00Oomoo`0EOol003Qoo`03001oo`0004Eoo`03001oogoo04Yoo`03001o
ogoo049oo`03001oogoo04aoo`03001oogoo03Ioo`03001oogoo031oo`03001oogoo03Qoo`03001o
ogoo035oo`03001oogoo01Eoo`00>7oo0`00A7oo00<007ooOol0Bgoo00<007ooOol0@Woo00<007oo
Ool0C7oo0P00=goo00<007ooOol0<7oo00<007ooOol0>7oo00<007ooOol0<7oo00<007ooOol05Woo
000hOol01000Oomoo`00@goo00<007ooOol0C7oo00<007ooOol0@Goo00<007ooOol0C7oo00<007oo
Ool0=Woo00<007ooOol0<7oo00<007ooOol0>Goo00<007ooOol0;goo00<007ooOol05Woo000hOol0
1000Oomoo`00@Woo00<007ooOol0CGoo00<007ooOol0@7oo00<007ooOol0CGoo00<007ooOol0=goo
00<007ooOol0;Woo00<007ooOol0>Woo00<007ooOol0;goo00<007ooOol05Woo000hOol01000Oomo
o`00@Woo00<007ooOol0CWoo00<007ooOol0?goo00<007ooOol0CGoo00<007ooOol0=goo00<007oo
Ool0;Woo00<007ooOol0>Woo00<007ooOol0;Woo00<007ooOol05goo000hOol20002Ool00`00Oomo
o`0oOol00`00Oomoo`1>Ool00`00Oomoo`0oOol00`00Oomoo`1=Ool2000hOol00`00Oomoo`0^Ool0
0`00Oomoo`0kOol00`00Oomoo`0]Ool00`00Oomoo`0GOol003Qoo`05001oogooOol00010Ool00`00
Oomoo`1?Ool00`00Oomoo`0nOol00`00Oomoo`1>Ool00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00
Oomoo`0lOol00`00Oomoo`0]Ool00`00Oomoo`0GOol003Qoo`03001oogoo009oo`03001oogoo03eo
o`03001oogoo051oo`03001oogoo03eoo`03001oogoo04ioo`03001oogoo03Qoo`03001oogoo02ao
o`03001oogoo03aoo`03001oogoo02aoo`03001oogoo01Qoo`00>7oo0P000goo00<007ooOol0?Goo
00<007ooOol0D7oo00<007ooOol0?7oo00<007ooOol0Cgoo0P00>Goo00<007ooOol0;7oo00<007oo
Ool0?Goo00<007ooOol0:goo00<007ooOol067oo000GOol30006Ool20004Ool50004Ool40005Ool0
0`00Oomoo`02Ool00`00Oomoo`0lOol00`00Oomoo`1AOol00`00Oomoo`0lOol00`00Oomoo`0^Ool3
0006Ool20004Ool50004Ool40005Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0nOol0
0`00Oomoo`0[Ool00`00Oomoo`0HOol001Ioo`05001oogooOol00005Ool20005Ool01000Oomoo`00
27oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0>goo00<007ooOol0DWoo00<007ooOol0
>goo00<007ooOol0;Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02
Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00Oomoo`0I
Ool001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`0kOol00`00Oomoo`1BOol00`00Oomoo`0jOol00`00Oomoo`0^Ool01@00Oomoogoo0000
3Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0>Goo00<007ooOol0:Woo00<007ooOol0
?goo00<007ooOol0:Goo00<007ooOol06Goo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo0P0017oo00<007ooOol0>Woo00<007ooOol0Dgoo00<007ooOol0>Woo00<007oo
Ool0;Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8003]oo`03001oogoo
02Uoo`03001oogoo03moo`03001oogoo02Uoo`03001oogoo01Uoo`005Woo00D007ooOomoo`0000mo
o`03001oogoo009oo`@000Eoo`03001oogoo00Aoo`03001oogoo03Uoo`03001oogoo05Aoo`03001o
ogoo03Uoo`03001oogoo02ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomo
o`0jOol00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`0JOol001Ioo`05
001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`0h
Ool00`00Oomoo`1EOol00`00Oomoo`0hOol00`00Oomoo`0_Ool01@00Oomoogoo00003goo00<007oo
Ool00Woo00<007ooOol01Woo00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol0@Goo00<007oo
Ool09goo00<007ooOol06Woo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001o
ogoo00Ioo`8000Eoo`03001oogoo03Qoo`03001oogoo05Ioo`03001oogoo03Moo`03001oogoo02mo
o`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00?7oo00<007ooOol0
9goo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol06Woo000GOol3000=Ool30005Ool40005
Ool00`00Oomoo`05Ool00`00Oomoo`0gOol00`00Oomoo`1FOol00`00Oomoo`0gOol00`00Oomoo`0`
Ool3000=Ool30005Ool40005Ool00`00Oomoo`0kOol00`00Oomoo`0VOol00`00Oomoo`12Ool00`00
Oomoo`0VOol00`00Oomoo`0KOol003Qoo`03001oogoo00Eoo`03001oogoo03Ioo`03001oogoo05Mo
o`03001oogoo03Ioo`03001oogoo059oo`03001oogoo03]oo`03001oogoo02Ioo`03001oogoo04=o
o`03001oogoo02Eoo`03001oogoo01]oo`00>7oo00<007ooOol01Goo00<007ooOol0=Woo00<007oo
Ool0F7oo00<007ooOol0=Goo00<007ooOol0DWoo00<007ooOol0?7oo00<007ooOol09Goo00<007oo
Ool0@goo00<007ooOol09Goo00<007ooOol06goo000hOol20007Ool00`00Oomoo`0eOol00`00Oomo
o`1HOol00`00Oomoo`0eOol00`00Oomoo`1BOol2000mOol00`00Oomoo`0TOol00`00Oomoo`14Ool0
0`00Oomoo`0TOol00`00Oomoo`0LOol003Qoo`03001oogoo00Ioo`03001oogoo03Aoo`03001oogoo
05Uoo`03001oogoo03Aoo`03001oogoo05=oo`03001oogoo03aoo`03001oogoo02Aoo`03001oogoo
04Eoo`03001oogoo02=oo`03001oogoo01aoo`00>7oo00<007ooOol01goo00<007ooOol0<goo00<0
07ooOol0FWoo00<007ooOol0<goo00<007ooOol0Dgoo00<007ooOol0?Goo00<007ooOol08goo00<0
07ooOol0AGoo00<007ooOol08goo00<007ooOol077oo000hOol20008Ool00`00Oomoo`0bOol00`00
Oomoo`1KOol00`00Oomoo`0bOol00`00Oomoo`1DOol2000nOol00`00Oomoo`0ROol00`00Oomoo`16
Ool00`00Oomoo`0ROol00`00Oomoo`0MOol003Qoo`03001oogoo00Moo`03001oogoo039oo`03001o
ogoo05aoo`03001oogoo035oo`03001oogoo05Aoo`03001oogoo03eoo`03001oogoo029oo`03001o
ogoo04Moo`03001oogoo025oo`03001oogoo01eoo`00>7oo00<007ooOol027oo00<007ooOol0<Goo
00<007ooOol0G7oo00<007ooOol0<Goo00<007ooOol0E7oo00<007ooOol0?Woo00<007ooOol08Goo
00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol07Goo000hOol00`00Oomoo`08Ool00`00Oomo
o`0`Ool00`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomoo`1EOol00`00Oomoo`0nOol00`00Oomo
o`0POol00`00Oomoo`18Ool00`00Oomoo`0POol00`00Oomoo`0NOol003Qoo`8000Yoo`03001oogoo
02moo`03001oogoo05ioo`03001oogoo02moo`03001oogoo05Eoo`8003moo`03001oogoo021oo`03
001oogoo04Uoo`03001oogoo01moo`03001oogoo01ioo`007goo0`001Woo0P001Goo10001Goo00<0
07ooOol02Goo00<007ooOol0;goo00<007ooOol0GWoo00<007ooOol0;Woo00<007ooOol0?Goo0`00
1Woo0P001Goo10001Goo00<007ooOol0?goo00<007ooOol07goo00<007ooOol0BGoo00<007ooOol0
7Woo00<007ooOol07goo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007oo
Ool02Woo00<007ooOol0;Goo00<007ooOol0Ggoo00<007ooOol0;Woo00<007ooOol0?7oo00D007oo
Oomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo03moo`03001oogoo01ioo`03001oogoo
04Yoo`03001oogoo01ioo`03001oogoo01moo`007Woo00D007ooOomoo`00011oo`03001oogoo009o
o`03001oogoo00Yoo`03001oogoo02eoo`03001oogoo061oo`03001oogoo02eoo`03001oogoo03ao
o`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`10Ool00`00Oomoo`0MOol00`00Oomo
o`1;Ool00`00Oomoo`0MOol00`00Oomoo`0OOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02
Ool2000;Ool00`00Oomoo`0/Ool00`00Oomoo`1QOol00`00Oomoo`0/Ool00`00Oomoo`0mOol01@00
Oomoogoo000047oo00<007ooOol00Woo0P00@Goo00<007ooOol07Goo00<007ooOol0Bgoo00<007oo
Ool077oo00<007ooOol087oo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol02goo00<0
07ooOol0:goo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0?Goo00D007ooOomoo`0000ao
o`@000Eoo`03001oogoo045oo`03001oogoo01]oo`03001oogoo04aoo`03001oogoo01aoo`03001o
ogoo021oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo
02]oo`03001oogoo069oo`03001oogoo02Yoo`03001oogoo03ioo`05001oogooOol0000<Ool00`00
Oomoo`06Ool00`00Oomoo`11Ool00`00Oomoo`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00
Oomoo`0POol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2000=Ool00`00Oomoo`0YOol0
0`00Oomoo`1SOol00`00Oomoo`0ZOol00`00Oomoo`0nOol01@00Oomoogoo000037oo00<007ooOol0
1Woo0P00@Woo00<007ooOol06goo00<007ooOol0CGoo00<007ooOol06Woo00<007ooOol08Goo000O
Ool3000=Ool40005Ool00`00Oomoo`0<Ool00`00Oomoo`0YOol00`00Oomoo`1SOol00`00Oomoo`0Z
Ool00`00Oomoo`0oOol3000=Ool40005Ool00`00Oomoo`12Ool00`00Oomoo`0IOol00`00Oomoo`1?
Ool00`00Oomoo`0IOol00`00Oomoo`0QOol003Qoo`03001oogoo00aoo`03001oogoo02Qoo`03001o
ogoo06Eoo`03001oogoo02Qoo`03001oogoo05Uoo`03001oogoo049oo`03001oogoo01Uoo`03001o
ogoo04moo`03001oogoo01Uoo`03001oogoo025oo`00>7oo00<007ooOol03Goo00<007ooOol09goo
00<007ooOol0IGoo00<007ooOol0:7oo00<007ooOol0FGoo00<007ooOol0@goo00<007ooOol05goo
00<007ooOol0D7oo00<007ooOol067oo00<007ooOol08Woo000hOol2000>Ool00`00Oomoo`0WOol0
0`00Oomoo`1VOol00`00Oomoo`0WOol00`00Oomoo`1IOol20014Ool00`00Oomoo`0GOol00`00Oomo
o`1AOol00`00Oomoo`0GOol00`00Oomoo`0ROol003Qoo`03001oogoo00ioo`03001oogoo02Eoo`03
001oogoo06Moo`03001oogoo02Ioo`03001oogoo05Yoo`03001oogoo04=oo`03001oogoo01Ioo`03
001oogoo059oo`03001oogoo01Moo`03001oogoo029oo`00>7oo00<007ooOol03Woo00<007ooOol0
9Goo00<007ooOol0J7oo00<007ooOol09Goo00<007ooOol0FWoo00<007ooOol0A7oo00<007ooOol0
57oo00<007ooOol0E7oo00<007ooOol05Goo00<007ooOol08goo000hOol2000@Ool00`00Oomoo`0T
Ool00`00Oomoo`1XOol00`00Oomoo`0TOol00`00Oomoo`1KOol20015Ool00`00Oomoo`0DOol00`00
Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`0TOol003Qoo`03001oogoo00moo`03001oogoo02=o
o`03001oogoo06Yoo`03001oogoo02=oo`03001oogoo05]oo`03001oogoo04Aoo`03001oogoo01=o
o`03001oogoo05Eoo`03001oogoo01Aoo`03001oogoo02Aoo`00>7oo00<007ooOol03goo00<007oo
Ool08goo00<007ooOol0JWoo00<007ooOol08goo00<007ooOol0Fgoo00<007ooOol0AGoo00<007oo
Ool04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol09Goo000hOol00`00Oomoo`0@Ool0
0`00Oomoo`0QOol00`00Oomoo`1/Ool00`00Oomoo`0QOol00`00Oomoo`1LOol00`00Oomoo`16Ool0
0`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0AOol00`00Oomoo`0UOol003Qoo`80015oo`03
001oogoo025oo`03001oogoo06aoo`03001oogoo025oo`03001oogoo05aoo`8004Qoo`03001oogoo
00moo`03001oogoo05Uoo`03001oogoo00moo`03001oogoo02Ioo`005goo0`001Woo0P001Woo00<0
07ooOol017oo10001Goo00<007ooOol04Goo00<007ooOol07goo00<007ooOol0KWoo00<007ooOol0
7goo00<007ooOol0?7oo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0Agoo00<0
07ooOol03Woo00<007ooOol0Fgoo00<007ooOol03Woo00<007ooOol09Woo000FOol01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol07Woo
00<007ooOol0Kgoo00<007ooOol07Woo00<007ooOol0?7oo00D007ooOomoo`0000Eoo`8000Ioo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo04Qoo`03001oogoo00eoo`03001oogoo05]oo`03
001oogoo00eoo`03001oogoo02Moo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo019oo`03001oogoo01eoo`03001oogoo071oo`03001oogoo01eoo`03001o
ogoo03aoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`18Ool0
0`00Oomoo`0<Ool00`00Oomoo`1MOol00`00Oomoo`0<Ool00`00Oomoo`0WOol001Ioo`05001oogoo
Ool0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000COol00`00Oomoo`0LOol00`00Oomoo`1a
Ool00`00Oomoo`0LOol00`00Oomoo`0mOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007oo
Ool00Woo0P00BWoo00<007ooOol02Woo00<007ooOol0Ggoo00<007ooOol02Woo00<007ooOol0:7oo
000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol04goo00<007ooOol0
6goo00<007ooOol0LWoo00<007ooOol06goo00<007ooOol0?Goo00D007ooOomoo`0000ioo`03001o
ogoo00=oo`@000Eoo`03001oogoo04Yoo`03001oogoo00Qoo`03001oogoo061oo`03001oogoo00Qo
o`8002]oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
01=oo`03001oogoo01Yoo`03001oogoo07=oo`03001oogoo01Yoo`03001oogoo03ioo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`1;Ool00`00Oomoo`06Ool00`00
Oomoo`1ROol20007Ool00`00Oomoo`0[Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P005Goo00<007ooOol06Goo00<007ooOol0M7oo00<007ooOol067oo00<0
07ooOol0?goo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001=Ool3
0003Ool2001WOol20003Ool2000^Ool001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo01Aoo`03
001oogoo01Qoo`03001oogoo07Eoo`03001oogoo01Qoo`03001oogoo041oo`<000aoo`D000Aoo`@0
00Eoo`03001oogoo04ioo`@006Yoo`@0031oo`00>7oo00<007ooOol05Goo00<007ooOol05Woo00<0
07ooOol0Mgoo00<007ooOol05Woo00<007ooOol0HWoo00<007ooOol0l7oo000hOol00`00Oomoo`0F
Ool00`00Oomoo`0DOol00`00Oomoo`1iOol00`00Oomoo`0DOol00`00Oomoo`1SOol00`00Oomoo`3`
Ool003Qoo`8001Qoo`03001oogoo019oo`03001oogoo07]oo`03001oogoo01=oo`03001oogoo06=o
o`800?5oo`00>7oo00<007ooOol067oo00<007ooOol047oo00<007ooOol0OGoo00<007ooOol04Goo
00<007ooOol0I7oo00<007ooOol0l7oo000hOol00`00Oomoo`0IOol00`00Oomoo`0?Ool00`00Oomo
o`1nOol00`00Oomoo`0>Ool2001WOol00`00Oomoo`3`Ool003Qoo`8001]oo`03001oogoo00eoo`03
001oogoo081oo`03001oogoo00aoo`03001oogoo06Moo`800?5oo`00>7oo00<007ooOol06goo00<0
07ooOol02Woo0P00Q7oo00<007ooOol02Woo00<007ooOol0J7oo00<007ooOol0l7oo000hOol00`00
Oomoo`0LOol20009Ool00`00Oomoo`25Ool00`00Oomoo`08Ool00`00Oomoo`1YOol00`00Oomoo`3`
Ool003Qoo`03001oogoo01ioo`8000Eoo`8008Uoo`<000Eoo`8006aoo`03001oogoo0?1oo`00>7oo
0P0087oo1P00SWoo1@00KWoo0P00lGoo000_Ool50004Ool00`00Oomoo`3oOolNOol50004Ool00`00
Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo
0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000aOol00`00Oomo
o`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<0
07ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002mo
o`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<00004Ool00000000HOol3
003oOol7Ool3000017oo000000006Goo0`00M7oo002FOol01@00Oomoogoo00002Goo1P002Goo00D0
07ooOomoo`000?moo`Moo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05001o
ogooOol0000LOol00`00Oomoo`3oOol5Ool01@00Oomoogoo000067oo1@00M7oo002FOol01@00Oomo
ogoo00002Goo1P003Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Uoo`H000Uoo`04001oogoo
001eOol009Ioo`05001oogooOol0000JOol2003oOol8Ool01@00Oomoogoo00006Goo00<007oo0000
MGoo002EOol5000MOol00`00Oomoo`3oOol4Ool5000JOol00`00Ool0001eOol00;=oo`05001oogoo
Ool0003oOolVOol2001eOol00;Aoo`<00?moobQoo`03001oogoo07=oo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo000_Ool5003oOolUOol5
003gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`009Woo1P001Goo00<007ooOol0ogoo
77oo1P001Goo00<007ooOol0mgoo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2
003aOol0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1o
o`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000a
Ool00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol002moo`<000Ioo`03001oogoo
0?mooaioo`<000Ioo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`80
0?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo
:7oo0P00lGoo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool3
0006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol00005
Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo0000
1Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0l7oo000>Ool60002Ool01@00
Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0o7oo1P000Woo00D007oo
Oomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?1oo`005Woo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool4
0005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007oo
Ool0l7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?1oo`00
5Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00
Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?5oo`005goo0`0037oo1@00
17oo10001Goo00<007ooOol0ogoo1Woo0`0037oo1@0017oo10001Goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`1QOolF
002_Ool00`00Oomoo`3`Ool003Qoo`03001oogoo05aoo`D001Ioo`H00:Uoo`03001oogoo0?1oo`00
>7oo00<007ooOol0DWoo2P008Goo1`00XWoo00<007ooOol0l7oo000hOol2001@Ool3000bOol6002L
Ool2003aOol001moo`<000Ioo`8000Eoo`@000Eoo`03001oogoo04aoo`<003]oo`<0081oo`<000Io
o`8000Eoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo
009oo`03001oogoo04Uoo`<0045oo`<007aoo`05001oogooOol00005Ool20009Ool00`00Oomoo`02
Ool00`00Oomoo`3`Ool001Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool20017Ool3
0017Ool3001aOol60002Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00
Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0@goo0`00CGoo0`00MWoo00D007ooOomoo`00
011oo`03001oogoo009oo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001o
ogoo041oo`<005=oo`<007=oo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3`Ool001ioo`05
001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0lOol4001IOol2001aOol01@00Oomoogoo
000037oo00<007ooOol01Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol0
1Woo0P00>Woo0`00Ggoo0`00KWoo00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?5oo`007goo
0`003Goo10001Goo00<007ooOol0=Woo0`00IGoo0P00KGoo0`003Goo10001Goo00<007ooOol0l7oo
000hOol00`00Oomoo`0cOol3001ZOol30023Ool00`00Oomoo`3`Ool003Qoo`03001oogoo035oo`80
071oo`80085oo`03001oogoo0?1oo`00>7oo0P00<7oo0P00M7oo0P00Ogoo0P00lGoo000hOol00`00
Oomoo`0^Ool00`00Oomoo`1fOol3001lOol00`00Oomoo`3`Ool003Qoo`03001oogoo02aoo`8007ao
o`8007Yoo`03001oogoo0?1oo`00>7oo0P00:goo0P00P7oo0P00N7oo0P00lGoo000hOol00`00Oomo
o`0XOol20024Ool2001fOol00`00Oomoo`3`Ool003Qoo`03001oogoo02Eoo`<008Qoo`<007=oo`03
001oogoo0?1oo`00>7oo00<007ooOol08goo0P00SWoo0P00LGoo00<007ooOol0;Woo3@00]Goo000h
Ool2000ROol2002BOol2001_Ool2000YOol6000=Ool6002_Ool001Moo`<000Ioo`8000Aoo`D000Ao
o`@000Eoo`03001oogoo01moo`8009Ioo`8004aoo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001o
ogoo02Aoo`@001Uoo`@00:]oo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool0
0`00Oomoo`02Ool00`00Oomoo`0MOol2002JOol20019Ool01@00Oomoogoo00001Goo0P001Goo00@0
07ooOol000Qoo`03001oogoo009oo`03001oogoo021oo`@0025oo`<00:Qoo`003Woo1P000Woo00D0
07ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8001eoo`03001oogoo09aoo`03001o
ogoo03ioo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000NOol3
000XOol2002VOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`0JOol2002POol20016Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol06Woo0`00;Goo0`00Xgoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo1000
1Goo00<007ooOol067oo0P00Y7oo0P00A7oo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eo
o`03001oogoo01Qoo`8003=oo`800:5oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo01Ioo`800:Qoo`80049oo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`0FOol2000gOol2002OOol001Ioo`05001oogooOol0000;Ool0
1@00Oomoogoo000017oo00<007ooOol01Woo0P005Goo0P00[7oo0P00@7oo00D007ooOomoo`0000]o
o`05001oogooOol00004Ool00`00Oomoo`06Ool2000EOol2000kOol2002MOol001Moo`<000eoo`<0
00Eoo`@000Eoo`03001oogoo01=oo`03001oogoo0:ioo`03001oogoo03ioo`<000eoo`<000Eoo`@0
00Eoo`03001oogoo019oo`8003moo`<009Yoo`00>7oo00<007ooOol04Goo0P0037oo0`001Woo0P00
17oo1@0067oo0`001Woo0P001Woo0`0067oo0`001Woo0P001Goo0`006Woo0`001Woo0P001Goo0`00
3Woo0P004Goo1@00BGoo00<007ooOol047oo0P003Goo0`001Woo0P0017oo1@0067oo0`001Woo1000
17oo0`0067oo0`001Woo0P001Goo0`006Goo0`001Woo0P001Goo0`008Goo1@0057oo000hOol2000@
Ool2000=Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool2
0007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Qoo`05001o
ogooOol00005Ool20004Ool01@00Oomoogoo00003goo0P004Goo00<007ooOol0BGoo0P003goo0P00
3Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomoogoo00001Goo0P000Woo
0P000goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000GOol01@00
Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol0
3Goo0P003goo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol0
1@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo0000
4Goo0P003goo00<007ooOol0BGoo00<007ooOol03Goo00<007ooOol03Woo00D007ooOomoo`0000eo
o`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00
Oomoo`0<Ool00`00Oomoo`0?Ool01@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`00
00]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0
000;Ool01@00Oomoogoo00004goo00<007ooOol037oo00<007ooOol0BGoo00<007ooOol02goo0P00
4Goo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000Ool0000067oo
00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00002goo00D007ooOomoo`00
029oo`03001oogoo01Aoo`00>7oo00<007ooOol02Woo0P004Woo00D007ooOomoo`0000moo`03001o
ogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10006Goo00D0
07ooOomoo`0000aoo`<001Eoo`8000aoo`03001oogoo04Uoo`03001oogoo00Yoo`03001oogoo015o
o`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo00000P005Woo
00D007ooOomoo`0000]oo`@001Qoo`05001oogooOol0000<Ool3000SOol00`00Oomoo`0DOol003Qo
o`8000Uoo`8001Aoo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<0
07oo000067oo00D007ooOomoo`0000]oo`03001oogoo01Yoo`05001oogooOol0000;Ool01@00Oomo
ogoo00005Woo0P002Woo00<007ooOol0BGoo0P002Goo0P0057oo00D007ooOomoo`0000moo`03001o
ogoo01Eoo`05001oogooOol0000<Ool00`00Ool00002Ool2000DOol01@00Oomoogoo00002goo00<0
07ooOol06Goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03
001oogoo00Moo`03001oogoo01Aoo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007oo
Oomoo`0000eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo
00D007ooOomoo`0001Qoo`03001oogoo00Moo`03001oogoo04Uoo`03001oogoo00Moo`03001oogoo
01Aoo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8000Aoo`80
019oo`05001oogooOol0000<Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007ooOomoo`00
029oo`03001oogoo01Aoo`00>7oo00<007ooOol01Goo0P0067oo0`003Goo0`006Goo0`003goo00<0
07ooOol05goo0`003Woo0`006Goo0`003Goo0`006Woo0P001Goo0`00Bgoo00<007ooOol01Goo0P00
67oo0`003Goo0`006Goo0`003goo00<007ooOol017oo00<007ooOol047oo0`003Woo0`0067oo0`00
3Goo0`008Goo0`005Woo000hOol00`00Oomoo`03Ool2003>Ool2001AOol00`00Oomoo`03Ool2001P
Ool20029Ool003Qoo`80009oo`800=9oo`8004moo`80009oo`8006Aoo`03001oogoo08Ioo`00>7oo
00@007ooOol00=Ioo`03001oogoo04aoo`04001oogoo001WOol20026Ool003Qoo`<00=Qoo`8004ao
o`<006Yoo`03001oogoo08=oo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`19Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Ool0
0008Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool2000FOol0
03Qoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo
02Uoo`03001oogoo04Uoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo01Ioo`80015oo`03
001oogoo02Uoo`03001oogoo02Ioo`800003Ool007oo01Eoo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0L7oo00<007ooOol0HGoo0P006Woo000hOol2003oOolXOol2001bOol2001POol00`00Oomo
o`0JOol003Qoo`03001oogoo0?moobMoo`03001oogoo07=oo`03001oogoo05]oo`8001eoo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0M7oo0P00FGoo0P007goo000hOol2003oOolXOol2001gOol2
001EOol2000QOol003Qoo`03001oogoo0?moobMoo`03001oogoo07Qoo`80055oo`8002=oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0NWoo0P00CWoo00<007ooOol08goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`1lOol2001:Ool2000VOol003Qoo`800?moobQoo`8007moo`8004Ioo`8002Qo
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0P7oo0P00@Woo0P00:Woo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`22Ool2000nOol2000/Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Ao
o`03001oogoo03Uoo`8002ioo`00>7oo0P00ogoo:7oo0P00QWoo0P00=goo0P00<7oo000GOol30006
Ool20004Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20004Ool50004Ool40005Ool0
0`00Oomoo`27Ool2000cOol2000bOol001Ioo`05001oogooOol00005Ool20005Ool01000Oomoo`00
27oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo
0008Ool00`00Oomoo`02Ool00`00Oomoo`29Ool2000^Ool3000dOol001Ioo`05001oogooOol0000=
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Goo00<007ooOol0
27oo00<007ooOol00Woo0P00S7oo10009goo0`00=goo000FOol01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo08moo`<0029oo`8003Yoo`005Woo00D007ooOomoo`0000moo`03
001oogoo009oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool4
0005Ool00`00Oomoo`2BOol3000LOol3000lOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol0UGoo0`005Goo1000?goo000FOol01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P00VGoo5@00@goo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`3o
Ool6Ool3000=Ool30005Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`00
1Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007oo
Ool00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001o
ogoo0?1oo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`ioo`05001oogooOol0
000@Ool00`00Oomoo`02Ool2003aOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0l7oo000NOol01@00
Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001o
ogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00
Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P00lGoo000OOol3000=
Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol0
01Moo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`800?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eo
o`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00002goo
00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000;Ool0
1@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0l7oo000GOol3000<Ool50004Ool40005
Ool2003oOol7Ool3000<Ool50004Ool40005Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`800?moobQoo`800?5oo`00;goo1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0
l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0
035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo
00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo
9goo00<007ooOol0mgoo000_Ool3003oOolWOol3003iOol00?mooomooeIoo`00ogooogooEWoo002E
Ool3000017oo0000000067oo1@00ogoo1Goo0`0000Aoo`00000001Moo`D007Aoo`00UWoo00D007oo
Oomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000:Ool01000Oomo
o`00M7oo002FOol01@00Oomoogoo00006goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001Yoo`03
001oogoo07Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogoo
Ool00009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6
Ool01@00Oomoogoo000077oo00<007ooOol0LWoo002EOol5000LOol00`00Oomoo`3oOol5Ool5000M
Ool00`00Oomoo`1bOol00;Ioo`03001oogoo0?moob=oo`05001oogooOol0001dOol00;Aoo`<00?mo
obIoo`<007Eoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .39054 L
.08255 .42901 L
.10458 .46566 L
.12507 .49313 L
.14415 .51195 L
.14918 .51573 L
.15465 .51925 L
.15946 .52185 L
.16457 .52408 L
.16917 .52561 L
.17178 .52629 L
.17423 .52679 L
.17538 .52698 L
.17647 .52713 L
.17746 .52725 L
.17852 .52735 L
.17967 .52744 L
.18073 .52749 L
.182 .52752 L
.18314 .52752 L
.18435 .52749 L
.18547 .52743 L
.1867 .52734 L
.18802 .5272 L
.19071 .52681 L
.19317 .52632 L
.1979 .525 L
.20239 .52332 L
.21236 .51808 L
.22321 .51006 L
.24299 .48958 L
.26399 .4603 L
.30174 .39232 L
.34195 .30755 L
.38063 .22603 L
.40028 .18854 L
.42177 .15278 L
.44253 .1249 L
.4614 .10626 L
.47149 .09915 L
.47611 .09659 L
.48101 .09436 L
.4835 .09342 L
.48624 .09253 L
.48876 .09186 L
.49106 .09136 L
.49378 .09092 L
.49527 .09075 L
.49596 .09068 L
Mistroke
.49669 .09063 L
.498 .09055 L
.49921 .09052 L
.49996 .09051 L
.50065 .09051 L
.50196 .09055 L
.50313 .09061 L
.50438 .09071 L
.50556 .09084 L
.50663 .09098 L
.50926 .09143 L
.51175 .09198 L
.5167 .09349 L
.52208 .0957 L
.53169 .10116 L
.54056 .10788 L
.55926 .12702 L
.57988 .1553 L
.62014 .22758 L
.65888 .30933 L
.70007 .39593 L
.72063 .43466 L
.73974 .46603 L
.75939 .49242 L
.77791 .511 L
.78775 .51815 L
.79293 .52112 L
.7984 .52365 L
.80302 .5253 L
.80546 .52599 L
.80809 .52659 L
.8105 .52701 L
.8127 .52728 L
.81375 .52738 L
.81491 .52746 L
.81599 .5275 L
.817 .52752 L
.81818 .52752 L
.81941 .52748 L
.82047 .52743 L
.82163 .52734 L
.82287 .52721 L
.82421 .52704 L
.82661 .52663 L
.82905 .52609 L
.83134 .52547 L
.83564 .524 L
.84078 .52173 L
.84552 .51915 L
.85624 .51163 L
Mistroke
.87498 .49308 L
.89561 .46538 L
.93591 .39382 L
.97471 .31223 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .15822 L
.08255 .09277 L
.0932 .064 L
.10458 .03858 L
.11009 .02843 L
.11531 .02019 L
.12038 .01349 L
.12507 .00848 L
.12951 .00478 L
.13178 .0033 L
.13422 .00201 L
.13549 .00146 L
.13666 .00103 L
.13784 .00068 L
.13895 .00041 L
.14022 .00019 L
.1409 .0001 L
.14161 4e-05 L
.1423 1e-05 L
.14295 0 L
.14415 5e-05 L
.14531 .00016 L
.14656 .00037 L
.14773 .00064 L
.14881 .00095 L
.15143 .00197 L
.15392 .00328 L
.15886 .00686 L
.16423 .01221 L
.17383 .02544 L
.1827 .04173 L
.20137 .08761 L
.22197 .15361 L
.26217 .31011 L
.30086 .46095 L
.32051 .52485 L
.3309 .55305 L
.342 .57811 L
.35275 .59689 L
.35784 .60377 L
.36253 .60895 L
.36724 .61299 L
.36972 .61465 L
.37235 .61605 L
.37463 .61696 L
.37573 .6173 L
.37677 .61756 L
.37799 .6178 L
.37911 .61794 L
Mistroke
.38031 .61802 L
.38162 .61802 L
.38227 .61799 L
.38296 .61793 L
.38419 .61775 L
.38551 .61748 L
.38695 .61707 L
.38955 .61605 L
.39197 .61478 L
.39649 .61156 L
.40134 .60693 L
.40698 .59999 L
.41232 .59194 L
.42232 .57313 L
.44227 .52229 L
.4607 .46216 L
.50002 .30893 L
.53782 .16112 L
.55884 .0925 L
.56803 .0674 L
.57808 .04406 L
.58722 .02686 L
.59696 .01303 L
.60236 .00746 L
.60726 .00373 L
.60962 .00239 L
.61086 .0018 L
.61218 .00127 L
.61333 .00088 L
.61459 .00053 L
.61574 .00029 L
.61682 .00013 L
.61808 3e-05 L
.61871 0 L
.61941 0 L
.62065 7e-05 L
.62181 .00021 L
.62248 .00032 L
.62318 .00046 L
.62443 .00078 L
.62578 .00122 L
.62725 .00181 L
.62973 .00306 L
.63238 .00477 L
.63715 .00877 L
.64214 .01424 L
.64686 .02058 L
.6557 .03543 L
.67568 .08235 L
.69413 .13964 L
Mistroke
.7335 .29029 L
.77136 .44032 L
.79241 .512 L
.81166 .56404 L
.82118 .58388 L
.8262 .59264 L
.83155 .60059 L
.8367 .60686 L
.84136 .61136 L
.84361 .61312 L
.84604 .61473 L
.84835 .61596 L
.85045 .61683 L
.85159 .61721 L
.85283 .61753 L
.85414 .61779 L
.85538 .61795 L
.85653 .61802 L
.85776 .61802 L
.85881 .61796 L
.85997 .61782 L
.86063 .61771 L
.86132 .61756 L
.86256 .61724 L
.86535 .61622 L
.86777 .615 L
.87041 .61331 L
.87569 .60883 L
.88133 .60244 L
.89148 .58686 L
.90173 .56608 L
.91284 .53828 L
.933 .47576 L
.97393 .31822 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28124 L
.10458 .25149 L
.14415 .22454 L
.18221 .19997 L
.22272 .17572 L
.26171 .15461 L
.30316 .13498 L
.34309 .11913 L
.3815 .10699 L
.40095 .10207 L
.42237 .09764 L
.44268 .0944 L
.45178 .09327 L
.46172 .09225 L
.4671 .09179 L
.4721 .09143 L
.47727 .09112 L
.48196 .0909 L
.48658 .09072 L
.4887 .09066 L
.49093 .09061 L
.49332 .09056 L
.49438 .09055 L
.49552 .09053 L
.49675 .09052 L
.49789 .09051 L
.49859 .09051 L
.49925 .09051 L
.50049 .09051 L
.50163 .09051 L
.50286 .09052 L
.50401 .09053 L
.50508 .09054 L
.50754 .09058 L
.51014 .09063 L
.51268 .0907 L
.51504 .09078 L
.5204 .091 L
.5293 .09153 L
.53882 .0923 L
.54906 .09336 L
.56016 .0948 L
.58032 .09813 L
.62123 .10775 L
.66064 .12047 L
.69852 .13571 L
.73886 .1549 L
.77769 .17595 L
.81897 .2007 L
Mistroke
.85873 .22645 L
.89697 .25256 L
.93767 .28133 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20178 .30902 L
.21267 .30902 L
.22272 .30902 L
.23293 .30902 L
.23832 .30902 L
.24402 .30902 L
.24641 .30902 L
.24897 .30902 L
.25119 .30902 L
.25361 .30902 L
.25507 .30902 L
.25643 .30902 L
.25773 .30902 L
.2584 .30902 L
.25912 .30902 L
.25983 .30902 L
.26048 .30902 L
.26176 .30902 L
.26293 .30902 L
.26416 .30902 L
.26538 .30902 L
.26607 .30902 L
.26671 .30902 L
.26912 .30902 L
.27131 .30902 L
.27364 .30902 L
.27847 .30902 L
.2838 .30902 L
.29326 .30902 L
.30213 .30902 L
.32232 .30902 L
.34082 .30902 L
.38045 .30902 L
.41855 .30902 L
.45912 .30902 L
.49816 .30902 L
.53966 .30902 L
.57964 .30902 L
.61811 .30902 L
.63759 .30902 L
.65902 .30902 L
.67938 .30902 L
.69843 .30902 L
.70884 .30902 L
.71396 .30902 L
Mistroke
.71872 .30902 L
.72301 .30902 L
.72758 .30902 L
.7302 .30902 L
.73148 .30902 L
.73266 .30902 L
.73371 .30902 L
.73487 .30902 L
.73603 .30902 L
.73725 .30902 L
.73856 .30902 L
.73977 .30902 L
.7404 .30902 L
.7411 .30902 L
.74251 .30902 L
.74375 .30902 L
.74508 .30902 L
.74748 .30902 L
.74985 .30902 L
.75235 .30902 L
.7568 .30902 L
.76198 .30902 L
.7668 .30902 L
.77773 .30902 L
.78828 .30902 L
.79823 .30902 L
.81683 .30902 L
.85534 .30902 L
.89632 .30902 L
.93577 .30902 L
.97371 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`8001Qoo`@006Yoo`@006Moo`00
<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol05Goo0`000Woo
0P00J7oo0P000goo0P00IGoo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04
Ool00`00Oomoo`0DOol00`00Oomoo`05Ool00`00Oomoo`1TOol00`00Oomoo`05Ool00`00Oomoo`1R
Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo01=oo`03
001oogoo00Moo`03001oogoo069oo`03001oogoo00Moo`03001oogoo065oo`00<Goo00<007ooOol0
17oo0P00ogoo8Goo00<007ooOol017oo0P0057oo00<007ooOol027oo00<007ooOol0H7oo00<007oo
Ool027oo00<007ooOol0HGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`0B
Ool00`00Oomoo`0:Ool00`00Oomoo`1NOol00`00Oomoo`0:Ool00`00Oomoo`1POol003Qoo`03001o
ogoo0?moobMoo`03001oogoo019oo`03001oogoo00]oo`03001oogoo05aoo`03001oogoo00]oo`03
001oogoo061oo`00>7oo0P00ogoo:7oo0P004Woo00<007ooOol037oo00<007ooOol0G7oo00<007oo
Ool037oo00<007ooOol0Ggoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0@Ool00`00Oomoo`0>
Ool00`00Oomoo`1JOol00`00Oomoo`0>Ool00`00Oomoo`1NOol003Qoo`03001oogoo0?moobMoo`03
001oogoo00moo`03001oogoo00moo`03001oogoo05Yoo`03001oogoo00ioo`03001oogoo05ioo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol03goo00<007ooOol047oo00<007ooOol0F7oo00<007oo
Ool047oo00<007ooOol0GGoo000hOol2003oOolXOol2000?Ool00`00Oomoo`0AOol00`00Oomoo`1H
Ool00`00Oomoo`0@Ool00`00Oomoo`1MOol003Qoo`03001oogoo0?moobMoo`03001oogoo00ioo`03
001oogoo019oo`03001oogoo05Ioo`03001oogoo019oo`03001oogoo05aoo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007oo
Ool0G7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0=Ool00`00Oomoo`0COol00`00Oomoo`1F
Ool00`00Oomoo`0COol00`00Oomoo`1KOol003Qoo`800?moobQoo`8000ioo`03001oogoo01Aoo`03
001oogoo05Aoo`03001oogoo01Aoo`03001oogoo05]oo`005goo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool03Goo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol057oo00<007ooOol0Fgoo000FOol0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00aoo`03
001oogoo01Ioo`03001oogoo05=oo`03001oogoo01Eoo`03001oogoo05Yoo`003Woo1P000Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000=Ool00`00Oomoo`0FOol00`00Oomoo`1BOol0
0`00Oomoo`0FOol00`00Oomoo`1JOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol02goo00<007ooOol05goo00<007ooOol0DWoo00<007ooOol05goo00<007ooOol0
FGoo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo00]oo`03001oogoo01Qoo`03001o
ogoo055oo`03001oogoo01Moo`03001oogoo05Uoo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo06Uoo`D009Ioo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0H
Ool00`00Oomoo`1IOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol0
1Woo0P00J7oo0P001Goo1000TWoo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomo
o`06Ool2000;Ool00`00Oomoo`0IOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`1HOol0
01Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo06Aoo`<000]oo`03001oogoo091oo`<000aoo`D0
00Aoo`@000Eoo`03001oogoo00Yoo`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03
001oogoo05Qoo`00>7oo00<007ooOol0Hgoo00<007ooOol03Goo0P00/Goo00<007ooOol02Woo00<0
07ooOol06Woo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol0F7oo000hOol2001SOol00`00
Oomoo`0@Ool00`00Oomoo`2^Ool2000:Ool00`00Oomoo`0KOol00`00Oomoo`1>Ool00`00Oomoo`0K
Ool00`00Oomoo`1GOol003Qoo`03001oogoo065oo`03001oogoo015oo`03001oogoo0:ioo`03001o
ogoo00Uoo`03001oogoo01aoo`03001oogoo04eoo`03001oogoo01]oo`03001oogoo05Moo`00>7oo
00<007ooOol0H7oo00<007ooOol04goo00<007ooOol0[Goo00<007ooOol02Goo00<007ooOol077oo
00<007ooOol0CGoo00<007ooOol06goo00<007ooOol0Egoo000hOol00`00Oomoo`1OOol00`00Oomo
o`0EOol00`00Oomoo`2/Ool00`00Oomoo`09Ool00`00Oomoo`0LOol00`00Oomoo`1<Ool00`00Oomo
o`0LOol00`00Oomoo`1GOol003Qoo`8005moo`03001oogoo01Moo`03001oogoo0:]oo`8000Uoo`03
001oogoo01ioo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo05Ioo`00>7oo00<007ooOol0
GWoo00<007ooOol067oo00<007ooOol0ZWoo00<007ooOol027oo00<007ooOol07Woo00<007ooOol0
Bgoo00<007ooOol07Goo00<007ooOol0EWoo000hOol00`00Oomoo`1MOol00`00Oomoo`0IOol00`00
Oomoo`2ZOol00`00Oomoo`08Ool00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00
Oomoo`1FOol003Qoo`8005eoo`03001oogoo01]oo`03001oogoo0:Uoo`8000Qoo`03001oogoo021o
o`03001oogoo04Uoo`03001oogoo01moo`03001oogoo05Eoo`007goo0`001Woo0P001Goo10001Goo
00<007ooOol0Fgoo00<007ooOol07Goo00<007ooOol0Sgoo0`001Woo0P001Goo10001Goo00<007oo
Ool01goo00<007ooOol087oo00<007ooOol0BGoo00<007ooOol07goo00<007ooOol0EGoo000NOol0
1@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0Fgoo00<007ooOol07Woo00<0
07ooOol0SGoo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo00Moo`03001o
ogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001oogoo05Eoo`005Woo1P000Woo00D007oo
Oomoo`00011oo`03001oogoo009oo`03001oogoo05Yoo`03001oogoo021oo`03001oogoo08Aoo`H0
009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0QOol00`00
Oomoo`17Ool00`00Oomoo`0POol00`00Oomoo`1EOol001ioo`05001oogooOol0000@Ool00`00Oomo
o`02Ool2001JOol00`00Oomoo`0ROol00`00Oomoo`2;Ool01@00Oomoogoo000047oo00<007ooOol0
0Woo0P001goo00<007ooOol08Woo00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol0E7oo000N
Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0FGoo00<007ooOol08Woo00<007ooOol0Rgoo
00D007ooOomoo`0000aoo`@000Eoo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo04Ioo`03
001oogoo029oo`03001oogoo05Aoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001o
ogoo05Qoo`03001oogoo02Aoo`03001oogoo08Yoo`05001oogooOol0000<Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`0ROol00`00Oomoo`16Ool00`00Oomoo`0ROol00`00Oomoo`1DOol0
01ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1GOol00`00Oomoo`0UOol00`00
Oomoo`2:Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol08goo
00<007ooOol0AGoo00<007ooOol08Woo00<007ooOol0E7oo000OOol3000=Ool40005Ool2001HOol0
0`00Oomoo`0VOol00`00Oomoo`2:Ool3000=Ool40005Ool20006Ool00`00Oomoo`0TOol00`00Oomo
o`15Ool00`00Oomoo`0SOol00`00Oomoo`1COol003Qoo`03001oogoo05Ioo`03001oogoo02Moo`03
001oogoo0:=oo`03001oogoo00Eoo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03
001oogoo05=oo`00>7oo00<007ooOol0EWoo00<007ooOol0:7oo00<007ooOol0XWoo00<007ooOol0
1Goo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol0Dgoo000hOol2001F
Ool00`00Oomoo`0YOol00`00Oomoo`2ROol20006Ool00`00Oomoo`0UOol00`00Oomoo`13Ool00`00
Oomoo`0UOol00`00Oomoo`1BOol003Qoo`03001oogoo05Aoo`03001oogoo02]oo`03001oogoo0:5o
o`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03001oogoo059o
o`00>7oo00<007ooOol0E7oo00<007ooOol0;7oo00<007ooOol0X7oo00<007ooOol017oo00<007oo
Ool09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol0DWoo000hOol00`00Oomoo`1COol0
0`00Oomoo`0]Ool00`00Oomoo`2POol00`00Oomoo`04Ool00`00Oomoo`0VOol00`00Oomoo`12Ool0
0`00Oomoo`0VOol00`00Oomoo`1BOol003Qoo`8005Aoo`03001oogoo02ioo`03001oogoo09moo`80
00Eoo`03001oogoo02Moo`03001oogoo045oo`03001oogoo02Moo`03001oogoo055oo`00>7oo00<0
07ooOol0DWoo00<007ooOol0;goo00<007ooOol0Wgoo00<007ooOol00goo00<007ooOol0:7oo00<0
07ooOol0@7oo00<007ooOol0:7oo00<007ooOol0DGoo000hOol00`00Oomoo`1BOol00`00Oomoo`0`
Ool00`00Oomoo`2NOol00`00Oomoo`03Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0X
Ool00`00Oomoo`1AOol003Qoo`8005=oo`03001oogoo031oo`03001oogoo09ioo`8000Aoo`03001o
ogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo055oo`005goo0`001Woo0P0017oo
1@0017oo10001Goo00<007ooOol0DGoo00<007ooOol0<Woo00<007ooOol0O7oo0`001Woo0P0017oo
1@0017oo10001Goo00<007ooOol00goo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0:Goo
00<007ooOol0D7oo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo
009oo`03001oogoo055oo`03001oogoo039oo`03001oogoo07]oo`05001oogooOol00005Ool20005
Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0:Woo00<007ooOol0
?Woo00<007ooOol0:Woo00<007ooOol0D7oo000>Ool60002Ool01@00Oomoogoo00003Goo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol0D7oo00<007ooOol0=7oo00<007ooOol0LWoo1P000Woo
00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo
02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo051oo`005Woo00D007ooOomoo`0000io
o`03001oogoo00Moo`03001oogoo009oo`80055oo`03001oogoo03Aoo`03001oogoo07Yoo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`0ZOol00`00Oomo
o`0nOol00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02
Ool40005Ool00`00Oomoo`1?Ool00`00Oomoo`0fOol00`00Oomoo`1iOol01@00Oomoogoo00003goo
00<007ooOol00Woo10001Goo00D007ooOomoo`0002ioo`03001oogoo03eoo`03001oogoo02]oo`03
001oogoo04moo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo04moo`03001oogoo03Ioo`03001oogoo07Uoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0
Cgoo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8004moo`03
001oogoo03Qoo`03001oogoo07Qoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P000Woo00<007ooOol0;7oo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo
000GOol3000=Ool30005Ool40005Ool00`00Oomoo`1>Ool00`00Oomoo`0hOol00`00Oomoo`1iOol3
000=Ool30005Ool40005Ool01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<0
07ooOol0Cgoo000hOol00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00Oomoo`2IOol01000Oomoo`00
<7oo00<007ooOol0>goo00<007ooOol0;Goo00<007ooOol0CWoo000hOol00`00Oomoo`0OOol30006
Ool20004Ool5000HOol30006Ool20006Ool3000HOol30006Ool20005Ool4000IOol30006Ool20005
Ool3000QOol50019Ool01000Oomoo`007Woo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`00
3goo00<007ooOol01Woo0`001Woo0P001Goo0`005Goo00@007ooOomoo`<000Ioo`8000Eoo`<0025o
o`D001Aoo`00>7oo0P007goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Ool0
07oo00001Goo0P001goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`04001oogooOol2
000GOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo04Uoo`800003
Ool007oo01aoo`05001oogooOol00005Ool20005Ool01000Ool000005goo00D007ooOomoo`0000Eo
o`8000Moo`03001oogoo00ioo`03001oogoo00Eoo`05001oogooOol00005Ool20004Ool01@00Oomo
ogoo000057oo00@007ooOol000=oo`03001oogoo00=oo`8000Aoo`05001oogooOol0000ROol00`00
Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogooOol0000=Ool00`00Oomoo`0GOol01@00Ool0
07oo00002goo1@005goo00D007ooOomoo`0000]oo`04001oogooOol2000GOol01@00Oomoogoo0000
2goo00D007ooOomoo`00029oo`03001oogoo04Uoo`04001oogoo000MOol01@00Oomoogoo00003Goo
0P0067oo00D007ooOomoo`0000]oo`D000moo`03001oogoo00Eoo`05001oogooOol0000;Ool01@00
Oomoogoo00005Goo00<007oo00000goo00<007ooOol02Goo00D007ooOomoo`00029oo`03001oogoo
01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`80009oo`03001o
ogoo00Uoo`04001oogoo000HOol01@00Oomoogoo00002goo00L007ooOomoo`00Ool0000FOol01@00
Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03001oo`0001ioo`05001oogoo
Ool0000>Ool2000GOol01@00Oomoogoo00002goo00@007ooOol0011oo`03001oogoo00Eoo`05001o
ogooOol0000;Ool01@00Oomoogoo00005Goo00<007oo00000goo00<007ooOol02Goo00D007ooOomo
o`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000moo`03001oogoo
01Eoo`80009oo`03001oogoo00Yoo`03001oo`0001Qoo`05001oogooOol0000;Ool40002Ool00`00
Oomoo`0DOol01@00Oomoogoo000037oo0`008goo00<007ooOol0BGoo00<007oo00007Woo00D007oo
Oomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000?Ool00`00Oomoo`06
Ool01@00Oomoogoo00002goo10005Woo00<007oo00000goo00<007ooOol02Woo0`008goo00<007oo
Ool057oo000hOol2000OOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000ao
o`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`03Ool00`00Oomoo`0DOol01@00Oomo
ogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`<001ioo`05001oogooOol0000?Ool0
0`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo00003goo00<007ooOol01Woo00D007ooOomo
o`0000]oo`03001oogoo01Moo`03001oo`0000=oo`03001oogoo00Uoo`05001oogooOol0000ROol0
0`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo
00D007ooOomoo`0000eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`03Ool00`00Oomoo`0C
Ool01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03001oo`0001ioo`05
001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8000moo`03001oogoo
00Ioo`05001oogooOol0000<Ool00`00Oomoo`0GOol20003Ool00`00Oomoo`09Ool01@00Oomoogoo
00008Woo00<007ooOol057oo000hOol00`00Oomoo`0OOol3000=Ool3000GOol00`00Ool00002000?
Ool00`00Oomoo`0GOol3000>Ool30002Ool00`00Oomoo`0DOol3000=Ool3000QOol3001;Ool2000P
Ool3000=Ool300000goo001oo`0FOol3000?Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool3000>Ool3
000FOol00`00Ool00002000=Ool3000QOol3000FOol003Qoo`8004Yoo`03001oogoo049oo`03001o
ogoo09Eoo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo00<007oo
Ool0B7oo00<007ooOol0@goo00<007ooOol0UGoo0P00=7oo00<007ooOol0=Woo00<007ooOol0<Woo
00<007ooOol0C7oo000hOol00`00Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`2DOol2000dOol0
0`00Oomoo`0fOol00`00Oomoo`0cOol00`00Oomoo`1;Ool003Qoo`03001oogoo04Moo`03001oogoo
04Eoo`03001oogoo09Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo
04]oo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`04Ool01@00Oomoogoo
00002Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00D007ooOomoo`0000Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`8004]oo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo0P00
Agoo00<007ooOol0B7oo00<007ooOol0AGoo00<007ooOol0BWoo00<007ooOol0=7oo00<007ooOol0
=7oo00<007ooOol0=Goo00<007ooOol0<goo00<007ooOol057oo000hOol20016Ool00`00Oomoo`19
Ool00`00Oomoo`14Ool00`00Oomoo`1;Ool2000fOol00`00Oomoo`0bOol00`00Oomoo`0fOol00`00
Oomoo`0cOol00`00Oomoo`0DOol003Qoo`03001oo`0004Eoo`03001oogoo04Yoo`03001oogoo04=o
o`03001oogoo04]oo`03001oogoo03Eoo`03001oogoo039oo`03001oogoo03Ioo`03001oogoo03=o
o`03001oogoo01Aoo`00>7oo00<007oo0000A7oo00<007ooOol0Bgoo00<007ooOol0@Woo00<007oo
Ool0C7oo00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=Woo00<007ooOol0<Woo00<007oo
Ool05Goo000hOol01000Oomoo`00@goo00<007ooOol0C7oo00<007ooOol0@Goo00<007ooOol0C7oo
00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=goo00<007ooOol0<Goo00<007ooOol05Goo
000hOol200000goo001oo`11Ool00`00Oomoo`1=Ool00`00Oomoo`10Ool00`00Oomoo`1=Ool2000g
Ool00`00Oomoo`0`Ool00`00Oomoo`0hOol00`00Oomoo`0aOol00`00Oomoo`0EOol003Qoo`05001o
ogooOol00011Ool00`00Oomoo`1>Ool00`00Oomoo`0oOol00`00Oomoo`1=Ool00`00Oomoo`0fOol0
0`00Oomoo`0`Ool00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`0FOol003Qoo`05001oogoo
Ool00010Ool00`00Oomoo`1?Ool00`00Oomoo`0nOol00`00Oomoo`1>Ool00`00Oomoo`0fOol00`00
Oomoo`0`Ool00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`0FOol003Qoo`03001oogoo009o
o`03001oogoo03eoo`03001oogoo051oo`03001oogoo03eoo`03001oogoo04ioo`03001oogoo03Io
o`03001oogoo031oo`03001oogoo03Uoo`03001oogoo02moo`03001oogoo01Ioo`00>7oo0P000goo
00<007ooOol0?7oo00<007ooOol0DGoo00<007ooOol0?7oo00<007ooOol0Cgoo0P00>7oo00<007oo
Ool0;Woo00<007ooOol0>Woo00<007ooOol0;goo00<007ooOol05Woo000hOol00`00Oomoo`02Ool0
0`00Oomoo`0lOol00`00Oomoo`1BOol00`00Oomoo`0kOol00`00Oomoo`1?Ool00`00Oomoo`0gOol0
0`00Oomoo`0^Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`0GOol003Qoo`03001oogoo
00=oo`03001oogoo03Yoo`03001oogoo05=oo`03001oogoo03Yoo`03001oogoo051oo`03001oogoo
03Moo`03001oogoo02ioo`03001oogoo03]oo`03001oogoo02eoo`03001oogoo01Moo`00>7oo0P00
17oo00<007ooOol0>Woo00<007ooOol0E7oo00<007ooOol0>Goo00<007ooOol0D7oo0P00>7oo00<0
07ooOol0;Woo00<007ooOol0>goo00<007ooOol0;Goo00<007ooOol05goo000GOol30006Ool20004
Ool50004Ool40005Ool00`00Oomoo`04Ool00`00Oomoo`0hOol00`00Oomoo`1EOol00`00Oomoo`0h
Ool00`00Oomoo`0`Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`0hOol00`00Oomoo`0/
Ool00`00Oomoo`0lOol00`00Oomoo`0]Ool00`00Oomoo`0GOol001Ioo`05001oogooOol00005Ool2
0005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0>7oo00<007oo
Ool0EWoo00<007ooOol0=goo00<007ooOol0;goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo
0008Ool00`00Oomoo`02Ool00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00Oomoo`0lOol00`00Oomo
o`0/Ool00`00Oomoo`0HOol001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`1GOol00`00Oomoo`0fOol00`00Oomoo`0`
Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0>7oo00<007oo
Ool0;7oo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol067oo000FOol01@00Oomoogoo0000
3Woo00<007ooOol01goo00<007ooOol00Woo0P001Woo00<007ooOol0=Woo00<007ooOol0F7oo00<0
07ooOol0=Goo00<007ooOol0<7oo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`8003Yoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02]oo`03001oogoo01Qoo`005Woo
00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00Ioo`03001oogoo03Aoo`03
001oogoo05Uoo`03001oogoo03Aoo`03001oogoo035oo`05001oogooOol0000?Ool00`00Oomoo`02
Ool40005Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00
Oomoo`0IOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`0dOol00`00Oomoo`1JOol00`00Oomoo`0cOol00`00Oomoo`0aOol01@00Oomo
ogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0>Goo00<007ooOol0:Woo00<0
07ooOol0?Woo00<007ooOol0:Woo00<007ooOol06Goo000FOol01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`8000Qoo`03001oogoo039oo`03001oogoo05]oo`03001oogoo
039oo`03001oogoo039oo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo
0P00>Woo00<007ooOol0:Woo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol06Goo000GOol3
000=Ool30005Ool40005Ool00`00Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`1LOol00`00Oomo
o`0aOol00`00Oomoo`0cOol3000=Ool30005Ool40005Ool00`00Oomoo`0jOol00`00Oomoo`0XOol0
0`00Oomoo`10Ool00`00Oomoo`0YOol00`00Oomoo`0IOol003Qoo`03001oogoo00Qoo`03001oogoo
031oo`03001oogoo05eoo`03001oogoo031oo`03001oogoo05Eoo`03001oogoo03Yoo`03001oogoo
02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo01Yoo`00>7oo00<007ooOol02Goo00<0
07ooOol0;goo00<007ooOol0GWoo00<007ooOol0;goo00<007ooOol0EGoo00<007ooOol0>Woo00<0
07ooOol0:7oo00<007ooOol0@7oo00<007ooOol0:7oo00<007ooOol06Woo000hOol2000:Ool00`00
Oomoo`0^Ool00`00Oomoo`1OOol00`00Oomoo`0^Ool00`00Oomoo`1FOol2000kOol00`00Oomoo`0X
Ool00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`0JOol003Qoo`03001oogoo00Yoo`03001o
ogoo02eoo`03001oogoo05moo`03001oogoo02ioo`03001oogoo05Ioo`03001oogoo03]oo`03001o
ogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01]oo`00>7oo00<007ooOol02Woo
00<007ooOol0;7oo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0Egoo00<007ooOol0>goo
00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol06goo000hOol2000<Ool0
0`00Oomoo`0[Ool00`00Oomoo`1QOol00`00Oomoo`0[Ool00`00Oomoo`1HOol2000lOol00`00Oomo
o`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomoo`0KOol003Qoo`03001oogoo00]oo`03
001oogoo02Yoo`03001oogoo06=oo`03001oogoo02Yoo`03001oogoo05Qoo`03001oogoo03]oo`03
001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03001oogoo01]oo`00>7oo00<007ooOol0
37oo00<007ooOol0:Goo00<007ooOol0Hgoo00<007ooOol0:Goo00<007ooOol0FGoo00<007ooOol0
?7oo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol077oo000hOol00`00
Oomoo`0=Ool00`00Oomoo`0WOol00`00Oomoo`1UOol00`00Oomoo`0XOol00`00Oomoo`1IOol00`00
Oomoo`0lOol00`00Oomoo`0TOol00`00Oomoo`14Ool00`00Oomoo`0TOol00`00Oomoo`0LOol003Qo
o`8000ioo`03001oogoo02Moo`03001oogoo06Ioo`03001oogoo02Ioo`03001oogoo05Yoo`8003eo
o`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo01aoo`007goo0`001Woo
0P001Goo10001Goo00<007ooOol03Woo00<007ooOol09Goo00<007ooOol0J7oo00<007ooOol09Goo
00<007ooOol0@Goo0`001Woo0P001Goo10001Goo00<007ooOol0?7oo00<007ooOol097oo00<007oo
Ool0AGoo00<007ooOol08goo00<007ooOol077oo000NOol01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol00Woo00<007ooOol03Woo00<007ooOol09Goo00<007ooOol0J7oo00<007ooOol097oo00<0
07ooOol0@Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo03eoo`03001o
ogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo01eoo`007Woo00D007ooOomoo`00
011oo`03001oogoo009oo`03001oogoo00moo`03001oogoo02=oo`03001oogoo06Yoo`03001oogoo
02=oo`03001oogoo045oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0mOol00`00
Oomoo`0ROol00`00Oomoo`16Ool00`00Oomoo`0ROol00`00Oomoo`0MOol001ioo`05001oogooOol0
000@Ool00`00Oomoo`02Ool2000AOol00`00Oomoo`0ROol00`00Oomoo`1[Ool00`00Oomoo`0QOol0
0`00Oomoo`12Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00?Woo00<007ooOol08Woo00<0
07ooOol0Agoo00<007ooOol08Goo00<007ooOol07Goo000NOol01@00Oomoogoo000037oo10001Goo
00<007ooOol047oo00<007ooOol08Goo00<007ooOol0K7oo00<007ooOol08Goo00<007ooOol0@Woo
00D007ooOomoo`0000aoo`@000Eoo`03001oogoo03ioo`03001oogoo025oo`03001oogoo04Moo`03
001oogoo021oo`03001oogoo01ioo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001o
ogoo015oo`03001oogoo01moo`03001oogoo06ioo`03001oogoo01moo`03001oogoo04=oo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0nOol00`00Oomoo`0POol00`00Oomoo`18Ool0
0`00Oomoo`0POol00`00Oomoo`0NOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2000C
Ool00`00Oomoo`0MOol00`00Oomoo`1`Ool00`00Oomoo`0MOol00`00Oomoo`14Ool01@00Oomoogoo
000037oo00<007ooOol01Woo0P00?goo00<007ooOol087oo00<007ooOol0BGoo00<007ooOol07goo
00<007ooOol07Woo000OOol3000=Ool40005Ool00`00Oomoo`0BOol00`00Oomoo`0MOol00`00Oomo
o`1`Ool00`00Oomoo`0LOol00`00Oomoo`16Ool3000=Ool40005Ool00`00Oomoo`0oOol00`00Oomo
o`0OOol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`0NOol003Qoo`03001oogoo01=oo`03
001oogoo01]oo`03001oogoo079oo`03001oogoo01Yoo`03001oogoo061oo`03001oogoo03moo`03
001oogoo01ioo`03001oogoo04Yoo`03001oogoo01ioo`03001oogoo01moo`00>7oo00<007ooOol0
57oo00<007ooOol067oo0P00MWoo00<007ooOol067oo00<007ooOol0HGoo00<007ooOol0?goo00<0
07ooOol07Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol07goo000hOol2000FOol00`00
Oomoo`0FOol00`00Oomoo`1gOol00`00Oomoo`0GOol00`00Oomoo`1QOol20011Ool00`00Oomoo`0M
Ool00`00Oomoo`1;Ool00`00Oomoo`0MOol00`00Oomoo`0OOol003Qoo`03001oogoo01Ioo`03001o
ogoo01Aoo`03001oogoo07Uoo`03001oogoo01Eoo`03001oogoo069oo`03001oogoo041oo`03001o
ogoo01eoo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo01moo`00>7oo00<007ooOol05goo
00<007ooOol04Woo00<007ooOol0Ngoo00<007ooOol04goo00<007ooOol0Hgoo00<007ooOol0@7oo
00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol087oo000hOol2000IOol0
0`00Oomoo`0@Ool00`00Oomoo`1mOol00`00Oomoo`0AOol00`00Oomoo`1TOol20012Ool00`00Oomo
o`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`0POol003Qoo`03001oogoo01Uoo`03
001oogoo00ioo`03001oogoo07moo`8000moo`8006Moo`03001oogoo045oo`03001oogoo01]oo`03
001oogoo04eoo`03001oogoo01]oo`03001oogoo021oo`00>7oo00<007ooOol06Woo00<007ooOol0
2goo0P00Q7oo00<007ooOol02Woo0P00JGoo00<007ooOol0@Goo00<007ooOol06Woo00<007ooOol0
CWoo00<007ooOol06Woo00<007ooOol08Goo000hOol00`00Oomoo`0KOol30008Ool20027Ool00`00
Oomoo`08Ool00`00Oomoo`1YOol00`00Oomoo`12Ool00`00Oomoo`0IOol00`00Oomoo`1?Ool00`00
Oomoo`0IOol00`00Oomoo`0QOol003Qoo`8001moo`P008Yoo`X006aoo`8004=oo`03001oogoo01Uo
o`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025oo`005goo0`001Woo0P001Woo00<007oo
Ool017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<0
07ooOol0@Woo00<007ooOol067oo00<007ooOol0D7oo00<007ooOol06Goo00<007ooOol08Goo000F
Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04=o
o`03001oogoo01Moo`03001oogoo055oo`03001oogoo01Moo`03001oogoo029oo`005Woo00D007oo
Oomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`13Ool00`00Oomoo`0GOol00`00Oomo
o`1AOol00`00Oomoo`0GOol00`00Oomoo`0ROol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo0P00A7oo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05goo00<007ooOol08Woo000F
Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo04Aoo`03001oogoo01Eoo`03001oogoo05=o
o`03001oogoo01Eoo`03001oogoo02=oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`14Ool00`00Oomoo`0DOol00`00Oomoo`1DOol00`00Oomoo`0EOol00`00Oomo
o`0SOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo
1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20015Ool00`00Oomo
o`0DOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`0TOol001Moo`<000aoo`D000Aoo`@0
00Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo04Eoo`03001oogoo019o
o`03001oogoo05Ioo`03001oogoo01=oo`03001oogoo02Aoo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0AGoo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol09Goo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`16Ool00`00Oomoo`0AOol00`00Oomoo`1FOol00`00Oomo
o`0BOol00`00Oomoo`0UOol003Qoo`800?moobQoo`8004Moo`03001oogoo011oo`03001oogoo05Qo
o`03001oogoo011oo`03001oogoo02Ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Agoo00<0
07ooOol03goo00<007ooOol0FGoo00<007ooOol03goo00<007ooOol09Woo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`17Ool00`00Oomoo`0>Ool00`00Oomoo`1KOol00`00Oomoo`0>Ool00`00Oomo
o`0VOol003Qoo`800?moobQoo`8004Uoo`03001oogoo00eoo`03001oogoo05]oo`03001oogoo00eo
o`03001oogoo02Moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0B7oo00<007ooOol037oo00<0
07ooOol0GGoo00<007ooOol037oo00<007ooOol09goo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`18Ool00`00Oomoo`0<Ool00`00Oomoo`1MOol00`00Oomoo`0;Ool00`00Oomoo`0XOol003Qoo`03
001oogoo0?moobMoo`03001oogoo04Uoo`03001oogoo00Yoo`03001oogoo05moo`03001oogoo00Yo
o`03001oogoo02Qoo`00>7oo0P00ogoo:7oo0P00Bgoo00<007ooOol027oo00<007ooOol0H7oo00<0
07ooOol027oo0P00:goo000_Ool50004Ool00`00Oomoo`3oOolNOol50004Ool00`00Oomoo`1;Ool0
0`00Oomoo`06Ool00`00Oomoo`1ROol00`00Oomoo`06Ool00`00Oomoo`0[Ool0035oo`03001oogoo
00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo04aoo`03001oogoo00Aoo`03001o
ogoo06Aoo`8000Eoo`03001oogoo02aoo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol0
17oo0P00CWoo1P00J7oo1P00;goo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03
001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000a
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo
003oOoooOomFOol009Eoo`<00004Ool00000000HOol3003oOol7Ool3000017oo000000006Goo0`00
M7oo002FOol01@00Oomoogoo00002Goo1P002Goo00D007ooOomoo`000?moo`Moo`05001oogooOol0
0009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05001oogooOol0000LOol00`00Oomoo`3oOol5Ool0
1@00Oomoogoo000067oo1@00M7oo002FOol01@00Oomoogoo00002Goo1P003Goo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000Uoo`H000Uoo`04001oogoo001eOol009Ioo`05001oogooOol0000JOol2
003oOol8Ool01@00Oomoogoo00006Goo00<007oo0000MGoo002EOol5000MOol00`00Oomoo`3oOol4
Ool5000JOol00`00Ool0001eOol00;=oo`05001oogooOol0003oOolVOol2001eOol00;Aoo`<00?mo
obQoo`03001oogoo07=oo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo000_Ool5003oOolUOol5003gOol0035oo`03001oogoo0?moobMoo`03
001oogoo0?Moo`009Woo1P001Goo00<007ooOol0ogoo77oo1P001Goo00<007ooOol0mgoo000aOol0
0`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0
ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00
Oomoo`04Ool2003aOol002moo`<000Ioo`03001oogoo0?mooaioo`<000Ioo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`
Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000GOol30006Ool20006Ool0
0`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomoo`04Ool40005
Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007oo
Ool00Woo00<007ooOol0l7oo000>Ool60002Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol0o7oo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo
009oo`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol0
01Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomo
ogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00003goo
00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000]oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool2001POolJ002;Ool01@00Oomoogoo00002goo00D007ooOomoo`00
00Aoo`03001oogoo00Ioo`800?5oo`005goo0`0037oo1@0017oo10001Goo00<007ooOol0Egoo2000
6Woo2000Q7oo0`0037oo1@0017oo10001Goo00<007ooOol0l7oo000hOol00`00Oomoo`1BOol5000Z
Ool3002ROol00`00Oomoo`3`Ool003Qoo`03001oogoo04moo`<0039oo`<009moo`03001oogoo0?1o
o`00>7oo0P00CGoo0`00>7oo0`00W7oo0P00lGoo000hOol00`00Oomoo`19Ool3000nOol3002IOol0
0`00Oomoo`3`Ool003Qoo`03001oogoo04Ioo`<004Aoo`<009Ioo`03001oogoo0?1oo`00>7oo0P00
AGoo0P00BWoo0`00Tgoo0P00lGoo000hOol00`00Oomoo`11Ool3001?Ool3002@Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo03moo`8005Eoo`<008eoo`03001oogoo0?1oo`00>7oo00<007ooOol0?Goo
0P00FWoo0P00Rgoo00<007ooOol0l7oo000hOol2000kOol3001NOol20029Ool2003aOol001moo`<0
00Ioo`8000Eoo`@000Eoo`03001oogoo03Qoo`8006=oo`8006ioo`<000Ioo`8000Eoo`@000Eoo`03
001oogoo0?1oo`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo03Eo
o`<006Moo`8006]oo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool0
01Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000dOol2001/Ool2001QOol60002
Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomoogoo000047oo00<0
07ooOol00Woo00<007ooOol0<Goo0P00L7oo0P00Igoo00D007ooOomoo`00011oo`03001oogoo009o
o`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo02moo`8007Aoo`80
06Eoo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool00`00Oomoo`0^Ool00`00Oomoo`1fOol3001ROol01@00Oomoogoo000037oo00<0
07ooOol01Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00;Goo
0P00O7oo0P00H7oo00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?5oo`007goo0`003Goo1000
1Goo00<007ooOol0:Woo0P00P7oo0P00Ggoo0`003Goo10001Goo00<007ooOol0l7oo000hOol00`00
Oomoo`0YOol00`00Oomoo`22Ool00`00Oomoo`1eOol00`00Oomoo`3`Ool003Qoo`03001oogoo02Mo
o`8008Ioo`8007Eoo`03001oogoo0?1oo`00>7oo0P009goo00<007ooOol0R7oo00<007ooOol0LWoo
0P00lGoo000hOol00`00Oomoo`0TOol2002<Ool2001bOol00`00Oomoo`3`Ool003Qoo`03001oogoo
02=oo`03001oogoo08ioo`03001oogoo06moo`03001oogoo0?1oo`00>7oo0P008Woo0P00TWoo0P00
Kgoo0P00lGoo000hOol00`00Oomoo`0POol00`00Oomoo`2DOol00`00Oomoo`1/Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo01ioo`8009Qoo`8006aoo`03001oogoo0?1oo`00>7oo00<007ooOol07Goo
00<007ooOol0VWoo00<007ooOol0JGoo00<007ooOol0l7oo000hOol2000LOol2002NOol2001YOol2
003aOol001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo01Yoo`03001oogoo0:1oo`03
001oogoo04Eoo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomo
o`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`0HOol2002TOol20014
Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo0?1o
o`003Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8001Qoo`03
001oogoo0:Ioo`03001oogoo03Uoo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`0EOol2002ZOol20011Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007oo
Ool057oo00<007ooOol0[7oo00<007ooOol0?Woo00D007ooOomoo`0000moo`03001oogoo009oo`@0
00Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo019oo`800;1oo`8003ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P004Woo00<007ooOol0/Woo00<007ooOol0>goo00D007ooOomoo`0000]oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool2003aOol001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo00mo
o`800;Ioo`8003aoo`<000eoo`<000Eoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol03Woo
00<007ooOol03Woo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`0067oo0`001Woo0P001Goo
0`006Woo0`001Woo0P001Goo0`004Woo00<007ooOol037oo1@00BGoo00<007ooOol07goo0`001Woo
0P0017oo1@0067oo0`001Woo0P001Woo0`0067oo0`001Woo0P001Goo0`006Goo0`001Woo0P001Goo
0`008Goo1@0057oo000hOol2000=Ool2000@Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol0
01Moo`05001oogooOol00005Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo
00D007ooOomoo`0001Qoo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00004Woo0P003Woo
00<007ooOol0BGoo0P007goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomo
ogoo00001Goo0P001goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0
000GOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo
00<007ooOol02goo00<007ooOol047oo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogoo
Ool0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;
Ool01@00Oomoogoo000057oo00<007ooOol02goo00<007ooOol0BGoo00<007ooOol07Woo00D007oo
Oomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo
00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo
000hOol00`00Oomoo`0:Ool00`00Oomoo`0AOol01@00Oomoogoo00003Woo00<007ooOol05Woo00D0
07ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05
001oogooOol0000;Ool01@00Oomoogoo00005Goo00<007ooOol02Woo00<007ooOol0BGoo00<007oo
Ool07Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000Oomoo`00
67oo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00002goo00D007ooOomo
o`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol027oo0P0057oo00D007ooOomoo`0000moo`03
001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10006Goo
00D007ooOomoo`0000aoo`<001Moo`8000Yoo`03001oogoo04Uoo`03001oogoo01ioo`05001oogoo
Ool0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`00
00]oo`@001Qoo`05001oogooOol0000<Ool3000SOol00`00Oomoo`0DOol003Qoo`8000Qoo`03001o
ogoo01Aoo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo0000
67oo00D007ooOomoo`0000]oo`03001oogoo01Yoo`05001oogooOol0000;Ool01@00Oomoogoo0000
67oo00<007ooOol01goo00<007ooOol0BGoo0P007goo00D007ooOomoo`0000moo`03001oogoo01Eo
o`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo00<007ooOol06Goo00D0
07ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo00Eoo`80
01Moo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8001Qoo`05
001oogooOol0000<Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`0001Uoo`80
00Moo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo
00D007ooOomoo`0000eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`0HOol01@00Oomoogoo
00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol017oo00<007ooOol0
67oo0`003Goo0`006Goo0`003goo00<007ooOol05goo0`003Woo0`006Goo0`003Goo0`0077oo00<0
07ooOol00Woo0`00Bgoo00<007ooOol07goo0`003Goo0`006Goo0`003goo00<007ooOol05goo0`00
3Woo0`0067oo0`003Goo0`008Goo0`005Woo000hOol00`00Oomoo`02Ool2003@Ool2001@Ool00`00
Oomoo`3`Ool003Qoo`80009oo`03001oogoo0=9oo`03001oogoo04eoo`800?5oo`00>7oo00@007oo
00000=Ioo`8004eoo`03001oogoo0?1oo`00>7oo0P00fWoo00<007ooOol0BWoo00<007ooOol0l7oo
000bOooY0010OooY000@Ool003Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo04Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo00<007ooOol0
:Goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol0:Goo00<007ooOol0
BGoo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0
:Goo00<007ooOol057oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol2003oOolXOol2003aOol001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo
0?moo`Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo0?1oo`005Woo00D007oo
Oomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000=Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo
00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo0?1o
o`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eo
o`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05
001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003aOol001Moo`<000eoo`<000Eoo`@0
00Eoo`03001oogoo0?moo`Ioo`<000eoo`<000Eoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMo
o`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000OOol30006Ool20005Ool40005Ool00`00
Oomoo`3oOol>Ool30006Ool20005Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol00005
Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol00Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00ogoo
3Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?5oo`007Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomo
o`3`Ool001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo0000
37oo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007oo
Ool0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?1oo`007Woo00D007oo
Oomoo`0000aoo`03001oogoo00Ioo`800?moo`ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2
003aOol001moo`<000eoo`@000Eoo`03001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo0?1o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03
001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`80
0?moobQoo`800?5oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo
1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`005Woo00D007oo
Oomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo0P00lGoo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo
00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1o
o`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eo
o`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05
001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Moo`<0
00aoo`D000Aoo`@000Eoo`800?moo`Moo`<000aoo`D000Aoo`@000Eoo`800?5oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`80
0?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo
:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMo
o`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000_Ool50004Ool00`00Oomoo`3oOolNOol5
0004Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Ao
o`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<0
07ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03
001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000a
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo
003oOoooOomFOol009Eoo`<00004Ool00000000HOol5003oOol5Ool3000017oo000000005goo1@00
M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uo
o`H000Yoo`04001oogoo001dOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00
Oomoogoo00006Woo00<007ooOol0M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0
ogoo1Woo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001]o
o`03001oogoo0?moo`Ioo`05001oogooOol0000LOol00`00Oomoo`1bOol009Eoo`D001aoo`03001o
ogoo0?moo`Eoo`D001eoo`03001oogoo079oo`00]Woo00<007ooOol0ogoo8goo00D007ooOomoo`00
07Aoo`00]7oo0`00ogoo9Woo0`00MGoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34464 L
.08255 .36146 L
.10458 .37747 L
.12507 .38948 L
.14415 .3977 L
.14918 .39935 L
.15465 .40089 L
.15946 .40203 L
.16457 .403 L
.16917 .40367 L
.17178 .40397 L
.17423 .40419 L
.17538 .40427 L
.17647 .40434 L
.17746 .40439 L
.17852 .40443 L
.17967 .40447 L
.18073 .40449 L
.182 .40451 L
.18314 .40451 L
.18435 .40449 L
.18547 .40447 L
.1867 .40443 L
.18802 .40437 L
.19071 .4042 L
.19317 .40398 L
.1979 .40341 L
.20239 .40267 L
.21236 .40038 L
.22321 .39688 L
.24299 .38793 L
.26399 .37513 L
.30174 .34542 L
.34195 .30838 L
.38063 .27275 L
.40028 .25637 L
.42177 .24074 L
.44253 .22855 L
.4614 .22041 L
.47149 .2173 L
.47611 .21618 L
.48101 .21521 L
.4835 .2148 L
.48624 .21441 L
.48876 .21412 L
.49106 .2139 L
.49378 .21371 L
.49527 .21363 L
.49596 .2136 L
Mistroke
.49669 .21358 L
.498 .21354 L
.49921 .21353 L
.49996 .21353 L
.50065 .21353 L
.50196 .21354 L
.50313 .21357 L
.50438 .21362 L
.50556 .21367 L
.50663 .21373 L
.50926 .21393 L
.51175 .21417 L
.5167 .21483 L
.52208 .2158 L
.53169 .21818 L
.54056 .22112 L
.55926 .22948 L
.57988 .24184 L
.62014 .27343 L
.65888 .30915 L
.70007 .347 L
.72063 .36393 L
.73974 .37763 L
.75939 .38917 L
.77791 .39729 L
.78775 .40041 L
.79293 .40171 L
.7984 .40282 L
.80302 .40353 L
.80546 .40384 L
.80809 .4041 L
.8105 .40428 L
.8127 .4044 L
.81375 .40444 L
.81491 .40448 L
.81599 .4045 L
.817 .40451 L
.81818 .40451 L
.81941 .40449 L
.82047 .40447 L
.82163 .40443 L
.82287 .40437 L
.82421 .4043 L
.82661 .40412 L
.82905 .40388 L
.83134 .40361 L
.83564 .40297 L
.84078 .40198 L
.84552 .40085 L
.85624 .39756 L
Mistroke
.87498 .38945 L
.89561 .37735 L
.93591 .34608 L
.97471 .31042 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .18702 L
.08255 .13407 L
.0932 .1108 L
.10458 .09023 L
.11009 .08202 L
.11531 .07535 L
.12038 .06993 L
.12507 .06587 L
.12951 .06288 L
.13178 .06168 L
.13422 .06064 L
.13549 .0602 L
.13666 .05985 L
.13784 .05956 L
.13895 .05935 L
.14022 .05917 L
.1409 .0591 L
.14161 .05905 L
.1423 .05902 L
.14295 .05902 L
.14415 .05905 L
.14531 .05915 L
.14656 .05932 L
.14773 .05953 L
.14881 .05979 L
.15143 .06061 L
.15392 .06167 L
.15886 .06457 L
.16423 .06889 L
.17383 .0796 L
.1827 .09278 L
.20137 .12989 L
.22197 .18329 L
.26217 .3099 L
.30086 .43193 L
.32051 .48363 L
.3309 .50645 L
.342 .52672 L
.35275 .54191 L
.35784 .54748 L
.36253 .55166 L
.36724 .55494 L
.36972 .55628 L
.37235 .55741 L
.37463 .55815 L
.37573 .55842 L
.37677 .55864 L
.37799 .55883 L
.37911 .55894 L
Mistroke
.38031 .55901 L
.38162 .55901 L
.38227 .55898 L
.38296 .55893 L
.38419 .55879 L
.38551 .55857 L
.38695 .55823 L
.38955 .55741 L
.39197 .55638 L
.39649 .55378 L
.40134 .55003 L
.40698 .54442 L
.41232 .53791 L
.42232 .52269 L
.44227 .48156 L
.4607 .43291 L
.50002 .30895 L
.53782 .18936 L
.55884 .13385 L
.56803 .11355 L
.57808 .09466 L
.58722 .08075 L
.59696 .06956 L
.60236 .06505 L
.60726 .06204 L
.60962 .06095 L
.61086 .06047 L
.61218 .06004 L
.61333 .05973 L
.61459 .05945 L
.61574 .05925 L
.61682 .05913 L
.61808 .05904 L
.61871 .05902 L
.61941 .05902 L
.62065 .05907 L
.62181 .05918 L
.62248 .05927 L
.62318 .05939 L
.62443 .05965 L
.62578 .06 L
.62725 .06048 L
.62973 .0615 L
.63238 .06287 L
.63715 .06611 L
.64214 .07053 L
.64686 .07566 L
.6557 .08768 L
.67568 .12564 L
.69413 .17199 L
Mistroke
.7335 .29387 L
.77136 .41524 L
.79241 .47323 L
.81166 .51534 L
.82118 .53139 L
.8262 .53847 L
.83155 .5449 L
.8367 .54998 L
.84136 .55361 L
.84361 .55504 L
.84604 .55634 L
.84835 .55734 L
.85045 .55804 L
.85159 .55835 L
.85283 .55861 L
.85414 .55882 L
.85538 .55895 L
.85653 .55901 L
.85776 .55901 L
.85881 .55896 L
.85997 .55884 L
.86063 .55875 L
.86132 .55864 L
.86256 .55838 L
.86535 .55755 L
.86777 .55656 L
.87041 .5552 L
.87569 .55157 L
.88133 .5464 L
.89148 .5338 L
.90173 .51699 L
.91284 .49449 L
.933 .44391 L
.97393 .31646 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .27724 L
.10458 .24319 L
.14415 .21236 L
.18221 .18425 L
.22272 .1565 L
.26171 .13235 L
.30316 .10989 L
.34309 .09177 L
.3815 .07787 L
.40095 .07224 L
.42237 .06717 L
.44268 .06347 L
.45178 .06217 L
.46172 .06101 L
.4671 .06049 L
.4721 .06008 L
.47727 .05972 L
.48196 .05946 L
.48658 .05926 L
.4887 .05919 L
.49093 .05913 L
.49332 .05908 L
.49438 .05906 L
.49552 .05904 L
.49675 .05903 L
.49789 .05902 L
.49859 .05902 L
.49925 .05902 L
.50049 .05902 L
.50163 .05902 L
.50286 .05903 L
.50401 .05904 L
.50508 .05905 L
.50754 .05909 L
.51014 .05916 L
.51268 .05924 L
.51504 .05932 L
.5204 .05958 L
.5293 .06018 L
.53882 .06106 L
.54906 .06228 L
.56016 .06392 L
.58032 .06774 L
.62123 .07874 L
.66064 .0933 L
.69852 .11073 L
.73886 .13269 L
.77769 .15677 L
.81897 .18509 L
Mistroke
.85873 .21455 L
.89697 .24443 L
.93767 .27733 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33309 L
.10458 .35753 L
.14415 .37711 L
.18221 .39161 L
.20178 .39709 L
.21267 .39951 L
.22272 .40133 L
.23293 .40277 L
.23832 .40335 L
.24402 .40384 L
.24641 .40401 L
.24897 .40416 L
.25119 .40427 L
.25361 .40437 L
.25507 .40441 L
.25643 .40445 L
.25773 .40447 L
.2584 .40448 L
.25912 .40449 L
.25983 .4045 L
.26048 .4045 L
.26176 .40451 L
.26293 .40451 L
.26416 .4045 L
.26538 .40448 L
.26607 .40447 L
.26671 .40446 L
.26912 .4044 L
.27131 .40432 L
.27364 .40422 L
.27847 .40394 L
.2838 .40351 L
.29326 .40247 L
.30213 .40116 L
.32232 .39702 L
.34082 .39186 L
.38045 .37677 L
.41855 .35789 L
.45912 .33446 L
.49816 .31018 L
.53966 .28432 L
.57964 .26112 L
.61811 .24191 L
.63759 .23376 L
.65902 .22623 L
.67938 .2206 L
.69843 .21678 L
.70884 .2153 L
.71396 .21473 L
Mistroke
.71872 .2143 L
.72301 .214 L
.72758 .21376 L
.7302 .21366 L
.73148 .21362 L
.73266 .21359 L
.73371 .21357 L
.73487 .21355 L
.73603 .21353 L
.73725 .21353 L
.73856 .21353 L
.73977 .21353 L
.7404 .21354 L
.7411 .21354 L
.74251 .21357 L
.74375 .21359 L
.74508 .21363 L
.74748 .21371 L
.74985 .21381 L
.75235 .21395 L
.7568 .21425 L
.76198 .21471 L
.7668 .21523 L
.77773 .21677 L
.78828 .21871 L
.79823 .22094 L
.81683 .22612 L
.85534 .2407 L
.89632 .26099 L
.93577 .28385 L
.97371 .30745 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`0FOol6001YOol5001VOol003Qoo`800?moobQoo`8001Eoo`80
00Ioo`03001oogoo06Aoo`8000Eoo`03001oogoo06=oo`005goo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool04goo00<007ooOol01goo00<007ooOol0HWoo00<007ooOol01Woo00<007ooOol0HWoo000FOol0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo01=oo`03
001oogoo00Qoo`03001oogoo061oo`03001oogoo00Qoo`03001oogoo065oo`003Woo1P000Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000COol00`00Oomoo`0:Ool00`00Oomoo`1NOol0
0`00Oomoo`0:Ool00`00Oomoo`1POol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol04Goo00<007ooOol037oo00<007ooOol0G7oo00<007ooOol02goo00<007ooOol0
H7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo011oo`03001oogoo00eoo`03001o
ogoo05aoo`03001oogoo00aoo`03001oogoo05moo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`1JOol00`00Oomoo`0>Ool0
0`00Oomoo`1NOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo
0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000@Ool0
0`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0?Ool00`00Oomoo`1NOol001Moo`<000aoo`D0
00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo00ioo`03001o
ogoo015oo`03001oogoo05Qoo`03001oogoo011oo`03001oogoo05eoo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0
G7oo000hOol2003oOolXOol2000?Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol0
0`00Oomoo`1LOol003Qoo`03001oogoo0?moobMoo`03001oogoo00eoo`03001oogoo01Aoo`03001o
ogoo05Eoo`03001oogoo01=oo`03001oogoo05]oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
3Goo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol057oo00<007ooOol0Fgoo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomoo`1COol00`00Oomoo`0EOol0
0`00Oomoo`1JOol003Qoo`800?moobQoo`8000aoo`03001oogoo01Moo`03001oogoo059oo`03001o
ogoo01Moo`03001oogoo05Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol02goo00<007ooOol0
67oo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol0FGoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`1HOol0
03Qoo`800?moobQoo`8000]oo`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03001o
ogoo05Qoo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo1000
1Goo00<007ooOol02Woo00<007ooOol06Woo00<007ooOol0CWoo00<007ooOol06Woo00<007ooOol0
F7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo01]oo`03001o
ogoo04ioo`03001oogoo01]oo`03001oogoo05Moo`005Woo1P000Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo0?moo`Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`09Ool00`00Oomoo`0LOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`1GOol0
01ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<0
07ooOol00Woo0P002Woo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol0
Egoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000ao
o`@000Eoo`03001oogoo00Qoo`03001oogoo01ioo`03001oogoo04]oo`03001oogoo01eoo`03001o
ogoo05Ioo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0NOol00`00Oomoo`1:Ool0
0`00Oomoo`0NOol00`00Oomoo`1FOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00
Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
7Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000OOol3000=Ool40005Ool2003o
Ool?Ool3000=Ool40005Ool20008Ool00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol0
0`00Oomoo`1EOol003Qoo`03001oogoo0?moobMoo`03001oogoo00Moo`03001oogoo021oo`03001o
ogoo04Qoo`03001oogoo021oo`03001oogoo05Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
1goo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol087oo00<007ooOol0EGoo000hOol2003o
OolXOol20007Ool00`00Oomoo`0ROol00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`1DOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo04Ioo`03001o
ogoo029oo`03001oogoo05Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol01Woo00<007ooOol0
8Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol0E7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`06Ool00`00Oomoo`0SOol00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`1COol0
03Qoo`800?moobQoo`8000Ioo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001o
ogoo05=oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol01Goo00<007ooOol097oo00<007ooOol0
A7oo00<007ooOol097oo00<007ooOol0Dgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`05Ool0
0`00Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`1BOol003Qoo`8006Moo`d0
0;=oo`8000Eoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo059oo`00
5goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0HGoo1@003Goo1000SWoo0`001Woo0P00
17oo1@0017oo10001Goo00<007ooOol017oo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol0
9Woo00<007ooOol0DWoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001o
ogoo009oo`03001oogoo05moo`8001Ioo`8008]oo`05001oogooOol00005Ool20005Ool01000Oomo
o`0027oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol09goo00<007ooOol0@Goo00<007oo
Ool09goo00<007ooOol0DGoo000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol0GGoo0P006Woo0P00PGoo1P000Woo00D007ooOomoo`0000eoo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo041oo`03001o
ogoo02Qoo`03001oogoo055oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo
009oo`8005aoo`8001ioo`8008Moo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool20004Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`1AOol001Io
o`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1JOol00`00Oomoo`0POol0
0`00Oomoo`24Ool01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol00goo00<0
07ooOol0:Goo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol0D7oo000FOol01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0F7oo0P0097oo0P00Q7oo00D007oo
Oomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo02Yoo`03
001oogoo03ioo`03001oogoo02Yoo`03001oogoo051oo`005Woo00D007ooOomoo`0000]oo`05001o
ogooOol00004Ool00`00Oomoo`06Ool2001HOol00`00Oomoo`0VOol00`00Oomoo`21Ool01@00Oomo
ogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000=oo`03001oogoo02Yoo`03001o
ogoo03ioo`03001oogoo02Yoo`03001oogoo051oo`005goo0`003Goo0`001Goo10001Goo00<007oo
Ool0EWoo00<007ooOol0:7oo00<007ooOol0PGoo0`003Goo0`001Goo10001Goo00<007ooOol00Woo
00<007ooOol0:goo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol0Cgoo000hOol00`00Oomo
o`1EOol00`00Oomoo`0ZOol00`00Oomoo`2QOol01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<0
07ooOol0;7oo00<007ooOol0Cgoo000hOol00`00Oomoo`0OOol30006Ool20004Ool5000HOol30005
Ool30006Ool3000HOol30006Ool200000goo001oo`02Ool3000JOol30006Ool20005Ool3000QOol5
0019Ool01@00Oomoogoo00007Goo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`0047oo00<0
07ooOol01Goo0`001Woo0P001Goo0`0057oo00<007ooOol00Woo0`001Woo0P001Goo0`008Goo1@00
57oo000hOol2000OOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol0
0003Ool01000Ool000001goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`80009oo`03001oo`00
00=oo`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00008Woo00<007oo
Ool0BGoo0P000Woo00<007ooOol06Woo00D007ooOomoo`0000Eoo`8000Eoo`800003Ool007oo01Io
o`05001oogooOol00005Ool20007Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool01@00Oomoogoo0000
1Goo0P0017oo00D007ooOomoo`0001Aoo`04001oogoo0003Ool00`00Oomoo`03Ool20004Ool01@00
Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<0
07ooOol05goo00D007ooOomoo`00009oo`03001oogoo00Ioo`D001Moo`05001oogooOol0000:Ool2
0003Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uo
o`04001oogoo000MOol01@00Oomoogoo00003Goo0P0067oo00D007ooOomoo`0000]oo`D000moo`03
001oogoo00Eoo`05001oogooOol0000;Ool01@00Oomoogoo000057oo00@007ooOol000=oo`03001o
ogoo00Uoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogoo
Ool0000>Ool00`00Oomoo`0FOol01`00Oomoogoo001oo`0000Uoo`04001oogoo000HOol01@00Oomo
ogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<0
07ooOol0BGoo00@007ooOol001eoo`05001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo
00002goo00@007ooOol0011oo`03001oogoo00Eoo`05001oogooOol0000;Ool01@00Oomoogoo0000
57oo00@007ooOol000=oo`03001oogoo00Uoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qo
o`03001oogoo01ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol01000Oomoogoo0P002goo00<0
07oo000067oo00D007ooOomoo`0000]oo`@001Uoo`05001oogooOol0000<Ool3000SOol00`00Oomo
o`19Ool01000Oomoo`007Goo00D007ooOomoo`0000ioo`8001Moo`05001oogooOol0000<Ool00`00
Ool0000@Ool00`00Oomoo`05Ool01@00Oomoogoo00002goo10005Woo00<007oo00000goo00<007oo
Ool02Woo0`008goo00<007ooOol057oo000hOol2000OOol01@00Oomoogoo00003goo00<007ooOol0
5Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool01000Oomoo`006Goo
00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool3000NOol01@00Oomoogoo
00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0000moo`03001oogoo00Ioo`05
001oogooOol0000;Ool00`00Oomoo`0GOol00`00Ool00003Ool00`00Oomoo`09Ool01@00Oomoogoo
00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Moo`03001oogoo008000eoo`8001Qoo`05001oogooOol0000<Ool01000Oomoo`0067oo00D0
07ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Ool0000NOol01@00Oomo
ogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000=Ool2000?Ool00`00Oomoo`06Ool0
1@00Oomoogoo000037oo00<007ooOol05Woo00<007oo00000goo00<007ooOol02Goo00D007ooOomo
o`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07goo0`003Goo0`006Goo0`003goo00<007oo
Ool05goo0`003Woo100067oo0`003Goo0`008Goo0`00Bgoo00<007oo00007goo0`003Goo100067oo
0`003goo00<007ooOol03Goo00<007ooOol01goo0`003Woo0`005Woo00<007oo00000P003Goo0`00
8Goo0`005Woo000hOol2001<Ool00`00Oomoo`0nOol00`00Oomoo`2GOol2000dOol00`00Oomoo`0f
Ool00`00Oomoo`0bOol00`00Oomoo`1<Ool003Qoo`03001oogoo04Yoo`03001oogoo041oo`03001o
ogoo09Ioo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo00<007oo
Ool0BGoo00<007ooOol0@Woo00<007ooOol0UGoo0P00=7oo00<007ooOol0=Woo00<007ooOol0<Woo
00<007ooOol0C7oo000hOol00`00Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`2DOol00`00Oomo
o`0dOol00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`1;Ool0039oonT0041oonT0011oo`00
>7oo00<007oo000027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol01Goo00@007ooOol004]oo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo00@0
07ooOol004=oo`03001oogoo04aoo`03001oogoo041oo`03001oogoo04eoo`03001oogoo03Aoo`03
001oogoo03Aoo`03001oogoo03Eoo`03001oogoo03=oo`03001oogoo01Aoo`00>7oo0P000Woo00<0
07ooOol0?goo00<007ooOol0CWoo00<007ooOol0?Woo00<007ooOol0CWoo0P00=Woo00<007ooOol0
<Woo00<007ooOol0=Woo00<007ooOol0<goo00<007ooOol057oo000hOol00`00Oomoo`02Ool00`00
Oomoo`0lOol2001BOol00`00Oomoo`0lOol00`00Oomoo`1?Ool00`00Oomoo`0eOol00`00Oomoo`0b
Ool00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`0EOol003Qoo`03001oogoo00=oo`03001o
ogoo03Yoo`03001oogoo05=oo`03001oogoo03Yoo`03001oogoo051oo`03001oogoo03Eoo`03001o
ogoo039oo`03001oogoo03Moo`03001oogoo035oo`03001oogoo01Eoo`00>7oo00<007ooOol017oo
00<007ooOol0>7oo00<007ooOol0EGoo00<007ooOol0>7oo00<007ooOol0DGoo00<007ooOol0=Woo
00<007ooOol0<7oo00<007ooOol0>7oo00<007ooOol0<Goo00<007ooOol05Goo000hOol20006Ool0
0`00Oomoo`0fOol00`00Oomoo`1GOol00`00Oomoo`0fOol00`00Oomoo`1BOol2000gOol00`00Oomo
o`0`Ool00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`0FOol003Qoo`03001oogoo00Ioo`80
03Aoo`8005]oo`03001oogoo03=oo`8005Eoo`03001oogoo03Ioo`03001oogoo031oo`03001oogoo
03Uoo`03001oogoo02moo`03001oogoo01Ioo`00>7oo00<007ooOol027oo00<007ooOol0<7oo00<0
07ooOol0G7oo00<007ooOol0<Goo00<007ooOol0EGoo00<007ooOol0=goo00<007ooOol0;Woo00<0
07ooOol0>Woo00<007ooOol0;goo00<007ooOol05Woo000hOol00`00Oomoo`09Ool00`00Oomoo`0^
Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool00`00Oomoo`1FOol00`00Oomoo`0gOol00`00Oomoo`0^
Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`0GOol003Qoo`8000]oo`03001oogoo02ao
o`03001oogoo061oo`03001oogoo02eoo`03001oogoo05Moo`8003Qoo`03001oogoo02ioo`03001o
ogoo03]oo`03001oogoo02eoo`03001oogoo01Moo`00>7oo00<007ooOol02goo0P00:goo00<007oo
Ool0HWoo00<007ooOol0:goo00<007ooOol0F7oo00<007ooOol0>7oo00<007ooOol0;7oo00<007oo
Ool0?7oo00<007ooOol0;Goo00<007ooOol05goo000hOol00`00Oomoo`0=Ool00`00Oomoo`0WOol0
0`00Oomoo`1TOol2000ZOol00`00Oomoo`1IOol00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00Oomo
o`0lOol00`00Oomoo`0/Ool00`00Oomoo`0HOol003Qoo`8000moo`03001oogoo02Eoo`03001oogoo
06Moo`8002Moo`03001oogoo05Yoo`8003Uoo`03001oogoo02aoo`03001oogoo03eoo`03001oogoo
02]oo`03001oogoo01Qoo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol03goo00<0
07ooOol08Woo0P00K7oo00<007ooOol08goo00<007ooOol0>Woo0`001Woo0P0017oo1@0017oo1000
1Goo00<007ooOol0>Goo00<007ooOol0:Woo00<007ooOol0?Woo00<007ooOol0:goo00<007ooOol0
67oo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001o
ogoo011oo`80021oo`8006moo`80025oo`8003aoo`05001oogooOol00005Ool20005Ool01000Oomo
o`0027oo00<007ooOol00Woo00<007ooOol0>Goo00<007ooOol0:Woo00<007ooOol0?Woo00<007oo
Ool0:Woo00<007ooOol06Goo000FOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol04Woo0P007Goo00<007ooOol0LGoo0P0077oo0`00?Woo00D007ooOomoo`0000eo
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo03Uoo`03001oogoo02Yoo`03001oogoo03mo
o`03001oogoo02Uoo`03001oogoo01Uoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`8001Eoo`8001Uoo`8007Ioo`8001Qoo`80045oo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool2000kOol00`00Oomoo`0YOol00`00Oomoo`0oOol00`00Oomoo`0Y
Ool00`00Oomoo`0IOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomo
o`0FOol3000COol3001jOol3000COol20013Ool01@00Oomoogoo00003goo00<007ooOol00Woo1000
1Goo00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol0@7oo00<007ooOol0:7oo00<007ooOol0
6Woo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol06Goo
00<007ooOol03Woo0P00P7oo0P003goo0P00AGoo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo03Yoo`03001oogoo02Qoo`03001oogoo045oo`03001oogoo02Moo`03
001oogoo01Yoo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2
000KOol4000:Ool20024Ool2000:Ool30017Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Ao
o`03001oogoo00Ioo`8003aoo`03001oogoo02Moo`03001oogoo045oo`03001oogoo02Moo`03001o
ogoo01Yoo`005goo0`003Goo0`001Goo10001Goo00<007ooOol07Woo2P00R7oo2P00Bgoo0`003Goo
0`001Goo10001Goo00<007ooOol0>goo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo
00<007ooOol06goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0kOol00`00Oomoo`0VOol00`00
Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`0KOol003Qoo`03001oogoo0?moobMoo`03001oogoo
03aoo`03001oogoo02Eoo`03001oogoo04=oo`03001oogoo02Eoo`03001oogoo01]oo`00>7oo0P00
ogoo:7oo0P00?Goo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol077oo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0lOol00`00Oomoo`0TOol00`00Oomoo`15Ool00`00
Oomoo`0SOol00`00Oomoo`0LOol003Qoo`03001oogoo0?moobMoo`03001oogoo03eoo`03001oogoo
02=oo`03001oogoo04Eoo`03001oogoo02=oo`03001oogoo01aoo`00>7oo0P00ogoo:7oo0P00?Woo
00<007ooOol08Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol07Goo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`0mOol00`00Oomoo`0ROol00`00Oomoo`17Ool00`00Oomoo`0QOol00`00
Oomoo`0MOol003Qoo`03001oogoo0?moobMoo`03001oogoo03ioo`03001oogoo025oo`03001oogoo
04Moo`03001oogoo025oo`03001oogoo01eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0?Woo
00<007ooOol087oo00<007ooOol0B7oo00<007ooOol087oo00<007ooOol07Woo000hOol2003oOolX
Ool2000oOol00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`0NOol001mo
o`<000Ioo`8000Eoo`@000Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo
03moo`03001oogoo01moo`03001oogoo04Uoo`03001oogoo01ioo`03001oogoo01moo`007Woo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol00005
Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00
Oomoo`0NOol00`00Oomoo`0OOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomo
o`3oOol=Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0@7oo00<007ooOol07Goo
00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol07goo000NOol01@00Oomoogoo000047oo00<0
07ooOol00Woo0P00ogoo3Woo00D007ooOomoo`00011oo`03001oogoo009oo`80045oo`03001oogoo
01eoo`03001oogoo04]oo`03001oogoo01aoo`03001oogoo021oo`007Woo00D007ooOomoo`0000ao
o`@000Eoo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool40005Ool00`00Oomoo`11Ool00`00
Oomoo`0KOol00`00Oomoo`1<Ool00`00Oomoo`0LOol00`00Oomoo`0POol001ioo`05001oogooOol0
000<Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo
00<007ooOol0@Goo00<007ooOol06goo00<007ooOol0CGoo00<007ooOol06goo00<007ooOol087oo
000NOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00ogoo3Woo00D007ooOomoo`0000aoo`03
001oogoo00Ioo`80049oo`03001oogoo01]oo`03001oogoo04eoo`03001oogoo01Yoo`03001oogoo
025oo`007goo0`003Goo10001Goo00<007ooOol0ogoo3Woo0`003Goo10001Goo00<007ooOol0@Woo
00<007ooOol06Goo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol08Goo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`12Ool00`00Oomoo`0IOol00`00Oomoo`1?Ool00`00Oomoo`0IOol00`00
Oomoo`0QOol003Qoo`03001oogoo0?moobMoo`03001oogoo04=oo`03001oogoo01Moo`03001oogoo
051oo`03001oogoo01Qoo`03001oogoo029oo`00>7oo0P00ogoo:7oo0P00A7oo00<007ooOol05goo
00<007ooOol0DGoo00<007ooOol05goo00<007ooOol08Woo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`13Ool00`00Oomoo`0FOol00`00Oomoo`1BOol00`00Oomoo`0GOol00`00Oomoo`0ROol003Qo
o`03001oogoo0?moobMoo`03001oogoo04Aoo`03001oogoo01Aoo`03001oogoo05Aoo`03001oogoo
01Eoo`03001oogoo02=oo`00>7oo0P00ogoo:7oo0P00AGoo00<007ooOol057oo00<007ooOol0E7oo
00<007ooOol057oo00<007ooOol097oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`14Ool00`00
Oomoo`0COol00`00Oomoo`1EOol00`00Oomoo`0DOol00`00Oomoo`0TOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo04Eoo`03001oogoo019oo`03001oogoo05Ioo`03001oogoo019oo`03001oogoo
02Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0AWoo00<007ooOol047oo00<007ooOol0F7oo
00<007ooOol04Goo00<007ooOol09Goo000hOol2003oOolXOol20018Ool00`00Oomoo`0?Ool00`00
Oomoo`1IOol00`00Oomoo`0?Ool00`00Oomoo`0VOol001Moo`<000Ioo`8000Ioo`03001oogoo00Ao
o`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo
04Moo`03001oogoo00ioo`03001oogoo05]oo`03001oogoo00ioo`03001oogoo02Ioo`005Woo00D0
07ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05
001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`18Ool00`00
Oomoo`0=Ool00`00Oomoo`1KOol00`00Oomoo`0=Ool00`00Oomoo`0WOol001Ioo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol0B7oo00<007ooOol037oo00<007ooOol0GGoo
00<007ooOol037oo00<007ooOol09goo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80
04Yoo`03001oogoo00Yoo`03001oogoo05moo`03001oogoo00Yoo`03001oogoo02Qoo`005Woo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000>
Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`1:Ool00`00Oomoo`08Ool00`00Oomoo`1POol00`00
Oomoo`08Ool2000[Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0
0`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool0Bgoo00<007ooOol01Woo00<007ooOol0HWoo0P001goo00<007ooOol0:goo000FOol01@00Oomo
ogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;
Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00CGoo0`000goo0P00Igoo0P000goo0P00;Woo
000GOol3000<Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool3000<Ool50004Ool40005Ool00`00
Oomoo`1>Ool4001ZOol4000`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolX
Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo
00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`80
0?5oo`00;goo1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo000aOol00`00Oomo
o`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Ao
o`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo
000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo
0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3003oOolWOol3003iOol00?mo
oomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo0`00ogoo1goo0`0000Aoo`000000
01Uoo`<007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000Uoo`05001oogooOol0003oOol7Ool01@00
Oomoogoo00002Goo1P0037oo00<007ooOol0Lgoo002FOol01@00Oomoogoo000077oo00<007ooOol0
ogoo1Goo00D007ooOomoo`0001Qoo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000eoo`03001o
ogoo0?moo`Eoo`05001oogooOol00009Ool60009Ool01000Oomoo`00MGoo002FOol01@00Oomoogoo
00006Woo0P00ogoo27oo00D007ooOomoo`0001Uoo`03001oo`0007Eoo`00UGoo1@007Goo00<007oo
Ool0ogoo17oo1@006Woo00<007oo0000MGoo002cOol01@00Oomoogoo0000ogoo9Woo0P00MGoo002d
Ool3003oOolXOol00`00Oomoo`1cOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomF
Ool00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3o
OolWOol00`00Oomoo`3gOol002Ioo`H000Eoo`03001oogoo0?mooaaoo`H000Eoo`03001oogoo0?Mo
o`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`04
Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03
001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo
8Goo00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomo
o`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03
001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000h
Ool00`00Oomoo`1VOol<002dOol00`00Oomoo`3`Ool003Qoo`8005eoo`X000aoo`/00:Uoo`800?5o
o`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0Egoo1@008Goo1000Q7oo
0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo0000
1Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0Dgoo1000:Woo0`00P7oo00D0
07ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`003Woo
1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo055oo`80
035oo`<007Eoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2001@Ool2
000fOol3001jOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00lGoo000F
Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0C7oo0`00>goo0`00Mgoo
00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomo
o`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo04Uoo`<0045oo`<007Aoo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00Agoo0`00Agoo0`00LGoo00D007oo
Oomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Ao
o`@000Eoo`03001oogoo04Aoo`8004eoo`80071oo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1o
o`00>7oo00<007ooOol0@Goo0`00DGoo0P00Sgoo00<007ooOol0l7oo000hOol00`00Oomoo`0oOol2
001FOol2002=Ool00`00Oomoo`3`Ool003Qoo`8003ioo`8005Yoo`8008]oo`800?5oo`00>7oo00<0
07ooOol0>goo0P00GWoo0P00RGoo00<007ooOol0l7oo000hOol00`00Oomoo`0iOol2001ROol20027
Ool00`00Oomoo`3`Ool003Qoo`8003Qoo`8006Ioo`8008Eoo`800?5oo`00>7oo00<007ooOol0=Goo
0P00JWoo0P00Pgoo00<007ooOol0l7oo000hOol00`00Oomoo`0cOol2001^Ool20021Ool00`00Oomo
o`3`Ool003Qoo`03001oogoo039oo`03001oogoo071oo`03001oogoo07ioo`03001oogoo0?1oo`00
>7oo0P00<Goo0P00M7oo0P00OWoo0P00lGoo000OOol30006Ool20005Ool40005Ool00`00Oomoo`0_
Ool00`00Oomoo`1fOol00`00Oomoo`1ROol30006Ool20005Ool40005Ool00`00Oomoo`3`Ool001io
o`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool2001jOol2001QOol0
1@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0l7oo000FOol60002Ool01@00
Oomoogoo000047oo00<007ooOol00Woo0P00;Goo00<007ooOol0O7oo00<007ooOol0EWoo1P000Woo
00D007ooOomoo`00011oo`03001oogoo009oo`800?5oo`007Woo00D007ooOomoo`00011oo`03001o
ogoo009oo`03001oogoo02Yoo`80081oo`8005ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`0YOol00`00Oomoo`22
Ool00`00Oomoo`1KOol01@00Oomoogoo000037oo10001Goo00<007ooOol0l7oo000NOol01@00Oomo
ogoo000037oo00<007ooOol01Woo00<007ooOol09goo0P00QWoo00<007ooOol0FWoo00D007ooOomo
o`0000aoo`03001oogoo00Ioo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo
00Ioo`8002Moo`03001oogoo08Moo`8005Yoo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003a
Ool001moo`<000eoo`@000Eoo`03001oogoo02Aoo`8008aoo`03001oogoo05Qoo`<000eoo`@000Eo
o`03001oogoo0?1oo`00>7oo00<007ooOol08goo00<007ooOol0SGoo00<007ooOol0L7oo00<007oo
Ool0l7oo000hOol00`00Oomoo`0QOol2002AOol00`00Oomoo`1_Ool00`00Oomoo`3`Ool003Qoo`80
025oo`03001oogoo099oo`8006moo`800?5oo`00>7oo00<007ooOol07goo00<007ooOol0UGoo00<0
07ooOol0K7oo00<007ooOol0l7oo000hOol00`00Oomoo`0MOol2002IOol2001/Ool00`00Oomoo`3`
Ool003Qoo`8001eoo`03001oogoo09]oo`03001oogoo06Uoo`800?5oo`00>7oo00<007ooOol06goo
00<007ooOol0WGoo0P00JGoo00<007ooOol0l7oo000hOol00`00Oomoo`0JOol00`00Oomoo`2POol0
0`00Oomoo`1VOol00`00Oomoo`3`Ool003Qoo`03001oogoo01Qoo`800:Aoo`8006Ioo`03001oogoo
09eoo``004Moo`00>7oo0P0067oo00<007ooOol0YWoo00<007ooOol0Hgoo0P00V7oo1P0037oo1`00
@7oo000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`0FOol00`00Oomoo`2XOol00`00
Oomoo`11Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`2COol4000IOol4000lOol001Io
o`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol057oo
0P00[7oo0P00@7oo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`2?Ool4000QOol3000iOol000ioo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool2000DOol00`00Oomoo`2^Ool00`00Oomoo`0eOol60002Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo0P00SGoo0`00:7oo0`00=Woo000FOol01@00Oomo
ogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol0/7oo00<0
07ooOol0?7oo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo08Yo
o`8002ioo`<003=oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo
015oo`03001oogoo0;9oo`03001oogoo03]oo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005
Ool00`00Oomoo`28Ool2000cOol2000aOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`0?Ool2002fOol2000kOol01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol0QWoo0P00=goo0P00;goo000FOol01@00Oomoogoo00002goo
00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000moo`03001oogoo0;Qoo`03001oogoo03Qoo`05
001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00QGoo0P00>goo0P00;Goo
000GOol3000=Ool30005Ool40005Ool00`00Oomoo`0=Ool00`00Oomoo`2jOol00`00Oomoo`0hOol3
000=Ool30005Ool40005Ool00`00Oomoo`21Ool3000oOol2000[Ool003Qoo`03001oogoo00aoo`03
001oogoo011oo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<0
01Yoo`<000Ioo`8000Eoo`<001Aoo`03001oogoo00Yoo`D004Uoo`03001oogoo01moo`<000Ioo`80
00Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Eoo`<000Eoo`<001Uoo`<000Ioo`8000Eoo`<0
00moo`80011oo`D001Aoo`00>7oo0P002goo0P004Woo00D007ooOomoo`0000Eoo`8000Eoo`04001o
ogoo000GOol01@00Oomoogoo00001Goo0P001goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`80
00Aoo`05001oogooOol0000HOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Aoo`80
00aoo`03001oogoo04Uoo`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`005goo00D0
07ooOomoo`0000Eoo`8000Moo`03001oogoo01Ioo`05001oogooOol00002Ool200000goo00000004
Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000@Ool2000@
Ool00`00Oomoo`0DOol003Qoo`03001oogoo00Uoo`03001oogoo019oo`05001oogooOol0000=Ool0
0`00Oomoo`0GOol01@00Oomoogoo00002goo1@005goo00D007ooOomoo`0000]oo`05001oogooOol0
000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Ioo`03001oogoo00Uoo`03001oogoo04Uo
o`03001oogoo01ioo`05001oogooOol0000=Ool00`00Oomoo`0GOol01@00Oomoogoo00002goo1@00
5goo00@007ooOomoo`<000Uoo`05001oogooOol0000GOol01@00Oomoogoo00002goo00D007ooOomo
o`00019oo`8000ioo`03001oogoo01Aoo`00>7oo00<007ooOol027oo00<007ooOol04goo00D007oo
Oomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000Oomoo`0067oo00D007ooOomo
o`0000]oo`05001oogooOol0000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`03001o
ogoo00Qoo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000>Ool00`00Oomoo`0FOol0
1@00Oomoogoo00002goo00@007ooOol001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00005goo
00D007ooOomoo`0000]oo`05001oogooOol0000DOol2000<Ool00`00Oomoo`0DOol003Qoo`03001o
ogoo00Moo`03001oogoo01Aoo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo0000
37oo00<007oo000067oo00D007ooOomoo`0000]oo`@001Uoo`05001oogooOol0000<Ool3000IOol0
0`00Oomoo`07Ool00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003goo00<007ooOol0
5Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`03001oo`00008000]oo`@001Qoo`05001oogoo
Ool0000<Ool3000GOol00`00Oomoo`09Ool00`00Oomoo`0DOol003Qoo`8000Ioo`8001Moo`05001o
ogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomo
o`0000]oo`03001oogoo01Yoo`05001oogooOol0000;Ool01@00Oomoogoo00006Goo0P001goo00<0
07ooOol0BGoo0P007goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool0
0`00Ool0000HOol20002Ool00`00Oomoo`09Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D0
07ooOomoo`0001Moo`8000Uoo`03001oogoo01Aoo`00>7oo00<007ooOol017oo00<007ooOol05goo
00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00003Goo0P0067oo00D007oo
Oomoo`0000aoo`03001oogoo01Uoo`05001oogooOol0000;Ool01@00Oomoogoo00006goo00<007oo
Ool017oo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000]oo`05001oogooOol0000G
Ool01@00Oomoogoo00003Goo0P005goo0P000goo00<007ooOol02Woo00<007ooOol067oo00D007oo
Oomoo`0000]oo`05001oogooOol0000IOol20007Ool00`00Oomoo`0DOol003Qoo`03001oogoo00=o
o`03001oogoo01Uoo`<000eoo`<001Uoo`<000moo`03001oogoo01Moo`<000ioo`<001Uoo`<000eo
o`<001eoo`04001oogooOol3001;Ool00`00Oomoo`0OOol3000=Ool3000IOol3000?Ool00`00Oomo
o`0COol20002Ool3000>Ool3000HOol3000=Ool3000LOol00`00Oomoo`02Ool3000FOol003Qoo`04
001oogooOol2003BOol2001?Ool00`00Oomoo`1bOol00`00Oomoo`1NOol2000KOol003Qoo`800003
Ool007oo0=Eoo`03001oogoo04aoo`80075oo`8006=oo`03001oogoo01Qoo`00>7oo00<007oo0000
f7oo00<007ooOol0Bgoo00<007ooOol0Kgoo00<007ooOol0I7oo0P0067oo000hOol2003JOol00`00
Oomoo`1:Ool00`00Oomoo`1]Ool2001YOol00`00Oomoo`0EOol0039oonT0041oonT0011oo`00>7oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol0BGoo00<007oo000027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol01goo0P002Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol057oo000hOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0YOol0
0`00Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomoo`19Ool00`00Oomoo`02000WOol00`00Oomoo`0Y
Ool00`00Oomoo`0@Ool2000GOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0DOol003Qo
o`03001oogoo0?moobMoo`03001oogoo009oo`03001oogoo065oo`8008Qoo`00>7oo0P00ogoo:7oo
0P0017oo0P00H7oo00<007ooOol0R7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`05Ool00`00
Oomoo`1KOol2002;Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Ioo`8005Uoo`8008eoo`00
>7oo0P00ogoo:7oo0P002Goo0P00EGoo0P00Sgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0:
Ool2001BOol00`00Oomoo`2?Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00aoo`03001oogoo
04eoo`80099oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol03Goo0P00Bgoo0P00U7oo000hOol2
003oOolXOol2000@Ool20018Ool00`00Oomoo`2DOol003Qoo`03001oogoo0?moobMoo`03001oogoo
015oo`8004Aoo`8009Moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol04goo0P00@7oo0P00VGoo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0EOol2000kOol3002KOol003Qoo`800?moobQoo`80
01Qoo`8003Moo`8009ioo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo1Woo
0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol06Goo0P00<goo0P00X7oo000FOol01@00Oomo
ogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001o
ogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol06goo0`00;Goo
0`00XWoo000FOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P00ogoo1Woo
00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8001moo`<002Moo`<00:Eoo`00
5Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05
001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0QOol2000ROol3002X
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol08goo0`007Goo0P00Zgoo000FOol0
1@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007oo
Oomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo02Ioo`D001Eoo`<00:eoo`00
5Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00
Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8002aooaD00;1oo`005goo0`00
3Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo0`003Goo0`001Goo10001Goo00<007ooOol0l7oo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00
ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool001moo`<000Ioo`8000Eo
o`@000Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo0?1oo`007Woo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol00005
Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool00`00Oomo
o`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomo
ogoo000047oo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`00011oo`03001oogoo
009oo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?moo`eoo`05
001oogooOol0000<Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00Oomo
o`06Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0l7oo
000NOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00ogoo3Woo00D007ooOomoo`0000aoo`03
001oogoo00Ioo`800?5oo`007goo0`003Goo10001Goo00<007ooOol0ogoo3Woo0`003Goo10001Goo
00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`80
0?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool0
0`00Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3`Ool001Io
o`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0l7oo
000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?1oo`005Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomo
o`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo
00<007ooOol0l7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<0
07ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
0?1oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomo
o`3oOol5Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo
0?1oo`005goo0`0037oo1@0017oo10001Goo0P00ogoo1goo0`0037oo1@0017oo10001Goo0P00lGoo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo
000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol002moo`D000Aoo`03001o
ogoo0?mooaioo`D000Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo
00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00
Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`80
0?5oo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00
Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00nGoo
003oOoooOomFOol00?mooomooeIoo`00UGoo0`0000Aoo`00000001Qoo`D00?moo`Eoo`<00004Ool0
0000000GOol5001dOol009Ioo`05001oogooOol00009Ool6000<Ool00`00Oomoo`3oOol6Ool01@00
Oomoogoo00002Goo1P002Woo00@007ooOol007Aoo`00UWoo00D007ooOomoo`0001]oo`03001oogoo
0?moo`Ioo`05001oogooOol0000JOol00`00Oomoo`1dOol009Ioo`05001oogooOol00009Ool6000<
Ool00`00Oomoo`3oOol6Ool01@00Oomoogoo00002Goo1P0037oo00<007ooOol0Lgoo002FOol01@00
Oomoogoo00006goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001aoo`03001oogoo079oo`00UGoo
1@0077oo00<007ooOol0ogoo1Goo1@007Goo00<007ooOol0LWoo002fOol00`00Oomoo`3oOolSOol0
1@00Oomoogoo0000M7oo002dOol3003oOolVOol3001eOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00001\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .29098 L
.08255 .28247 L
.10458 .27436 L
.12507 .26829 L
.14415 .26412 L
.14918 .26329 L
.15465 .26251 L
.15946 .26193 L
.16457 .26144 L
.16917 .2611 L
.17178 .26095 L
.17423 .26084 L
.17538 .2608 L
.17647 .26076 L
.17746 .26074 L
.17852 .26071 L
.17967 .2607 L
.18073 .26068 L
.182 .26068 L
.18314 .26068 L
.18435 .26068 L
.18547 .2607 L
.1867 .26072 L
.18802 .26075 L
.19071 .26083 L
.19317 .26094 L
.1979 .26123 L
.20239 .26161 L
.21236 .26277 L
.22321 .26454 L
.24299 .26907 L
.26399 .27555 L
.30174 .29059 L
.34195 .30934 L
.38063 .32738 L
.40028 .33567 L
.42177 .34358 L
.44253 .34975 L
.4614 .35387 L
.47149 .35545 L
.47611 .35601 L
.48101 .35651 L
.4835 .35671 L
.48624 .35691 L
.48876 .35706 L
.49106 .35717 L
.49378 .35727 L
.49527 .3573 L
.49596 .35732 L
Mistroke
.49669 .35733 L
.498 .35735 L
.49921 .35736 L
.49996 .35736 L
.50065 .35736 L
.50196 .35735 L
.50313 .35733 L
.50438 .35731 L
.50556 .35728 L
.50663 .35725 L
.50926 .35716 L
.51175 .35703 L
.5167 .3567 L
.52208 .35621 L
.53169 .355 L
.54056 .35352 L
.55926 .34928 L
.57988 .34302 L
.62014 .32703 L
.65888 .30895 L
.70007 .28979 L
.72063 .28122 L
.73974 .27428 L
.75939 .26844 L
.77791 .26433 L
.78775 .26275 L
.79293 .26209 L
.7984 .26153 L
.80302 .26117 L
.80546 .26102 L
.80809 .26088 L
.8105 .26079 L
.8127 .26073 L
.81375 .26071 L
.81491 .26069 L
.81599 .26068 L
.817 .26068 L
.81818 .26068 L
.81941 .26069 L
.82047 .2607 L
.82163 .26072 L
.82287 .26075 L
.82421 .26078 L
.82661 .26087 L
.82905 .26099 L
.83134 .26113 L
.83564 .26146 L
.84078 .26196 L
.84552 .26253 L
.85624 .26419 L
Mistroke
.87498 .2683 L
.89561 .27443 L
.93591 .29026 L
.97471 .30831 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .26242 L
.08255 .24219 L
.0932 .2333 L
.10458 .22545 L
.11009 .22231 L
.11531 .21977 L
.12038 .21769 L
.12507 .21614 L
.12951 .215 L
.13178 .21454 L
.13422 .21415 L
.13549 .21398 L
.13666 .21384 L
.13784 .21373 L
.13895 .21365 L
.14022 .21358 L
.1409 .21356 L
.14161 .21354 L
.1423 .21353 L
.14295 .21353 L
.14415 .21354 L
.14531 .21358 L
.14656 .21364 L
.14773 .21372 L
.14881 .21382 L
.15143 .21414 L
.15392 .21454 L
.15886 .21565 L
.16423 .2173 L
.17383 .22139 L
.1827 .22642 L
.20137 .2406 L
.22197 .261 L
.26217 .30935 L
.30086 .35597 L
.32051 .37571 L
.3309 .38443 L
.342 .39217 L
.35275 .39797 L
.35784 .4001 L
.36253 .4017 L
.36724 .40295 L
.36972 .40346 L
.37235 .40389 L
.37463 .40418 L
.37573 .40428 L
.37677 .40436 L
.37799 .40444 L
.37911 .40448 L
Mistroke
.38031 .40451 L
.38162 .4045 L
.38227 .40449 L
.38296 .40448 L
.38419 .40442 L
.38551 .40434 L
.38695 .40421 L
.38955 .40389 L
.39197 .4035 L
.39649 .40251 L
.40134 .40108 L
.40698 .39893 L
.41232 .39645 L
.42232 .39063 L
.44227 .37492 L
.4607 .35634 L
.50002 .30899 L
.53782 .26331 L
.55884 .24211 L
.56803 .23435 L
.57808 .22714 L
.58722 .22183 L
.59696 .21755 L
.60236 .21583 L
.60726 .21468 L
.60962 .21426 L
.61086 .21408 L
.61218 .21392 L
.61333 .2138 L
.61459 .21369 L
.61574 .21362 L
.61682 .21357 L
.61808 .21353 L
.61871 .21353 L
.61941 .21353 L
.62065 .21355 L
.62181 .21359 L
.62248 .21362 L
.62318 .21367 L
.62443 .21377 L
.62578 .2139 L
.62725 .21408 L
.62973 .21447 L
.63238 .215 L
.63715 .21624 L
.64214 .21792 L
.64686 .21988 L
.6557 .22447 L
.67568 .23897 L
.69413 .25668 L
Mistroke
.7335 .30323 L
.77136 .34959 L
.79241 .37174 L
.81166 .38782 L
.82118 .39396 L
.8262 .39666 L
.83155 .39912 L
.8367 .40105 L
.84136 .40244 L
.84361 .40299 L
.84604 .40349 L
.84835 .40387 L
.85045 .40414 L
.85159 .40425 L
.85283 .40435 L
.85414 .40443 L
.85538 .40448 L
.85653 .40451 L
.85776 .40451 L
.85881 .40449 L
.85997 .40444 L
.86063 .40441 L
.86132 .40436 L
.86256 .40426 L
.86535 .40395 L
.86777 .40357 L
.87041 .40305 L
.87569 .40166 L
.88133 .39969 L
.89148 .39488 L
.90173 .38845 L
.91284 .37986 L
.933 .36054 L
.97393 .31186 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .27402 L
.10458 .23652 L
.14415 .20257 L
.18221 .17161 L
.22272 .14105 L
.26171 .11445 L
.30316 .08971 L
.34309 .06975 L
.3815 .05445 L
.40095 .04825 L
.42237 .04266 L
.44268 .03859 L
.45178 .03716 L
.46172 .03587 L
.4671 .0353 L
.4721 .03485 L
.47727 .03445 L
.48196 .03417 L
.48658 .03395 L
.4887 .03387 L
.49093 .0338 L
.49332 .03375 L
.49438 .03373 L
.49552 .03371 L
.49675 .0337 L
.49789 .03369 L
.49859 .03368 L
.49925 .03368 L
.50049 .03368 L
.50163 .03368 L
.50286 .03369 L
.50401 .0337 L
.50508 .03372 L
.50754 .03377 L
.51014 .03383 L
.51268 .03392 L
.51504 .03402 L
.5204 .0343 L
.5293 .03497 L
.53882 .03593 L
.54906 .03728 L
.56016 .03909 L
.58032 .04329 L
.62123 .05541 L
.66064 .07144 L
.69852 .09064 L
.73886 .11482 L
.77769 .14134 L
.81897 .17253 L
Mistroke
.85873 .20498 L
.89697 .23788 L
.93767 .27412 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35481 L
.10458 .40129 L
.14415 .43855 L
.18221 .46612 L
.20178 .47655 L
.21267 .48115 L
.22272 .48462 L
.23293 .48734 L
.23832 .48846 L
.24402 .48939 L
.24641 .4897 L
.24897 .48999 L
.25119 .4902 L
.25361 .49038 L
.25507 .49047 L
.25643 .49053 L
.25773 .49058 L
.2584 .4906 L
.25912 .49062 L
.25983 .49064 L
.26048 .49064 L
.26176 .49065 L
.26293 .49065 L
.26416 .49063 L
.26538 .4906 L
.26607 .49058 L
.26671 .49056 L
.26912 .49045 L
.27131 .4903 L
.27364 .49011 L
.27847 .48957 L
.2838 .48876 L
.29326 .48678 L
.30213 .48429 L
.32232 .47642 L
.34082 .46659 L
.38045 .43788 L
.41855 .40199 L
.45912 .35742 L
.49816 .31122 L
.53966 .26203 L
.57964 .21791 L
.61811 .18138 L
.63759 .16587 L
.65902 .15154 L
.67938 .14084 L
.69843 .13357 L
.70884 .13076 L
.71396 .12968 L
Mistroke
.71872 .12886 L
.72301 .12828 L
.72758 .12782 L
.7302 .12763 L
.73148 .12755 L
.73266 .1275 L
.73371 .12746 L
.73487 .12742 L
.73603 .1274 L
.73725 .12738 L
.73856 .12738 L
.73977 .12739 L
.7404 .1274 L
.7411 .12742 L
.74251 .12746 L
.74375 .12751 L
.74508 .12757 L
.74748 .12773 L
.74985 .12793 L
.75235 .12818 L
.7568 .12876 L
.76198 .12963 L
.7668 .13063 L
.77773 .13356 L
.78828 .13725 L
.79823 .14149 L
.81683 .15134 L
.85534 .17907 L
.89632 .21767 L
.93577 .26115 L
.97371 .30604 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo0P00
1Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo
10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00
Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Io
o`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`007goo0`001Woo0P001Goo
10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00
Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eo
o`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`005Woo1P000Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo0?moo`Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomo
ogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomoogoo000037oo10001Goo00<007oo
Ool0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool0
0`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool0
1@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0l7oo000OOol3000=Ool40005Ool2003o
Ool?Ool3000=Ool40005Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`8001Eoo`T006Ioo`T006Aoo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo
1Woo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol04Woo0P002Goo1000H7oo0P002Goo0`00
HGoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001o
ogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<0
07ooOol03goo0`003goo00<007ooOol0FWoo0`003Woo0P00Ggoo000>Ool60002Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0o7oo1P000Woo00D007ooOomoo`00
00eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo015oo`8005Qoo`80
01=oo`03001oogoo05aoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000=Ool2000F
Ool00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`1KOol001Ioo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo
10001Goo00<007ooOol02goo00<007ooOol05goo00<007ooOol0DWoo00<007ooOol05Woo00<007oo
Ool0FWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Yoo`03
001oogoo01Uoo`03001oogoo051oo`03001oogoo01Qoo`03001oogoo05Uoo`005Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000]oo`03001oogoo01Yoo`03001oogoo04ioo`03
001oogoo01Yoo`03001oogoo05Qoo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo
0`003Goo0`001Goo10001Goo00<007ooOol02Goo00<007ooOol077oo00<007ooOol0C7oo00<007oo
Ool077oo00<007ooOol0Egoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`08Ool00`00Oomoo`0N
Ool00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`1FOol003Qoo`03001oogoo01moo`<000Io
o`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<001Yoo`<000Ioo`8000Eo
o`<0025oo`D004Uoo`03001oogoo00Moo`03001oogoo01Eoo`<000Ioo`<000=oo`D001Qoo`<000Io
o`8000Ioo`<001Ioo`03001oo`00008000Ioo`8000Eoo`<000ioo`03001oogoo00Qoo`<000Ioo`80
00Eoo`<0025oo`D001Aoo`00>7oo0P0067oo5P000Woo00@007ooOol001Moo`05001oogooOol00005
Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Qoo`05
001oogooOol00002OolG000IOol00`00Oomoo`19Ool20007Ool00`00Oomoo`0EOol01@00Oomoogoo
00001Goo0P0000=oo`00Ool00Woo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00
Oomoo`0DOol00`00Ool00003Ool00`00Oomoo`03Ool20004Ool01@00Oomoogoo00003Goo00<007oo
Ool01goo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qo
o`03001oogoo01=oo`@000Moo`05001oogooOol0000:Ool4000IOol01@00Oomoogoo00002goo1@00
5goo00D007ooOomoo`0000]oo`05001oogooOol0000HOol00`00Oomoo`040009Ool01@00Oomoogoo
00002Goo0`005Woo00<007ooOol0BGoo00<007ooOol01Woo00<007ooOol05Goo00D007ooOomoo`00
00Qoo`03001oogoo009oo`03001oogoo01Moo`05001oogooOol0000;Ool5000EOol00`00Ool00003
Ool00`00Oomoo`09Ool01@00Oomoogoo00003Woo00<007ooOol01Woo00D007ooOomoo`0000]oo`05
001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo015oo`8000]oo`05001oogooOol0
000=Ool4000FOol01@00Oomoogoo00002goo00@007ooOol001Qoo`05001oogooOol0000;Ool01@00
Oomoogoo000067oo0`0000=oo`00Ool02Woo00D007ooOomoo`0000aoo`<001=oo`03001oogoo04Uo
o`03001oogoo00Eoo`03001oogoo01Ioo`05001oogooOol00009Ool00`00Oomoo`02Ool00`00Oomo
o`0FOol01@00Oomoogoo00002goo00@007ooOol001Eoo`04001oogoo0003Ool00`00Oomoo`09Ool0
1@00Oomoogoo00003goo00<007ooOol01Goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol0
0`00Oomoo`0DOol003Qoo`03001oogoo00moo`8000eoo`05001oogooOol0000?Ool00`00Ool00002
000COol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`0000]oo`@001Moo`<000=o
o`03001oogoo00Yoo`<0011oo`<0011oo`03001oogoo04Uoo`03001oogoo00Aoo`03001oogoo01Mo
o`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<0
07oo000057oo00D007ooOomoo`0000=oo`03001oogoo00Uoo`@0015oo`03001oogoo00Aoo`05001o
ogooOol0000<Ool3000SOol00`00Oomoo`0DOol003Qoo`8000eoo`<000moo`05001oogooOol0000?
Ool00`00Oomoo`02Ool2000AOol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`00
00]oo`03001oogoo01Aoo`@0009oo`05001oogooOol0000;Ool01@00Oomoogoo00004Woo0`003Goo
00<007ooOol0BGoo0P0017oo00<007ooOol067oo00D007ooOomoo`0000]oo`05001oogooOol0000G
Ool01@00Oomoogoo000037oo00<007oo00004goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03
001oogoo01=oo`03001oogoo00=oo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007oo
Ool057oo000hOol00`00Oomoo`0:Ool2000BOol01@00Oomoogoo00002goo00D007ooOomoo`0000Io
o`8000moo`05001oogooOol0000=Ool2000HOol01@00Oomoogoo000037oo00<007ooOol04Goo0P00
1Woo00D007ooOomoo`0000]oo`05001oogooOol0000EOol3000:Ool00`00Oomoo`19Ool00`00Oomo
o`02Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo0P000Woo00<007ooOol05Goo00D007ooOomo
o`0000eoo`80019oo`03001oogoo00=oo`05001oogooOol0000<Ool00`00Oomoo`0COol00`00Oomo
o`02Ool01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007oo
Ool01goo0`005Goo0`003Goo0`002Goo0P003Woo0`003goo00<007ooOol05goo0`003Woo0`003Woo
0P002Goo0`003Goo0`006Goo0P001Woo0`00Bgoo00D007ooOomoo`0001eoo`<000eoo`<001Uoo`<0
00moo`03001oogoo00moo`03001oogoo00Eoo`<000ioo`<001=oo`03001oogoo009oo`<000eoo`<0
025oo`<001Ioo`00>7oo0P001Woo0P00=Woo0P00F7oo0P00>Goo0P00DWoo0P000Woo00<007ooOol0
;7oo00<007ooOol0?7oo00<007ooOol0;Goo00<007ooOol0CWoo000hOol00`00Oomoo`03Ool2000j
Ool3001COol2000mOol2001@Ool01000Oomoo`00<7oo00<007ooOol0>Woo00<007ooOol0;goo00<0
07ooOol0CGoo000hOol00`00Oomoo`03000oOol2001?Ool20011Ool00`00Oomoo`1=Ool00`00Ool0
000bOol00`00Oomoo`0hOol00`00Oomoo`0aOol00`00Oomoo`1<Ool003Qoo`<004Aoo`<004Yoo`80
04Aoo`8004eoo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00<Wooj@00
@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool2000:Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool30008Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool20009Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`0DOol003Qoo`03001oogoo04]oo`<003aoo`<009Uoo`03001oogoo03Eo
o`03001oogoo039oo`03001oogoo03Moo`03001oogoo035oo`03001oogoo01Eoo`00>7oo0P00Cgoo
0P00>7oo0P00W7oo0P00=goo00<007ooOol0<7oo00<007ooOol0>Goo00<007ooOol0;goo00<007oo
Ool05Woo000hOol00`00Oomoo`1@Ool2000dOol2002NOol00`00Oomoo`0gOol00`00Oomoo`0^Ool0
0`00Oomoo`0kOol00`00Oomoo`0]Ool00`00Oomoo`0GOol003Qoo`03001oogoo059oo`80031oo`80
0:1oo`03001oogoo03Qoo`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo
01Qoo`00>7oo00<007ooOol0E7oo0P00:goo0`00XWoo00<007ooOol0>Goo00<007ooOol0:Woo00<0
07ooOol0?Woo00<007ooOol0:Woo00<007ooOol06Goo000hOol2001GOol3000VOol2002UOol2000j
Ool00`00Oomoo`0ZOol00`00Oomoo`0oOol00`00Oomoo`0YOol00`00Oomoo`0IOol003Qoo`03001o
ogoo05Uoo`@001moo`<00:Moo`03001oogoo03Yoo`03001oogoo02Qoo`03001oogoo045oo`03001o
ogoo02Moo`03001oogoo01Yoo`00>7oo00<007ooOol0GGoo10005Woo1@00ZWoo00<007ooOol0>goo
00<007ooOol09Woo00<007ooOol0@goo00<007ooOol09Goo00<007ooOol06goo000hOol00`00Oomo
o`1QOol4000=Ool5002_Ool00`00Oomoo`0lOol00`00Oomoo`0TOol00`00Oomoo`15Ool00`00Oomo
o`0SOol00`00Oomoo`0LOol003Qoo`8006Ioo`d00;Aoo`8003ioo`8002=oo`03001oogoo04Moo`03
001oogoo025oo`03001oogoo01eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0?goo00<007oo
Ool07goo00<007ooOol0BGoo00<007ooOol07goo00<007ooOol07Woo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`10Ool00`00Oomoo`0MOol00`00Oomoo`1;Ool00`00Oomoo`0MOol00`00Oomoo`0O
Ool003Qoo`800?moobQoo`80049oo`03001oogoo01]oo`03001oogoo04eoo`03001oogoo01]oo`03
001oogoo021oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo
0P0017oo1@0017oo10001Goo00<007ooOol0@Woo00<007ooOol067oo0P00DGoo00<007ooOol06Goo
00<007ooOol08Goo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo
009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007oo
Ool00Woo00<007ooOol0@goo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05Woo0P0097oo
000FOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04Aoo`8001Eoo`03
001oogoo05Aoo`03001oogoo01Aoo`03001oogoo02Aoo`005Woo00D007ooOomoo`0000ioo`03001o
ogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool20017Ool00`00Oomoo`0AOol00`00Oomoo`1FOol3000BOol00`00Oomoo`0UOol001Io
o`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003goo00<007ooOol00Woo10001Goo00<007ooOol0Agoo0P003goo0P00G7oo00<007ooOol03Woo
00<007ooOol09Woo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<0
07ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
04Uoo`03001oogoo00]oo`03001oogoo05eoo`03001oogoo00]oo`8002Uoo`005Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8004]oo`8000Moo`@0065oo`<000Moo`<002]oo`00
5goo0`003Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo0`003Goo0`001Goo10001Goo00<007oo
Ool0C7oo1`00J7oo1`00;Woo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo
0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003a
Ool001moo`<000Ioo`8000Eoo`@000Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03
001oogoo0?1oo`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?mo
o`eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001ioo`05001o
ogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007oo
Ool00Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00ogoo3Woo
00D007ooOomoo`00011oo`03001oogoo009oo`800?5oo`007Woo00D007ooOomoo`0000aoo`@000Eo
o`03001oogoo0?moo`eoo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3`Ool001ioo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007oo
Ool01Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00ogoo3Woo
00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?5oo`007goo0`003Goo10001Goo00<007ooOol0
ogoo3Woo0`003Goo10001Goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2
003oOolXOol2003aOol001Moo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?mo
o`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomo
o`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogoo
Ool00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo0000
3Woo00<007ooOol01goo00<007ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo
00Moo`03001oogoo009oo`800?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eo
o`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3`
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0l7oo000FOol0
1@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00lGoo000GOol3000<Ool50004Ool4
0005Ool00`00Oomoo`3oOol6Ool3000<Ool50004Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2
003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00;goo1@0017oo00<007ooOol0ogoo7Woo
1@0017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04
Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00
<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3g
Ool0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007oo
Ool0mgoo000_Ool3003oOolWOol3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo
0000000067oo0`00ogoo1goo0`0000Aoo`00000001Uoo`<007Aoo`00UWoo00D007ooOomoo`0000Uo
o`H000Uoo`05001oogooOol0003oOol7Ool01@00Oomoogoo00002Goo1P0037oo00<007ooOol0Lgoo
002FOol01@00Oomoogoo000077oo00<007ooOol0ogoo1Goo00D007ooOomoo`0001Qoo`D007Aoo`00
UWoo00D007ooOomoo`0000Uoo`H000eoo`03001oogoo0?moo`Eoo`05001oogooOol00009Ool60009
Ool01000Oomoo`00MGoo002FOol01@00Oomoogoo00006Woo0P00ogoo27oo00D007ooOomoo`0001Uo
o`03001oo`0007Eoo`00UGoo1@007Goo00<007ooOol0ogoo17oo1@006Woo00<007oo0000MGoo002c
Ool01@00Oomoogoo0000ogoo9Woo0P00MGoo002dOol3003oOolXOol00`00Oomoo`1cOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00;goo
1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eoo`03
001oogoo0?mooaaoo`H000Eoo`03001oogoo0?Moo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<0
07ooOol017oo0P00lGoo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool0
0`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001o
ogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000_Ool30006
Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2001YOol7002gOol2003a
Ool003Qoo`03001oogoo05moo`T000Moo`X00:eoo`03001oogoo0?1oo`00>7oo00<007ooOol0G7oo
0`006Woo1000ZGoo00<007ooOol0l7oo000hOol2001HOol5000QOol4002UOol2003aOol003Qoo`03
001oogoo059oo`D002Yoo`D00:1oo`03001oogoo0?1oo`00>7oo00<007ooOol0Cgoo0`00=7oo0`00
WGoo00<007ooOol0l7oo000hOol00`00Oomoo`1=Ool2000jOol3002JOol00`00Oomoo`3`Ool003Qo
o`8004]oo`<003moo`8009Qoo`800?5oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo
00<007ooOol0B7oo0P00A7oo0`00M7oo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<0
07ooOol0AWoo0P00BGoo0P00LGoo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001o
ogoo009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo04Aoo`8004eoo`03001oogoo06Ioo`H0009oo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool20012Ool3001@Ool2001^Ool01@00Oomoogoo00003Woo00<0
07ooOol01goo00<007ooOol00Woo0P00lGoo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo
10001Goo00<007ooOol0?goo0P00EGoo0P00K7oo00D007ooOomoo`0000ioo`03001oogoo00=oo`@0
00Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo03eoo`8005Uoo`03001oogoo06Uoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol01Woo0P00?7oo0P00G7oo0P00JGoo00D007ooOomoo`0000]oo`05001oogooOol00004
Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo03Yoo`03001o
ogoo05ioo`8006Qoo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0>7oo
0P00Hgoo0P00Qgoo00<007ooOol0l7oo000hOol00`00Oomoo`0fOol2001WOol20025Ool00`00Oomo
o`3`Ool003Qoo`8003Ioo`03001oogoo06Uoo`8008=oo`800?5oo`00>7oo00<007ooOol0<goo0P00
KWoo0P00PGoo00<007ooOol0l7oo000hOol00`00Oomoo`0bOol00`00Oomoo`1`Ool00`00Oomoo`1n
Ool00`00Oomoo`3`Ool003Qoo`80035oo`8007Aoo`8007ioo`800?5oo`00>7oo00<007ooOol0;goo
00<007ooOol0MWoo00<007ooOol0Ngoo00<007ooOol0WWoo2P00B7oo000hOol00`00Oomoo`0]Ool2
001jOol2001kOol00`00Oomoo`2KOol3000:Ool30015Ool003Qoo`03001oogoo02aoo`03001oogoo
07aoo`03001oogoo07Qoo`03001oogoo09Moo`@0011oo`D0041oo`00>7oo0P00:goo0P00P7oo0P00
N7oo0P00UGoo0`006Goo0P00?Woo000OOol30006Ool20005Ool40005Ool00`00Oomoo`0YOol00`00
Oomoo`22Ool00`00Oomoo`1LOol30006Ool20005Ool40005Ool00`00Oomoo`2BOol2000NOol2000l
Ool001ioo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0XOol00`00Oomo
o`24Ool00`00Oomoo`1JOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0
TGoo00<007ooOol087oo00<007ooOol0>Goo000FOol60002Ool01@00Oomoogoo000047oo00<007oo
Ool00Woo0P009goo0P00R7oo00<007ooOol0DGoo1P000Woo00D007ooOomoo`00011oo`03001oogoo
009oo`80091oo`8002Aoo`8003Uoo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001o
ogoo02Eoo`03001oogoo08Uoo`03001oogoo05Qoo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`2=Ool2000XOol00`00Oomoo`0fOol001ioo`05001oogooOol0000<Ool40005Ool00`00
Oomoo`0TOol00`00Oomoo`2;Ool00`00Oomoo`1GOol01@00Oomoogoo000037oo10001Goo00<007oo
Ool0S7oo00<007ooOol0:Goo00<007ooOol0=Goo000NOol01@00Oomoogoo000037oo00<007ooOol0
1Woo00<007ooOol08goo00<007ooOol0SGoo00<007ooOol0EWoo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`03001oogoo08]oo`03001oogoo02]oo`8003Eoo`007Woo00D007ooOomoo`0000aoo`03
001oogoo00Ioo`80029oo`80095oo`03001oogoo05Eoo`05001oogooOol0000<Ool00`00Oomoo`06
Ool2002;Ool00`00Oomoo`0^Ool00`00Oomoo`0bOol001moo`<000eoo`@000Eoo`03001oogoo021o
o`03001oogoo099oo`8005Ioo`<000eoo`@000Eoo`03001oogoo08Uoo`03001oogoo031oo`03001o
ogoo035oo`00>7oo00<007ooOol07goo00<007ooOol0UGoo00<007ooOol0K7oo00<007ooOol0R7oo
00<007ooOol0<Woo0P00<Goo000hOol00`00Oomoo`0NOol00`00Oomoo`2GOol00`00Oomoo`1[Ool0
0`00Oomoo`26Ool2000gOol00`00Oomoo`0^Ool003Qoo`8001ioo`03001oogoo09Uoo`8006]oo`80
08Ioo`03001oogoo03Qoo`03001oogoo02eoo`00>7oo00<007ooOol077oo00<007ooOol0W7oo00<0
07ooOol0J7oo00<007ooOol0Q7oo00<007ooOol0>Woo00<007ooOol0;7oo000hOol00`00Oomoo`0K
Ool00`00Oomoo`2NOol00`00Oomoo`1WOol00`00Oomoo`23Ool00`00Oomoo`0lOol00`00Oomoo`0[
Ool003Qoo`8001]oo`03001oogoo0:1oo`03001oogoo06Ioo`8008=oo`03001oogoo03ioo`03001o
ogoo02Yoo`00>7oo00<007ooOol067oo0P00Y7oo0P00IWoo00<007ooOol0PGoo00<007ooOol0@7oo
00<007ooOol0:Goo000hOol00`00Oomoo`0GOol00`00Oomoo`2VOol00`00Oomoo`1SOol00`00Oomo
o`20Ool00`00Oomoo`12Ool00`00Oomoo`0XOol003Qoo`03001oogoo01Ioo`03001oogoo0:Qoo`03
001oogoo069oo`03001oogoo07moo`03001oogoo04Aoo`03001oogoo02Moo`00>7oo0P005Goo0P00
[7oo00<007ooOol0HGoo0P00Ogoo00<007ooOol0AWoo00<007ooOol09Woo000GOol30006Ool20004
Ool50004Ool40005Ool00`00Oomoo`0COol00`00Oomoo`2]Ool00`00Oomoo`0oOol30006Ool20004
Ool50004Ool40005Ool00`00Oomoo`1mOol00`00Oomoo`17Ool00`00Oomoo`0VOol001Ioo`05001o
ogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol04Woo00<007oo
Ool0[goo00<007ooOol0?Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomo
o`02Ool00`00Oomoo`1lOol00`00Oomoo`19Ool00`00Oomoo`0UOol000ioo`H0009oo`05001oogoo
Ool0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000BOol00`00Oomoo`2aOol00`00Oomoo`0d
Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P00O7oo00<007oo
Ool0Bgoo00<007ooOol097oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol03goo0P00]Goo00<007ooOol0>goo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo07Yoo`03001oogoo04eoo`03001oogoo02=oo`005Woo00D007oo
Oomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00ioo`03001oogoo0;Ioo`8003]oo`05
001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1iOol00`00Oomoo`1?Ool00`00
Oomoo`0ROol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`0=Ool00`00Oomoo`2iOol00`00Oomoo`0hOol01@00Oomoogoo00003goo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol0N7oo00<007ooOol0DGoo00<007ooOol08Goo000FOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000eoo`03001oogoo0;]oo`03001oogoo
03Moo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00N7oo00<007oo
Ool0Dgoo00<007ooOol087oo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`0;Ool00`00Oomo
o`2mOol00`00Oomoo`0gOol3000=Ool30005Ool40005Ool00`00Oomoo`1fOol00`00Oomoo`1EOol0
0`00Oomoo`0OOol003Qoo`03001oogoo00Yoo`03001oogoo019oo`<000Ioo`8000Aoo`D001Qoo`<0
00Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<001Yoo`<000Ioo`8000Eoo`<001Eoo`8000Yoo`D0
04Uoo`03001oogoo01moo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Ioo`03001oo`00
008000Ioo`8000Eoo`<001Uoo`<000Ioo`8000Eoo`<001Uoo`03001oogoo00Eoo`D001Aoo`00>7oo
0P002Woo00<007ooOol04Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomo
ogoo00001Goo0P001goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0
000HOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Ioo`03001oogoo00Uoo`03001o
ogoo04Uoo`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`005goo00D007ooOomoo`00
00Eoo`8000Moo`03001oogoo01Aoo`03001oo`0000=oo`03001oogoo00=oo`8000Aoo`05001oogoo
Ool0000GOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Uoo`03001oogoo00Ioo`03
001oogoo01Aoo`00>7oo00<007ooOol027oo00<007ooOol04goo00D007ooOomoo`0000eoo`03001o
ogoo01Moo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qo
o`05001oogooOol0000;Ool01@00Oomoogoo00005goo00<007ooOol027oo00<007ooOol0BGoo00<0
07ooOol07Woo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000EOol0
0`00Ool00003Ool00`00Oomoo`09Ool01@00Oomoogoo00005goo00D007ooOomoo`0000]oo`05001o
ogooOol0000IOol00`00Oomoo`06Ool00`00Oomoo`0DOol003Qoo`03001oogoo00Moo`03001oogoo
01Aoo`05001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol001Qo
o`05001oogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogooOol0
000HOol00`00Oomoo`07Ool00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Woo00<0
07ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000EOol01000Oomoo`000goo00<007ooOol0
2Goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00006Woo00<007ooOol0
1Goo00<007ooOol057oo000hOol00`00Oomoo`05Ool2000GOol01@00Oomoogoo00003goo00<007oo
Ool05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool4000IOol01@00
Oomoogoo000037oo0`006Woo0P001goo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`00
00moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000DOol01@00Oomoogoo00000goo
00<007ooOol02Goo100067oo00D007ooOomoo`0000aoo`<001aoo`03001oogoo00Aoo`03001oogoo
01Aoo`00>7oo0P001Goo00<007ooOol05goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001o
ogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo00<007ooOol06Woo00D007ooOomo
o`0000]oo`05001oogooOol0000KOol00`00Oomoo`04Ool00`00Oomoo`19Ool2000OOol01@00Oomo
ogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001=oo`03001oogoo009o
o`05001oogooOol0000;Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`0001ao
o`03001oogoo00=oo`03001oogoo01Aoo`00>7oo00<007ooOol00goo00<007ooOol067oo00D007oo
Oomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00003Goo0P0067oo00D007ooOomoo`00
00aoo`03001oogoo01Uoo`05001oogooOol0000;Ool01@00Oomoogoo000077oo00<007ooOol00goo
00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00
Oomoogoo00003Goo0P004goo00<007ooOol00Woo00D007ooOomoo`0000aoo`03001oogoo01Qoo`05
001oogooOol0000;Ool01@00Oomoogoo00007Goo00<007ooOol00Woo00<007ooOol057oo000hOol0
0`00Oomoo`02Ool00`00Oomoo`0JOol3000=Ool3000IOol3000?Ool00`00Oomoo`0GOol3000>Ool3
000IOol3000=Ool3000NOol00`00Oomoo`03001;Ool00`00Oomoo`0OOol3000=Ool3000IOol3000?
Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool3000>Ool3000HOol3000=Ool3000OOol00`00Ool00002
000FOol003Qoo`05001oogooOol0003DOol00`00Oomoo`1=Ool00`00Oomoo`1_Ool00`00Oomoo`1S
Ool00`00Oomoo`0HOol003Qoo`800003Ool007oo0=Eoo`03001oogoo04aoo`8006moo`03001oogoo
06Eoo`03001oogoo01Moo`00>7oo00<007oo0000f7oo00<007ooOol0Bgoo00<007ooOol0KWoo00<0
07ooOol0IWoo00<007ooOol05Woo000hOol2003JOol00`00Oomoo`1:Ool00`00Oomoo`1]Ool00`00
Oomoo`1XOol00`00Oomoo`0EOol0039oonT0041oonT0011oo`00>7oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0BGoo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool057oo000hOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0ZOol0
0`00Oomoo`0YOol00`00Oomoo`19Ool2000ZOol00`00Oomoo`0YOol00`00Oomoo`0COol00`00Oomo
o`0COol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0DOol003Qoo`03001oogoo0?moobMo
o`03001oo`0006Yoo`03001oogoo08=oo`00>7oo0P00ogoo:7oo0P0000=oo`00Ool0Igoo00<007oo
Ool0Q7oo000hOol00`00Oomoo`3oOolWOol01@00Oomoogoo0000IWoo00<007ooOol0QGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`02Ool00`00Oomoo`1ROol00`00Oomoo`26Ool003Qoo`800?mo
obQoo`8000=oo`03001oogoo065oo`03001oogoo08Moo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool00goo00<007ooOol0Ggoo00<007ooOol0R7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`04
Ool00`00Oomoo`1MOol00`00Oomoo`29Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Eoo`03
001oogoo05]oo`03001oogoo08Yoo`00>7oo0P00ogoo:7oo0P001goo00<007ooOol0FGoo00<007oo
Ool0Rgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`06Ool00`00Oomoo`1IOol00`00Oomoo`2;
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Moo`03001oogoo05Moo`03001oogoo08aoo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol027oo00<007ooOol0EGoo00<007ooOol0SGoo000hOol2
003oOolXOol2000:Ool00`00Oomoo`1COol00`00Oomoo`2>Ool001Moo`<000Ioo`8000Aoo`D000Ao
o`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Yoo`03
001oogoo055oo`03001oogoo08moo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008
Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol0
00Qoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo04moo`03001oogoo091oo`005Woo00D0
07ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000=
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`1>Ool00`00Oomoo`2AOol001Io
o`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00
Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0C7oo
00<007ooOol0TWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00eoo`03001oogoo
04Yoo`03001oogoo09=oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`0>Ool00`00Oomoo`18Ool00`00Oomoo`2DOol001Ioo`05001oogooOol0000;Ool01@00Oomo
ogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004
Ool00`00Oomoo`06Ool2000@Ool20016Ool2002GOol001Moo`<000eoo`<000Eoo`@000Eoo`03001o
ogoo0?moo`Ioo`<000eoo`<000Eoo`@000Eoo`03001oogoo015oo`03001oogoo049oo`03001oogoo
09Moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol04Woo00<007ooOol0@7oo00<007ooOol0V7oo
000hOol2003oOolXOol2000DOol00`00Oomoo`0nOol00`00Oomoo`2IOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo01Aoo`8003eoo`03001oogoo09Yoo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool05Woo00<007ooOol0>Goo00<007ooOol0Vgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0G
Ool00`00Oomoo`0gOol00`00Oomoo`2LOol003Qoo`800?moobQoo`8001Uoo`03001oogoo03Eoo`03
001oogoo09eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol06Goo0P00<goo0P00X7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`0KOol00`00Oomoo`0_Ool00`00Oomoo`2POol003Qoo`800?mo
obQoo`8001eoo`03001oogoo02eoo`03001oogoo0:5oo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool07Goo00<007ooOol0:Woo0P00Y7oo000OOol30006Ool20005Ool40005Ool00`00Oomoo`3oOol>
Ool30006Ool20005Ool40005Ool00`00Oomoo`0NOol00`00Oomoo`0XOol00`00Oomoo`2TOol001io
o`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo
00001Goo0P002Goo00<007ooOol00Woo00<007ooOol07goo00<007ooOol09Woo00<007ooOol0YGoo
000NOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00ogoo3Woo00D007ooOomoo`00011oo`03
001oogoo009oo`80025oo`03001oogoo02Aoo`03001oogoo0:Ioo`007Woo00D007ooOomoo`00011o
o`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00
Oomoo`0QOol2000ROol2002YOol001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3oOol=
Ool01@00Oomoogoo000037oo10001Goo00<007ooOol08goo0`007Goo0P00Zgoo000NOol01@00Oomo
ogoo000037oo00<007ooOol01Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo
00Ioo`03001oogoo02Ioo`<001Qoo`800:eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Io
o`800?moo`ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2000ZOol2000COol3002_Ool001mo
o`<000eoo`@000Eoo`03001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo02]oo`8000eoo`@0
0;9oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0;Goo3@00]Woo000hOol2003oOolXOol2003a
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`
Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<0
07ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0l7oo000FOol0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`00
5Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05
001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00Woo0P00lGoo000FOol01@00Oomoogoo00003Woo00<007ooOol0
0goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03
001oogoo0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`
Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`3`
Ool001Moo`<000aoo`D000Aoo`@000Eoo`800?moo`Moo`<000aoo`D000Aoo`@000Eoo`800?5oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`
Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000_Ool50004Ool00`00Oomo
o`3oOolNOol50004Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03
001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007oo
Ool017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003a
Ool0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007oo
Ool0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00
ogooogooEWoo003oOoooOomFOol009Eoo`<00004Ool00000000HOol5003oOol5Ool3000017oo0000
00005goo1@00M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007oo
Oomoo`0000Uoo`H000Yoo`04001oogoo001dOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3o
Ool6Ool01@00Oomoogoo00006Woo00<007ooOol0M7oo002FOol01@00Oomoogoo00002Goo1P0037oo
00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007oo
Oomoo`0001]oo`03001oogoo0?moo`Ioo`05001oogooOol0000LOol00`00Oomoo`1bOol009Eoo`D0
01aoo`03001oogoo0?moo`Eoo`D001eoo`03001oogoo079oo`00]Woo00<007ooOol0ogoo8goo00D0
07ooOomoo`0007Aoo`00]7oo0`00ogoo9Woo0`00MGoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .24125 L
.08255 .20927 L
.10458 .17881 L
.12507 .15598 L
.14415 .14033 L
.14918 .13719 L
.15465 .13426 L
.15946 .1321 L
.16457 .13025 L
.16917 .12897 L
.17178 .12841 L
.17423 .128 L
.17538 .12784 L
.17647 .12771 L
.17746 .12761 L
.17852 .12752 L
.17967 .12745 L
.18073 .12741 L
.182 .12738 L
.18314 .12738 L
.18435 .12741 L
.18547 .12746 L
.1867 .12754 L
.18802 .12765 L
.19071 .12798 L
.19317 .12839 L
.1979 .12948 L
.20239 .13088 L
.21236 .13523 L
.22321 .1419 L
.24299 .15892 L
.26399 .18326 L
.30174 .23977 L
.34195 .31023 L
.38063 .378 L
.40028 .40916 L
.42177 .43889 L
.44253 .46207 L
.4614 .47756 L
.47149 .48347 L
.47611 .4856 L
.48101 .48745 L
.4835 .48824 L
.48624 .48897 L
.48876 .48953 L
.49106 .48994 L
.49378 .49031 L
.49527 .49045 L
.49596 .49051 L
Mistroke
.49669 .49056 L
.498 .49062 L
.49921 .49065 L
.49996 .49065 L
.50065 .49065 L
.50196 .49062 L
.50313 .49057 L
.50438 .49048 L
.50556 .49038 L
.50663 .49026 L
.50926 .48989 L
.51175 .48943 L
.5167 .48818 L
.52208 .48633 L
.53169 .4818 L
.54056 .47621 L
.55926 .4603 L
.57988 .4368 L
.62014 .37671 L
.65888 .30875 L
.70007 .23677 L
.72063 .20458 L
.73974 .1785 L
.75939 .15656 L
.77791 .14112 L
.78775 .13518 L
.79293 .13271 L
.7984 .1306 L
.80302 .12923 L
.80546 .12866 L
.80809 .12816 L
.8105 .12781 L
.8127 .12758 L
.81375 .1275 L
.81491 .12744 L
.81599 .1274 L
.817 .12738 L
.81818 .12739 L
.81941 .12742 L
.82047 .12746 L
.82163 .12754 L
.82287 .12764 L
.82421 .12779 L
.82661 .12813 L
.82905 .12857 L
.83134 .12909 L
.83564 .13031 L
.84078 .1322 L
.84552 .13434 L
.85624 .14059 L
Mistroke
.87498 .15602 L
.89561 .17904 L
.93591 .23852 L
.97471 .30635 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35562 L
.08255 .37584 L
.0932 .38473 L
.10458 .39259 L
.11009 .39572 L
.11531 .39827 L
.12038 .40034 L
.12507 .40189 L
.12951 .40303 L
.13178 .40349 L
.13422 .40389 L
.13549 .40406 L
.13666 .40419 L
.13784 .4043 L
.13895 .40438 L
.14022 .40445 L
.1409 .40448 L
.14161 .4045 L
.1423 .40451 L
.14295 .40451 L
.14415 .40449 L
.14531 .40446 L
.14656 .40439 L
.14773 .40431 L
.14881 .40421 L
.15143 .4039 L
.15392 .40349 L
.15886 .40239 L
.16423 .40074 L
.17383 .39665 L
.1827 .39161 L
.20137 .37744 L
.22197 .35704 L
.26217 .30868 L
.30086 .26207 L
.32051 .24232 L
.3309 .23361 L
.342 .22586 L
.35275 .22006 L
.35784 .21793 L
.36253 .21633 L
.36724 .21508 L
.36972 .21457 L
.37235 .21414 L
.37463 .21386 L
.37573 .21375 L
.37677 .21367 L
.37799 .2136 L
.37911 .21355 L
Mistroke
.38031 .21353 L
.38162 .21353 L
.38227 .21354 L
.38296 .21356 L
.38419 .21361 L
.38551 .2137 L
.38695 .21382 L
.38955 .21414 L
.39197 .21453 L
.39649 .21553 L
.40134 .21696 L
.40698 .2191 L
.41232 .22159 L
.42232 .2274 L
.44227 .24311 L
.4607 .26169 L
.50002 .30904 L
.53782 .35472 L
.55884 .37593 L
.56803 .38368 L
.57808 .39089 L
.58722 .39621 L
.59696 .40048 L
.60236 .4022 L
.60726 .40336 L
.60962 .40377 L
.61086 .40395 L
.61218 .40412 L
.61333 .40424 L
.61459 .40434 L
.61574 .40442 L
.61682 .40447 L
.61808 .4045 L
.61871 .40451 L
.61941 .40451 L
.62065 .40449 L
.62181 .40444 L
.62248 .40441 L
.62318 .40437 L
.62443 .40427 L
.62578 .40413 L
.62725 .40395 L
.62973 .40356 L
.63238 .40304 L
.63715 .4018 L
.64214 .40011 L
.64686 .39815 L
.6557 .39356 L
.67568 .37906 L
.69413 .36136 L
Mistroke
.7335 .3148 L
.77136 .26844 L
.79241 .24629 L
.81166 .23021 L
.82118 .22408 L
.8262 .22137 L
.83155 .21892 L
.8367 .21698 L
.84136 .21559 L
.84361 .21504 L
.84604 .21455 L
.84835 .21417 L
.85045 .2139 L
.85159 .21378 L
.85283 .21368 L
.85414 .2136 L
.85538 .21355 L
.85653 .21353 L
.85776 .21353 L
.85881 .21355 L
.85997 .21359 L
.86063 .21363 L
.86132 .21367 L
.86256 .21377 L
.86535 .21409 L
.86777 .21446 L
.87041 .21498 L
.87569 .21637 L
.88133 .21835 L
.89148 .22316 L
.90173 .22958 L
.91284 .23817 L
.933 .25749 L
.97393 .30617 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .27166 L
.10458 .23164 L
.14415 .19539 L
.18221 .16235 L
.22272 .12973 L
.26171 .10134 L
.30316 .07493 L
.34309 .05362 L
.3815 .03729 L
.40095 .03067 L
.42237 .02471 L
.44268 .02036 L
.45178 .01883 L
.46172 .01746 L
.4671 .01685 L
.4721 .01637 L
.47727 .01595 L
.48196 .01564 L
.48658 .01541 L
.4887 .01533 L
.49093 .01526 L
.49332 .0152 L
.49438 .01517 L
.49552 .01516 L
.49675 .01514 L
.49789 .01513 L
.49859 .01513 L
.49925 .01513 L
.50049 .01512 L
.50163 .01513 L
.50286 .01514 L
.50401 .01515 L
.50508 .01517 L
.50754 .01522 L
.51014 .01529 L
.51268 .01538 L
.51504 .01549 L
.5204 .01579 L
.5293 .0165 L
.53882 .01753 L
.54906 .01896 L
.56016 .02089 L
.58032 .02538 L
.62123 .03831 L
.66064 .05543 L
.69852 .07592 L
.73886 .10173 L
.77769 .13004 L
.81897 .16334 L
Mistroke
.85873 .19797 L
.89697 .23309 L
.93767 .27177 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .37205 L
.10458 .43602 L
.14415 .4873 L
.18221 .52525 L
.20178 .53961 L
.21267 .54594 L
.22272 .55071 L
.23293 .55446 L
.23832 .556 L
.24402 .55728 L
.24641 .55771 L
.24897 .55811 L
.25119 .55839 L
.25361 .55864 L
.25507 .55876 L
.25643 .55885 L
.25773 .55892 L
.2584 .55895 L
.25912 .55897 L
.25983 .55899 L
.26048 .55901 L
.26176 .55902 L
.26293 .55901 L
.26416 .55899 L
.26538 .55895 L
.26607 .55892 L
.26671 .55889 L
.26912 .55873 L
.27131 .55854 L
.27364 .55827 L
.27847 .55753 L
.2838 .55641 L
.29326 .55369 L
.30213 .55026 L
.32232 .53942 L
.34082 .52589 L
.38045 .48638 L
.41855 .43698 L
.45912 .37564 L
.49816 .31205 L
.53966 .24435 L
.57964 .18362 L
.61811 .13334 L
.63759 .11199 L
.65902 .09227 L
.67938 .07754 L
.69843 .06753 L
.70884 .06366 L
.71396 .06218 L
Mistroke
.71872 .06106 L
.72301 .06025 L
.72758 .05962 L
.7302 .05936 L
.73148 .05926 L
.73266 .05918 L
.73371 .05912 L
.73487 .05907 L
.73603 .05904 L
.73725 .05902 L
.73856 .05902 L
.73977 .05903 L
.7404 .05905 L
.7411 .05907 L
.74251 .05912 L
.74375 .05919 L
.74508 .05928 L
.74748 .0595 L
.74985 .05977 L
.75235 .06012 L
.7568 .06092 L
.76198 .06212 L
.7668 .06349 L
.77773 .06751 L
.78828 .07259 L
.79823 .07843 L
.81683 .09199 L
.85534 .13016 L
.89632 .18329 L
.93577 .24314 L
.97371 .30493 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo0P00
1Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo
10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00
Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Io
o`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol07Goo2@00RWoo2P00K7oo00<007ooOol0l7oo
000hOol00`00Oomoo`0KOol20009Ool30026Ool00`00Oomoo`08Ool3001YOol00`00Oomoo`3`Ool0
03Qoo`8001]oo`03001oogoo00aoo`80089oo`8000ioo`03001oogoo06Ioo`800?5oo`007goo0`00
1Woo0P001Goo10001Goo00<007ooOol067oo0P004Goo0P00OWoo0P004Goo0P00CGoo0`001Woo0P00
1Goo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo
00<007ooOol05Woo0P005Goo00<007ooOol0NGoo0P005Goo00<007ooOol0BGoo00D007ooOomoo`00
00Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`005Woo1P000Woo00D007ooOomoo`00011o
o`03001oogoo009oo`03001oogoo01Eoo`03001oogoo01Ioo`03001oogoo07Moo`03001oogoo01Io
o`03001oogoo041oo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool0
01ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000EOol00`00Oomoo`0HOol00`00Oomoo`1e
Ool00`00Oomoo`0HOol00`00Oomoo`17Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo
000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol057oo00<007ooOol06Goo00<007ooOol0
M7oo00<007ooOol067oo00<007ooOol0Agoo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1o
o`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo01=oo`03001oogoo01Yoo`03
001oogoo07=oo`03001oogoo01Yoo`03001oogoo04Ioo`05001oogooOol0000<Ool00`00Oomoo`06
Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0BOol0
0`00Oomoo`0LOol00`00Oomoo`1aOol00`00Oomoo`0LOol00`00Oomoo`15Ool01@00Oomoogoo0000
37oo00<007ooOol01Woo00<007ooOol0l7oo000OOol3000=Ool40005Ool2000COol00`00Oomoo`0M
Ool00`00Oomoo`1`Ool00`00Oomoo`0MOol00`00Oomoo`15Ool3000=Ool40005Ool2003aOol003Qo
o`03001oogoo015oo`03001oogoo01moo`03001oogoo06ioo`03001oogoo01moo`03001oogoo05eo
o`03001oogoo0?1oo`00>7oo00<007ooOol047oo00<007ooOol08Goo00<007ooOol0K7oo00<007oo
Ool08Goo00<007ooOol0G7oo00<007ooOol0l7oo000hOol2000AOol00`00Oomoo`0ROol00`00Oomo
o`1[Ool00`00Oomoo`0QOol00`00Oomoo`1LOol2003aOol003Qoo`03001oogoo00moo`03001oogoo
02=oo`03001oogoo06Yoo`03001oogoo02=oo`03001oogoo05]oo`03001oogoo0?1oo`00>7oo00<0
07ooOol03Woo00<007ooOol09Goo00<007ooOol0J7oo00<007ooOol09Goo00<007ooOol0FWoo00<0
07ooOol0l7oo000hOol00`00Oomoo`0=Ool00`00Oomoo`0WOol00`00Oomoo`1VOol00`00Oomoo`0V
Ool00`00Oomoo`1JOol00`00Oomoo`3`Ool003Qoo`8000ioo`03001oogoo02Moo`03001oogoo06Eo
o`03001oogoo02Qoo`03001oogoo05Uoo`800?5oo`00>7oo00<007ooOol037oo00<007ooOol0:Goo
00<007ooOol0Hgoo00<007ooOol0:Woo00<007ooOol0F7oo00<007ooOol0l7oo000hOol00`00Oomo
o`0;Ool00`00Oomoo`0ZOol00`00Oomoo`1SOol00`00Oomoo`0[Ool00`00Oomoo`1GOol00`00Oomo
o`3`Ool003Qoo`8000aoo`03001oogoo02]oo`03001oogoo065oo`03001oogoo02aoo`03001oogoo
05Moo`8004aoo`/006=oo`/002aoo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0
2Woo00<007ooOol0;Goo00<007ooOol0H7oo00<007ooOol0;Goo00<007ooOol0=Goo0`001Woo0P00
17oo1@0017oo10001Goo00<007ooOol0BGoo0P002goo00<007ooOol0GWoo0P002goo0P00:Woo000F
Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Uo
o`03001oogoo02ioo`03001oogoo05moo`03001oogoo02moo`03001oogoo03=oo`05001oogooOol0
0005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0B7oo00<007ooOol037oo
0P00G7oo0P003goo0P00:7oo000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol027oo00<007ooOol0<7oo00<007ooOol0GGoo00<007ooOol0<7oo00<0
07ooOol0:goo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001o
ogoo04Ioo`80015oo`8005Uoo`03001oogoo015oo`8002Ioo`005Woo00D007ooOomoo`0000ioo`03
001oogoo00Moo`03001oogoo009oo`8000Uoo`03001oogoo031oo`03001oogoo05eoo`03001oogoo
035oo`03001oogoo039oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20015
Ool2000EOol00`00Oomoo`1DOol2000FOol00`00Oomoo`0SOol001Ioo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool40005Ool00`00Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`1KOol00`00Oomo
o`0cOol00`00Oomoo`0aOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0
@goo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05goo00<007ooOol08Woo000FOol01@00
Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0=7oo
00<007ooOol0FWoo00<007ooOol0<goo00<007ooOol0<Goo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo049oo`03001oogoo01Qoo`03001oogoo051oo`03001oogoo
01Qoo`03001oogoo029oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomo
o`06Ool20007Ool00`00Oomoo`0dOol00`00Oomoo`1IOol00`00Oomoo`0eOol00`00Oomoo`0`Ool0
1@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`80049oo`03001oogoo01Yo
o`03001oogoo04ioo`03001oogoo01Yoo`03001oogoo025oo`005goo0`003Goo0`001Goo10001Goo
00<007ooOol01Goo00<007ooOol0=Woo00<007ooOol0F7oo00<007ooOol0=Goo00<007ooOol0<Goo
0`003Goo0`001Goo10001Goo00<007ooOol0@7oo00<007ooOol077oo00<007ooOol0C7oo00<007oo
Ool077oo00<007ooOol087oo000hOol00`00Oomoo`05Ool00`00Oomoo`0gOol00`00Oomoo`1FOol0
0`00Oomoo`0gOol00`00Oomoo`1AOol00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1:Ool0
0`00Oomoo`0NOol00`00Oomoo`0OOol003Qoo`03001oogoo00Aoo`03001oogoo01Qoo`<000Ioo`80
00Aoo`D000aoo`03001oogoo00Uoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<000eoo`03
001oogoo00Yoo`<000Ioo`8000Eoo`<001aoo`03001oogoo009oo`D004Uoo`03001oogoo01moo`<0
00Ioo`8000Aoo`D000]oo`03001oogoo00Yoo`<000Ioo`8000Ioo`<0009oo`03001oogoo01=oo`<0
00Ioo`8000Eoo`<001Uoo`<000Ioo`8000Eoo`<001Uoo`03001oogoo00Eoo`D001Aoo`00>7oo0P00
17oo00<007ooOol067oo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000=Ool00`00Oomoo`07
Ool01@00Oomoogoo00001Goo0P001goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`05
001oogooOol0000<Ool00`00Oomoo`09Ool01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00
01]oo`03001oogoo00Aoo`03001oogoo04Uoo`8001moo`05001oogooOol00005Ool20005Ool01000
Oomoo`002Woo00<007ooOol02Woo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo009oo`03001o
ogoo015oo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Ao
o`<000Aoo`05001oogooOol0000HOol00`00Oomoo`07Ool00`00Oomoo`0DOol003Qoo`03001oogoo
00=oo`03001oogoo01Qoo`05001oogooOol0000=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool01@00
Oomoogoo00002goo1@005goo00D007ooOomoo`0000]oo`05001oogooOol0000;Ool00`00Oomoo`0:
Ool01@00Oomoogoo00002goo00D007ooOomoo`0001aoo`03001oogoo00=oo`03001oogoo04Uoo`03
001oogoo01ioo`05001oogooOol0000=Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool01@00Oomoogoo
00002goo1@000goo00<007ooOol04Goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00
Oomoogoo00000goo00<007ooOol01Goo00D007ooOomoo`0001Uoo`03001oogoo00Ioo`03001oogoo
01Aoo`00>7oo00<007ooOol00Woo00<007ooOol06Goo00D007ooOomoo`0000ioo`03001oogoo00eo
o`03001oogoo00Ioo`05001oogooOol0000;Ool01000Oomoo`0067oo00D007ooOomoo`0000]oo`05
001oogooOol0000;Ool00`00Oomoo`0:Ool01@00Oomoogoo00002goo00D007ooOomoo`0001aoo`03
001oogoo00=oo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000>Ool00`00Oomoo`08
Ool00`00Oomoo`0;Ool01@00Oomoogoo00002goo00@007ooOol000Eoo`03001oogoo011oo`05001o
ogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000=oo`03001oogoo00Eoo`05001o
ogooOol0000JOol00`00Oomoo`05Ool00`00Oomoo`0DOol003Qoo`03001oogoo009oo`03001oogoo
01Uoo`05001oogooOol0000?Ool00`00Oomoo`0=Ool00`00Oomoo`05Ool01@00Oomoogoo000037oo
00<007oo000067oo00D007ooOomoo`0000]oo`@000]oo`03001oogoo00]oo`05001oogooOol0000<
Ool3000NOol00`00Oomoo`02Ool00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003goo
00<007ooOol01Woo00<007ooOol037oo00D007ooOomoo`0000aoo`03001oo`0000Ioo`03001oogoo
00moo`05001oogooOol0000;Ool4000HOol01@00Oomoogoo00000Woo00<007ooOol01goo0`0077oo
00<007ooOol017oo00<007ooOol057oo000hOol20002Ool00`00Oomoo`0JOol01@00Oomoogoo0000
3goo00<007ooOol03Goo00<007ooOol01Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001o
ogooOol0000;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool01@00Oomoogoo00002goo00D007ooOomo
o`0001eoo`03001oogoo009oo`03001oogoo04Uoo`8001moo`05001oogooOol0000?Ool00`00Oomo
o`05Ool00`00Oomoo`0=Ool01@00Oomoogoo000037oo00<007oo00001goo00<007ooOol03Woo00D0
07ooOomoo`0000]oo`03001oogoo01Uoo`07001oogooOol007oo00002Goo00D007ooOomoo`0001ao
o`03001oogoo00=oo`03001oogoo01Aoo`00>7oo00D007ooOomoo`0001aoo`05001oogooOol0000;
Ool01@00Oomoogoo000047oo00<007ooOol017oo00D007ooOomoo`0000eoo`8001Qoo`05001oogoo
Ool0000<Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool01@00Oomoogoo00002goo00D007ooOomoo`00
01ioo`05001oogooOol0001;Ool00`00Oomoo`0NOol01@00Oomoogoo00002goo00D007ooOomoo`00
00Ioo`03001oogoo00ioo`05001oogooOol0000=Ool20008Ool00`00Oomoo`0=Ool01@00Oomoogoo
000037oo00<007ooOol067oo00@007ooOomoo`8000Yoo`05001oogooOol0000MOol00`00Oomoo`02
Ool00`00Oomoo`0DOol003Qoo`04001oogoo000NOol3000=Ool3000BOol00`00Oomoo`04Ool3000?
Ool00`00Oomoo`0GOol3000>Ool30008Ool00`00Oomoo`0>Ool3000=Ool3000OOol00`00Ool00002
001;Ool00`00Oomoo`0OOol3000=Ool30006Ool00`00Oomoo`0@Ool3000?Ool00`00Oomoo`07Ool0
0`00Oomoo`0=Ool3000>Ool3000HOol4000<Ool3000OOol00`00Ool00002000FOol003Qoo`800003
Ool007oo049oo`03001oogoo04aoo`03001oogoo045oo`03001oogoo04aoo`8003Uoo`03001oogoo
02aoo`03001oogoo03]oo`03001oogoo02ioo`03001oogoo01Moo`00>7oo00<007oo0000AGoo00<0
07ooOol0BWoo00<007ooOol0@goo00<007ooOol0Bgoo00<007ooOol0=goo00<007ooOol0;Woo00<0
07ooOol0>Woo00<007ooOol0;goo00<007ooOol05Woo000hOol20016Ool00`00Oomoo`19Ool00`00
Oomoo`14Ool00`00Oomoo`1;Ool00`00Oomoo`0fOol00`00Oomoo`0`Ool00`00Oomoo`0hOol00`00
Oomoo`0aOol00`00Oomoo`0EOol003Qoo`8004Moo`03001oogoo04Qoo`03001oogoo04Eoo`03001o
ogoo04Yoo`03001oogoo03Eoo`03001oogoo039oo`03001oogoo03Ioo`03001oogoo03=oo`03001o
ogoo01Aoo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`05Ool01000Oomo
o`002Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00D007ooOomoo`0000Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo04Uoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`8000Yoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo00<0
07ooOol0B7oo00<007ooOol0A7oo00<007ooOol0U7oo0P00=7oo00<007ooOol0=Woo00<007ooOol0
<Woo00<007ooOol0C7oo000hOol20019Ool00`00Oomoo`13Ool00`00Oomoo`2EOol3000bOol00`00
Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`1=Ool003Qoo`03001oogoo04Uoo`03001oogoo049o
o`03001oogoo09Eoo`04001oogoo000`Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`1>
Ool003Qoo`03001oogoo04Yoo`03001oogoo041oo`03001oogoo09Ioo`05001oogooOol0000^Ool0
0`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`1?Ool003Qoo`03001oogoo04Yoo`03001oogoo
041oo`03001oogoo09Ioo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo
02Yoo`03001oogoo051oo`00>7oo0P00C7oo00<007ooOol0?Woo00<007ooOol0Ugoo0P000goo00<0
07ooOol0:Woo00<007ooOol0?goo00<007ooOol0:7oo00<007ooOol0DGoo000hOol00`00Oomoo`1;
Ool00`00Oomoo`0mOol00`00Oomoo`2HOol00`00Oomoo`03Ool00`00Oomoo`0XOol00`00Oomoo`11
Ool00`00Oomoo`0WOol00`00Oomoo`1AOol003Qoo`03001oogoo04aoo`03001oogoo03aoo`03001o
ogoo09Qoo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03001o
ogoo059oo`00>7oo00<007ooOol0C7oo00<007ooOol0>goo00<007ooOol0VGoo00<007ooOol01Goo
00<007ooOol097oo00<007ooOol0AGoo00<007ooOol08goo00<007ooOol0Dgoo000hOol2001>Ool0
0`00Oomoo`0jOol00`00Oomoo`2IOol20007Ool00`00Oomoo`0ROol00`00Oomoo`17Ool00`00Oomo
o`0QOol00`00Oomoo`1DOol003Qoo`03001oogoo04eoo`03001oogoo03Uoo`03001oogoo09Yoo`03
001oogoo00Moo`03001oogoo021oo`03001oogoo04Uoo`03001oogoo01moo`03001oogoo05Eoo`00
>7oo00<007ooOol0CWoo00<007ooOol0=goo00<007ooOol0Vgoo00<007ooOol027oo00<007ooOol0
7Woo00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol0EWoo000hOol2001@Ool00`00Oomoo`0f
Ool00`00Oomoo`2KOol2000:Ool00`00Oomoo`0LOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00
Oomoo`1GOol001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo04moo`03001oogoo03Eo
o`03001oogoo07]oo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Yoo`8001]oo`03001o
ogoo04moo`03001oogoo01Uoo`03001oogoo05Qoo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04
001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`1@Ool00`00Oomoo`0dOol00`00Oomoo`1jOol0
1@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00aoo`03
001oogoo01Ioo`8005=oo`03001oogoo01Ioo`8005]oo`005Woo00D007ooOomoo`0000eoo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo051oo`03001oogoo03=oo`03001oogoo07]oo`05001o
ogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0DOol0
0`00Oomoo`1DOol00`00Oomoo`0COol2001MOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool2001BOol00`00Oomoo`0aOol00`00Oomoo`1lOol01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00Woo0P003goo00<007ooOol04Woo00<007ooOol0EWoo00<007oo
Ool04Goo00<007ooOol0GGoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<0
07ooOol0DGoo00<007ooOol0<Goo00<007ooOol0O7oo00D007ooOomoo`0000moo`03001oogoo009o
o`@000Eoo`03001oogoo00moo`80011oo`8005Yoo`8000moo`80061oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo059oo`03001oogoo02moo`03001oogoo
07eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0AOol2000<
Ool2001NOol3000;Ool00`00Oomoo`1POol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P00E7oo00<007ooOol0;Goo00<007ooOol0OWoo00D007ooOomoo`0000]o
o`05001oogooOol00004Ool00`00Oomoo`06Ool2000DOol20007Ool3001SOol20007Ool2001SOol0
01Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo05=oo`03001oogoo02eoo`03001oogoo07moo`<0
00eoo`<000Eoo`@000Eoo`03001oogoo01Eoo`L006Qoo`L006Eoo`00>7oo00<007ooOol0E7oo00<0
07ooOol0:goo00<007ooOol0XGoo00<007ooOol0l7oo000hOol00`00Oomoo`1DOol00`00Oomoo`0[
Ool00`00Oomoo`2QOol00`00Oomoo`3`Ool003Qoo`8005Ioo`03001oogoo02Uoo`03001oogoo0:9o
o`800?5oo`00>7oo00<007ooOol0EWoo00<007ooOol09goo00<007ooOol0Xgoo00<007ooOol0l7oo
000hOol00`00Oomoo`1GOol00`00Oomoo`0VOol00`00Oomoo`2SOol00`00Oomoo`3`Ool003Qoo`80
05Qoo`03001oogoo02Eoo`03001oogoo0:Aoo`800?5oo`00>7oo00<007ooOol0F7oo00<007ooOol0
8goo00<007ooOol0YGoo00<007ooOol0l7oo000hOol00`00Oomoo`1IOol00`00Oomoo`0ROol00`00
Oomoo`2UOol00`00Oomoo`3`Ool003Qoo`03001oogoo05Yoo`03001oogoo021oo`03001oogoo0:Io
o`03001oogoo0?1oo`00>7oo0P00G7oo00<007ooOol07Woo00<007ooOol0Ygoo0P00lGoo000OOol3
0006Ool20005Ool40005Ool00`00Oomoo`1LOol00`00Oomoo`0LOol00`00Oomoo`2?Ool30006Ool2
0005Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol00005Ool20009Ool00`00Oomoo`02
Ool00`00Oomoo`1MOol00`00Oomoo`0JOol00`00Oomoo`2?Ool01@00Oomoogoo00001Goo0P002Goo
00<007ooOol00Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo00<0
07ooOol0GWoo00<007ooOol067oo00<007ooOol0T7oo00D007ooOomoo`00011oo`03001oogoo009o
o`03001oogoo0?1oo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`80061oo`03001oogoo
01Ioo`03001oogoo095oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003aOol001ioo`05001o
ogooOol0000<Ool40005Ool00`00Oomoo`1POol00`00Oomoo`0DOol00`00Oomoo`2BOol01@00Oomo
ogoo000037oo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo
00<007ooOol0HGoo00<007ooOol04Woo00<007ooOol0Tgoo00D007ooOomoo`0000aoo`03001oogoo
00Ioo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`8006=oo`<000mo
o`8009Ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003aOol001moo`<000eoo`@000Eoo`03
001oogoo06Eoo`03001oogoo00Yoo`8009Uoo`<000eoo`@000Eoo`03001oogoo0?1oo`00>7oo00<0
07ooOol0IWoo0P001goo0`00]7oo00<007ooOol0l7oo000hOol00`00Oomoo`1XOol7002gOol00`00
Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000GOol30006Ool2
0006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomoo`04
Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool0
0`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo
00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo
009oo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Io
o`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003Woo00<007ooOol00goo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00003goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03
001oogoo00Ioo`800?5oo`005goo0`0037oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`0037oo
1@0017oo10001Goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00
ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?mo
obMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolX
Ool2003aOol002moo`D000Aoo`03001oogoo0?mooaioo`D000Aoo`03001oogoo0?1oo`00<Goo00<0
07ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomo
o`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001oogoo
0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00
Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00nGoo
003oOoooOomFOol00?mooomooeIoo`00UGoo0`0000Aoo`00000001Qoo`<00?moo`Moo`<00004Ool0
0000000IOol3001dOol009Ioo`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000ogoo1goo
00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001aoo`03001o
ogoo0?moo`Eoo`05001oogooOol0000HOol5001dOol009Ioo`05001oogooOol00009Ool6000=Ool0
0`00Oomoo`3oOol5Ool01@00Oomoogoo00002Goo1P002Goo00@007ooOol007Eoo`00UWoo00D007oo
Oomoo`0001Yoo`800?moo`Qoo`05001oogooOol0000IOol00`00Ool0001eOol009Eoo`D001eoo`03
001oogoo0?moo`Aoo`D001Yoo`03001oo`0007Eoo`00/goo00D007ooOomoo`000?moobIoo`8007Eo
o`00]7oo0`00ogoo:7oo00<007ooOol0Lgoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo003oOoooOomFOol002moo`D00?moobEoo`D00?Moo`00<Goo00<007oo
Ool0ogoo9goo00<007ooOol0mgoo000VOol60005Ool00`00Oomoo`3oOolLOol60005Ool00`00Oomo
o`3gOol0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<007oo
Ool017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04
Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`80
06Ioo`l00:]oo`03001oogoo00Aoo`800?5oo`00;goo0`001Woo00<007ooOol0G7oo2@003goo1`00
XWoo0`001Woo00<007ooOol0l7oo000hOol00`00Oomoo`1HOol4000OOol3002XOol00`00Oomoo`3`
Ool003Qoo`03001oogoo05Eoo`<002Ioo`<00:Eoo`03001oogoo0?1oo`00>7oo0P00Dgoo0`00;7oo
0`00XWoo0P00lGoo000hOol00`00Oomoo`1?Ool3000bOol3002OOol00`00Oomoo`3`Ool003Qoo`03
001oogoo04eoo`8003Qoo`<009aoo`03001oogoo0?1oo`00>7oo0P00Bgoo0`00?Goo0`00VGoo0P00
lGoo000hOol00`00Oomoo`18Ool20013Ool3002FOol00`00Oomoo`3`Ool003Qoo`03001oogoo04Io
o`8004Qoo`<009=oo`03001oogoo0?1oo`00>7oo00<007ooOol0A7oo0P00CGoo00<007ooOol0T7oo
00<007ooOol0X7oo1P00BWoo000hOol20013Ool2001@Ool2002@Ool2002LOol50006Ool50015Ool0
01Moo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo045oo`03001oogoo059oo`80
06eoo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo09Qoo`<0011oo`<0049oo`00
5Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo03mo
o`8005Moo`03001oogoo06Uoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool00`00Oomoo`2GOol00`00Oomoo`0DOol00`00Oomoo`0oOol000ioo`H0009oo`05001oogoo
Ool0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0mOol2001JOol2001QOol60002
Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0UWoo00<007oo
Ool05Woo00<007ooOol0?Woo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo0P00?7oo0P00GWoo0P00Igoo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`8009Eoo`8001Yoo`8003ioo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03
001oogoo03Yoo`03001oogoo061oo`03001oogoo06Aoo`05001oogooOol0000>Ool00`00Oomoo`03
Ool40005Ool00`00Oomoo`2BOol2000NOol2000lOol001Ioo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`0hOol2001TOol2001TOol01@00Oomoogoo00003goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol0TGoo00<007ooOol087oo00<007ooOol0>Goo000F
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8003Moo`8006Qoo`80
069oo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00TGoo00<007oo
Ool08Woo00<007ooOol0>7oo000GOol3000<Ool50004Ool40005Ool00`00Oomoo`0eOol00`00Oomo
o`1ZOol00`00Oomoo`1POol3000<Ool50004Ool40005Ool00`00Oomoo`2?Ool00`00Oomoo`0SOol0
0`00Oomoo`0hOol003Qoo`03001oogoo03=oo`8006ioo`80085oo`03001oogoo08ioo`03001oogoo
02Eoo`03001oogoo03Moo`00>7oo00<007ooOol0<Woo00<007ooOol0L7oo00<007ooOol0OWoo00<0
07ooOol0SGoo00<007ooOol09goo00<007ooOol0=Woo000hOol2000bOol00`00Oomoo`1bOol00`00
Oomoo`1mOol2002=Ool00`00Oomoo`0YOol00`00Oomoo`0eOol003Qoo`03001oogoo02moo`8007Io
o`8007eoo`03001oogoo08]oo`03001oogoo02]oo`03001oogoo03Aoo`00>7oo00<007ooOol0;Woo
00<007ooOol0N7oo00<007ooOol0NWoo00<007ooOol0Rgoo00<007ooOol0;7oo00<007ooOol0<goo
000hOol2000^Ool00`00Oomoo`1jOol00`00Oomoo`1iOol2002;Ool00`00Oomoo`0^Ool00`00Oomo
o`0bOol003Qoo`03001oogoo02aoo`03001oogoo07aoo`03001oogoo07Qoo`03001oogoo08Uoo`03
001oogoo031oo`03001oogoo035oo`00>7oo00<007ooOol0:Woo0P00P7oo0P00N7oo00<007ooOol0
R7oo00<007ooOol0<Woo00<007ooOol0<7oo000hOol00`00Oomoo`0YOol00`00Oomoo`22Ool00`00
Oomoo`1eOol00`00Oomoo`27Ool00`00Oomoo`0cOol00`00Oomoo`0`Ool003Qoo`8002Uoo`03001o
ogoo08Aoo`03001oogoo07Aoo`8008Qoo`03001oogoo03Aoo`03001oogoo02moo`007goo0`001Woo
0P001Goo10001Goo00<007ooOol09Woo0P00R7oo0P00Fgoo0`001Woo0P001Goo10001Goo00<007oo
Ool0QWoo00<007ooOol0=Woo00<007ooOol0;Woo000NOol01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol00Woo00<007ooOol09Goo00<007ooOol0RWoo00<007ooOol0Egoo00D007ooOomoo`0000Eo
o`8000Uoo`03001oogoo009oo`03001oogoo08Eoo`03001oogoo03Qoo`03001oogoo02eoo`005Woo
1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`8002Eoo`03001oogoo08aoo`03001oogoo
04ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool20025Ool00`00Oomoo`0jOol00`00
Oomoo`0/Ool001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0SOol00`00Oomo
o`2>Ool00`00Oomoo`1EOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0Pgoo00<0
07ooOol0?7oo00<007ooOol0:goo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol08Goo
0P00TWoo00<007ooOol0E7oo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo089oo`03001oogoo
03eoo`03001oogoo02]oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo021o
o`03001oogoo09=oo`03001oogoo05=oo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomo
o`22Ool00`00Oomoo`0nOol00`00Oomoo`0ZOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06
Ool2000POol00`00Oomoo`2EOol00`00Oomoo`1BOol01@00Oomoogoo000037oo00<007ooOol01Woo
0P00PWoo00<007ooOol0@7oo00<007ooOol0:Goo000OOol3000=Ool40005Ool00`00Oomoo`0NOol0
0`00Oomoo`2GOol00`00Oomoo`1BOol3000=Ool40005Ool00`00Oomoo`20Ool00`00Oomoo`12Ool0
0`00Oomoo`0XOol003Qoo`03001oogoo01eoo`03001oogoo09Uoo`03001oogoo06Yoo`03001oogoo
07moo`03001oogoo04Aoo`03001oogoo02Moo`00>7oo00<007ooOol077oo00<007ooOol0Vgoo00<0
07ooOol0JGoo00<007ooOol0OWoo00<007ooOol0AWoo00<007ooOol09Woo000hOol2000LOol00`00
Oomoo`2MOol00`00Oomoo`1XOol2001oOol00`00Oomoo`16Ool00`00Oomoo`0VOol003Qoo`03001o
ogoo01Yoo`03001oogoo09moo`03001oogoo06Moo`03001oogoo07eoo`03001oogoo04Qoo`03001o
ogoo02Eoo`00>7oo00<007ooOol067oo0P00Xgoo00<007ooOol0IWoo00<007ooOol0O7oo00<007oo
Ool0BWoo00<007ooOol097oo000hOol2000HOol00`00Oomoo`2TOol2001VOol2001lOol00`00Oomo
o`1;Ool00`00Oomoo`0TOol003Qoo`03001oogoo01Ioo`03001oogoo0:Moo`03001oogoo06=oo`03
001oogoo07]oo`03001oogoo04aoo`03001oogoo02=oo`00>7oo00<007ooOol05Goo00<007ooOol0
ZGoo00<007ooOol0HWoo00<007ooOol0NWoo00<007ooOol0CWoo00<007ooOol08Woo000hOol00`00
Oomoo`0DOol00`00Oomoo`2[Ool00`00Oomoo`1QOol00`00Oomoo`1iOol00`00Oomoo`1?Ool00`00
Oomoo`0ROol003Qoo`8001Aoo`03001oogoo0:eoo`03001oogoo061oo`8007Yoo`03001oogoo051o
o`03001oogoo025oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol04Woo00<007oo
Ool0[goo00<007ooOol0?Woo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0N7oo00<007oo
Ool0DGoo00<007ooOol08Goo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03
001oogoo009oo`03001oogoo015oo`03001oogoo0;5oo`03001oogoo03aoo`05001oogooOol00005
Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0Mgoo00<007ooOol0Dgoo00<0
07ooOol087oo000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo
0P004Goo00<007ooOol0/goo00<007ooOol0<goo1P000Woo00D007ooOomoo`0000eoo`03001oogoo
00Qoo`03001oogoo009oo`8007Moo`03001oogoo05Eoo`03001oogoo01moo`005Woo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00moo`03001oogoo0;Eoo`8003]o
o`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`1fOol00`00Oomo
o`1EOol00`00Oomoo`0OOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00
Oomoo`0>Ool00`00Oomoo`2hOol00`00Oomoo`0hOol01@00Oomoogoo00003goo00<007ooOol00Woo
10001Goo00<007ooOol0MGoo00<007ooOol0Egoo00<007ooOol07Woo000FOol01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol03Goo00<007ooOol0^Woo00<007ooOol0
=goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo07Aoo`03001o
ogoo05Uoo`03001oogoo01eoo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool2000=Ool00`00Oomoo`2lOol00`00Oomoo`0fOol01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`8007Eoo`03001oogoo05Uoo`03001oogoo01eoo`005goo0`00
3Goo0`001Goo10001Goo00<007ooOol02goo00<007ooOol0_Woo00<007ooOol0=Woo0`003Goo0`00
1Goo10001Goo00<007ooOol0Lgoo00<007ooOol0Fgoo00<007ooOol077oo000hOol00`00Oomoo`0:
Ool00`00Oomoo`0BOol30006Ool20004Ool5000HOol30006Ool20006Ool3000HOol30006Ool20005
Ool3000JOol30006Ool20005Ool3000FOol00`00Oomoo`08Ool50019Ool00`00Oomoo`0OOol30006
Ool20004Ool5000HOol30006Ool20006Ool3000DOol01000Oomoogoo0`001Woo0P001Goo0`006Goo
0`001Woo0P001Goo0`0077oo00<007ooOol00Woo1@0057oo000hOol2000:Ool00`00Oomoo`0BOol0
1@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00
Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Qoo`05001oogooOol00005
Ool20004Ool01@00Oomoogoo00005Woo00<007ooOol02Goo00<007ooOol0BGoo0P007goo00D007oo
Oomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomoogoo00001Goo0P001goo00<007ooOol0
4Woo00D007ooOomoo`0000=oo`03001oogoo00=oo`8000Aoo`05001oogooOol0000GOol01@00Oomo
ogoo00001Goo0P0017oo00D007ooOomoo`0001]oo`03001oogoo00Aoo`03001oogoo01Aoo`00>7oo
00<007ooOol027oo00<007ooOol04goo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogoo
Ool0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;
Ool01@00Oomoogoo00005goo00<007ooOol027oo00<007ooOol0BGoo00<007ooOol07Woo00D007oo
Oomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000BOol00`00Oomoo`02Ool01@00
Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo000077oo
00<007ooOol00goo00<007ooOol057oo000hOol00`00Oomoo`07Ool00`00Oomoo`0DOol01@00Oomo
ogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo
00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo000067oo00<007oo
Ool01goo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05
001oogooOol0000;Ool01000Oomoo`004goo00<007ooOol00Woo00D007ooOomoo`0000]oo`05001o
ogooOol0000GOol01@00Oomoogoo00002goo00D007ooOomoo`0001eoo`03001oogoo009oo`03001o
ogoo01Aoo`00>7oo00<007ooOol01Goo0P005goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05
001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10006Goo00D007ooOomoo`00
00aoo`<001Yoo`8000Moo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000?Ool00`00
Oomoo`0EOol01@00Oomoogoo000037oo00<007oo00004Woo00<007ooOol00goo00D007ooOomoo`00
00]oo`@001Qoo`05001oogooOol0000<Ool3000NOol00`00Oomoo`02Ool00`00Oomoo`0DOol003Qo
o`8000Eoo`03001oogoo01Moo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo0000
37oo00<007oo000067oo00D007ooOomoo`0000]oo`03001oogoo01Yoo`05001oogooOol0000;Ool0
1@00Oomoogoo00006goo00<007ooOol017oo00<007ooOol0BGoo0P007goo00D007ooOomoo`0000mo
o`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000BOol00`00Oomoo`03Ool01@00Oomo
ogoo00002goo00<007ooOol06Goo00D007ooOomoo`0000]oo`05001oogooOol0000NOol01@00Oomo
ogoo00005Woo000hOol00`00Oomoo`03Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007oo
Oomoo`0001Moo`05001oogooOol0000=Ool2000HOol01@00Oomoogoo000037oo00<007ooOol06Goo
00D007ooOomoo`0000]oo`05001oogooOol0000LOol00`00Oomoo`03Ool00`00Oomoo`19Ool00`00
Oomoo`0NOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000=Ool2000A
Ool00`00Oomoo`04Ool01@00Oomoogoo000037oo00<007ooOol067oo00D007ooOomoo`0000]oo`05
001oogooOol0000NOol01@00Oomoogoo00005Woo000hOol00`00Oomoo`02Ool00`00Oomoo`0JOol3
000=Ool3000IOol3000?Ool00`00Oomoo`0GOol3000>Ool3000IOol3000=Ool3000NOol00`00Oomo
o`03001;Ool00`00Oomoo`0OOol3000=Ool3000IOol3000?Ool00`00Oomoo`0?Ool00`00Oomoo`05
Ool3000>Ool3000HOol3000=Ool3000POol4000FOol003Qoo`05001oogooOol0003DOol00`00Oomo
o`1=Ool00`00Oomoo`1^Ool00`00Oomoo`1VOol00`00Oomoo`0FOol003Qoo`800003Ool007oo0=Eo
o`03001oogoo04aoo`8006moo`03001oogoo06Ioo`03001oogoo01Ioo`00>7oo00<007oo0000f7oo
00<007ooOol0Bgoo00<007ooOol0KGoo00<007ooOol0J7oo00<007ooOol05Goo000hOol2003JOol0
0`00Oomoo`1:Ool00`00Oomoo`1/Ool00`00Oomoo`1ZOol00`00Oomoo`0DOol0039oonT0041oonT0
011oo`00>7oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol0BGoo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol057oo000hOol00`00Oomoo`0YOol00`00Oomoo`0Y
Ool00`00Oomoo`0YOol00`00Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomoo`19Ool2000ZOol00`00
Oomoo`0YOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00
Oomoo`0DOol003Qoo`03001oogoo0?moobMoo`03001oo`0006Yoo`03001oogoo08=oo`00>7oo0P00
ogoo:7oo0`00JGoo00<007ooOol0Q7oo000hOol00`00Oomoo`3oOolWOol01000Oomoo`00J7oo00<0
07ooOol0Q7oo000hOol00`00Oomoo`3oOolWOol01000Oomoo`00Igoo00<007ooOol0QGoo000hOol2
003oOolXOol20002Ool00`00Oomoo`1TOol00`00Oomoo`25Ool003Qoo`03001oogoo0?moobMoo`03
001oogoo009oo`03001oogoo069oo`03001oogoo08Ioo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool00Woo00<007ooOol0HGoo00<007ooOol0Qgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`03
Ool00`00Oomoo`1POol00`00Oomoo`27Ool003Qoo`800?moobQoo`8000Aoo`03001oogoo05moo`03
001oogoo08Qoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol017oo00<007ooOol0GWoo00<007oo
Ool0R7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`05Ool00`00Oomoo`1LOol00`00Oomoo`29
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Eoo`03001oogoo05]oo`03001oogoo08Yoo`00
>7oo0P00ogoo:7oo0P001goo00<007ooOol0FWoo00<007ooOol0RWoo000GOol30006Ool20004Ool5
0004Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`06
Ool00`00Oomoo`1IOol00`00Oomoo`2;Ool001Ioo`05001oogooOol00005Ool20005Ool01000Oomo
o`0027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Eoo`04001o
ogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`1HOol00`00Oomoo`2;Ool001Io
o`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo0P002Goo00<007ooOol0EWoo00<007ooOol0S7oo
000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo
05Eoo`03001oogoo08eoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001o
ogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`09Ool00`00
Oomoo`1COol00`00Oomoo`2>Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol02Goo00<007ooOol0Dgoo00<007ooOol0SWoo000FOol01@00Oomoogoo00002goo00D0
07ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo
000017oo00<007ooOol01Woo0P002goo00<007ooOol0DGoo00<007ooOol0Sgoo000GOol3000=Ool3
0005Ool40005Ool00`00Oomoo`3oOol6Ool3000=Ool30005Ool40005Ool00`00Oomoo`0;Ool00`00
Oomoo`1?Ool00`00Oomoo`2@Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00]oo`03001oogoo
04moo`03001oogoo091oo`00>7oo0P00ogoo:7oo0P003Goo00<007ooOol0CGoo00<007ooOol0TGoo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0<Ool00`00Oomoo`1<Ool00`00Oomoo`2BOol003Qo
o`03001oogoo0?moobMoo`03001oogoo00eoo`03001oogoo04Yoo`03001oogoo09=oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol03Woo00<007ooOol0BGoo00<007ooOol0Tgoo000hOol2003oOolX
Ool2000?Ool00`00Oomoo`18Ool00`00Oomoo`2DOol003Qoo`03001oogoo0?moobMoo`03001oogoo
00moo`03001oogoo04Ioo`03001oogoo09Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol03goo
00<007ooOol0AWoo00<007ooOol0UGoo000hOol2003oOolXOol2000AOol00`00Oomoo`14Ool00`00
Oomoo`2FOol003Qoo`03001oogoo0?moobMoo`03001oogoo015oo`03001oogoo049oo`03001oogoo
09Moo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo
00<007ooOol04Woo00<007ooOol0@7oo00<007ooOol0V7oo000NOol01@00Oomoogoo00001Goo0P00
2Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo
009oo`03001oogoo01=oo`03001oogoo03ioo`03001oogoo09Uoo`007Woo00D007ooOomoo`00011o
o`03001oogoo009oo`800?moo`ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000EOol00`00
Oomoo`0lOol00`00Oomoo`2JOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomo
o`3oOol=Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol057oo00<007ooOol0?7oo
00<007ooOol0VWoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007oo
Oomoo`0000aoo`@000Eoo`03001oogoo01Eoo`03001oogoo03Yoo`03001oogoo09]oo`007Woo00D0
07ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00
Oomoo`06Ool00`00Oomoo`0FOol00`00Oomoo`0hOol00`00Oomoo`2LOol001ioo`05001oogooOol0
000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P0067oo
00<007ooOol0=Woo00<007ooOol0WGoo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=
Ool40005Ool00`00Oomoo`0HOol00`00Oomoo`0dOol00`00Oomoo`2NOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo01Uoo`03001oogoo039oo`03001oogoo09moo`00>7oo0P00ogoo:7oo0P006goo
00<007ooOol0<7oo00<007ooOol0X7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0KOol00`00
Oomoo`0^Ool00`00Oomoo`2QOol003Qoo`03001oogoo0?moobMoo`03001oogoo01aoo`03001oogoo
02aoo`03001oogoo0:9oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol07Goo00<007ooOol0:Woo
00<007ooOol0Xgoo000hOol2003oOolXOol2000OOol00`00Oomoo`0XOol00`00Oomoo`2TOol003Qo
o`03001oogoo0?moobMoo`03001oogoo01moo`03001oogoo02Ioo`03001oogoo0:Eoo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol087oo00<007ooOol097oo00<007ooOol0YWoo000hOol2003oOolX
Ool2000ROol2000SOol00`00Oomoo`2WOol001Moo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eo
o`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo02=oo`03
001oogoo01moo`03001oogoo0:Qoo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qo
o`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomoo`0MOol00`00Oomoo`2YOol001Ioo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol09Goo00<007ooOol06goo00<007oo
Ool0ZWoo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00ogoo1Woo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8002Moo`<001Qoo`800:eoo`00
5Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogoo
Ool0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`0YOol2000COol3002_Ool001Ioo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0:goo0P003goo0P00/Woo000FOol0
1@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05
001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0;Goo0`002Woo
0P00]7oo000GOol3000<Ool50004Ool40005Ool2003oOol7Ool3000<Ool50004Ool40005Ool2000a
Ool:002fOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo
00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00;goo1@00
17oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomo
o`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?mo
ob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007oo
Ool017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?mo
obMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3003oOolW
Ool3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo1@00ogoo1Goo
0`0000Aoo`00000001Moo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo0?mo
o`Ioo`05001oogooOol00009Ool6000:Ool01000Oomoo`00M7oo002FOol01@00Oomoogoo00006goo
00<007ooOol0ogoo1Woo00D007ooOomoo`0001Yoo`03001oogoo07Aoo`00UWoo00D007ooOomoo`00
00Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1cOol0
09Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo000077oo00<007ooOol0
LWoo002EOol5000LOol00`00Oomoo`3oOol5Ool5000MOol00`00Oomoo`1bOol00;Ioo`03001oogoo
0?moob=oo`05001oogooOol0001dOol00;Aoo`<00?moobIoo`<007Eoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .20629 L
.08255 .15782 L
.10458 .11164 L
.12507 .07703 L
.14415 .05331 L
.14918 .04854 L
.15465 .0441 L
.15946 .04083 L
.16457 .03802 L
.16917 .03609 L
.17178 .03524 L
.17423 .03461 L
.17538 .03437 L
.17647 .03418 L
.17746 .03403 L
.17852 .0339 L
.17967 .03379 L
.18073 .03372 L
.182 .03368 L
.18314 .03369 L
.18435 .03372 L
.18547 .0338 L
.1867 .03391 L
.18802 .03409 L
.19071 .03458 L
.19317 .0352 L
.1979 .03686 L
.20239 .03898 L
.21236 .04559 L
.22321 .05568 L
.24299 .08149 L
.26399 .11839 L
.30174 .20404 L
.34195 .31086 L
.38063 .41358 L
.40028 .46082 L
.42177 .50589 L
.44253 .54102 L
.4614 .56451 L
.47149 .57346 L
.47611 .5767 L
.48101 .57951 L
.4835 .58069 L
.48624 .5818 L
.48876 .58265 L
.49106 .58328 L
.49378 .58383 L
.49527 .58405 L
.49596 .58413 L
Mistroke
.49669 .58421 L
.498 .5843 L
.49921 .58434 L
.49996 .58435 L
.50065 .58435 L
.50196 .5843 L
.50313 .58422 L
.50438 .58409 L
.50556 .58394 L
.50663 .58376 L
.50926 .5832 L
.51175 .58249 L
.5167 .5806 L
.52208 .57781 L
.53169 .57093 L
.54056 .56247 L
.55926 .53834 L
.57988 .50271 L
.62014 .41164 L
.65888 .30862 L
.70007 .1995 L
.72063 .1507 L
.73974 .11117 L
.75939 .07791 L
.77791 .05451 L
.78775 .0455 L
.79293 .04176 L
.7984 .03856 L
.80302 .03649 L
.80546 .03562 L
.80809 .03486 L
.8105 .03433 L
.8127 .03399 L
.81375 .03387 L
.81491 .03377 L
.81599 .03371 L
.817 .03368 L
.81818 .03369 L
.81941 .03373 L
.82047 .0338 L
.82163 .03391 L
.82287 .03408 L
.82421 .03429 L
.82661 .03481 L
.82905 .03549 L
.83134 .03628 L
.83564 .03813 L
.84078 .04098 L
.84552 .04423 L
.85624 .0537 L
Mistroke
.87498 .07709 L
.89561 .11199 L
.93591 .20216 L
.97471 .30497 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .43101 L
.08255 .48397 L
.0932 .50724 L
.10458 .5278 L
.11009 .53602 L
.11531 .54268 L
.12038 .5481 L
.12507 .55216 L
.12951 .55515 L
.13178 .55635 L
.13422 .55739 L
.13549 .55784 L
.13666 .55818 L
.13784 .55847 L
.13895 .55868 L
.14022 .55887 L
.1409 .55893 L
.14161 .55898 L
.1423 .55901 L
.14295 .55902 L
.14415 .55898 L
.14531 .55889 L
.14656 .55872 L
.14773 .5585 L
.14881 .55825 L
.15143 .55742 L
.15392 .55636 L
.15886 .55347 L
.16423 .54914 L
.17383 .53844 L
.1827 .52525 L
.20137 .48814 L
.22197 .43474 L
.26217 .30814 L
.30086 .1861 L
.32051 .1344 L
.3309 .11159 L
.342 .09132 L
.35275 .07612 L
.35784 .07055 L
.36253 .06637 L
.36724 .0631 L
.36972 .06176 L
.37235 .06063 L
.37463 .05989 L
.37573 .05961 L
.37677 .0594 L
.37799 .05921 L
.37911 .05909 L
Mistroke
.38031 .05903 L
.38162 .05903 L
.38227 .05905 L
.38296 .0591 L
.38419 .05924 L
.38551 .05947 L
.38695 .0598 L
.38955 .06062 L
.39197 .06165 L
.39649 .06425 L
.40134 .068 L
.40698 .07361 L
.41232 .08012 L
.42232 .09535 L
.44227 .13647 L
.4607 .18512 L
.50002 .30909 L
.53782 .42867 L
.55884 .48419 L
.56803 .50449 L
.57808 .52337 L
.58722 .53729 L
.59696 .54848 L
.60236 .55298 L
.60726 .556 L
.60962 .55709 L
.61086 .55756 L
.61218 .55799 L
.61333 .55831 L
.61459 .55859 L
.61574 .55878 L
.61682 .55891 L
.61808 .559 L
.61871 .55901 L
.61941 .55901 L
.62065 .55896 L
.62181 .55885 L
.62248 .55876 L
.62318 .55865 L
.62443 .55839 L
.62578 .55803 L
.62725 .55755 L
.62973 .55654 L
.63238 .55516 L
.63715 .55192 L
.64214 .5475 L
.64686 .54237 L
.6557 .53035 L
.67568 .4924 L
.69413 .44605 L
Mistroke
.7335 .32417 L
.77136 .20279 L
.79241 .1448 L
.81166 .1027 L
.82118 .08664 L
.8262 .07956 L
.83155 .07313 L
.8367 .06806 L
.84136 .06442 L
.84361 .06299 L
.84604 .06169 L
.84835 .0607 L
.85045 .05999 L
.85159 .05969 L
.85283 .05942 L
.85414 .05921 L
.85538 .05908 L
.85653 .05903 L
.85776 .05903 L
.85881 .05908 L
.85997 .05919 L
.86063 .05928 L
.86132 .0594 L
.86256 .05966 L
.86535 .06048 L
.86777 .06147 L
.87041 .06284 L
.87569 .06646 L
.88133 .07164 L
.89148 .08424 L
.90173 .10105 L
.91284 .12354 L
.933 .17412 L
.97393 .30158 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .27022 L
.10458 .22866 L
.14415 .19101 L
.18221 .1567 L
.22272 .12282 L
.26171 .09334 L
.30316 .06592 L
.34309 .04379 L
.3815 .02683 L
.40095 .01995 L
.42237 .01376 L
.44268 .00924 L
.45178 .00766 L
.46172 .00624 L
.4671 .0056 L
.4721 .0051 L
.47727 .00466 L
.48196 .00434 L
.48658 .0041 L
.4887 .00402 L
.49093 .00394 L
.49332 .00388 L
.49438 .00386 L
.49552 .00384 L
.49675 .00382 L
.49789 .00381 L
.49859 .00381 L
.49925 .00381 L
.50049 .0038 L
.50163 .00381 L
.50286 .00382 L
.50401 .00383 L
.50508 .00385 L
.50754 .0039 L
.51014 .00398 L
.51268 .00407 L
.51504 .00418 L
.5204 .0045 L
.5293 .00523 L
.53882 .0063 L
.54906 .00779 L
.56016 .0098 L
.58032 .01445 L
.62123 .02789 L
.66064 .04566 L
.69852 .06694 L
.73886 .09375 L
.77769 .12314 L
.81897 .15772 L
Mistroke
.85873 .19369 L
.89697 .23016 L
.93767 .27034 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .38312 L
.10458 .45832 L
.14415 .5186 L
.18221 .56321 L
.20178 .58009 L
.21267 .58754 L
.22272 .59314 L
.23293 .59756 L
.23832 .59936 L
.24402 .60087 L
.24641 .60137 L
.24897 .60184 L
.25119 .60218 L
.25361 .60247 L
.25507 .60261 L
.25643 .60272 L
.25773 .6028 L
.2584 .60283 L
.25912 .60286 L
.25983 .60288 L
.26048 .6029 L
.26176 .60291 L
.26293 .6029 L
.26416 .60288 L
.26538 .60283 L
.26607 .6028 L
.26671 .60276 L
.26912 .60258 L
.27131 .60234 L
.27364 .60203 L
.27847 .60116 L
.2838 .59985 L
.29326 .59665 L
.30213 .59262 L
.32232 .57987 L
.34082 .56397 L
.38045 .51752 L
.41855 .45944 L
.45912 .38733 L
.49816 .31258 L
.53966 .233 L
.57964 .16161 L
.61811 .1025 L
.63759 .0774 L
.65902 .05421 L
.67938 .0369 L
.69843 .02513 L
.70884 .02058 L
.71396 .01884 L
Mistroke
.71872 .01752 L
.72301 .01658 L
.72758 .01583 L
.7302 .01552 L
.73148 .0154 L
.73266 .01531 L
.73371 .01525 L
.73487 .01519 L
.73603 .01515 L
.73725 .01513 L
.73856 .01513 L
.73977 .01514 L
.7404 .01516 L
.7411 .01518 L
.74251 .01525 L
.74375 .01533 L
.74508 .01544 L
.74748 .01569 L
.74985 .01601 L
.75235 .01642 L
.7568 .01736 L
.76198 .01877 L
.7668 .02038 L
.77773 .02511 L
.78828 .03109 L
.79823 .03795 L
.81683 .05389 L
.85534 .09875 L
.89632 .16122 L
.93577 .23157 L
.97371 .30421 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`0OOol6002=Ool7001]Ool00`00Oomoo`3`Ool003Qoo`03001oogoo01eoo`<000Eoo`<0
08Qoo`<000Eoo`8006aoo`03001oogoo0?1oo`00>7oo00<007ooOol06goo0P002goo00<007ooOol0
Q7oo00<007ooOol027oo0P00JWoo00<007ooOol0l7oo000hOol2000KOol00`00Oomoo`0<Ool00`00
Oomoo`22Ool00`00Oomoo`0;Ool00`00Oomoo`1WOol2003aOol003Qoo`03001oogoo01Yoo`03001o
ogoo00eoo`03001oogoo081oo`03001oogoo00eoo`03001oogoo06Ioo`03001oogoo0?1oo`00>7oo
00<007ooOol06Goo00<007ooOol03goo00<007ooOol0OWoo00<007ooOol03goo00<007ooOol0IGoo
00<007ooOol0l7oo000hOol00`00Oomoo`0HOol00`00Oomoo`0@Ool00`00Oomoo`1mOol00`00Oomo
o`0@Ool00`00Oomoo`1UOol00`00Oomoo`1=Ool6001XOol6000_Ool003Qoo`8001Qoo`03001oogoo
019oo`03001oogoo07]oo`03001oogoo019oo`03001oogoo06Aoo`8004eoo`03001oogoo00Aoo`03
001oogoo06Aoo`8000Eoo`03001oogoo02aoo`005goo0`001Woo0P001Woo00<007ooOol017oo1000
1Goo00<007ooOol05Woo00<007ooOol057oo00<007ooOol0NGoo00<007ooOol057oo00<007ooOol0
@Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0Bgoo00<007ooOol01Woo0P00
Hgoo00<007ooOol01Woo0P00;7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo
00<007ooOol00Woo00<007ooOol05Goo00<007ooOol05Woo00<007ooOol0Mgoo00<007ooOol05Woo
00<007ooOol0@7oo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo04Yoo`03001oogoo00Uoo`03001oogoo05moo`03001oogoo00Uoo`03001oogoo02Uoo`00
3Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8001Eoo`03001o
ogoo01Qoo`03001oogoo07Eoo`03001oogoo01Qoo`03001oogoo03Moo`H0009oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2001:Ool00`00Oomoo`0:Ool00`00Oomoo`1OOol0
0`00Oomoo`09Ool00`00Oomoo`0YOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`0DOol00`00Oomoo`0IOol00`00Oomoo`1dOol00`00Oomoo`0HOol00`00
Oomoo`0oOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0BGoo
00<007ooOol02goo00<007ooOol0GGoo00<007ooOol02goo00<007ooOol0:7oo000FOol01@00Oomo
ogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol04goo00<007ooOol06Woo00<007ooOol0
Lgoo00<007ooOol06Woo00<007ooOol0?Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eo
o`03001oogoo04Qoo`03001oogoo00aoo`03001oogoo05aoo`03001oogoo00eoo`03001oogoo02Mo
o`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01=oo`03
001oogoo01]oo`03001oogoo079oo`03001oogoo01]oo`03001oogoo03eoo`05001oogooOol0000?
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`17Ool00`00Oomoo`0>Ool00`00Oomoo`1K
Ool00`00Oomoo`0=Ool00`00Oomoo`0WOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P004goo00<007ooOol077oo00<007ooOol0LGoo00<007ooOol077oo00<0
07ooOol0?Goo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20018Ool0
0`00Oomoo`0?Ool00`00Oomoo`1IOol00`00Oomoo`0?Ool00`00Oomoo`0VOol001Moo`<000aoo`D0
00Aoo`@000Eoo`03001oogoo019oo`03001oogoo01eoo`03001oogoo071oo`03001oogoo01eoo`03
001oogoo03eoo`<000aoo`D000Aoo`@000Eoo`03001oogoo04Ioo`03001oogoo011oo`03001oogoo
05Qoo`03001oogoo011oo`03001oogoo02Ioo`00>7oo00<007ooOol04Goo00<007ooOol07goo00<0
07ooOol0KWoo00<007ooOol07Woo00<007ooOol0GWoo00<007ooOol0AGoo00<007ooOol04Woo00<0
07ooOol0EWoo00<007ooOol04Woo00<007ooOol09Goo000hOol2000BOol00`00Oomoo`0OOol00`00
Oomoo`1^Ool00`00Oomoo`0OOol00`00Oomoo`1MOol20016Ool00`00Oomoo`0BOol00`00Oomoo`1F
Ool00`00Oomoo`0BOol00`00Oomoo`0UOol003Qoo`03001oogoo011oo`03001oogoo025oo`03001o
ogoo06aoo`03001oogoo025oo`03001oogoo05aoo`03001oogoo04Aoo`03001oogoo01Aoo`03001o
ogoo05Aoo`03001oogoo01Aoo`03001oogoo02Aoo`00>7oo00<007ooOol047oo00<007ooOol08Goo
00<007ooOol0K7oo00<007ooOol08Goo00<007ooOol0G7oo00<007ooOol0A7oo00<007ooOol057oo
00<007ooOol0E7oo00<007ooOol05Goo00<007ooOol08goo000hOol00`00Oomoo`0?Ool00`00Oomo
o`0SOol00`00Oomoo`1ZOol00`00Oomoo`0SOol00`00Oomoo`1KOol00`00Oomoo`13Ool00`00Oomo
o`0FOol00`00Oomoo`1COol00`00Oomoo`0EOol00`00Oomoo`0SOol003Qoo`80011oo`03001oogoo
02=oo`03001oogoo06Yoo`03001oogoo02=oo`03001oogoo05]oo`8004Aoo`03001oogoo01Ioo`03
001oogoo059oo`03001oogoo01Moo`03001oogoo029oo`00>7oo00<007ooOol03Woo00<007ooOol0
9Goo00<007ooOol0J7oo00<007ooOol09Goo00<007ooOol0FWoo00<007ooOol0@goo00<007ooOol0
5goo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol08Woo000hOol00`00Oomoo`0>Ool00`00
Oomoo`0UOol00`00Oomoo`1WOol00`00Oomoo`0VOol00`00Oomoo`1JOol00`00Oomoo`12Ool00`00
Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`0QOol003Qoo`8000ioo`03001o
ogoo02Ioo`03001oogoo06Moo`03001oogoo02Ioo`03001oogoo05Yoo`8004=oo`03001oogoo01Uo
o`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025oo`007goo0`001Woo0P001Goo10001Goo
00<007ooOol03Goo00<007ooOol09goo00<007ooOol0IGoo00<007ooOol0:7oo00<007ooOol0@7oo
0`001Woo0P001Goo10001Goo00<007ooOol0@Goo00<007ooOol06Woo00<007ooOol0Cgoo00<007oo
Ool06Goo00<007ooOol08Goo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<0
07ooOol03Goo00<007ooOol09goo00<007ooOol0IGoo00<007ooOol0:7oo00<007ooOol0?goo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo045oo`03001oogoo01]oo`03001o
ogoo04eoo`03001oogoo01]oo`03001oogoo021oo`005Woo1P000Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo00aoo`03001oogoo02Uoo`03001oogoo06=oo`03001oogoo02Yoo`03
001oogoo03Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`11Ool00`00
Oomoo`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`0POol001ioo`05001oogooOol0
000@Ool00`00Oomoo`02Ool2000=Ool00`00Oomoo`0YOol00`00Oomoo`1SOol00`00Oomoo`0ZOol0
0`00Oomoo`0nOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00@Goo00<007ooOol077oo00<0
07ooOol0C7oo00<007ooOol077oo00<007ooOol087oo000NOol01@00Oomoogoo000037oo10001Goo
00<007ooOol02goo00<007ooOol0:goo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0?Goo
00D007ooOomoo`0000aoo`@000Eoo`03001oogoo041oo`03001oogoo01eoo`03001oogoo04]oo`03
001oogoo01eoo`03001oogoo01moo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001o
ogoo00]oo`03001oogoo02]oo`03001oogoo065oo`03001oogoo02aoo`03001oogoo03eoo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1;Ool0
0`00Oomoo`0MOol00`00Oomoo`0OOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00
Oomoo`0:Ool00`00Oomoo`0/Ool00`00Oomoo`1QOol00`00Oomoo`0/Ool00`00Oomoo`0mOol01@00
Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0?goo00<007ooOol07Woo00<007ooOol0BWoo
00<007ooOol07Woo00<007ooOol07goo000OOol3000=Ool40005Ool2000;Ool00`00Oomoo`0]Ool0
0`00Oomoo`1OOol00`00Oomoo`0^Ool00`00Oomoo`0mOol3000=Ool40005Ool2000oOol00`00Oomo
o`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`0NOol003Qoo`03001oogoo00Uoo`03
001oogoo02ioo`03001oogoo05moo`03001oogoo02ioo`03001oogoo05Ioo`03001oogoo03ioo`03
001oogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001oogoo01ioo`00>7oo00<007ooOol0
2Goo00<007ooOol0;goo00<007ooOol0GWoo00<007ooOol0;goo00<007ooOol0EGoo00<007ooOol0
?Woo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol087oo00<007ooOol07Woo000hOol20009
Ool00`00Oomoo`0`Ool00`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomoo`1EOol2000nOol00`00
Oomoo`0ROol00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`0MOol003Qoo`03001oogoo00Qo
o`03001oogoo035oo`03001oogoo05aoo`03001oogoo035oo`03001oogoo05Aoo`03001oogoo03eo
o`03001oogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo01eoo`00>7oo00<007oo
Ool027oo00<007ooOol0<Goo00<007ooOol0G7oo00<007ooOol0<Goo00<007ooOol0E7oo00<007oo
Ool0?Goo00<007ooOol08Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol07Goo000hOol0
0`00Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`1KOol00`00Oomoo`0bOol00`00Oomoo`1DOol0
0`00Oomoo`0lOol00`00Oomoo`0TOol00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`0LOol0
03Qoo`8000Qoo`03001oogoo03=oo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo05=oo`80
03eoo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo01aoo`00>7oo00<0
07ooOol01Woo00<007ooOol0=7oo00<007ooOol0FGoo00<007ooOol0=7oo00<007ooOol0Dgoo00<0
07ooOol0?7oo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol077oo000h
Ool00`00Oomoo`06Ool00`00Oomoo`0eOol00`00Oomoo`1HOol00`00Oomoo`0eOol00`00Oomoo`1B
Ool00`00Oomoo`0kOol00`00Oomoo`0VOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`0K
Ool003Qoo`8000Ioo`03001oogoo03Ioo`03001oogoo05Qoo`03001oogoo03Eoo`03001oogoo059o
o`8003aoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01]oo`005goo
0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol01Goo00<007ooOol0=Woo00<007ooOol0Egoo
00<007ooOol0=Woo00<007ooOol0<Goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0>goo
00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol06goo000FOol01@00Oomo
ogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo
03Moo`03001oogoo05Ioo`03001oogoo03Moo`03001oogoo02moo`05001oogooOol00005Ool20005
Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol0
@Goo00<007ooOol09goo00<007ooOol06Woo000>Ool60002Ool01@00Oomoogoo00003Goo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0>7oo00<007ooOol0EGoo00<007oo
Ool0>7oo00<007ooOol09goo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo03Yoo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo
01Yoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000Eoo`03001o
ogoo03Uoo`03001oogoo05Aoo`03001oogoo03Qoo`03001oogoo02moo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool2000kOol00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomo
o`0XOol00`00Oomoo`0JOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00
Oomoo`04Ool00`00Oomoo`0iOol00`00Oomoo`1DOol00`00Oomoo`0iOol00`00Oomoo`0^Ool01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0>Goo00<007ooOol0:Woo00<007oo
Ool0?goo00<007ooOol0:Goo00<007ooOol06Goo000FOol01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0>Woo00<007ooOol0Dgoo00<007ooOol0
>Woo00<007ooOol0;Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo03Uoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo01Uoo`005Woo
00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20004Ool00`00Oomoo`0k
Ool00`00Oomoo`1BOol00`00Oomoo`0kOol00`00Oomoo`0]Ool01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`8003Yoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo
02Yoo`03001oogoo01Uoo`005goo0`003Goo0`001Goo10001Goo00<007ooOol00Woo00<007ooOol0
?7oo00<007ooOol0DWoo00<007ooOol0>goo00<007ooOol0;Woo0`003Goo0`001Goo10001Goo00<0
07ooOol0>7oo00<007ooOol0;7oo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol067oo000h
Ool00`00Oomoo`02Ool00`00Oomoo`0mOol00`00Oomoo`1@Ool00`00Oomoo`0lOol00`00Oomoo`1?
Ool00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`0H
Ool003Qoo`03001oogoo009oo`03001oogoo01Yoo`<000Ioo`8000Aoo`D000moo`03001oogoo00Io
o`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<000]oo`03001oogoo00aoo`<000Ioo`8000Eo
o`<001ioo`03001oogoo00D004Uoo`03001oogoo01moo`<000Ioo`8000Aoo`D000Eoo`03001oogoo
011oo`<000Ioo`8000Ioo`<000Qoo`03001oogoo00eoo`<000Ioo`8000Eoo`<001Uoo`@000Eoo`80
00Eoo`<001moo`03001oo`0000@001Aoo`00>7oo0P000Woo00<007ooOol06Woo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo000?Ool00`00Oomoo`05Ool01@00Oomoogoo00001Goo0P001goo00<0
07ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol00009Ool00`00Oomoo`0<Ool0
1@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001eoo`03001oogoo009oo`03001oogoo04Uo
o`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`001Goo00<007ooOol03goo00D007oo
Oomoo`0000Eoo`8000Moo`03001oogoo00Moo`03001oogoo00aoo`05001oogooOol00005Ool20004
Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000OOol01000
Oomoo`005Woo000hOol01@00Oomoogoo000077oo00D007ooOomoo`0000eoo`03001oogoo011oo`03
001oogoo00Aoo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomoo`00
00Uoo`03001oogoo00aoo`05001oogooOol0000;Ool01@00Oomoogoo00007Goo00<007ooOol00Woo
00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000eoo`03001oogoo00Aoo`03001oogoo
011oo`05001oogooOol0000;Ool50009Ool00`00Oomoo`0;Ool01@00Oomoogoo00002goo00D007oo
Oomoo`0001Moo`03001oogoo008000]oo`05001oogooOol0000OOol01000Oomoo`005Woo000hOol0
1@00Oomoogoo000077oo00D007ooOomoo`0000ioo`03001oogoo00moo`03001oogoo00Aoo`05001o
ogooOol0000;Ool01000Oomoo`0067oo00D007ooOomoo`0000]oo`05001oogooOol00009Ool00`00
Oomoo`0<Ool01@00Oomoogoo00002goo00D007ooOomoo`0001ioo`05001oogooOol0001;Ool00`00
Oomoo`0NOol01@00Oomoogoo00003Woo00<007ooOol00goo00<007ooOol047oo00D007ooOomoo`00
00]oo`04001oogoo000:Ool00`00Oomoo`0;Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Mo
o`03001oogoo008000]oo`05001oogooOol0000OOol01000Oomoo`005Woo000hOol01000Oomoo`00
7Goo00D007ooOomoo`0000moo`03001oogoo00moo`03001oogoo00=oo`05001oogooOol0000<Ool0
0`00Ool0000HOol01@00Oomoogoo00002goo10002Goo00<007ooOol03Goo00D007ooOomoo`0000ao
o`<001moo`05001oogooOol0001;Ool00`00Oomoo`0NOol01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol047oo00D007ooOomoo`0000aoo`03001oo`0000Yoo`03001oogoo00]oo`05001o
ogooOol0000;Ool4000HOol00`00Oomoo`02000<Ool3000QOol00`00Ool0000FOol003Qoo`800003
Ool007oo01aoo`05001oogooOol0000?Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool01@00Oomoogoo
000037oo00<007oo000067oo00D007ooOomoo`0000]oo`03001oogoo00Yoo`03001oogoo00eoo`05
001oogooOol0000;Ool01@00Oomoogoo00007goo00@007ooOol004]oo`8001moo`05001oogooOol0
000?Ool01@00Oomoogoo00004goo00D007ooOomoo`0000aoo`03001oo`0000]oo`03001oogoo00Yo
o`05001oogooOol0000;Ool00`00Oomoo`0IOol01@00Ool007oo00002goo00D007ooOomoo`00021o
o`03001oo`0001Ioo`00>7oo00<007oo00007Woo00D007ooOomoo`0000]oo`05001oogooOol0000A
Ool00`00Oomoo`03Ool01@00Oomoogoo00003Goo0P0067oo00D007ooOomoo`0000aoo`03001oogoo
00Qoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo00007goo00@007ooOol004]o
o`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00000goo00<007ooOol04Goo00D0
07ooOomoo`0000eoo`8000]oo`03001oogoo00Yoo`05001oogooOol0000<Ool00`00Oomoo`0HOol0
1@00Ool007oo00002goo00D007ooOomoo`00021oo`03001oo`0001Ioo`00>7oo00<007oo00007goo
0`003Goo0`004goo00<007ooOol00goo0`003goo00<007ooOol05goo0`003Woo0`001goo00<007oo
Ool03goo0`003Goo0`0087oo1000Bgoo00<007ooOol07goo0`003Goo0`0017oo00<007ooOol04Woo
0`003goo00<007ooOol02Goo00<007ooOol02goo0`003Woo0`0067oo0`003Goo0`008Goo0`005Woo
000hOol30015Ool00`00Oomoo`1:Ool00`00Oomoo`13Ool00`00Oomoo`1;Ool2000fOol00`00Oomo
o`0bOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`0EOol003Qoo`8004Moo`03001oogoo
04Qoo`03001oogoo04Aoo`03001oogoo04]oo`03001oogoo03Eoo`03001oogoo039oo`03001oogoo
03Ioo`03001oogoo039oo`03001oogoo01Eoo`00>7oo0P00Agoo00<007ooOol0B7oo00<007ooOol0
A7oo00<007ooOol0Bgoo00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=Woo00<007ooOol0
<goo00<007ooOol057oo000hOol20017Ool00`00Oomoo`18Ool00`00Oomoo`15Ool00`00Oomoo`1:
Ool00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0D
Ool0039oonT0041oonT0011oo`00>7oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol01Goo00@007ooOol000Yo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qo
o`05001oogooOol00006Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0DOol003Qoo`03
001oogoo04Qoo`03001oogoo04Aoo`03001oogoo09Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03
001oogoo03=oo`03001oogoo04aoo`00>7oo0P00BGoo00<007ooOol0A7oo00<007ooOol0U7oo0P00
=7oo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol0C7oo000hOol00`00Oomoo`18Ool00`00
Oomoo`14Ool00`00Oomoo`2DOol2000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`1<
Ool003Qoo`03001oogoo04Uoo`03001oogoo049oo`03001oogoo09Eoo`8003Aoo`03001oogoo03Io
o`03001oogoo039oo`03001oogoo04aoo`00>7oo00<007ooOol0BGoo00<007ooOol0@Woo00<007oo
Ool0UGoo00<007oo0000<Woo00<007ooOol0>7oo00<007ooOol0<7oo00<007ooOol0CGoo000hOol2
001:Ool00`00Oomoo`12Ool00`00Oomoo`2EOol3000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool0
0`00Oomoo`1=Ool003Qoo`03001oogoo04Yoo`03001oogoo041oo`03001oogoo09Ioo`03001oo`00
039oo`03001oogoo03Qoo`03001oogoo031oo`03001oogoo04eoo`00>7oo00<007ooOol0BWoo00<0
07ooOol0@7oo00<007ooOol0UWoo00@007ooOol0031oo`03001oogoo03Yoo`03001oogoo02ioo`03
001oogoo04ioo`00>7oo00<007ooOol0Bgoo00<007ooOol0?Woo00<007ooOol0Ugoo00@007ooOol0
031oo`03001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo0P00C7oo00<007ooOol0
?Woo00<007ooOol0Ugoo0P0000=oo`00Ool0;goo00<007ooOol0>Woo00<007ooOol0;Woo00<007oo
Ool0CWoo000hOol00`00Oomoo`1;Ool00`00Oomoo`0nOol00`00Oomoo`2GOol01@00Oomoogoo0000
;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo000hOol00`00Oomoo`1<Ool00`00
Oomoo`0lOol00`00Oomoo`2HOol01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007ooOol0;7oo
00<007ooOol0Cgoo000hOol2001=Ool00`00Oomoo`0lOol00`00Oomoo`2HOol20002Ool00`00Oomo
o`0/Ool00`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`1?Ool001Moo`<000Ioo`8000Aoo`D0
00Aoo`@000Eoo`03001oogoo04aoo`03001oogoo03aoo`03001oogoo07Moo`<000Ioo`8000Aoo`D0
00Aoo`@000Eoo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03
001oogoo051oo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02
Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00Oomoo`1gOol01@00Oomoogoo00001Goo0P001Goo
00@007ooOol000Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03io
o`03001oogoo02Yoo`03001oogoo051oo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo04eoo`03001oogoo03Yoo`03001oogoo07Moo`05001oogooOol0000=
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`0n
Ool00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool2001?Ool00`00Oomoo`0hOol00`00Oomoo`1hOol01@00Oomoogoo00003Woo00<0
07ooOol01goo00<007ooOol00Woo0P0017oo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0
:7oo00<007ooOol0DGoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007oo
Ool0CWoo00<007ooOol0>7oo00<007ooOol0N7oo00D007ooOomoo`0000moo`03001oogoo009oo`@0
00Eoo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo
055oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo04io
o`03001oogoo03Qoo`03001oogoo07Qoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`03Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomo
o`1AOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00D7oo
00<007ooOol0=Woo00<007ooOol0NGoo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool20005Ool00`00Oomoo`0WOol00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`1A
Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo04moo`03001oogoo03Ioo`03001oogoo07Yo
o`<000eoo`<000Eoo`@000Eoo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo049oo`03001o
ogoo02Ioo`03001oogoo059oo`00>7oo00<007ooOol0Cgoo00<007ooOol0=Woo00<007ooOol0Vgoo
00<007ooOol017oo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol0DWoo
000hOol00`00Oomoo`1@Ool00`00Oomoo`0dOol00`00Oomoo`2LOol00`00Oomoo`05Ool00`00Oomo
o`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`1BOol003Qoo`80055oo`03001oogoo
03Aoo`03001oogoo09aoo`8000Ioo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03
001oogoo05=oo`00>7oo00<007ooOol0DGoo00<007ooOol0<Woo00<007ooOol0WGoo00<007ooOol0
1Goo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol0Dgoo000hOol00`00
Oomoo`1AOol00`00Oomoo`0bOol00`00Oomoo`2MOol00`00Oomoo`06Ool00`00Oomoo`0SOol00`00
Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`1COol003Qoo`80059oo`03001oogoo035oo`03001o
ogoo09ioo`8000Moo`03001oogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo05Ao
o`00>7oo00<007ooOol0DWoo00<007ooOol0<7oo00<007ooOol0WWoo00<007ooOol01Woo00<007oo
Ool08Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol0E7oo000hOol00`00Oomoo`1BOol0
0`00Oomoo`0`Ool00`00Oomoo`2NOol00`00Oomoo`07Ool00`00Oomoo`0QOol00`00Oomoo`17Ool0
0`00Oomoo`0QOol00`00Oomoo`1DOol003Qoo`03001oogoo059oo`03001oogoo02moo`03001oogoo
09moo`03001oogoo00Moo`03001oogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001oogoo
05Eoo`00>7oo0P00E7oo00<007ooOol0;Woo00<007ooOol0Wgoo0P0027oo00<007ooOol087oo00<0
07ooOol0B7oo00<007ooOol087oo00<007ooOol0EGoo000OOol30006Ool20005Ool40005Ool00`00
Oomoo`1COol00`00Oomoo`0]Ool00`00Oomoo`27Ool30006Ool20005Ool40005Ool00`00Oomoo`08
Ool00`00Oomoo`0OOol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`1EOol001ioo`05001o
ogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`0]Ool00`00Oomo
o`26Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0
7Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000NOol01@00Oomoogoo000047oo
00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol0:goo00<007ooOol0Qgoo00D007ooOomoo`00
011oo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo01ioo`03001oogoo04]oo`03001oogoo
01eoo`03001oogoo05Ioo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`8005Eoo`03001o
ogoo02]oo`03001oogoo08Moo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000:Ool00`00Oomo
o`0LOol00`00Oomoo`1<Ool00`00Oomoo`0MOol00`00Oomoo`1FOol001ioo`05001oogooOol0000<
Ool40005Ool00`00Oomoo`1EOol00`00Oomoo`0ZOol00`00Oomoo`27Ool01@00Oomoogoo000037oo
10001Goo00<007ooOol02Goo00<007ooOol077oo00<007ooOol0CGoo00<007ooOol06goo00<007oo
Ool0Egoo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0EGoo00<007ooOol0
:Goo00<007ooOol0R7oo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo00Uoo`03001o
ogoo01]oo`03001oogoo04ioo`03001oogoo01]oo`03001oogoo05Moo`007Woo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`8005Moo`03001oogoo02Qoo`03001oogoo08Qoo`05001oogooOol0000<
Ool00`00Oomoo`06Ool2000;Ool00`00Oomoo`0JOol00`00Oomoo`1>Ool00`00Oomoo`0JOol00`00
Oomoo`1HOol001moo`<000eoo`@000Eoo`03001oogoo05Ioo`03001oogoo02Moo`03001oogoo08Yo
o`<000eoo`@000Eoo`03001oogoo00Yoo`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uo
o`03001oogoo05Qoo`00>7oo00<007ooOol0Egoo00<007ooOol09Woo00<007ooOol0Xgoo00<007oo
Ool02Woo00<007ooOol06Goo00<007ooOol0D7oo00<007ooOol06Goo00<007ooOol0F7oo000hOol0
0`00Oomoo`1GOol00`00Oomoo`0UOol00`00Oomoo`2TOol00`00Oomoo`0;Ool00`00Oomoo`0HOol0
0`00Oomoo`1AOol00`00Oomoo`0GOol00`00Oomoo`1IOol003Qoo`8005Uoo`03001oogoo02Aoo`03
001oogoo0:Aoo`8000aoo`03001oogoo01Moo`03001oogoo059oo`03001oogoo01Moo`03001oogoo
05Uoo`00>7oo00<007ooOol0F7oo00<007ooOol097oo00<007ooOol0Y7oo00<007ooOol037oo00<0
07ooOol05Woo00<007ooOol0DWoo00<007ooOol05Woo00<007ooOol0FWoo000hOol00`00Oomoo`1I
Ool00`00Oomoo`0ROol00`00Oomoo`2UOol00`00Oomoo`0<Ool00`00Oomoo`0EOol00`00Oomoo`1D
Ool00`00Oomoo`0EOol00`00Oomoo`1JOol003Qoo`8005Yoo`03001oogoo029oo`03001oogoo0:Eo
o`8000ioo`03001oogoo01Aoo`03001oogoo05Aoo`03001oogoo01Aoo`03001oogoo05]oo`00>7oo
00<007ooOol0FWoo00<007ooOol087oo00<007ooOol0YWoo00<007ooOol03Goo00<007ooOol057oo
00<007ooOol0EGoo00<007ooOol04Woo00<007ooOol0G7oo000hOol00`00Oomoo`1JOol00`00Oomo
o`0OOol00`00Oomoo`2WOol00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomo
o`0BOol00`00Oomoo`1LOol003Qoo`03001oogoo05]oo`03001oogoo01ioo`03001oogoo0:Moo`03
001oogoo00ioo`03001oogoo019oo`03001oogoo05Moo`03001oogoo011oo`03001oogoo05eoo`00
>7oo0P00GGoo00<007ooOol077oo00<007ooOol0Z7oo0P003goo00<007ooOol04Goo00<007ooOol0
F7oo00<007ooOol047oo00<007ooOol0GGoo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005
Ool00`00Oomoo`1LOol00`00Oomoo`0LOol00`00Oomoo`27Ool30006Ool20006Ool00`00Oomoo`04
Ool40005Ool00`00Oomoo`0?Ool2000AOol00`00Oomoo`1IOol00`00Oomoo`0>Ool00`00Oomoo`1N
Ool001Ioo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomo
o`1MOol00`00Oomoo`0JOol00`00Oomoo`27Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol0
27oo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol03Goo00<007ooOol0FWoo00<007ooOol0
3Woo00<007ooOol0GWoo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol0GGoo00<007ooOol06Goo00<007ooOol0R7oo00D007ooOomoo`0000ioo`03001oogoo
00Moo`03001oogoo009oo`03001oogoo015oo`03001oogoo00]oo`8005ioo`8000eoo`03001oogoo
05moo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8005moo`03001o
ogoo01Qoo`03001oogoo08Qoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2
000COol00`00Oomoo`09Ool00`00Oomoo`1POol00`00Oomoo`09Ool00`00Oomoo`1POol001Ioo`05
001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`1NOol00`00Oomoo`0GOol00`00
Oomoo`29Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol04goo00<007oo
Ool01goo00<007ooOol0HWoo00<007ooOol01goo00<007ooOol0HGoo000FOol01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0Ggoo00<007ooOol05Goo00<007ooOol0
RWoo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01Aoo`03001o
ogoo00Eoo`03001oogoo06Aoo`03001oogoo00Eoo`03001oogoo069oo`005Woo00D007ooOomoo`00
00]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001QOol00`00Oomoo`0DOol00`00Oomoo`2:
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8001Ioo`<0009oo`80
06Qoo`8000=oo`8006Eoo`005goo0`0037oo1@0017oo10001Goo00<007ooOol0HGoo00<007ooOol0
4Woo00<007ooOol0S7oo0`0037oo1@0017oo10001Goo00<007ooOol05goo1000JWoo1000Igoo000h
Ool00`00Oomoo`1ROol2000@Ool2002`Ool00`00Oomoo`3`Ool003Qoo`03001oogoo06Aoo`03001o
ogoo00]oo`800;9oo`03001oogoo0?1oo`00>7oo0P00IWoo00<007ooOol02Goo00<007ooOol0/Woo
0P00lGoo000hOol00`00Oomoo`1VOol20008Ool00`00Oomoo`2cOol00`00Oomoo`3`Ool003Qoo`03
001oogoo06Moo`@0009oo`<00;Ioo`03001oogoo0?1oo`00>7oo0P00Jgoo1000^7oo0P00lGoo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol002moo`D0
00Aoo`03001oogoo0?mooaioo`D000Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007oo
Ool0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol0
0`00Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007oo
Ool0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03
001oogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00nGoo003oOoooOomFOol00?mo
oomooeIoo`00UGoo0`0000Aoo`00000001Qoo`<00?moo`Moo`<00004Ool00000000IOol3001dOol0
09Ioo`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000ogoo1goo00D007ooOomoo`0000Uo
o`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001aoo`03001oogoo0?moo`Eoo`05001o
ogooOol0000HOol5001dOol009Ioo`05001oogooOol00009Ool6000=Ool00`00Oomoo`3oOol5Ool0
1@00Oomoogoo00002Goo1P002Goo00@007ooOol007Eoo`00UWoo00D007ooOomoo`0001Yoo`800?mo
o`Qoo`05001oogooOol0000IOol00`00Ool0001eOol009Eoo`D001eoo`03001oogoo0?moo`Aoo`D0
01Yoo`03001oo`0007Eoo`00/goo00D007ooOomoo`000?moobIoo`8007Eoo`00]7oo0`00ogoo:7oo
00<007ooOol0Lgoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomF
Ool00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol002moo`D00?moobEoo`D00?Moo`00<Goo00<007ooOol0ogoo9goo00<007oo
Ool0mgoo000VOol60005Ool00`00Oomoo`3oOolLOol60005Ool00`00Oomoo`3gOol0035oo`03001o
ogoo00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol017oo00<007ooOol0
Ggoo6P00YWoo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`1L
Ool3000JOol4002ROol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`8005Qo
o`D0025oo`@009ioo`03001oogoo00Aoo`800:1oo`P004Uoo`00;goo0`001Woo00<007ooOol0Dgoo
1000:Woo0`00VGoo0`001Woo00<007ooOol0Vgoo100027oo1000AGoo000hOol00`00Oomoo`1AOol2
000aOol3002OOol00`00Oomoo`2HOol3000@Ool20013Ool003Qoo`03001oogoo04moo`8003Ioo`80
09eoo`03001oogoo09Moo`03001oogoo01=oo`03001oogoo041oo`00>7oo0P00CWoo0P00>Woo0`00
VWoo0P00Ugoo00<007ooOol05Goo0P00@7oo000hOol00`00Oomoo`1:Ool3000oOol2002HOol00`00
Oomoo`2DOol2000JOol2000nOol003Qoo`03001oogoo04Qoo`8004Aoo`<009Eoo`03001oogoo09=o
o`03001oogoo01aoo`03001oogoo03]oo`00>7oo0P00Agoo0P00BGoo0P00Tgoo0P00Tgoo00<007oo
Ool07Woo00<007ooOol0>Woo000hOol00`00Oomoo`14Ool2001=Ool00`00Oomoo`2@Ool00`00Oomo
o`2AOol00`00Oomoo`0POol00`00Oomoo`0iOol003Qoo`03001oogoo049oo`80051oo`80091oo`03
001oogoo091oo`03001oogoo029oo`03001oogoo03Qoo`00>7oo00<007ooOol0@Goo00<007ooOol0
DWoo0P00SWoo00<007ooOol0T7oo00<007ooOol08Woo00<007ooOol0>7oo000hOol20010Ool2001G
Ool00`00Oomoo`2;Ool2002@Ool00`00Oomoo`0TOol00`00Oomoo`0gOol001Moo`<000Ioo`8000Io
o`03001oogoo00Aoo`@000Eoo`03001oogoo03eoo`8005Yoo`8006Yoo`<000Ioo`8000Ioo`03001o
ogoo00Aoo`@000Eoo`03001oogoo08ioo`03001oogoo02Ioo`03001oogoo03Ioo`005Woo00D007oo
Oomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo03]oo`8005ioo`80
06Moo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`2=
Ool00`00Oomoo`0XOol00`00Oomoo`0eOol000ioo`H0009oo`05001oogooOol0000>Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`0jOol00`00Oomoo`1POol00`00Oomoo`1LOol60002Ool0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0S7oo00<007ooOol0
:Goo00<007ooOol0=Goo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo
0P00>Goo0P00I7oo0P00I7oo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80
08aoo`03001oogoo02]oo`03001oogoo03Aoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=o
o`@000Eoo`03001oogoo03Ioo`8006Qoo`80069oo`05001oogooOol0000>Ool00`00Oomoo`03Ool4
0005Ool00`00Oomoo`2;Ool00`00Oomoo`0/Ool00`00Oomoo`0cOol001Ioo`05001oogooOol0000?
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0eOol00`00Oomoo`1ZOol00`00Oomoo`1O
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0RWoo00<007oo
Ool0;Goo00<007ooOol0<goo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001o
ogoo00Ioo`8003Aoo`8006ioo`8005moo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<0
07ooOol01Woo0P00RWoo00<007ooOol0;goo00<007ooOol0<Woo000GOol3000<Ool50004Ool40005
Ool00`00Oomoo`0bOol00`00Oomoo`1`Ool00`00Oomoo`1MOol3000<Ool50004Ool40005Ool00`00
Oomoo`28Ool00`00Oomoo`0aOol00`00Oomoo`0aOol003Qoo`03001oogoo035oo`03001oogoo079o
o`03001oogoo07eoo`03001oogoo08Moo`03001oogoo03=oo`03001oogoo031oo`00>7oo00<007oo
Ool0;goo0P00MWoo0P00OGoo00<007ooOol0Qgoo00<007ooOol0<goo00<007ooOol0<7oo000hOol2
000_Ool00`00Oomoo`1hOol00`00Oomoo`1jOol20027Ool00`00Oomoo`0eOol00`00Oomoo`0_Ool0
03Qoo`03001oogoo02eoo`03001oogoo07Yoo`03001oogoo07Uoo`03001oogoo08Eoo`03001oogoo
03Moo`03001oogoo02ioo`00>7oo00<007ooOol0;7oo00<007ooOol0O7oo00<007ooOol0N7oo00<0
07ooOol0QGoo00<007ooOol0>7oo00<007ooOol0;Goo000hOol2000[Ool20020Ool2001hOol20025
Ool00`00Oomoo`0iOol00`00Oomoo`0]Ool003Qoo`03001oogoo02Uoo`03001oogoo089oo`03001o
ogoo07Eoo`03001oogoo08=oo`03001oogoo03]oo`03001oogoo02aoo`00>7oo00<007ooOol0:7oo
00<007ooOol0Q7oo00<007ooOol0M7oo00<007ooOol0Pgoo00<007ooOol0?7oo00<007ooOol0:goo
000hOol00`00Oomoo`0WOol00`00Oomoo`26Ool00`00Oomoo`1cOol00`00Oomoo`22Ool00`00Oomo
o`0mOol00`00Oomoo`0[Ool003Qoo`8002Moo`03001oogoo08Qoo`03001oogoo079oo`8008=oo`03
001oogoo03ioo`03001oogoo02Yoo`007goo0`001Woo0P001Goo10001Goo00<007ooOol09Goo00<0
07ooOol0RWoo00<007ooOol0F7oo0`001Woo0P001Goo10001Goo00<007ooOol0PGoo00<007ooOol0
@7oo00<007ooOol0:Goo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007oo
Ool097oo00<007ooOol0S7oo00<007ooOol0EWoo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo
009oo`03001oogoo081oo`03001oogoo049oo`03001oogoo02Qoo`005Woo1P000Woo00D007ooOomo
o`00011oo`03001oogoo009oo`8002Aoo`03001oogoo08ioo`03001oogoo04eoo`H0009oo`05001o
ogooOol0000@Ool00`00Oomoo`02Ool20021Ool00`00Oomoo`12Ool00`00Oomoo`0XOol001ioo`05
001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0QOol2002BOol00`00Oomoo`1DOol01@00
Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0Ogoo00<007ooOol0A7oo00<007ooOol09goo
000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol087oo00<007ooOol0Tgoo00<007ooOol0
Dgoo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo07ioo`03001oogoo04Ioo`03001oogoo02Io
o`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo01moo`03001oogoo09Eoo`03
001oogoo059oo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1nOol00`00Oomoo`16
Ool00`00Oomoo`0VOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2000OOol00`00Oomo
o`2GOol00`00Oomoo`1AOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00OWoo00<007ooOol0
B7oo00<007ooOol09Goo000OOol3000=Ool40005Ool00`00Oomoo`0MOol00`00Oomoo`2IOol00`00
Oomoo`1AOol3000=Ool40005Ool00`00Oomoo`1mOol00`00Oomoo`18Ool00`00Oomoo`0UOol003Qo
o`03001oogoo01aoo`03001oogoo09]oo`03001oogoo06Uoo`03001oogoo07aoo`03001oogoo04Yo
o`03001oogoo02Aoo`00>7oo00<007ooOol06goo00<007ooOol0WGoo00<007ooOol0J7oo00<007oo
Ool0Ngoo00<007ooOol0C7oo00<007ooOol08goo000hOol2000KOol00`00Oomoo`2OOol00`00Oomo
o`1WOol2001lOol00`00Oomoo`1<Ool00`00Oomoo`0SOol003Qoo`03001oogoo01Uoo`03001oogoo
0:5oo`03001oogoo06Ioo`03001oogoo07Yoo`03001oogoo04ioo`03001oogoo029oo`00>7oo00<0
07ooOol067oo00<007ooOol0Xgoo0P00IWoo00<007ooOol0NWoo00<007ooOol0CWoo00<007ooOol0
8Woo000hOol2000HOol00`00Oomoo`2VOol00`00Oomoo`1SOol2001jOol00`00Oomoo`1@Ool00`00
Oomoo`0QOol003Qoo`03001oogoo01Ioo`03001oogoo0:Qoo`03001oogoo069oo`03001oogoo07Qo
o`03001oogoo055oo`03001oogoo025oo`00>7oo00<007ooOol05Goo00<007ooOol0ZWoo00<007oo
Ool0HGoo00<007ooOol0N7oo00<007ooOol0DWoo00<007ooOol087oo000hOol00`00Oomoo`0DOol0
0`00Oomoo`2/Ool00`00Oomoo`1POol00`00Oomoo`1gOol00`00Oomoo`1COol00`00Oomoo`0POol0
03Qoo`8001Aoo`03001oogoo0:ioo`03001oogoo05moo`8007Qoo`03001oogoo05Aoo`03001oogoo
01moo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol04Woo00<007ooOol0/7oo00<0
07ooOol0?Goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0MWoo00<007ooOol0EWoo00<0
07ooOol07Woo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009o
o`03001oogoo015oo`03001oogoo0;9oo`03001oogoo03]oo`05001oogooOol00005Ool20005Ool0
1000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0MGoo00<007ooOol0Egoo00<007ooOol07Woo
000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P0047oo0P00
]Woo0P00<goo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8007Io
o`03001oogoo05Qoo`03001oogoo01eoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo00ioo`03001oogoo0;Qoo`03001oogoo03Qoo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`1dOol00`00Oomoo`1IOol00`00Oomoo`0M
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`0=Ool00`00Oomo
o`2jOol00`00Oomoo`0gOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0
M7oo00<007ooOol0FWoo00<007ooOol077oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol037oo00<007ooOol0_7oo00<007ooOol0=Woo00D007ooOomoo`00
00moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo07=oo`03001oogoo05]oo`03001oogoo
01aoo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000<Ool0
0`00Oomoo`2nOol00`00Oomoo`0eOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001o
ogoo00Ioo`8007Aoo`03001oogoo05aoo`03001oogoo01]oo`005goo0`003Goo0`001Goo10001Goo
00<007ooOol02Woo00<007ooOol0`7oo00<007ooOol0=Goo0`003Goo0`001Goo10001Goo00<007oo
Ool0LWoo00<007ooOol0GGoo00<007ooOol06goo000hOol00`00Oomoo`09Ool00`00Oomoo`0COol3
0006Ool20004Ool5000HOol30006Ool20006Ool3000HOol30006Ool20005Ool3000JOol30006Ool2
0005Ool3000GOol00`00Oomoo`07Ool50019Ool00`00Oomoo`0OOol30006Ool20004Ool5000HOol3
0006Ool20006Ool3000COol00`00Oomoo`02Ool30006Ool20005Ool3000IOol30006Ool20005Ool3
000MOol01000Oomoogoo1@0057oo000hOol20009Ool00`00Oomoo`0COol01@00Oomoogoo00001Goo
0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00Oomoo`0FOol01@00Oomo
ogoo00001Goo0P0017oo00D007ooOomoo`0001Qoo`05001oogooOol00005Ool20004Ool01@00Oomo
ogoo00005goo00<007ooOol027oo00<007ooOol0BGoo0P007goo00D007ooOomoo`0000Eoo`8000Eo
o`04001oogoo000GOol01@00Oomoogoo00001Goo0P001goo00<007ooOol04Goo00<007ooOol00Woo
00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000GOol01@00Oomoogoo00001Goo0P0017oo
00D007ooOomoo`0001aoo`03001oogoo00=oo`03001oogoo01Aoo`00>7oo00<007ooOol01goo00<0
07ooOol057oo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol0
1@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo0000
67oo00<007ooOol01goo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000eoo`03001o
ogoo01Moo`05001oogooOol0000;Ool5000BOol00`00Oomoo`02Ool01@00Oomoogoo00002goo00D0
07ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00007Goo00<007ooOol00Woo00<0
07ooOol057oo000hOol00`00Oomoo`06Ool00`00Oomoo`0EOol01@00Oomoogoo00003Woo00<007oo
Ool05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00006Goo00<007ooOol01Woo00<007ooOol0
BGoo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool0
1000Oomoo`004Woo00<007ooOol00goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00
Oomoogoo00002goo00D007ooOomoo`0001ioo`05001oogooOol0000FOol003Qoo`03001oogoo00Eo
o`03001oogoo01Ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<0
07oo000067oo00D007ooOomoo`0000]oo`@001Uoo`05001oogooOol0000<Ool3000KOol00`00Oomo
o`05Ool00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003goo00<007ooOol05Goo00D0
07ooOomoo`0000aoo`03001oo`00019oo`03001oogoo00=oo`05001oogooOol0000;Ool4000HOol0
1@00Oomoogoo000037oo0`007goo00D007ooOomoo`0001Ioo`00>7oo0P001Goo00<007ooOol05goo
00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00
Oomoogoo00002goo00<007ooOol06Woo00D007ooOomoo`0000]oo`05001oogooOol0000KOol00`00
Oomoo`04Ool00`00Oomoo`19Ool2000OOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007oo
Oomoo`0000aoo`03001oo`00015oo`03001oogoo00Aoo`05001oogooOol0000;Ool00`00Oomoo`0I
Ool01@00Oomoogoo00002goo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`03001oogoo
00=oo`03001oogoo01Qoo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`00
00eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007oo
Oomoo`0001aoo`03001oogoo00=oo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000;
Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`80015oo`03001oogoo00Aoo`05001oogoo
Ool0000<Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007ooOomoo`0001moo`04001oogoo
000FOol003Qoo`03001oogoo009oo`03001oogoo01Yoo`<000eoo`<001Uoo`<000moo`03001oogoo
01Moo`<000ioo`<001Uoo`<000eoo`<001ioo`03001oogoo00<004]oo`03001oogoo01moo`<000eo
o`<001Uoo`<000moo`03001oogoo00ioo`03001oogoo00Ioo`<000ioo`<001Qoo`<000eoo`<0025o
o`<001Ioo`00>7oo00D007ooOomoo`000=Aoo`03001oogoo04eoo`03001oogoo06ioo`03001oogoo
06Ioo`03001oogoo01Ioo`00>7oo0P0000=oo`00Ool0eGoo00<007ooOol0C7oo0P00KWoo00<007oo
Ool0J7oo00<007ooOol05Goo000hOol00`00Ool0003HOol00`00Oomoo`1;Ool00`00Oomoo`1]Ool0
0`00Oomoo`1XOol00`00Oomoo`0EOol003Qoo`800=Yoo`03001oogoo04Yoo`03001oogoo06aoo`03
001oogoo06Yoo`03001oogoo01Aoo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`19Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`0DOol003Qoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Yo
o`03001oogoo02Uoo`03001oogoo04Uoo`8002Yoo`03001oogoo02Uoo`03001oogoo01=oo`03001o
ogoo01=oo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo01Aoo`00>7oo00<007ooOol0ogoo
9goo0P00Jgoo00<007ooOol0Pgoo000hOol2003oOolXOol3001ZOol00`00Oomoo`23Ool003Qoo`03
001oogoo0?moobMoo`03001oo`0006Uoo`03001oogoo08Aoo`00>7oo00<007ooOol0ogoo9goo00@0
07ooOol006Qoo`03001oogoo08Aoo`00>7oo0P00ogoo:7oo0P0000=oo`00Ool0IWoo00<007ooOol0
QGoo000hOol00`00Oomoo`3oOolWOol01@00Oomoogoo0000IWoo00<007ooOol0QGoo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`02Ool00`00Oomoo`1ROol00`00Oomoo`26Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo009oo`03001oogoo065oo`03001oogoo08Moo`00>7oo0P00ogoo:7oo0P00
17oo00<007ooOol0H7oo00<007ooOol0Qgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`03Ool0
0`00Oomoo`1OOol00`00Oomoo`28Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Aoo`03001o
ogoo05ioo`03001oogoo08Qoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol017oo00<007ooOol0
GGoo00<007ooOol0RGoo000hOol2003oOolXOol20006Ool00`00Oomoo`1LOol00`00Oomoo`29Ool0
01Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Aoo`D000Ao
o`@000Eoo`03001oogoo00Eoo`03001oogoo05]oo`03001oogoo08Yoo`005Woo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo05Yo
o`03001oogoo08Yoo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`80
0?moo`Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool20007Ool00`00Oomo
o`1IOol00`00Oomoo`2;Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol0F7oo00<007ooOol0Rgoo000FOol01@00Oomoogoo00003goo00<007oo
Ool00Woo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eo
o`03001oogoo00Moo`03001oogoo05Moo`03001oogoo08aoo`005Woo00D007ooOomoo`0000moo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`1FOol00`00Oomoo`2<Ool001Ioo`05
001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20009Ool00`00Oomoo`1EOol00`00Oomo
o`2=Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo0?moo`Ioo`<000eoo`<000Eoo`@000Eo
o`03001oogoo00Uoo`03001oogoo05=oo`03001oogoo08ioo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol02Goo00<007ooOol0Dgoo00<007ooOol0SWoo000hOol2003oOolXOol2000;Ool00`00Oomo
o`1AOol00`00Oomoo`2?Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Yoo`03001oogoo055o
o`03001oogoo08moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol02goo00<007ooOol0Cgoo00<0
07ooOol0T7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0;Ool00`00Oomoo`1>Ool00`00Oomo
o`2AOol003Qoo`800?moobQoo`8000eoo`03001oogoo04eoo`03001oogoo095oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol037oo00<007ooOol0C7oo00<007ooOol0TWoo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`0=Ool00`00Oomoo`1;Ool00`00Oomoo`2BOol003Qoo`800?moobQoo`8000io
o`03001oogoo04Yoo`03001oogoo09=oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol03Woo00<0
07ooOol0B7oo00<007ooOol0U7oo000OOol30006Ool20005Ool40005Ool00`00Oomoo`3oOol>Ool3
0006Ool20005Ool40005Ool00`00Oomoo`0>Ool00`00Oomoo`18Ool00`00Oomoo`2DOol001ioo`05
001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo0000
1Goo0P002Goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol0AWoo00<007ooOol0UGoo000N
Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00ogoo3Woo00D007ooOomoo`00011oo`03001o
ogoo009oo`80011oo`03001oogoo04Ioo`03001oogoo09Eoo`007Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomo
o`0@Ool00`00Oomoo`14Ool00`00Oomoo`2FOol001ioo`05001oogooOol0000<Ool40005Ool00`00
Oomoo`3oOol=Ool01@00Oomoogoo000037oo10001Goo00<007ooOol04Goo00<007ooOol0@Woo00<0
07ooOol0Ugoo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo045oo`03001oogoo09Mo
o`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?moo`ioo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool2000COol00`00Oomoo`10Ool00`00Oomoo`2HOol001moo`<000eoo`@000Eoo`03
001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo01=oo`03001oogoo03ioo`03001oogoo09Uo
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol057oo00<007ooOol0?Goo00<007ooOol0VGoo000h
Ool2003oOolXOol2000EOol00`00Oomoo`0lOol00`00Oomoo`2JOol003Qoo`03001oogoo0?moobMo
o`03001oogoo01Eoo`03001oogoo03]oo`03001oogoo09Yoo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol05Woo00<007ooOol0>Goo00<007ooOol0Vgoo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`0GOol00`00Oomoo`0gOol00`00Oomoo`2LOol003Qoo`800?moobQoo`8001Qoo`03001oogoo03Mo
o`03001oogoo09aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol067oo00<007ooOol0=Goo00<0
07ooOol0WGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0IOol00`00Oomoo`0cOol00`00Oomo
o`2NOol003Qoo`800?moobQoo`8001Yoo`03001oogoo03=oo`03001oogoo09ioo`005goo0`001Woo
0P001Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol06Woo00<007ooOol0<Goo00<007ooOol0Wgoo000FOol01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo01]oo`03001oogoo02mo
o`03001oogoo0:1oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03
001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomo
o`0LOol00`00Oomoo`0]Ool00`00Oomoo`2QOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo0P007Woo00<007ooOol0:goo00<007ooOol0XWoo000FOol01@00Oomoogoo00003Woo00<007oo
Ool00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eo
o`03001oogoo01eoo`03001oogoo02Yoo`03001oogoo0:=oo`005Woo00D007ooOomoo`0000moo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`0NOol00`00Oomoo`0XOol00`00Oomoo`2TOol001Ioo`05
001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`0OOol00`00Oomo
o`0VOol00`00Oomoo`2UOol001Moo`<000aoo`D000Aoo`@000Eoo`800?moo`Moo`<000aoo`D000Ao
o`@000Eoo`80025oo`03001oogoo02Aoo`03001oogoo0:Ioo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol08Goo0P008goo00<007ooOol0Ygoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0SOol0
0`00Oomoo`0OOol00`00Oomoo`2XOol003Qoo`800?moobQoo`8002Eoo`03001oogoo01eoo`03001o
ogoo0:Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol09Goo00<007ooOol06goo00<007ooOol0
ZWoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0VOol2000IOol2002]Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo02Qoo`03001oogoo01Aoo`800:moo`00>7oo0P00ogoo:7oo0P00:Woo0P00
4goo00<007ooOol0[goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0[Ool2000?Ool2002bOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo02eoo`03001oogoo00Yoo`800;Aoo`00>7oo0P00ogoo
:7oo0P00;goo3000]Woo000_Ool50004Ool00`00Oomoo`3oOolNOol50004Ool00`00Oomoo`3`Ool0
035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo
00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00
Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001o
ogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<0
0004Ool00000000HOol5003oOol5Ool3000017oo000000005goo1@00M7oo002FOol01@00Oomoogoo
00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H000Yoo`04001oogoo001d
Ool009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo00006Woo00<007oo
Ool0M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`00
00Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001]oo`03001oogoo0?moo`Ioo`05
001oogooOol0000LOol00`00Oomoo`1bOol009Eoo`D001aoo`03001oogoo0?moo`Eoo`D001eoo`03
001oogoo079oo`00]Woo00<007ooOol0ogoo8goo00D007ooOomoo`0007Aoo`00]7oo0`00ogoo9Woo
0`00MGoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .19373 L
.08255 .13932 L
.10458 .08749 L
.12507 .04865 L
.14415 .02203 L
.14918 .01668 L
.15465 .0117 L
.15946 .00802 L
.16457 .00487 L
.16917 .0027 L
.17178 .00175 L
.17423 .00104 L
.17538 .00078 L
.17647 .00056 L
.17746 .00039 L
.17852 .00024 L
.17967 .00012 L
.18073 5e-05 L
.182 0 L
.18314 1e-05 L
.18435 5e-05 L
.18547 .00013 L
.1867 .00026 L
.18802 .00045 L
.19071 .00101 L
.19317 .00171 L
.1979 .00357 L
.20239 .00594 L
.21236 .01336 L
.22321 .02469 L
.24299 .05366 L
.26399 .09507 L
.30174 .1912 L
.34195 .31109 L
.38063 .42637 L
.40028 .4794 L
.42177 .52998 L
.44253 .5694 L
.4614 .59576 L
.47149 .60581 L
.47611 .60944 L
.48101 .61259 L
.4835 .61392 L
.48624 .61517 L
.48876 .61612 L
.49106 .61683 L
.49378 .61745 L
.49527 .6177 L
.49596 .61779 L
Mistroke
.49669 .61787 L
.498 .61797 L
.49921 .61802 L
.49996 .61803 L
.50065 .61803 L
.50196 .61798 L
.50313 .61789 L
.50438 .61774 L
.50556 .61757 L
.50663 .61737 L
.50926 .61674 L
.51175 .61595 L
.5167 .61382 L
.52208 .61069 L
.53169 .60297 L
.54056 .59347 L
.55926 .56639 L
.57988 .52641 L
.62014 .42419 L
.65888 .30857 L
.70007 .1861 L
.72063 .13133 L
.73974 .08697 L
.75939 .04964 L
.77791 .02337 L
.78775 .01326 L
.79293 .00906 L
.7984 .00548 L
.80302 .00315 L
.80546 .00218 L
.80809 .00133 L
.8105 .00073 L
.8127 .00034 L
.81375 .00021 L
.81491 .0001 L
.81599 3e-05 L
.817 0 L
.81818 1e-05 L
.81941 6e-05 L
.82047 .00014 L
.82163 .00026 L
.82287 .00044 L
.82421 .00069 L
.82661 .00127 L
.82905 .00203 L
.83134 .00291 L
.83564 .00499 L
.84078 .00819 L
.84552 .01184 L
.85624 .02247 L
Mistroke
.87498 .04872 L
.89561 .08789 L
.93591 .18909 L
.97471 .30448 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .45981 L
.08255 .52527 L
.0932 .55403 L
.10458 .57945 L
.11009 .58961 L
.11531 .59784 L
.12038 .60454 L
.12507 .60956 L
.12951 .61325 L
.13178 .61474 L
.13422 .61603 L
.13549 .61658 L
.13666 .617 L
.13784 .61736 L
.13895 .61762 L
.14022 .61785 L
.1409 .61793 L
.14161 .61799 L
.1423 .61803 L
.14295 .61803 L
.14415 .61799 L
.14531 .61787 L
.14656 .61767 L
.14773 .61739 L
.14881 .61708 L
.15143 .61606 L
.15392 .61475 L
.15886 .61117 L
.16423 .60583 L
.17383 .59259 L
.1827 .5763 L
.20137 .53043 L
.22197 .46442 L
.26217 .30793 L
.30086 .15709 L
.32051 .09318 L
.3309 .06498 L
.342 .03993 L
.35275 .02114 L
.35784 .01426 L
.36253 .00909 L
.36724 .00504 L
.36972 .00339 L
.37235 .00199 L
.37463 .00107 L
.37573 .00073 L
.37677 .00047 L
.37799 .00024 L
.37911 9e-05 L
Mistroke
.38031 1e-05 L
.38162 1e-05 L
.38227 5e-05 L
.38296 .00011 L
.38419 .00028 L
.38551 .00056 L
.38695 .00097 L
.38955 .00199 L
.39197 .00326 L
.39649 .00647 L
.40134 .01111 L
.40698 .01804 L
.41232 .02609 L
.42232 .0449 L
.44227 .09574 L
.4607 .15587 L
.50002 .3091 L
.53782 .45692 L
.55884 .52554 L
.56803 .55063 L
.57808 .57397 L
.58722 .59118 L
.59696 .60501 L
.60236 .61057 L
.60726 .6143 L
.60962 .61565 L
.61086 .61623 L
.61218 .61677 L
.61333 .61715 L
.61459 .6175 L
.61574 .61774 L
.61682 .6179 L
.61808 .61801 L
.61871 .61803 L
.61941 .61803 L
.62065 .61796 L
.62181 .61783 L
.62248 .61772 L
.62318 .61757 L
.62443 .61725 L
.62578 .61682 L
.62725 .61622 L
.62973 .61497 L
.63238 .61327 L
.63715 .60926 L
.64214 .6038 L
.64686 .59746 L
.6557 .5826 L
.67568 .53569 L
.69413 .4784 L
Mistroke
.7335 .32774 L
.77136 .17771 L
.79241 .10603 L
.81166 .05399 L
.82118 .03415 L
.8262 .0254 L
.83155 .01745 L
.8367 .01118 L
.84136 .00668 L
.84361 .00491 L
.84604 .00331 L
.84835 .00208 L
.85045 .0012 L
.85159 .00083 L
.85283 .0005 L
.85414 .00024 L
.85538 8e-05 L
.85653 1e-05 L
.85776 1e-05 L
.85881 7e-05 L
.85997 .00021 L
.86063 .00033 L
.86132 .00047 L
.86256 .00079 L
.86535 .00181 L
.86777 .00303 L
.87041 .00472 L
.87569 .00921 L
.88133 .0156 L
.89148 .03117 L
.90173 .05195 L
.91284 .07976 L
.933 .14228 L
.97393 .29982 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .26974 L
.10458 .22765 L
.14415 .18954 L
.18221 .1548 L
.22272 .1205 L
.26171 .09065 L
.30316 .06289 L
.34309 .04048 L
.3815 .02331 L
.40095 .01635 L
.42237 .01008 L
.44268 .00551 L
.45178 .0039 L
.46172 .00246 L
.4671 .00182 L
.4721 .00131 L
.47727 .00087 L
.48196 .00055 L
.48658 .0003 L
.4887 .00021 L
.49093 .00014 L
.49332 7e-05 L
.49438 5e-05 L
.49552 3e-05 L
.49675 2e-05 L
.49789 1e-05 L
.49859 0 L
.49925 0 L
.50049 0 L
.50163 0 L
.50286 1e-05 L
.50401 3e-05 L
.50508 4e-05 L
.50754 .0001 L
.51014 .00017 L
.51268 .00027 L
.51504 .00038 L
.5204 .0007 L
.5293 .00144 L
.53882 .00253 L
.54906 .00404 L
.56016 .00607 L
.58032 .01078 L
.62123 .02438 L
.66064 .04238 L
.69852 .06393 L
.73886 .09106 L
.77769 .12083 L
.81897 .15584 L
Mistroke
.85873 .19225 L
.89697 .22918 L
.93767 .26986 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .38693 L
.10458 .466 L
.14415 .52938 L
.18221 .57629 L
.20178 .59404 L
.21267 .60187 L
.22272 .60776 L
.23293 .61241 L
.23832 .6143 L
.24402 .61589 L
.24641 .61642 L
.24897 .61691 L
.25119 .61726 L
.25361 .61757 L
.25507 .61772 L
.25643 .61783 L
.25773 .61792 L
.2584 .61795 L
.25912 .61798 L
.25983 .618 L
.26048 .61802 L
.26176 .61803 L
.26293 .61803 L
.26416 .618 L
.26538 .61795 L
.26607 .61792 L
.26671 .61788 L
.26912 .61768 L
.27131 .61744 L
.27364 .61711 L
.27847 .61619 L
.2838 .61482 L
.29326 .61145 L
.30213 .60721 L
.32232 .59381 L
.34082 .57709 L
.38045 .52825 L
.41855 .46718 L
.45912 .39136 L
.49816 .31277 L
.53966 .22909 L
.57964 .15402 L
.61811 .09187 L
.63759 .06548 L
.65902 .0411 L
.67938 .02289 L
.69843 .01052 L
.70884 .00574 L
.71396 .00391 L
Mistroke
.71872 .00252 L
.72301 .00153 L
.72758 .00074 L
.7302 .00042 L
.73148 .00029 L
.73266 .0002 L
.73371 .00013 L
.73487 7e-05 L
.73603 3e-05 L
.73725 0 L
.73856 0 L
.73977 2e-05 L
.7404 4e-05 L
.7411 6e-05 L
.74251 .00013 L
.74375 .00021 L
.74508 .00033 L
.74748 .00059 L
.74985 .00093 L
.75235 .00136 L
.7568 .00235 L
.76198 .00383 L
.7668 .00553 L
.77773 .0105 L
.78828 .01678 L
.79823 .024 L
.81683 .04076 L
.85534 .08793 L
.89632 .15361 L
.93577 .22759 L
.97371 .30396 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`80025oo`D008ioo`D005aoo`H000Eoo`03001oogoo00Aoo`8004moo`@006Yo
o`@0031oo`00<Goo00<007ooOol017oo00<007ooOol07Goo0`0017oo0P00RWoo0`001Goo0P00IGoo
00<007ooOol017oo00<007ooOol0C7oo0`000goo00<007ooOol0IWoo0P000goo0P00;Woo000aOol0
0`00Oomoo`04Ool00`00Oomoo`0LOol00`00Oomoo`07Ool30026Ool00`00Oomoo`08Ool00`00Oomo
o`1ROol00`00Oomoo`04Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool00`00Oomoo`1TOol00`00Oomo
o`05Ool00`00Oomoo`0[Ool0035oo`03001oogoo00Aoo`03001oogoo01]oo`03001oogoo00]oo`03
001oogoo089oo`03001oogoo00Yoo`80069oo`03001oogoo00Aoo`03001oogoo04Yoo`03001oogoo
00Moo`8006=oo`03001oogoo00Moo`03001oogoo02Yoo`00<Goo00<007ooOol017oo0P006goo00<0
07ooOol037oo00<007ooOol0PWoo00<007ooOol037oo00<007ooOol0Ggoo00<007ooOol017oo0P00
Bgoo00<007ooOol02Goo00<007ooOol0Ggoo00<007ooOol02Goo00<007ooOol0:Goo000_Ool30006
Ool00`00Oomoo`0IOol00`00Oomoo`0>Ool00`00Oomoo`20Ool00`00Oomoo`0>Ool00`00Oomoo`1L
Ool30006Ool00`00Oomoo`19Ool00`00Oomoo`0:Ool00`00Oomoo`1OOol00`00Oomoo`09Ool00`00
Oomoo`0YOol003Qoo`03001oogoo01Uoo`03001oogoo00moo`03001oogoo07ioo`03001oogoo00mo
o`03001oogoo06Eoo`03001oogoo04Uoo`03001oogoo00]oo`03001oogoo05eoo`03001oogoo00]o
o`03001oogoo02Qoo`00>7oo0P006Goo00<007ooOol047oo00<007ooOol0OWoo00<007ooOol047oo
00<007ooOol0I7oo0P00BGoo00<007ooOol037oo00<007ooOol0GGoo00<007ooOol037oo00<007oo
Ool09goo000hOol00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`1lOol00`00Oomoo`0BOol0
0`00Oomoo`1SOol00`00Oomoo`18Ool00`00Oomoo`0=Ool00`00Oomoo`1KOol00`00Oomoo`0=Ool0
0`00Oomoo`0WOol003Qoo`03001oogoo01Ioo`03001oogoo01Aoo`03001oogoo07Yoo`03001oogoo
01=oo`03001oogoo06=oo`03001oogoo04Moo`03001oogoo00ioo`03001oogoo05]oo`03001oogoo
00ioo`03001oogoo02Ioo`00>7oo00<007ooOol05Goo00<007ooOol05Woo00<007ooOol0N7oo00<0
07ooOol05Goo00<007ooOol0HWoo00<007ooOol0Agoo00<007ooOol03Woo00<007ooOol0FWoo00<0
07ooOol03goo00<007ooOol09Woo000hOol2000EOol00`00Oomoo`0GOol00`00Oomoo`1gOol00`00
Oomoo`0GOol00`00Oomoo`1QOol20017Ool00`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0@
Ool00`00Oomoo`0VOol003Qoo`03001oogoo01Aoo`03001oogoo01Qoo`03001oogoo07Eoo`03001o
ogoo01Qoo`03001oogoo065oo`03001oogoo04Ioo`03001oogoo011oo`03001oogoo05Qoo`03001o
ogoo015oo`03001oogoo02Eoo`00>7oo00<007ooOol04goo00<007ooOol06Woo00<007ooOol0M7oo
00<007ooOol06Goo00<007ooOol0H7oo00<007ooOol0AGoo00<007ooOol04Woo00<007ooOol0EWoo
00<007ooOol04Woo00<007ooOol09Goo000hOol00`00Oomoo`0COol00`00Oomoo`0JOol00`00Oomo
o`1cOol00`00Oomoo`0JOol00`00Oomoo`1POol00`00Oomoo`15Ool00`00Oomoo`0BOol00`00Oomo
o`1FOol00`00Oomoo`0COol00`00Oomoo`0TOol003Qoo`8001=oo`03001oogoo01aoo`03001oogoo
079oo`03001oogoo01]oo`03001oogoo05moo`8004Eoo`03001oogoo01Aoo`03001oogoo05Aoo`03
001oogoo01Aoo`03001oogoo02Aoo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<0
07ooOol04Woo00<007ooOol077oo00<007ooOol0LGoo00<007ooOol077oo00<007ooOol0?Woo0`00
1Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0A7oo00<007ooOol057oo00<007ooOol0
E7oo00<007ooOol05Goo00<007ooOol08goo000FOol01@00Oomoogoo00001Goo0P001Woo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol07Goo00<007ooOol0L7oo00<007oo
Ool07Goo00<007ooOol0?7oo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo04Aoo`03001oogoo01Eoo`03001oogoo05=oo`03001oogoo01Eoo`03001oogoo
02=oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80019o
o`03001oogoo01moo`03001oogoo06ioo`03001oogoo01ioo`03001oogoo03Aoo`H0009oo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20014Ool00`00Oomoo`0FOol00`00Oomo
o`1BOol00`00Oomoo`0FOol00`00Oomoo`0SOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`0OOol00`00Oomoo`1^Ool00`00Oomoo`0O
Ool00`00Oomoo`0kOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool0@goo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05goo00<007ooOol08Woo000FOol0
1@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol047oo00<007ooOol08Goo00<0
07ooOol0K7oo00<007ooOol087oo00<007ooOol0>goo00D007ooOomoo`0000ioo`03001oogoo00=o
o`@000Eoo`03001oogoo04=oo`03001oogoo01Moo`03001oogoo055oo`03001oogoo01Moo`03001o
ogoo029oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
011oo`03001oogoo025oo`03001oogoo06aoo`03001oogoo025oo`03001oogoo03Yoo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`12Ool00`00Oomoo`0HOol00`00
Oomoo`1@Ool00`00Oomoo`0HOol00`00Oomoo`0ROol001Ioo`05001oogooOol0000;Ool01@00Oomo
ogoo000017oo00<007ooOol01Woo0P0047oo00<007ooOol08goo00<007ooOol0JWoo00<007ooOol0
8Woo00<007ooOol0>Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2
0013Ool00`00Oomoo`0IOol00`00Oomoo`1?Ool00`00Oomoo`0IOol00`00Oomoo`0QOol001Moo`<0
00aoo`D000Aoo`@000Eoo`03001oogoo00moo`03001oogoo02=oo`03001oogoo06Yoo`03001oogoo
02=oo`03001oogoo03Yoo`<000aoo`D000Aoo`@000Eoo`03001oogoo049oo`03001oogoo01Uoo`03
001oogoo04moo`03001oogoo01Uoo`03001oogoo025oo`00>7oo00<007ooOol03goo00<007ooOol0
97oo00<007ooOol0J7oo00<007ooOol097oo00<007ooOol0Fgoo00<007ooOol0@Goo00<007ooOol0
6Woo00<007ooOol0CWoo00<007ooOol06Woo00<007ooOol08Goo000hOol2000?Ool00`00Oomoo`0U
Ool00`00Oomoo`1XOol00`00Oomoo`0TOol00`00Oomoo`1KOol20012Ool00`00Oomoo`0KOol00`00
Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`0POol003Qoo`03001oogoo00ioo`03001oogoo02Eo
o`03001oogoo06Moo`03001oogoo02Ioo`03001oogoo05Yoo`03001oogoo045oo`03001oogoo01]o
o`03001oogoo04eoo`03001oogoo01]oo`03001oogoo021oo`00>7oo00<007ooOol03Goo00<007oo
Ool09goo00<007ooOol0IWoo00<007ooOol09Woo00<007ooOol0FWoo00<007ooOol0@7oo00<007oo
Ool077oo00<007ooOol0CGoo00<007ooOol06goo00<007ooOol087oo000hOol00`00Oomoo`0=Ool0
0`00Oomoo`0WOol00`00Oomoo`1VOol00`00Oomoo`0WOol00`00Oomoo`1IOol00`00Oomoo`10Ool0
0`00Oomoo`0MOol00`00Oomoo`1;Ool00`00Oomoo`0LOol00`00Oomoo`0POol003Qoo`8000eoo`03
001oogoo02Qoo`03001oogoo06Eoo`03001oogoo02Qoo`03001oogoo05Uoo`80045oo`03001oogoo
01eoo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo01moo`00>7oo00<007ooOol037oo00<0
07ooOol0:Goo00<007ooOol0I7oo00<007ooOol0:7oo00<007ooOol0FGoo00<007ooOol0?goo00<0
07ooOol07Woo00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol07goo000hOol00`00Oomoo`0<
Ool00`00Oomoo`0YOol00`00Oomoo`1SOol00`00Oomoo`0ZOol00`00Oomoo`1HOol00`00Oomoo`0o
Ool00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`0OOol003Qoo`8000ao
o`03001oogoo02Yoo`03001oogoo06=oo`03001oogoo02Yoo`03001oogoo05Qoo`80041oo`03001o
ogoo01moo`03001oogoo04Uoo`03001oogoo01moo`03001oogoo01ioo`007goo0`001Woo0P001Goo
10001Goo00<007ooOol02goo00<007ooOol0:goo00<007ooOol0HGoo00<007ooOol0;7oo00<007oo
Ool0?Woo0`001Woo0P001Goo10001Goo00<007ooOol0?Woo00<007ooOol087oo00<007ooOol0BGoo
00<007ooOol07goo00<007ooOol07Woo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0Woo00<007ooOol02Woo00<007ooOol0;7oo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0
?Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo03ioo`03001oogoo021o
o`03001oogoo04Qoo`03001oogoo021oo`03001oogoo01ioo`005Woo1P000Woo00D007ooOomoo`00
011oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo02eoo`03001oogoo061oo`03001oogoo
02aoo`03001oogoo03Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0n
Ool00`00Oomoo`0QOol00`00Oomoo`17Ool00`00Oomoo`0POol00`00Oomoo`0NOol001ioo`05001o
ogooOol0000@Ool00`00Oomoo`02Ool2000;Ool00`00Oomoo`0]Ool00`00Oomoo`1OOol00`00Oomo
o`0^Ool00`00Oomoo`0lOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00?Woo00<007ooOol0
8Woo00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol07Goo000NOol01@00Oomoogoo000037oo
10001Goo00<007ooOol02Goo00<007ooOol0;Woo00<007ooOol0Ggoo00<007ooOol0;Woo00<007oo
Ool0?7oo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo03eoo`03001oogoo029oo`03001oogoo
04Ioo`03001oogoo029oo`03001oogoo01eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Io
o`03001oogoo00Uoo`03001oogoo02moo`03001oogoo05ioo`03001oogoo02ioo`03001oogoo03ao
o`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0mOol00`00Oomoo`0ROol00`00Oomo
o`16Ool00`00Oomoo`0ROol00`00Oomoo`0MOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06
Ool00`00Oomoo`08Ool00`00Oomoo`0`Ool00`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomoo`0k
Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0?Goo00<007ooOol08goo00<007oo
Ool0AGoo00<007ooOol08Woo00<007ooOol07Goo000OOol3000=Ool40005Ool20009Ool00`00Oomo
o`0`Ool00`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomoo`0lOol3000=Ool40005Ool2000mOol0
0`00Oomoo`0TOol00`00Oomoo`14Ool00`00Oomoo`0TOol00`00Oomoo`0LOol003Qoo`03001oogoo
00Qoo`03001oogoo035oo`03001oogoo05aoo`03001oogoo035oo`03001oogoo05Aoo`03001oogoo
03aoo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo01aoo`00>7oo00<0
07ooOol01goo00<007ooOol0<Woo00<007ooOol0Fgoo00<007ooOol0<Woo00<007ooOol0E7oo00<0
07ooOol0?7oo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol077oo000h
Ool20008Ool00`00Oomoo`0bOol00`00Oomoo`1KOol00`00Oomoo`0bOol00`00Oomoo`1DOol2000m
Ool00`00Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`0KOol003Qoo`03001o
ogoo00Moo`03001oogoo03=oo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo05=oo`03001o
ogoo03]oo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01]oo`00>7oo
00<007ooOol01Woo00<007ooOol0=7oo00<007ooOol0FGoo00<007ooOol0=7oo00<007ooOol0Dgoo
00<007ooOol0>goo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol06goo
000hOol00`00Oomoo`06Ool00`00Oomoo`0eOol00`00Oomoo`1HOol00`00Oomoo`0eOol00`00Oomo
o`1BOol00`00Oomoo`0kOol00`00Oomoo`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomo
o`0KOol003Qoo`8000Ioo`03001oogoo03Ioo`03001oogoo05Qoo`03001oogoo03Eoo`03001oogoo
059oo`8003aoo`03001oogoo02Moo`03001oogoo045oo`03001oogoo02Moo`03001oogoo01Yoo`00
>7oo00<007ooOol01Goo00<007ooOol0=Woo00<007ooOol0Egoo00<007ooOol0=Woo00<007ooOol0
DWoo00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol0@7oo00<007ooOol0:7oo00<007ooOol0
6Woo000hOol00`00Oomoo`05Ool00`00Oomoo`0gOol00`00Oomoo`1FOol00`00Oomoo`0gOol00`00
Oomoo`1AOol00`00Oomoo`0jOol00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00
Oomoo`0JOol003Qoo`8000Eoo`03001oogoo03Qoo`03001oogoo05Ioo`03001oogoo03Moo`03001o
ogoo055oo`8003]oo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo01Yo
o`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol017oo00<007ooOol0>7oo00<007oo
Ool0EGoo00<007ooOol0>7oo00<007ooOol0<7oo0`001Woo0P0017oo1@0017oo10001Goo00<007oo
Ool0>Woo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol06Goo000FOol0
1@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Aoo`03
001oogoo03Uoo`03001oogoo05Aoo`03001oogoo03Uoo`03001oogoo02ioo`05001oogooOol00005
Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0>Goo00<007ooOol0:Woo00<0
07ooOol0?Woo00<007ooOol0:Woo00<007ooOol06Goo000>Ool60002Ool01@00Oomoogoo00003Goo
00<007ooOol027oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0>Woo00<007ooOol0E7oo
00<007ooOol0>Goo00<007ooOol09Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo03Uoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03
001oogoo01Uoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000Ao
o`03001oogoo03Yoo`03001oogoo05=oo`03001oogoo03Yoo`03001oogoo02ioo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000jOol00`00Oomoo`0ZOol00`00Oomoo`0nOol0
0`00Oomoo`0[Ool00`00Oomoo`0HOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005
Ool00`00Oomoo`03Ool00`00Oomoo`0kOol00`00Oomoo`1BOol00`00Oomoo`0kOol00`00Oomoo`0]
Ool01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0>7oo00<007ooOol0;7oo
00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol067oo000FOol01@00Oomoogoo00003goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0?7oo00<007ooOol0DWoo00<0
07ooOol0>goo00<007ooOol0;Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo03Qoo`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo01Qo
o`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20003Ool00`00
Oomoo`0lOol00`00Oomoo`1AOol00`00Oomoo`0lOol00`00Oomoo`0]Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8003Uoo`03001oogoo02aoo`03001oogoo03aoo`03
001oogoo02aoo`03001oogoo01Qoo`005goo0`003Goo0`001Goo10001Goo00<007ooOol00Woo00<0
07ooOol0?Goo00<007ooOol0D7oo00<007ooOol0?Goo00<007ooOol0;Goo0`003Goo0`001Goo1000
1Goo00<007ooOol0>7oo00<007ooOol0;7oo00<007ooOol0?7oo00<007ooOol0;Goo00<007ooOol0
5goo000hOol01@00Oomoogoo0000@7oo00<007ooOol0D7oo00<007ooOol0?Goo00<007ooOol0CWoo
00<007ooOol0=goo00<007ooOol0;Woo00<007ooOol0>Woo00<007ooOol0;Woo00<007ooOol05goo
000hOol01@00Oomoogoo00007Goo0`001Woo0P0017oo1@0047oo00<007ooOol01Goo0`001Woo0P00
1Woo0`0067oo0`001Woo0P001Goo0`002Woo00<007ooOol03Goo0`001Woo0P001Goo0`007Woo00<0
07ooOol01@00BGoo00<007ooOol07goo0`001Woo0P0017oo1@0017oo00<007ooOol04Goo0`001Woo
0P001Woo0`002Goo00<007ooOol037oo0`001Woo0P001Goo0`006Goo0`001Woo0P001Goo0`0087oo
1P0057oo000hOol20002Ool00`00Oomoo`0JOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol0
011oo`03001oogoo00Aoo`05001oogooOol00005Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo
00001Goo0P0017oo00D007ooOomoo`0000Uoo`03001oogoo00aoo`05001oogooOol00005Ool20004
Ool01@00Oomoogoo00007Woo00D007ooOomoo`0004]oo`8001moo`05001oogooOol00005Ool20005
Ool01000Oomoo`0017oo00<007ooOol047oo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo00Qo
o`03001oogoo00]oo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00005goo00<007ooOol0
0P001Goo0P0017oo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`04001oogoo000MOol0
1@00Oomoogoo00003Goo00<007ooOol047oo00<007ooOol017oo00D007ooOomoo`0000]oo`D001Mo
o`05001oogooOol0000;Ool01@00Oomoogoo00002Goo00<007ooOol037oo00D007ooOomoo`0000]o
o`05001oogooOol0000NOol01@00Oomoogoo0000Bgoo00<007ooOol07Woo00D007ooOomoo`0000eo
o`03001oogoo00Aoo`03001oogoo011oo`05001oogooOol0000;Ool50009Ool00`00Oomoo`0;Ool0
1@00Oomoogoo00002goo00D007ooOomoo`0001Moo`03001oogoo008000]oo`05001oogooOol0000P
Ool00`00Ool0000FOol003Qoo`04001oogoo000MOol01@00Oomoogoo00003Woo00<007ooOol047oo
00<007ooOol00goo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D0
07ooOomoo`0000Qoo`03001oogoo00eoo`05001oogooOol0000;Ool01@00Oomoogoo00007Woo00D0
07ooOomoo`0004]oo`03001oogoo01ioo`05001oogooOol0000>Ool00`00Oomoo`02Ool00`00Oomo
o`0AOol01@00Oomoogoo00002goo00@007ooOol000]oo`03001oogoo00Yoo`05001oogooOol0000;
Ool01@00Oomoogoo00005goo00D007oo001oo`0000]oo`05001oogooOol0000POol00`00Ool0000F
Ool003Qoo`04001oogoo000MOol01@00Oomoogoo00003goo00<007ooOol03goo00<007ooOol00goo
00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool40009Ool00`00Oomoo`0=
Ool01@00Oomoogoo000037oo0`0087oo00@007ooOol004]oo`03001oogoo01ioo`05001oogooOol0
000?Ool01@00Oomoogoo00004goo00D007ooOomoo`0000aoo`03001oo`0000]oo`03001oogoo00Yo
o`05001oogooOol0000;Ool4000HOol01@00Ool007oo000037oo0`008Goo00<007oo00005Woo000h
Ool3000NOol01@00Oomoogoo00003goo00<007ooOol03goo00<007ooOol00goo00D007ooOomoo`00
00aoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool01@00
Oomoogoo00002goo00D007ooOomoo`0001moo`04001oogoo001;Ool2000OOol01@00Oomoogoo0000
3goo00D007ooOomoo`0001=oo`05001oogooOol0000<Ool00`00Ool0000;Ool00`00Oomoo`0:Ool0
1@00Oomoogoo00002goo00<007ooOol06Goo00D007oo001oo`0000]oo`05001oogooOol0000QOol2
000FOol003Qoo`03001oo`0001ioo`05001oogooOol0000;Ool01@00Oomoogoo00004Woo00<007oo
Ool00Woo00D007ooOomoo`0000eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`08Ool00`00
Oomoo`0>Ool01@00Oomoogoo00002goo00D007ooOomoo`0001moo`04001oogoo001;Ool00`00Oomo
o`0NOol01@00Oomoogoo00002goo00D007ooOomoo`0000=oo`03001oogoo015oo`05001oogooOol0
000=Ool2000;Ool00`00Oomoo`0:Ool01@00Oomoogoo000037oo00<007ooOol067oo00D007oo001o
o`0000]oo`05001oogooOol0000QOol2000FOol003Qoo`03001oo`0001moo`<000eoo`<001=oo`03
001oogoo00=oo`<000moo`03001oogoo01Moo`<000ioo`<000Moo`03001oogoo00moo`<000eoo`<0
025oo`<004]oo`03001oogoo01moo`<000eoo`<000=oo`03001oogoo01=oo`<000moo`03001oogoo
00Yoo`03001oogoo00Yoo`<000ioo`<001Qoo`<000eoo`<0025oo`<001Ioo`00>7oo0P00AWoo00<0
07ooOol0BWoo00<007ooOol0@goo00<007ooOol0Bgoo0P00=Woo00<007ooOol0<Woo00<007ooOol0
=Woo00<007ooOol0<Woo00<007ooOol05Goo000hOol20017Ool00`00Oomoo`18Ool00`00Oomoo`14
Ool00`00Oomoo`1;Ool00`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomoo`0fOol00`00Oomoo`0c
Ool00`00Oomoo`0DOol003Qoo`8004Moo`03001oogoo04Qoo`03001oogoo04Eoo`03001oogoo04Yo
o`03001oogoo03Eoo`03001oogoo039oo`03001oogoo03Ioo`03001oogoo03=oo`03001oogoo01Ao
o`00>7oo00<007ooOol0AWoo00<007ooOol0B7oo00<007ooOol0AGoo00<007ooOol0BWoo00<007oo
Ool0=7oo00<007ooOol0=7oo00<007ooOol0=7oo00<007ooOol0=7oo00<007ooOol057oo000bOooY
0010OooY000@Ool003Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Eoo`04001oogoo000:Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool01@00Oomo
ogoo00001Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol0BGoo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol057oo000hOol00`00Oomoo`18
Ool00`00Oomoo`14Ool00`00Oomoo`2DOol00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0d
Ool00`00Oomoo`1;Ool003Qoo`8004Uoo`03001oogoo04Aoo`03001oogoo09Aoo`8003Aoo`03001o
ogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo00<007ooOol0B7oo00<007ooOol0A7oo
00<007ooOol0U7oo0P00=7oo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol0C7oo000hOol0
0`00Oomoo`19Ool00`00Oomoo`12Ool00`00Oomoo`2EOol2000dOol00`00Oomoo`0fOol00`00Oomo
o`0bOol00`00Oomoo`1<Ool003Qoo`03001oogoo04Uoo`03001oogoo049oo`03001oogoo09Eoo`80
03Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo0P00BWoo00<007ooOol0
@Woo00<007ooOol0UGoo0`00<Woo00<007ooOol0>7oo00<007ooOol0<7oo00<007ooOol0CGoo000h
Ool00`00Oomoo`1:Ool00`00Oomoo`10Ool00`00Oomoo`2FOol00`00Ool0000bOol00`00Oomoo`0h
Ool00`00Oomoo`0`Ool00`00Oomoo`1=Ool003Qoo`03001oogoo04Yoo`03001oogoo041oo`03001o
ogoo09Ioo`03001oo`00039oo`03001oogoo03Qoo`03001oogoo031oo`03001oogoo04eoo`00>7oo
00<007ooOol0BWoo00<007ooOol0@7oo00<007ooOol0UWoo00<007oo0000<Woo00<007ooOol0>Goo
00<007ooOol0;goo00<007ooOol0CGoo000hOol2001<Ool00`00Oomoo`0nOol00`00Oomoo`2GOol2
00000goo001oo`0_Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`1>Ool003Qoo`03001o
ogoo04]oo`03001oogoo03ioo`03001oogoo09Moo`04001oogoo000`Ool00`00Oomoo`0jOol00`00
Oomoo`0^Ool00`00Oomoo`1>Ool003Qoo`03001oogoo04]oo`03001oogoo03ioo`03001oogoo09Mo
o`04001oogoo000`Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`1>Ool003Qoo`8004eo
o`03001oogoo03aoo`03001oogoo09Qoo`800003Ool007oo02moo`03001oogoo03]oo`03001oogoo
02eoo`03001oogoo04ioo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0C7oo00<0
07ooOol0?7oo00<007ooOol0Mgoo0`001Woo0P0017oo1@0017oo10001Goo00D007ooOomoo`0002io
o`03001oogoo03aoo`03001oogoo02aoo`03001oogoo04moo`005Woo00D007ooOomoo`0000Eoo`80
00Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`1<Ool00`00Oomoo`0lOol00`00Oomo
o`1fOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`05001oogoo
Ool0000^Ool00`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`1?Ool001Ioo`05001oogooOol0
000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00Oomo
o`1gOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00D007ooOomoo`0002io
o`03001oogoo03aoo`03001oogoo02aoo`03001oogoo04moo`005Woo00D007ooOomoo`0000ioo`03
001oogoo00Moo`03001oogoo009oo`8004ioo`03001oogoo03Yoo`03001oogoo07Moo`05001oogoo
Ool0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`0[Ool00`00Oomoo`0m
Ool00`00Oomoo`0[Ool00`00Oomoo`1?Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool4
0005Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00Oomoo`1gOol01@00Oomoogoo00003goo00<0
07ooOol00Woo10001Goo00<007ooOol00Woo00<007ooOol0:Woo00<007ooOol0?Woo00<007ooOol0
:Woo00<007ooOol0D7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol0CWoo00<007ooOol0>7oo00<007ooOol0N7oo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo
02Yoo`03001oogoo051oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomo
o`06Ool2001?Ool00`00Oomoo`0hOol00`00Oomoo`1hOol01@00Oomoogoo00002goo00D007ooOomo
o`0000Aoo`03001oogoo00Ioo`8000=oo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yo
o`03001oogoo051oo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0CWoo00<007ooOol0>7oo
00<007ooOol0NGoo0`003Goo0`001Goo10001Goo00<007ooOol00goo00<007ooOol0:Goo00<007oo
Ool0?goo00<007ooOol0:7oo00<007ooOol0DGoo000hOol00`00Oomoo`1?Ool00`00Oomoo`0fOol0
0`00Oomoo`2KOol00`00Oomoo`03Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol0
0`00Oomoo`1AOol003Qoo`03001oogoo04moo`03001oogoo03Ioo`03001oogoo09]oo`03001oogoo
00=oo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo055oo`00>7oo0P00
D7oo00<007ooOol0=Woo00<007ooOol0Vgoo0P0017oo00<007ooOol0:7oo00<007ooOol0@7oo00<0
07ooOol0:7oo00<007ooOol0DGoo000hOol00`00Oomoo`1@Ool00`00Oomoo`0dOol00`00Oomoo`2L
Ool00`00Oomoo`04Ool00`00Oomoo`0WOol00`00Oomoo`11Ool00`00Oomoo`0VOol00`00Oomoo`1B
Ool003Qoo`03001oogoo051oo`03001oogoo03Aoo`03001oogoo09aoo`03001oogoo00Aoo`03001o
ogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo059oo`00>7oo0P00DGoo00<007oo
Ool0<goo00<007ooOol0WGoo0P001Goo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo
00<007ooOol0DWoo000hOol00`00Oomoo`1AOol00`00Oomoo`0bOol00`00Oomoo`2MOol00`00Oomo
o`04Ool00`00Oomoo`0VOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`1BOol003Qoo`03
001oogoo055oo`03001oogoo039oo`03001oogoo09eoo`03001oogoo00Eoo`03001oogoo02Eoo`03
001oogoo04=oo`03001oogoo02Aoo`03001oogoo05=oo`00>7oo00<007ooOol0DGoo00<007ooOol0
<Goo00<007ooOol0WWoo00<007ooOol01Goo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol0
97oo00<007ooOol0Dgoo000hOol2001COol00`00Oomoo`0`Ool00`00Oomoo`2NOol20006Ool00`00
Oomoo`0TOol00`00Oomoo`14Ool00`00Oomoo`0TOol00`00Oomoo`1COol001moo`<000Ioo`8000Eo
o`@000Eoo`03001oogoo059oo`03001oogoo031oo`03001oogoo08Eoo`<000Ioo`8000Eoo`@000Eo
o`03001oogoo00Eoo`03001oogoo02Aoo`03001oogoo04Eoo`03001oogoo02=oo`03001oogoo05=o
o`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo059oo`03001oogoo
02moo`03001oogoo08Eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`0SOol00`00Oomoo`15Ool00`00Oomoo`0ROol00`00Oomoo`1DOol001ioo`05001o
ogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`0^Ool00`00Oomoo`25Ool0
1@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol08Woo00<007ooOol0
AWoo00<007ooOol08Woo00<007ooOol0E7oo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo
0P00E7oo00<007ooOol0;Goo00<007ooOol0QWoo00D007ooOomoo`00011oo`03001oogoo009oo`80
00Moo`03001oogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo05Aoo`007Woo00D0
07ooOomoo`0000aoo`@000Eoo`03001oogoo05=oo`03001oogoo02eoo`03001oogoo08Ioo`05001o
ogooOol0000<Ool40005Ool00`00Oomoo`06Ool00`00Oomoo`0ROol00`00Oomoo`17Ool00`00Oomo
o`0QOol00`00Oomoo`1DOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1D
Ool00`00Oomoo`0/Ool00`00Oomoo`26Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol087oo00<007ooOol0EGoo000NOol0
1@00Oomoogoo000037oo00<007ooOol01Woo0P00EGoo00<007ooOol0:goo00<007ooOol0Qgoo00D0
07ooOomoo`0000aoo`03001oogoo00Ioo`8000Qoo`03001oogoo021oo`03001oogoo04Qoo`03001o
ogoo021oo`03001oogoo05Eoo`007goo0`003Goo10001Goo00<007ooOol0E7oo00<007ooOol0:goo
00<007ooOol0R7oo0`003Goo10001Goo00<007ooOol01goo00<007ooOol087oo00<007ooOol0BGoo
00<007ooOol07goo00<007ooOol0EGoo000hOol00`00Oomoo`1EOol00`00Oomoo`0ZOol00`00Oomo
o`2QOol00`00Oomoo`07Ool00`00Oomoo`0OOol00`00Oomoo`1:Ool00`00Oomoo`0OOol00`00Oomo
o`1EOol003Qoo`03001oogoo05Eoo`03001oogoo02Uoo`03001oogoo0:9oo`03001oogoo00Qoo`03
001oogoo01ioo`03001oogoo04Yoo`03001oogoo01ioo`03001oogoo05Ioo`00>7oo0P00EWoo00<0
07ooOol0:Goo00<007ooOol0XWoo0P002Goo00<007ooOol07Woo00<007ooOol0Bgoo00<007ooOol0
7Goo00<007ooOol0EWoo000hOol00`00Oomoo`1FOol00`00Oomoo`0WOol00`00Oomoo`2SOol00`00
Oomoo`08Ool00`00Oomoo`0MOol00`00Oomoo`1<Ool00`00Oomoo`0MOol00`00Oomoo`1FOol003Qo
o`03001oogoo05Ioo`03001oogoo02Moo`03001oogoo0:=oo`03001oogoo00Uoo`03001oogoo01ao
o`03001oogoo04aoo`03001oogoo01aoo`03001oogoo05Moo`00>7oo0P00F7oo00<007ooOol09Woo
00<007ooOol0Xgoo0P002Woo00<007ooOol077oo00<007ooOol0CGoo00<007ooOol06goo00<007oo
Ool0Egoo000hOol00`00Oomoo`1GOol00`00Oomoo`0UOol00`00Oomoo`2TOol00`00Oomoo`09Ool0
0`00Oomoo`0KOol00`00Oomoo`1>Ool00`00Oomoo`0KOol00`00Oomoo`1GOol003Qoo`03001oogoo
05Qoo`03001oogoo02Aoo`03001oogoo0:Aoo`03001oogoo00Uoo`03001oogoo01]oo`03001oogoo
04ioo`03001oogoo01Yoo`03001oogoo05Qoo`00>7oo00<007ooOol0F7oo00<007ooOol097oo00<0
07ooOol0Y7oo00<007ooOol02Woo00<007ooOol06Woo00<007ooOol0Cgoo00<007ooOol06Goo00<0
07ooOol0F7oo000hOol2001IOol00`00Oomoo`0SOol00`00Oomoo`2UOol2000;Ool00`00Oomoo`0I
Ool00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`1HOol001Moo`<000Ioo`8000Ioo`03001o
ogoo00Aoo`@000Eoo`03001oogoo05Uoo`03001oogoo029oo`03001oogoo08Aoo`<000Ioo`8000Io
o`03001oogoo00Aoo`@000Eoo`03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo051oo`03001o
ogoo01Qoo`03001oogoo05Uoo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo05Uoo`03001oogoo025oo`03001oogoo08Aoo`05001oogooOol00005
Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00
Oomoo`1AOol00`00Oomoo`0GOol00`00Oomoo`1IOol001Ioo`05001oogooOol0000>Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`1JOol00`00Oomoo`0POol00`00Oomoo`24Ool01@00Oomo
ogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol05goo00<0
07ooOol0DWoo00<007ooOol05goo00<007ooOol0FGoo000FOol01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo0P00Fgoo00<007ooOol07goo00<007ooOol0QGoo00D007ooOomoo`00
00ioo`03001oogoo00Moo`03001oogoo009oo`8000eoo`03001oogoo01Ioo`03001oogoo059oo`03
001oogoo01Ioo`03001oogoo05Yoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eo
o`03001oogoo05]oo`03001oogoo01eoo`03001oogoo08Ioo`05001oogooOol0000>Ool00`00Oomo
o`03Ool40005Ool00`00Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomoo`1COol00`00Oomoo`0EOol0
0`00Oomoo`1JOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`1LOol00`00Oomoo`0LOol00`00Oomoo`26Ool01@00Oomoogoo00003goo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol037oo00<007ooOol05Goo00<007ooOol0E7oo00<007ooOol057oo
00<007ooOol0Fgoo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Io
o`8005eoo`03001oogoo01]oo`03001oogoo08Moo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P003Woo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol057oo00<0
07ooOol0Fgoo000GOol3000<Ool50004Ool40005Ool00`00Oomoo`1MOol00`00Oomoo`0JOol00`00
Oomoo`28Ool3000<Ool50004Ool40005Ool00`00Oomoo`0=Ool00`00Oomoo`0DOol00`00Oomoo`1E
Ool00`00Oomoo`0BOol00`00Oomoo`1LOol003Qoo`03001oogoo05eoo`03001oogoo01Uoo`03001o
ogoo0:Yoo`03001oogoo00ioo`03001oogoo019oo`03001oogoo05Ioo`03001oogoo019oo`03001o
ogoo05aoo`00>7oo00<007ooOol0GWoo00<007ooOol067oo00<007ooOol0ZWoo00<007ooOol03Woo
00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0G7oo000hOol2001OOol0
0`00Oomoo`0GOol00`00Oomoo`2[Ool2000?Ool00`00Oomoo`0BOol00`00Oomoo`1GOol00`00Oomo
o`0@Ool00`00Oomoo`1MOol003Qoo`03001oogoo05moo`03001oogoo01Ioo`03001oogoo0:]oo`03
001oogoo00moo`03001oogoo011oo`03001oogoo05Qoo`03001oogoo011oo`03001oogoo05eoo`00
>7oo00<007ooOol0H7oo00<007ooOol057oo00<007ooOol0[7oo00<007ooOol03goo00<007ooOol0
47oo00<007ooOol0FGoo00<007ooOol03Woo00<007ooOol0GWoo000hOol2001QOol00`00Oomoo`0C
Ool00`00Oomoo`2]Ool2000AOol00`00Oomoo`0>Ool00`00Oomoo`1JOol00`00Oomoo`0>Ool00`00
Oomoo`1NOol003Qoo`03001oogoo065oo`03001oogoo019oo`03001oogoo0:eoo`03001oogoo015o
o`03001oogoo00eoo`03001oogoo05]oo`03001oogoo00aoo`03001oogoo05moo`00>7oo00<007oo
Ool0HWoo00<007ooOol047oo00<007ooOol0[Woo00<007ooOol04Goo00<007ooOol037oo00<007oo
Ool0GGoo00<007ooOol02goo00<007ooOol0Ggoo000hOol00`00Oomoo`1SOol00`00Oomoo`0>Ool0
0`00Oomoo`2_Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool00`00Oomoo`1OOol00`00Oomoo`09Ool0
0`00Oomoo`1POol003Qoo`8006Eoo`03001oogoo00]oo`800;9oo`8001Aoo`03001oogoo00Qoo`03
001oogoo065oo`03001oogoo00Moo`03001oogoo065oo`00;goo1@0017oo00<007ooOol0IGoo0P00
2Woo00<007ooOol0ZGoo1@0017oo00<007ooOol057oo00<007ooOol01Woo00<007ooOol0HWoo00<0
07ooOol01Woo00<007ooOol0HWoo000aOol00`00Oomoo`04Ool00`00Oomoo`1WOol00`00Oomoo`05
Ool2002^Ool00`00Oomoo`04Ool00`00Oomoo`0EOol00`00Oomoo`04Ool00`00Oomoo`1TOol00`00
Oomoo`04Ool00`00Oomoo`1SOol0035oo`03001oogoo00Aoo`8006Uoo`L00;1oo`03001oogoo00Ao
o`8001Moo`H006Qoo`H006Ioo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00
Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo
00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3003oOolWOol3003iOol00?mooomooeIoo`00
ogooogooEWoo002EOol3000017oo0000000067oo0`00ogoo1goo0`0000Aoo`00000001Uoo`<007Ao
o`00UWoo00D007ooOomoo`0000Uoo`H000Uoo`05001oogooOol0003oOol7Ool01@00Oomoogoo0000
2Goo1P0037oo00<007ooOol0Lgoo002FOol01@00Oomoogoo000077oo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0001Qoo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000eoo`03001oogoo0?moo`Eo
o`05001oogooOol00009Ool60009Ool01000Oomoo`00MGoo002FOol01@00Oomoogoo00006Woo0P00
ogoo27oo00D007ooOomoo`0001Uoo`03001oo`0007Eoo`00UGoo1@007Goo00<007ooOol0ogoo17oo
1@006Woo00<007oo0000MGoo002cOol01@00Oomoogoo0000ogoo9Woo0P00MGoo002dOol3003oOolX
Ool00`00Oomoo`1cOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00
Oomoo`3gOol002Ioo`H000Eoo`03001oogoo0?mooaaoo`H000Eoo`03001oogoo0?Moo`00<Goo00<0
07ooOol017oo0P00HWoo5P00Z7oo00<007ooOol017oo0P00Wgoo2P00B7oo000aOol00`00Oomoo`04
Ool00`00Oomoo`1LOol5000FOol6002ROol00`00Oomoo`04Ool00`00Oomoo`2KOol3000:Ool30015
Ool0035oo`03001oogoo00Aoo`03001oogoo05Moo`D0025oo`@009ioo`03001oogoo00Aoo`03001o
ogoo09Qoo`<0011oo`8004=oo`00<Goo00<007ooOol017oo0P00E7oo1000:Woo0`00Vgoo00<007oo
Ool017oo0P00V7oo00<007ooOol04goo00<007ooOol0@7oo000_Ool30006Ool00`00Oomoo`1AOol2
000aOol3002FOol30006Ool00`00Oomoo`2FOol00`00Oomoo`0EOol20010Ool003Qoo`03001oogoo
04moo`8003Ioo`8009eoo`03001oogoo09Aoo`8001Yoo`8003ioo`00>7oo00<007ooOol0CGoo0P00
>Woo0`00VWoo00<007ooOol0Tgoo00<007ooOol077oo00<007ooOol0>goo000hOol2001;Ool3000o
Ool2002HOol2002COol00`00Oomoo`0NOol00`00Oomoo`0jOol003Qoo`03001oogoo04Qoo`8004Ao
o`<009Eoo`03001oogoo095oo`03001oogoo021oo`03001oogoo03Uoo`00>7oo00<007ooOol0AWoo
0P00BGoo0P00Tgoo00<007ooOol0T7oo00<007ooOol08Woo00<007ooOol0>7oo000hOol20015Ool2
001=Ool00`00Oomoo`2@Ool2002AOol00`00Oomoo`0ROol00`00Oomoo`0hOol003Qoo`03001oogoo
049oo`80051oo`80091oo`03001oogoo08moo`03001oogoo02Aoo`03001oogoo03Moo`00>7oo00<0
07ooOol0@Goo00<007ooOol0DWoo0P00SWoo00<007ooOol0SWoo00<007ooOol09Woo00<007ooOol0
=Woo000hOol00`00Oomoo`0oOol2001GOol00`00Oomoo`2;Ool00`00Oomoo`2=Ool00`00Oomoo`0X
Ool00`00Oomoo`0eOol003Qoo`8003ioo`8005Yoo`8008]oo`8008eoo`03001oogoo02Uoo`03001o
ogoo03Eoo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0?7oo00<007oo
Ool0G7oo00<007ooOol0Igoo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0Rgoo
00<007ooOol0:goo00<007ooOol0=7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol0
27oo00<007ooOol00Woo00<007ooOol0>Woo0P00H7oo0P00IWoo00D007ooOomoo`0000Eoo`8000Io
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo08]oo`03001oogoo02aoo`03001oogoo03=o
o`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo
03Uoo`03001oogoo069oo`03001oogoo05]oo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`2:Ool00`00Oomoo`0]Ool00`00Oomoo`0cOol001Ioo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000iOol00`00Oomoo`1TOol00`00Oomo
o`1ROol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00RWoo00<007ooOol0
;goo00<007ooOol0<Woo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007oo
Ool0=Woo0P00J7oo0P00HWoo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo
08Uoo`03001oogoo031oo`03001oogoo035oo`005Woo00D007ooOomoo`0000moo`03001oogoo009o
o`03001oogoo00Ioo`03001oogoo03Eoo`03001oogoo06Yoo`03001oogoo05moo`05001oogooOol0
000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`28Ool00`00Oomoo`0bOol00`00Oomo
o`0`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00=7oo
0P00KWoo0P00Ggoo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20028
Ool00`00Oomoo`0cOol00`00Oomoo`0`Ool001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo039o
o`03001oogoo071oo`03001oogoo05eoo`<000aoo`D000Aoo`@000Eoo`03001oogoo08Moo`03001o
ogoo03Aoo`03001oogoo02moo`00>7oo00<007ooOol0<Goo00<007ooOol0LWoo00<007ooOol0OGoo
00<007ooOol0QWoo00<007ooOol0=Woo00<007ooOol0;Woo000hOol00`00Oomoo`0_Ool2001fOol2
001mOol00`00Oomoo`25Ool00`00Oomoo`0gOol00`00Oomoo`0^Ool003Qoo`8002moo`03001oogoo
07Qoo`03001oogoo07Yoo`8008Ioo`03001oogoo03Qoo`03001oogoo02eoo`00>7oo00<007ooOol0
;Goo00<007ooOol0NWoo00<007ooOol0NGoo00<007ooOol0Q7oo00<007ooOol0>Woo00<007ooOol0
;7oo000hOol00`00Oomoo`0/Ool00`00Oomoo`1lOol00`00Oomoo`1hOol00`00Oomoo`23Ool00`00
Oomoo`0kOol00`00Oomoo`0/Ool003Qoo`8002]oo`80081oo`8007Qoo`8008Aoo`03001oogoo03ao
o`03001oogoo02]oo`00>7oo00<007ooOol0:Goo00<007ooOol0PWoo00<007ooOol0MGoo00<007oo
Ool0PWoo00<007ooOol0?Woo00<007ooOol0:Woo000hOol00`00Oomoo`0XOol00`00Oomoo`24Ool0
0`00Oomoo`1dOol00`00Oomoo`22Ool00`00Oomoo`0nOol00`00Oomoo`0ZOol003Qoo`03001oogoo
02Ioo`8008Qoo`03001oogoo07=oo`03001oogoo085oo`03001oogoo041oo`03001oogoo02Uoo`00
>7oo0P009Woo00<007ooOol0RGoo00<007ooOol0LWoo0P00PGoo00<007ooOol0@Woo00<007ooOol0
:7oo000OOol30006Ool20005Ool40005Ool00`00Oomoo`0TOol00`00Oomoo`2;Ool00`00Oomoo`1H
Ool30006Ool20005Ool40005Ool00`00Oomoo`20Ool00`00Oomoo`12Ool00`00Oomoo`0XOol001io
o`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0SOol00`00Oomoo`2=Ool0
0`00Oomoo`1FOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0Ogoo00<0
07ooOol0A7oo00<007ooOol09goo000FOol60002Ool01@00Oomoogoo000047oo00<007ooOol00Woo
0P008goo00<007ooOol0Sgoo00<007ooOol0CGoo1P000Woo00D007ooOomoo`00011oo`03001oogoo
009oo`8007moo`03001oogoo04Ioo`03001oogoo02Ioo`007Woo00D007ooOomoo`00011oo`03001o
ogoo009oo`03001oogoo025oo`03001oogoo095oo`8005Eoo`05001oogooOol0000@Ool00`00Oomo
o`02Ool00`00Oomoo`1nOol00`00Oomoo`16Ool00`00Oomoo`0VOol001ioo`05001oogooOol0000<
Ool40005Ool00`00Oomoo`0POol00`00Oomoo`2DOol00`00Oomoo`1BOol01@00Oomoogoo000037oo
10001Goo00<007ooOol0OGoo00<007ooOol0B7oo00<007ooOol09Goo000NOol01@00Oomoogoo0000
37oo00<007ooOol01Woo00<007ooOol07goo00<007ooOol0UWoo00<007ooOol0DGoo00D007ooOomo
o`0000aoo`03001oogoo00Ioo`03001oogoo07eoo`03001oogoo04Qoo`03001oogoo02Eoo`007Woo
00D007ooOomoo`0000aoo`03001oogoo00Ioo`8001moo`03001oogoo09Qoo`03001oogoo051oo`05
001oogooOol0000<Ool00`00Oomoo`06Ool2001mOol00`00Oomoo`1:Ool00`00Oomoo`0TOol001mo
o`<000eoo`@000Eoo`03001oogoo01eoo`03001oogoo09Yoo`03001oogoo051oo`<000eoo`@000Eo
o`03001oogoo07]oo`03001oogoo04]oo`03001oogoo02Aoo`00>7oo00<007ooOol077oo00<007oo
Ool0W7oo00<007ooOol0J7oo00<007ooOol0Ngoo00<007ooOol0C7oo00<007ooOol08goo000hOol0
0`00Oomoo`0KOol00`00Oomoo`2NOol00`00Oomoo`1WOol00`00Oomoo`1jOol00`00Oomoo`1=Ool0
0`00Oomoo`0SOol003Qoo`8001]oo`03001oogoo0:1oo`03001oogoo06Ioo`8007]oo`03001oogoo
04ioo`03001oogoo029oo`00>7oo00<007ooOol067oo0P00Y7oo00<007ooOol0IGoo00<007ooOol0
NGoo00<007ooOol0D7oo00<007ooOol08Goo000hOol00`00Oomoo`0GOol00`00Oomoo`2UOol00`00
Oomoo`1TOol00`00Oomoo`1iOol00`00Oomoo`1@Ool00`00Oomoo`0QOol003Qoo`8001Moo`03001o
ogoo0:Moo`03001oogoo06=oo`8007Uoo`03001oogoo059oo`03001oogoo021oo`00>7oo00<007oo
Ool05Goo00<007ooOol0ZGoo00<007ooOol0HWoo00<007ooOol0N7oo00<007ooOol0DWoo00<007oo
Ool087oo000hOol00`00Oomoo`0DOol00`00Oomoo`2[Ool00`00Oomoo`1QOol00`00Oomoo`1gOol0
0`00Oomoo`1DOol00`00Oomoo`0OOol003Qoo`03001oogoo01=oo`03001oogoo0:eoo`03001oogoo
061oo`03001oogoo07Ioo`03001oogoo05Eoo`03001oogoo01moo`00>7oo0P004goo00<007ooOol0
[goo00<007ooOol0Ggoo0P00Mgoo00<007ooOol0EWoo00<007ooOol07Woo000GOol30006Ool20004
Ool50004Ool40005Ool00`00Oomoo`0AOol00`00Oomoo`2aOol00`00Oomoo`0mOol30006Ool20004
Ool50004Ool40005Ool00`00Oomoo`1eOol00`00Oomoo`1GOol00`00Oomoo`0NOol001Ioo`05001o
ogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol047oo00<007oo
Ool0/goo00<007ooOol0>goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomo
o`02Ool00`00Oomoo`1eOol00`00Oomoo`1HOol00`00Oomoo`0MOol000ioo`H0009oo`05001oogoo
Ool0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000@Ool00`00Oomoo`2eOol2000cOol60002
Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P00MGoo00<007ooOol0FGoo
00<007ooOol07Goo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol03Woo00<007ooOol0^7oo00<007ooOol0>7oo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo07Aoo`03001oogoo05Yoo`03001oogoo01aoo`005Woo00D007oo
Oomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00eoo`03001oogoo0;Yoo`03001oogoo
03Moo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1cOol00`00Oomoo`1K
Ool00`00Oomoo`0LOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0
0`00Oomoo`0<Ool00`00Oomoo`2lOol00`00Oomoo`0fOol01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol0Lgoo00<007ooOol0G7oo00<007ooOol06goo000FOol01@00
Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000aoo`03001oogoo0;ioo`03
001oogoo03Eoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00Lgoo
00<007ooOol0GGoo00<007ooOol06goo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`0:Ool0
0`00Oomoo`30Ool00`00Oomoo`0eOol3000=Ool30005Ool40005Ool00`00Oomoo`1bOol00`00Oomo
o`1NOol00`00Oomoo`0JOol003Qoo`03001oogoo00Uoo`03001oogoo01=oo`<000Ioo`8000Aoo`D0
01Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<001Yoo`<000Ioo`8000Eoo`<001Moo`03
001oogoo00Moo`D004Uoo`03001oogoo01moo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<0
019oo`03001oogoo00=oo`<000Ioo`8000Eoo`<001Uoo`<000Ioo`8000Eoo`<001eoo`04001oogoo
Ool5000DOol003Qoo`8000Uoo`03001oogoo01=oo`05001oogooOol00005Ool20005Ool01000Oomo
o`005goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo01Ioo`05001oogooOol00005Ool20004
Ool01@00Oomoogoo000067oo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000GOol00`00
Oomoo`08Ool00`00Oomoo`19Ool2000OOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Mo
o`05001oogooOol00005Ool20007Ool00`00Oomoo`0AOol00`00Oomoo`02Ool01@00Oomoogoo0000
1Goo0P0017oo00D007ooOomoo`0001Moo`05001oogooOol00005Ool20004Ool01@00Oomoogoo0000
7Goo00<007ooOol00Woo00<007ooOol057oo000hOol00`00Oomoo`07Ool00`00Oomoo`0DOol01@00
Oomoogoo00003Goo00<007ooOol05goo00D007ooOomoo`0000]oo`D001Moo`05001oogooOol0000;
Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogooOol0000HOol00`00Oomoo`07
Ool00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol05goo00D007oo
Oomoo`0000]oo`D0015oo`03001oogoo00=oo`05001oogooOol0000;Ool01@00Oomoogoo00005goo
00D007ooOomoo`0000]oo`05001oogooOol0000MOol00`00Oomoo`02Ool00`00Oomoo`0DOol003Qo
o`03001oogoo00Ioo`03001oogoo01Eoo`05001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomo
ogoo00002goo00@007ooOol001Qoo`05001oogooOol0000;Ool01@00Oomoogoo000067oo00D007oo
Oomoo`0000]oo`05001oogooOol0000IOol00`00Oomoo`06Ool00`00Oomoo`19Ool00`00Oomoo`0N
Ool01@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000BOol0
0`00Oomoo`03Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool0
1@00Oomoogoo00007Woo00D007ooOomoo`0001Ioo`00>7oo00<007ooOol01Goo00<007ooOol05Woo
00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00
Oomoogoo00002goo10006Goo00D007ooOomoo`0000aoo`<001]oo`03001oogoo00Eoo`03001oogoo
04Uoo`03001oogoo01ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo
00<007oo00004Goo00<007ooOol017oo00D007ooOomoo`0000]oo`@001Qoo`05001oogooOol0000<
Ool3000OOol01@00Oomoogoo00005Woo000hOol20005Ool00`00Oomoo`0GOol01@00Oomoogoo0000
3goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool0
0`00Oomoo`0JOol01@00Oomoogoo00002goo00D007ooOomoo`0001]oo`03001oogoo00Aoo`03001o
ogoo04Uoo`8001moo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<0
07oo00004Goo00<007ooOol017oo00D007ooOomoo`0000]oo`03001oogoo01Uoo`05001oogooOol0
000;Ool01@00Oomoogoo00007goo00@007ooOol001Ioo`00>7oo00<007ooOol00goo00<007ooOol0
67oo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00003Goo0P0067oo00D0
07ooOomoo`0000aoo`03001oogoo01Uoo`05001oogooOol0000;Ool01@00Oomoogoo000077oo00<0
07ooOol00goo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000]oo`05001oogooOol0
000GOol01@00Oomoogoo00003Goo0P004Goo00<007ooOol017oo00D007ooOomoo`0000aoo`03001o
ogoo01Qoo`05001oogooOol0000;Ool01@00Oomoogoo00007goo00@007ooOol001Ioo`00>7oo00<0
07ooOol00Woo00<007ooOol06Woo0`003Goo0`006Goo0`003goo00<007ooOol05goo0`003Woo0`00
6Goo0`003Goo0`007Woo00<007ooOol00`00Bgoo00<007ooOol07goo0`003Goo0`006Goo0`003goo
00<007ooOol03Woo00<007ooOol01Woo0`003Woo0`0067oo0`003Goo0`008Goo0`005Woo000hOol0
1@00Oomoogoo0000e7oo00<007ooOol0CGoo00<007ooOol0KWoo00<007ooOol0IWoo00<007ooOol0
5Woo000hOol200000goo001oo`3EOol00`00Oomoo`1<Ool2001^Ool00`00Oomoo`1XOol00`00Oomo
o`0EOol003Qoo`03001oo`000=Qoo`03001oogoo04]oo`03001oogoo06eoo`03001oogoo06Qoo`03
001oogoo01Eoo`00>7oo0P00fWoo00<007ooOol0BWoo00<007ooOol0K7oo00<007ooOol0JWoo00<0
07ooOol057oo000bOooY0010OooY000@Ool003Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo04Uoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo
00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol0:Goo
00<007ooOol0BGoo0P00:Woo00<007ooOol0:Goo00<007ooOol04goo00<007ooOol04goo00<007oo
Ool0:Goo00<007ooOol0:Goo00<007ooOol057oo000hOol00`00Oomoo`3oOolWOol2001[Ool00`00
Oomoo`23Ool003Qoo`800?moobQoo`<006Yoo`03001oogoo08=oo`00>7oo00<007ooOol0ogoo9goo
00<007oo0000JGoo00<007ooOol0Q7oo000hOol00`00Oomoo`3oOolWOol01000Oomoo`00J7oo00<0
07ooOol0Q7oo000hOol2003oOolXOol200000goo001oo`1VOol00`00Oomoo`25Ool003Qoo`03001o
ogoo0?moobMoo`05001oogooOol0001VOol00`00Oomoo`25Ool003Qoo`03001oogoo0?moobMoo`05
001oogooOol0001UOol00`00Oomoo`26Ool003Qoo`03001oogoo0?moobMoo`03001oogoo009oo`03
001oogoo069oo`03001oogoo08Ioo`00>7oo0P00ogoo:7oo0P000goo00<007ooOol0HGoo00<007oo
Ool0Qgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`03Ool00`00Oomoo`1POol00`00Oomoo`27
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00=oo`03001oogoo05moo`03001oogoo08Qoo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol017oo00<007ooOol0GWoo00<007ooOol0R7oo000hOol2
003oOolXOol20005Ool00`00Oomoo`1MOol00`00Oomoo`29Ool001Moo`<000Ioo`8000Aoo`D000Ao
o`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Eoo`03
001oogoo05aoo`03001oogoo08Uoo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008
Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol0
00Qoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo05]oo`03001oogoo08Yoo`005Woo00D0
07ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000=
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`1JOol00`00Oomoo`2:Ool001Io
o`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00
Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0FGoo
00<007ooOol0Rgoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00Moo`03001oogoo
05Qoo`03001oogoo08]oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`07Ool00`00Oomoo`1GOol00`00Oomoo`2<Ool001Ioo`05001oogooOol0000;Ool01@00Oomo
ogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004
Ool00`00Oomoo`06Ool20009Ool00`00Oomoo`1FOol00`00Oomoo`2<Ool001Moo`<000eoo`<000Eo
o`@000Eoo`03001oogoo0?moo`Ioo`<000eoo`<000Eoo`@000Eoo`03001oogoo00Qoo`03001oogoo
05Eoo`03001oogoo08eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol02Goo00<007ooOol0Dgoo
00<007ooOol0SWoo000hOol2003oOolXOol2000:Ool00`00Oomoo`1COol00`00Oomoo`2>Ool003Qo
o`03001oogoo0?moobMoo`03001oogoo00Yoo`03001oogoo055oo`03001oogoo08moo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol02Woo00<007ooOol0DGoo00<007ooOol0Sgoo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`0;Ool00`00Oomoo`1?Ool00`00Oomoo`2@Ool003Qoo`800?moobQoo`80
00aoo`03001oogoo04moo`03001oogoo091oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol02goo
00<007ooOol0CWoo00<007ooOol0TGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0<Ool00`00
Oomoo`1=Ool00`00Oomoo`2AOol003Qoo`800?moobQoo`8000eoo`03001oogoo04aoo`03001oogoo
099oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol03Goo00<007ooOol0BWoo00<007ooOol0Tgoo
000OOol30006Ool20005Ool40005Ool00`00Oomoo`3oOol>Ool30006Ool20005Ool40005Ool00`00
Oomoo`0=Ool00`00Oomoo`1:Ool00`00Oomoo`2COol001ioo`05001oogooOol00005Ool20009Ool0
0`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo
00<007ooOol03Woo00<007ooOol0B7oo00<007ooOol0U7oo000NOol01@00Oomoogoo000047oo00<0
07ooOol00Woo0P00ogoo3Woo00D007ooOomoo`00011oo`03001oogoo009oo`8000moo`03001oogoo
04Qoo`03001oogoo09Aoo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo0?mo
o`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`16Ool00`00
Oomoo`2EOol001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo
000037oo10001Goo00<007ooOol03goo00<007ooOol0AWoo00<007ooOol0UGoo000NOol01@00Oomo
ogoo000037oo00<007ooOol01Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo
00Ioo`03001oogoo011oo`03001oogoo04Aoo`03001oogoo09Ioo`007Woo00D007ooOomoo`0000ao
o`03001oogoo00Ioo`800?moo`ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2000BOol00`00
Oomoo`12Ool00`00Oomoo`2GOol001moo`<000eoo`@000Eoo`03001oogoo0?moo`ioo`<000eoo`@0
00Eoo`03001oogoo019oo`03001oogoo045oo`03001oogoo09Moo`00>7oo00<007ooOol0ogoo9goo
00<007ooOol04Woo00<007ooOol0@7oo00<007ooOol0V7oo000hOol2003oOolXOol2000DOol00`00
Oomoo`0nOol00`00Oomoo`2IOol003Qoo`03001oogoo0?moobMoo`03001oogoo01Aoo`03001oogoo
03eoo`03001oogoo09Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol057oo00<007ooOol0?7oo
00<007ooOol0VWoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0EOol00`00Oomoo`0kOol00`00
Oomoo`2JOol003Qoo`800?moobQoo`8001Moo`03001oogoo03Uoo`03001oogoo09]oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol05goo00<007ooOol0=goo00<007ooOol0W7oo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`0GOol00`00Oomoo`0gOol00`00Oomoo`2LOol003Qoo`800?moobQoo`80
01Uoo`03001oogoo03Eoo`03001oogoo09eoo`005goo0`001Woo0P001Woo00<007ooOol017oo1000
1Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol06Goo
00<007ooOol0<goo00<007ooOol0WWoo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol0
27oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo
00Qoo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo03=oo`03001oogoo09ioo`005Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogoo
Ool0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`0aOol00`00
Oomoo`2OOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003oOol6
Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P0077oo00<007ooOol0;goo
00<007ooOol0X7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo01aoo`03001oogoo
02eoo`03001oogoo0:5oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`0LOol00`00Oomoo`0/Ool00`00Oomoo`2ROol001Ioo`05001oogooOol0000;Ool01@00Oomo
ogoo000017oo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000]oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool00`00Oomoo`0MOol00`00Oomoo`0ZOol00`00Oomoo`2SOol001Mo
o`<000aoo`D000Aoo`@000Eoo`800?moo`Moo`<000aoo`D000Aoo`@000Eoo`8001moo`03001oogoo
02Uoo`03001oogoo0:=oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol07Woo00<007ooOol0:7oo
00<007ooOol0Y7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0OOol00`00Oomoo`0VOol00`00
Oomoo`2UOol003Qoo`800?moobQoo`80025oo`03001oogoo02Aoo`03001oogoo0:Ioo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol08Goo0P008goo00<007ooOol0Ygoo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`0SOol00`00Oomoo`0OOol00`00Oomoo`2XOol003Qoo`03001oogoo0?moobMoo`03
001oogoo02Aoo`03001oogoo01eoo`03001oogoo0:Uoo`00>7oo0P00ogoo:7oo0P009Woo00<007oo
Ool06goo00<007ooOol0ZWoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0VOol2000IOol2002]
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo02Qoo`03001oogoo01Aoo`800:moo`00>7oo0P00
ogoo:7oo0P00:Woo0P004goo00<007ooOol0[goo000_Ool50004Ool00`00Oomoo`3oOolNOol50004
Ool00`00Oomoo`0[Ool00`00Oomoo`0>Ool2002bOol0035oo`03001oogoo00Aoo`03001oogoo0?mo
ob1oo`03001oogoo00Aoo`03001oogoo02aoo`03001oogoo00]oo`800;Aoo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0;Goo10001goo0P00]Woo000aOol0
0`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2000bOol7002hOol0035oo`03001oogoo0?mo
obMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomo
o`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomF
Ool009Eoo`<00004Ool00000000HOol5003oOol5Ool3000017oo000000005goo1@00M7oo002FOol0
1@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H000Yoo`04
001oogoo001dOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo0000
6Woo00<007ooOol0M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D0
07ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001]oo`03001oogoo
0?moo`Ioo`05001oogooOol0000LOol00`00Oomoo`1bOol009Eoo`D001aoo`03001oogoo0?moo`Eo
o`D001eoo`03001oogoo079oo`00]Woo00<007ooOol0ogoo8goo00D007ooOomoo`0007Aoo`00]7oo
0`00ogoo9Woo0`00MGoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .20629 L
.08255 .15782 L
.10458 .11164 L
.12507 .07703 L
.14415 .05331 L
.14918 .04854 L
.15465 .0441 L
.15946 .04083 L
.16457 .03802 L
.16917 .03609 L
.17178 .03524 L
.17423 .03461 L
.17538 .03437 L
.17647 .03418 L
.17746 .03403 L
.17852 .0339 L
.17967 .03379 L
.18073 .03372 L
.182 .03368 L
.18314 .03369 L
.18435 .03372 L
.18547 .0338 L
.1867 .03391 L
.18802 .03409 L
.19071 .03458 L
.19317 .0352 L
.1979 .03686 L
.20239 .03898 L
.21236 .04559 L
.22321 .05568 L
.24299 .08149 L
.26399 .11839 L
.30174 .20404 L
.34195 .31086 L
.38063 .41358 L
.40028 .46082 L
.42177 .50589 L
.44253 .54102 L
.4614 .56451 L
.47149 .57346 L
.47611 .5767 L
.48101 .57951 L
.4835 .58069 L
.48624 .5818 L
.48876 .58265 L
.49106 .58328 L
.49378 .58383 L
.49527 .58405 L
.49596 .58413 L
Mistroke
.49669 .58421 L
.498 .5843 L
.49921 .58434 L
.49996 .58435 L
.50065 .58435 L
.50196 .5843 L
.50313 .58422 L
.50438 .58409 L
.50556 .58394 L
.50663 .58376 L
.50926 .5832 L
.51175 .58249 L
.5167 .5806 L
.52208 .57781 L
.53169 .57093 L
.54056 .56247 L
.55926 .53834 L
.57988 .50271 L
.62014 .41164 L
.65888 .30862 L
.70007 .1995 L
.72063 .1507 L
.73974 .11117 L
.75939 .07791 L
.77791 .05451 L
.78775 .0455 L
.79293 .04176 L
.7984 .03856 L
.80302 .03649 L
.80546 .03562 L
.80809 .03486 L
.8105 .03433 L
.8127 .03399 L
.81375 .03387 L
.81491 .03377 L
.81599 .03371 L
.817 .03368 L
.81818 .03369 L
.81941 .03373 L
.82047 .0338 L
.82163 .03391 L
.82287 .03408 L
.82421 .03429 L
.82661 .03481 L
.82905 .03549 L
.83134 .03628 L
.83564 .03813 L
.84078 .04098 L
.84552 .04423 L
.85624 .0537 L
Mistroke
.87498 .07709 L
.89561 .11199 L
.93591 .20216 L
.97471 .30497 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .43101 L
.08255 .48397 L
.0932 .50724 L
.10458 .5278 L
.11009 .53602 L
.11531 .54268 L
.12038 .5481 L
.12507 .55216 L
.12951 .55515 L
.13178 .55635 L
.13422 .55739 L
.13549 .55784 L
.13666 .55818 L
.13784 .55847 L
.13895 .55868 L
.14022 .55887 L
.1409 .55893 L
.14161 .55898 L
.1423 .55901 L
.14295 .55902 L
.14415 .55898 L
.14531 .55889 L
.14656 .55872 L
.14773 .5585 L
.14881 .55825 L
.15143 .55742 L
.15392 .55636 L
.15886 .55347 L
.16423 .54914 L
.17383 .53844 L
.1827 .52525 L
.20137 .48814 L
.22197 .43474 L
.26217 .30814 L
.30086 .1861 L
.32051 .1344 L
.3309 .11159 L
.342 .09132 L
.35275 .07612 L
.35784 .07055 L
.36253 .06637 L
.36724 .0631 L
.36972 .06176 L
.37235 .06063 L
.37463 .05989 L
.37573 .05961 L
.37677 .0594 L
.37799 .05921 L
.37911 .05909 L
Mistroke
.38031 .05903 L
.38162 .05903 L
.38227 .05905 L
.38296 .0591 L
.38419 .05924 L
.38551 .05947 L
.38695 .0598 L
.38955 .06062 L
.39197 .06165 L
.39649 .06425 L
.40134 .068 L
.40698 .07361 L
.41232 .08012 L
.42232 .09535 L
.44227 .13647 L
.4607 .18512 L
.50002 .30909 L
.53782 .42867 L
.55884 .48419 L
.56803 .50449 L
.57808 .52337 L
.58722 .53729 L
.59696 .54848 L
.60236 .55298 L
.60726 .556 L
.60962 .55709 L
.61086 .55756 L
.61218 .55799 L
.61333 .55831 L
.61459 .55859 L
.61574 .55878 L
.61682 .55891 L
.61808 .559 L
.61871 .55901 L
.61941 .55901 L
.62065 .55896 L
.62181 .55885 L
.62248 .55876 L
.62318 .55865 L
.62443 .55839 L
.62578 .55803 L
.62725 .55755 L
.62973 .55654 L
.63238 .55516 L
.63715 .55192 L
.64214 .5475 L
.64686 .54237 L
.6557 .53035 L
.67568 .4924 L
.69413 .44605 L
Mistroke
.7335 .32417 L
.77136 .20279 L
.79241 .1448 L
.81166 .1027 L
.82118 .08664 L
.8262 .07956 L
.83155 .07313 L
.8367 .06806 L
.84136 .06442 L
.84361 .06299 L
.84604 .06169 L
.84835 .0607 L
.85045 .05999 L
.85159 .05969 L
.85283 .05942 L
.85414 .05921 L
.85538 .05908 L
.85653 .05903 L
.85776 .05903 L
.85881 .05908 L
.85997 .05919 L
.86063 .05928 L
.86132 .0594 L
.86256 .05966 L
.86535 .06048 L
.86777 .06147 L
.87041 .06284 L
.87569 .06646 L
.88133 .07164 L
.89148 .08424 L
.90173 .10105 L
.91284 .12354 L
.933 .17412 L
.97393 .30158 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .27022 L
.10458 .22866 L
.14415 .19101 L
.18221 .1567 L
.22272 .12282 L
.26171 .09334 L
.30316 .06592 L
.34309 .04379 L
.3815 .02683 L
.40095 .01995 L
.42237 .01376 L
.44268 .00924 L
.45178 .00766 L
.46172 .00624 L
.4671 .0056 L
.4721 .0051 L
.47727 .00466 L
.48196 .00434 L
.48658 .0041 L
.4887 .00402 L
.49093 .00394 L
.49332 .00388 L
.49438 .00386 L
.49552 .00384 L
.49675 .00382 L
.49789 .00381 L
.49859 .00381 L
.49925 .00381 L
.50049 .0038 L
.50163 .00381 L
.50286 .00382 L
.50401 .00383 L
.50508 .00385 L
.50754 .0039 L
.51014 .00398 L
.51268 .00407 L
.51504 .00418 L
.5204 .0045 L
.5293 .00523 L
.53882 .0063 L
.54906 .00779 L
.56016 .0098 L
.58032 .01445 L
.62123 .02789 L
.66064 .04566 L
.69852 .06694 L
.73886 .09375 L
.77769 .12314 L
.81897 .15772 L
Mistroke
.85873 .19369 L
.89697 .23016 L
.93767 .27034 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .38312 L
.10458 .45832 L
.14415 .5186 L
.18221 .56321 L
.20178 .58009 L
.21267 .58754 L
.22272 .59314 L
.23293 .59756 L
.23832 .59936 L
.24402 .60087 L
.24641 .60137 L
.24897 .60184 L
.25119 .60218 L
.25361 .60247 L
.25507 .60261 L
.25643 .60272 L
.25773 .6028 L
.2584 .60283 L
.25912 .60286 L
.25983 .60288 L
.26048 .6029 L
.26176 .60291 L
.26293 .6029 L
.26416 .60288 L
.26538 .60283 L
.26607 .6028 L
.26671 .60276 L
.26912 .60258 L
.27131 .60234 L
.27364 .60203 L
.27847 .60116 L
.2838 .59985 L
.29326 .59665 L
.30213 .59262 L
.32232 .57987 L
.34082 .56397 L
.38045 .51752 L
.41855 .45944 L
.45912 .38733 L
.49816 .31258 L
.53966 .233 L
.57964 .16161 L
.61811 .1025 L
.63759 .0774 L
.65902 .05421 L
.67938 .0369 L
.69843 .02513 L
.70884 .02058 L
.71396 .01884 L
Mistroke
.71872 .01752 L
.72301 .01658 L
.72758 .01583 L
.7302 .01552 L
.73148 .0154 L
.73266 .01531 L
.73371 .01525 L
.73487 .01519 L
.73603 .01515 L
.73725 .01513 L
.73856 .01513 L
.73977 .01514 L
.7404 .01516 L
.7411 .01518 L
.74251 .01525 L
.74375 .01533 L
.74508 .01544 L
.74748 .01569 L
.74985 .01601 L
.75235 .01642 L
.7568 .01736 L
.76198 .01877 L
.7668 .02038 L
.77773 .02511 L
.78828 .03109 L
.79823 .03795 L
.81683 .05389 L
.85534 .09875 L
.89632 .16122 L
.93577 .23157 L
.97371 .30421 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`0OOol6002=Ool7001]Ool00`00Oomoo`3`Ool003Qoo`03001oogoo01eoo`<000Eoo`<0
08Qoo`<000Eoo`8006aoo`03001oogoo0?1oo`00>7oo00<007ooOol06goo0P002goo00<007ooOol0
Q7oo00<007ooOol027oo0P00JWoo00<007ooOol0l7oo000hOol2000KOol00`00Oomoo`0<Ool00`00
Oomoo`22Ool00`00Oomoo`0;Ool00`00Oomoo`1WOol2003aOol003Qoo`03001oogoo01Yoo`03001o
ogoo00eoo`03001oogoo081oo`03001oogoo00eoo`03001oogoo06Ioo`03001oogoo0?1oo`00>7oo
00<007ooOol06Goo00<007ooOol03goo00<007ooOol0OWoo00<007ooOol03goo00<007ooOol0IGoo
00<007ooOol0l7oo000hOol00`00Oomoo`0HOol00`00Oomoo`0@Ool00`00Oomoo`1mOol00`00Oomo
o`0@Ool00`00Oomoo`1UOol00`00Oomoo`1=Ool6001XOol6000_Ool003Qoo`8001Qoo`03001oogoo
019oo`03001oogoo07]oo`03001oogoo019oo`03001oogoo06Aoo`8004eoo`03001oogoo00Aoo`03
001oogoo06Aoo`8000Eoo`03001oogoo02aoo`005goo0`001Woo0P001Woo00<007ooOol017oo1000
1Goo00<007ooOol05Woo00<007ooOol057oo00<007ooOol0NGoo00<007ooOol057oo00<007ooOol0
@Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0Bgoo00<007ooOol01Woo0P00
Hgoo00<007ooOol01Woo0P00;7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo
00<007ooOol00Woo00<007ooOol05Goo00<007ooOol05Woo00<007ooOol0Mgoo00<007ooOol05Woo
00<007ooOol0@7oo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo04Yoo`03001oogoo00Uoo`03001oogoo05moo`03001oogoo00Uoo`03001oogoo02Uoo`00
3Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8001Eoo`03001o
ogoo01Qoo`03001oogoo07Eoo`03001oogoo01Qoo`03001oogoo03Moo`H0009oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2001:Ool00`00Oomoo`0:Ool00`00Oomoo`1OOol0
0`00Oomoo`09Ool00`00Oomoo`0YOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`0DOol00`00Oomoo`0IOol00`00Oomoo`1dOol00`00Oomoo`0HOol00`00
Oomoo`0oOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0BGoo
00<007ooOol02goo00<007ooOol0GGoo00<007ooOol02goo00<007ooOol0:7oo000FOol01@00Oomo
ogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol04goo00<007ooOol06Woo00<007ooOol0
Lgoo00<007ooOol06Woo00<007ooOol0?Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eo
o`03001oogoo04Qoo`03001oogoo00aoo`03001oogoo05aoo`03001oogoo00eoo`03001oogoo02Mo
o`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01=oo`03
001oogoo01]oo`03001oogoo079oo`03001oogoo01]oo`03001oogoo03eoo`05001oogooOol0000?
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`17Ool00`00Oomoo`0>Ool00`00Oomoo`1K
Ool00`00Oomoo`0=Ool00`00Oomoo`0WOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P004goo00<007ooOol077oo00<007ooOol0LGoo00<007ooOol077oo00<0
07ooOol0?Goo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20018Ool0
0`00Oomoo`0?Ool00`00Oomoo`1IOol00`00Oomoo`0?Ool00`00Oomoo`0VOol001Moo`<000aoo`D0
00Aoo`@000Eoo`03001oogoo019oo`03001oogoo01eoo`03001oogoo071oo`03001oogoo01eoo`03
001oogoo03eoo`<000aoo`D000Aoo`@000Eoo`03001oogoo04Ioo`03001oogoo011oo`03001oogoo
05Qoo`03001oogoo011oo`03001oogoo02Ioo`00>7oo00<007ooOol04Goo00<007ooOol07goo00<0
07ooOol0KWoo00<007ooOol07Woo00<007ooOol0GWoo00<007ooOol0AGoo00<007ooOol04Woo00<0
07ooOol0EWoo00<007ooOol04Woo00<007ooOol09Goo000hOol2000BOol00`00Oomoo`0OOol00`00
Oomoo`1^Ool00`00Oomoo`0OOol00`00Oomoo`1MOol20016Ool00`00Oomoo`0BOol00`00Oomoo`1F
Ool00`00Oomoo`0BOol00`00Oomoo`0UOol003Qoo`03001oogoo011oo`03001oogoo025oo`03001o
ogoo06aoo`03001oogoo025oo`03001oogoo05aoo`03001oogoo04Aoo`03001oogoo01Aoo`03001o
ogoo05Aoo`03001oogoo01Aoo`03001oogoo02Aoo`00>7oo00<007ooOol047oo00<007ooOol08Goo
00<007ooOol0K7oo00<007ooOol08Goo00<007ooOol0G7oo00<007ooOol0A7oo00<007ooOol057oo
00<007ooOol0E7oo00<007ooOol05Goo00<007ooOol08goo000hOol00`00Oomoo`0?Ool00`00Oomo
o`0SOol00`00Oomoo`1ZOol00`00Oomoo`0SOol00`00Oomoo`1KOol00`00Oomoo`13Ool00`00Oomo
o`0FOol00`00Oomoo`1COol00`00Oomoo`0EOol00`00Oomoo`0SOol003Qoo`80011oo`03001oogoo
02=oo`03001oogoo06Yoo`03001oogoo02=oo`03001oogoo05]oo`8004Aoo`03001oogoo01Ioo`03
001oogoo059oo`03001oogoo01Moo`03001oogoo029oo`00>7oo00<007ooOol03Woo00<007ooOol0
9Goo00<007ooOol0J7oo00<007ooOol09Goo00<007ooOol0FWoo00<007ooOol0@goo00<007ooOol0
5goo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol08Woo000hOol00`00Oomoo`0>Ool00`00
Oomoo`0UOol00`00Oomoo`1WOol00`00Oomoo`0VOol00`00Oomoo`1JOol00`00Oomoo`12Ool00`00
Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`0QOol003Qoo`8000ioo`03001o
ogoo02Ioo`03001oogoo06Moo`03001oogoo02Ioo`03001oogoo05Yoo`8004=oo`03001oogoo01Uo
o`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025oo`007goo0`001Woo0P001Goo10001Goo
00<007ooOol03Goo00<007ooOol09goo00<007ooOol0IGoo00<007ooOol0:7oo00<007ooOol0@7oo
0`001Woo0P001Goo10001Goo00<007ooOol0@Goo00<007ooOol06Woo00<007ooOol0Cgoo00<007oo
Ool06Goo00<007ooOol08Goo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<0
07ooOol03Goo00<007ooOol09goo00<007ooOol0IGoo00<007ooOol0:7oo00<007ooOol0?goo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo045oo`03001oogoo01]oo`03001o
ogoo04eoo`03001oogoo01]oo`03001oogoo021oo`005Woo1P000Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo00aoo`03001oogoo02Uoo`03001oogoo06=oo`03001oogoo02Yoo`03
001oogoo03Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`11Ool00`00
Oomoo`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`0POol001ioo`05001oogooOol0
000@Ool00`00Oomoo`02Ool2000=Ool00`00Oomoo`0YOol00`00Oomoo`1SOol00`00Oomoo`0ZOol0
0`00Oomoo`0nOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00@Goo00<007ooOol077oo00<0
07ooOol0C7oo00<007ooOol077oo00<007ooOol087oo000NOol01@00Oomoogoo000037oo10001Goo
00<007ooOol02goo00<007ooOol0:goo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0?Goo
00D007ooOomoo`0000aoo`@000Eoo`03001oogoo041oo`03001oogoo01eoo`03001oogoo04]oo`03
001oogoo01eoo`03001oogoo01moo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001o
ogoo00]oo`03001oogoo02]oo`03001oogoo065oo`03001oogoo02aoo`03001oogoo03eoo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1;Ool0
0`00Oomoo`0MOol00`00Oomoo`0OOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00
Oomoo`0:Ool00`00Oomoo`0/Ool00`00Oomoo`1QOol00`00Oomoo`0/Ool00`00Oomoo`0mOol01@00
Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0?goo00<007ooOol07Woo00<007ooOol0BWoo
00<007ooOol07Woo00<007ooOol07goo000OOol3000=Ool40005Ool2000;Ool00`00Oomoo`0]Ool0
0`00Oomoo`1OOol00`00Oomoo`0^Ool00`00Oomoo`0mOol3000=Ool40005Ool2000oOol00`00Oomo
o`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`0NOol003Qoo`03001oogoo00Uoo`03
001oogoo02ioo`03001oogoo05moo`03001oogoo02ioo`03001oogoo05Ioo`03001oogoo03ioo`03
001oogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001oogoo01ioo`00>7oo00<007ooOol0
2Goo00<007ooOol0;goo00<007ooOol0GWoo00<007ooOol0;goo00<007ooOol0EGoo00<007ooOol0
?Woo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol087oo00<007ooOol07Woo000hOol20009
Ool00`00Oomoo`0`Ool00`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomoo`1EOol2000nOol00`00
Oomoo`0ROol00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`0MOol003Qoo`03001oogoo00Qo
o`03001oogoo035oo`03001oogoo05aoo`03001oogoo035oo`03001oogoo05Aoo`03001oogoo03eo
o`03001oogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo01eoo`00>7oo00<007oo
Ool027oo00<007ooOol0<Goo00<007ooOol0G7oo00<007ooOol0<Goo00<007ooOol0E7oo00<007oo
Ool0?Goo00<007ooOol08Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol07Goo000hOol0
0`00Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`1KOol00`00Oomoo`0bOol00`00Oomoo`1DOol0
0`00Oomoo`0lOol00`00Oomoo`0TOol00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`0LOol0
03Qoo`8000Qoo`03001oogoo03=oo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo05=oo`80
03eoo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo01aoo`00>7oo00<0
07ooOol01Woo00<007ooOol0=7oo00<007ooOol0FGoo00<007ooOol0=7oo00<007ooOol0Dgoo00<0
07ooOol0?7oo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol077oo000h
Ool00`00Oomoo`06Ool00`00Oomoo`0eOol00`00Oomoo`1HOol00`00Oomoo`0eOol00`00Oomoo`1B
Ool00`00Oomoo`0kOol00`00Oomoo`0VOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`0K
Ool003Qoo`8000Ioo`03001oogoo03Ioo`03001oogoo05Qoo`03001oogoo03Eoo`03001oogoo059o
o`8003aoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01]oo`005goo
0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol01Goo00<007ooOol0=Woo00<007ooOol0Egoo
00<007ooOol0=Woo00<007ooOol0<Goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0>goo
00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol06goo000FOol01@00Oomo
ogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo
03Moo`03001oogoo05Ioo`03001oogoo03Moo`03001oogoo02moo`05001oogooOol00005Ool20005
Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol0
@Goo00<007ooOol09goo00<007ooOol06Woo000>Ool60002Ool01@00Oomoogoo00003Goo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0>7oo00<007ooOol0EGoo00<007oo
Ool0>7oo00<007ooOol09goo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo03Yoo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo
01Yoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000Eoo`03001o
ogoo03Uoo`03001oogoo05Aoo`03001oogoo03Qoo`03001oogoo02moo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool2000kOol00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomo
o`0XOol00`00Oomoo`0JOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00
Oomoo`04Ool00`00Oomoo`0iOol00`00Oomoo`1DOol00`00Oomoo`0iOol00`00Oomoo`0^Ool01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0>Goo00<007ooOol0:Woo00<007oo
Ool0?goo00<007ooOol0:Goo00<007ooOol06Goo000FOol01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0>Woo00<007ooOol0Dgoo00<007ooOol0
>Woo00<007ooOol0;Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo03Uoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo01Uoo`005Woo
00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20004Ool00`00Oomoo`0k
Ool00`00Oomoo`1BOol00`00Oomoo`0kOol00`00Oomoo`0]Ool01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`8003Yoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo
02Yoo`03001oogoo01Uoo`005goo0`003Goo0`001Goo10001Goo00<007ooOol00Woo00<007ooOol0
?7oo00<007ooOol0DWoo00<007ooOol0>goo00<007ooOol0;Woo0`003Goo0`001Goo10001Goo00<0
07ooOol0>7oo00<007ooOol0;7oo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol067oo000h
Ool00`00Oomoo`02Ool00`00Oomoo`0mOol00`00Oomoo`1@Ool00`00Oomoo`0lOol00`00Oomoo`1?
Ool00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`0H
Ool003Qoo`03001oogoo009oo`03001oogoo01Yoo`<000Ioo`8000Aoo`D000moo`03001oogoo00Io
o`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<000]oo`03001oogoo00aoo`<000Ioo`8000Eo
o`<001ioo`03001oogoo00D004Uoo`03001oogoo01moo`<000Ioo`8000Aoo`D000Eoo`03001oogoo
011oo`<000Ioo`8000Ioo`<000Qoo`03001oogoo00eoo`<000Ioo`8000Eoo`<001Uoo`@000Eoo`80
00Eoo`<001moo`03001oo`0000@001Aoo`00>7oo0P000Woo00<007ooOol06Woo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo000?Ool00`00Oomoo`05Ool01@00Oomoogoo00001Goo0P001goo00<0
07ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol00009Ool00`00Oomoo`0<Ool0
1@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001eoo`03001oogoo009oo`03001oogoo04Uo
o`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`001Goo00<007ooOol03goo00D007oo
Oomoo`0000Eoo`8000Moo`03001oogoo00Moo`03001oogoo00aoo`05001oogooOol00005Ool20004
Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000OOol01000
Oomoo`005Woo000hOol01@00Oomoogoo000077oo00D007ooOomoo`0000eoo`03001oogoo011oo`03
001oogoo00Aoo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomoo`00
00Uoo`03001oogoo00aoo`05001oogooOol0000;Ool01@00Oomoogoo00007Goo00<007ooOol00Woo
00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000eoo`03001oogoo00Aoo`03001oogoo
011oo`05001oogooOol0000;Ool50009Ool00`00Oomoo`0;Ool01@00Oomoogoo00002goo00D007oo
Oomoo`0001Moo`03001oogoo008000]oo`05001oogooOol0000OOol01000Oomoo`005Woo000hOol0
1@00Oomoogoo000077oo00D007ooOomoo`0000ioo`03001oogoo00moo`03001oogoo00Aoo`05001o
ogooOol0000;Ool01000Oomoo`0067oo00D007ooOomoo`0000]oo`05001oogooOol00009Ool00`00
Oomoo`0<Ool01@00Oomoogoo00002goo00D007ooOomoo`0001ioo`05001oogooOol0001;Ool00`00
Oomoo`0NOol01@00Oomoogoo00003Woo00<007ooOol00goo00<007ooOol047oo00D007ooOomoo`00
00]oo`04001oogoo000:Ool00`00Oomoo`0;Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Mo
o`03001oogoo008000]oo`05001oogooOol0000OOol01000Oomoo`005Woo000hOol01000Oomoo`00
7Goo00D007ooOomoo`0000moo`03001oogoo00moo`03001oogoo00=oo`05001oogooOol0000<Ool0
0`00Ool0000HOol01@00Oomoogoo00002goo10002Goo00<007ooOol03Goo00D007ooOomoo`0000ao
o`<001moo`05001oogooOol0001;Ool00`00Oomoo`0NOol01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol047oo00D007ooOomoo`0000aoo`03001oo`0000Yoo`03001oogoo00]oo`05001o
ogooOol0000;Ool4000HOol00`00Oomoo`02000<Ool3000QOol00`00Ool0000FOol003Qoo`800003
Ool007oo01aoo`05001oogooOol0000?Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool01@00Oomoogoo
000037oo00<007oo000067oo00D007ooOomoo`0000]oo`03001oogoo00Yoo`03001oogoo00eoo`05
001oogooOol0000;Ool01@00Oomoogoo00007goo00@007ooOol004]oo`8001moo`05001oogooOol0
000?Ool01@00Oomoogoo00004goo00D007ooOomoo`0000aoo`03001oo`0000]oo`03001oogoo00Yo
o`05001oogooOol0000;Ool00`00Oomoo`0IOol01@00Ool007oo00002goo00D007ooOomoo`00021o
o`03001oo`0001Ioo`00>7oo00<007oo00007Woo00D007ooOomoo`0000]oo`05001oogooOol0000A
Ool00`00Oomoo`03Ool01@00Oomoogoo00003Goo0P0067oo00D007ooOomoo`0000aoo`03001oogoo
00Qoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo00007goo00@007ooOol004]o
o`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00000goo00<007ooOol04Goo00D0
07ooOomoo`0000eoo`8000]oo`03001oogoo00Yoo`05001oogooOol0000<Ool00`00Oomoo`0HOol0
1@00Ool007oo00002goo00D007ooOomoo`00021oo`03001oo`0001Ioo`00>7oo00<007oo00007goo
0`003Goo0`004goo00<007ooOol00goo0`003goo00<007ooOol05goo0`003Woo0`001goo00<007oo
Ool03goo0`003Goo0`0087oo1000Bgoo00<007ooOol07goo0`003Goo0`0017oo00<007ooOol04Woo
0`003goo00<007ooOol02Goo00<007ooOol02goo0`003Woo0`0067oo0`003Goo0`008Goo0`005Woo
000hOol30015Ool00`00Oomoo`1:Ool00`00Oomoo`13Ool00`00Oomoo`1;Ool2000fOol00`00Oomo
o`0bOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`0EOol003Qoo`8004Moo`03001oogoo
04Qoo`03001oogoo04Aoo`03001oogoo04]oo`03001oogoo03Eoo`03001oogoo039oo`03001oogoo
03Ioo`03001oogoo039oo`03001oogoo01Eoo`00>7oo0P00Agoo00<007ooOol0B7oo00<007ooOol0
A7oo00<007ooOol0Bgoo00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=Woo00<007ooOol0
<goo00<007ooOol057oo000hOol20017Ool00`00Oomoo`18Ool00`00Oomoo`15Ool00`00Oomoo`1:
Ool00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0D
Ool0039oonT0041oonT0011oo`00>7oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol01Goo00@007ooOol000Yo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qo
o`05001oogooOol00006Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0DOol003Qoo`03
001oogoo04Qoo`03001oogoo04Aoo`03001oogoo09Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03
001oogoo03=oo`03001oogoo04aoo`00>7oo0P00BGoo00<007ooOol0A7oo00<007ooOol0U7oo0P00
=7oo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol0C7oo000hOol00`00Oomoo`18Ool00`00
Oomoo`14Ool00`00Oomoo`2DOol2000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`1<
Ool003Qoo`03001oogoo04Uoo`03001oogoo049oo`03001oogoo09Eoo`8003Aoo`03001oogoo03Io
o`03001oogoo039oo`03001oogoo04aoo`00>7oo00<007ooOol0BGoo00<007ooOol0@Woo00<007oo
Ool0UGoo00<007oo0000<Woo00<007ooOol0>7oo00<007ooOol0<7oo00<007ooOol0CGoo000hOol2
001:Ool00`00Oomoo`12Ool00`00Oomoo`2EOol3000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool0
0`00Oomoo`1=Ool003Qoo`03001oogoo04Yoo`03001oogoo041oo`03001oogoo09Ioo`03001oo`00
039oo`03001oogoo03Qoo`03001oogoo031oo`03001oogoo04eoo`00>7oo00<007ooOol0BWoo00<0
07ooOol0@7oo00<007ooOol0UWoo00@007ooOol0031oo`03001oogoo03Yoo`03001oogoo02ioo`03
001oogoo04ioo`00>7oo00<007ooOol0Bgoo00<007ooOol0?Woo00<007ooOol0Ugoo00@007ooOol0
031oo`03001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo0P00C7oo00<007ooOol0
?Woo00<007ooOol0Ugoo0P0000=oo`00Ool0;goo00<007ooOol0>Woo00<007ooOol0;Woo00<007oo
Ool0CWoo000hOol00`00Oomoo`1;Ool00`00Oomoo`0nOol00`00Oomoo`2GOol01@00Oomoogoo0000
;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo000hOol00`00Oomoo`1<Ool00`00
Oomoo`0lOol00`00Oomoo`2HOol01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007ooOol0;7oo
00<007ooOol0Cgoo000hOol2001=Ool00`00Oomoo`0lOol00`00Oomoo`2HOol20002Ool00`00Oomo
o`0/Ool00`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`1?Ool001Moo`<000Ioo`8000Aoo`D0
00Aoo`@000Eoo`03001oogoo04aoo`03001oogoo03aoo`03001oogoo07Moo`<000Ioo`8000Aoo`D0
00Aoo`@000Eoo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03
001oogoo051oo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02
Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00Oomoo`1gOol01@00Oomoogoo00001Goo0P001Goo
00@007ooOol000Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03io
o`03001oogoo02Yoo`03001oogoo051oo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo04eoo`03001oogoo03Yoo`03001oogoo07Moo`05001oogooOol0000=
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`0n
Ool00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool2001?Ool00`00Oomoo`0hOol00`00Oomoo`1hOol01@00Oomoogoo00003Woo00<0
07ooOol01goo00<007ooOol00Woo0P0017oo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0
:7oo00<007ooOol0DGoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007oo
Ool0CWoo00<007ooOol0>7oo00<007ooOol0N7oo00D007ooOomoo`0000moo`03001oogoo009oo`@0
00Eoo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo
055oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo04io
o`03001oogoo03Qoo`03001oogoo07Qoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`03Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomo
o`1AOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00D7oo
00<007ooOol0=Woo00<007ooOol0NGoo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool20005Ool00`00Oomoo`0WOol00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`1A
Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo04moo`03001oogoo03Ioo`03001oogoo07Yo
o`<000eoo`<000Eoo`@000Eoo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo049oo`03001o
ogoo02Ioo`03001oogoo059oo`00>7oo00<007ooOol0Cgoo00<007ooOol0=Woo00<007ooOol0Vgoo
00<007ooOol017oo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol0DWoo
000hOol00`00Oomoo`1@Ool00`00Oomoo`0dOol00`00Oomoo`2LOol00`00Oomoo`05Ool00`00Oomo
o`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`1BOol003Qoo`80055oo`03001oogoo
03Aoo`03001oogoo09aoo`8000Ioo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03
001oogoo05=oo`00>7oo00<007ooOol0DGoo00<007ooOol0<Woo00<007ooOol0WGoo00<007ooOol0
1Goo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol0Dgoo000hOol00`00
Oomoo`1AOol00`00Oomoo`0bOol00`00Oomoo`2MOol00`00Oomoo`06Ool00`00Oomoo`0SOol00`00
Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`1COol003Qoo`80059oo`03001oogoo035oo`03001o
ogoo09ioo`8000Moo`03001oogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo05Ao
o`00>7oo00<007ooOol0DWoo00<007ooOol0<7oo00<007ooOol0WWoo00<007ooOol01Woo00<007oo
Ool08Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol0E7oo000hOol00`00Oomoo`1BOol0
0`00Oomoo`0`Ool00`00Oomoo`2NOol00`00Oomoo`07Ool00`00Oomoo`0QOol00`00Oomoo`17Ool0
0`00Oomoo`0QOol00`00Oomoo`1DOol003Qoo`03001oogoo059oo`03001oogoo02moo`03001oogoo
09moo`03001oogoo00Moo`03001oogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001oogoo
05Eoo`00>7oo0P00E7oo00<007ooOol0;Woo00<007ooOol0Wgoo0P0027oo00<007ooOol087oo00<0
07ooOol0B7oo00<007ooOol087oo00<007ooOol0EGoo000OOol30006Ool20005Ool40005Ool00`00
Oomoo`1COol00`00Oomoo`0]Ool00`00Oomoo`27Ool30006Ool20005Ool40005Ool00`00Oomoo`08
Ool00`00Oomoo`0OOol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`1EOol001ioo`05001o
ogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`0]Ool00`00Oomo
o`26Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0
7Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000NOol01@00Oomoogoo000047oo
00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol0:goo00<007ooOol0Qgoo00D007ooOomoo`00
011oo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo01ioo`03001oogoo04]oo`03001oogoo
01eoo`03001oogoo05Ioo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`8005Eoo`03001o
ogoo02]oo`03001oogoo08Moo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000:Ool00`00Oomo
o`0LOol00`00Oomoo`1<Ool00`00Oomoo`0MOol00`00Oomoo`1FOol001ioo`05001oogooOol0000<
Ool40005Ool00`00Oomoo`1EOol00`00Oomoo`0ZOol00`00Oomoo`27Ool01@00Oomoogoo000037oo
10001Goo00<007ooOol02Goo00<007ooOol077oo00<007ooOol0CGoo00<007ooOol06goo00<007oo
Ool0Egoo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0EGoo00<007ooOol0
:Goo00<007ooOol0R7oo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo00Uoo`03001o
ogoo01]oo`03001oogoo04ioo`03001oogoo01]oo`03001oogoo05Moo`007Woo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`8005Moo`03001oogoo02Qoo`03001oogoo08Qoo`05001oogooOol0000<
Ool00`00Oomoo`06Ool2000;Ool00`00Oomoo`0JOol00`00Oomoo`1>Ool00`00Oomoo`0JOol00`00
Oomoo`1HOol001moo`<000eoo`@000Eoo`03001oogoo05Ioo`03001oogoo02Moo`03001oogoo08Yo
o`<000eoo`@000Eoo`03001oogoo00Yoo`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uo
o`03001oogoo05Qoo`00>7oo00<007ooOol0Egoo00<007ooOol09Woo00<007ooOol0Xgoo00<007oo
Ool02Woo00<007ooOol06Goo00<007ooOol0D7oo00<007ooOol06Goo00<007ooOol0F7oo000hOol0
0`00Oomoo`1GOol00`00Oomoo`0UOol00`00Oomoo`2TOol00`00Oomoo`0;Ool00`00Oomoo`0HOol0
0`00Oomoo`1AOol00`00Oomoo`0GOol00`00Oomoo`1IOol003Qoo`8005Uoo`03001oogoo02Aoo`03
001oogoo0:Aoo`8000aoo`03001oogoo01Moo`03001oogoo059oo`03001oogoo01Moo`03001oogoo
05Uoo`00>7oo00<007ooOol0F7oo00<007ooOol097oo00<007ooOol0Y7oo00<007ooOol037oo00<0
07ooOol05Woo00<007ooOol0DWoo00<007ooOol05Woo00<007ooOol0FWoo000hOol00`00Oomoo`1I
Ool00`00Oomoo`0ROol00`00Oomoo`2UOol00`00Oomoo`0<Ool00`00Oomoo`0EOol00`00Oomoo`1D
Ool00`00Oomoo`0EOol00`00Oomoo`1JOol003Qoo`8005Yoo`03001oogoo029oo`03001oogoo0:Eo
o`8000ioo`03001oogoo01Aoo`03001oogoo05Aoo`03001oogoo01Aoo`03001oogoo05]oo`00>7oo
00<007ooOol0FWoo00<007ooOol087oo00<007ooOol0YWoo00<007ooOol03Goo00<007ooOol057oo
00<007ooOol0EGoo00<007ooOol04Woo00<007ooOol0G7oo000hOol00`00Oomoo`1JOol00`00Oomo
o`0OOol00`00Oomoo`2WOol00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomo
o`0BOol00`00Oomoo`1LOol003Qoo`03001oogoo05]oo`03001oogoo01ioo`03001oogoo0:Moo`03
001oogoo00ioo`03001oogoo019oo`03001oogoo05Moo`03001oogoo011oo`03001oogoo05eoo`00
>7oo0P00GGoo00<007ooOol077oo00<007ooOol0Z7oo0P003goo00<007ooOol04Goo00<007ooOol0
F7oo00<007ooOol047oo00<007ooOol0GGoo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005
Ool00`00Oomoo`1LOol00`00Oomoo`0LOol00`00Oomoo`27Ool30006Ool20006Ool00`00Oomoo`04
Ool40005Ool00`00Oomoo`0?Ool2000AOol00`00Oomoo`1IOol00`00Oomoo`0>Ool00`00Oomoo`1N
Ool001Ioo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomo
o`1MOol00`00Oomoo`0JOol00`00Oomoo`27Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol0
27oo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol03Goo00<007ooOol0FWoo00<007ooOol0
3Woo00<007ooOol0GWoo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol0GGoo00<007ooOol06Goo00<007ooOol0R7oo00D007ooOomoo`0000ioo`03001oogoo
00Moo`03001oogoo009oo`03001oogoo015oo`03001oogoo00]oo`8005ioo`8000eoo`03001oogoo
05moo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8005moo`03001o
ogoo01Qoo`03001oogoo08Qoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2
000COol00`00Oomoo`09Ool00`00Oomoo`1POol00`00Oomoo`09Ool00`00Oomoo`1POol001Ioo`05
001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`1NOol00`00Oomoo`0GOol00`00
Oomoo`29Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol04goo00<007oo
Ool01goo00<007ooOol0HWoo00<007ooOol01goo00<007ooOol0HGoo000FOol01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0Ggoo00<007ooOol05Goo00<007ooOol0
RWoo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01Aoo`03001o
ogoo00Eoo`03001oogoo06Aoo`03001oogoo00Eoo`03001oogoo069oo`005Woo00D007ooOomoo`00
00]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001QOol00`00Oomoo`0DOol00`00Oomoo`2:
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8001Ioo`<0009oo`80
06Qoo`8000=oo`8006Eoo`005goo0`0037oo1@0017oo10001Goo00<007ooOol0HGoo00<007ooOol0
4Woo00<007ooOol0S7oo0`0037oo1@0017oo10001Goo00<007ooOol05goo1000JWoo1000Igoo000h
Ool00`00Oomoo`1ROol2000@Ool2002`Ool00`00Oomoo`3`Ool003Qoo`03001oogoo06Aoo`03001o
ogoo00]oo`800;9oo`03001oogoo0?1oo`00>7oo0P00IWoo00<007ooOol02Goo00<007ooOol0/Woo
0P00lGoo000hOol00`00Oomoo`1VOol20008Ool00`00Oomoo`2cOol00`00Oomoo`3`Ool003Qoo`03
001oogoo06Moo`@0009oo`<00;Ioo`03001oogoo0?1oo`00>7oo0P00Jgoo1000^7oo0P00lGoo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol002moo`D0
00Aoo`03001oogoo0?mooaioo`D000Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007oo
Ool0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol0
0`00Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007oo
Ool0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03
001oogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00nGoo003oOoooOomFOol00?mo
oomooeIoo`00UGoo0`0000Aoo`00000001Qoo`<00?moo`Moo`<00004Ool00000000IOol3001dOol0
09Ioo`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000ogoo1goo00D007ooOomoo`0000Uo
o`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001aoo`03001oogoo0?moo`Eoo`05001o
ogooOol0000HOol5001dOol009Ioo`05001oogooOol00009Ool6000=Ool00`00Oomoo`3oOol5Ool0
1@00Oomoogoo00002Goo1P002Goo00@007ooOol007Eoo`00UWoo00D007ooOomoo`0001Yoo`800?mo
o`Qoo`05001oogooOol0000IOol00`00Ool0001eOol009Eoo`D001eoo`03001oogoo0?moo`Aoo`D0
01Yoo`03001oo`0007Eoo`00/goo00D007ooOomoo`000?moobIoo`8007Eoo`00]7oo0`00ogoo:7oo
00<007ooOol0Lgoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomF
Ool00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol002moo`D00?moobEoo`D00?Moo`00<Goo00<007ooOol0ogoo9goo00<007oo
Ool0mgoo000VOol60005Ool00`00Oomoo`3oOolLOol60005Ool00`00Oomoo`3gOol0035oo`03001o
ogoo00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol017oo00<007ooOol0
Ggoo6P00YWoo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`1L
Ool3000JOol4002ROol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`8005Qo
o`D0025oo`@009ioo`03001oogoo00Aoo`800:1oo`P004Uoo`00;goo0`001Woo00<007ooOol0Dgoo
1000:Woo0`00VGoo0`001Woo00<007ooOol0Vgoo100027oo1000AGoo000hOol00`00Oomoo`1AOol2
000aOol3002OOol00`00Oomoo`2HOol3000@Ool20013Ool003Qoo`03001oogoo04moo`8003Ioo`80
09eoo`03001oogoo09Moo`03001oogoo01=oo`03001oogoo041oo`00>7oo0P00CWoo0P00>Woo0`00
VWoo0P00Ugoo00<007ooOol05Goo0P00@7oo000hOol00`00Oomoo`1:Ool3000oOol2002HOol00`00
Oomoo`2DOol2000JOol2000nOol003Qoo`03001oogoo04Qoo`8004Aoo`<009Eoo`03001oogoo09=o
o`03001oogoo01aoo`03001oogoo03]oo`00>7oo0P00Agoo0P00BGoo0P00Tgoo0P00Tgoo00<007oo
Ool07Woo00<007ooOol0>Woo000hOol00`00Oomoo`14Ool2001=Ool00`00Oomoo`2@Ool00`00Oomo
o`2AOol00`00Oomoo`0POol00`00Oomoo`0iOol003Qoo`03001oogoo049oo`80051oo`80091oo`03
001oogoo091oo`03001oogoo029oo`03001oogoo03Qoo`00>7oo00<007ooOol0@Goo00<007ooOol0
DWoo0P00SWoo00<007ooOol0T7oo00<007ooOol08Woo00<007ooOol0>7oo000hOol20010Ool2001G
Ool00`00Oomoo`2;Ool2002@Ool00`00Oomoo`0TOol00`00Oomoo`0gOol001Moo`<000Ioo`8000Io
o`03001oogoo00Aoo`@000Eoo`03001oogoo03eoo`8005Yoo`8006Yoo`<000Ioo`8000Ioo`03001o
ogoo00Aoo`@000Eoo`03001oogoo08ioo`03001oogoo02Ioo`03001oogoo03Ioo`005Woo00D007oo
Oomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo03]oo`8005ioo`80
06Moo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`2=
Ool00`00Oomoo`0XOol00`00Oomoo`0eOol000ioo`H0009oo`05001oogooOol0000>Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`0jOol00`00Oomoo`1POol00`00Oomoo`1LOol60002Ool0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0S7oo00<007ooOol0
:Goo00<007ooOol0=Goo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo
0P00>Goo0P00I7oo0P00I7oo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80
08aoo`03001oogoo02]oo`03001oogoo03Aoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=o
o`@000Eoo`03001oogoo03Ioo`8006Qoo`80069oo`05001oogooOol0000>Ool00`00Oomoo`03Ool4
0005Ool00`00Oomoo`2;Ool00`00Oomoo`0/Ool00`00Oomoo`0cOol001Ioo`05001oogooOol0000?
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0eOol00`00Oomoo`1ZOol00`00Oomoo`1O
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0RWoo00<007oo
Ool0;Goo00<007ooOol0<goo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001o
ogoo00Ioo`8003Aoo`8006ioo`8005moo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<0
07ooOol01Woo0P00RWoo00<007ooOol0;goo00<007ooOol0<Woo000GOol3000<Ool50004Ool40005
Ool00`00Oomoo`0bOol00`00Oomoo`1`Ool00`00Oomoo`1MOol3000<Ool50004Ool40005Ool00`00
Oomoo`28Ool00`00Oomoo`0aOol00`00Oomoo`0aOol003Qoo`03001oogoo035oo`03001oogoo079o
o`03001oogoo07eoo`03001oogoo08Moo`03001oogoo03=oo`03001oogoo031oo`00>7oo00<007oo
Ool0;goo0P00MWoo0P00OGoo00<007ooOol0Qgoo00<007ooOol0<goo00<007ooOol0<7oo000hOol2
000_Ool00`00Oomoo`1hOol00`00Oomoo`1jOol20027Ool00`00Oomoo`0eOol00`00Oomoo`0_Ool0
03Qoo`03001oogoo02eoo`03001oogoo07Yoo`03001oogoo07Uoo`03001oogoo08Eoo`03001oogoo
03Moo`03001oogoo02ioo`00>7oo00<007ooOol0;7oo00<007ooOol0O7oo00<007ooOol0N7oo00<0
07ooOol0QGoo00<007ooOol0>7oo00<007ooOol0;Goo000hOol2000[Ool20020Ool2001hOol20025
Ool00`00Oomoo`0iOol00`00Oomoo`0]Ool003Qoo`03001oogoo02Uoo`03001oogoo089oo`03001o
ogoo07Eoo`03001oogoo08=oo`03001oogoo03]oo`03001oogoo02aoo`00>7oo00<007ooOol0:7oo
00<007ooOol0Q7oo00<007ooOol0M7oo00<007ooOol0Pgoo00<007ooOol0?7oo00<007ooOol0:goo
000hOol00`00Oomoo`0WOol00`00Oomoo`26Ool00`00Oomoo`1cOol00`00Oomoo`22Ool00`00Oomo
o`0mOol00`00Oomoo`0[Ool003Qoo`8002Moo`03001oogoo08Qoo`03001oogoo079oo`8008=oo`03
001oogoo03ioo`03001oogoo02Yoo`007goo0`001Woo0P001Goo10001Goo00<007ooOol09Goo00<0
07ooOol0RWoo00<007ooOol0F7oo0`001Woo0P001Goo10001Goo00<007ooOol0PGoo00<007ooOol0
@7oo00<007ooOol0:Goo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007oo
Ool097oo00<007ooOol0S7oo00<007ooOol0EWoo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo
009oo`03001oogoo081oo`03001oogoo049oo`03001oogoo02Qoo`005Woo1P000Woo00D007ooOomo
o`00011oo`03001oogoo009oo`8002Aoo`03001oogoo08ioo`03001oogoo04eoo`H0009oo`05001o
ogooOol0000@Ool00`00Oomoo`02Ool20021Ool00`00Oomoo`12Ool00`00Oomoo`0XOol001ioo`05
001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0QOol2002BOol00`00Oomoo`1DOol01@00
Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0Ogoo00<007ooOol0A7oo00<007ooOol09goo
000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol087oo00<007ooOol0Tgoo00<007ooOol0
Dgoo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo07ioo`03001oogoo04Ioo`03001oogoo02Io
o`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo01moo`03001oogoo09Eoo`03
001oogoo059oo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1nOol00`00Oomoo`16
Ool00`00Oomoo`0VOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2000OOol00`00Oomo
o`2GOol00`00Oomoo`1AOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00OWoo00<007ooOol0
B7oo00<007ooOol09Goo000OOol3000=Ool40005Ool00`00Oomoo`0MOol00`00Oomoo`2IOol00`00
Oomoo`1AOol3000=Ool40005Ool00`00Oomoo`1mOol00`00Oomoo`18Ool00`00Oomoo`0UOol003Qo
o`03001oogoo01aoo`03001oogoo09]oo`03001oogoo06Uoo`03001oogoo07aoo`03001oogoo04Yo
o`03001oogoo02Aoo`00>7oo00<007ooOol06goo00<007ooOol0WGoo00<007ooOol0J7oo00<007oo
Ool0Ngoo00<007ooOol0C7oo00<007ooOol08goo000hOol2000KOol00`00Oomoo`2OOol00`00Oomo
o`1WOol2001lOol00`00Oomoo`1<Ool00`00Oomoo`0SOol003Qoo`03001oogoo01Uoo`03001oogoo
0:5oo`03001oogoo06Ioo`03001oogoo07Yoo`03001oogoo04ioo`03001oogoo029oo`00>7oo00<0
07ooOol067oo00<007ooOol0Xgoo0P00IWoo00<007ooOol0NWoo00<007ooOol0CWoo00<007ooOol0
8Woo000hOol2000HOol00`00Oomoo`2VOol00`00Oomoo`1SOol2001jOol00`00Oomoo`1@Ool00`00
Oomoo`0QOol003Qoo`03001oogoo01Ioo`03001oogoo0:Qoo`03001oogoo069oo`03001oogoo07Qo
o`03001oogoo055oo`03001oogoo025oo`00>7oo00<007ooOol05Goo00<007ooOol0ZWoo00<007oo
Ool0HGoo00<007ooOol0N7oo00<007ooOol0DWoo00<007ooOol087oo000hOol00`00Oomoo`0DOol0
0`00Oomoo`2/Ool00`00Oomoo`1POol00`00Oomoo`1gOol00`00Oomoo`1COol00`00Oomoo`0POol0
03Qoo`8001Aoo`03001oogoo0:ioo`03001oogoo05moo`8007Qoo`03001oogoo05Aoo`03001oogoo
01moo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol04Woo00<007ooOol0/7oo00<0
07ooOol0?Goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0MWoo00<007ooOol0EWoo00<0
07ooOol07Woo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009o
o`03001oogoo015oo`03001oogoo0;9oo`03001oogoo03]oo`05001oogooOol00005Ool20005Ool0
1000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0MGoo00<007ooOol0Egoo00<007ooOol07Woo
000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P0047oo0P00
]Woo0P00<goo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8007Io
o`03001oogoo05Qoo`03001oogoo01eoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo00ioo`03001oogoo0;Qoo`03001oogoo03Qoo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`1dOol00`00Oomoo`1IOol00`00Oomoo`0M
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`0=Ool00`00Oomo
o`2jOol00`00Oomoo`0gOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0
M7oo00<007ooOol0FWoo00<007ooOol077oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol037oo00<007ooOol0_7oo00<007ooOol0=Woo00D007ooOomoo`00
00moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo07=oo`03001oogoo05]oo`03001oogoo
01aoo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000<Ool0
0`00Oomoo`2nOol00`00Oomoo`0eOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001o
ogoo00Ioo`8007Aoo`03001oogoo05aoo`03001oogoo01]oo`005goo0`003Goo0`001Goo10001Goo
00<007ooOol02Woo00<007ooOol0`7oo00<007ooOol0=Goo0`003Goo0`001Goo10001Goo00<007oo
Ool0LWoo00<007ooOol0GGoo00<007ooOol06goo000hOol00`00Oomoo`09Ool00`00Oomoo`0COol3
0006Ool20004Ool5000HOol30006Ool20006Ool3000HOol30006Ool20005Ool3000JOol30006Ool2
0005Ool3000GOol00`00Oomoo`07Ool50019Ool00`00Oomoo`0OOol30006Ool20004Ool5000HOol3
0006Ool20006Ool3000COol00`00Oomoo`02Ool30006Ool20005Ool3000IOol30006Ool20005Ool3
000MOol01000Oomoogoo1@0057oo000hOol20009Ool00`00Oomoo`0COol01@00Oomoogoo00001Goo
0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00Oomoo`0FOol01@00Oomo
ogoo00001Goo0P0017oo00D007ooOomoo`0001Qoo`05001oogooOol00005Ool20004Ool01@00Oomo
ogoo00005goo00<007ooOol027oo00<007ooOol0BGoo0P007goo00D007ooOomoo`0000Eoo`8000Eo
o`04001oogoo000GOol01@00Oomoogoo00001Goo0P001goo00<007ooOol04Goo00<007ooOol00Woo
00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000GOol01@00Oomoogoo00001Goo0P0017oo
00D007ooOomoo`0001aoo`03001oogoo00=oo`03001oogoo01Aoo`00>7oo00<007ooOol01goo00<0
07ooOol057oo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol0
1@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo0000
67oo00<007ooOol01goo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000eoo`03001o
ogoo01Moo`05001oogooOol0000;Ool5000BOol00`00Oomoo`02Ool01@00Oomoogoo00002goo00D0
07ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00007Goo00<007ooOol00Woo00<0
07ooOol057oo000hOol00`00Oomoo`06Ool00`00Oomoo`0EOol01@00Oomoogoo00003Woo00<007oo
Ool05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00006Goo00<007ooOol01Woo00<007ooOol0
BGoo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool0
1000Oomoo`004Woo00<007ooOol00goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00
Oomoogoo00002goo00D007ooOomoo`0001ioo`05001oogooOol0000FOol003Qoo`03001oogoo00Eo
o`03001oogoo01Ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<0
07oo000067oo00D007ooOomoo`0000]oo`@001Uoo`05001oogooOol0000<Ool3000KOol00`00Oomo
o`05Ool00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003goo00<007ooOol05Goo00D0
07ooOomoo`0000aoo`03001oo`00019oo`03001oogoo00=oo`05001oogooOol0000;Ool4000HOol0
1@00Oomoogoo000037oo0`007goo00D007ooOomoo`0001Ioo`00>7oo0P001Goo00<007ooOol05goo
00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00
Oomoogoo00002goo00<007ooOol06Woo00D007ooOomoo`0000]oo`05001oogooOol0000KOol00`00
Oomoo`04Ool00`00Oomoo`19Ool2000OOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007oo
Oomoo`0000aoo`03001oo`00015oo`03001oogoo00Aoo`05001oogooOol0000;Ool00`00Oomoo`0I
Ool01@00Oomoogoo00002goo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`03001oogoo
00=oo`03001oogoo01Qoo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`00
00eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007oo
Oomoo`0001aoo`03001oogoo00=oo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000;
Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`80015oo`03001oogoo00Aoo`05001oogoo
Ool0000<Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007ooOomoo`0001moo`04001oogoo
000FOol003Qoo`03001oogoo009oo`03001oogoo01Yoo`<000eoo`<001Uoo`<000moo`03001oogoo
01Moo`<000ioo`<001Uoo`<000eoo`<001ioo`03001oogoo00<004]oo`03001oogoo01moo`<000eo
o`<001Uoo`<000moo`03001oogoo00ioo`03001oogoo00Ioo`<000ioo`<001Qoo`<000eoo`<0025o
o`<001Ioo`00>7oo00D007ooOomoo`000=Aoo`03001oogoo04eoo`03001oogoo06ioo`03001oogoo
06Ioo`03001oogoo01Ioo`00>7oo0P0000=oo`00Ool0eGoo00<007ooOol0C7oo0P00KWoo00<007oo
Ool0J7oo00<007ooOol05Goo000hOol00`00Ool0003HOol00`00Oomoo`1;Ool00`00Oomoo`1]Ool0
0`00Oomoo`1XOol00`00Oomoo`0EOol003Qoo`800=Yoo`03001oogoo04Yoo`03001oogoo06aoo`03
001oogoo06Yoo`03001oogoo01Aoo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`19Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`0DOol003Qoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Yo
o`03001oogoo02Uoo`03001oogoo04Uoo`8002Yoo`03001oogoo02Uoo`03001oogoo01=oo`03001o
ogoo01=oo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo01Aoo`00>7oo00<007ooOol0ogoo
9goo0P00Jgoo00<007ooOol0Pgoo000hOol2003oOolXOol3001ZOol00`00Oomoo`23Ool003Qoo`03
001oogoo0?moobMoo`03001oo`0006Uoo`03001oogoo08Aoo`00>7oo00<007ooOol0ogoo9goo00@0
07ooOol006Qoo`03001oogoo08Aoo`00>7oo0P00ogoo:7oo0P0000=oo`00Ool0IWoo00<007ooOol0
QGoo000hOol00`00Oomoo`3oOolWOol01@00Oomoogoo0000IWoo00<007ooOol0QGoo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`02Ool00`00Oomoo`1ROol00`00Oomoo`26Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo009oo`03001oogoo065oo`03001oogoo08Moo`00>7oo0P00ogoo:7oo0P00
17oo00<007ooOol0H7oo00<007ooOol0Qgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`03Ool0
0`00Oomoo`1OOol00`00Oomoo`28Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Aoo`03001o
ogoo05ioo`03001oogoo08Qoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol017oo00<007ooOol0
GGoo00<007ooOol0RGoo000hOol2003oOolXOol20006Ool00`00Oomoo`1LOol00`00Oomoo`29Ool0
01Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Aoo`D000Ao
o`@000Eoo`03001oogoo00Eoo`03001oogoo05]oo`03001oogoo08Yoo`005Woo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo05Yo
o`03001oogoo08Yoo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`80
0?moo`Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool20007Ool00`00Oomo
o`1IOol00`00Oomoo`2;Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol0F7oo00<007ooOol0Rgoo000FOol01@00Oomoogoo00003goo00<007oo
Ool00Woo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eo
o`03001oogoo00Moo`03001oogoo05Moo`03001oogoo08aoo`005Woo00D007ooOomoo`0000moo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`1FOol00`00Oomoo`2<Ool001Ioo`05
001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20009Ool00`00Oomoo`1EOol00`00Oomo
o`2=Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo0?moo`Ioo`<000eoo`<000Eoo`@000Eo
o`03001oogoo00Uoo`03001oogoo05=oo`03001oogoo08ioo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol02Goo00<007ooOol0Dgoo00<007ooOol0SWoo000hOol2003oOolXOol2000;Ool00`00Oomo
o`1AOol00`00Oomoo`2?Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Yoo`03001oogoo055o
o`03001oogoo08moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol02goo00<007ooOol0Cgoo00<0
07ooOol0T7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0;Ool00`00Oomoo`1>Ool00`00Oomo
o`2AOol003Qoo`800?moobQoo`8000eoo`03001oogoo04eoo`03001oogoo095oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol037oo00<007ooOol0C7oo00<007ooOol0TWoo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`0=Ool00`00Oomoo`1;Ool00`00Oomoo`2BOol003Qoo`800?moobQoo`8000io
o`03001oogoo04Yoo`03001oogoo09=oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol03Woo00<0
07ooOol0B7oo00<007ooOol0U7oo000OOol30006Ool20005Ool40005Ool00`00Oomoo`3oOol>Ool3
0006Ool20005Ool40005Ool00`00Oomoo`0>Ool00`00Oomoo`18Ool00`00Oomoo`2DOol001ioo`05
001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo0000
1Goo0P002Goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol0AWoo00<007ooOol0UGoo000N
Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00ogoo3Woo00D007ooOomoo`00011oo`03001o
ogoo009oo`80011oo`03001oogoo04Ioo`03001oogoo09Eoo`007Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomo
o`0@Ool00`00Oomoo`14Ool00`00Oomoo`2FOol001ioo`05001oogooOol0000<Ool40005Ool00`00
Oomoo`3oOol=Ool01@00Oomoogoo000037oo10001Goo00<007ooOol04Goo00<007ooOol0@Woo00<0
07ooOol0Ugoo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo045oo`03001oogoo09Mo
o`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?moo`ioo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool2000COol00`00Oomoo`10Ool00`00Oomoo`2HOol001moo`<000eoo`@000Eoo`03
001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo01=oo`03001oogoo03ioo`03001oogoo09Uo
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol057oo00<007ooOol0?Goo00<007ooOol0VGoo000h
Ool2003oOolXOol2000EOol00`00Oomoo`0lOol00`00Oomoo`2JOol003Qoo`03001oogoo0?moobMo
o`03001oogoo01Eoo`03001oogoo03]oo`03001oogoo09Yoo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol05Woo00<007ooOol0>Goo00<007ooOol0Vgoo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`0GOol00`00Oomoo`0gOol00`00Oomoo`2LOol003Qoo`800?moobQoo`8001Qoo`03001oogoo03Mo
o`03001oogoo09aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol067oo00<007ooOol0=Goo00<0
07ooOol0WGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0IOol00`00Oomoo`0cOol00`00Oomo
o`2NOol003Qoo`800?moobQoo`8001Yoo`03001oogoo03=oo`03001oogoo09ioo`005goo0`001Woo
0P001Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol06Woo00<007ooOol0<Goo00<007ooOol0Wgoo000FOol01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo01]oo`03001oogoo02mo
o`03001oogoo0:1oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03
001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomo
o`0LOol00`00Oomoo`0]Ool00`00Oomoo`2QOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo0P007Woo00<007ooOol0:goo00<007ooOol0XWoo000FOol01@00Oomoogoo00003Woo00<007oo
Ool00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eo
o`03001oogoo01eoo`03001oogoo02Yoo`03001oogoo0:=oo`005Woo00D007ooOomoo`0000moo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`0NOol00`00Oomoo`0XOol00`00Oomoo`2TOol001Ioo`05
001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`0OOol00`00Oomo
o`0VOol00`00Oomoo`2UOol001Moo`<000aoo`D000Aoo`@000Eoo`800?moo`Moo`<000aoo`D000Ao
o`@000Eoo`80025oo`03001oogoo02Aoo`03001oogoo0:Ioo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol08Goo0P008goo00<007ooOol0Ygoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0SOol0
0`00Oomoo`0OOol00`00Oomoo`2XOol003Qoo`800?moobQoo`8002Eoo`03001oogoo01eoo`03001o
ogoo0:Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol09Goo00<007ooOol06goo00<007ooOol0
ZWoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0VOol2000IOol2002]Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo02Qoo`03001oogoo01Aoo`800:moo`00>7oo0P00ogoo:7oo0P00:Woo0P00
4goo00<007ooOol0[goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0[Ool2000?Ool2002bOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo02eoo`03001oogoo00Yoo`800;Aoo`00>7oo0P00ogoo
:7oo0P00;goo3000]Woo000_Ool50004Ool00`00Oomoo`3oOolNOol50004Ool00`00Oomoo`3`Ool0
035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo
00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00
Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001o
ogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<0
0004Ool00000000HOol5003oOol5Ool3000017oo000000005goo1@00M7oo002FOol01@00Oomoogoo
00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H000Yoo`04001oogoo001d
Ool009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo00006Woo00<007oo
Ool0M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`00
00Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001]oo`03001oogoo0?moo`Ioo`05
001oogooOol0000LOol00`00Oomoo`1bOol009Eoo`D001aoo`03001oogoo0?moo`Eoo`D001eoo`03
001oogoo079oo`00]Woo00<007ooOol0ogoo8goo00D007ooOomoo`0007Aoo`00]7oo0`00ogoo9Woo
0`00MGoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .24125 L
.08255 .20927 L
.10458 .17881 L
.12507 .15598 L
.14415 .14033 L
.14918 .13719 L
.15465 .13426 L
.15946 .1321 L
.16457 .13025 L
.16917 .12897 L
.17178 .12841 L
.17423 .128 L
.17538 .12784 L
.17647 .12771 L
.17746 .12761 L
.17852 .12752 L
.17967 .12745 L
.18073 .12741 L
.182 .12738 L
.18314 .12738 L
.18435 .12741 L
.18547 .12746 L
.1867 .12754 L
.18802 .12765 L
.19071 .12798 L
.19317 .12839 L
.1979 .12948 L
.20239 .13088 L
.21236 .13523 L
.22321 .1419 L
.24299 .15892 L
.26399 .18326 L
.30174 .23977 L
.34195 .31023 L
.38063 .378 L
.40028 .40916 L
.42177 .43889 L
.44253 .46207 L
.4614 .47756 L
.47149 .48347 L
.47611 .4856 L
.48101 .48745 L
.4835 .48824 L
.48624 .48897 L
.48876 .48953 L
.49106 .48994 L
.49378 .49031 L
.49527 .49045 L
.49596 .49051 L
Mistroke
.49669 .49056 L
.498 .49062 L
.49921 .49065 L
.49996 .49065 L
.50065 .49065 L
.50196 .49062 L
.50313 .49057 L
.50438 .49048 L
.50556 .49038 L
.50663 .49026 L
.50926 .48989 L
.51175 .48943 L
.5167 .48818 L
.52208 .48633 L
.53169 .4818 L
.54056 .47621 L
.55926 .4603 L
.57988 .4368 L
.62014 .37671 L
.65888 .30875 L
.70007 .23677 L
.72063 .20458 L
.73974 .1785 L
.75939 .15656 L
.77791 .14112 L
.78775 .13518 L
.79293 .13271 L
.7984 .1306 L
.80302 .12923 L
.80546 .12866 L
.80809 .12816 L
.8105 .12781 L
.8127 .12758 L
.81375 .1275 L
.81491 .12744 L
.81599 .1274 L
.817 .12738 L
.81818 .12739 L
.81941 .12742 L
.82047 .12746 L
.82163 .12754 L
.82287 .12764 L
.82421 .12779 L
.82661 .12813 L
.82905 .12857 L
.83134 .12909 L
.83564 .13031 L
.84078 .1322 L
.84552 .13434 L
.85624 .14059 L
Mistroke
.87498 .15602 L
.89561 .17904 L
.93591 .23852 L
.97471 .30635 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35562 L
.08255 .37584 L
.0932 .38473 L
.10458 .39259 L
.11009 .39572 L
.11531 .39827 L
.12038 .40034 L
.12507 .40189 L
.12951 .40303 L
.13178 .40349 L
.13422 .40389 L
.13549 .40406 L
.13666 .40419 L
.13784 .4043 L
.13895 .40438 L
.14022 .40445 L
.1409 .40448 L
.14161 .4045 L
.1423 .40451 L
.14295 .40451 L
.14415 .40449 L
.14531 .40446 L
.14656 .40439 L
.14773 .40431 L
.14881 .40421 L
.15143 .4039 L
.15392 .40349 L
.15886 .40239 L
.16423 .40074 L
.17383 .39665 L
.1827 .39161 L
.20137 .37744 L
.22197 .35704 L
.26217 .30868 L
.30086 .26207 L
.32051 .24232 L
.3309 .23361 L
.342 .22586 L
.35275 .22006 L
.35784 .21793 L
.36253 .21633 L
.36724 .21508 L
.36972 .21457 L
.37235 .21414 L
.37463 .21386 L
.37573 .21375 L
.37677 .21367 L
.37799 .2136 L
.37911 .21355 L
Mistroke
.38031 .21353 L
.38162 .21353 L
.38227 .21354 L
.38296 .21356 L
.38419 .21361 L
.38551 .2137 L
.38695 .21382 L
.38955 .21414 L
.39197 .21453 L
.39649 .21553 L
.40134 .21696 L
.40698 .2191 L
.41232 .22159 L
.42232 .2274 L
.44227 .24311 L
.4607 .26169 L
.50002 .30904 L
.53782 .35472 L
.55884 .37593 L
.56803 .38368 L
.57808 .39089 L
.58722 .39621 L
.59696 .40048 L
.60236 .4022 L
.60726 .40336 L
.60962 .40377 L
.61086 .40395 L
.61218 .40412 L
.61333 .40424 L
.61459 .40434 L
.61574 .40442 L
.61682 .40447 L
.61808 .4045 L
.61871 .40451 L
.61941 .40451 L
.62065 .40449 L
.62181 .40444 L
.62248 .40441 L
.62318 .40437 L
.62443 .40427 L
.62578 .40413 L
.62725 .40395 L
.62973 .40356 L
.63238 .40304 L
.63715 .4018 L
.64214 .40011 L
.64686 .39815 L
.6557 .39356 L
.67568 .37906 L
.69413 .36136 L
Mistroke
.7335 .3148 L
.77136 .26844 L
.79241 .24629 L
.81166 .23021 L
.82118 .22408 L
.8262 .22137 L
.83155 .21892 L
.8367 .21698 L
.84136 .21559 L
.84361 .21504 L
.84604 .21455 L
.84835 .21417 L
.85045 .2139 L
.85159 .21378 L
.85283 .21368 L
.85414 .2136 L
.85538 .21355 L
.85653 .21353 L
.85776 .21353 L
.85881 .21355 L
.85997 .21359 L
.86063 .21363 L
.86132 .21367 L
.86256 .21377 L
.86535 .21409 L
.86777 .21446 L
.87041 .21498 L
.87569 .21637 L
.88133 .21835 L
.89148 .22316 L
.90173 .22958 L
.91284 .23817 L
.933 .25749 L
.97393 .30617 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .27166 L
.10458 .23164 L
.14415 .19539 L
.18221 .16235 L
.22272 .12973 L
.26171 .10134 L
.30316 .07493 L
.34309 .05362 L
.3815 .03729 L
.40095 .03067 L
.42237 .02471 L
.44268 .02036 L
.45178 .01883 L
.46172 .01746 L
.4671 .01685 L
.4721 .01637 L
.47727 .01595 L
.48196 .01564 L
.48658 .01541 L
.4887 .01533 L
.49093 .01526 L
.49332 .0152 L
.49438 .01517 L
.49552 .01516 L
.49675 .01514 L
.49789 .01513 L
.49859 .01513 L
.49925 .01513 L
.50049 .01512 L
.50163 .01513 L
.50286 .01514 L
.50401 .01515 L
.50508 .01517 L
.50754 .01522 L
.51014 .01529 L
.51268 .01538 L
.51504 .01549 L
.5204 .01579 L
.5293 .0165 L
.53882 .01753 L
.54906 .01896 L
.56016 .02089 L
.58032 .02538 L
.62123 .03831 L
.66064 .05543 L
.69852 .07592 L
.73886 .10173 L
.77769 .13004 L
.81897 .16334 L
Mistroke
.85873 .19797 L
.89697 .23309 L
.93767 .27177 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .37205 L
.10458 .43602 L
.14415 .4873 L
.18221 .52525 L
.20178 .53961 L
.21267 .54594 L
.22272 .55071 L
.23293 .55446 L
.23832 .556 L
.24402 .55728 L
.24641 .55771 L
.24897 .55811 L
.25119 .55839 L
.25361 .55864 L
.25507 .55876 L
.25643 .55885 L
.25773 .55892 L
.2584 .55895 L
.25912 .55897 L
.25983 .55899 L
.26048 .55901 L
.26176 .55902 L
.26293 .55901 L
.26416 .55899 L
.26538 .55895 L
.26607 .55892 L
.26671 .55889 L
.26912 .55873 L
.27131 .55854 L
.27364 .55827 L
.27847 .55753 L
.2838 .55641 L
.29326 .55369 L
.30213 .55026 L
.32232 .53942 L
.34082 .52589 L
.38045 .48638 L
.41855 .43698 L
.45912 .37564 L
.49816 .31205 L
.53966 .24435 L
.57964 .18362 L
.61811 .13334 L
.63759 .11199 L
.65902 .09227 L
.67938 .07754 L
.69843 .06753 L
.70884 .06366 L
.71396 .06218 L
Mistroke
.71872 .06106 L
.72301 .06025 L
.72758 .05962 L
.7302 .05936 L
.73148 .05926 L
.73266 .05918 L
.73371 .05912 L
.73487 .05907 L
.73603 .05904 L
.73725 .05902 L
.73856 .05902 L
.73977 .05903 L
.7404 .05905 L
.7411 .05907 L
.74251 .05912 L
.74375 .05919 L
.74508 .05928 L
.74748 .0595 L
.74985 .05977 L
.75235 .06012 L
.7568 .06092 L
.76198 .06212 L
.7668 .06349 L
.77773 .06751 L
.78828 .07259 L
.79823 .07843 L
.81683 .09199 L
.85534 .13016 L
.89632 .18329 L
.93577 .24314 L
.97371 .30493 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo0P00
1Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo
10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00
Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Io
o`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol07Goo2@00RWoo2P00K7oo00<007ooOol0l7oo
000hOol00`00Oomoo`0KOol20009Ool30026Ool00`00Oomoo`08Ool3001YOol00`00Oomoo`3`Ool0
03Qoo`8001]oo`03001oogoo00aoo`80089oo`8000ioo`03001oogoo06Ioo`800?5oo`007goo0`00
1Woo0P001Goo10001Goo00<007ooOol067oo0P004Goo0P00OWoo0P004Goo0P00CGoo0`001Woo0P00
1Goo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo
00<007ooOol05Woo0P005Goo00<007ooOol0NGoo0P005Goo00<007ooOol0BGoo00D007ooOomoo`00
00Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`005Woo1P000Woo00D007ooOomoo`00011o
o`03001oogoo009oo`03001oogoo01Eoo`03001oogoo01Ioo`03001oogoo07Moo`03001oogoo01Io
o`03001oogoo041oo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool0
01ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000EOol00`00Oomoo`0HOol00`00Oomoo`1e
Ool00`00Oomoo`0HOol00`00Oomoo`17Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo
000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol057oo00<007ooOol06Goo00<007ooOol0
M7oo00<007ooOol067oo00<007ooOol0Agoo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1o
o`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo01=oo`03001oogoo01Yoo`03
001oogoo07=oo`03001oogoo01Yoo`03001oogoo04Ioo`05001oogooOol0000<Ool00`00Oomoo`06
Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0BOol0
0`00Oomoo`0LOol00`00Oomoo`1aOol00`00Oomoo`0LOol00`00Oomoo`15Ool01@00Oomoogoo0000
37oo00<007ooOol01Woo00<007ooOol0l7oo000OOol3000=Ool40005Ool2000COol00`00Oomoo`0M
Ool00`00Oomoo`1`Ool00`00Oomoo`0MOol00`00Oomoo`15Ool3000=Ool40005Ool2003aOol003Qo
o`03001oogoo015oo`03001oogoo01moo`03001oogoo06ioo`03001oogoo01moo`03001oogoo05eo
o`03001oogoo0?1oo`00>7oo00<007ooOol047oo00<007ooOol08Goo00<007ooOol0K7oo00<007oo
Ool08Goo00<007ooOol0G7oo00<007ooOol0l7oo000hOol2000AOol00`00Oomoo`0ROol00`00Oomo
o`1[Ool00`00Oomoo`0QOol00`00Oomoo`1LOol2003aOol003Qoo`03001oogoo00moo`03001oogoo
02=oo`03001oogoo06Yoo`03001oogoo02=oo`03001oogoo05]oo`03001oogoo0?1oo`00>7oo00<0
07ooOol03Woo00<007ooOol09Goo00<007ooOol0J7oo00<007ooOol09Goo00<007ooOol0FWoo00<0
07ooOol0l7oo000hOol00`00Oomoo`0=Ool00`00Oomoo`0WOol00`00Oomoo`1VOol00`00Oomoo`0V
Ool00`00Oomoo`1JOol00`00Oomoo`3`Ool003Qoo`8000ioo`03001oogoo02Moo`03001oogoo06Eo
o`03001oogoo02Qoo`03001oogoo05Uoo`800?5oo`00>7oo00<007ooOol037oo00<007ooOol0:Goo
00<007ooOol0Hgoo00<007ooOol0:Woo00<007ooOol0F7oo00<007ooOol0l7oo000hOol00`00Oomo
o`0;Ool00`00Oomoo`0ZOol00`00Oomoo`1SOol00`00Oomoo`0[Ool00`00Oomoo`1GOol00`00Oomo
o`3`Ool003Qoo`8000aoo`03001oogoo02]oo`03001oogoo065oo`03001oogoo02aoo`03001oogoo
05Moo`8004aoo`/006=oo`/002aoo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0
2Woo00<007ooOol0;Goo00<007ooOol0H7oo00<007ooOol0;Goo00<007ooOol0=Goo0`001Woo0P00
17oo1@0017oo10001Goo00<007ooOol0BGoo0P002goo00<007ooOol0GWoo0P002goo0P00:Woo000F
Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Uo
o`03001oogoo02ioo`03001oogoo05moo`03001oogoo02moo`03001oogoo03=oo`05001oogooOol0
0005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0B7oo00<007ooOol037oo
0P00G7oo0P003goo0P00:7oo000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol027oo00<007ooOol0<7oo00<007ooOol0GGoo00<007ooOol0<7oo00<0
07ooOol0:goo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001o
ogoo04Ioo`80015oo`8005Uoo`03001oogoo015oo`8002Ioo`005Woo00D007ooOomoo`0000ioo`03
001oogoo00Moo`03001oogoo009oo`8000Uoo`03001oogoo031oo`03001oogoo05eoo`03001oogoo
035oo`03001oogoo039oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20015
Ool2000EOol00`00Oomoo`1DOol2000FOol00`00Oomoo`0SOol001Ioo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool40005Ool00`00Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`1KOol00`00Oomo
o`0cOol00`00Oomoo`0aOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0
@goo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05goo00<007ooOol08Woo000FOol01@00
Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0=7oo
00<007ooOol0FWoo00<007ooOol0<goo00<007ooOol0<Goo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo049oo`03001oogoo01Qoo`03001oogoo051oo`03001oogoo
01Qoo`03001oogoo029oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomo
o`06Ool20007Ool00`00Oomoo`0dOol00`00Oomoo`1IOol00`00Oomoo`0eOol00`00Oomoo`0`Ool0
1@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`80049oo`03001oogoo01Yo
o`03001oogoo04ioo`03001oogoo01Yoo`03001oogoo025oo`005goo0`003Goo0`001Goo10001Goo
00<007ooOol01Goo00<007ooOol0=Woo00<007ooOol0F7oo00<007ooOol0=Goo00<007ooOol0<Goo
0`003Goo0`001Goo10001Goo00<007ooOol0@7oo00<007ooOol077oo00<007ooOol0C7oo00<007oo
Ool077oo00<007ooOol087oo000hOol00`00Oomoo`05Ool00`00Oomoo`0gOol00`00Oomoo`1FOol0
0`00Oomoo`0gOol00`00Oomoo`1AOol00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1:Ool0
0`00Oomoo`0NOol00`00Oomoo`0OOol003Qoo`03001oogoo00Aoo`03001oogoo01Qoo`<000Ioo`80
00Aoo`D000aoo`03001oogoo00Uoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<000eoo`03
001oogoo00Yoo`<000Ioo`8000Eoo`<001aoo`03001oogoo009oo`D004Uoo`03001oogoo01moo`<0
00Ioo`8000Aoo`D000]oo`03001oogoo00Yoo`<000Ioo`8000Ioo`<0009oo`03001oogoo01=oo`<0
00Ioo`8000Eoo`<001Uoo`<000Ioo`8000Eoo`<001Uoo`03001oogoo00Eoo`D001Aoo`00>7oo0P00
17oo00<007ooOol067oo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000=Ool00`00Oomoo`07
Ool01@00Oomoogoo00001Goo0P001goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`05
001oogooOol0000<Ool00`00Oomoo`09Ool01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00
01]oo`03001oogoo00Aoo`03001oogoo04Uoo`8001moo`05001oogooOol00005Ool20005Ool01000
Oomoo`002Woo00<007ooOol02Woo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo009oo`03001o
ogoo015oo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Ao
o`<000Aoo`05001oogooOol0000HOol00`00Oomoo`07Ool00`00Oomoo`0DOol003Qoo`03001oogoo
00=oo`03001oogoo01Qoo`05001oogooOol0000=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool01@00
Oomoogoo00002goo1@005goo00D007ooOomoo`0000]oo`05001oogooOol0000;Ool00`00Oomoo`0:
Ool01@00Oomoogoo00002goo00D007ooOomoo`0001aoo`03001oogoo00=oo`03001oogoo04Uoo`03
001oogoo01ioo`05001oogooOol0000=Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool01@00Oomoogoo
00002goo1@000goo00<007ooOol04Goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00
Oomoogoo00000goo00<007ooOol01Goo00D007ooOomoo`0001Uoo`03001oogoo00Ioo`03001oogoo
01Aoo`00>7oo00<007ooOol00Woo00<007ooOol06Goo00D007ooOomoo`0000ioo`03001oogoo00eo
o`03001oogoo00Ioo`05001oogooOol0000;Ool01000Oomoo`0067oo00D007ooOomoo`0000]oo`05
001oogooOol0000;Ool00`00Oomoo`0:Ool01@00Oomoogoo00002goo00D007ooOomoo`0001aoo`03
001oogoo00=oo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000>Ool00`00Oomoo`08
Ool00`00Oomoo`0;Ool01@00Oomoogoo00002goo00@007ooOol000Eoo`03001oogoo011oo`05001o
ogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000=oo`03001oogoo00Eoo`05001o
ogooOol0000JOol00`00Oomoo`05Ool00`00Oomoo`0DOol003Qoo`03001oogoo009oo`03001oogoo
01Uoo`05001oogooOol0000?Ool00`00Oomoo`0=Ool00`00Oomoo`05Ool01@00Oomoogoo000037oo
00<007oo000067oo00D007ooOomoo`0000]oo`@000]oo`03001oogoo00]oo`05001oogooOol0000<
Ool3000NOol00`00Oomoo`02Ool00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003goo
00<007ooOol01Woo00<007ooOol037oo00D007ooOomoo`0000aoo`03001oo`0000Ioo`03001oogoo
00moo`05001oogooOol0000;Ool4000HOol01@00Oomoogoo00000Woo00<007ooOol01goo0`0077oo
00<007ooOol017oo00<007ooOol057oo000hOol20002Ool00`00Oomoo`0JOol01@00Oomoogoo0000
3goo00<007ooOol03Goo00<007ooOol01Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001o
ogooOol0000;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool01@00Oomoogoo00002goo00D007ooOomo
o`0001eoo`03001oogoo009oo`03001oogoo04Uoo`8001moo`05001oogooOol0000?Ool00`00Oomo
o`05Ool00`00Oomoo`0=Ool01@00Oomoogoo000037oo00<007oo00001goo00<007ooOol03Woo00D0
07ooOomoo`0000]oo`03001oogoo01Uoo`07001oogooOol007oo00002Goo00D007ooOomoo`0001ao
o`03001oogoo00=oo`03001oogoo01Aoo`00>7oo00D007ooOomoo`0001aoo`05001oogooOol0000;
Ool01@00Oomoogoo000047oo00<007ooOol017oo00D007ooOomoo`0000eoo`8001Qoo`05001oogoo
Ool0000<Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool01@00Oomoogoo00002goo00D007ooOomoo`00
01ioo`05001oogooOol0001;Ool00`00Oomoo`0NOol01@00Oomoogoo00002goo00D007ooOomoo`00
00Ioo`03001oogoo00ioo`05001oogooOol0000=Ool20008Ool00`00Oomoo`0=Ool01@00Oomoogoo
000037oo00<007ooOol067oo00@007ooOomoo`8000Yoo`05001oogooOol0000MOol00`00Oomoo`02
Ool00`00Oomoo`0DOol003Qoo`04001oogoo000NOol3000=Ool3000BOol00`00Oomoo`04Ool3000?
Ool00`00Oomoo`0GOol3000>Ool30008Ool00`00Oomoo`0>Ool3000=Ool3000OOol00`00Ool00002
001;Ool00`00Oomoo`0OOol3000=Ool30006Ool00`00Oomoo`0@Ool3000?Ool00`00Oomoo`07Ool0
0`00Oomoo`0=Ool3000>Ool3000HOol4000<Ool3000OOol00`00Ool00002000FOol003Qoo`800003
Ool007oo049oo`03001oogoo04aoo`03001oogoo045oo`03001oogoo04aoo`8003Uoo`03001oogoo
02aoo`03001oogoo03]oo`03001oogoo02ioo`03001oogoo01Moo`00>7oo00<007oo0000AGoo00<0
07ooOol0BWoo00<007ooOol0@goo00<007ooOol0Bgoo00<007ooOol0=goo00<007ooOol0;Woo00<0
07ooOol0>Woo00<007ooOol0;goo00<007ooOol05Woo000hOol20016Ool00`00Oomoo`19Ool00`00
Oomoo`14Ool00`00Oomoo`1;Ool00`00Oomoo`0fOol00`00Oomoo`0`Ool00`00Oomoo`0hOol00`00
Oomoo`0aOol00`00Oomoo`0EOol003Qoo`8004Moo`03001oogoo04Qoo`03001oogoo04Eoo`03001o
ogoo04Yoo`03001oogoo03Eoo`03001oogoo039oo`03001oogoo03Ioo`03001oogoo03=oo`03001o
ogoo01Aoo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`05Ool01000Oomo
o`002Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00D007ooOomoo`0000Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo04Uoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`8000Yoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo00<0
07ooOol0B7oo00<007ooOol0A7oo00<007ooOol0U7oo0P00=7oo00<007ooOol0=Woo00<007ooOol0
<Woo00<007ooOol0C7oo000hOol20019Ool00`00Oomoo`13Ool00`00Oomoo`2EOol3000bOol00`00
Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`1=Ool003Qoo`03001oogoo04Uoo`03001oogoo049o
o`03001oogoo09Eoo`04001oogoo000`Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`1>
Ool003Qoo`03001oogoo04Yoo`03001oogoo041oo`03001oogoo09Ioo`05001oogooOol0000^Ool0
0`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`1?Ool003Qoo`03001oogoo04Yoo`03001oogoo
041oo`03001oogoo09Ioo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo
02Yoo`03001oogoo051oo`00>7oo0P00C7oo00<007ooOol0?Woo00<007ooOol0Ugoo0P000goo00<0
07ooOol0:Woo00<007ooOol0?goo00<007ooOol0:7oo00<007ooOol0DGoo000hOol00`00Oomoo`1;
Ool00`00Oomoo`0mOol00`00Oomoo`2HOol00`00Oomoo`03Ool00`00Oomoo`0XOol00`00Oomoo`11
Ool00`00Oomoo`0WOol00`00Oomoo`1AOol003Qoo`03001oogoo04aoo`03001oogoo03aoo`03001o
ogoo09Qoo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03001o
ogoo059oo`00>7oo00<007ooOol0C7oo00<007ooOol0>goo00<007ooOol0VGoo00<007ooOol01Goo
00<007ooOol097oo00<007ooOol0AGoo00<007ooOol08goo00<007ooOol0Dgoo000hOol2001>Ool0
0`00Oomoo`0jOol00`00Oomoo`2IOol20007Ool00`00Oomoo`0ROol00`00Oomoo`17Ool00`00Oomo
o`0QOol00`00Oomoo`1DOol003Qoo`03001oogoo04eoo`03001oogoo03Uoo`03001oogoo09Yoo`03
001oogoo00Moo`03001oogoo021oo`03001oogoo04Uoo`03001oogoo01moo`03001oogoo05Eoo`00
>7oo00<007ooOol0CWoo00<007ooOol0=goo00<007ooOol0Vgoo00<007ooOol027oo00<007ooOol0
7Woo00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol0EWoo000hOol2001@Ool00`00Oomoo`0f
Ool00`00Oomoo`2KOol2000:Ool00`00Oomoo`0LOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00
Oomoo`1GOol001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo04moo`03001oogoo03Eo
o`03001oogoo07]oo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Yoo`8001]oo`03001o
ogoo04moo`03001oogoo01Uoo`03001oogoo05Qoo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04
001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`1@Ool00`00Oomoo`0dOol00`00Oomoo`1jOol0
1@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00aoo`03
001oogoo01Ioo`8005=oo`03001oogoo01Ioo`8005]oo`005Woo00D007ooOomoo`0000eoo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo051oo`03001oogoo03=oo`03001oogoo07]oo`05001o
ogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0DOol0
0`00Oomoo`1DOol00`00Oomoo`0COol2001MOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool2001BOol00`00Oomoo`0aOol00`00Oomoo`1lOol01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00Woo0P003goo00<007ooOol04Woo00<007ooOol0EWoo00<007oo
Ool04Goo00<007ooOol0GGoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<0
07ooOol0DGoo00<007ooOol0<Goo00<007ooOol0O7oo00D007ooOomoo`0000moo`03001oogoo009o
o`@000Eoo`03001oogoo00moo`80011oo`8005Yoo`8000moo`80061oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo059oo`03001oogoo02moo`03001oogoo
07eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0AOol2000<
Ool2001NOol3000;Ool00`00Oomoo`1POol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P00E7oo00<007ooOol0;Goo00<007ooOol0OWoo00D007ooOomoo`0000]o
o`05001oogooOol00004Ool00`00Oomoo`06Ool2000DOol20007Ool3001SOol20007Ool2001SOol0
01Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo05=oo`03001oogoo02eoo`03001oogoo07moo`<0
00eoo`<000Eoo`@000Eoo`03001oogoo01Eoo`L006Qoo`L006Eoo`00>7oo00<007ooOol0E7oo00<0
07ooOol0:goo00<007ooOol0XGoo00<007ooOol0l7oo000hOol00`00Oomoo`1DOol00`00Oomoo`0[
Ool00`00Oomoo`2QOol00`00Oomoo`3`Ool003Qoo`8005Ioo`03001oogoo02Uoo`03001oogoo0:9o
o`800?5oo`00>7oo00<007ooOol0EWoo00<007ooOol09goo00<007ooOol0Xgoo00<007ooOol0l7oo
000hOol00`00Oomoo`1GOol00`00Oomoo`0VOol00`00Oomoo`2SOol00`00Oomoo`3`Ool003Qoo`80
05Qoo`03001oogoo02Eoo`03001oogoo0:Aoo`800?5oo`00>7oo00<007ooOol0F7oo00<007ooOol0
8goo00<007ooOol0YGoo00<007ooOol0l7oo000hOol00`00Oomoo`1IOol00`00Oomoo`0ROol00`00
Oomoo`2UOol00`00Oomoo`3`Ool003Qoo`03001oogoo05Yoo`03001oogoo021oo`03001oogoo0:Io
o`03001oogoo0?1oo`00>7oo0P00G7oo00<007ooOol07Woo00<007ooOol0Ygoo0P00lGoo000OOol3
0006Ool20005Ool40005Ool00`00Oomoo`1LOol00`00Oomoo`0LOol00`00Oomoo`2?Ool30006Ool2
0005Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol00005Ool20009Ool00`00Oomoo`02
Ool00`00Oomoo`1MOol00`00Oomoo`0JOol00`00Oomoo`2?Ool01@00Oomoogoo00001Goo0P002Goo
00<007ooOol00Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo00<0
07ooOol0GWoo00<007ooOol067oo00<007ooOol0T7oo00D007ooOomoo`00011oo`03001oogoo009o
o`03001oogoo0?1oo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`80061oo`03001oogoo
01Ioo`03001oogoo095oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003aOol001ioo`05001o
ogooOol0000<Ool40005Ool00`00Oomoo`1POol00`00Oomoo`0DOol00`00Oomoo`2BOol01@00Oomo
ogoo000037oo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo
00<007ooOol0HGoo00<007ooOol04Woo00<007ooOol0Tgoo00D007ooOomoo`0000aoo`03001oogoo
00Ioo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`8006=oo`<000mo
o`8009Ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003aOol001moo`<000eoo`@000Eoo`03
001oogoo06Eoo`03001oogoo00Yoo`8009Uoo`<000eoo`@000Eoo`03001oogoo0?1oo`00>7oo00<0
07ooOol0IWoo0P001goo0`00]7oo00<007ooOol0l7oo000hOol00`00Oomoo`1XOol7002gOol00`00
Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000GOol30006Ool2
0006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomoo`04
Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool0
0`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo
00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo
009oo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Io
o`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003Woo00<007ooOol00goo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00003goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03
001oogoo00Ioo`800?5oo`005goo0`0037oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`0037oo
1@0017oo10001Goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00
ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?mo
obMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolX
Ool2003aOol002moo`D000Aoo`03001oogoo0?mooaioo`D000Aoo`03001oogoo0?1oo`00<Goo00<0
07ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomo
o`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001oogoo
0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00
Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00nGoo
003oOoooOomFOol00?mooomooeIoo`00UGoo0`0000Aoo`00000001Qoo`<00?moo`Moo`<00004Ool0
0000000IOol3001dOol009Ioo`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000ogoo1goo
00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001aoo`03001o
ogoo0?moo`Eoo`05001oogooOol0000HOol5001dOol009Ioo`05001oogooOol00009Ool6000=Ool0
0`00Oomoo`3oOol5Ool01@00Oomoogoo00002Goo1P002Goo00@007ooOol007Eoo`00UWoo00D007oo
Oomoo`0001Yoo`800?moo`Qoo`05001oogooOol0000IOol00`00Ool0001eOol009Eoo`D001eoo`03
001oogoo0?moo`Aoo`D001Yoo`03001oo`0007Eoo`00/goo00D007ooOomoo`000?moobIoo`8007Eo
o`00]7oo0`00ogoo:7oo00<007ooOol0Lgoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo003oOoooOomFOol002moo`D00?moobEoo`D00?Moo`00<Goo00<007oo
Ool0ogoo9goo00<007ooOol0mgoo000VOol60005Ool00`00Oomoo`3oOolLOol60005Ool00`00Oomo
o`3gOol0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<007oo
Ool017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04
Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`80
06Ioo`l00:]oo`03001oogoo00Aoo`800?5oo`00;goo0`001Woo00<007ooOol0G7oo2@003goo1`00
XWoo0`001Woo00<007ooOol0l7oo000hOol00`00Oomoo`1HOol4000OOol3002XOol00`00Oomoo`3`
Ool003Qoo`03001oogoo05Eoo`<002Ioo`<00:Eoo`03001oogoo0?1oo`00>7oo0P00Dgoo0`00;7oo
0`00XWoo0P00lGoo000hOol00`00Oomoo`1?Ool3000bOol3002OOol00`00Oomoo`3`Ool003Qoo`03
001oogoo04eoo`8003Qoo`<009aoo`03001oogoo0?1oo`00>7oo0P00Bgoo0`00?Goo0`00VGoo0P00
lGoo000hOol00`00Oomoo`18Ool20013Ool3002FOol00`00Oomoo`3`Ool003Qoo`03001oogoo04Io
o`8004Qoo`<009=oo`03001oogoo0?1oo`00>7oo00<007ooOol0A7oo0P00CGoo00<007ooOol0T7oo
00<007ooOol0X7oo1P00BWoo000hOol20013Ool2001@Ool2002@Ool2002LOol50006Ool50015Ool0
01Moo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo045oo`03001oogoo059oo`80
06eoo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo09Qoo`<0011oo`<0049oo`00
5Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo03mo
o`8005Moo`03001oogoo06Uoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool00`00Oomoo`2GOol00`00Oomoo`0DOol00`00Oomoo`0oOol000ioo`H0009oo`05001oogoo
Ool0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0mOol2001JOol2001QOol60002
Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0UWoo00<007oo
Ool05Woo00<007ooOol0?Woo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo0P00?7oo0P00GWoo0P00Igoo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`8009Eoo`8001Yoo`8003ioo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03
001oogoo03Yoo`03001oogoo061oo`03001oogoo06Aoo`05001oogooOol0000>Ool00`00Oomoo`03
Ool40005Ool00`00Oomoo`2BOol2000NOol2000lOol001Ioo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`0hOol2001TOol2001TOol01@00Oomoogoo00003goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol0TGoo00<007ooOol087oo00<007ooOol0>Goo000F
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8003Moo`8006Qoo`80
069oo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00TGoo00<007oo
Ool08Woo00<007ooOol0>7oo000GOol3000<Ool50004Ool40005Ool00`00Oomoo`0eOol00`00Oomo
o`1ZOol00`00Oomoo`1POol3000<Ool50004Ool40005Ool00`00Oomoo`2?Ool00`00Oomoo`0SOol0
0`00Oomoo`0hOol003Qoo`03001oogoo03=oo`8006ioo`80085oo`03001oogoo08ioo`03001oogoo
02Eoo`03001oogoo03Moo`00>7oo00<007ooOol0<Woo00<007ooOol0L7oo00<007ooOol0OWoo00<0
07ooOol0SGoo00<007ooOol09goo00<007ooOol0=Woo000hOol2000bOol00`00Oomoo`1bOol00`00
Oomoo`1mOol2002=Ool00`00Oomoo`0YOol00`00Oomoo`0eOol003Qoo`03001oogoo02moo`8007Io
o`8007eoo`03001oogoo08]oo`03001oogoo02]oo`03001oogoo03Aoo`00>7oo00<007ooOol0;Woo
00<007ooOol0N7oo00<007ooOol0NWoo00<007ooOol0Rgoo00<007ooOol0;7oo00<007ooOol0<goo
000hOol2000^Ool00`00Oomoo`1jOol00`00Oomoo`1iOol2002;Ool00`00Oomoo`0^Ool00`00Oomo
o`0bOol003Qoo`03001oogoo02aoo`03001oogoo07aoo`03001oogoo07Qoo`03001oogoo08Uoo`03
001oogoo031oo`03001oogoo035oo`00>7oo00<007ooOol0:Woo0P00P7oo0P00N7oo00<007ooOol0
R7oo00<007ooOol0<Woo00<007ooOol0<7oo000hOol00`00Oomoo`0YOol00`00Oomoo`22Ool00`00
Oomoo`1eOol00`00Oomoo`27Ool00`00Oomoo`0cOol00`00Oomoo`0`Ool003Qoo`8002Uoo`03001o
ogoo08Aoo`03001oogoo07Aoo`8008Qoo`03001oogoo03Aoo`03001oogoo02moo`007goo0`001Woo
0P001Goo10001Goo00<007ooOol09Woo0P00R7oo0P00Fgoo0`001Woo0P001Goo10001Goo00<007oo
Ool0QWoo00<007ooOol0=Woo00<007ooOol0;Woo000NOol01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol00Woo00<007ooOol09Goo00<007ooOol0RWoo00<007ooOol0Egoo00D007ooOomoo`0000Eo
o`8000Uoo`03001oogoo009oo`03001oogoo08Eoo`03001oogoo03Qoo`03001oogoo02eoo`005Woo
1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`8002Eoo`03001oogoo08aoo`03001oogoo
04ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool20025Ool00`00Oomoo`0jOol00`00
Oomoo`0/Ool001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0SOol00`00Oomo
o`2>Ool00`00Oomoo`1EOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0Pgoo00<0
07ooOol0?7oo00<007ooOol0:goo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol08Goo
0P00TWoo00<007ooOol0E7oo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo089oo`03001oogoo
03eoo`03001oogoo02]oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo021o
o`03001oogoo09=oo`03001oogoo05=oo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomo
o`22Ool00`00Oomoo`0nOol00`00Oomoo`0ZOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06
Ool2000POol00`00Oomoo`2EOol00`00Oomoo`1BOol01@00Oomoogoo000037oo00<007ooOol01Woo
0P00PWoo00<007ooOol0@7oo00<007ooOol0:Goo000OOol3000=Ool40005Ool00`00Oomoo`0NOol0
0`00Oomoo`2GOol00`00Oomoo`1BOol3000=Ool40005Ool00`00Oomoo`20Ool00`00Oomoo`12Ool0
0`00Oomoo`0XOol003Qoo`03001oogoo01eoo`03001oogoo09Uoo`03001oogoo06Yoo`03001oogoo
07moo`03001oogoo04Aoo`03001oogoo02Moo`00>7oo00<007ooOol077oo00<007ooOol0Vgoo00<0
07ooOol0JGoo00<007ooOol0OWoo00<007ooOol0AWoo00<007ooOol09Woo000hOol2000LOol00`00
Oomoo`2MOol00`00Oomoo`1XOol2001oOol00`00Oomoo`16Ool00`00Oomoo`0VOol003Qoo`03001o
ogoo01Yoo`03001oogoo09moo`03001oogoo06Moo`03001oogoo07eoo`03001oogoo04Qoo`03001o
ogoo02Eoo`00>7oo00<007ooOol067oo0P00Xgoo00<007ooOol0IWoo00<007ooOol0O7oo00<007oo
Ool0BWoo00<007ooOol097oo000hOol2000HOol00`00Oomoo`2TOol2001VOol2001lOol00`00Oomo
o`1;Ool00`00Oomoo`0TOol003Qoo`03001oogoo01Ioo`03001oogoo0:Moo`03001oogoo06=oo`03
001oogoo07]oo`03001oogoo04aoo`03001oogoo02=oo`00>7oo00<007ooOol05Goo00<007ooOol0
ZGoo00<007ooOol0HWoo00<007ooOol0NWoo00<007ooOol0CWoo00<007ooOol08Woo000hOol00`00
Oomoo`0DOol00`00Oomoo`2[Ool00`00Oomoo`1QOol00`00Oomoo`1iOol00`00Oomoo`1?Ool00`00
Oomoo`0ROol003Qoo`8001Aoo`03001oogoo0:eoo`03001oogoo061oo`8007Yoo`03001oogoo051o
o`03001oogoo025oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol04Woo00<007oo
Ool0[goo00<007ooOol0?Woo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0N7oo00<007oo
Ool0DGoo00<007ooOol08Goo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03
001oogoo009oo`03001oogoo015oo`03001oogoo0;5oo`03001oogoo03aoo`05001oogooOol00005
Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0Mgoo00<007ooOol0Dgoo00<0
07ooOol087oo000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo
0P004Goo00<007ooOol0/goo00<007ooOol0<goo1P000Woo00D007ooOomoo`0000eoo`03001oogoo
00Qoo`03001oogoo009oo`8007Moo`03001oogoo05Eoo`03001oogoo01moo`005Woo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00moo`03001oogoo0;Eoo`8003]o
o`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`1fOol00`00Oomo
o`1EOol00`00Oomoo`0OOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00
Oomoo`0>Ool00`00Oomoo`2hOol00`00Oomoo`0hOol01@00Oomoogoo00003goo00<007ooOol00Woo
10001Goo00<007ooOol0MGoo00<007ooOol0Egoo00<007ooOol07Woo000FOol01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol03Goo00<007ooOol0^Woo00<007ooOol0
=goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo07Aoo`03001o
ogoo05Uoo`03001oogoo01eoo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool2000=Ool00`00Oomoo`2lOol00`00Oomoo`0fOol01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`8007Eoo`03001oogoo05Uoo`03001oogoo01eoo`005goo0`00
3Goo0`001Goo10001Goo00<007ooOol02goo00<007ooOol0_Woo00<007ooOol0=Woo0`003Goo0`00
1Goo10001Goo00<007ooOol0Lgoo00<007ooOol0Fgoo00<007ooOol077oo000hOol00`00Oomoo`0:
Ool00`00Oomoo`0BOol30006Ool20004Ool5000HOol30006Ool20006Ool3000HOol30006Ool20005
Ool3000JOol30006Ool20005Ool3000FOol00`00Oomoo`08Ool50019Ool00`00Oomoo`0OOol30006
Ool20004Ool5000HOol30006Ool20006Ool3000DOol01000Oomoogoo0`001Woo0P001Goo0`006Goo
0`001Woo0P001Goo0`0077oo00<007ooOol00Woo1@0057oo000hOol2000:Ool00`00Oomoo`0BOol0
1@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00
Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Qoo`05001oogooOol00005
Ool20004Ool01@00Oomoogoo00005Woo00<007ooOol02Goo00<007ooOol0BGoo0P007goo00D007oo
Oomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomoogoo00001Goo0P001goo00<007ooOol0
4Woo00D007ooOomoo`0000=oo`03001oogoo00=oo`8000Aoo`05001oogooOol0000GOol01@00Oomo
ogoo00001Goo0P0017oo00D007ooOomoo`0001]oo`03001oogoo00Aoo`03001oogoo01Aoo`00>7oo
00<007ooOol027oo00<007ooOol04goo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogoo
Ool0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;
Ool01@00Oomoogoo00005goo00<007ooOol027oo00<007ooOol0BGoo00<007ooOol07Woo00D007oo
Oomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000BOol00`00Oomoo`02Ool01@00
Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo000077oo
00<007ooOol00goo00<007ooOol057oo000hOol00`00Oomoo`07Ool00`00Oomoo`0DOol01@00Oomo
ogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo
00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo000067oo00<007oo
Ool01goo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05
001oogooOol0000;Ool01000Oomoo`004goo00<007ooOol00Woo00D007ooOomoo`0000]oo`05001o
ogooOol0000GOol01@00Oomoogoo00002goo00D007ooOomoo`0001eoo`03001oogoo009oo`03001o
ogoo01Aoo`00>7oo00<007ooOol01Goo0P005goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05
001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10006Goo00D007ooOomoo`00
00aoo`<001Yoo`8000Moo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000?Ool00`00
Oomoo`0EOol01@00Oomoogoo000037oo00<007oo00004Woo00<007ooOol00goo00D007ooOomoo`00
00]oo`@001Qoo`05001oogooOol0000<Ool3000NOol00`00Oomoo`02Ool00`00Oomoo`0DOol003Qo
o`8000Eoo`03001oogoo01Moo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo0000
37oo00<007oo000067oo00D007ooOomoo`0000]oo`03001oogoo01Yoo`05001oogooOol0000;Ool0
1@00Oomoogoo00006goo00<007ooOol017oo00<007ooOol0BGoo0P007goo00D007ooOomoo`0000mo
o`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000BOol00`00Oomoo`03Ool01@00Oomo
ogoo00002goo00<007ooOol06Goo00D007ooOomoo`0000]oo`05001oogooOol0000NOol01@00Oomo
ogoo00005Woo000hOol00`00Oomoo`03Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007oo
Oomoo`0001Moo`05001oogooOol0000=Ool2000HOol01@00Oomoogoo000037oo00<007ooOol06Goo
00D007ooOomoo`0000]oo`05001oogooOol0000LOol00`00Oomoo`03Ool00`00Oomoo`19Ool00`00
Oomoo`0NOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000=Ool2000A
Ool00`00Oomoo`04Ool01@00Oomoogoo000037oo00<007ooOol067oo00D007ooOomoo`0000]oo`05
001oogooOol0000NOol01@00Oomoogoo00005Woo000hOol00`00Oomoo`02Ool00`00Oomoo`0JOol3
000=Ool3000IOol3000?Ool00`00Oomoo`0GOol3000>Ool3000IOol3000=Ool3000NOol00`00Oomo
o`03001;Ool00`00Oomoo`0OOol3000=Ool3000IOol3000?Ool00`00Oomoo`0?Ool00`00Oomoo`05
Ool3000>Ool3000HOol3000=Ool3000POol4000FOol003Qoo`05001oogooOol0003DOol00`00Oomo
o`1=Ool00`00Oomoo`1^Ool00`00Oomoo`1VOol00`00Oomoo`0FOol003Qoo`800003Ool007oo0=Eo
o`03001oogoo04aoo`8006moo`03001oogoo06Ioo`03001oogoo01Ioo`00>7oo00<007oo0000f7oo
00<007ooOol0Bgoo00<007ooOol0KGoo00<007ooOol0J7oo00<007ooOol05Goo000hOol2003JOol0
0`00Oomoo`1:Ool00`00Oomoo`1/Ool00`00Oomoo`1ZOol00`00Oomoo`0DOol0039oonT0041oonT0
011oo`00>7oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol0BGoo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol057oo000hOol00`00Oomoo`0YOol00`00Oomoo`0Y
Ool00`00Oomoo`0YOol00`00Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomoo`19Ool2000ZOol00`00
Oomoo`0YOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00
Oomoo`0DOol003Qoo`03001oogoo0?moobMoo`03001oo`0006Yoo`03001oogoo08=oo`00>7oo0P00
ogoo:7oo0`00JGoo00<007ooOol0Q7oo000hOol00`00Oomoo`3oOolWOol01000Oomoo`00J7oo00<0
07ooOol0Q7oo000hOol00`00Oomoo`3oOolWOol01000Oomoo`00Igoo00<007ooOol0QGoo000hOol2
003oOolXOol20002Ool00`00Oomoo`1TOol00`00Oomoo`25Ool003Qoo`03001oogoo0?moobMoo`03
001oogoo009oo`03001oogoo069oo`03001oogoo08Ioo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool00Woo00<007ooOol0HGoo00<007ooOol0Qgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`03
Ool00`00Oomoo`1POol00`00Oomoo`27Ool003Qoo`800?moobQoo`8000Aoo`03001oogoo05moo`03
001oogoo08Qoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol017oo00<007ooOol0GWoo00<007oo
Ool0R7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`05Ool00`00Oomoo`1LOol00`00Oomoo`29
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Eoo`03001oogoo05]oo`03001oogoo08Yoo`00
>7oo0P00ogoo:7oo0P001goo00<007ooOol0FWoo00<007ooOol0RWoo000GOol30006Ool20004Ool5
0004Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`06
Ool00`00Oomoo`1IOol00`00Oomoo`2;Ool001Ioo`05001oogooOol00005Ool20005Ool01000Oomo
o`0027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Eoo`04001o
ogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`1HOol00`00Oomoo`2;Ool001Io
o`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo0P002Goo00<007ooOol0EWoo00<007ooOol0S7oo
000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo
05Eoo`03001oogoo08eoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001o
ogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`09Ool00`00
Oomoo`1COol00`00Oomoo`2>Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol02Goo00<007ooOol0Dgoo00<007ooOol0SWoo000FOol01@00Oomoogoo00002goo00D0
07ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo
000017oo00<007ooOol01Woo0P002goo00<007ooOol0DGoo00<007ooOol0Sgoo000GOol3000=Ool3
0005Ool40005Ool00`00Oomoo`3oOol6Ool3000=Ool30005Ool40005Ool00`00Oomoo`0;Ool00`00
Oomoo`1?Ool00`00Oomoo`2@Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00]oo`03001oogoo
04moo`03001oogoo091oo`00>7oo0P00ogoo:7oo0P003Goo00<007ooOol0CGoo00<007ooOol0TGoo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0<Ool00`00Oomoo`1<Ool00`00Oomoo`2BOol003Qo
o`03001oogoo0?moobMoo`03001oogoo00eoo`03001oogoo04Yoo`03001oogoo09=oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol03Woo00<007ooOol0BGoo00<007ooOol0Tgoo000hOol2003oOolX
Ool2000?Ool00`00Oomoo`18Ool00`00Oomoo`2DOol003Qoo`03001oogoo0?moobMoo`03001oogoo
00moo`03001oogoo04Ioo`03001oogoo09Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol03goo
00<007ooOol0AWoo00<007ooOol0UGoo000hOol2003oOolXOol2000AOol00`00Oomoo`14Ool00`00
Oomoo`2FOol003Qoo`03001oogoo0?moobMoo`03001oogoo015oo`03001oogoo049oo`03001oogoo
09Moo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo
00<007ooOol04Woo00<007ooOol0@7oo00<007ooOol0V7oo000NOol01@00Oomoogoo00001Goo0P00
2Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo
009oo`03001oogoo01=oo`03001oogoo03ioo`03001oogoo09Uoo`007Woo00D007ooOomoo`00011o
o`03001oogoo009oo`800?moo`ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000EOol00`00
Oomoo`0lOol00`00Oomoo`2JOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomo
o`3oOol=Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol057oo00<007ooOol0?7oo
00<007ooOol0VWoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007oo
Oomoo`0000aoo`@000Eoo`03001oogoo01Eoo`03001oogoo03Yoo`03001oogoo09]oo`007Woo00D0
07ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00
Oomoo`06Ool00`00Oomoo`0FOol00`00Oomoo`0hOol00`00Oomoo`2LOol001ioo`05001oogooOol0
000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P0067oo
00<007ooOol0=Woo00<007ooOol0WGoo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=
Ool40005Ool00`00Oomoo`0HOol00`00Oomoo`0dOol00`00Oomoo`2NOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo01Uoo`03001oogoo039oo`03001oogoo09moo`00>7oo0P00ogoo:7oo0P006goo
00<007ooOol0<7oo00<007ooOol0X7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0KOol00`00
Oomoo`0^Ool00`00Oomoo`2QOol003Qoo`03001oogoo0?moobMoo`03001oogoo01aoo`03001oogoo
02aoo`03001oogoo0:9oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol07Goo00<007ooOol0:Woo
00<007ooOol0Xgoo000hOol2003oOolXOol2000OOol00`00Oomoo`0XOol00`00Oomoo`2TOol003Qo
o`03001oogoo0?moobMoo`03001oogoo01moo`03001oogoo02Ioo`03001oogoo0:Eoo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol087oo00<007ooOol097oo00<007ooOol0YWoo000hOol2003oOolX
Ool2000ROol2000SOol00`00Oomoo`2WOol001Moo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eo
o`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo02=oo`03
001oogoo01moo`03001oogoo0:Qoo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qo
o`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomoo`0MOol00`00Oomoo`2YOol001Ioo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol09Goo00<007ooOol06goo00<007oo
Ool0ZWoo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00ogoo1Woo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8002Moo`<001Qoo`800:eoo`00
5Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogoo
Ool0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`0YOol2000COol3002_Ool001Ioo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0:goo0P003goo0P00/Woo000FOol0
1@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05
001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0;Goo0`002Woo
0P00]7oo000GOol3000<Ool50004Ool40005Ool2003oOol7Ool3000<Ool50004Ool40005Ool2000a
Ool:002fOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo
00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00;goo1@00
17oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomo
o`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?mo
ob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007oo
Ool017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?mo
obMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3003oOolW
Ool3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo1@00ogoo1Goo
0`0000Aoo`00000001Moo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo0?mo
o`Ioo`05001oogooOol00009Ool6000:Ool01000Oomoo`00M7oo002FOol01@00Oomoogoo00006goo
00<007ooOol0ogoo1Woo00D007ooOomoo`0001Yoo`03001oogoo07Aoo`00UWoo00D007ooOomoo`00
00Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1cOol0
09Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo000077oo00<007ooOol0
LWoo002EOol5000LOol00`00Oomoo`3oOol5Ool5000MOol00`00Oomoo`1bOol00;Ioo`03001oogoo
0?moob=oo`05001oogooOol0001dOol00;Aoo`<00?moobIoo`<007Eoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .29098 L
.08255 .28247 L
.10458 .27436 L
.12507 .26829 L
.14415 .26412 L
.14918 .26329 L
.15465 .26251 L
.15946 .26193 L
.16457 .26144 L
.16917 .2611 L
.17178 .26095 L
.17423 .26084 L
.17538 .2608 L
.17647 .26076 L
.17746 .26074 L
.17852 .26071 L
.17967 .2607 L
.18073 .26068 L
.182 .26068 L
.18314 .26068 L
.18435 .26068 L
.18547 .2607 L
.1867 .26072 L
.18802 .26075 L
.19071 .26083 L
.19317 .26094 L
.1979 .26123 L
.20239 .26161 L
.21236 .26277 L
.22321 .26454 L
.24299 .26907 L
.26399 .27555 L
.30174 .29059 L
.34195 .30934 L
.38063 .32738 L
.40028 .33567 L
.42177 .34358 L
.44253 .34975 L
.4614 .35387 L
.47149 .35545 L
.47611 .35601 L
.48101 .35651 L
.4835 .35671 L
.48624 .35691 L
.48876 .35706 L
.49106 .35717 L
.49378 .35727 L
.49527 .3573 L
.49596 .35732 L
Mistroke
.49669 .35733 L
.498 .35735 L
.49921 .35736 L
.49996 .35736 L
.50065 .35736 L
.50196 .35735 L
.50313 .35733 L
.50438 .35731 L
.50556 .35728 L
.50663 .35725 L
.50926 .35716 L
.51175 .35703 L
.5167 .3567 L
.52208 .35621 L
.53169 .355 L
.54056 .35352 L
.55926 .34928 L
.57988 .34302 L
.62014 .32703 L
.65888 .30895 L
.70007 .28979 L
.72063 .28122 L
.73974 .27428 L
.75939 .26844 L
.77791 .26433 L
.78775 .26275 L
.79293 .26209 L
.7984 .26153 L
.80302 .26117 L
.80546 .26102 L
.80809 .26088 L
.8105 .26079 L
.8127 .26073 L
.81375 .26071 L
.81491 .26069 L
.81599 .26068 L
.817 .26068 L
.81818 .26068 L
.81941 .26069 L
.82047 .2607 L
.82163 .26072 L
.82287 .26075 L
.82421 .26078 L
.82661 .26087 L
.82905 .26099 L
.83134 .26113 L
.83564 .26146 L
.84078 .26196 L
.84552 .26253 L
.85624 .26419 L
Mistroke
.87498 .2683 L
.89561 .27443 L
.93591 .29026 L
.97471 .30831 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .26242 L
.08255 .24219 L
.0932 .2333 L
.10458 .22545 L
.11009 .22231 L
.11531 .21977 L
.12038 .21769 L
.12507 .21614 L
.12951 .215 L
.13178 .21454 L
.13422 .21415 L
.13549 .21398 L
.13666 .21384 L
.13784 .21373 L
.13895 .21365 L
.14022 .21358 L
.1409 .21356 L
.14161 .21354 L
.1423 .21353 L
.14295 .21353 L
.14415 .21354 L
.14531 .21358 L
.14656 .21364 L
.14773 .21372 L
.14881 .21382 L
.15143 .21414 L
.15392 .21454 L
.15886 .21565 L
.16423 .2173 L
.17383 .22139 L
.1827 .22642 L
.20137 .2406 L
.22197 .261 L
.26217 .30935 L
.30086 .35597 L
.32051 .37571 L
.3309 .38443 L
.342 .39217 L
.35275 .39797 L
.35784 .4001 L
.36253 .4017 L
.36724 .40295 L
.36972 .40346 L
.37235 .40389 L
.37463 .40418 L
.37573 .40428 L
.37677 .40436 L
.37799 .40444 L
.37911 .40448 L
Mistroke
.38031 .40451 L
.38162 .4045 L
.38227 .40449 L
.38296 .40448 L
.38419 .40442 L
.38551 .40434 L
.38695 .40421 L
.38955 .40389 L
.39197 .4035 L
.39649 .40251 L
.40134 .40108 L
.40698 .39893 L
.41232 .39645 L
.42232 .39063 L
.44227 .37492 L
.4607 .35634 L
.50002 .30899 L
.53782 .26331 L
.55884 .24211 L
.56803 .23435 L
.57808 .22714 L
.58722 .22183 L
.59696 .21755 L
.60236 .21583 L
.60726 .21468 L
.60962 .21426 L
.61086 .21408 L
.61218 .21392 L
.61333 .2138 L
.61459 .21369 L
.61574 .21362 L
.61682 .21357 L
.61808 .21353 L
.61871 .21353 L
.61941 .21353 L
.62065 .21355 L
.62181 .21359 L
.62248 .21362 L
.62318 .21367 L
.62443 .21377 L
.62578 .2139 L
.62725 .21408 L
.62973 .21447 L
.63238 .215 L
.63715 .21624 L
.64214 .21792 L
.64686 .21988 L
.6557 .22447 L
.67568 .23897 L
.69413 .25668 L
Mistroke
.7335 .30323 L
.77136 .34959 L
.79241 .37174 L
.81166 .38782 L
.82118 .39396 L
.8262 .39666 L
.83155 .39912 L
.8367 .40105 L
.84136 .40244 L
.84361 .40299 L
.84604 .40349 L
.84835 .40387 L
.85045 .40414 L
.85159 .40425 L
.85283 .40435 L
.85414 .40443 L
.85538 .40448 L
.85653 .40451 L
.85776 .40451 L
.85881 .40449 L
.85997 .40444 L
.86063 .40441 L
.86132 .40436 L
.86256 .40426 L
.86535 .40395 L
.86777 .40357 L
.87041 .40305 L
.87569 .40166 L
.88133 .39969 L
.89148 .39488 L
.90173 .38845 L
.91284 .37986 L
.933 .36054 L
.97393 .31186 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .27402 L
.10458 .23652 L
.14415 .20257 L
.18221 .17161 L
.22272 .14105 L
.26171 .11445 L
.30316 .08971 L
.34309 .06975 L
.3815 .05445 L
.40095 .04825 L
.42237 .04266 L
.44268 .03859 L
.45178 .03716 L
.46172 .03587 L
.4671 .0353 L
.4721 .03485 L
.47727 .03445 L
.48196 .03417 L
.48658 .03395 L
.4887 .03387 L
.49093 .0338 L
.49332 .03375 L
.49438 .03373 L
.49552 .03371 L
.49675 .0337 L
.49789 .03369 L
.49859 .03368 L
.49925 .03368 L
.50049 .03368 L
.50163 .03368 L
.50286 .03369 L
.50401 .0337 L
.50508 .03372 L
.50754 .03377 L
.51014 .03383 L
.51268 .03392 L
.51504 .03402 L
.5204 .0343 L
.5293 .03497 L
.53882 .03593 L
.54906 .03728 L
.56016 .03909 L
.58032 .04329 L
.62123 .05541 L
.66064 .07144 L
.69852 .09064 L
.73886 .11482 L
.77769 .14134 L
.81897 .17253 L
Mistroke
.85873 .20498 L
.89697 .23788 L
.93767 .27412 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35481 L
.10458 .40129 L
.14415 .43855 L
.18221 .46612 L
.20178 .47655 L
.21267 .48115 L
.22272 .48462 L
.23293 .48734 L
.23832 .48846 L
.24402 .48939 L
.24641 .4897 L
.24897 .48999 L
.25119 .4902 L
.25361 .49038 L
.25507 .49047 L
.25643 .49053 L
.25773 .49058 L
.2584 .4906 L
.25912 .49062 L
.25983 .49064 L
.26048 .49064 L
.26176 .49065 L
.26293 .49065 L
.26416 .49063 L
.26538 .4906 L
.26607 .49058 L
.26671 .49056 L
.26912 .49045 L
.27131 .4903 L
.27364 .49011 L
.27847 .48957 L
.2838 .48876 L
.29326 .48678 L
.30213 .48429 L
.32232 .47642 L
.34082 .46659 L
.38045 .43788 L
.41855 .40199 L
.45912 .35742 L
.49816 .31122 L
.53966 .26203 L
.57964 .21791 L
.61811 .18138 L
.63759 .16587 L
.65902 .15154 L
.67938 .14084 L
.69843 .13357 L
.70884 .13076 L
.71396 .12968 L
Mistroke
.71872 .12886 L
.72301 .12828 L
.72758 .12782 L
.7302 .12763 L
.73148 .12755 L
.73266 .1275 L
.73371 .12746 L
.73487 .12742 L
.73603 .1274 L
.73725 .12738 L
.73856 .12738 L
.73977 .12739 L
.7404 .1274 L
.7411 .12742 L
.74251 .12746 L
.74375 .12751 L
.74508 .12757 L
.74748 .12773 L
.74985 .12793 L
.75235 .12818 L
.7568 .12876 L
.76198 .12963 L
.7668 .13063 L
.77773 .13356 L
.78828 .13725 L
.79823 .14149 L
.81683 .15134 L
.85534 .17907 L
.89632 .21767 L
.93577 .26115 L
.97371 .30604 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo0P00
1Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo
10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00
Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Io
o`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`007goo0`001Woo0P001Goo
10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00
Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eo
o`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`005Woo1P000Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo0?moo`Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomo
ogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomoogoo000037oo10001Goo00<007oo
Ool0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool0
0`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool0
1@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0l7oo000OOol3000=Ool40005Ool2003o
Ool?Ool3000=Ool40005Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`8001Eoo`T006Ioo`T006Aoo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo
1Woo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol04Woo0P002Goo1000H7oo0P002Goo0`00
HGoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001o
ogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<0
07ooOol03goo0`003goo00<007ooOol0FWoo0`003Woo0P00Ggoo000>Ool60002Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0o7oo1P000Woo00D007ooOomoo`00
00eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo015oo`8005Qoo`80
01=oo`03001oogoo05aoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000=Ool2000F
Ool00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`1KOol001Ioo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo
10001Goo00<007ooOol02goo00<007ooOol05goo00<007ooOol0DWoo00<007ooOol05Woo00<007oo
Ool0FWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Yoo`03
001oogoo01Uoo`03001oogoo051oo`03001oogoo01Qoo`03001oogoo05Uoo`005Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000]oo`03001oogoo01Yoo`03001oogoo04ioo`03
001oogoo01Yoo`03001oogoo05Qoo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo
0`003Goo0`001Goo10001Goo00<007ooOol02Goo00<007ooOol077oo00<007ooOol0C7oo00<007oo
Ool077oo00<007ooOol0Egoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`08Ool00`00Oomoo`0N
Ool00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`1FOol003Qoo`03001oogoo01moo`<000Io
o`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<001Yoo`<000Ioo`8000Eo
o`<0025oo`D004Uoo`03001oogoo00Moo`03001oogoo01Eoo`<000Ioo`<000=oo`D001Qoo`<000Io
o`8000Ioo`<001Ioo`03001oo`00008000Ioo`8000Eoo`<000ioo`03001oogoo00Qoo`<000Ioo`80
00Eoo`<0025oo`D001Aoo`00>7oo0P0067oo5P000Woo00@007ooOol001Moo`05001oogooOol00005
Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Qoo`05
001oogooOol00002OolG000IOol00`00Oomoo`19Ool20007Ool00`00Oomoo`0EOol01@00Oomoogoo
00001Goo0P0000=oo`00Ool00Woo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00
Oomoo`0DOol00`00Ool00003Ool00`00Oomoo`03Ool20004Ool01@00Oomoogoo00003Goo00<007oo
Ool01goo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qo
o`03001oogoo01=oo`@000Moo`05001oogooOol0000:Ool4000IOol01@00Oomoogoo00002goo1@00
5goo00D007ooOomoo`0000]oo`05001oogooOol0000HOol00`00Oomoo`040009Ool01@00Oomoogoo
00002Goo0`005Woo00<007ooOol0BGoo00<007ooOol01Woo00<007ooOol05Goo00D007ooOomoo`00
00Qoo`03001oogoo009oo`03001oogoo01Moo`05001oogooOol0000;Ool5000EOol00`00Ool00003
Ool00`00Oomoo`09Ool01@00Oomoogoo00003Woo00<007ooOol01Woo00D007ooOomoo`0000]oo`05
001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo015oo`8000]oo`05001oogooOol0
000=Ool4000FOol01@00Oomoogoo00002goo00@007ooOol001Qoo`05001oogooOol0000;Ool01@00
Oomoogoo000067oo0`0000=oo`00Ool02Woo00D007ooOomoo`0000aoo`<001=oo`03001oogoo04Uo
o`03001oogoo00Eoo`03001oogoo01Ioo`05001oogooOol00009Ool00`00Oomoo`02Ool00`00Oomo
o`0FOol01@00Oomoogoo00002goo00@007ooOol001Eoo`04001oogoo0003Ool00`00Oomoo`09Ool0
1@00Oomoogoo00003goo00<007ooOol01Goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol0
0`00Oomoo`0DOol003Qoo`03001oogoo00moo`8000eoo`05001oogooOol0000?Ool00`00Ool00002
000COol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`0000]oo`@001Moo`<000=o
o`03001oogoo00Yoo`<0011oo`<0011oo`03001oogoo04Uoo`03001oogoo00Aoo`03001oogoo01Mo
o`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<0
07oo000057oo00D007ooOomoo`0000=oo`03001oogoo00Uoo`@0015oo`03001oogoo00Aoo`05001o
ogooOol0000<Ool3000SOol00`00Oomoo`0DOol003Qoo`8000eoo`<000moo`05001oogooOol0000?
Ool00`00Oomoo`02Ool2000AOol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`00
00]oo`03001oogoo01Aoo`@0009oo`05001oogooOol0000;Ool01@00Oomoogoo00004Woo0`003Goo
00<007ooOol0BGoo0P0017oo00<007ooOol067oo00D007ooOomoo`0000]oo`05001oogooOol0000G
Ool01@00Oomoogoo000037oo00<007oo00004goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03
001oogoo01=oo`03001oogoo00=oo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007oo
Ool057oo000hOol00`00Oomoo`0:Ool2000BOol01@00Oomoogoo00002goo00D007ooOomoo`0000Io
o`8000moo`05001oogooOol0000=Ool2000HOol01@00Oomoogoo000037oo00<007ooOol04Goo0P00
1Woo00D007ooOomoo`0000]oo`05001oogooOol0000EOol3000:Ool00`00Oomoo`19Ool00`00Oomo
o`02Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo0P000Woo00<007ooOol05Goo00D007ooOomo
o`0000eoo`80019oo`03001oogoo00=oo`05001oogooOol0000<Ool00`00Oomoo`0COol00`00Oomo
o`02Ool01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007oo
Ool01goo0`005Goo0`003Goo0`002Goo0P003Woo0`003goo00<007ooOol05goo0`003Woo0`003Woo
0P002Goo0`003Goo0`006Goo0P001Woo0`00Bgoo00D007ooOomoo`0001eoo`<000eoo`<001Uoo`<0
00moo`03001oogoo00moo`03001oogoo00Eoo`<000ioo`<001=oo`03001oogoo009oo`<000eoo`<0
025oo`<001Ioo`00>7oo0P001Woo0P00=Woo0P00F7oo0P00>Goo0P00DWoo0P000Woo00<007ooOol0
;7oo00<007ooOol0?7oo00<007ooOol0;Goo00<007ooOol0CWoo000hOol00`00Oomoo`03Ool2000j
Ool3001COol2000mOol2001@Ool01000Oomoo`00<7oo00<007ooOol0>Woo00<007ooOol0;goo00<0
07ooOol0CGoo000hOol00`00Oomoo`03000oOol2001?Ool20011Ool00`00Oomoo`1=Ool00`00Ool0
000bOol00`00Oomoo`0hOol00`00Oomoo`0aOol00`00Oomoo`1<Ool003Qoo`<004Aoo`<004Yoo`80
04Aoo`8004eoo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00<Wooj@00
@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool2000:Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool30008Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool20009Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`0DOol003Qoo`03001oogoo04]oo`<003aoo`<009Uoo`03001oogoo03Eo
o`03001oogoo039oo`03001oogoo03Moo`03001oogoo035oo`03001oogoo01Eoo`00>7oo0P00Cgoo
0P00>7oo0P00W7oo0P00=goo00<007ooOol0<7oo00<007ooOol0>Goo00<007ooOol0;goo00<007oo
Ool05Woo000hOol00`00Oomoo`1@Ool2000dOol2002NOol00`00Oomoo`0gOol00`00Oomoo`0^Ool0
0`00Oomoo`0kOol00`00Oomoo`0]Ool00`00Oomoo`0GOol003Qoo`03001oogoo059oo`80031oo`80
0:1oo`03001oogoo03Qoo`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo
01Qoo`00>7oo00<007ooOol0E7oo0P00:goo0`00XWoo00<007ooOol0>Goo00<007ooOol0:Woo00<0
07ooOol0?Woo00<007ooOol0:Woo00<007ooOol06Goo000hOol2001GOol3000VOol2002UOol2000j
Ool00`00Oomoo`0ZOol00`00Oomoo`0oOol00`00Oomoo`0YOol00`00Oomoo`0IOol003Qoo`03001o
ogoo05Uoo`@001moo`<00:Moo`03001oogoo03Yoo`03001oogoo02Qoo`03001oogoo045oo`03001o
ogoo02Moo`03001oogoo01Yoo`00>7oo00<007ooOol0GGoo10005Woo1@00ZWoo00<007ooOol0>goo
00<007ooOol09Woo00<007ooOol0@goo00<007ooOol09Goo00<007ooOol06goo000hOol00`00Oomo
o`1QOol4000=Ool5002_Ool00`00Oomoo`0lOol00`00Oomoo`0TOol00`00Oomoo`15Ool00`00Oomo
o`0SOol00`00Oomoo`0LOol003Qoo`8006Ioo`d00;Aoo`8003ioo`8002=oo`03001oogoo04Moo`03
001oogoo025oo`03001oogoo01eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0?goo00<007oo
Ool07goo00<007ooOol0BGoo00<007ooOol07goo00<007ooOol07Woo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`10Ool00`00Oomoo`0MOol00`00Oomoo`1;Ool00`00Oomoo`0MOol00`00Oomoo`0O
Ool003Qoo`800?moobQoo`80049oo`03001oogoo01]oo`03001oogoo04eoo`03001oogoo01]oo`03
001oogoo021oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo
0P0017oo1@0017oo10001Goo00<007ooOol0@Woo00<007ooOol067oo0P00DGoo00<007ooOol06Goo
00<007ooOol08Goo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo
009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007oo
Ool00Woo00<007ooOol0@goo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05Woo0P0097oo
000FOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04Aoo`8001Eoo`03
001oogoo05Aoo`03001oogoo01Aoo`03001oogoo02Aoo`005Woo00D007ooOomoo`0000ioo`03001o
ogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool20017Ool00`00Oomoo`0AOol00`00Oomoo`1FOol3000BOol00`00Oomoo`0UOol001Io
o`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003goo00<007ooOol00Woo10001Goo00<007ooOol0Agoo0P003goo0P00G7oo00<007ooOol03Woo
00<007ooOol09Woo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<0
07ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
04Uoo`03001oogoo00]oo`03001oogoo05eoo`03001oogoo00]oo`8002Uoo`005Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8004]oo`8000Moo`@0065oo`<000Moo`<002]oo`00
5goo0`003Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo0`003Goo0`001Goo10001Goo00<007oo
Ool0C7oo1`00J7oo1`00;Woo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo
0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003a
Ool001moo`<000Ioo`8000Eoo`@000Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03
001oogoo0?1oo`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?mo
o`eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001ioo`05001o
ogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007oo
Ool00Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00ogoo3Woo
00D007ooOomoo`00011oo`03001oogoo009oo`800?5oo`007Woo00D007ooOomoo`0000aoo`@000Eo
o`03001oogoo0?moo`eoo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3`Ool001ioo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007oo
Ool01Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00ogoo3Woo
00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?5oo`007goo0`003Goo10001Goo00<007ooOol0
ogoo3Woo0`003Goo10001Goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2
003oOolXOol2003aOol001Moo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?mo
o`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomo
o`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogoo
Ool00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo0000
3Woo00<007ooOol01goo00<007ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo
00Moo`03001oogoo009oo`800?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eo
o`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3`
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0l7oo000FOol0
1@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00lGoo000GOol3000<Ool50004Ool4
0005Ool00`00Oomoo`3oOol6Ool3000<Ool50004Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2
003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00;goo1@0017oo00<007ooOol0ogoo7Woo
1@0017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04
Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00
<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3g
Ool0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007oo
Ool0mgoo000_Ool3003oOolWOol3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo
0000000067oo0`00ogoo1goo0`0000Aoo`00000001Uoo`<007Aoo`00UWoo00D007ooOomoo`0000Uo
o`H000Uoo`05001oogooOol0003oOol7Ool01@00Oomoogoo00002Goo1P0037oo00<007ooOol0Lgoo
002FOol01@00Oomoogoo000077oo00<007ooOol0ogoo1Goo00D007ooOomoo`0001Qoo`D007Aoo`00
UWoo00D007ooOomoo`0000Uoo`H000eoo`03001oogoo0?moo`Eoo`05001oogooOol00009Ool60009
Ool01000Oomoo`00MGoo002FOol01@00Oomoogoo00006Woo0P00ogoo27oo00D007ooOomoo`0001Uo
o`03001oo`0007Eoo`00UGoo1@007Goo00<007ooOol0ogoo17oo1@006Woo00<007oo0000MGoo002c
Ool01@00Oomoogoo0000ogoo9Woo0P00MGoo002dOol3003oOolXOol00`00Oomoo`1cOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00;goo
1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eoo`03
001oogoo0?mooaaoo`H000Eoo`03001oogoo0?Moo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<0
07ooOol017oo0P00lGoo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool0
0`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001o
ogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000_Ool30006
Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2001YOol7002gOol2003a
Ool003Qoo`03001oogoo05moo`T000Moo`X00:eoo`03001oogoo0?1oo`00>7oo00<007ooOol0G7oo
0`006Woo1000ZGoo00<007ooOol0l7oo000hOol2001HOol5000QOol4002UOol2003aOol003Qoo`03
001oogoo059oo`D002Yoo`D00:1oo`03001oogoo0?1oo`00>7oo00<007ooOol0Cgoo0`00=7oo0`00
WGoo00<007ooOol0l7oo000hOol00`00Oomoo`1=Ool2000jOol3002JOol00`00Oomoo`3`Ool003Qo
o`8004]oo`<003moo`8009Qoo`800?5oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo
00<007ooOol0B7oo0P00A7oo0`00M7oo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<0
07ooOol0AWoo0P00BGoo0P00LGoo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001o
ogoo009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo04Aoo`8004eoo`03001oogoo06Ioo`H0009oo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool20012Ool3001@Ool2001^Ool01@00Oomoogoo00003Woo00<0
07ooOol01goo00<007ooOol00Woo0P00lGoo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo
10001Goo00<007ooOol0?goo0P00EGoo0P00K7oo00D007ooOomoo`0000ioo`03001oogoo00=oo`@0
00Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo03eoo`8005Uoo`03001oogoo06Uoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol01Woo0P00?7oo0P00G7oo0P00JGoo00D007ooOomoo`0000]oo`05001oogooOol00004
Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo03Yoo`03001o
ogoo05ioo`8006Qoo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0>7oo
0P00Hgoo0P00Qgoo00<007ooOol0l7oo000hOol00`00Oomoo`0fOol2001WOol20025Ool00`00Oomo
o`3`Ool003Qoo`8003Ioo`03001oogoo06Uoo`8008=oo`800?5oo`00>7oo00<007ooOol0<goo0P00
KWoo0P00PGoo00<007ooOol0l7oo000hOol00`00Oomoo`0bOol00`00Oomoo`1`Ool00`00Oomoo`1n
Ool00`00Oomoo`3`Ool003Qoo`80035oo`8007Aoo`8007ioo`800?5oo`00>7oo00<007ooOol0;goo
00<007ooOol0MWoo00<007ooOol0Ngoo00<007ooOol0WWoo2P00B7oo000hOol00`00Oomoo`0]Ool2
001jOol2001kOol00`00Oomoo`2KOol3000:Ool30015Ool003Qoo`03001oogoo02aoo`03001oogoo
07aoo`03001oogoo07Qoo`03001oogoo09Moo`@0011oo`D0041oo`00>7oo0P00:goo0P00P7oo0P00
N7oo0P00UGoo0`006Goo0P00?Woo000OOol30006Ool20005Ool40005Ool00`00Oomoo`0YOol00`00
Oomoo`22Ool00`00Oomoo`1LOol30006Ool20005Ool40005Ool00`00Oomoo`2BOol2000NOol2000l
Ool001ioo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0XOol00`00Oomo
o`24Ool00`00Oomoo`1JOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0
TGoo00<007ooOol087oo00<007ooOol0>Goo000FOol60002Ool01@00Oomoogoo000047oo00<007oo
Ool00Woo0P009goo0P00R7oo00<007ooOol0DGoo1P000Woo00D007ooOomoo`00011oo`03001oogoo
009oo`80091oo`8002Aoo`8003Uoo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001o
ogoo02Eoo`03001oogoo08Uoo`03001oogoo05Qoo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`2=Ool2000XOol00`00Oomoo`0fOol001ioo`05001oogooOol0000<Ool40005Ool00`00
Oomoo`0TOol00`00Oomoo`2;Ool00`00Oomoo`1GOol01@00Oomoogoo000037oo10001Goo00<007oo
Ool0S7oo00<007ooOol0:Goo00<007ooOol0=Goo000NOol01@00Oomoogoo000037oo00<007ooOol0
1Woo00<007ooOol08goo00<007ooOol0SGoo00<007ooOol0EWoo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`03001oogoo08]oo`03001oogoo02]oo`8003Eoo`007Woo00D007ooOomoo`0000aoo`03
001oogoo00Ioo`80029oo`80095oo`03001oogoo05Eoo`05001oogooOol0000<Ool00`00Oomoo`06
Ool2002;Ool00`00Oomoo`0^Ool00`00Oomoo`0bOol001moo`<000eoo`@000Eoo`03001oogoo021o
o`03001oogoo099oo`8005Ioo`<000eoo`@000Eoo`03001oogoo08Uoo`03001oogoo031oo`03001o
ogoo035oo`00>7oo00<007ooOol07goo00<007ooOol0UGoo00<007ooOol0K7oo00<007ooOol0R7oo
00<007ooOol0<Woo0P00<Goo000hOol00`00Oomoo`0NOol00`00Oomoo`2GOol00`00Oomoo`1[Ool0
0`00Oomoo`26Ool2000gOol00`00Oomoo`0^Ool003Qoo`8001ioo`03001oogoo09Uoo`8006]oo`80
08Ioo`03001oogoo03Qoo`03001oogoo02eoo`00>7oo00<007ooOol077oo00<007ooOol0W7oo00<0
07ooOol0J7oo00<007ooOol0Q7oo00<007ooOol0>Woo00<007ooOol0;7oo000hOol00`00Oomoo`0K
Ool00`00Oomoo`2NOol00`00Oomoo`1WOol00`00Oomoo`23Ool00`00Oomoo`0lOol00`00Oomoo`0[
Ool003Qoo`8001]oo`03001oogoo0:1oo`03001oogoo06Ioo`8008=oo`03001oogoo03ioo`03001o
ogoo02Yoo`00>7oo00<007ooOol067oo0P00Y7oo0P00IWoo00<007ooOol0PGoo00<007ooOol0@7oo
00<007ooOol0:Goo000hOol00`00Oomoo`0GOol00`00Oomoo`2VOol00`00Oomoo`1SOol00`00Oomo
o`20Ool00`00Oomoo`12Ool00`00Oomoo`0XOol003Qoo`03001oogoo01Ioo`03001oogoo0:Qoo`03
001oogoo069oo`03001oogoo07moo`03001oogoo04Aoo`03001oogoo02Moo`00>7oo0P005Goo0P00
[7oo00<007ooOol0HGoo0P00Ogoo00<007ooOol0AWoo00<007ooOol09Woo000GOol30006Ool20004
Ool50004Ool40005Ool00`00Oomoo`0COol00`00Oomoo`2]Ool00`00Oomoo`0oOol30006Ool20004
Ool50004Ool40005Ool00`00Oomoo`1mOol00`00Oomoo`17Ool00`00Oomoo`0VOol001Ioo`05001o
ogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol04Woo00<007oo
Ool0[goo00<007ooOol0?Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomo
o`02Ool00`00Oomoo`1lOol00`00Oomoo`19Ool00`00Oomoo`0UOol000ioo`H0009oo`05001oogoo
Ool0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000BOol00`00Oomoo`2aOol00`00Oomoo`0d
Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P00O7oo00<007oo
Ool0Bgoo00<007ooOol097oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol03goo0P00]Goo00<007ooOol0>goo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo07Yoo`03001oogoo04eoo`03001oogoo02=oo`005Woo00D007oo
Oomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00ioo`03001oogoo0;Ioo`8003]oo`05
001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1iOol00`00Oomoo`1?Ool00`00
Oomoo`0ROol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`0=Ool00`00Oomoo`2iOol00`00Oomoo`0hOol01@00Oomoogoo00003goo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol0N7oo00<007ooOol0DGoo00<007ooOol08Goo000FOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000eoo`03001oogoo0;]oo`03001oogoo
03Moo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00N7oo00<007oo
Ool0Dgoo00<007ooOol087oo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`0;Ool00`00Oomo
o`2mOol00`00Oomoo`0gOol3000=Ool30005Ool40005Ool00`00Oomoo`1fOol00`00Oomoo`1EOol0
0`00Oomoo`0OOol003Qoo`03001oogoo00Yoo`03001oogoo019oo`<000Ioo`8000Aoo`D001Qoo`<0
00Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<001Yoo`<000Ioo`8000Eoo`<001Eoo`8000Yoo`D0
04Uoo`03001oogoo01moo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Ioo`03001oo`00
008000Ioo`8000Eoo`<001Uoo`<000Ioo`8000Eoo`<001Uoo`03001oogoo00Eoo`D001Aoo`00>7oo
0P002Woo00<007ooOol04Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomo
ogoo00001Goo0P001goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0
000HOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Ioo`03001oogoo00Uoo`03001o
ogoo04Uoo`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`005goo00D007ooOomoo`00
00Eoo`8000Moo`03001oogoo01Aoo`03001oo`0000=oo`03001oogoo00=oo`8000Aoo`05001oogoo
Ool0000GOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Uoo`03001oogoo00Ioo`03
001oogoo01Aoo`00>7oo00<007ooOol027oo00<007ooOol04goo00D007ooOomoo`0000eoo`03001o
ogoo01Moo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qo
o`05001oogooOol0000;Ool01@00Oomoogoo00005goo00<007ooOol027oo00<007ooOol0BGoo00<0
07ooOol07Woo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000EOol0
0`00Ool00003Ool00`00Oomoo`09Ool01@00Oomoogoo00005goo00D007ooOomoo`0000]oo`05001o
ogooOol0000IOol00`00Oomoo`06Ool00`00Oomoo`0DOol003Qoo`03001oogoo00Moo`03001oogoo
01Aoo`05001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol001Qo
o`05001oogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogooOol0
000HOol00`00Oomoo`07Ool00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Woo00<0
07ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000EOol01000Oomoo`000goo00<007ooOol0
2Goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00006Woo00<007ooOol0
1Goo00<007ooOol057oo000hOol00`00Oomoo`05Ool2000GOol01@00Oomoogoo00003goo00<007oo
Ool05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool4000IOol01@00
Oomoogoo000037oo0`006Woo0P001goo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`00
00moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000DOol01@00Oomoogoo00000goo
00<007ooOol02Goo100067oo00D007ooOomoo`0000aoo`<001aoo`03001oogoo00Aoo`03001oogoo
01Aoo`00>7oo0P001Goo00<007ooOol05goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001o
ogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo00<007ooOol06Woo00D007ooOomo
o`0000]oo`05001oogooOol0000KOol00`00Oomoo`04Ool00`00Oomoo`19Ool2000OOol01@00Oomo
ogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001=oo`03001oogoo009o
o`05001oogooOol0000;Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`0001ao
o`03001oogoo00=oo`03001oogoo01Aoo`00>7oo00<007ooOol00goo00<007ooOol067oo00D007oo
Oomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00003Goo0P0067oo00D007ooOomoo`00
00aoo`03001oogoo01Uoo`05001oogooOol0000;Ool01@00Oomoogoo000077oo00<007ooOol00goo
00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00
Oomoogoo00003Goo0P004goo00<007ooOol00Woo00D007ooOomoo`0000aoo`03001oogoo01Qoo`05
001oogooOol0000;Ool01@00Oomoogoo00007Goo00<007ooOol00Woo00<007ooOol057oo000hOol0
0`00Oomoo`02Ool00`00Oomoo`0JOol3000=Ool3000IOol3000?Ool00`00Oomoo`0GOol3000>Ool3
000IOol3000=Ool3000NOol00`00Oomoo`03001;Ool00`00Oomoo`0OOol3000=Ool3000IOol3000?
Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool3000>Ool3000HOol3000=Ool3000OOol00`00Ool00002
000FOol003Qoo`05001oogooOol0003DOol00`00Oomoo`1=Ool00`00Oomoo`1_Ool00`00Oomoo`1S
Ool00`00Oomoo`0HOol003Qoo`800003Ool007oo0=Eoo`03001oogoo04aoo`8006moo`03001oogoo
06Eoo`03001oogoo01Moo`00>7oo00<007oo0000f7oo00<007ooOol0Bgoo00<007ooOol0KWoo00<0
07ooOol0IWoo00<007ooOol05Woo000hOol2003JOol00`00Oomoo`1:Ool00`00Oomoo`1]Ool00`00
Oomoo`1XOol00`00Oomoo`0EOol0039oonT0041oonT0011oo`00>7oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0BGoo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool057oo000hOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0ZOol0
0`00Oomoo`0YOol00`00Oomoo`19Ool2000ZOol00`00Oomoo`0YOol00`00Oomoo`0COol00`00Oomo
o`0COol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0DOol003Qoo`03001oogoo0?moobMo
o`03001oo`0006Yoo`03001oogoo08=oo`00>7oo0P00ogoo:7oo0P0000=oo`00Ool0Igoo00<007oo
Ool0Q7oo000hOol00`00Oomoo`3oOolWOol01@00Oomoogoo0000IWoo00<007ooOol0QGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`02Ool00`00Oomoo`1ROol00`00Oomoo`26Ool003Qoo`800?mo
obQoo`8000=oo`03001oogoo065oo`03001oogoo08Moo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool00goo00<007ooOol0Ggoo00<007ooOol0R7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`04
Ool00`00Oomoo`1MOol00`00Oomoo`29Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Eoo`03
001oogoo05]oo`03001oogoo08Yoo`00>7oo0P00ogoo:7oo0P001goo00<007ooOol0FGoo00<007oo
Ool0Rgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`06Ool00`00Oomoo`1IOol00`00Oomoo`2;
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Moo`03001oogoo05Moo`03001oogoo08aoo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol027oo00<007ooOol0EGoo00<007ooOol0SGoo000hOol2
003oOolXOol2000:Ool00`00Oomoo`1COol00`00Oomoo`2>Ool001Moo`<000Ioo`8000Aoo`D000Ao
o`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Yoo`03
001oogoo055oo`03001oogoo08moo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008
Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol0
00Qoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo04moo`03001oogoo091oo`005Woo00D0
07ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000=
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`1>Ool00`00Oomoo`2AOol001Io
o`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00
Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0C7oo
00<007ooOol0TWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00eoo`03001oogoo
04Yoo`03001oogoo09=oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`0>Ool00`00Oomoo`18Ool00`00Oomoo`2DOol001Ioo`05001oogooOol0000;Ool01@00Oomo
ogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004
Ool00`00Oomoo`06Ool2000@Ool20016Ool2002GOol001Moo`<000eoo`<000Eoo`@000Eoo`03001o
ogoo0?moo`Ioo`<000eoo`<000Eoo`@000Eoo`03001oogoo015oo`03001oogoo049oo`03001oogoo
09Moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol04Woo00<007ooOol0@7oo00<007ooOol0V7oo
000hOol2003oOolXOol2000DOol00`00Oomoo`0nOol00`00Oomoo`2IOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo01Aoo`8003eoo`03001oogoo09Yoo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool05Woo00<007ooOol0>Goo00<007ooOol0Vgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0G
Ool00`00Oomoo`0gOol00`00Oomoo`2LOol003Qoo`800?moobQoo`8001Uoo`03001oogoo03Eoo`03
001oogoo09eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol06Goo0P00<goo0P00X7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`0KOol00`00Oomoo`0_Ool00`00Oomoo`2POol003Qoo`800?mo
obQoo`8001eoo`03001oogoo02eoo`03001oogoo0:5oo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool07Goo00<007ooOol0:Woo0P00Y7oo000OOol30006Ool20005Ool40005Ool00`00Oomoo`3oOol>
Ool30006Ool20005Ool40005Ool00`00Oomoo`0NOol00`00Oomoo`0XOol00`00Oomoo`2TOol001io
o`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo
00001Goo0P002Goo00<007ooOol00Woo00<007ooOol07goo00<007ooOol09Woo00<007ooOol0YGoo
000NOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00ogoo3Woo00D007ooOomoo`00011oo`03
001oogoo009oo`80025oo`03001oogoo02Aoo`03001oogoo0:Ioo`007Woo00D007ooOomoo`00011o
o`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00
Oomoo`0QOol2000ROol2002YOol001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3oOol=
Ool01@00Oomoogoo000037oo10001Goo00<007ooOol08goo0`007Goo0P00Zgoo000NOol01@00Oomo
ogoo000037oo00<007ooOol01Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo
00Ioo`03001oogoo02Ioo`<001Qoo`800:eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Io
o`800?moo`ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2000ZOol2000COol3002_Ool001mo
o`<000eoo`@000Eoo`03001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo02]oo`8000eoo`@0
0;9oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0;Goo3@00]Woo000hOol2003oOolXOol2003a
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`
Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<0
07ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0l7oo000FOol0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`00
5Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05
001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00Woo0P00lGoo000FOol01@00Oomoogoo00003Woo00<007ooOol0
0goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03
001oogoo0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`
Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`3`
Ool001Moo`<000aoo`D000Aoo`@000Eoo`800?moo`Moo`<000aoo`D000Aoo`@000Eoo`800?5oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`
Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000_Ool50004Ool00`00Oomo
o`3oOolNOol50004Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03
001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007oo
Ool017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003a
Ool0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007oo
Ool0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00
ogooogooEWoo003oOoooOomFOol009Eoo`<00004Ool00000000HOol5003oOol5Ool3000017oo0000
00005goo1@00M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007oo
Oomoo`0000Uoo`H000Yoo`04001oogoo001dOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3o
Ool6Ool01@00Oomoogoo00006Woo00<007ooOol0M7oo002FOol01@00Oomoogoo00002Goo1P0037oo
00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007oo
Oomoo`0001]oo`03001oogoo0?moo`Ioo`05001oogooOol0000LOol00`00Oomoo`1bOol009Eoo`D0
01aoo`03001oogoo0?moo`Eoo`D001eoo`03001oogoo079oo`00]Woo00<007ooOol0ogoo8goo00D0
07ooOomoo`0007Aoo`00]7oo0`00ogoo9Woo0`00MGoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34464 L
.08255 .36146 L
.10458 .37747 L
.12507 .38948 L
.14415 .3977 L
.14918 .39935 L
.15465 .40089 L
.15946 .40203 L
.16457 .403 L
.16917 .40367 L
.17178 .40397 L
.17423 .40419 L
.17538 .40427 L
.17647 .40434 L
.17746 .40439 L
.17852 .40443 L
.17967 .40447 L
.18073 .40449 L
.182 .40451 L
.18314 .40451 L
.18435 .40449 L
.18547 .40447 L
.1867 .40443 L
.18802 .40437 L
.19071 .4042 L
.19317 .40398 L
.1979 .40341 L
.20239 .40267 L
.21236 .40038 L
.22321 .39688 L
.24299 .38793 L
.26399 .37513 L
.30174 .34542 L
.34195 .30838 L
.38063 .27275 L
.40028 .25637 L
.42177 .24074 L
.44253 .22855 L
.4614 .22041 L
.47149 .2173 L
.47611 .21618 L
.48101 .21521 L
.4835 .2148 L
.48624 .21441 L
.48876 .21412 L
.49106 .2139 L
.49378 .21371 L
.49527 .21363 L
.49596 .2136 L
Mistroke
.49669 .21358 L
.498 .21354 L
.49921 .21353 L
.49996 .21353 L
.50065 .21353 L
.50196 .21354 L
.50313 .21357 L
.50438 .21362 L
.50556 .21367 L
.50663 .21373 L
.50926 .21393 L
.51175 .21417 L
.5167 .21483 L
.52208 .2158 L
.53169 .21818 L
.54056 .22112 L
.55926 .22948 L
.57988 .24184 L
.62014 .27343 L
.65888 .30915 L
.70007 .347 L
.72063 .36393 L
.73974 .37763 L
.75939 .38917 L
.77791 .39729 L
.78775 .40041 L
.79293 .40171 L
.7984 .40282 L
.80302 .40353 L
.80546 .40384 L
.80809 .4041 L
.8105 .40428 L
.8127 .4044 L
.81375 .40444 L
.81491 .40448 L
.81599 .4045 L
.817 .40451 L
.81818 .40451 L
.81941 .40449 L
.82047 .40447 L
.82163 .40443 L
.82287 .40437 L
.82421 .4043 L
.82661 .40412 L
.82905 .40388 L
.83134 .40361 L
.83564 .40297 L
.84078 .40198 L
.84552 .40085 L
.85624 .39756 L
Mistroke
.87498 .38945 L
.89561 .37735 L
.93591 .34608 L
.97471 .31042 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .18702 L
.08255 .13407 L
.0932 .1108 L
.10458 .09023 L
.11009 .08202 L
.11531 .07535 L
.12038 .06993 L
.12507 .06587 L
.12951 .06288 L
.13178 .06168 L
.13422 .06064 L
.13549 .0602 L
.13666 .05985 L
.13784 .05956 L
.13895 .05935 L
.14022 .05917 L
.1409 .0591 L
.14161 .05905 L
.1423 .05902 L
.14295 .05902 L
.14415 .05905 L
.14531 .05915 L
.14656 .05932 L
.14773 .05953 L
.14881 .05979 L
.15143 .06061 L
.15392 .06167 L
.15886 .06457 L
.16423 .06889 L
.17383 .0796 L
.1827 .09278 L
.20137 .12989 L
.22197 .18329 L
.26217 .3099 L
.30086 .43193 L
.32051 .48363 L
.3309 .50645 L
.342 .52672 L
.35275 .54191 L
.35784 .54748 L
.36253 .55166 L
.36724 .55494 L
.36972 .55628 L
.37235 .55741 L
.37463 .55815 L
.37573 .55842 L
.37677 .55864 L
.37799 .55883 L
.37911 .55894 L
Mistroke
.38031 .55901 L
.38162 .55901 L
.38227 .55898 L
.38296 .55893 L
.38419 .55879 L
.38551 .55857 L
.38695 .55823 L
.38955 .55741 L
.39197 .55638 L
.39649 .55378 L
.40134 .55003 L
.40698 .54442 L
.41232 .53791 L
.42232 .52269 L
.44227 .48156 L
.4607 .43291 L
.50002 .30895 L
.53782 .18936 L
.55884 .13385 L
.56803 .11355 L
.57808 .09466 L
.58722 .08075 L
.59696 .06956 L
.60236 .06505 L
.60726 .06204 L
.60962 .06095 L
.61086 .06047 L
.61218 .06004 L
.61333 .05973 L
.61459 .05945 L
.61574 .05925 L
.61682 .05913 L
.61808 .05904 L
.61871 .05902 L
.61941 .05902 L
.62065 .05907 L
.62181 .05918 L
.62248 .05927 L
.62318 .05939 L
.62443 .05965 L
.62578 .06 L
.62725 .06048 L
.62973 .0615 L
.63238 .06287 L
.63715 .06611 L
.64214 .07053 L
.64686 .07566 L
.6557 .08768 L
.67568 .12564 L
.69413 .17199 L
Mistroke
.7335 .29387 L
.77136 .41524 L
.79241 .47323 L
.81166 .51534 L
.82118 .53139 L
.8262 .53847 L
.83155 .5449 L
.8367 .54998 L
.84136 .55361 L
.84361 .55504 L
.84604 .55634 L
.84835 .55734 L
.85045 .55804 L
.85159 .55835 L
.85283 .55861 L
.85414 .55882 L
.85538 .55895 L
.85653 .55901 L
.85776 .55901 L
.85881 .55896 L
.85997 .55884 L
.86063 .55875 L
.86132 .55864 L
.86256 .55838 L
.86535 .55755 L
.86777 .55656 L
.87041 .5552 L
.87569 .55157 L
.88133 .5464 L
.89148 .5338 L
.90173 .51699 L
.91284 .49449 L
.933 .44391 L
.97393 .31646 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .27724 L
.10458 .24319 L
.14415 .21236 L
.18221 .18425 L
.22272 .1565 L
.26171 .13235 L
.30316 .10989 L
.34309 .09177 L
.3815 .07787 L
.40095 .07224 L
.42237 .06717 L
.44268 .06347 L
.45178 .06217 L
.46172 .06101 L
.4671 .06049 L
.4721 .06008 L
.47727 .05972 L
.48196 .05946 L
.48658 .05926 L
.4887 .05919 L
.49093 .05913 L
.49332 .05908 L
.49438 .05906 L
.49552 .05904 L
.49675 .05903 L
.49789 .05902 L
.49859 .05902 L
.49925 .05902 L
.50049 .05902 L
.50163 .05902 L
.50286 .05903 L
.50401 .05904 L
.50508 .05905 L
.50754 .05909 L
.51014 .05916 L
.51268 .05924 L
.51504 .05932 L
.5204 .05958 L
.5293 .06018 L
.53882 .06106 L
.54906 .06228 L
.56016 .06392 L
.58032 .06774 L
.62123 .07874 L
.66064 .0933 L
.69852 .11073 L
.73886 .13269 L
.77769 .15677 L
.81897 .18509 L
Mistroke
.85873 .21455 L
.89697 .24443 L
.93767 .27733 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33309 L
.10458 .35753 L
.14415 .37711 L
.18221 .39161 L
.20178 .39709 L
.21267 .39951 L
.22272 .40133 L
.23293 .40277 L
.23832 .40335 L
.24402 .40384 L
.24641 .40401 L
.24897 .40416 L
.25119 .40427 L
.25361 .40437 L
.25507 .40441 L
.25643 .40445 L
.25773 .40447 L
.2584 .40448 L
.25912 .40449 L
.25983 .4045 L
.26048 .4045 L
.26176 .40451 L
.26293 .40451 L
.26416 .4045 L
.26538 .40448 L
.26607 .40447 L
.26671 .40446 L
.26912 .4044 L
.27131 .40432 L
.27364 .40422 L
.27847 .40394 L
.2838 .40351 L
.29326 .40247 L
.30213 .40116 L
.32232 .39702 L
.34082 .39186 L
.38045 .37677 L
.41855 .35789 L
.45912 .33446 L
.49816 .31018 L
.53966 .28432 L
.57964 .26112 L
.61811 .24191 L
.63759 .23376 L
.65902 .22623 L
.67938 .2206 L
.69843 .21678 L
.70884 .2153 L
.71396 .21473 L
Mistroke
.71872 .2143 L
.72301 .214 L
.72758 .21376 L
.7302 .21366 L
.73148 .21362 L
.73266 .21359 L
.73371 .21357 L
.73487 .21355 L
.73603 .21353 L
.73725 .21353 L
.73856 .21353 L
.73977 .21353 L
.7404 .21354 L
.7411 .21354 L
.74251 .21357 L
.74375 .21359 L
.74508 .21363 L
.74748 .21371 L
.74985 .21381 L
.75235 .21395 L
.7568 .21425 L
.76198 .21471 L
.7668 .21523 L
.77773 .21677 L
.78828 .21871 L
.79823 .22094 L
.81683 .22612 L
.85534 .2407 L
.89632 .26099 L
.93577 .28385 L
.97371 .30745 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`0FOol6001YOol5001VOol003Qoo`800?moobQoo`8001Eoo`80
00Ioo`03001oogoo06Aoo`8000Eoo`03001oogoo06=oo`005goo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool04goo00<007ooOol01goo00<007ooOol0HWoo00<007ooOol01Woo00<007ooOol0HWoo000FOol0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo01=oo`03
001oogoo00Qoo`03001oogoo061oo`03001oogoo00Qoo`03001oogoo065oo`003Woo1P000Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000COol00`00Oomoo`0:Ool00`00Oomoo`1NOol0
0`00Oomoo`0:Ool00`00Oomoo`1POol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol04Goo00<007ooOol037oo00<007ooOol0G7oo00<007ooOol02goo00<007ooOol0
H7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo011oo`03001oogoo00eoo`03001o
ogoo05aoo`03001oogoo00aoo`03001oogoo05moo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`1JOol00`00Oomoo`0>Ool0
0`00Oomoo`1NOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo
0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000@Ool0
0`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0?Ool00`00Oomoo`1NOol001Moo`<000aoo`D0
00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo00ioo`03001o
ogoo015oo`03001oogoo05Qoo`03001oogoo011oo`03001oogoo05eoo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0
G7oo000hOol2003oOolXOol2000?Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol0
0`00Oomoo`1LOol003Qoo`03001oogoo0?moobMoo`03001oogoo00eoo`03001oogoo01Aoo`03001o
ogoo05Eoo`03001oogoo01=oo`03001oogoo05]oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
3Goo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol057oo00<007ooOol0Fgoo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomoo`1COol00`00Oomoo`0EOol0
0`00Oomoo`1JOol003Qoo`800?moobQoo`8000aoo`03001oogoo01Moo`03001oogoo059oo`03001o
ogoo01Moo`03001oogoo05Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol02goo00<007ooOol0
67oo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol0FGoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`1HOol0
03Qoo`800?moobQoo`8000]oo`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03001o
ogoo05Qoo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo1000
1Goo00<007ooOol02Woo00<007ooOol06Woo00<007ooOol0CWoo00<007ooOol06Woo00<007ooOol0
F7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo01]oo`03001o
ogoo04ioo`03001oogoo01]oo`03001oogoo05Moo`005Woo1P000Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo0?moo`Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`09Ool00`00Oomoo`0LOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`1GOol0
01ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<0
07ooOol00Woo0P002Woo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol0
Egoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000ao
o`@000Eoo`03001oogoo00Qoo`03001oogoo01ioo`03001oogoo04]oo`03001oogoo01eoo`03001o
ogoo05Ioo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0NOol00`00Oomoo`1:Ool0
0`00Oomoo`0NOol00`00Oomoo`1FOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00
Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
7Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000OOol3000=Ool40005Ool2003o
Ool?Ool3000=Ool40005Ool20008Ool00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol0
0`00Oomoo`1EOol003Qoo`03001oogoo0?moobMoo`03001oogoo00Moo`03001oogoo021oo`03001o
ogoo04Qoo`03001oogoo021oo`03001oogoo05Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
1goo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol087oo00<007ooOol0EGoo000hOol2003o
OolXOol20007Ool00`00Oomoo`0ROol00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`1DOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo04Ioo`03001o
ogoo029oo`03001oogoo05Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol01Woo00<007ooOol0
8Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol0E7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`06Ool00`00Oomoo`0SOol00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`1COol0
03Qoo`800?moobQoo`8000Ioo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001o
ogoo05=oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol01Goo00<007ooOol097oo00<007ooOol0
A7oo00<007ooOol097oo00<007ooOol0Dgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`05Ool0
0`00Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`1BOol003Qoo`8006Moo`d0
0;=oo`8000Eoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo059oo`00
5goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0HGoo1@003Goo1000SWoo0`001Woo0P00
17oo1@0017oo10001Goo00<007ooOol017oo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol0
9Woo00<007ooOol0DWoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001o
ogoo009oo`03001oogoo05moo`8001Ioo`8008]oo`05001oogooOol00005Ool20005Ool01000Oomo
o`0027oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol09goo00<007ooOol0@Goo00<007oo
Ool09goo00<007ooOol0DGoo000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol0GGoo0P006Woo0P00PGoo1P000Woo00D007ooOomoo`0000eoo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo041oo`03001o
ogoo02Qoo`03001oogoo055oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo
009oo`8005aoo`8001ioo`8008Moo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool20004Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`1AOol001Io
o`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1JOol00`00Oomoo`0POol0
0`00Oomoo`24Ool01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol00goo00<0
07ooOol0:Goo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol0D7oo000FOol01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0F7oo0P0097oo0P00Q7oo00D007oo
Oomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo02Yoo`03
001oogoo03ioo`03001oogoo02Yoo`03001oogoo051oo`005Woo00D007ooOomoo`0000]oo`05001o
ogooOol00004Ool00`00Oomoo`06Ool2001HOol00`00Oomoo`0VOol00`00Oomoo`21Ool01@00Oomo
ogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000=oo`03001oogoo02Yoo`03001o
ogoo03ioo`03001oogoo02Yoo`03001oogoo051oo`005goo0`003Goo0`001Goo10001Goo00<007oo
Ool0EWoo00<007ooOol0:7oo00<007ooOol0PGoo0`003Goo0`001Goo10001Goo00<007ooOol00Woo
00<007ooOol0:goo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol0Cgoo000hOol00`00Oomo
o`1EOol00`00Oomoo`0ZOol00`00Oomoo`2QOol01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<0
07ooOol0;7oo00<007ooOol0Cgoo000hOol00`00Oomoo`0OOol30006Ool20004Ool5000HOol30005
Ool30006Ool3000HOol30006Ool200000goo001oo`02Ool3000JOol30006Ool20005Ool3000QOol5
0019Ool01@00Oomoogoo00007Goo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`0047oo00<0
07ooOol01Goo0`001Woo0P001Goo0`0057oo00<007ooOol00Woo0`001Woo0P001Goo0`008Goo1@00
57oo000hOol2000OOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol0
0003Ool01000Ool000001goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`80009oo`03001oo`00
00=oo`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00008Woo00<007oo
Ool0BGoo0P000Woo00<007ooOol06Woo00D007ooOomoo`0000Eoo`8000Eoo`800003Ool007oo01Io
o`05001oogooOol00005Ool20007Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool01@00Oomoogoo0000
1Goo0P0017oo00D007ooOomoo`0001Aoo`04001oogoo0003Ool00`00Oomoo`03Ool20004Ool01@00
Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<0
07ooOol05goo00D007ooOomoo`00009oo`03001oogoo00Ioo`D001Moo`05001oogooOol0000:Ool2
0003Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uo
o`04001oogoo000MOol01@00Oomoogoo00003Goo0P0067oo00D007ooOomoo`0000]oo`D000moo`03
001oogoo00Eoo`05001oogooOol0000;Ool01@00Oomoogoo000057oo00@007ooOol000=oo`03001o
ogoo00Uoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogoo
Ool0000>Ool00`00Oomoo`0FOol01`00Oomoogoo001oo`0000Uoo`04001oogoo000HOol01@00Oomo
ogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<0
07ooOol0BGoo00@007ooOol001eoo`05001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo
00002goo00@007ooOol0011oo`03001oogoo00Eoo`05001oogooOol0000;Ool01@00Oomoogoo0000
57oo00@007ooOol000=oo`03001oogoo00Uoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qo
o`03001oogoo01ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol01000Oomoogoo0P002goo00<0
07oo000067oo00D007ooOomoo`0000]oo`@001Uoo`05001oogooOol0000<Ool3000SOol00`00Oomo
o`19Ool01000Oomoo`007Goo00D007ooOomoo`0000ioo`8001Moo`05001oogooOol0000<Ool00`00
Ool0000@Ool00`00Oomoo`05Ool01@00Oomoogoo00002goo10005Woo00<007oo00000goo00<007oo
Ool02Woo0`008goo00<007ooOol057oo000hOol2000OOol01@00Oomoogoo00003goo00<007ooOol0
5Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool01000Oomoo`006Goo
00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool3000NOol01@00Oomoogoo
00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0000moo`03001oogoo00Ioo`05
001oogooOol0000;Ool00`00Oomoo`0GOol00`00Ool00003Ool00`00Oomoo`09Ool01@00Oomoogoo
00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Moo`03001oogoo008000eoo`8001Qoo`05001oogooOol0000<Ool01000Oomoo`0067oo00D0
07ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Ool0000NOol01@00Oomo
ogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000=Ool2000?Ool00`00Oomoo`06Ool0
1@00Oomoogoo000037oo00<007ooOol05Woo00<007oo00000goo00<007ooOol02Goo00D007ooOomo
o`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07goo0`003Goo0`006Goo0`003goo00<007oo
Ool05goo0`003Woo100067oo0`003Goo0`008Goo0`00Bgoo00<007oo00007goo0`003Goo100067oo
0`003goo00<007ooOol03Goo00<007ooOol01goo0`003Woo0`005Woo00<007oo00000P003Goo0`00
8Goo0`005Woo000hOol2001<Ool00`00Oomoo`0nOol00`00Oomoo`2GOol2000dOol00`00Oomoo`0f
Ool00`00Oomoo`0bOol00`00Oomoo`1<Ool003Qoo`03001oogoo04Yoo`03001oogoo041oo`03001o
ogoo09Ioo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo00<007oo
Ool0BGoo00<007ooOol0@Woo00<007ooOol0UGoo0P00=7oo00<007ooOol0=Woo00<007ooOol0<Woo
00<007ooOol0C7oo000hOol00`00Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`2DOol00`00Oomo
o`0dOol00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`1;Ool0039oonT0041oonT0011oo`00
>7oo00<007oo000027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol01Goo00@007ooOol004]oo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo00@0
07ooOol004=oo`03001oogoo04aoo`03001oogoo041oo`03001oogoo04eoo`03001oogoo03Aoo`03
001oogoo03Aoo`03001oogoo03Eoo`03001oogoo03=oo`03001oogoo01Aoo`00>7oo0P000Woo00<0
07ooOol0?goo00<007ooOol0CWoo00<007ooOol0?Woo00<007ooOol0CWoo0P00=Woo00<007ooOol0
<Woo00<007ooOol0=Woo00<007ooOol0<goo00<007ooOol057oo000hOol00`00Oomoo`02Ool00`00
Oomoo`0lOol2001BOol00`00Oomoo`0lOol00`00Oomoo`1?Ool00`00Oomoo`0eOol00`00Oomoo`0b
Ool00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`0EOol003Qoo`03001oogoo00=oo`03001o
ogoo03Yoo`03001oogoo05=oo`03001oogoo03Yoo`03001oogoo051oo`03001oogoo03Eoo`03001o
ogoo039oo`03001oogoo03Moo`03001oogoo035oo`03001oogoo01Eoo`00>7oo00<007ooOol017oo
00<007ooOol0>7oo00<007ooOol0EGoo00<007ooOol0>7oo00<007ooOol0DGoo00<007ooOol0=Woo
00<007ooOol0<7oo00<007ooOol0>7oo00<007ooOol0<Goo00<007ooOol05Goo000hOol20006Ool0
0`00Oomoo`0fOol00`00Oomoo`1GOol00`00Oomoo`0fOol00`00Oomoo`1BOol2000gOol00`00Oomo
o`0`Ool00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`0FOol003Qoo`03001oogoo00Ioo`80
03Aoo`8005]oo`03001oogoo03=oo`8005Eoo`03001oogoo03Ioo`03001oogoo031oo`03001oogoo
03Uoo`03001oogoo02moo`03001oogoo01Ioo`00>7oo00<007ooOol027oo00<007ooOol0<7oo00<0
07ooOol0G7oo00<007ooOol0<Goo00<007ooOol0EGoo00<007ooOol0=goo00<007ooOol0;Woo00<0
07ooOol0>Woo00<007ooOol0;goo00<007ooOol05Woo000hOol00`00Oomoo`09Ool00`00Oomoo`0^
Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool00`00Oomoo`1FOol00`00Oomoo`0gOol00`00Oomoo`0^
Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`0GOol003Qoo`8000]oo`03001oogoo02ao
o`03001oogoo061oo`03001oogoo02eoo`03001oogoo05Moo`8003Qoo`03001oogoo02ioo`03001o
ogoo03]oo`03001oogoo02eoo`03001oogoo01Moo`00>7oo00<007ooOol02goo0P00:goo00<007oo
Ool0HWoo00<007ooOol0:goo00<007ooOol0F7oo00<007ooOol0>7oo00<007ooOol0;7oo00<007oo
Ool0?7oo00<007ooOol0;Goo00<007ooOol05goo000hOol00`00Oomoo`0=Ool00`00Oomoo`0WOol0
0`00Oomoo`1TOol2000ZOol00`00Oomoo`1IOol00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00Oomo
o`0lOol00`00Oomoo`0/Ool00`00Oomoo`0HOol003Qoo`8000moo`03001oogoo02Eoo`03001oogoo
06Moo`8002Moo`03001oogoo05Yoo`8003Uoo`03001oogoo02aoo`03001oogoo03eoo`03001oogoo
02]oo`03001oogoo01Qoo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol03goo00<0
07ooOol08Woo0P00K7oo00<007ooOol08goo00<007ooOol0>Woo0`001Woo0P0017oo1@0017oo1000
1Goo00<007ooOol0>Goo00<007ooOol0:Woo00<007ooOol0?Woo00<007ooOol0:goo00<007ooOol0
67oo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001o
ogoo011oo`80021oo`8006moo`80025oo`8003aoo`05001oogooOol00005Ool20005Ool01000Oomo
o`0027oo00<007ooOol00Woo00<007ooOol0>Goo00<007ooOol0:Woo00<007ooOol0?Woo00<007oo
Ool0:Woo00<007ooOol06Goo000FOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol04Woo0P007Goo00<007ooOol0LGoo0P0077oo0`00?Woo00D007ooOomoo`0000eo
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo03Uoo`03001oogoo02Yoo`03001oogoo03mo
o`03001oogoo02Uoo`03001oogoo01Uoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`8001Eoo`8001Uoo`8007Ioo`8001Qoo`80045oo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool2000kOol00`00Oomoo`0YOol00`00Oomoo`0oOol00`00Oomoo`0Y
Ool00`00Oomoo`0IOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomo
o`0FOol3000COol3001jOol3000COol20013Ool01@00Oomoogoo00003goo00<007ooOol00Woo1000
1Goo00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol0@7oo00<007ooOol0:7oo00<007ooOol0
6Woo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol06Goo
00<007ooOol03Woo0P00P7oo0P003goo0P00AGoo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo03Yoo`03001oogoo02Qoo`03001oogoo045oo`03001oogoo02Moo`03
001oogoo01Yoo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2
000KOol4000:Ool20024Ool2000:Ool30017Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Ao
o`03001oogoo00Ioo`8003aoo`03001oogoo02Moo`03001oogoo045oo`03001oogoo02Moo`03001o
ogoo01Yoo`005goo0`003Goo0`001Goo10001Goo00<007ooOol07Woo2P00R7oo2P00Bgoo0`003Goo
0`001Goo10001Goo00<007ooOol0>goo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo
00<007ooOol06goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0kOol00`00Oomoo`0VOol00`00
Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`0KOol003Qoo`03001oogoo0?moobMoo`03001oogoo
03aoo`03001oogoo02Eoo`03001oogoo04=oo`03001oogoo02Eoo`03001oogoo01]oo`00>7oo0P00
ogoo:7oo0P00?Goo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol077oo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0lOol00`00Oomoo`0TOol00`00Oomoo`15Ool00`00
Oomoo`0SOol00`00Oomoo`0LOol003Qoo`03001oogoo0?moobMoo`03001oogoo03eoo`03001oogoo
02=oo`03001oogoo04Eoo`03001oogoo02=oo`03001oogoo01aoo`00>7oo0P00ogoo:7oo0P00?Woo
00<007ooOol08Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol07Goo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`0mOol00`00Oomoo`0ROol00`00Oomoo`17Ool00`00Oomoo`0QOol00`00
Oomoo`0MOol003Qoo`03001oogoo0?moobMoo`03001oogoo03ioo`03001oogoo025oo`03001oogoo
04Moo`03001oogoo025oo`03001oogoo01eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0?Woo
00<007ooOol087oo00<007ooOol0B7oo00<007ooOol087oo00<007ooOol07Woo000hOol2003oOolX
Ool2000oOol00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`0NOol001mo
o`<000Ioo`8000Eoo`@000Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo
03moo`03001oogoo01moo`03001oogoo04Uoo`03001oogoo01ioo`03001oogoo01moo`007Woo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol00005
Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00
Oomoo`0NOol00`00Oomoo`0OOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomo
o`3oOol=Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0@7oo00<007ooOol07Goo
00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol07goo000NOol01@00Oomoogoo000047oo00<0
07ooOol00Woo0P00ogoo3Woo00D007ooOomoo`00011oo`03001oogoo009oo`80045oo`03001oogoo
01eoo`03001oogoo04]oo`03001oogoo01aoo`03001oogoo021oo`007Woo00D007ooOomoo`0000ao
o`@000Eoo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool40005Ool00`00Oomoo`11Ool00`00
Oomoo`0KOol00`00Oomoo`1<Ool00`00Oomoo`0LOol00`00Oomoo`0POol001ioo`05001oogooOol0
000<Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo
00<007ooOol0@Goo00<007ooOol06goo00<007ooOol0CGoo00<007ooOol06goo00<007ooOol087oo
000NOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00ogoo3Woo00D007ooOomoo`0000aoo`03
001oogoo00Ioo`80049oo`03001oogoo01]oo`03001oogoo04eoo`03001oogoo01Yoo`03001oogoo
025oo`007goo0`003Goo10001Goo00<007ooOol0ogoo3Woo0`003Goo10001Goo00<007ooOol0@Woo
00<007ooOol06Goo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol08Goo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`12Ool00`00Oomoo`0IOol00`00Oomoo`1?Ool00`00Oomoo`0IOol00`00
Oomoo`0QOol003Qoo`03001oogoo0?moobMoo`03001oogoo04=oo`03001oogoo01Moo`03001oogoo
051oo`03001oogoo01Qoo`03001oogoo029oo`00>7oo0P00ogoo:7oo0P00A7oo00<007ooOol05goo
00<007ooOol0DGoo00<007ooOol05goo00<007ooOol08Woo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`13Ool00`00Oomoo`0FOol00`00Oomoo`1BOol00`00Oomoo`0GOol00`00Oomoo`0ROol003Qo
o`03001oogoo0?moobMoo`03001oogoo04Aoo`03001oogoo01Aoo`03001oogoo05Aoo`03001oogoo
01Eoo`03001oogoo02=oo`00>7oo0P00ogoo:7oo0P00AGoo00<007ooOol057oo00<007ooOol0E7oo
00<007ooOol057oo00<007ooOol097oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`14Ool00`00
Oomoo`0COol00`00Oomoo`1EOol00`00Oomoo`0DOol00`00Oomoo`0TOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo04Eoo`03001oogoo019oo`03001oogoo05Ioo`03001oogoo019oo`03001oogoo
02Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0AWoo00<007ooOol047oo00<007ooOol0F7oo
00<007ooOol04Goo00<007ooOol09Goo000hOol2003oOolXOol20018Ool00`00Oomoo`0?Ool00`00
Oomoo`1IOol00`00Oomoo`0?Ool00`00Oomoo`0VOol001Moo`<000Ioo`8000Ioo`03001oogoo00Ao
o`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo
04Moo`03001oogoo00ioo`03001oogoo05]oo`03001oogoo00ioo`03001oogoo02Ioo`005Woo00D0
07ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05
001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`18Ool00`00
Oomoo`0=Ool00`00Oomoo`1KOol00`00Oomoo`0=Ool00`00Oomoo`0WOol001Ioo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol0B7oo00<007ooOol037oo00<007ooOol0GGoo
00<007ooOol037oo00<007ooOol09goo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80
04Yoo`03001oogoo00Yoo`03001oogoo05moo`03001oogoo00Yoo`03001oogoo02Qoo`005Woo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000>
Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`1:Ool00`00Oomoo`08Ool00`00Oomoo`1POol00`00
Oomoo`08Ool2000[Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0
0`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool0Bgoo00<007ooOol01Woo00<007ooOol0HWoo0P001goo00<007ooOol0:goo000FOol01@00Oomo
ogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;
Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00CGoo0`000goo0P00Igoo0P000goo0P00;Woo
000GOol3000<Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool3000<Ool50004Ool40005Ool00`00
Oomoo`1>Ool4001ZOol4000`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolX
Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo
00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`80
0?5oo`00;goo1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo000aOol00`00Oomo
o`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Ao
o`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo
000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo
0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3003oOolWOol3003iOol00?mo
oomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo0`00ogoo1goo0`0000Aoo`000000
01Uoo`<007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000Uoo`05001oogooOol0003oOol7Ool01@00
Oomoogoo00002Goo1P0037oo00<007ooOol0Lgoo002FOol01@00Oomoogoo000077oo00<007ooOol0
ogoo1Goo00D007ooOomoo`0001Qoo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000eoo`03001o
ogoo0?moo`Eoo`05001oogooOol00009Ool60009Ool01000Oomoo`00MGoo002FOol01@00Oomoogoo
00006Woo0P00ogoo27oo00D007ooOomoo`0001Uoo`03001oo`0007Eoo`00UGoo1@007Goo00<007oo
Ool0ogoo17oo1@006Woo00<007oo0000MGoo002cOol01@00Oomoogoo0000ogoo9Woo0P00MGoo002d
Ool3003oOolXOol00`00Oomoo`1cOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomF
Ool00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3o
OolWOol00`00Oomoo`3gOol002Ioo`H000Eoo`03001oogoo0?mooaaoo`H000Eoo`03001oogoo0?Mo
o`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`04
Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03
001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo
8Goo00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomo
o`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03
001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000h
Ool00`00Oomoo`1VOol<002dOol00`00Oomoo`3`Ool003Qoo`8005eoo`X000aoo`/00:Uoo`800?5o
o`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0Egoo1@008Goo1000Q7oo
0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo0000
1Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0Dgoo1000:Woo0`00P7oo00D0
07ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`003Woo
1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo055oo`80
035oo`<007Eoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2001@Ool2
000fOol3001jOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00lGoo000F
Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0C7oo0`00>goo0`00Mgoo
00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomo
o`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo04Uoo`<0045oo`<007Aoo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00Agoo0`00Agoo0`00LGoo00D007oo
Oomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Ao
o`@000Eoo`03001oogoo04Aoo`8004eoo`80071oo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1o
o`00>7oo00<007ooOol0@Goo0`00DGoo0P00Sgoo00<007ooOol0l7oo000hOol00`00Oomoo`0oOol2
001FOol2002=Ool00`00Oomoo`3`Ool003Qoo`8003ioo`8005Yoo`8008]oo`800?5oo`00>7oo00<0
07ooOol0>goo0P00GWoo0P00RGoo00<007ooOol0l7oo000hOol00`00Oomoo`0iOol2001ROol20027
Ool00`00Oomoo`3`Ool003Qoo`8003Qoo`8006Ioo`8008Eoo`800?5oo`00>7oo00<007ooOol0=Goo
0P00JWoo0P00Pgoo00<007ooOol0l7oo000hOol00`00Oomoo`0cOol2001^Ool20021Ool00`00Oomo
o`3`Ool003Qoo`03001oogoo039oo`03001oogoo071oo`03001oogoo07ioo`03001oogoo0?1oo`00
>7oo0P00<Goo0P00M7oo0P00OWoo0P00lGoo000OOol30006Ool20005Ool40005Ool00`00Oomoo`0_
Ool00`00Oomoo`1fOol00`00Oomoo`1ROol30006Ool20005Ool40005Ool00`00Oomoo`3`Ool001io
o`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool2001jOol2001QOol0
1@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0l7oo000FOol60002Ool01@00
Oomoogoo000047oo00<007ooOol00Woo0P00;Goo00<007ooOol0O7oo00<007ooOol0EWoo1P000Woo
00D007ooOomoo`00011oo`03001oogoo009oo`800?5oo`007Woo00D007ooOomoo`00011oo`03001o
ogoo009oo`03001oogoo02Yoo`80081oo`8005ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`0YOol00`00Oomoo`22
Ool00`00Oomoo`1KOol01@00Oomoogoo000037oo10001Goo00<007ooOol0l7oo000NOol01@00Oomo
ogoo000037oo00<007ooOol01Woo00<007ooOol09goo0P00QWoo00<007ooOol0FWoo00D007ooOomo
o`0000aoo`03001oogoo00Ioo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo
00Ioo`8002Moo`03001oogoo08Moo`8005Yoo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003a
Ool001moo`<000eoo`@000Eoo`03001oogoo02Aoo`8008aoo`03001oogoo05Qoo`<000eoo`@000Eo
o`03001oogoo0?1oo`00>7oo00<007ooOol08goo00<007ooOol0SGoo00<007ooOol0L7oo00<007oo
Ool0l7oo000hOol00`00Oomoo`0QOol2002AOol00`00Oomoo`1_Ool00`00Oomoo`3`Ool003Qoo`80
025oo`03001oogoo099oo`8006moo`800?5oo`00>7oo00<007ooOol07goo00<007ooOol0UGoo00<0
07ooOol0K7oo00<007ooOol0l7oo000hOol00`00Oomoo`0MOol2002IOol2001/Ool00`00Oomoo`3`
Ool003Qoo`8001eoo`03001oogoo09]oo`03001oogoo06Uoo`800?5oo`00>7oo00<007ooOol06goo
00<007ooOol0WGoo0P00JGoo00<007ooOol0l7oo000hOol00`00Oomoo`0JOol00`00Oomoo`2POol0
0`00Oomoo`1VOol00`00Oomoo`3`Ool003Qoo`03001oogoo01Qoo`800:Aoo`8006Ioo`03001oogoo
09eoo``004Moo`00>7oo0P0067oo00<007ooOol0YWoo00<007ooOol0Hgoo0P00V7oo1P0037oo1`00
@7oo000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`0FOol00`00Oomoo`2XOol00`00
Oomoo`11Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`2COol4000IOol4000lOol001Io
o`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol057oo
0P00[7oo0P00@7oo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`2?Ool4000QOol3000iOol000ioo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool2000DOol00`00Oomoo`2^Ool00`00Oomoo`0eOol60002Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo0P00SGoo0`00:7oo0`00=Woo000FOol01@00Oomo
ogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol0/7oo00<0
07ooOol0?7oo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo08Yo
o`8002ioo`<003=oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo
015oo`03001oogoo0;9oo`03001oogoo03]oo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005
Ool00`00Oomoo`28Ool2000cOol2000aOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`0?Ool2002fOol2000kOol01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol0QWoo0P00=goo0P00;goo000FOol01@00Oomoogoo00002goo
00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000moo`03001oogoo0;Qoo`03001oogoo03Qoo`05
001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00QGoo0P00>goo0P00;Goo
000GOol3000=Ool30005Ool40005Ool00`00Oomoo`0=Ool00`00Oomoo`2jOol00`00Oomoo`0hOol3
000=Ool30005Ool40005Ool00`00Oomoo`21Ool3000oOol2000[Ool003Qoo`03001oogoo00aoo`03
001oogoo011oo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<0
01Yoo`<000Ioo`8000Eoo`<001Aoo`03001oogoo00Yoo`D004Uoo`03001oogoo01moo`<000Ioo`80
00Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Eoo`<000Eoo`<001Uoo`<000Ioo`8000Eoo`<0
00moo`80011oo`D001Aoo`00>7oo0P002goo0P004Woo00D007ooOomoo`0000Eoo`8000Eoo`04001o
ogoo000GOol01@00Oomoogoo00001Goo0P001goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`80
00Aoo`05001oogooOol0000HOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Aoo`80
00aoo`03001oogoo04Uoo`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`005goo00D0
07ooOomoo`0000Eoo`8000Moo`03001oogoo01Ioo`05001oogooOol00002Ool200000goo00000004
Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000@Ool2000@
Ool00`00Oomoo`0DOol003Qoo`03001oogoo00Uoo`03001oogoo019oo`05001oogooOol0000=Ool0
0`00Oomoo`0GOol01@00Oomoogoo00002goo1@005goo00D007ooOomoo`0000]oo`05001oogooOol0
000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Ioo`03001oogoo00Uoo`03001oogoo04Uo
o`03001oogoo01ioo`05001oogooOol0000=Ool00`00Oomoo`0GOol01@00Oomoogoo00002goo1@00
5goo00@007ooOomoo`<000Uoo`05001oogooOol0000GOol01@00Oomoogoo00002goo00D007ooOomo
o`00019oo`8000ioo`03001oogoo01Aoo`00>7oo00<007ooOol027oo00<007ooOol04goo00D007oo
Oomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000Oomoo`0067oo00D007ooOomo
o`0000]oo`05001oogooOol0000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`03001o
ogoo00Qoo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000>Ool00`00Oomoo`0FOol0
1@00Oomoogoo00002goo00@007ooOol001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00005goo
00D007ooOomoo`0000]oo`05001oogooOol0000DOol2000<Ool00`00Oomoo`0DOol003Qoo`03001o
ogoo00Moo`03001oogoo01Aoo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo0000
37oo00<007oo000067oo00D007ooOomoo`0000]oo`@001Uoo`05001oogooOol0000<Ool3000IOol0
0`00Oomoo`07Ool00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003goo00<007ooOol0
5Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`03001oo`00008000]oo`@001Qoo`05001oogoo
Ool0000<Ool3000GOol00`00Oomoo`09Ool00`00Oomoo`0DOol003Qoo`8000Ioo`8001Moo`05001o
ogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomo
o`0000]oo`03001oogoo01Yoo`05001oogooOol0000;Ool01@00Oomoogoo00006Goo0P001goo00<0
07ooOol0BGoo0P007goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool0
0`00Ool0000HOol20002Ool00`00Oomoo`09Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D0
07ooOomoo`0001Moo`8000Uoo`03001oogoo01Aoo`00>7oo00<007ooOol017oo00<007ooOol05goo
00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00003Goo0P0067oo00D007oo
Oomoo`0000aoo`03001oogoo01Uoo`05001oogooOol0000;Ool01@00Oomoogoo00006goo00<007oo
Ool017oo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000]oo`05001oogooOol0000G
Ool01@00Oomoogoo00003Goo0P005goo0P000goo00<007ooOol02Woo00<007ooOol067oo00D007oo
Oomoo`0000]oo`05001oogooOol0000IOol20007Ool00`00Oomoo`0DOol003Qoo`03001oogoo00=o
o`03001oogoo01Uoo`<000eoo`<001Uoo`<000moo`03001oogoo01Moo`<000ioo`<001Uoo`<000eo
o`<001eoo`04001oogooOol3001;Ool00`00Oomoo`0OOol3000=Ool3000IOol3000?Ool00`00Oomo
o`0COol20002Ool3000>Ool3000HOol3000=Ool3000LOol00`00Oomoo`02Ool3000FOol003Qoo`04
001oogooOol2003BOol2001?Ool00`00Oomoo`1bOol00`00Oomoo`1NOol2000KOol003Qoo`800003
Ool007oo0=Eoo`03001oogoo04aoo`80075oo`8006=oo`03001oogoo01Qoo`00>7oo00<007oo0000
f7oo00<007ooOol0Bgoo00<007ooOol0Kgoo00<007ooOol0I7oo0P0067oo000hOol2003JOol00`00
Oomoo`1:Ool00`00Oomoo`1]Ool2001YOol00`00Oomoo`0EOol0039oonT0041oonT0011oo`00>7oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol0BGoo00<007oo000027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol01goo0P002Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol057oo000hOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0YOol0
0`00Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomoo`19Ool00`00Oomoo`02000WOol00`00Oomoo`0Y
Ool00`00Oomoo`0@Ool2000GOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0DOol003Qo
o`03001oogoo0?moobMoo`03001oogoo009oo`03001oogoo065oo`8008Qoo`00>7oo0P00ogoo:7oo
0P0017oo0P00H7oo00<007ooOol0R7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`05Ool00`00
Oomoo`1KOol2002;Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Ioo`8005Uoo`8008eoo`00
>7oo0P00ogoo:7oo0P002Goo0P00EGoo0P00Sgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0:
Ool2001BOol00`00Oomoo`2?Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00aoo`03001oogoo
04eoo`80099oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol03Goo0P00Bgoo0P00U7oo000hOol2
003oOolXOol2000@Ool20018Ool00`00Oomoo`2DOol003Qoo`03001oogoo0?moobMoo`03001oogoo
015oo`8004Aoo`8009Moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol04goo0P00@7oo0P00VGoo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0EOol2000kOol3002KOol003Qoo`800?moobQoo`80
01Qoo`8003Moo`8009ioo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo1Woo
0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol06Goo0P00<goo0P00X7oo000FOol01@00Oomo
ogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001o
ogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol06goo0`00;Goo
0`00XWoo000FOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P00ogoo1Woo
00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8001moo`<002Moo`<00:Eoo`00
5Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05
001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0QOol2000ROol3002X
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol08goo0`007Goo0P00Zgoo000FOol0
1@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007oo
Oomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo02Ioo`D001Eoo`<00:eoo`00
5Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00
Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8002aooaD00;1oo`005goo0`00
3Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo0`003Goo0`001Goo10001Goo00<007ooOol0l7oo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00
ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool001moo`<000Ioo`8000Eo
o`@000Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo0?1oo`007Woo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol00005
Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool00`00Oomo
o`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomo
ogoo000047oo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`00011oo`03001oogoo
009oo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?moo`eoo`05
001oogooOol0000<Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00Oomo
o`06Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0l7oo
000NOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00ogoo3Woo00D007ooOomoo`0000aoo`03
001oogoo00Ioo`800?5oo`007goo0`003Goo10001Goo00<007ooOol0ogoo3Woo0`003Goo10001Goo
00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`80
0?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool0
0`00Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3`Ool001Io
o`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0l7oo
000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?1oo`005Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomo
o`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo
00<007ooOol0l7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<0
07ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
0?1oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomo
o`3oOol5Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo
0?1oo`005goo0`0037oo1@0017oo10001Goo0P00ogoo1goo0`0037oo1@0017oo10001Goo0P00lGoo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo
000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol002moo`D000Aoo`03001o
ogoo0?mooaioo`D000Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo
00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00
Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`80
0?5oo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00
Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00nGoo
003oOoooOomFOol00?mooomooeIoo`00UGoo0`0000Aoo`00000001Qoo`D00?moo`Eoo`<00004Ool0
0000000GOol5001dOol009Ioo`05001oogooOol00009Ool6000<Ool00`00Oomoo`3oOol6Ool01@00
Oomoogoo00002Goo1P002Woo00@007ooOol007Aoo`00UWoo00D007ooOomoo`0001]oo`03001oogoo
0?moo`Ioo`05001oogooOol0000JOol00`00Oomoo`1dOol009Ioo`05001oogooOol00009Ool6000<
Ool00`00Oomoo`3oOol6Ool01@00Oomoogoo00002Goo1P0037oo00<007ooOol0Lgoo002FOol01@00
Oomoogoo00006goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001aoo`03001oogoo079oo`00UGoo
1@0077oo00<007ooOol0ogoo1Goo1@007Goo00<007ooOol0LWoo002fOol00`00Oomoo`3oOolSOol0
1@00Oomoogoo0000M7oo002dOol3003oOolVOol3001eOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00001\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .39054 L
.08255 .42901 L
.10458 .46566 L
.12507 .49313 L
.14415 .51195 L
.14918 .51573 L
.15465 .51925 L
.15946 .52185 L
.16457 .52408 L
.16917 .52561 L
.17178 .52629 L
.17423 .52679 L
.17538 .52698 L
.17647 .52713 L
.17746 .52725 L
.17852 .52735 L
.17967 .52744 L
.18073 .52749 L
.182 .52752 L
.18314 .52752 L
.18435 .52749 L
.18547 .52743 L
.1867 .52734 L
.18802 .5272 L
.19071 .52681 L
.19317 .52632 L
.1979 .525 L
.20239 .52332 L
.21236 .51808 L
.22321 .51006 L
.24299 .48958 L
.26399 .4603 L
.30174 .39232 L
.34195 .30755 L
.38063 .22603 L
.40028 .18854 L
.42177 .15278 L
.44253 .1249 L
.4614 .10626 L
.47149 .09915 L
.47611 .09659 L
.48101 .09436 L
.4835 .09342 L
.48624 .09253 L
.48876 .09186 L
.49106 .09136 L
.49378 .09092 L
.49527 .09075 L
.49596 .09068 L
Mistroke
.49669 .09063 L
.498 .09055 L
.49921 .09052 L
.49996 .09051 L
.50065 .09051 L
.50196 .09055 L
.50313 .09061 L
.50438 .09071 L
.50556 .09084 L
.50663 .09098 L
.50926 .09143 L
.51175 .09198 L
.5167 .09349 L
.52208 .0957 L
.53169 .10116 L
.54056 .10788 L
.55926 .12702 L
.57988 .1553 L
.62014 .22758 L
.65888 .30933 L
.70007 .39593 L
.72063 .43466 L
.73974 .46603 L
.75939 .49242 L
.77791 .511 L
.78775 .51815 L
.79293 .52112 L
.7984 .52365 L
.80302 .5253 L
.80546 .52599 L
.80809 .52659 L
.8105 .52701 L
.8127 .52728 L
.81375 .52738 L
.81491 .52746 L
.81599 .5275 L
.817 .52752 L
.81818 .52752 L
.81941 .52748 L
.82047 .52743 L
.82163 .52734 L
.82287 .52721 L
.82421 .52704 L
.82661 .52663 L
.82905 .52609 L
.83134 .52547 L
.83564 .524 L
.84078 .52173 L
.84552 .51915 L
.85624 .51163 L
Mistroke
.87498 .49308 L
.89561 .46538 L
.93591 .39382 L
.97471 .31223 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .15822 L
.08255 .09277 L
.0932 .064 L
.10458 .03858 L
.11009 .02843 L
.11531 .02019 L
.12038 .01349 L
.12507 .00848 L
.12951 .00478 L
.13178 .0033 L
.13422 .00201 L
.13549 .00146 L
.13666 .00103 L
.13784 .00068 L
.13895 .00041 L
.14022 .00019 L
.1409 .0001 L
.14161 4e-05 L
.1423 1e-05 L
.14295 0 L
.14415 5e-05 L
.14531 .00016 L
.14656 .00037 L
.14773 .00064 L
.14881 .00095 L
.15143 .00197 L
.15392 .00328 L
.15886 .00686 L
.16423 .01221 L
.17383 .02544 L
.1827 .04173 L
.20137 .08761 L
.22197 .15361 L
.26217 .31011 L
.30086 .46095 L
.32051 .52485 L
.3309 .55305 L
.342 .57811 L
.35275 .59689 L
.35784 .60377 L
.36253 .60895 L
.36724 .61299 L
.36972 .61465 L
.37235 .61605 L
.37463 .61696 L
.37573 .6173 L
.37677 .61756 L
.37799 .6178 L
.37911 .61794 L
Mistroke
.38031 .61802 L
.38162 .61802 L
.38227 .61799 L
.38296 .61793 L
.38419 .61775 L
.38551 .61748 L
.38695 .61707 L
.38955 .61605 L
.39197 .61478 L
.39649 .61156 L
.40134 .60693 L
.40698 .59999 L
.41232 .59194 L
.42232 .57313 L
.44227 .52229 L
.4607 .46216 L
.50002 .30893 L
.53782 .16112 L
.55884 .0925 L
.56803 .0674 L
.57808 .04406 L
.58722 .02686 L
.59696 .01303 L
.60236 .00746 L
.60726 .00373 L
.60962 .00239 L
.61086 .0018 L
.61218 .00127 L
.61333 .00088 L
.61459 .00053 L
.61574 .00029 L
.61682 .00013 L
.61808 3e-05 L
.61871 0 L
.61941 0 L
.62065 7e-05 L
.62181 .00021 L
.62248 .00032 L
.62318 .00046 L
.62443 .00078 L
.62578 .00122 L
.62725 .00181 L
.62973 .00306 L
.63238 .00477 L
.63715 .00877 L
.64214 .01424 L
.64686 .02058 L
.6557 .03543 L
.67568 .08235 L
.69413 .13964 L
Mistroke
.7335 .29029 L
.77136 .44032 L
.79241 .512 L
.81166 .56404 L
.82118 .58388 L
.8262 .59264 L
.83155 .60059 L
.8367 .60686 L
.84136 .61136 L
.84361 .61312 L
.84604 .61473 L
.84835 .61596 L
.85045 .61683 L
.85159 .61721 L
.85283 .61753 L
.85414 .61779 L
.85538 .61795 L
.85653 .61802 L
.85776 .61802 L
.85881 .61796 L
.85997 .61782 L
.86063 .61771 L
.86132 .61756 L
.86256 .61724 L
.86535 .61622 L
.86777 .615 L
.87041 .61331 L
.87569 .60883 L
.88133 .60244 L
.89148 .58686 L
.90173 .56608 L
.91284 .53828 L
.933 .47576 L
.97393 .31822 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28124 L
.10458 .25149 L
.14415 .22454 L
.18221 .19997 L
.22272 .17572 L
.26171 .15461 L
.30316 .13498 L
.34309 .11913 L
.3815 .10699 L
.40095 .10207 L
.42237 .09764 L
.44268 .0944 L
.45178 .09327 L
.46172 .09225 L
.4671 .09179 L
.4721 .09143 L
.47727 .09112 L
.48196 .0909 L
.48658 .09072 L
.4887 .09066 L
.49093 .09061 L
.49332 .09056 L
.49438 .09055 L
.49552 .09053 L
.49675 .09052 L
.49789 .09051 L
.49859 .09051 L
.49925 .09051 L
.50049 .09051 L
.50163 .09051 L
.50286 .09052 L
.50401 .09053 L
.50508 .09054 L
.50754 .09058 L
.51014 .09063 L
.51268 .0907 L
.51504 .09078 L
.5204 .091 L
.5293 .09153 L
.53882 .0923 L
.54906 .09336 L
.56016 .0948 L
.58032 .09813 L
.62123 .10775 L
.66064 .12047 L
.69852 .13571 L
.73886 .1549 L
.77769 .17595 L
.81897 .2007 L
Mistroke
.85873 .22645 L
.89697 .25256 L
.93767 .28133 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20178 .30902 L
.21267 .30902 L
.22272 .30902 L
.23293 .30902 L
.23832 .30902 L
.24402 .30902 L
.24641 .30902 L
.24897 .30902 L
.25119 .30902 L
.25361 .30902 L
.25507 .30902 L
.25643 .30902 L
.25773 .30902 L
.2584 .30902 L
.25912 .30902 L
.25983 .30902 L
.26048 .30902 L
.26176 .30902 L
.26293 .30902 L
.26416 .30902 L
.26538 .30902 L
.26607 .30902 L
.26671 .30902 L
.26912 .30902 L
.27131 .30902 L
.27364 .30902 L
.27847 .30902 L
.2838 .30902 L
.29326 .30902 L
.30213 .30902 L
.32232 .30902 L
.34082 .30902 L
.38045 .30902 L
.41855 .30902 L
.45912 .30902 L
.49816 .30902 L
.53966 .30902 L
.57964 .30902 L
.61811 .30902 L
.63759 .30902 L
.65902 .30902 L
.67938 .30902 L
.69843 .30902 L
.70884 .30902 L
.71396 .30902 L
Mistroke
.71872 .30902 L
.72301 .30902 L
.72758 .30902 L
.7302 .30902 L
.73148 .30902 L
.73266 .30902 L
.73371 .30902 L
.73487 .30902 L
.73603 .30902 L
.73725 .30902 L
.73856 .30902 L
.73977 .30902 L
.7404 .30902 L
.7411 .30902 L
.74251 .30902 L
.74375 .30902 L
.74508 .30902 L
.74748 .30902 L
.74985 .30902 L
.75235 .30902 L
.7568 .30902 L
.76198 .30902 L
.7668 .30902 L
.77773 .30902 L
.78828 .30902 L
.79823 .30902 L
.81683 .30902 L
.85534 .30902 L
.89632 .30902 L
.93577 .30902 L
.97371 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`8001Qoo`@006Yoo`@006Moo`00
<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol05Goo0`000Woo
0P00J7oo0P000goo0P00IGoo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04
Ool00`00Oomoo`0DOol00`00Oomoo`05Ool00`00Oomoo`1TOol00`00Oomoo`05Ool00`00Oomoo`1R
Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo01=oo`03
001oogoo00Moo`03001oogoo069oo`03001oogoo00Moo`03001oogoo065oo`00<Goo00<007ooOol0
17oo0P00ogoo8Goo00<007ooOol017oo0P0057oo00<007ooOol027oo00<007ooOol0H7oo00<007oo
Ool027oo00<007ooOol0HGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`0B
Ool00`00Oomoo`0:Ool00`00Oomoo`1NOol00`00Oomoo`0:Ool00`00Oomoo`1POol003Qoo`03001o
ogoo0?moobMoo`03001oogoo019oo`03001oogoo00]oo`03001oogoo05aoo`03001oogoo00]oo`03
001oogoo061oo`00>7oo0P00ogoo:7oo0P004Woo00<007ooOol037oo00<007ooOol0G7oo00<007oo
Ool037oo00<007ooOol0Ggoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0@Ool00`00Oomoo`0>
Ool00`00Oomoo`1JOol00`00Oomoo`0>Ool00`00Oomoo`1NOol003Qoo`03001oogoo0?moobMoo`03
001oogoo00moo`03001oogoo00moo`03001oogoo05Yoo`03001oogoo00ioo`03001oogoo05ioo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol03goo00<007ooOol047oo00<007ooOol0F7oo00<007oo
Ool047oo00<007ooOol0GGoo000hOol2003oOolXOol2000?Ool00`00Oomoo`0AOol00`00Oomoo`1H
Ool00`00Oomoo`0@Ool00`00Oomoo`1MOol003Qoo`03001oogoo0?moobMoo`03001oogoo00ioo`03
001oogoo019oo`03001oogoo05Ioo`03001oogoo019oo`03001oogoo05aoo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007oo
Ool0G7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0=Ool00`00Oomoo`0COol00`00Oomoo`1F
Ool00`00Oomoo`0COol00`00Oomoo`1KOol003Qoo`800?moobQoo`8000ioo`03001oogoo01Aoo`03
001oogoo05Aoo`03001oogoo01Aoo`03001oogoo05]oo`005goo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool03Goo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol057oo00<007ooOol0Fgoo000FOol0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00aoo`03
001oogoo01Ioo`03001oogoo05=oo`03001oogoo01Eoo`03001oogoo05Yoo`003Woo1P000Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000=Ool00`00Oomoo`0FOol00`00Oomoo`1BOol0
0`00Oomoo`0FOol00`00Oomoo`1JOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol02goo00<007ooOol05goo00<007ooOol0DWoo00<007ooOol05goo00<007ooOol0
FGoo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo00]oo`03001oogoo01Qoo`03001o
ogoo055oo`03001oogoo01Moo`03001oogoo05Uoo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo06Uoo`D009Ioo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0H
Ool00`00Oomoo`1IOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol0
1Woo0P00J7oo0P001Goo1000TWoo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomo
o`06Ool2000;Ool00`00Oomoo`0IOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`1HOol0
01Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo06Aoo`<000]oo`03001oogoo091oo`<000aoo`D0
00Aoo`@000Eoo`03001oogoo00Yoo`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03
001oogoo05Qoo`00>7oo00<007ooOol0Hgoo00<007ooOol03Goo0P00/Goo00<007ooOol02Woo00<0
07ooOol06Woo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol0F7oo000hOol2001SOol00`00
Oomoo`0@Ool00`00Oomoo`2^Ool2000:Ool00`00Oomoo`0KOol00`00Oomoo`1>Ool00`00Oomoo`0K
Ool00`00Oomoo`1GOol003Qoo`03001oogoo065oo`03001oogoo015oo`03001oogoo0:ioo`03001o
ogoo00Uoo`03001oogoo01aoo`03001oogoo04eoo`03001oogoo01]oo`03001oogoo05Moo`00>7oo
00<007ooOol0H7oo00<007ooOol04goo00<007ooOol0[Goo00<007ooOol02Goo00<007ooOol077oo
00<007ooOol0CGoo00<007ooOol06goo00<007ooOol0Egoo000hOol00`00Oomoo`1OOol00`00Oomo
o`0EOol00`00Oomoo`2/Ool00`00Oomoo`09Ool00`00Oomoo`0LOol00`00Oomoo`1<Ool00`00Oomo
o`0LOol00`00Oomoo`1GOol003Qoo`8005moo`03001oogoo01Moo`03001oogoo0:]oo`8000Uoo`03
001oogoo01ioo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo05Ioo`00>7oo00<007ooOol0
GWoo00<007ooOol067oo00<007ooOol0ZWoo00<007ooOol027oo00<007ooOol07Woo00<007ooOol0
Bgoo00<007ooOol07Goo00<007ooOol0EWoo000hOol00`00Oomoo`1MOol00`00Oomoo`0IOol00`00
Oomoo`2ZOol00`00Oomoo`08Ool00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00
Oomoo`1FOol003Qoo`8005eoo`03001oogoo01]oo`03001oogoo0:Uoo`8000Qoo`03001oogoo021o
o`03001oogoo04Uoo`03001oogoo01moo`03001oogoo05Eoo`007goo0`001Woo0P001Goo10001Goo
00<007ooOol0Fgoo00<007ooOol07Goo00<007ooOol0Sgoo0`001Woo0P001Goo10001Goo00<007oo
Ool01goo00<007ooOol087oo00<007ooOol0BGoo00<007ooOol07goo00<007ooOol0EGoo000NOol0
1@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0Fgoo00<007ooOol07Woo00<0
07ooOol0SGoo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo00Moo`03001o
ogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001oogoo05Eoo`005Woo1P000Woo00D007oo
Oomoo`00011oo`03001oogoo009oo`03001oogoo05Yoo`03001oogoo021oo`03001oogoo08Aoo`H0
009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0QOol00`00
Oomoo`17Ool00`00Oomoo`0POol00`00Oomoo`1EOol001ioo`05001oogooOol0000@Ool00`00Oomo
o`02Ool2001JOol00`00Oomoo`0ROol00`00Oomoo`2;Ool01@00Oomoogoo000047oo00<007ooOol0
0Woo0P001goo00<007ooOol08Woo00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol0E7oo000N
Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0FGoo00<007ooOol08Woo00<007ooOol0Rgoo
00D007ooOomoo`0000aoo`@000Eoo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo04Ioo`03
001oogoo029oo`03001oogoo05Aoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001o
ogoo05Qoo`03001oogoo02Aoo`03001oogoo08Yoo`05001oogooOol0000<Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`0ROol00`00Oomoo`16Ool00`00Oomoo`0ROol00`00Oomoo`1DOol0
01ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1GOol00`00Oomoo`0UOol00`00
Oomoo`2:Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol08goo
00<007ooOol0AGoo00<007ooOol08Woo00<007ooOol0E7oo000OOol3000=Ool40005Ool2001HOol0
0`00Oomoo`0VOol00`00Oomoo`2:Ool3000=Ool40005Ool20006Ool00`00Oomoo`0TOol00`00Oomo
o`15Ool00`00Oomoo`0SOol00`00Oomoo`1COol003Qoo`03001oogoo05Ioo`03001oogoo02Moo`03
001oogoo0:=oo`03001oogoo00Eoo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03
001oogoo05=oo`00>7oo00<007ooOol0EWoo00<007ooOol0:7oo00<007ooOol0XWoo00<007ooOol0
1Goo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol0Dgoo000hOol2001F
Ool00`00Oomoo`0YOol00`00Oomoo`2ROol20006Ool00`00Oomoo`0UOol00`00Oomoo`13Ool00`00
Oomoo`0UOol00`00Oomoo`1BOol003Qoo`03001oogoo05Aoo`03001oogoo02]oo`03001oogoo0:5o
o`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03001oogoo059o
o`00>7oo00<007ooOol0E7oo00<007ooOol0;7oo00<007ooOol0X7oo00<007ooOol017oo00<007oo
Ool09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol0DWoo000hOol00`00Oomoo`1COol0
0`00Oomoo`0]Ool00`00Oomoo`2POol00`00Oomoo`04Ool00`00Oomoo`0VOol00`00Oomoo`12Ool0
0`00Oomoo`0VOol00`00Oomoo`1BOol003Qoo`8005Aoo`03001oogoo02ioo`03001oogoo09moo`80
00Eoo`03001oogoo02Moo`03001oogoo045oo`03001oogoo02Moo`03001oogoo055oo`00>7oo00<0
07ooOol0DWoo00<007ooOol0;goo00<007ooOol0Wgoo00<007ooOol00goo00<007ooOol0:7oo00<0
07ooOol0@7oo00<007ooOol0:7oo00<007ooOol0DGoo000hOol00`00Oomoo`1BOol00`00Oomoo`0`
Ool00`00Oomoo`2NOol00`00Oomoo`03Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0X
Ool00`00Oomoo`1AOol003Qoo`8005=oo`03001oogoo031oo`03001oogoo09ioo`8000Aoo`03001o
ogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo055oo`005goo0`001Woo0P0017oo
1@0017oo10001Goo00<007ooOol0DGoo00<007ooOol0<Woo00<007ooOol0O7oo0`001Woo0P0017oo
1@0017oo10001Goo00<007ooOol00goo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0:Goo
00<007ooOol0D7oo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo
009oo`03001oogoo055oo`03001oogoo039oo`03001oogoo07]oo`05001oogooOol00005Ool20005
Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0:Woo00<007ooOol0
?Woo00<007ooOol0:Woo00<007ooOol0D7oo000>Ool60002Ool01@00Oomoogoo00003Goo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol0D7oo00<007ooOol0=7oo00<007ooOol0LWoo1P000Woo
00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo
02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo051oo`005Woo00D007ooOomoo`0000io
o`03001oogoo00Moo`03001oogoo009oo`80055oo`03001oogoo03Aoo`03001oogoo07Yoo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`0ZOol00`00Oomo
o`0nOol00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02
Ool40005Ool00`00Oomoo`1?Ool00`00Oomoo`0fOol00`00Oomoo`1iOol01@00Oomoogoo00003goo
00<007ooOol00Woo10001Goo00D007ooOomoo`0002ioo`03001oogoo03eoo`03001oogoo02]oo`03
001oogoo04moo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo04moo`03001oogoo03Ioo`03001oogoo07Uoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0
Cgoo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8004moo`03
001oogoo03Qoo`03001oogoo07Qoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P000Woo00<007ooOol0;7oo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo
000GOol3000=Ool30005Ool40005Ool00`00Oomoo`1>Ool00`00Oomoo`0hOol00`00Oomoo`1iOol3
000=Ool30005Ool40005Ool01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<0
07ooOol0Cgoo000hOol00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00Oomoo`2IOol01000Oomoo`00
<7oo00<007ooOol0>goo00<007ooOol0;Goo00<007ooOol0CWoo000hOol00`00Oomoo`0OOol30006
Ool20004Ool5000HOol30006Ool20006Ool3000HOol30006Ool20005Ool4000IOol30006Ool20005
Ool3000QOol50019Ool01000Oomoo`007Woo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`00
3goo00<007ooOol01Woo0`001Woo0P001Goo0`005Goo00@007ooOomoo`<000Ioo`8000Eoo`<0025o
o`D001Aoo`00>7oo0P007goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Ool0
07oo00001Goo0P001goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`04001oogooOol2
000GOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo04Uoo`800003
Ool007oo01aoo`05001oogooOol00005Ool20005Ool01000Ool000005goo00D007ooOomoo`0000Eo
o`8000Moo`03001oogoo00ioo`03001oogoo00Eoo`05001oogooOol00005Ool20004Ool01@00Oomo
ogoo000057oo00@007ooOol000=oo`03001oogoo00=oo`8000Aoo`05001oogooOol0000ROol00`00
Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogooOol0000=Ool00`00Oomoo`0GOol01@00Ool0
07oo00002goo1@005goo00D007ooOomoo`0000]oo`04001oogooOol2000GOol01@00Oomoogoo0000
2goo00D007ooOomoo`00029oo`03001oogoo04Uoo`04001oogoo000MOol01@00Oomoogoo00003Goo
0P0067oo00D007ooOomoo`0000]oo`D000moo`03001oogoo00Eoo`05001oogooOol0000;Ool01@00
Oomoogoo00005Goo00<007oo00000goo00<007ooOol02Goo00D007ooOomoo`00029oo`03001oogoo
01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`80009oo`03001o
ogoo00Uoo`04001oogoo000HOol01@00Oomoogoo00002goo00L007ooOomoo`00Ool0000FOol01@00
Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03001oo`0001ioo`05001oogoo
Ool0000>Ool2000GOol01@00Oomoogoo00002goo00@007ooOol0011oo`03001oogoo00Eoo`05001o
ogooOol0000;Ool01@00Oomoogoo00005Goo00<007oo00000goo00<007ooOol02Goo00D007ooOomo
o`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000moo`03001oogoo
01Eoo`80009oo`03001oogoo00Yoo`03001oo`0001Qoo`05001oogooOol0000;Ool40002Ool00`00
Oomoo`0DOol01@00Oomoogoo000037oo0`008goo00<007ooOol0BGoo00<007oo00007Woo00D007oo
Oomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000?Ool00`00Oomoo`06
Ool01@00Oomoogoo00002goo10005Woo00<007oo00000goo00<007ooOol02Woo0`008goo00<007oo
Ool057oo000hOol2000OOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000ao
o`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`03Ool00`00Oomoo`0DOol01@00Oomo
ogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`<001ioo`05001oogooOol0000?Ool0
0`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo00003goo00<007ooOol01Woo00D007ooOomo
o`0000]oo`03001oogoo01Moo`03001oo`0000=oo`03001oogoo00Uoo`05001oogooOol0000ROol0
0`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo
00D007ooOomoo`0000eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`03Ool00`00Oomoo`0C
Ool01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03001oo`0001ioo`05
001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8000moo`03001oogoo
00Ioo`05001oogooOol0000<Ool00`00Oomoo`0GOol20003Ool00`00Oomoo`09Ool01@00Oomoogoo
00008Woo00<007ooOol057oo000hOol00`00Oomoo`0OOol3000=Ool3000GOol00`00Ool00002000?
Ool00`00Oomoo`0GOol3000>Ool30002Ool00`00Oomoo`0DOol3000=Ool3000QOol3001;Ool2000P
Ool3000=Ool300000goo001oo`0FOol3000?Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool3000>Ool3
000FOol00`00Ool00002000=Ool3000QOol3000FOol003Qoo`8004Yoo`03001oogoo049oo`03001o
ogoo09Eoo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo00<007oo
Ool0B7oo00<007ooOol0@goo00<007ooOol0UGoo0P00=7oo00<007ooOol0=Woo00<007ooOol0<Woo
00<007ooOol0C7oo000hOol00`00Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`2DOol2000dOol0
0`00Oomoo`0fOol00`00Oomoo`0cOol00`00Oomoo`1;Ool003Qoo`03001oogoo04Moo`03001oogoo
04Eoo`03001oogoo09Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo
04]oo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`04Ool01@00Oomoogoo
00002Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00D007ooOomoo`0000Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`8004]oo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo0P00
Agoo00<007ooOol0B7oo00<007ooOol0AGoo00<007ooOol0BWoo00<007ooOol0=7oo00<007ooOol0
=7oo00<007ooOol0=Goo00<007ooOol0<goo00<007ooOol057oo000hOol20016Ool00`00Oomoo`19
Ool00`00Oomoo`14Ool00`00Oomoo`1;Ool2000fOol00`00Oomoo`0bOol00`00Oomoo`0fOol00`00
Oomoo`0cOol00`00Oomoo`0DOol003Qoo`03001oo`0004Eoo`03001oogoo04Yoo`03001oogoo04=o
o`03001oogoo04]oo`03001oogoo03Eoo`03001oogoo039oo`03001oogoo03Ioo`03001oogoo03=o
o`03001oogoo01Aoo`00>7oo00<007oo0000A7oo00<007ooOol0Bgoo00<007ooOol0@Woo00<007oo
Ool0C7oo00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=Woo00<007ooOol0<Woo00<007oo
Ool05Goo000hOol01000Oomoo`00@goo00<007ooOol0C7oo00<007ooOol0@Goo00<007ooOol0C7oo
00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=goo00<007ooOol0<Goo00<007ooOol05Goo
000hOol200000goo001oo`11Ool00`00Oomoo`1=Ool00`00Oomoo`10Ool00`00Oomoo`1=Ool2000g
Ool00`00Oomoo`0`Ool00`00Oomoo`0hOol00`00Oomoo`0aOol00`00Oomoo`0EOol003Qoo`05001o
ogooOol00011Ool00`00Oomoo`1>Ool00`00Oomoo`0oOol00`00Oomoo`1=Ool00`00Oomoo`0fOol0
0`00Oomoo`0`Ool00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`0FOol003Qoo`05001oogoo
Ool00010Ool00`00Oomoo`1?Ool00`00Oomoo`0nOol00`00Oomoo`1>Ool00`00Oomoo`0fOol00`00
Oomoo`0`Ool00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`0FOol003Qoo`03001oogoo009o
o`03001oogoo03eoo`03001oogoo051oo`03001oogoo03eoo`03001oogoo04ioo`03001oogoo03Io
o`03001oogoo031oo`03001oogoo03Uoo`03001oogoo02moo`03001oogoo01Ioo`00>7oo0P000goo
00<007ooOol0?7oo00<007ooOol0DGoo00<007ooOol0?7oo00<007ooOol0Cgoo0P00>7oo00<007oo
Ool0;Woo00<007ooOol0>Woo00<007ooOol0;goo00<007ooOol05Woo000hOol00`00Oomoo`02Ool0
0`00Oomoo`0lOol00`00Oomoo`1BOol00`00Oomoo`0kOol00`00Oomoo`1?Ool00`00Oomoo`0gOol0
0`00Oomoo`0^Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`0GOol003Qoo`03001oogoo
00=oo`03001oogoo03Yoo`03001oogoo05=oo`03001oogoo03Yoo`03001oogoo051oo`03001oogoo
03Moo`03001oogoo02ioo`03001oogoo03]oo`03001oogoo02eoo`03001oogoo01Moo`00>7oo0P00
17oo00<007ooOol0>Woo00<007ooOol0E7oo00<007ooOol0>Goo00<007ooOol0D7oo0P00>7oo00<0
07ooOol0;Woo00<007ooOol0>goo00<007ooOol0;Goo00<007ooOol05goo000GOol30006Ool20004
Ool50004Ool40005Ool00`00Oomoo`04Ool00`00Oomoo`0hOol00`00Oomoo`1EOol00`00Oomoo`0h
Ool00`00Oomoo`0`Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`0hOol00`00Oomoo`0/
Ool00`00Oomoo`0lOol00`00Oomoo`0]Ool00`00Oomoo`0GOol001Ioo`05001oogooOol00005Ool2
0005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0>7oo00<007oo
Ool0EWoo00<007ooOol0=goo00<007ooOol0;goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo
0008Ool00`00Oomoo`02Ool00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00Oomoo`0lOol00`00Oomo
o`0/Ool00`00Oomoo`0HOol001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`1GOol00`00Oomoo`0fOol00`00Oomoo`0`
Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0>7oo00<007oo
Ool0;7oo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol067oo000FOol01@00Oomoogoo0000
3Woo00<007ooOol01goo00<007ooOol00Woo0P001Woo00<007ooOol0=Woo00<007ooOol0F7oo00<0
07ooOol0=Goo00<007ooOol0<7oo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`8003Yoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02]oo`03001oogoo01Qoo`005Woo
00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00Ioo`03001oogoo03Aoo`03
001oogoo05Uoo`03001oogoo03Aoo`03001oogoo035oo`05001oogooOol0000?Ool00`00Oomoo`02
Ool40005Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00
Oomoo`0IOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`0dOol00`00Oomoo`1JOol00`00Oomoo`0cOol00`00Oomoo`0aOol01@00Oomo
ogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0>Goo00<007ooOol0:Woo00<0
07ooOol0?Woo00<007ooOol0:Woo00<007ooOol06Goo000FOol01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`8000Qoo`03001oogoo039oo`03001oogoo05]oo`03001oogoo
039oo`03001oogoo039oo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo
0P00>Woo00<007ooOol0:Woo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol06Goo000GOol3
000=Ool30005Ool40005Ool00`00Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`1LOol00`00Oomo
o`0aOol00`00Oomoo`0cOol3000=Ool30005Ool40005Ool00`00Oomoo`0jOol00`00Oomoo`0XOol0
0`00Oomoo`10Ool00`00Oomoo`0YOol00`00Oomoo`0IOol003Qoo`03001oogoo00Qoo`03001oogoo
031oo`03001oogoo05eoo`03001oogoo031oo`03001oogoo05Eoo`03001oogoo03Yoo`03001oogoo
02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo01Yoo`00>7oo00<007ooOol02Goo00<0
07ooOol0;goo00<007ooOol0GWoo00<007ooOol0;goo00<007ooOol0EGoo00<007ooOol0>Woo00<0
07ooOol0:7oo00<007ooOol0@7oo00<007ooOol0:7oo00<007ooOol06Woo000hOol2000:Ool00`00
Oomoo`0^Ool00`00Oomoo`1OOol00`00Oomoo`0^Ool00`00Oomoo`1FOol2000kOol00`00Oomoo`0X
Ool00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`0JOol003Qoo`03001oogoo00Yoo`03001o
ogoo02eoo`03001oogoo05moo`03001oogoo02ioo`03001oogoo05Ioo`03001oogoo03]oo`03001o
ogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01]oo`00>7oo00<007ooOol02Woo
00<007ooOol0;7oo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0Egoo00<007ooOol0>goo
00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol06goo000hOol2000<Ool0
0`00Oomoo`0[Ool00`00Oomoo`1QOol00`00Oomoo`0[Ool00`00Oomoo`1HOol2000lOol00`00Oomo
o`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomoo`0KOol003Qoo`03001oogoo00]oo`03
001oogoo02Yoo`03001oogoo06=oo`03001oogoo02Yoo`03001oogoo05Qoo`03001oogoo03]oo`03
001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03001oogoo01]oo`00>7oo00<007ooOol0
37oo00<007ooOol0:Goo00<007ooOol0Hgoo00<007ooOol0:Goo00<007ooOol0FGoo00<007ooOol0
?7oo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol077oo000hOol00`00
Oomoo`0=Ool00`00Oomoo`0WOol00`00Oomoo`1UOol00`00Oomoo`0XOol00`00Oomoo`1IOol00`00
Oomoo`0lOol00`00Oomoo`0TOol00`00Oomoo`14Ool00`00Oomoo`0TOol00`00Oomoo`0LOol003Qo
o`8000ioo`03001oogoo02Moo`03001oogoo06Ioo`03001oogoo02Ioo`03001oogoo05Yoo`8003eo
o`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo01aoo`007goo0`001Woo
0P001Goo10001Goo00<007ooOol03Woo00<007ooOol09Goo00<007ooOol0J7oo00<007ooOol09Goo
00<007ooOol0@Goo0`001Woo0P001Goo10001Goo00<007ooOol0?7oo00<007ooOol097oo00<007oo
Ool0AGoo00<007ooOol08goo00<007ooOol077oo000NOol01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol00Woo00<007ooOol03Woo00<007ooOol09Goo00<007ooOol0J7oo00<007ooOol097oo00<0
07ooOol0@Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo03eoo`03001o
ogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo01eoo`007Woo00D007ooOomoo`00
011oo`03001oogoo009oo`03001oogoo00moo`03001oogoo02=oo`03001oogoo06Yoo`03001oogoo
02=oo`03001oogoo045oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0mOol00`00
Oomoo`0ROol00`00Oomoo`16Ool00`00Oomoo`0ROol00`00Oomoo`0MOol001ioo`05001oogooOol0
000@Ool00`00Oomoo`02Ool2000AOol00`00Oomoo`0ROol00`00Oomoo`1[Ool00`00Oomoo`0QOol0
0`00Oomoo`12Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00?Woo00<007ooOol08Woo00<0
07ooOol0Agoo00<007ooOol08Goo00<007ooOol07Goo000NOol01@00Oomoogoo000037oo10001Goo
00<007ooOol047oo00<007ooOol08Goo00<007ooOol0K7oo00<007ooOol08Goo00<007ooOol0@Woo
00D007ooOomoo`0000aoo`@000Eoo`03001oogoo03ioo`03001oogoo025oo`03001oogoo04Moo`03
001oogoo021oo`03001oogoo01ioo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001o
ogoo015oo`03001oogoo01moo`03001oogoo06ioo`03001oogoo01moo`03001oogoo04=oo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0nOol00`00Oomoo`0POol00`00Oomoo`18Ool0
0`00Oomoo`0POol00`00Oomoo`0NOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2000C
Ool00`00Oomoo`0MOol00`00Oomoo`1`Ool00`00Oomoo`0MOol00`00Oomoo`14Ool01@00Oomoogoo
000037oo00<007ooOol01Woo0P00?goo00<007ooOol087oo00<007ooOol0BGoo00<007ooOol07goo
00<007ooOol07Woo000OOol3000=Ool40005Ool00`00Oomoo`0BOol00`00Oomoo`0MOol00`00Oomo
o`1`Ool00`00Oomoo`0LOol00`00Oomoo`16Ool3000=Ool40005Ool00`00Oomoo`0oOol00`00Oomo
o`0OOol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`0NOol003Qoo`03001oogoo01=oo`03
001oogoo01]oo`03001oogoo079oo`03001oogoo01Yoo`03001oogoo061oo`03001oogoo03moo`03
001oogoo01ioo`03001oogoo04Yoo`03001oogoo01ioo`03001oogoo01moo`00>7oo00<007ooOol0
57oo00<007ooOol067oo0P00MWoo00<007ooOol067oo00<007ooOol0HGoo00<007ooOol0?goo00<0
07ooOol07Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol07goo000hOol2000FOol00`00
Oomoo`0FOol00`00Oomoo`1gOol00`00Oomoo`0GOol00`00Oomoo`1QOol20011Ool00`00Oomoo`0M
Ool00`00Oomoo`1;Ool00`00Oomoo`0MOol00`00Oomoo`0OOol003Qoo`03001oogoo01Ioo`03001o
ogoo01Aoo`03001oogoo07Uoo`03001oogoo01Eoo`03001oogoo069oo`03001oogoo041oo`03001o
ogoo01eoo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo01moo`00>7oo00<007ooOol05goo
00<007ooOol04Woo00<007ooOol0Ngoo00<007ooOol04goo00<007ooOol0Hgoo00<007ooOol0@7oo
00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol087oo000hOol2000IOol0
0`00Oomoo`0@Ool00`00Oomoo`1mOol00`00Oomoo`0AOol00`00Oomoo`1TOol20012Ool00`00Oomo
o`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`0POol003Qoo`03001oogoo01Uoo`03
001oogoo00ioo`03001oogoo07moo`8000moo`8006Moo`03001oogoo045oo`03001oogoo01]oo`03
001oogoo04eoo`03001oogoo01]oo`03001oogoo021oo`00>7oo00<007ooOol06Woo00<007ooOol0
2goo0P00Q7oo00<007ooOol02Woo0P00JGoo00<007ooOol0@Goo00<007ooOol06Woo00<007ooOol0
CWoo00<007ooOol06Woo00<007ooOol08Goo000hOol00`00Oomoo`0KOol30008Ool20027Ool00`00
Oomoo`08Ool00`00Oomoo`1YOol00`00Oomoo`12Ool00`00Oomoo`0IOol00`00Oomoo`1?Ool00`00
Oomoo`0IOol00`00Oomoo`0QOol003Qoo`8001moo`P008Yoo`X006aoo`8004=oo`03001oogoo01Uo
o`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025oo`005goo0`001Woo0P001Woo00<007oo
Ool017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<0
07ooOol0@Woo00<007ooOol067oo00<007ooOol0D7oo00<007ooOol06Goo00<007ooOol08Goo000F
Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04=o
o`03001oogoo01Moo`03001oogoo055oo`03001oogoo01Moo`03001oogoo029oo`005Woo00D007oo
Oomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`13Ool00`00Oomoo`0GOol00`00Oomo
o`1AOol00`00Oomoo`0GOol00`00Oomoo`0ROol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo0P00A7oo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05goo00<007ooOol08Woo000F
Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo04Aoo`03001oogoo01Eoo`03001oogoo05=o
o`03001oogoo01Eoo`03001oogoo02=oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`14Ool00`00Oomoo`0DOol00`00Oomoo`1DOol00`00Oomoo`0EOol00`00Oomo
o`0SOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo
1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20015Ool00`00Oomo
o`0DOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`0TOol001Moo`<000aoo`D000Aoo`@0
00Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo04Eoo`03001oogoo019o
o`03001oogoo05Ioo`03001oogoo01=oo`03001oogoo02Aoo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0AGoo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol09Goo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`16Ool00`00Oomoo`0AOol00`00Oomoo`1FOol00`00Oomo
o`0BOol00`00Oomoo`0UOol003Qoo`800?moobQoo`8004Moo`03001oogoo011oo`03001oogoo05Qo
o`03001oogoo011oo`03001oogoo02Ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Agoo00<0
07ooOol03goo00<007ooOol0FGoo00<007ooOol03goo00<007ooOol09Woo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`17Ool00`00Oomoo`0>Ool00`00Oomoo`1KOol00`00Oomoo`0>Ool00`00Oomo
o`0VOol003Qoo`800?moobQoo`8004Uoo`03001oogoo00eoo`03001oogoo05]oo`03001oogoo00eo
o`03001oogoo02Moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0B7oo00<007ooOol037oo00<0
07ooOol0GGoo00<007ooOol037oo00<007ooOol09goo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`18Ool00`00Oomoo`0<Ool00`00Oomoo`1MOol00`00Oomoo`0;Ool00`00Oomoo`0XOol003Qoo`03
001oogoo0?moobMoo`03001oogoo04Uoo`03001oogoo00Yoo`03001oogoo05moo`03001oogoo00Yo
o`03001oogoo02Qoo`00>7oo0P00ogoo:7oo0P00Bgoo00<007ooOol027oo00<007ooOol0H7oo00<0
07ooOol027oo0P00:goo000_Ool50004Ool00`00Oomoo`3oOolNOol50004Ool00`00Oomoo`1;Ool0
0`00Oomoo`06Ool00`00Oomoo`1ROol00`00Oomoo`06Ool00`00Oomoo`0[Ool0035oo`03001oogoo
00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo04aoo`03001oogoo00Aoo`03001o
ogoo06Aoo`8000Eoo`03001oogoo02aoo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol0
17oo0P00CWoo1P00J7oo1P00;goo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03
001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000a
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo
003oOoooOomFOol009Eoo`<00004Ool00000000HOol3003oOol7Ool3000017oo000000006Goo0`00
M7oo002FOol01@00Oomoogoo00002Goo1P002Goo00D007ooOomoo`000?moo`Moo`05001oogooOol0
0009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05001oogooOol0000LOol00`00Oomoo`3oOol5Ool0
1@00Oomoogoo000067oo1@00M7oo002FOol01@00Oomoogoo00002Goo1P003Goo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000Uoo`H000Uoo`04001oogoo001eOol009Ioo`05001oogooOol0000JOol2
003oOol8Ool01@00Oomoogoo00006Goo00<007oo0000MGoo002EOol5000MOol00`00Oomoo`3oOol4
Ool5000JOol00`00Ool0001eOol00;=oo`05001oogooOol0003oOolVOol2001eOol00;Aoo`<00?mo
obQoo`03001oogoo07=oo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo000_Ool5003oOolUOol5003gOol0035oo`03001oogoo0?moobMoo`03
001oogoo0?Moo`009Woo1P001Goo00<007ooOol0ogoo77oo1P001Goo00<007ooOol0mgoo000aOol0
0`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0
ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00
Oomoo`04Ool2003aOol002moo`<000Ioo`03001oogoo0?mooaioo`<000Ioo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`
Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000GOol30006Ool20006Ool0
0`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomoo`04Ool40005
Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007oo
Ool00Woo00<007ooOol0l7oo000>Ool60002Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol0o7oo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo
009oo`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol0
01Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomo
ogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00003goo
00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000]oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool2001POolJ002;Ool01@00Oomoogoo00002goo00D007ooOomoo`00
00Aoo`03001oogoo00Ioo`800?5oo`005goo0`0037oo1@0017oo10001Goo00<007ooOol0Egoo2000
6Woo2000Q7oo0`0037oo1@0017oo10001Goo00<007ooOol0l7oo000hOol00`00Oomoo`1BOol5000Z
Ool3002ROol00`00Oomoo`3`Ool003Qoo`03001oogoo04moo`<0039oo`<009moo`03001oogoo0?1o
o`00>7oo0P00CGoo0`00>7oo0`00W7oo0P00lGoo000hOol00`00Oomoo`19Ool3000nOol3002IOol0
0`00Oomoo`3`Ool003Qoo`03001oogoo04Ioo`<004Aoo`<009Ioo`03001oogoo0?1oo`00>7oo0P00
AGoo0P00BWoo0`00Tgoo0P00lGoo000hOol00`00Oomoo`11Ool3001?Ool3002@Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo03moo`8005Eoo`<008eoo`03001oogoo0?1oo`00>7oo00<007ooOol0?Goo
0P00FWoo0P00Rgoo00<007ooOol0l7oo000hOol2000kOol3001NOol20029Ool2003aOol001moo`<0
00Ioo`8000Eoo`@000Eoo`03001oogoo03Qoo`8006=oo`8006ioo`<000Ioo`8000Eoo`@000Eoo`03
001oogoo0?1oo`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo03Eo
o`<006Moo`8006]oo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool0
01Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000dOol2001/Ool2001QOol60002
Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomoogoo000047oo00<0
07ooOol00Woo00<007ooOol0<Goo0P00L7oo0P00Igoo00D007ooOomoo`00011oo`03001oogoo009o
o`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo02moo`8007Aoo`80
06Eoo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool00`00Oomoo`0^Ool00`00Oomoo`1fOol3001ROol01@00Oomoogoo000037oo00<0
07ooOol01Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00;Goo
0P00O7oo0P00H7oo00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?5oo`007goo0`003Goo1000
1Goo00<007ooOol0:Woo0P00P7oo0P00Ggoo0`003Goo10001Goo00<007ooOol0l7oo000hOol00`00
Oomoo`0YOol00`00Oomoo`22Ool00`00Oomoo`1eOol00`00Oomoo`3`Ool003Qoo`03001oogoo02Mo
o`8008Ioo`8007Eoo`03001oogoo0?1oo`00>7oo0P009goo00<007ooOol0R7oo00<007ooOol0LWoo
0P00lGoo000hOol00`00Oomoo`0TOol2002<Ool2001bOol00`00Oomoo`3`Ool003Qoo`03001oogoo
02=oo`03001oogoo08ioo`03001oogoo06moo`03001oogoo0?1oo`00>7oo0P008Woo0P00TWoo0P00
Kgoo0P00lGoo000hOol00`00Oomoo`0POol00`00Oomoo`2DOol00`00Oomoo`1/Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo01ioo`8009Qoo`8006aoo`03001oogoo0?1oo`00>7oo00<007ooOol07Goo
00<007ooOol0VWoo00<007ooOol0JGoo00<007ooOol0l7oo000hOol2000LOol2002NOol2001YOol2
003aOol001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo01Yoo`03001oogoo0:1oo`03
001oogoo04Eoo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomo
o`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`0HOol2002TOol20014
Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo0?1o
o`003Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8001Qoo`03
001oogoo0:Ioo`03001oogoo03Uoo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`0EOol2002ZOol20011Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007oo
Ool057oo00<007ooOol0[7oo00<007ooOol0?Woo00D007ooOomoo`0000moo`03001oogoo009oo`@0
00Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo019oo`800;1oo`8003ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P004Woo00<007ooOol0/Woo00<007ooOol0>goo00D007ooOomoo`0000]oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool2003aOol001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo00mo
o`800;Ioo`8003aoo`<000eoo`<000Eoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol03Woo
00<007ooOol03Woo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`0067oo0`001Woo0P001Goo
0`006Woo0`001Woo0P001Goo0`004Woo00<007ooOol037oo1@00BGoo00<007ooOol07goo0`001Woo
0P0017oo1@0067oo0`001Woo0P001Woo0`0067oo0`001Woo0P001Goo0`006Goo0`001Woo0P001Goo
0`008Goo1@0057oo000hOol2000=Ool2000@Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol0
01Moo`05001oogooOol00005Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo
00D007ooOomoo`0001Qoo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00004Woo0P003Woo
00<007ooOol0BGoo0P007goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomo
ogoo00001Goo0P001goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0
000GOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo
00<007ooOol02goo00<007ooOol047oo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogoo
Ool0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;
Ool01@00Oomoogoo000057oo00<007ooOol02goo00<007ooOol0BGoo00<007ooOol07Woo00D007oo
Oomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo
00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo
000hOol00`00Oomoo`0:Ool00`00Oomoo`0AOol01@00Oomoogoo00003Woo00<007ooOol05Woo00D0
07ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05
001oogooOol0000;Ool01@00Oomoogoo00005Goo00<007ooOol02Woo00<007ooOol0BGoo00<007oo
Ool07Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000Oomoo`00
67oo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00002goo00D007ooOomo
o`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol027oo0P0057oo00D007ooOomoo`0000moo`03
001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10006Goo
00D007ooOomoo`0000aoo`<001Moo`8000Yoo`03001oogoo04Uoo`03001oogoo01ioo`05001oogoo
Ool0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`00
00]oo`@001Qoo`05001oogooOol0000<Ool3000SOol00`00Oomoo`0DOol003Qoo`8000Qoo`03001o
ogoo01Aoo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo0000
67oo00D007ooOomoo`0000]oo`03001oogoo01Yoo`05001oogooOol0000;Ool01@00Oomoogoo0000
67oo00<007ooOol01goo00<007ooOol0BGoo0P007goo00D007ooOomoo`0000moo`03001oogoo01Eo
o`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo00<007ooOol06Goo00D0
07ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo00Eoo`80
01Moo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8001Qoo`05
001oogooOol0000<Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`0001Uoo`80
00Moo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo
00D007ooOomoo`0000eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`0HOol01@00Oomoogoo
00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol017oo00<007ooOol0
67oo0`003Goo0`006Goo0`003goo00<007ooOol05goo0`003Woo0`006Goo0`003Goo0`0077oo00<0
07ooOol00Woo0`00Bgoo00<007ooOol07goo0`003Goo0`006Goo0`003goo00<007ooOol05goo0`00
3Woo0`0067oo0`003Goo0`008Goo0`005Woo000hOol00`00Oomoo`02Ool2003@Ool2001@Ool00`00
Oomoo`3`Ool003Qoo`80009oo`03001oogoo0=9oo`03001oogoo04eoo`800?5oo`00>7oo00@007oo
00000=Ioo`8004eoo`03001oogoo0?1oo`00>7oo0P00fWoo00<007ooOol0BWoo00<007ooOol0l7oo
000bOooY0010OooY000@Ool003Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo04Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo00<007ooOol0
:Goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol0:Goo00<007ooOol0
BGoo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0
:Goo00<007ooOol057oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol2003oOolXOol2003aOol001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo
0?moo`Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo0?1oo`005Woo00D007oo
Oomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000=Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo
00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo0?1o
o`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eo
o`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05
001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003aOol001Moo`<000eoo`<000Eoo`@0
00Eoo`03001oogoo0?moo`Ioo`<000eoo`<000Eoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMo
o`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000OOol30006Ool20005Ool40005Ool00`00
Oomoo`3oOol>Ool30006Ool20005Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol00005
Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol00Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00ogoo
3Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?5oo`007Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomo
o`3`Ool001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo0000
37oo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007oo
Ool0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?1oo`007Woo00D007oo
Oomoo`0000aoo`03001oogoo00Ioo`800?moo`ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2
003aOol001moo`<000eoo`@000Eoo`03001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo0?1o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03
001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`80
0?moobQoo`800?5oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo
1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`005Woo00D007oo
Oomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo0P00lGoo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo
00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1o
o`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eo
o`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05
001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Moo`<0
00aoo`D000Aoo`@000Eoo`800?moo`Moo`<000aoo`D000Aoo`@000Eoo`800?5oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`80
0?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo
:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMo
o`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000_Ool50004Ool00`00Oomoo`3oOolNOol5
0004Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Ao
o`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<0
07ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03
001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000a
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo
003oOoooOomFOol009Eoo`<00004Ool00000000HOol5003oOol5Ool3000017oo000000005goo1@00
M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uo
o`H000Yoo`04001oogoo001dOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00
Oomoogoo00006Woo00<007ooOol0M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0
ogoo1Woo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001]o
o`03001oogoo0?moo`Ioo`05001oogooOol0000LOol00`00Oomoo`1bOol009Eoo`D001aoo`03001o
ogoo0?moo`Eoo`D001eoo`03001oogoo079oo`00]Woo00<007ooOol0ogoo8goo00D007ooOomoo`00
07Aoo`00]7oo0`00ogoo9Woo0`00MGoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .41866 L
.08255 .47041 L
.10458 .5197 L
.12507 .55664 L
.14415 .58196 L
.14918 .58704 L
.15465 .59178 L
.15946 .59528 L
.16457 .59827 L
.16917 .60034 L
.17178 .60124 L
.17423 .60192 L
.17538 .60217 L
.17647 .60238 L
.17746 .60254 L
.17852 .60268 L
.17967 .60279 L
.18073 .60286 L
.182 .60291 L
.18314 .6029 L
.18435 .60286 L
.18547 .60279 L
.1867 .60266 L
.18802 .60248 L
.19071 .60195 L
.19317 .60129 L
.1979 .59952 L
.20239 .59726 L
.21236 .5902 L
.22321 .57942 L
.24299 .55188 L
.26399 .51249 L
.30174 .42106 L
.34195 .30705 L
.38063 .1974 L
.40028 .14698 L
.42177 .09887 L
.44253 .06138 L
.4614 .03631 L
.47149 .02675 L
.47611 .0233 L
.48101 .0203 L
.4835 .01903 L
.48624 .01785 L
.48876 .01694 L
.49106 .01627 L
.49378 .01568 L
.49527 .01545 L
.49596 .01536 L
Mistroke
.49669 .01528 L
.498 .01518 L
.49921 .01513 L
.49996 .01512 L
.50065 .01513 L
.50196 .01518 L
.50313 .01527 L
.50438 .0154 L
.50556 .01557 L
.50663 .01576 L
.50926 .01636 L
.51175 .01711 L
.5167 .01913 L
.52208 .02211 L
.53169 .02945 L
.54056 .03849 L
.55926 .06424 L
.57988 .10227 L
.62014 .19948 L
.65888 .30944 L
.70007 .42592 L
.72063 .47801 L
.73974 .52019 L
.75939 .5557 L
.77791 .58068 L
.78775 .5903 L
.79293 .59429 L
.7984 .5977 L
.80302 .59991 L
.80546 .60084 L
.80809 .60165 L
.8105 .60221 L
.8127 .60258 L
.81375 .60271 L
.81491 .60282 L
.81599 .60288 L
.817 .60291 L
.81818 .6029 L
.81941 .60285 L
.82047 .60278 L
.82163 .60266 L
.82287 .60249 L
.82421 .60225 L
.82661 .6017 L
.82905 .60098 L
.83134 .60014 L
.83564 .59816 L
.84078 .59512 L
.84552 .59165 L
.85624 .58154 L
Mistroke
.87498 .55658 L
.89561 .51932 L
.93591 .42308 L
.97471 .31333 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .18702 L
.08255 .13407 L
.0932 .1108 L
.10458 .09023 L
.11009 .08202 L
.11531 .07535 L
.12038 .06993 L
.12507 .06587 L
.12951 .06288 L
.13178 .06168 L
.13422 .06064 L
.13549 .0602 L
.13666 .05985 L
.13784 .05956 L
.13895 .05935 L
.14022 .05917 L
.1409 .0591 L
.14161 .05905 L
.1423 .05902 L
.14295 .05902 L
.14415 .05905 L
.14531 .05915 L
.14656 .05932 L
.14773 .05953 L
.14881 .05979 L
.15143 .06061 L
.15392 .06167 L
.15886 .06457 L
.16423 .06889 L
.17383 .0796 L
.1827 .09278 L
.20137 .12989 L
.22197 .18329 L
.26217 .3099 L
.30086 .43193 L
.32051 .48363 L
.3309 .50645 L
.342 .52672 L
.35275 .54191 L
.35784 .54748 L
.36253 .55166 L
.36724 .55494 L
.36972 .55628 L
.37235 .55741 L
.37463 .55815 L
.37573 .55842 L
.37677 .55864 L
.37799 .55883 L
.37911 .55894 L
Mistroke
.38031 .55901 L
.38162 .55901 L
.38227 .55898 L
.38296 .55893 L
.38419 .55879 L
.38551 .55857 L
.38695 .55823 L
.38955 .55741 L
.39197 .55638 L
.39649 .55378 L
.40134 .55003 L
.40698 .54442 L
.41232 .53791 L
.42232 .52269 L
.44227 .48156 L
.4607 .43291 L
.50002 .30895 L
.53782 .18936 L
.55884 .13385 L
.56803 .11355 L
.57808 .09466 L
.58722 .08075 L
.59696 .06956 L
.60236 .06505 L
.60726 .06204 L
.60962 .06095 L
.61086 .06047 L
.61218 .06004 L
.61333 .05973 L
.61459 .05945 L
.61574 .05925 L
.61682 .05913 L
.61808 .05904 L
.61871 .05902 L
.61941 .05902 L
.62065 .05907 L
.62181 .05918 L
.62248 .05927 L
.62318 .05939 L
.62443 .05965 L
.62578 .06 L
.62725 .06048 L
.62973 .0615 L
.63238 .06287 L
.63715 .06611 L
.64214 .07053 L
.64686 .07566 L
.6557 .08768 L
.67568 .12564 L
.69413 .17199 L
Mistroke
.7335 .29387 L
.77136 .41524 L
.79241 .47323 L
.81166 .51534 L
.82118 .53139 L
.8262 .53847 L
.83155 .5449 L
.8367 .54998 L
.84136 .55361 L
.84361 .55504 L
.84604 .55634 L
.84835 .55734 L
.85045 .55804 L
.85159 .55835 L
.85283 .55861 L
.85414 .55882 L
.85538 .55895 L
.85653 .55901 L
.85776 .55901 L
.85881 .55896 L
.85997 .55884 L
.86063 .55875 L
.86132 .55864 L
.86256 .55838 L
.86535 .55755 L
.86777 .55656 L
.87041 .5552 L
.87569 .55157 L
.88133 .5464 L
.89148 .5338 L
.90173 .51699 L
.91284 .49449 L
.933 .44391 L
.97393 .31646 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28593 L
.10458 .26119 L
.14415 .23879 L
.18221 .21837 L
.22272 .19821 L
.26171 .18066 L
.30316 .16435 L
.34309 .15117 L
.3815 .14108 L
.40095 .13699 L
.42237 .1333 L
.44268 .13062 L
.45178 .12967 L
.46172 .12883 L
.4671 .12845 L
.4721 .12815 L
.47727 .12789 L
.48196 .1277 L
.48658 .12756 L
.4887 .12751 L
.49093 .12746 L
.49332 .12743 L
.49438 .12741 L
.49552 .1274 L
.49675 .12739 L
.49789 .12739 L
.49859 .12738 L
.49925 .12738 L
.50049 .12738 L
.50163 .12738 L
.50286 .12739 L
.50401 .1274 L
.50508 .12741 L
.50754 .12744 L
.51014 .12748 L
.51268 .12754 L
.51504 .1276 L
.5204 .12779 L
.5293 .12823 L
.53882 .12887 L
.54906 .12975 L
.56016 .13095 L
.58032 .13372 L
.62123 .14171 L
.66064 .15229 L
.69852 .16496 L
.73886 .18091 L
.77769 .1984 L
.81897 .21898 L
Mistroke
.85873 .24039 L
.89697 .26209 L
.93767 .286 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28494 L
.10458 .26051 L
.14415 .24092 L
.18221 .22642 L
.20178 .22094 L
.21267 .21852 L
.22272 .2167 L
.23293 .21526 L
.23832 .21468 L
.24402 .21419 L
.24641 .21402 L
.24897 .21387 L
.25119 .21376 L
.25361 .21367 L
.25507 .21362 L
.25643 .21359 L
.25773 .21356 L
.2584 .21355 L
.25912 .21354 L
.25983 .21353 L
.26048 .21353 L
.26176 .21353 L
.26293 .21353 L
.26416 .21354 L
.26538 .21355 L
.26607 .21356 L
.26671 .21357 L
.26912 .21363 L
.27131 .21371 L
.27364 .21381 L
.27847 .2141 L
.2838 .21452 L
.29326 .21556 L
.30213 .21687 L
.32232 .22101 L
.34082 .22618 L
.38045 .24127 L
.41855 .26014 L
.45912 .28357 L
.49816 .30786 L
.53966 .33372 L
.57964 .35691 L
.61811 .37612 L
.63759 .38428 L
.65902 .39181 L
.67938 .39743 L
.69843 .40126 L
.70884 .40273 L
.71396 .4033 L
Mistroke
.71872 .40373 L
.72301 .40404 L
.72758 .40428 L
.7302 .40438 L
.73148 .40442 L
.73266 .40445 L
.73371 .40447 L
.73487 .40449 L
.73603 .4045 L
.73725 .40451 L
.73856 .40451 L
.73977 .4045 L
.7404 .4045 L
.7411 .40449 L
.74251 .40447 L
.74375 .40444 L
.74508 .40441 L
.74748 .40433 L
.74985 .40422 L
.75235 .40409 L
.7568 .40378 L
.76198 .40332 L
.7668 .4028 L
.77773 .40126 L
.78828 .39932 L
.79823 .39709 L
.81683 .39191 L
.85534 .37734 L
.89632 .35704 L
.93577 .33418 L
.97371 .31058 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00JGoo1`00
/7oo00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`1WOol00`00Oomoo`05Ool3002[
Ool30006Ool00`00Oomoo`3`Ool003Qoo`03001oogoo06Eoo`8000]oo`03001oogoo0;5oo`03001o
ogoo0?1oo`00>7oo0P00IGoo00<007ooOol037oo00<007ooOol0/7oo0P00lGoo000hOol00`00Oomo
o`1SOol00`00Oomoo`0>Ool00`00Oomoo`2_Ool00`00Oomoo`3`Ool003Qoo`03001oogoo069oo`03
001oogoo011oo`03001oogoo0:ioo`03001oogoo0?1oo`00>7oo00<007ooOol0HWoo00<007ooOol0
47oo00<007ooOol0[Woo00<007ooOol0l7oo000hOol2001ROol00`00Oomoo`0BOol00`00Oomoo`2]
Ool2003aOol003Qoo`03001oogoo061oo`03001oogoo01Aoo`03001oogoo0:aoo`03001oogoo0?1o
o`00>7oo00<007ooOol0Ggoo00<007ooOol05Goo00<007ooOol0[7oo00<007ooOol0l7oo000hOol0
0`00Oomoo`1NOol00`00Oomoo`0GOol00`00Oomoo`2[Ool00`00Oomoo`0FOol6001YOol5001VOol0
03Qoo`8005moo`03001oogoo01Qoo`03001oogoo0:Yoo`8001Eoo`8000Ioo`03001oogoo06Aoo`80
00Eoo`03001oogoo06=oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0
GGoo00<007ooOol06Goo00<007ooOol0RGoo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<0
07ooOol04goo00<007ooOol01goo00<007ooOol0HWoo00<007ooOol01Woo00<007ooOol0HWoo000F
Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0GGoo
00<007ooOol06Woo00<007ooOol0Qgoo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo061oo`03001oogoo00Qoo`03
001oogoo065oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`8005eoo`03001oogoo01]oo`03001oogoo07moo`H0009oo`05001oogooOol0000>Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool2000COol00`00Oomoo`0:Ool00`00Oomoo`1NOol00`00Oomoo`0:Ool0
0`00Oomoo`1POol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`1KOol00`00Oomoo`0MOol00`00Oomoo`26Ool01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol04Goo00<007ooOol037oo00<007ooOol0G7oo00<007ooOol02goo
00<007ooOol0H7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0
Fgoo00<007ooOol07Woo00<007ooOol0QGoo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eo
o`03001oogoo011oo`03001oogoo00eoo`03001oogoo05aoo`03001oogoo00aoo`03001oogoo05mo
o`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo05Yoo`03
001oogoo01moo`03001oogoo08Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`1JOol00`00Oomoo`0>Ool00`00Oomoo`1N
Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00Fgoo00<0
07ooOol087oo00<007ooOol0Q7oo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomo
o`06Ool2000@Ool00`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0?Ool00`00Oomoo`1NOol0
01Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo05Uoo`03001oogoo025oo`03001oogoo08Eoo`<0
00aoo`D000Aoo`@000Eoo`03001oogoo00ioo`03001oogoo015oo`03001oogoo05Qoo`03001oogoo
011oo`03001oogoo05eoo`00>7oo00<007ooOol0FGoo00<007ooOol08Woo00<007ooOol0YGoo00<0
07ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0G7oo000h
Ool2001IOol00`00Oomoo`0SOol00`00Oomoo`2UOol2000?Ool00`00Oomoo`0BOol00`00Oomoo`1F
Ool00`00Oomoo`0BOol00`00Oomoo`1LOol003Qoo`03001oogoo05Qoo`03001oogoo02Aoo`03001o
ogoo0:Aoo`03001oogoo00eoo`03001oogoo01Aoo`03001oogoo05Eoo`03001oogoo01=oo`03001o
ogoo05]oo`00>7oo00<007ooOol0Egoo00<007ooOol09Goo00<007ooOol0Y7oo00<007ooOol03Goo
00<007ooOol057oo00<007ooOol0E7oo00<007ooOol057oo00<007ooOol0Fgoo000hOol00`00Oomo
o`1GOol00`00Oomoo`0UOol00`00Oomoo`2TOol00`00Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomo
o`1COol00`00Oomoo`0EOol00`00Oomoo`1JOol003Qoo`8005Moo`03001oogoo02Moo`03001oogoo
0:=oo`8000aoo`03001oogoo01Moo`03001oogoo059oo`03001oogoo01Moo`03001oogoo05Uoo`00
>7oo00<007ooOol0EWoo00<007ooOol09goo00<007ooOol0Xgoo00<007ooOol02goo00<007ooOol0
67oo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol0FGoo000hOol00`00Oomoo`1FOol00`00
Oomoo`0XOol00`00Oomoo`2ROol00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`1@Ool00`00
Oomoo`0IOol00`00Oomoo`1HOol003Qoo`8005Ioo`03001oogoo02Uoo`03001oogoo0:9oo`8000]o
o`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo05Qoo`007goo0`001Woo
0P001Goo10001Goo00<007ooOol0EGoo00<007ooOol0:Goo00<007ooOol0RGoo0`001Woo0P001Goo
10001Goo00<007ooOol02Woo00<007ooOol06Woo00<007ooOol0CWoo00<007ooOol06Woo00<007oo
Ool0F7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0E7oo00<0
07ooOol0:goo00<007ooOol0Qgoo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001o
ogoo00Uoo`03001oogoo01]oo`03001oogoo04ioo`03001oogoo01]oo`03001oogoo05Moo`005Woo
1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo05Aoo`03001oogoo02]oo`03
001oogoo07moo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00
Oomoo`0LOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`1GOol001ioo`05001oogooOol0
000@Ool00`00Oomoo`02Ool2001DOol00`00Oomoo`0]Ool00`00Oomoo`26Ool01@00Oomoogoo0000
47oo00<007ooOol00Woo0P002Woo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<0
07ooOol0Egoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0Dgoo00<007ooOol0;Goo
00<007ooOol0QWoo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo00Qoo`03001oogoo01ioo`03
001oogoo04]oo`03001oogoo01eoo`03001oogoo05Ioo`007Woo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`03001oogoo05=oo`03001oogoo02ioo`03001oogoo08Eoo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol0
0`00Oomoo`1FOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1BOol00`00
Oomoo`0_Ool00`00Oomoo`25Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol027oo
00<007ooOol07Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000OOol3000=Ool4
0005Ool2001COol00`00Oomoo`0_Ool00`00Oomoo`26Ool3000=Ool40005Ool20008Ool00`00Oomo
o`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`1EOol003Qoo`03001oogoo059oo`03
001oogoo031oo`03001oogoo09ioo`03001oogoo00Moo`03001oogoo021oo`03001oogoo04Qoo`03
001oogoo021oo`03001oogoo05Eoo`00>7oo00<007ooOol0DGoo00<007ooOol0<Goo00<007ooOol0
WWoo00<007ooOol01goo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol087oo00<007ooOol0
EGoo000hOol2001BOol00`00Oomoo`0bOol00`00Oomoo`2MOol20007Ool00`00Oomoo`0ROol00`00
Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`1DOol003Qoo`03001oogoo055oo`03001oogoo039o
o`03001oogoo09eoo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo04Ioo`03001oogoo029o
o`03001oogoo05Aoo`00>7oo00<007ooOol0D7oo00<007ooOol0<goo00<007ooOol0WGoo00<007oo
Ool01Woo00<007ooOol08Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol0E7oo000hOol0
0`00Oomoo`1@Ool00`00Oomoo`0dOol00`00Oomoo`2LOol00`00Oomoo`06Ool00`00Oomoo`0SOol0
0`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`1COol003Qoo`80055oo`03001oogoo03Aoo`03
001oogoo09aoo`8000Ioo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo
05=oo`00>7oo00<007ooOol0Cgoo00<007ooOol0=Woo00<007ooOol0Vgoo00<007ooOol01Goo00<0
07ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol0Dgoo000hOol00`00Oomoo`1?
Ool00`00Oomoo`0fOol00`00Oomoo`2KOol00`00Oomoo`05Ool00`00Oomoo`0UOol00`00Oomoo`13
Ool00`00Oomoo`0UOol00`00Oomoo`1BOol003Qoo`80051oo`03001oogoo03Ioo`03001oogoo09]o
o`8000Eoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo059oo`005goo
0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0CWoo00<007ooOol0>7oo00<007ooOol0NGoo
0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol017oo00<007ooOol09Woo00<007ooOol0@Woo
00<007ooOol09Woo00<007ooOol0DWoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol0
00Qoo`03001oogoo009oo`03001oogoo04ioo`03001oogoo03Qoo`03001oogoo07Qoo`05001oogoo
Ool00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
9goo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol0DGoo000>Ool60002Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0CWoo00<007ooOol0>7oo00<007oo
Ool0L7oo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo055oo`005Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8004ioo`03001oogoo03Yoo`03001o
ogoo07Moo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20004Ool00`00Oomo
o`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`1AOol001Ioo`05001oogooOol0000?
Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00Oomoo`1gOol01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol00goo00<007ooOol0:Goo00<007oo
Ool0?goo00<007ooOol0:Goo00<007ooOol0D7oo000FOol01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol0CGoo00<007ooOol0>Woo00<007ooOol0Mgoo00D007ooOomo
o`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo02Yoo`03001o
ogoo03ioo`03001oogoo02Yoo`03001oogoo051oo`005Woo00D007ooOomoo`0000]oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool2001=Ool00`00Oomoo`0lOol00`00Oomoo`1fOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000=oo`03001oogoo02Yoo`03001oogoo
03ioo`03001oogoo02Yoo`03001oogoo051oo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0
C7oo00<007ooOol0?7oo00<007ooOol0Mgoo0`003Goo0`001Goo10001Goo00<007ooOol00Woo00<0
07ooOol0:goo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol0Cgoo000hOol00`00Oomoo`1;
Ool00`00Oomoo`0mOol00`00Oomoo`2HOol01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007oo
Ool0;7oo00<007ooOol0Cgoo000hOol00`00Oomoo`0OOol30006Ool20004Ool5000HOol30006Ool2
0006Ool3000HOol30006Ool20005Ool30002Ool00`00Oomoo`0EOol30006Ool20005Ool3000QOol5
0019Ool01@00Oomoogoo00007Goo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`0047oo00<0
07ooOol01Goo0`001Woo0P001Goo0`0057oo00<007ooOol00Woo0`001Woo0P001Goo0`008Goo1@00
57oo000hOol2000OOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`80009oo`03001o
ogoo00=oo`8000Moo`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool01`00Oomoogoo001o
o`0001Ioo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo0P00
0Woo00<007ooOol06Woo00D007ooOomoo`0000Eoo`8000Eoo`800003Ool007oo01Ioo`05001oogoo
Ool00005Ool20007Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool01@00Oomoogoo00001Goo0P0017oo
00D007ooOomoo`0001Aoo`04001oogoo0003Ool00`00Oomoo`03Ool20004Ool01@00Oomoogoo0000
8Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol05goo
00D007ooOomoo`0000]oo`D001Moo`05001oogooOol0000;Ool01`00Oomoogoo001oo`0001Ioo`05
001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00@007ooOol001eoo`05001o
ogooOol0000=Ool2000HOol01@00Oomoogoo00002goo1@003goo00<007ooOol01Goo00D007ooOomo
o`0000]oo`05001oogooOol0000DOol01000Oomoo`000goo00<007ooOol02Goo00D007ooOomoo`00
029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo01Io
o`05001oogooOol0000;Ool01000Oomoo`0067oo00D007ooOomoo`0000]oo`05001oogooOol00002
Ool00`00Oomoo`0COol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`04
001oogoo000MOol01@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001o
ogoo000@Ool00`00Oomoo`05Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Aoo`04001oogoo
0003Ool00`00Oomoo`09Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0N
Ool01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05
001oogooOol0000;Ool40003Ool00`00Oomoo`0COol01@00Oomoogoo000037oo0`008goo00<007oo
Ool0BGoo00@007ooOol001eoo`05001oogooOol0000>Ool2000GOol01@00Oomoogoo000037oo00<0
07oo000047oo00<007ooOol01Goo00D007ooOomoo`0000]oo`@001Ioo`03001oo`0000=oo`03001o
ogoo00Yoo`<002=oo`03001oogoo01Aoo`00>7oo0P007goo00D007ooOomoo`0000moo`03001oogoo
01Aoo`8000=oo`03001oogoo00Yoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`04
Ool00`00Oomoo`0COol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`<0
01ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo00003goo
00<007ooOol01Woo00D007ooOomoo`0000]oo`03001oogoo01Moo`03001oo`0000=oo`03001oogoo
00Uoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogooOol0
000;Ool01@00Oomoogoo00005Woo0P000goo00<007ooOol02goo0P0067oo00D007ooOomoo`0000ao
o`03001oogoo00Aoo`03001oogoo019oo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<0
07ooOol0BGoo00<007oo00007Woo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomo
ogoo00003Goo0P003goo00<007ooOol01Woo00D007ooOomoo`0000aoo`03001oogoo01Ioo`03001o
o`0000=oo`03001oogoo00Uoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo
01moo`<000eoo`<001Moo`03001oo`00008000moo`03001oogoo01Moo`<000ioo`<000=oo`03001o
ogoo01=oo`<000eoo`<0025oo`<004]oo`03001oo`0001moo`<000eoo`@001Qoo`<000moo`03001o
ogoo00eoo`03001oogoo00Moo`<000ioo`<001Ioo`03001oo`00008000eoo`<0025oo`<001Ioo`00
>7oo0P00BGoo00<007ooOol0@goo00<007ooOol0UGoo0P00=7oo00<007ooOol0=Woo00<007ooOol0
<Woo00<007ooOol0C7oo000hOol00`00Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`2DOol2000d
Ool00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`1<Ool003Qoo`03001oogoo04Qoo`03001o
ogoo04Aoo`03001oogoo09Aoo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04ao
o`00>7oo00<007ooOol0Agoo00<007ooOol0AGoo00<007ooOol0U7oo00<007ooOol0=7oo00<007oo
Ool0=7oo00<007ooOol0=7oo00<007ooOol0Bgoo000bOooY0010OooY000@Ool003Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Aoo`05001oogooOol0000:Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool01@00Oomoogoo00001Woo00<007ooOol027oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo
0P00Bgoo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol057oo000hOol20017Ool00`00Oomoo`18Ool00`00Oomoo`15Ool00`00Oomo
o`1:Ool00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0eOol00`00Oomoo`0cOol00`00Oomo
o`0DOol003Qoo`8004Moo`03001oogoo04Qoo`03001oogoo04Aoo`03001oogoo04]oo`8003Ioo`03
001oogoo039oo`03001oogoo03Ioo`03001oogoo03=oo`03001oogoo01Aoo`00>7oo0P00AWoo00<0
07ooOol0BGoo00<007ooOol0A7oo00<007ooOol0Bgoo00<007ooOol0=Goo00<007ooOol0<Woo00<0
07ooOol0=Woo00<007ooOol0<Woo00<007ooOol05Goo000hOol00`00Ool00015Ool00`00Oomoo`1:
Ool00`00Oomoo`13Ool00`00Oomoo`1;Ool00`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomoo`0g
Ool00`00Oomoo`0aOol00`00Oomoo`0EOol003Qoo`03001oo`0004Eoo`03001oogoo04Yoo`03001o
ogoo049oo`03001oogoo04aoo`03001oogoo03Ioo`03001oogoo031oo`03001oogoo03Qoo`03001o
ogoo035oo`03001oogoo01Eoo`00>7oo0`00A7oo00<007ooOol0Bgoo00<007ooOol0@Woo00<007oo
Ool0C7oo0P00=goo00<007ooOol0<7oo00<007ooOol0>7oo00<007ooOol0<7oo00<007ooOol05Woo
000hOol01000Oomoo`00@goo00<007ooOol0C7oo00<007ooOol0@Goo00<007ooOol0C7oo00<007oo
Ool0=Woo00<007ooOol0<7oo00<007ooOol0>Goo00<007ooOol0;goo00<007ooOol05Woo000hOol0
1000Oomoo`00@Woo00<007ooOol0CGoo00<007ooOol0@7oo00<007ooOol0CGoo00<007ooOol0=goo
00<007ooOol0;Woo00<007ooOol0>Woo00<007ooOol0;goo00<007ooOol05Woo000hOol01000Oomo
o`00@Woo00<007ooOol0CWoo00<007ooOol0?goo00<007ooOol0CGoo00<007ooOol0=goo00<007oo
Ool0;Woo00<007ooOol0>Woo00<007ooOol0;Woo00<007ooOol05goo000hOol20002Ool00`00Oomo
o`0oOol00`00Oomoo`1>Ool00`00Oomoo`0oOol00`00Oomoo`1=Ool2000hOol00`00Oomoo`0^Ool0
0`00Oomoo`0kOol00`00Oomoo`0]Ool00`00Oomoo`0GOol003Qoo`05001oogooOol00010Ool00`00
Oomoo`1?Ool00`00Oomoo`0nOol00`00Oomoo`1>Ool00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00
Oomoo`0lOol00`00Oomoo`0]Ool00`00Oomoo`0GOol003Qoo`03001oogoo009oo`03001oogoo03eo
o`03001oogoo051oo`03001oogoo03eoo`03001oogoo04ioo`03001oogoo03Qoo`03001oogoo02ao
o`03001oogoo03aoo`03001oogoo02aoo`03001oogoo01Qoo`00>7oo0P000goo00<007ooOol0?Goo
00<007ooOol0D7oo00<007ooOol0?7oo00<007ooOol0Cgoo0P00>Goo00<007ooOol0;7oo00<007oo
Ool0?Goo00<007ooOol0:goo00<007ooOol067oo000GOol30006Ool20004Ool50004Ool40005Ool0
0`00Oomoo`02Ool00`00Oomoo`0lOol00`00Oomoo`1AOol00`00Oomoo`0lOol00`00Oomoo`0^Ool3
0006Ool20004Ool50004Ool40005Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0nOol0
0`00Oomoo`0[Ool00`00Oomoo`0HOol001Ioo`05001oogooOol00005Ool20005Ool01000Oomoo`00
27oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0>goo00<007ooOol0DWoo00<007ooOol0
>goo00<007ooOol0;Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02
Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00Oomoo`0I
Ool001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`0kOol00`00Oomoo`1BOol00`00Oomoo`0jOol00`00Oomoo`0^Ool01@00Oomoogoo0000
3Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0>Goo00<007ooOol0:Woo00<007ooOol0
?goo00<007ooOol0:Goo00<007ooOol06Goo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo0P0017oo00<007ooOol0>Woo00<007ooOol0Dgoo00<007ooOol0>Woo00<007oo
Ool0;Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8003]oo`03001oogoo
02Uoo`03001oogoo03moo`03001oogoo02Uoo`03001oogoo01Uoo`005Woo00D007ooOomoo`0000mo
o`03001oogoo009oo`@000Eoo`03001oogoo00Aoo`03001oogoo03Uoo`03001oogoo05Aoo`03001o
ogoo03Uoo`03001oogoo02ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomo
o`0jOol00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`0JOol001Ioo`05
001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`0h
Ool00`00Oomoo`1EOol00`00Oomoo`0hOol00`00Oomoo`0_Ool01@00Oomoogoo00003goo00<007oo
Ool00Woo00<007ooOol01Woo00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol0@Goo00<007oo
Ool09goo00<007ooOol06Woo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001o
ogoo00Ioo`8000Eoo`03001oogoo03Qoo`03001oogoo05Ioo`03001oogoo03Moo`03001oogoo02mo
o`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00?7oo00<007ooOol0
9goo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol06Woo000GOol3000=Ool30005Ool40005
Ool00`00Oomoo`05Ool00`00Oomoo`0gOol00`00Oomoo`1FOol00`00Oomoo`0gOol00`00Oomoo`0`
Ool3000=Ool30005Ool40005Ool00`00Oomoo`0kOol00`00Oomoo`0VOol00`00Oomoo`12Ool00`00
Oomoo`0VOol00`00Oomoo`0KOol003Qoo`03001oogoo00Eoo`03001oogoo03Ioo`03001oogoo05Mo
o`03001oogoo03Ioo`03001oogoo059oo`03001oogoo03]oo`03001oogoo02Ioo`03001oogoo04=o
o`03001oogoo02Eoo`03001oogoo01]oo`00>7oo00<007ooOol01Goo00<007ooOol0=Woo00<007oo
Ool0F7oo00<007ooOol0=Goo00<007ooOol0DWoo00<007ooOol0?7oo00<007ooOol09Goo00<007oo
Ool0@goo00<007ooOol09Goo00<007ooOol06goo000hOol20007Ool00`00Oomoo`0eOol00`00Oomo
o`1HOol00`00Oomoo`0eOol00`00Oomoo`1BOol2000mOol00`00Oomoo`0TOol00`00Oomoo`14Ool0
0`00Oomoo`0TOol00`00Oomoo`0LOol003Qoo`03001oogoo00Ioo`03001oogoo03Aoo`03001oogoo
05Uoo`03001oogoo03Aoo`03001oogoo05=oo`03001oogoo03aoo`03001oogoo02Aoo`03001oogoo
04Eoo`03001oogoo02=oo`03001oogoo01aoo`00>7oo00<007ooOol01goo00<007ooOol0<goo00<0
07ooOol0FWoo00<007ooOol0<goo00<007ooOol0Dgoo00<007ooOol0?Goo00<007ooOol08goo00<0
07ooOol0AGoo00<007ooOol08goo00<007ooOol077oo000hOol20008Ool00`00Oomoo`0bOol00`00
Oomoo`1KOol00`00Oomoo`0bOol00`00Oomoo`1DOol2000nOol00`00Oomoo`0ROol00`00Oomoo`16
Ool00`00Oomoo`0ROol00`00Oomoo`0MOol003Qoo`03001oogoo00Moo`03001oogoo039oo`03001o
ogoo05aoo`03001oogoo035oo`03001oogoo05Aoo`03001oogoo03eoo`03001oogoo029oo`03001o
ogoo04Moo`03001oogoo025oo`03001oogoo01eoo`00>7oo00<007ooOol027oo00<007ooOol0<Goo
00<007ooOol0G7oo00<007ooOol0<Goo00<007ooOol0E7oo00<007ooOol0?Woo00<007ooOol08Goo
00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol07Goo000hOol00`00Oomoo`08Ool00`00Oomo
o`0`Ool00`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomoo`1EOol00`00Oomoo`0nOol00`00Oomo
o`0POol00`00Oomoo`18Ool00`00Oomoo`0POol00`00Oomoo`0NOol003Qoo`8000Yoo`03001oogoo
02moo`03001oogoo05ioo`03001oogoo02moo`03001oogoo05Eoo`8003moo`03001oogoo021oo`03
001oogoo04Uoo`03001oogoo01moo`03001oogoo01ioo`007goo0`001Woo0P001Goo10001Goo00<0
07ooOol02Goo00<007ooOol0;goo00<007ooOol0GWoo00<007ooOol0;Woo00<007ooOol0?Goo0`00
1Woo0P001Goo10001Goo00<007ooOol0?goo00<007ooOol07goo00<007ooOol0BGoo00<007ooOol0
7Woo00<007ooOol07goo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007oo
Ool02Woo00<007ooOol0;Goo00<007ooOol0Ggoo00<007ooOol0;Woo00<007ooOol0?7oo00D007oo
Oomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo03moo`03001oogoo01ioo`03001oogoo
04Yoo`03001oogoo01ioo`03001oogoo01moo`007Woo00D007ooOomoo`00011oo`03001oogoo009o
o`03001oogoo00Yoo`03001oogoo02eoo`03001oogoo061oo`03001oogoo02eoo`03001oogoo03ao
o`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`10Ool00`00Oomoo`0MOol00`00Oomo
o`1;Ool00`00Oomoo`0MOol00`00Oomoo`0OOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02
Ool2000;Ool00`00Oomoo`0/Ool00`00Oomoo`1QOol00`00Oomoo`0/Ool00`00Oomoo`0mOol01@00
Oomoogoo000047oo00<007ooOol00Woo0P00@Goo00<007ooOol07Goo00<007ooOol0Bgoo00<007oo
Ool077oo00<007ooOol087oo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol02goo00<0
07ooOol0:goo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0?Goo00D007ooOomoo`0000ao
o`@000Eoo`03001oogoo045oo`03001oogoo01]oo`03001oogoo04aoo`03001oogoo01aoo`03001o
ogoo021oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo
02]oo`03001oogoo069oo`03001oogoo02Yoo`03001oogoo03ioo`05001oogooOol0000<Ool00`00
Oomoo`06Ool00`00Oomoo`11Ool00`00Oomoo`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00
Oomoo`0POol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2000=Ool00`00Oomoo`0YOol0
0`00Oomoo`1SOol00`00Oomoo`0ZOol00`00Oomoo`0nOol01@00Oomoogoo000037oo00<007ooOol0
1Woo0P00@Woo00<007ooOol06goo00<007ooOol0CGoo00<007ooOol06Woo00<007ooOol08Goo000O
Ool3000=Ool40005Ool00`00Oomoo`0<Ool00`00Oomoo`0YOol00`00Oomoo`1SOol00`00Oomoo`0Z
Ool00`00Oomoo`0oOol3000=Ool40005Ool00`00Oomoo`12Ool00`00Oomoo`0IOol00`00Oomoo`1?
Ool00`00Oomoo`0IOol00`00Oomoo`0QOol003Qoo`03001oogoo00aoo`03001oogoo02Qoo`03001o
ogoo06Eoo`03001oogoo02Qoo`03001oogoo05Uoo`03001oogoo049oo`03001oogoo01Uoo`03001o
ogoo04moo`03001oogoo01Uoo`03001oogoo025oo`00>7oo00<007ooOol03Goo00<007ooOol09goo
00<007ooOol0IGoo00<007ooOol0:7oo00<007ooOol0FGoo00<007ooOol0@goo00<007ooOol05goo
00<007ooOol0D7oo00<007ooOol067oo00<007ooOol08Woo000hOol2000>Ool00`00Oomoo`0WOol0
0`00Oomoo`1VOol00`00Oomoo`0WOol00`00Oomoo`1IOol20014Ool00`00Oomoo`0GOol00`00Oomo
o`1AOol00`00Oomoo`0GOol00`00Oomoo`0ROol003Qoo`03001oogoo00ioo`03001oogoo02Eoo`03
001oogoo06Moo`03001oogoo02Ioo`03001oogoo05Yoo`03001oogoo04=oo`03001oogoo01Ioo`03
001oogoo059oo`03001oogoo01Moo`03001oogoo029oo`00>7oo00<007ooOol03Woo00<007ooOol0
9Goo00<007ooOol0J7oo00<007ooOol09Goo00<007ooOol0FWoo00<007ooOol0A7oo00<007ooOol0
57oo00<007ooOol0E7oo00<007ooOol05Goo00<007ooOol08goo000hOol2000@Ool00`00Oomoo`0T
Ool00`00Oomoo`1XOol00`00Oomoo`0TOol00`00Oomoo`1KOol20015Ool00`00Oomoo`0DOol00`00
Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`0TOol003Qoo`03001oogoo00moo`03001oogoo02=o
o`03001oogoo06Yoo`03001oogoo02=oo`03001oogoo05]oo`03001oogoo04Aoo`03001oogoo01=o
o`03001oogoo05Eoo`03001oogoo01Aoo`03001oogoo02Aoo`00>7oo00<007ooOol03goo00<007oo
Ool08goo00<007ooOol0JWoo00<007ooOol08goo00<007ooOol0Fgoo00<007ooOol0AGoo00<007oo
Ool04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol09Goo000hOol00`00Oomoo`0@Ool0
0`00Oomoo`0QOol00`00Oomoo`1/Ool00`00Oomoo`0QOol00`00Oomoo`1LOol00`00Oomoo`16Ool0
0`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0AOol00`00Oomoo`0UOol003Qoo`80015oo`03
001oogoo025oo`03001oogoo06aoo`03001oogoo025oo`03001oogoo05aoo`8004Qoo`03001oogoo
00moo`03001oogoo05Uoo`03001oogoo00moo`03001oogoo02Ioo`005goo0`001Woo0P001Woo00<0
07ooOol017oo10001Goo00<007ooOol04Goo00<007ooOol07goo00<007ooOol0KWoo00<007ooOol0
7goo00<007ooOol0?7oo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0Agoo00<0
07ooOol03Woo00<007ooOol0Fgoo00<007ooOol03Woo00<007ooOol09Woo000FOol01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol07Woo
00<007ooOol0Kgoo00<007ooOol07Woo00<007ooOol0?7oo00D007ooOomoo`0000Eoo`8000Ioo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo04Qoo`03001oogoo00eoo`03001oogoo05]oo`03
001oogoo00eoo`03001oogoo02Moo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo019oo`03001oogoo01eoo`03001oogoo071oo`03001oogoo01eoo`03001o
ogoo03aoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`18Ool0
0`00Oomoo`0<Ool00`00Oomoo`1MOol00`00Oomoo`0<Ool00`00Oomoo`0WOol001Ioo`05001oogoo
Ool0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000COol00`00Oomoo`0LOol00`00Oomoo`1a
Ool00`00Oomoo`0LOol00`00Oomoo`0mOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007oo
Ool00Woo0P00BWoo00<007ooOol02Woo00<007ooOol0Ggoo00<007ooOol02Woo00<007ooOol0:7oo
000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol04goo00<007ooOol0
6goo00<007ooOol0LWoo00<007ooOol06goo00<007ooOol0?Goo00D007ooOomoo`0000ioo`03001o
ogoo00=oo`@000Eoo`03001oogoo04Yoo`03001oogoo00Qoo`03001oogoo061oo`03001oogoo00Qo
o`8002]oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
01=oo`03001oogoo01Yoo`03001oogoo07=oo`03001oogoo01Yoo`03001oogoo03ioo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`1;Ool00`00Oomoo`06Ool00`00
Oomoo`1ROol20007Ool00`00Oomoo`0[Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P005Goo00<007ooOol06Goo00<007ooOol0M7oo00<007ooOol067oo00<0
07ooOol0?goo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001=Ool3
0003Ool2001WOol20003Ool2000^Ool001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo01Aoo`03
001oogoo01Qoo`03001oogoo07Eoo`03001oogoo01Qoo`03001oogoo041oo`<000aoo`D000Aoo`@0
00Eoo`03001oogoo04ioo`@006Yoo`@0031oo`00>7oo00<007ooOol05Goo00<007ooOol05Woo00<0
07ooOol0Mgoo00<007ooOol05Woo00<007ooOol0HWoo00<007ooOol0l7oo000hOol00`00Oomoo`0F
Ool00`00Oomoo`0DOol00`00Oomoo`1iOol00`00Oomoo`0DOol00`00Oomoo`1SOol00`00Oomoo`3`
Ool003Qoo`8001Qoo`03001oogoo019oo`03001oogoo07]oo`03001oogoo01=oo`03001oogoo06=o
o`800?5oo`00>7oo00<007ooOol067oo00<007ooOol047oo00<007ooOol0OGoo00<007ooOol04Goo
00<007ooOol0I7oo00<007ooOol0l7oo000hOol00`00Oomoo`0IOol00`00Oomoo`0?Ool00`00Oomo
o`1nOol00`00Oomoo`0>Ool2001WOol00`00Oomoo`3`Ool003Qoo`8001]oo`03001oogoo00eoo`03
001oogoo081oo`03001oogoo00aoo`03001oogoo06Moo`800?5oo`00>7oo00<007ooOol06goo00<0
07ooOol02Woo0P00Q7oo00<007ooOol02Woo00<007ooOol0J7oo00<007ooOol0l7oo000hOol00`00
Oomoo`0LOol20009Ool00`00Oomoo`25Ool00`00Oomoo`08Ool00`00Oomoo`1YOol00`00Oomoo`3`
Ool003Qoo`03001oogoo01ioo`8000Eoo`8008Uoo`<000Eoo`8006aoo`03001oogoo0?1oo`00>7oo
0P0087oo1P00SWoo1@00KWoo0P00lGoo000_Ool50004Ool00`00Oomoo`3oOolNOol50004Ool00`00
Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo
0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000aOol00`00Oomo
o`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<0
07ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002mo
o`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<00004Ool00000000HOol3
003oOol7Ool3000017oo000000006Goo0`00M7oo002FOol01@00Oomoogoo00002Goo1P002Goo00D0
07ooOomoo`000?moo`Moo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05001o
ogooOol0000LOol00`00Oomoo`3oOol5Ool01@00Oomoogoo000067oo1@00M7oo002FOol01@00Oomo
ogoo00002Goo1P003Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Uoo`H000Uoo`04001oogoo
001eOol009Ioo`05001oogooOol0000JOol2003oOol8Ool01@00Oomoogoo00006Goo00<007oo0000
MGoo002EOol5000MOol00`00Oomoo`3oOol4Ool5000JOol00`00Ool0001eOol00;=oo`05001oogoo
Ool0003oOolVOol2001eOol00;Aoo`<00?moobQoo`03001oogoo07=oo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo000_Ool5003oOolUOol5
003gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`009Woo1P001Goo00<007ooOol0ogoo
77oo1P001Goo00<007ooOol0mgoo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2
003aOol0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1o
o`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000a
Ool00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol002moo`<000Ioo`03001oogoo
0?mooaioo`<000Ioo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`80
0?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo
:7oo0P00lGoo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool3
0006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol00005
Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo0000
1Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0l7oo000>Ool60002Ool01@00
Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0o7oo1P000Woo00D007oo
Oomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?1oo`005Woo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool4
0005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007oo
Ool0l7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?1oo`00
5Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00
Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?5oo`005goo0`0037oo1@00
17oo10001Goo00<007ooOol0ogoo1Woo0`0037oo1@0017oo10001Goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`1QOolF
002_Ool00`00Oomoo`3`Ool003Qoo`03001oogoo05aoo`D001Ioo`H00:Uoo`03001oogoo0?1oo`00
>7oo00<007ooOol0DWoo2P008Goo1`00XWoo00<007ooOol0l7oo000hOol2001@Ool3000bOol6002L
Ool2003aOol001moo`<000Ioo`8000Eoo`@000Eoo`03001oogoo04aoo`<003]oo`<0081oo`<000Io
o`8000Eoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo
009oo`03001oogoo04Uoo`<0045oo`<007aoo`05001oogooOol00005Ool20009Ool00`00Oomoo`02
Ool00`00Oomoo`3`Ool001Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool20017Ool3
0017Ool3001aOol60002Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00
Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0@goo0`00CGoo0`00MWoo00D007ooOomoo`00
011oo`03001oogoo009oo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001o
ogoo041oo`<005=oo`<007=oo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3`Ool001ioo`05
001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0lOol4001IOol2001aOol01@00Oomoogoo
000037oo00<007ooOol01Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol0
1Woo0P00>Woo0`00Ggoo0`00KWoo00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?5oo`007goo
0`003Goo10001Goo00<007ooOol0=Woo0`00IGoo0P00KGoo0`003Goo10001Goo00<007ooOol0l7oo
000hOol00`00Oomoo`0cOol3001ZOol30023Ool00`00Oomoo`3`Ool003Qoo`03001oogoo035oo`80
071oo`80085oo`03001oogoo0?1oo`00>7oo0P00<7oo0P00M7oo0P00Ogoo0P00lGoo000hOol00`00
Oomoo`0^Ool00`00Oomoo`1fOol3001lOol00`00Oomoo`3`Ool003Qoo`03001oogoo02aoo`8007ao
o`8007Yoo`03001oogoo0?1oo`00>7oo0P00:goo0P00P7oo0P00N7oo0P00lGoo000hOol00`00Oomo
o`0XOol20024Ool2001fOol00`00Oomoo`3`Ool003Qoo`03001oogoo02Eoo`<008Qoo`<007=oo`03
001oogoo0?1oo`00>7oo00<007ooOol08goo0P00SWoo0P00LGoo00<007ooOol0;Woo3@00]Goo000h
Ool2000ROol2002BOol2001_Ool2000YOol6000=Ool6002_Ool001Moo`<000Ioo`8000Aoo`D000Ao
o`@000Eoo`03001oogoo01moo`8009Ioo`8004aoo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001o
ogoo02Aoo`@001Uoo`@00:]oo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool0
0`00Oomoo`02Ool00`00Oomoo`0MOol2002JOol20019Ool01@00Oomoogoo00001Goo0P001Goo00@0
07ooOol000Qoo`03001oogoo009oo`03001oogoo021oo`@0025oo`<00:Qoo`003Woo1P000Woo00D0
07ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8001eoo`03001oogoo09aoo`03001o
ogoo03ioo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000NOol3
000XOol2002VOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`0JOol2002POol20016Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol06Woo0`00;Goo0`00Xgoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo1000
1Goo00<007ooOol067oo0P00Y7oo0P00A7oo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eo
o`03001oogoo01Qoo`8003=oo`800:5oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo01Ioo`800:Qoo`80049oo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`0FOol2000gOol2002OOol001Ioo`05001oogooOol0000;Ool0
1@00Oomoogoo000017oo00<007ooOol01Woo0P005Goo0P00[7oo0P00@7oo00D007ooOomoo`0000]o
o`05001oogooOol00004Ool00`00Oomoo`06Ool2000EOol2000kOol2002MOol001Moo`<000eoo`<0
00Eoo`@000Eoo`03001oogoo01=oo`03001oogoo0:ioo`03001oogoo03ioo`<000eoo`<000Eoo`@0
00Eoo`03001oogoo019oo`8003moo`<009Yoo`00>7oo00<007ooOol04Goo0P0037oo0`001Woo0P00
17oo1@0067oo0`001Woo0P001Woo0`0067oo0`001Woo0P001Goo0`006Woo0`001Woo0P001Goo0`00
3Woo0P004Goo1@00BGoo00<007ooOol047oo0P003Goo0`001Woo0P0017oo1@0067oo0`001Woo1000
17oo0`0067oo0`001Woo0P001Goo0`006Goo0`001Woo0P001Goo0`008Goo1@0057oo000hOol2000@
Ool2000=Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool2
0007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Qoo`05001o
ogooOol00005Ool20004Ool01@00Oomoogoo00003goo0P004Goo00<007ooOol0BGoo0P003goo0P00
3Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomoogoo00001Goo0P000Woo
0P000goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000GOol01@00
Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol0
3Goo0P003goo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol0
1@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo0000
4Goo0P003goo00<007ooOol0BGoo00<007ooOol03Goo00<007ooOol03Woo00D007ooOomoo`0000eo
o`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00
Oomoo`0<Ool00`00Oomoo`0?Ool01@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`00
00]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0
000;Ool01@00Oomoogoo00004goo00<007ooOol037oo00<007ooOol0BGoo00<007ooOol02goo0P00
4Goo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000Ool0000067oo
00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00002goo00D007ooOomoo`00
029oo`03001oogoo01Aoo`00>7oo00<007ooOol02Woo0P004Woo00D007ooOomoo`0000moo`03001o
ogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10006Goo00D0
07ooOomoo`0000aoo`<001Eoo`8000aoo`03001oogoo04Uoo`03001oogoo00Yoo`03001oogoo015o
o`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo00000P005Woo
00D007ooOomoo`0000]oo`@001Qoo`05001oogooOol0000<Ool3000SOol00`00Oomoo`0DOol003Qo
o`8000Uoo`8001Aoo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<0
07oo000067oo00D007ooOomoo`0000]oo`03001oogoo01Yoo`05001oogooOol0000;Ool01@00Oomo
ogoo00005Woo0P002Woo00<007ooOol0BGoo0P002Goo0P0057oo00D007ooOomoo`0000moo`03001o
ogoo01Eoo`05001oogooOol0000<Ool00`00Ool00002Ool2000DOol01@00Oomoogoo00002goo00<0
07ooOol06Goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03
001oogoo00Moo`03001oogoo01Aoo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007oo
Oomoo`0000eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo
00D007ooOomoo`0001Qoo`03001oogoo00Moo`03001oogoo04Uoo`03001oogoo00Moo`03001oogoo
01Aoo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8000Aoo`80
019oo`05001oogooOol0000<Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007ooOomoo`00
029oo`03001oogoo01Aoo`00>7oo00<007ooOol01Goo0P0067oo0`003Goo0`006Goo0`003goo00<0
07ooOol05goo0`003Woo0`006Goo0`003Goo0`006Woo0P001Goo0`00Bgoo00<007ooOol01Goo0P00
67oo0`003Goo0`006Goo0`003goo00<007ooOol017oo00<007ooOol047oo0`003Woo0`0067oo0`00
3Goo0`008Goo0`005Woo000hOol00`00Oomoo`03Ool2003>Ool2001AOol00`00Oomoo`03Ool2001P
Ool20029Ool003Qoo`80009oo`800=9oo`8004moo`80009oo`8006Aoo`03001oogoo08Ioo`00>7oo
00@007ooOol00=Ioo`03001oogoo04aoo`04001oogoo001WOol20026Ool003Qoo`<00=Qoo`8004ao
o`<006Yoo`03001oogoo08=oo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`19Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Ool0
0008Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool2000FOol0
03Qoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo
02Uoo`03001oogoo04Uoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo01Ioo`80015oo`03
001oogoo02Uoo`03001oogoo02Ioo`800003Ool007oo01Eoo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0L7oo00<007ooOol0HGoo0P006Woo000hOol2003oOolXOol2001bOol2001POol00`00Oomo
o`0JOol003Qoo`03001oogoo0?moobMoo`03001oogoo07=oo`03001oogoo05]oo`8001eoo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0M7oo0P00FGoo0P007goo000hOol2003oOolXOol2001gOol2
001EOol2000QOol003Qoo`03001oogoo0?moobMoo`03001oogoo07Qoo`80055oo`8002=oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0NWoo0P00CWoo00<007ooOol08goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`1lOol2001:Ool2000VOol003Qoo`800?moobQoo`8007moo`8004Ioo`8002Qo
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0P7oo0P00@Woo0P00:Woo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`22Ool2000nOol2000/Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Ao
o`03001oogoo03Uoo`8002ioo`00>7oo0P00ogoo:7oo0P00QWoo0P00=goo0P00<7oo000GOol30006
Ool20004Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20004Ool50004Ool40005Ool0
0`00Oomoo`27Ool2000cOol2000bOol001Ioo`05001oogooOol00005Ool20005Ool01000Oomoo`00
27oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo
0008Ool00`00Oomoo`02Ool00`00Oomoo`29Ool2000^Ool3000dOol001Ioo`05001oogooOol0000=
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Goo00<007ooOol0
27oo00<007ooOol00Woo0P00S7oo10009goo0`00=goo000FOol01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo08moo`<0029oo`8003Yoo`005Woo00D007ooOomoo`0000moo`03
001oogoo009oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool4
0005Ool00`00Oomoo`2BOol3000LOol3000lOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol0UGoo0`005Goo1000?goo000FOol01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P00VGoo5@00@goo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`3o
Ool6Ool3000=Ool30005Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`00
1Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007oo
Ool00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001o
ogoo0?1oo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`ioo`05001oogooOol0
000@Ool00`00Oomoo`02Ool2003aOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0l7oo000NOol01@00
Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001o
ogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00
Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P00lGoo000OOol3000=
Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol0
01Moo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`800?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eo
o`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00002goo
00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000;Ool0
1@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0l7oo000GOol3000<Ool50004Ool40005
Ool2003oOol7Ool3000<Ool50004Ool40005Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`800?moobQoo`800?5oo`00;goo1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0
l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0
035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo
00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo
9goo00<007ooOol0mgoo000_Ool3003oOolWOol3003iOol00?mooomooeIoo`00ogooogooEWoo002E
Ool3000017oo0000000067oo1@00ogoo1Goo0`0000Aoo`00000001Moo`D007Aoo`00UWoo00D007oo
Oomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000:Ool01000Oomo
o`00M7oo002FOol01@00Oomoogoo00006goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001Yoo`03
001oogoo07Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogoo
Ool00009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6
Ool01@00Oomoogoo000077oo00<007ooOol0LWoo002EOol5000LOol00`00Oomoo`3oOol5Ool5000M
Ool00`00Oomoo`1bOol00;Ioo`03001oogoo0?moob=oo`05001oogooOol0001dOol00;Aoo`<00?mo
obIoo`<007Eoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .42289 L
.08255 .47662 L
.10458 .52781 L
.12507 .56618 L
.14415 .59247 L
.14918 .59775 L
.15465 .60268 L
.15946 .60631 L
.16457 .60942 L
.16917 .61156 L
.17178 .6125 L
.17423 .6132 L
.17538 .61346 L
.17647 .61368 L
.17746 .61384 L
.17852 .61399 L
.17967 .61411 L
.18073 .61418 L
.182 .61423 L
.18314 .61422 L
.18435 .61418 L
.18547 .6141 L
.1867 .61397 L
.18802 .61378 L
.19071 .61323 L
.19317 .61254 L
.1979 .61071 L
.20239 .60836 L
.21236 .60103 L
.22321 .58984 L
.24299 .56123 L
.26399 .52033 L
.30174 .42538 L
.34195 .30697 L
.38063 .1931 L
.40028 .14074 L
.42177 .09078 L
.44253 .05184 L
.4614 .0258 L
.47149 .01588 L
.47611 .01229 L
.48101 .00918 L
.4835 .00786 L
.48624 .00663 L
.48876 .00569 L
.49106 .005 L
.49378 .00438 L
.49527 .00414 L
.49596 .00405 L
Mistroke
.49669 .00397 L
.498 .00386 L
.49921 .00381 L
.49996 .0038 L
.50065 .00381 L
.50196 .00386 L
.50313 .00395 L
.50438 .00409 L
.50556 .00427 L
.50663 .00446 L
.50926 .00509 L
.51175 .00587 L
.5167 .00796 L
.52208 .01106 L
.53169 .01869 L
.54056 .02807 L
.55926 .05481 L
.57988 .0943 L
.62014 .19526 L
.65888 .30946 L
.70007 .43042 L
.72063 .48452 L
.73974 .52833 L
.75939 .5652 L
.77791 .59114 L
.78775 .60113 L
.79293 .60528 L
.7984 .60882 L
.80302 .61112 L
.80546 .61208 L
.80809 .61292 L
.8105 .6135 L
.8127 .61389 L
.81375 .61402 L
.81491 .61413 L
.81599 .6142 L
.817 .61423 L
.81818 .61422 L
.81941 .61417 L
.82047 .61409 L
.82163 .61397 L
.82287 .61379 L
.82421 .61355 L
.82661 .61298 L
.82905 .61223 L
.83134 .61135 L
.83564 .6093 L
.84078 .60614 L
.84552 .60254 L
.85624 .59203 L
Mistroke
.87498 .56611 L
.89561 .52742 L
.93591 .42747 L
.97471 .3135 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .26242 L
.08255 .24219 L
.0932 .2333 L
.10458 .22545 L
.11009 .22231 L
.11531 .21977 L
.12038 .21769 L
.12507 .21614 L
.12951 .215 L
.13178 .21454 L
.13422 .21415 L
.13549 .21398 L
.13666 .21384 L
.13784 .21373 L
.13895 .21365 L
.14022 .21358 L
.1409 .21356 L
.14161 .21354 L
.1423 .21353 L
.14295 .21353 L
.14415 .21354 L
.14531 .21358 L
.14656 .21364 L
.14773 .21372 L
.14881 .21382 L
.15143 .21414 L
.15392 .21454 L
.15886 .21565 L
.16423 .2173 L
.17383 .22139 L
.1827 .22642 L
.20137 .2406 L
.22197 .261 L
.26217 .30935 L
.30086 .35597 L
.32051 .37571 L
.3309 .38443 L
.342 .39217 L
.35275 .39797 L
.35784 .4001 L
.36253 .4017 L
.36724 .40295 L
.36972 .40346 L
.37235 .40389 L
.37463 .40418 L
.37573 .40428 L
.37677 .40436 L
.37799 .40444 L
.37911 .40448 L
Mistroke
.38031 .40451 L
.38162 .4045 L
.38227 .40449 L
.38296 .40448 L
.38419 .40442 L
.38551 .40434 L
.38695 .40421 L
.38955 .40389 L
.39197 .4035 L
.39649 .40251 L
.40134 .40108 L
.40698 .39893 L
.41232 .39645 L
.42232 .39063 L
.44227 .37492 L
.4607 .35634 L
.50002 .30899 L
.53782 .26331 L
.55884 .24211 L
.56803 .23435 L
.57808 .22714 L
.58722 .22183 L
.59696 .21755 L
.60236 .21583 L
.60726 .21468 L
.60962 .21426 L
.61086 .21408 L
.61218 .21392 L
.61333 .2138 L
.61459 .21369 L
.61574 .21362 L
.61682 .21357 L
.61808 .21353 L
.61871 .21353 L
.61941 .21353 L
.62065 .21355 L
.62181 .21359 L
.62248 .21362 L
.62318 .21367 L
.62443 .21377 L
.62578 .2139 L
.62725 .21408 L
.62973 .21447 L
.63238 .215 L
.63715 .21624 L
.64214 .21792 L
.64686 .21988 L
.6557 .22447 L
.67568 .23897 L
.69413 .25668 L
Mistroke
.7335 .30323 L
.77136 .34959 L
.79241 .37174 L
.81166 .38782 L
.82118 .39396 L
.8262 .39666 L
.83155 .39912 L
.8367 .40105 L
.84136 .40244 L
.84361 .40299 L
.84604 .40349 L
.84835 .40387 L
.85045 .40414 L
.85159 .40425 L
.85283 .40435 L
.85414 .40443 L
.85538 .40448 L
.85653 .40451 L
.85776 .40451 L
.85881 .40449 L
.85997 .40444 L
.86063 .40441 L
.86132 .40436 L
.86256 .40426 L
.86535 .40395 L
.86777 .40357 L
.87041 .40305 L
.87569 .40166 L
.88133 .39969 L
.89148 .39488 L
.90173 .38845 L
.91284 .37986 L
.933 .36054 L
.97393 .31186 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .29119 L
.10458 .27208 L
.14415 .25478 L
.18221 .239 L
.22272 .22343 L
.26171 .20988 L
.30316 .19728 L
.34309 .1871 L
.3815 .17931 L
.40095 .17615 L
.42237 .1733 L
.44268 .17123 L
.45178 .1705 L
.46172 .16984 L
.4671 .16955 L
.4721 .16932 L
.47727 .16912 L
.48196 .16897 L
.48658 .16886 L
.4887 .16882 L
.49093 .16879 L
.49332 .16876 L
.49438 .16875 L
.49552 .16874 L
.49675 .16873 L
.49789 .16873 L
.49859 .16873 L
.49925 .16873 L
.50049 .16873 L
.50163 .16873 L
.50286 .16873 L
.50401 .16874 L
.50508 .16875 L
.50754 .16877 L
.51014 .1688 L
.51268 .16885 L
.51504 .1689 L
.5204 .16904 L
.5293 .16938 L
.53882 .16987 L
.54906 .17056 L
.56016 .17148 L
.58032 .17362 L
.62123 .1798 L
.66064 .18797 L
.69852 .19775 L
.73886 .21007 L
.77769 .22358 L
.81897 .23948 L
Mistroke
.85873 .25601 L
.89697 .27277 L
.93767 .29124 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .26322 L
.10458 .21674 L
.14415 .17949 L
.18221 .15192 L
.20178 .14148 L
.21267 .13688 L
.22272 .13342 L
.23293 .13069 L
.23832 .12958 L
.24402 .12864 L
.24641 .12833 L
.24897 .12804 L
.25119 .12784 L
.25361 .12765 L
.25507 .12757 L
.25643 .1275 L
.25773 .12745 L
.2584 .12743 L
.25912 .12741 L
.25983 .1274 L
.26048 .12739 L
.26176 .12738 L
.26293 .12739 L
.26416 .1274 L
.26538 .12743 L
.26607 .12745 L
.26671 .12747 L
.26912 .12759 L
.27131 .12773 L
.27364 .12793 L
.27847 .12846 L
.2838 .12927 L
.29326 .13125 L
.30213 .13374 L
.32232 .14162 L
.34082 .15145 L
.38045 .18015 L
.41855 .21605 L
.45912 .26062 L
.49816 .30681 L
.53966 .356 L
.57964 .40012 L
.61811 .43665 L
.63759 .45217 L
.65902 .46649 L
.67938 .4772 L
.69843 .48447 L
.70884 .48728 L
.71396 .48836 L
Mistroke
.71872 .48917 L
.72301 .48975 L
.72758 .49022 L
.7302 .49041 L
.73148 .49048 L
.73266 .49054 L
.73371 .49058 L
.73487 .49061 L
.73603 .49064 L
.73725 .49065 L
.73856 .49065 L
.73977 .49064 L
.7404 .49063 L
.7411 .49062 L
.74251 .49058 L
.74375 .49053 L
.74508 .49046 L
.74748 .4903 L
.74985 .49011 L
.75235 .48985 L
.7568 .48927 L
.76198 .4884 L
.7668 .4874 L
.77773 .48448 L
.78828 .48079 L
.79823 .47655 L
.81683 .4667 L
.85534 .43897 L
.89632 .40036 L
.93577 .35688 L
.97371 .31199 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0JGoo1@00/Goo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04
Ool00`00Oomoo`1WOol30004Ool2002_Ool00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001o
ogoo00Aoo`03001oogoo06Ioo`03001oogoo00Moo`800:eoo`03001oogoo00Aoo`03001oogoo0?1o
o`00<Goo00<007ooOol017oo0P00IGoo0P0037oo00<007ooOol0ZWoo00<007ooOol017oo0P00lGoo
000_Ool30006Ool00`00Oomoo`1SOol00`00Oomoo`0=Ool00`00Oomoo`2WOol30006Ool00`00Oomo
o`3`Ool003Qoo`03001oogoo069oo`03001oogoo00moo`03001oogoo0:moo`03001oogoo0?1oo`00
>7oo0P00Hgoo00<007ooOol047oo00<007ooOol0[Woo0P00lGoo000hOol00`00Oomoo`1QOol00`00
Oomoo`0AOol00`00Oomoo`2^Ool00`00Oomoo`3`Ool003Qoo`03001oogoo061oo`03001oogoo01=o
o`03001oogoo0:eoo`03001oogoo0?1oo`00>7oo00<007ooOol0H7oo00<007ooOol057oo00<007oo
Ool0[7oo00<007ooOol0l7oo000hOol2001POol00`00Oomoo`0EOol00`00Oomoo`2/Ool2003aOol0
03Qoo`03001oogoo05ioo`03001oogoo01Moo`03001oogoo0:]oo`03001oogoo0?1oo`00>7oo00<0
07ooOol0GWoo00<007ooOol067oo00<007ooOol0ZWoo00<007ooOol0l7oo000hOol00`00Oomoo`1M
Ool00`00Oomoo`0IOol00`00Oomoo`2ZOol00`00Oomoo`3`Ool003Qoo`8005ioo`03001oogoo01Yo
o`03001oogoo0:Uoo`800?5oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool0G7oo00<007ooOol06goo00<007ooOol0R7oo0`001Woo0P001Woo00<007ooOol017oo10001Goo
00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol0Fgoo00<007ooOol07Goo00<007ooOol0QWoo00D007ooOomoo`0000Eoo`8000Io
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`00
00ioo`03001oogoo00Moo`03001oogoo009oo`8005aoo`03001oogoo01ioo`03001oogoo07eoo`H0
009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`1JOol00`00Oomoo`0OOol0
0`00Oomoo`25Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0FWoo00<007oo
Ool087oo00<007ooOol0Q7oo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo
0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo05Uo
o`03001oogoo025oo`03001oogoo08Aoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P00FWoo00<007ooOol08Woo00<007ooOol0Pgoo00D007ooOomoo`0000]oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo05Qo
o`03001oogoo02=oo`03001oogoo08Aoo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo
00<007ooOol0F7oo00<007ooOol097oo00<007ooOol0Y7oo00<007ooOol0l7oo000hOol2001IOol0
0`00Oomoo`0TOol00`00Oomoo`2TOol2003aOol003Qoo`03001oogoo05Moo`03001oogoo02Eoo`03
001oogoo0:Aoo`03001oogoo0?1oo`00>7oo00<007ooOol0Egoo00<007ooOol09Woo00<007ooOol0
Xgoo00<007ooOol0l7oo000hOol00`00Oomoo`1FOol00`00Oomoo`0WOol00`00Oomoo`2SOol00`00
Oomoo`3`Ool003Qoo`8005Moo`03001oogoo02Qoo`03001oogoo0:9oo`800?5oo`00>7oo00<007oo
Ool0EGoo00<007ooOol0:Goo00<007ooOol0XWoo00<007ooOol0l7oo000hOol00`00Oomoo`1EOol0
0`00Oomoo`0YOol00`00Oomoo`2ROol00`00Oomoo`3`Ool003Qoo`8005Ioo`03001oogoo02Yoo`03
001oogoo0:5oo`800?5oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0E7oo00<007ooOol0
:goo00<007ooOol0R7oo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo
00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol0;7oo00<007ooOol0QWoo
00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`005Woo1P000Woo00D0
07ooOomoo`00011oo`03001oogoo009oo`03001oogoo05=oo`03001oogoo02eoo`03001oogoo07io
o`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001ioo`05001oogoo
Ool0000@Ool00`00Oomoo`02Ool2001DOol00`00Oomoo`0]Ool00`00Oomoo`26Ool01@00Oomoogoo
000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0
Dgoo00<007ooOol0;Woo00<007ooOol0QGoo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1o
o`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo059oo`03001oogoo02moo`03
001oogoo08Eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1BOol00`00Oomoo`0_Ool00`00Oomoo`25Ool0
1@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0l7oo000OOol3000=Ool40005Ool2001C
Ool00`00Oomoo`0`Ool00`00Oomoo`25Ool3000=Ool40005Ool2003aOol003Qoo`03001oogoo055o
o`03001oogoo035oo`03001oogoo09ioo`03001oogoo0?1oo`00>7oo00<007ooOol0DGoo00<007oo
Ool0<Woo00<007ooOol0WGoo00<007ooOol0l7oo000hOol2001BOol00`00Oomoo`0bOol00`00Oomo
o`2MOol2003aOol003Qoo`03001oogoo051oo`03001oogoo03=oo`03001oogoo09eoo`03001oogoo
0?1oo`00>7oo00<007ooOol0D7oo00<007ooOol0=7oo00<007ooOol0W7oo00<007ooOol0l7oo000h
Ool00`00Oomoo`1@Ool00`00Oomoo`0dOol00`00Oomoo`2LOol00`00Oomoo`3`Ool003Qoo`80051o
o`03001oogoo03Ioo`03001oogoo09]oo`800?5oo`00>7oo00<007ooOol0Cgoo00<007ooOol0=Woo
00<007ooOol0Vgoo00<007ooOol0l7oo000hOol00`00Oomoo`1?Ool00`00Oomoo`0fOol00`00Oomo
o`2KOol00`00Oomoo`3`Ool003Qoo`8004moo`03001oogoo03Qoo`03001oogoo09Yoo`8001Eoo`T0
06Ioo`T006Aoo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0CWoo00<007ooOol0
>7oo00<007ooOol0NGoo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol04Woo0P002Goo1000
H7oo0P002Goo0`00HGoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001o
ogoo009oo`03001oogoo04ioo`03001oogoo03Qoo`03001oogoo07Qoo`05001oogooOol00005Ool2
0005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol03goo0`003goo00<007ooOol0FWoo
0`003Woo0P00Ggoo000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol0CGoo00<007ooOol0>Woo00<007ooOol0Kgoo1P000Woo00D007ooOomoo`0000eo
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo015oo`8005Qoo`8001=o
o`03001oogoo05aoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80
04ioo`03001oogoo03Yoo`03001oogoo07Moo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool2000=Ool2000FOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`1KOol001Io
o`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol0
0`00Oomoo`1gOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol02goo00<0
07ooOol05goo00<007ooOol0DWoo00<007ooOol05Woo00<007ooOol0FWoo000FOol01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0C7oo00<007ooOol0?7oo00<007oo
Ool0MWoo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Yoo`03
001oogoo01Uoo`03001oogoo051oo`03001oogoo01Qoo`03001oogoo05Uoo`005Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001=Ool00`00Oomoo`0lOol00`00Oomo
o`1fOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000]oo`03001o
ogoo01Yoo`03001oogoo04ioo`03001oogoo01Yoo`03001oogoo05Qoo`005goo0`003Goo0`001Goo
10001Goo00<007ooOol0C7oo00<007ooOol0?7oo00<007ooOol0Mgoo0`003Goo0`001Goo10001Goo
00<007ooOol02Goo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol0Egoo
000hOol00`00Oomoo`1;Ool00`00Oomoo`0nOol00`00Oomoo`2GOol00`00Oomoo`08Ool00`00Oomo
o`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`1FOol003Qoo`03001oogoo01moo`<0
00Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<0009oo`03001oogoo
01Eoo`<000Ioo`8000Eoo`<0025oo`D004Uoo`03001oogoo00Moo`03001oogoo01Eoo`<000Ioo`<0
00=oo`D001Qoo`<000Ioo`8000Ioo`<001Ioo`03001oo`00008000Ioo`8000Eoo`<000ioo`03001o
ogoo00Qoo`<000Ioo`8000Eoo`<0025oo`D001Aoo`00>7oo0P007goo00D007ooOomoo`0000Eoo`80
00Eoo`04001oogoo000GOol20002Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`0FOol01@00Oomo
ogoo00001Goo0P0017oo00L007ooOomoo`00Ool0000FOol01@00Oomoogoo00001Goo0P0017oo00D0
07ooOomoo`00029oo`03001oogoo04Uoo`8000Moo`03001oogoo01Eoo`05001oogooOol00005Ool2
00000goo001oo`02Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo01Ao
o`03001oo`0000=oo`03001oogoo00=oo`8000Aoo`05001oogooOol0000=Ool00`00Oomoo`07Ool0
1@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007oo
Ool07Woo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol01@00
Oomoogoo00002goo00D007ooOomoo`00009oo`03001oogoo01=oo`05001oogooOol0000;Ool01@00
Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol01Woo00<007ooOol05Goo00D007ooOomoo`00
00Qoo`03001oogoo009oo`03001oogoo01Moo`05001oogooOol0000;Ool5000EOol00`00Ool00003
Ool00`00Oomoo`09Ool01@00Oomoogoo00003Woo00<007ooOol01Woo00D007ooOomoo`0000]oo`05
001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogooOol0000>Ool0
0`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol001Qoo`05001oogooOol0000;Ool01@00
Oomoogoo00000Woo00<007ooOol04goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00
Oomoo`19Ool00`00Oomoo`05Ool00`00Oomoo`0FOol01@00Oomoogoo00002Goo00<007ooOol00Woo
00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000EOol01000Oomoo`000goo00<007oo
Ool02Goo00D007ooOomoo`0000moo`03001oogoo00Eoo`05001oogooOol0000;Ool01@00Oomoogoo
00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003goo00<007ooOol0
5Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool40003Ool00`00Oomo
o`0COol01@00Oomoogoo000037oo0`008goo00<007ooOol0BGoo00<007ooOol017oo00<007ooOol0
5goo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo01Eoo`05001oogooOol0000<Ool0
0`00Ool0000DOol01@00Oomoogoo00000goo00<007ooOol02Goo10004Goo00<007ooOol017oo00D0
07ooOomoo`0000aoo`<002=oo`03001oogoo01Aoo`00>7oo0P007goo00D007ooOomoo`0000moo`03
001oogoo01Aoo`8000=oo`03001oogoo00Yoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00
Oomoo`05Ool00`00Oomoo`0BOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo
04Uoo`8000Aoo`03001oogoo01Qoo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007oo
Oomoo`0000aoo`03001oo`0001=oo`03001oogoo009oo`05001oogooOol0000;Ool00`00Oomoo`0C
Ool00`00Oomoo`03Ool01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00
>7oo00<007ooOol07Woo00D007ooOomoo`0000]oo`05001oogooOol0000FOol20003Ool00`00Oomo
o`0;Ool2000HOol01@00Oomoogoo000037oo00<007ooOol017oo00<007ooOol04Woo00D007ooOomo
o`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`02Ool00`00Oomoo`0IOol0
1@00Oomoogoo00002goo0P000Woo00<007ooOol05Goo00D007ooOomoo`0000eoo`80019oo`03001o
ogoo00=oo`05001oogooOol0000<Ool00`00Oomoo`0COol00`00Oomoo`02Ool01@00Oomoogoo0000
2goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07goo0`003Goo0`005goo
00<007oo00000P003goo00<007ooOol05goo0`003Woo0`000goo00<007ooOol04goo0`003Goo0`00
8Goo0`00Bgoo00D007ooOomoo`0001eoo`<000eoo`<001Uoo`<000moo`03001oogoo00moo`03001o
ogoo00Eoo`<000ioo`<001=oo`03001oogoo009oo`<000eoo`<0025oo`<001Ioo`00>7oo0P00BGoo
00<007ooOol0A7oo00<007ooOol0U7oo0P000Woo00<007ooOol0;7oo00<007ooOol0?7oo00<007oo
Ool0;Goo00<007ooOol0CWoo000hOol00`00Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`2DOol0
1000Oomoo`00<7oo00<007ooOol0>Woo00<007ooOol0;goo00<007ooOol0CGoo000hOol00`00Oomo
o`18Ool00`00Oomoo`14Ool00`00Oomoo`2DOol00`00Ool0000bOol00`00Oomoo`0hOol00`00Oomo
o`0aOol00`00Oomoo`1<Ool003Qoo`03001oogoo04Moo`03001oogoo04Ioo`03001oogoo09=oo`80
03Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00<Wooj@00@7ooj@0047oo000h
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`04Ool01@00Oomoogoo00002Woo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00D007ooOomoo`0000Ioo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Moo`8004]oo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`8000Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo01Aoo`00>7oo0P00Agoo00<007ooOol0B7oo00<007ooOol0AGoo00<0
07ooOol0BWoo00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=goo00<007ooOol0<Goo00<0
07ooOol05Goo000hOol20017Ool00`00Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`1;Ool2000g
Ool00`00Oomoo`0`Ool00`00Oomoo`0iOol00`00Oomoo`0_Ool00`00Oomoo`0FOol003Qoo`8004Io
o`03001oogoo04Uoo`03001oogoo04Aoo`03001oogoo04]oo`03001oogoo03Moo`03001oogoo02io
o`03001oogoo03]oo`03001oogoo02eoo`03001oogoo01Moo`00>7oo00<007oo0000AGoo00<007oo
Ool0BWoo00<007ooOol0@goo00<007ooOol0Bgoo00<007ooOol0>7oo00<007ooOol0;7oo00<007oo
Ool0?7oo00<007ooOol0;7oo00<007ooOol067oo000hOol00`00Ool00015Ool00`00Oomoo`1:Ool0
0`00Oomoo`12Ool00`00Oomoo`1<Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0nOol0
0`00Oomoo`0ZOol00`00Oomoo`0IOol003Qoo`<004Aoo`03001oogoo04]oo`03001oogoo049oo`03
001oogoo04aoo`8003Yoo`03001oogoo02Yoo`03001oogoo03moo`03001oogoo02Uoo`03001oogoo
01Uoo`00>7oo00@007ooOol004=oo`03001oogoo04aoo`03001oogoo045oo`03001oogoo04aoo`03
001oogoo03Yoo`03001oogoo02Qoo`03001oogoo045oo`03001oogoo02Moo`03001oogoo01Yoo`00
>7oo00@007ooOol004=oo`03001oogoo04aoo`03001oogoo041oo`03001oogoo04eoo`03001oogoo
03]oo`03001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03001oogoo01]oo`00>7oo00@0
07ooOol0049oo`03001oogoo04eoo`03001oogoo041oo`03001oogoo04eoo`03001oogoo03aoo`03
001oogoo02Aoo`03001oogoo04Eoo`03001oogoo02=oo`03001oogoo01aoo`00>7oo0P000Woo00<0
07ooOol0?goo00<007ooOol0CWoo00<007ooOol0?goo00<007ooOol0CGoo0P00?Woo0P008goo00<0
07ooOol0Agoo00<007ooOol08Goo00<007ooOol07Goo000hOol01@00Oomoogoo0000@Goo00<007oo
Ool0CWoo00<007ooOol0?Woo00<007ooOol0CWoo00<007ooOol0?goo00<007ooOol07goo00<007oo
Ool0BGoo00<007ooOol07goo00<007ooOol07Woo000hOol01@00Oomoogoo0000@7oo00<007ooOol0
Cgoo00<007ooOol0?Woo00<007ooOol0CWoo00<007ooOol0@7oo00<007ooOol07Goo00<007ooOol0
Bgoo00<007ooOol07Goo00<007ooOol07goo000hOol20003Ool00`00Oomoo`0mOol00`00Oomoo`1@
Ool00`00Oomoo`0mOol00`00Oomoo`1>Ool20012Ool00`00Oomoo`0KOol00`00Oomoo`1=Ool00`00
Oomoo`0KOol00`00Oomoo`0POol001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo009o
o`03001oogoo03aoo`03001oogoo055oo`03001oogoo03aoo`03001oogoo02ioo`<000Ioo`8000Ao
o`D000Aoo`@000Eoo`03001oogoo049oo`03001oogoo01Qoo`80055oo`03001oogoo01Uoo`03001o
ogoo025oo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`0lOol00`00Oomoo`1BOol00`00Oomoo`0kOol00`00Oomoo`0]Ool0
1@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo04=oo`03
001oogoo01Ioo`03001oogoo059oo`03001oogoo01Ioo`8002Aoo`005Woo00D007ooOomoo`0000eo
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo03]oo`03001oogoo059o
o`03001oogoo03]oo`03001oogoo02eoo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool00`00Oomoo`14Ool2000EOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`0TOol0
01Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`0j
Ool00`00Oomoo`1COol00`00Oomoo`0jOol00`00Oomoo`0^Ool01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo0P00Agoo00<007ooOol04Goo00<007ooOol0EWoo0`004Woo00<007oo
Ool09Goo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol00goo00<0
07ooOol0>Woo00<007ooOol0E7oo00<007ooOol0>Goo00<007ooOol0;Woo00D007ooOomoo`0000mo
o`03001oogoo009oo`@000Eoo`03001oogoo04Moo`8000moo`8005aoo`03001oogoo00ioo`03001o
ogoo02Ioo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
00Aoo`03001oogoo03Uoo`03001oogoo05Aoo`03001oogoo03Uoo`03001oogoo02ioo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`19Ool00`00Oomoo`0;Ool00`00
Oomoo`1MOol00`00Oomoo`0;Ool2000YOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P001Goo00<007ooOol0>7oo00<007ooOol0EGoo00<007ooOol0>7oo00<0
07ooOol0;goo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001;Ool2
0007Ool4001QOol30007Ool3000[Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo00Aoo`03
001oogoo03Qoo`03001oogoo05Ioo`03001oogoo03Moo`03001oogoo031oo`<000eoo`<000Eoo`@0
00Eoo`03001oogoo04aoo`L006Qoo`L002ioo`00>7oo00<007ooOol01Goo00<007ooOol0=goo00<0
07ooOol0EWoo00<007ooOol0=goo00<007ooOol0DGoo00<007ooOol0l7oo000hOol00`00Oomoo`05
Ool00`00Oomoo`0fOol00`00Oomoo`1GOol00`00Oomoo`0fOol00`00Oomoo`1BOol00`00Oomoo`3`
Ool003Qoo`8000Ioo`03001oogoo03Ioo`03001oogoo05Qoo`03001oogoo03Eoo`03001oogoo059o
o`800?5oo`00>7oo00<007ooOol01Woo00<007ooOol0=Goo00<007ooOol0F7oo00<007ooOol0=Goo
00<007ooOol0DWoo00<007ooOol0l7oo000hOol00`00Oomoo`06Ool00`00Oomoo`0dOol00`00Oomo
o`1IOol00`00Oomoo`0dOol00`00Oomoo`1COol00`00Oomoo`3`Ool003Qoo`8000Qoo`03001oogoo
03=oo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo05=oo`800?5oo`00>7oo00<007ooOol0
1goo00<007ooOol0<Woo00<007ooOol0Fgoo00<007ooOol0<Woo00<007ooOol0E7oo00<007ooOol0
l7oo000hOol00`00Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`1LOol00`00Oomoo`0aOol00`00
Oomoo`1DOol00`00Oomoo`3`Ool003Qoo`03001oogoo00Qoo`03001oogoo035oo`03001oogoo05ao
o`03001oogoo035oo`03001oogoo05Aoo`03001oogoo0?1oo`00>7oo0P002Goo00<007ooOol0<7oo
00<007ooOol0GGoo00<007ooOol0<7oo00<007ooOol0EGoo0P00lGoo000OOol30006Ool20005Ool4
0005Ool00`00Oomoo`09Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool00`00Oomo
o`0lOol30006Ool20005Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol00005Ool20009
Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0^
Ool00`00Oomoo`0lOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0l7oo
000NOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0;Woo00<0
07ooOol0Ggoo00<007ooOol0;Woo00<007ooOol0?7oo00D007ooOomoo`00011oo`03001oogoo009o
o`03001oogoo0?1oo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`8000]oo`03001oogoo
02eoo`03001oogoo061oo`03001oogoo02eoo`03001oogoo03aoo`05001oogooOol0000@Ool00`00
Oomoo`02Ool2003aOol001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`0:Ool00`00Oomo
o`0]Ool00`00Oomoo`1POol00`00Oomoo`0/Ool00`00Oomoo`0mOol01@00Oomoogoo000037oo1000
1Goo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol02Woo
00<007ooOol0;7oo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0?Goo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Io
o`8000aoo`03001oogoo02]oo`03001oogoo069oo`03001oogoo02Yoo`03001oogoo03ioo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool2003aOol001moo`<000eoo`@000Eoo`03001oogoo00]oo`03
001oogoo02Yoo`03001oogoo06=oo`03001oogoo02Yoo`03001oogoo03moo`<000eoo`@000Eoo`03
001oogoo0?1oo`00>7oo00<007ooOol037oo00<007ooOol0:Goo00<007ooOol0Hgoo00<007ooOol0
:Woo00<007ooOol0F7oo00<007ooOol0l7oo000hOol00`00Oomoo`0<Ool00`00Oomoo`0YOol00`00
Oomoo`1TOol00`00Oomoo`0XOol00`00Oomoo`1IOol00`00Oomoo`3`Ool003Qoo`8000eoo`03001o
ogoo02Qoo`03001oogoo06Eoo`03001oogoo02Qoo`03001oogoo05Uoo`800?5oo`00>7oo00<007oo
Ool03Goo00<007ooOol09goo00<007ooOol0IWoo00<007ooOol09goo00<007ooOol0FGoo00<007oo
Ool0l7oo000hOol00`00Oomoo`0=Ool00`00Oomoo`0WOol00`00Oomoo`1VOol00`00Oomoo`0VOol0
0`00Oomoo`1JOol00`00Oomoo`3`Ool003Qoo`8000moo`03001oogoo02Eoo`03001oogoo06Qoo`03
001oogoo02Eoo`03001oogoo05Yoo`800?5oo`00>7oo00<007ooOol03Woo00<007ooOol09Goo00<0
07ooOol0J7oo00<007ooOol097oo00<007ooOol0Fgoo00<007ooOol0l7oo000hOol00`00Oomoo`0?
Ool00`00Oomoo`0TOol00`00Oomoo`1XOol00`00Oomoo`0TOol00`00Oomoo`1KOol00`00Oomoo`3`
Ool003Qoo`03001oogoo00moo`03001oogoo02=oo`03001oogoo06Yoo`03001oogoo02=oo`03001o
ogoo05]oo`03001oogoo0?1oo`00>7oo0P0047oo00<007ooOol08goo00<007ooOol0JWoo00<007oo
Ool08Woo00<007ooOol0G7oo0P00lGoo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool0
0`00Oomoo`0@Ool00`00Oomoo`0QOol00`00Oomoo`1/Ool00`00Oomoo`0QOol00`00Oomoo`0kOol3
0006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol00005
Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`0QOol00`00
Oomoo`1/Ool00`00Oomoo`0POol00`00Oomoo`0kOol01@00Oomoogoo00001Goo0P001Woo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol07goo00<007ooOol0KWoo00<007ooOol0
7goo00<007ooOol0>goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo0?1oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80019oo`03
001oogoo01ioo`03001oogoo06moo`03001oogoo01ioo`03001oogoo03aoo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomo
o`03Ool40005Ool00`00Oomoo`0BOol00`00Oomoo`0MOol00`00Oomoo`1`Ool00`00Oomoo`0LOol0
0`00Oomoo`0mOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0l7oo000F
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol04Woo00<007oo
Ool077oo00<007ooOol0LGoo00<007ooOol077oo00<007ooOol0?Goo00D007ooOomoo`0000moo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000]oo`05001o
ogooOol00004Ool00`00Oomoo`06Ool2000DOol00`00Oomoo`0KOol00`00Oomoo`1bOol00`00Oomo
o`0JOol00`00Oomoo`0nOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Io
o`800?5oo`005goo0`0037oo1@0017oo10001Goo00<007ooOol04goo00<007ooOol06Woo00<007oo
Ool0Lgoo00<007ooOol06Woo00<007ooOol0?goo0`0037oo1@0017oo10001Goo00<007ooOol0l7oo
000hOol00`00Oomoo`0DOol00`00Oomoo`0IOol00`00Oomoo`1dOol00`00Oomoo`0HOol00`00Oomo
o`1QOol00`00Oomoo`3`Ool003Qoo`03001oogoo01Aoo`03001oogoo01Qoo`03001oogoo07Eoo`03
001oogoo01Qoo`03001oogoo065oo`03001oogoo0?1oo`00>7oo0P005Woo00<007ooOol05Woo00<0
07ooOol0Mgoo00<007ooOol05Woo00<007ooOol0HWoo0P00lGoo000hOol00`00Oomoo`0FOol00`00
Oomoo`0DOol00`00Oomoo`1iOol00`00Oomoo`0DOol00`00Oomoo`1SOol00`00Oomoo`3`Ool003Qo
o`03001oogoo01Moo`03001oogoo01=oo`03001oogoo07Yoo`03001oogoo01=oo`03001oogoo06=o
o`03001oogoo0?1oo`00>7oo0P006Goo00<007ooOol04Goo00<007ooOol0O7oo00<007ooOol04Goo
00<007ooOol0I7oo0P00lGoo000hOol00`00Oomoo`0IOol00`00Oomoo`0?Ool00`00Oomoo`1nOol0
0`00Oomoo`0?Ool00`00Oomoo`1UOol00`00Oomoo`3`Ool003Qoo`03001oogoo01Uoo`03001oogoo
00ioo`03001oogoo081oo`03001oogoo00eoo`03001oogoo06Ioo`03001oogoo0?1oo`00>7oo00<0
07ooOol06Woo00<007ooOol02goo0P00Q7oo00<007ooOol02goo00<007ooOol0Igoo00<007ooOol0
l7oo000hOol2000LOol00`00Oomoo`09Ool00`00Oomoo`25Ool00`00Oomoo`09Ool00`00Oomoo`1X
Ool2003aOol002moo`D000Aoo`03001oogoo01aoo`<000Moo`03001oogoo08Moo`8000Moo`80069o
o`D000Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol07goo0`0000Aoo`000000
08aoo`<00004Ool00000001VOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Ao
o`80029oo`80095oo`8006Uoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0ogoo9goo00<0
07ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMo
o`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3003oOolWOol3
003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo0`00ogoo1goo0`00
00Aoo`00000001Uoo`<007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000Uoo`05001oogooOol0003o
Ool7Ool01@00Oomoogoo00002Goo1P0037oo00<007ooOol0Lgoo002FOol01@00Oomoogoo000077oo
00<007ooOol0ogoo1Goo00D007ooOomoo`0001Qoo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H0
00eoo`03001oogoo0?moo`Eoo`05001oogooOol00009Ool60009Ool01000Oomoo`00MGoo002FOol0
1@00Oomoogoo00006Woo0P00ogoo27oo00D007ooOomoo`0001Uoo`03001oo`0007Eoo`00UGoo1@00
7Goo00<007ooOol0ogoo17oo1@006Woo00<007oo0000MGoo002cOol01@00Oomoogoo0000ogoo9Woo
0P00MGoo002dOol3003oOolXOol00`00Oomoo`1cOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00;goo1@00ogoo9Goo1@00mgoo000aOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eoo`03001oogoo0?mooaaoo`H000Eoo`03
001oogoo0?Moo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000aOol0
0`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001o
ogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol0
17oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006
Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003a
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00
5goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo
00<007ooOol017oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<0
07ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000io
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?aoo`H0009oo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P00lGoo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007oo
Ool0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo
00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]o
o`05001oogooOol00004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03
001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
;goo2P00]goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0/Ool3000:Ool4002cOol003Qoo`03
001oogoo0?moobMoo`03001oogoo02Qoo`@0015oo`@00:moo`00>7oo0P00ogoo:7oo0P009Woo0`00
6Goo0`00[7oo000OOol30006Ool20005Ool40005Ool00`00Oomoo`3oOol>Ool30006Ool20005Ool4
0005Ool00`00Oomoo`0SOol2000OOol00`00Oomoo`2YOol001ioo`05001oogooOol00005Ool20009
Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0Woo00<007ooOol08Woo00<007ooOol087oo00<007ooOol0Z7oo000FOol60002Ool01@00Oomoogoo
000047oo00<007ooOol00Woo0P00ogoo1Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009o
o`80025oo`8002Aoo`800:Qoo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo
0?moo`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`0VOol0
0`00Oomoo`2UOol001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3oOol=Ool01@00Oomo
ogoo000037oo10001Goo00<007ooOol07Woo00<007ooOol0:7oo0P00YGoo000NOol01@00Oomoogoo
000037oo00<007ooOol01Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo00Io
o`03001oogoo01aoo`8002eoo`03001oogoo0:9oo`007Woo00D007ooOomoo`0000aoo`03001oogoo
00Ioo`8005eoob4008moo`05001oogooOol0000<Ool00`00Oomoo`06Ool2000LOol00`00Oomoo`0^
Ool2002ROol001moo`<000eoo`@000Eoo`03001oogoo059oo`X0025oo`L008Uoo`<000eoo`@000Eo
o`03001oogoo01Yoo`03001oogoo035oo`03001oogoo09moo`00>7oo00<007ooOol0CWoo1000<Woo
1`00Vgoo00<007ooOol067oo0P00=Goo00<007ooOol0WWoo000hOol00`00Oomoo`19Ool5000mOol5
002FOol00`00Oomoo`0GOol00`00Oomoo`0fOol00`00Oomoo`2MOol003Qoo`8004Ioo`@004Moo`@0
099oo`8001Moo`03001oogoo03Qoo`03001oogoo09aoo`00>7oo00<007ooOol0@7oo1@00Cgoo1000
SWoo00<007ooOol05Goo00<007ooOol0>Woo00<007ooOol0Vgoo000hOol00`00Oomoo`0lOol4001H
Ool4002:Ool00`00Oomoo`0DOol00`00Oomoo`0lOol00`00Oomoo`2JOol003Qoo`8003Yoo`<0061o
o`<008Moo`8001Aoo`03001oogoo03ioo`03001oogoo09Uoo`00>7oo00<007ooOol0=Woo0`00IWoo
0`00Q7oo00<007ooOol04Woo00<007ooOol0@7oo00<007ooOol0V7oo000hOol00`00Oomoo`0cOol3
001/Ool40020Ool00`00Oomoo`0AOol00`00Oomoo`12Ool00`00Oomoo`2GOol003Qoo`03001oogoo
031oo`<007=oo`<007eoo`03001oogoo011oo`03001oogoo04Aoo`03001oogoo09Ioo`00>7oo0P00
;Woo0`00NGoo0`00NWoo0P0047oo00<007ooOol0AWoo00<007ooOol0UGoo000GOol30006Ool20004
Ool50004Ool40005Ool00`00Oomoo`0ZOol3001oOol2001GOol30006Ool20004Ool50004Ool40005
Ool00`00Oomoo`0?Ool00`00Oomoo`17Ool00`00Oomoo`2DOol001Ioo`05001oogooOol00005Ool2
0005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0:7oo0P00Q7oo0P00E7oo00D007oo
Oomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomo
o`19Ool00`00Oomoo`2COol000ioo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool2000VOol30028Ool30019Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo
00<007ooOol00Woo0P003Woo00<007ooOol0Bgoo00<007ooOol0TWoo000FOol01@00Oomoogoo0000
3Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol08goo0P00SWoo0P00Cgoo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00aoo`03001oogoo04eoo`03001o
ogoo095oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo025oo`80
099oo`8004eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`0;Ool00`00
Oomoo`1?Ool00`00Oomoo`2@Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`0OOol2002FOol2001;Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol02Woo00<007ooOol0DGoo00<007ooOol0Sgoo000FOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8001eoo`<009Yoo`<004Qoo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P002goo00<007ooOol0DWoo00<007oo
Ool0SWoo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`0JOol2002POol20017Ool3000=Ool3
0005Ool40005Ool00`00Oomoo`09Ool00`00Oomoo`1DOol00`00Oomoo`2=Ool003Qoo`03001oogoo
01Qoo`8000Eoo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<0
01Yoo`<000Ioo`8000Eoo`<000Moo`8001Qoo`D004Uoo`03001oogoo00Qoo`03001oogoo01Aoo`<0
00Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<0009oo`03001oogoo01=oo`<000Ioo`8000Eoo`<0
01Uoo`<000Ioo`8000Eoo`<0025oo`D001Aoo`00>7oo0P005goo0P001Woo00D007ooOomoo`0000Eo
o`8000Eoo`04001oogoo000GOol01@00Oomoogoo00001Goo0P001goo00<007ooOol05Woo00D007oo
Oomoo`0000Eoo`8000Aoo`05001oogooOol0000HOol01@00Oomoogoo00001Goo0P0017oo00D007oo
Oomoo`0000Qoo`8001Qoo`03001oogoo04Uoo`8000Qoo`03001oogoo01Aoo`05001oogooOol00005
Ool20005Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo009oo`03001o
ogoo015oo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Eo
o`8000Aoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo01=oo`<000Qoo`05
001oogooOol0000=Ool00`00Oomoo`0GOol01@00Oomoogoo00002goo1@005goo00D007ooOomoo`00
00]oo`05001oogooOol0000HOol01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`<001Eoo`03
001oogoo04Uoo`03001oogoo00Ioo`03001oogoo01Eoo`05001oogooOol0000=Ool00`00Oomoo`0G
Ool01@00Oomoogoo00002goo1@000goo00<007ooOol04Goo00D007ooOomoo`0000]oo`05001oogoo
Ool0000GOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<0
07ooOol04Goo0P002goo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool0
1000Oomoo`0067oo00D007ooOomoo`0000]oo`05001oogooOol0000HOol01@00Oomoogoo00002goo
00D007ooOomoo`0000eoo`8001=oo`03001oogoo04Uoo`03001oogoo00Ioo`03001oogoo01Eoo`05
001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol000Eoo`03001o
ogoo011oo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000]oo`05001o
ogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo00moo`8000eoo`05001oogooOol0000?
Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`0000]oo`@0
01Uoo`05001oogooOol0000<Ool3000@Ool2000AOol00`00Oomoo`19Ool00`00Oomoo`05Ool00`00
Oomoo`0FOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`00
00Ioo`03001oogoo00moo`05001oogooOol0000;Ool4000HOol01@00Oomoogoo000037oo0`008goo
00<007ooOol057oo000hOol2000=Ool3000?Ool01@00Oomoogoo00003goo00<007ooOol05Goo00D0
07ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`0JOol01@00Oomo
ogoo00002goo00D007ooOomoo`00015oo`<000ioo`03001oogoo04Uoo`8000Eoo`03001oogoo01Mo
o`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo00001goo00<0
07ooOol03Woo00D007ooOomoo`0000]oo`03001oogoo01Uoo`05001oogooOol0000;Ool01@00Oomo
ogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0:Ool2000BOol01@00Oomoogoo00002goo
00D007ooOomoo`0001Moo`05001oogooOol0000=Ool2000HOol01@00Oomoogoo000037oo00<007oo
Ool06Goo00D007ooOomoo`0000]oo`05001oogooOol0000DOol2000<Ool00`00Oomoo`19Ool00`00
Oomoo`03Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogoo
Ool0000=Ool20008Ool00`00Oomoo`0=Ool01@00Oomoogoo000037oo00<007ooOol067oo00D007oo
Oomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo00Moo`<001Eo
o`<000eoo`<001Uoo`<000moo`03001oogoo01Moo`<000ioo`<001Uoo`<000eoo`<001Moo`<000Mo
o`<004]oo`03001oogoo009oo`03001oogoo01Yoo`<000eoo`<001Uoo`<000moo`03001oogoo00Mo
o`03001oogoo00eoo`<000ioo`<001Qoo`<000eoo`<0025oo`<001Ioo`00>7oo00<007ooOol01Goo
0P00bWoo0P00Dgoo00D007ooOomoo`0006Eoo`03001oogoo08Ioo`00>7oo0P0017oo0P00cWoo0P00
DGoo0P0000=oo`00Ool0IWoo00<007ooOol0QGoo000hOol00`00Oomoo`03003BOol3001>Ool00`00
Ool0001YOol00`00Oomoo`24Ool003Qoo`<00=Qoo`8004aoo`8006]oo`03001oogoo08=oo`00<Woo
j@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0DOol003Qoo`03001oogoo02Uoo`03
001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo02Uoo`03001oogoo04Uoo`03
001oogoo02Uoo`03001oogoo02Uoo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo02Uoo`03
001oogoo02Uoo`03001oogoo01Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0KGoo00<007oo
Ool0J7oo00<007ooOol05Goo000hOol2003oOolXOol2001_Ool00`00Oomoo`1VOol00`00Oomoo`0F
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo06moo`03001oogoo06Aoo`03001oogoo01Moo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0L7oo00<007ooOol0HWoo00<007ooOol067oo000hOol2
003oOolXOol2001aOol00`00Oomoo`1QOol00`00Oomoo`0IOol003Qoo`03001oogoo0?moobMoo`03
001oogoo075oo`03001oogoo05moo`03001oogoo01Yoo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0LWoo00<007ooOol0GGoo00<007ooOol06goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1c
Ool00`00Oomoo`1KOol00`00Oomoo`0LOol003Qoo`800?moobQoo`8007Eoo`03001oogoo05Uoo`03
001oogoo01eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0MGoo00<007ooOol0F7oo00<007oo
Ool07Goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1fOol00`00Oomoo`1FOol00`00Oomoo`0N
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo07Moo`03001oogoo05Aoo`03001oogoo01moo`00
>7oo0P00ogoo:7oo0P00NGoo00<007ooOol0DWoo00<007ooOol087oo000GOol30006Ool20004Ool5
0004Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`1i
Ool00`00Oomoo`1@Ool00`00Oomoo`0QOol001Ioo`05001oogooOol00005Ool20005Ool01000Oomo
o`0027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Eoo`04001o
ogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`1jOol00`00Oomoo`1>Ool00`00Oomoo`0ROol001Io
o`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo0P00O7oo00<007ooOol0C7oo00<007ooOol08goo
000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo07aoo`03001oogoo
04Yoo`03001oogoo02Aoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001o
ogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1mOol00`00
Oomoo`18Ool00`00Oomoo`0UOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol0OWoo00<007ooOol0AGoo0P00:7oo000FOol01@00Oomoogoo00002goo00D007ooOomo
o`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol01Woo0P00P7oo00<007ooOol0@goo00<007ooOol0:7oo000GOol3000=Ool30005Ool4
0005Ool00`00Oomoo`3oOol6Ool3000=Ool30005Ool40005Ool00`00Oomoo`20Ool00`00Oomoo`11
Ool00`00Oomoo`0YOol003Qoo`03001oogoo0?moobMoo`03001oogoo085oo`03001oogoo03moo`03
001oogoo02Yoo`00>7oo0P00ogoo:7oo0P00Pgoo00<007ooOol0?Goo00<007ooOol0:goo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`23Ool00`00Oomoo`0kOol00`00Oomoo`0/Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo08Aoo`03001oogoo03Uoo`03001oogoo02eoo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0QGoo00<007ooOol0=goo00<007ooOol0;Woo000hOol2003oOolXOol20027
Ool00`00Oomoo`0eOol00`00Oomoo`0_Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Moo`80
03=oo`80039oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0RGoo00<007ooOol0;goo00<007oo
Ool0<Woo000hOol2003oOolXOol2002;Ool00`00Oomoo`0]Ool00`00Oomoo`0cOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo08]oo`8002aoo`03001oogoo03Aoo`007goo0`001Woo0P001Goo1000
1Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0SGoo00<007ooOol0:7oo
00<007ooOol0=Goo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0
ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo08ioo`03001oogoo
02Ioo`03001oogoo03Ioo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`ioo`05
001oogooOol0000@Ool00`00Oomoo`02Ool2002@Ool00`00Oomoo`0TOol00`00Oomoo`0gOol001io
o`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000047oo
00<007ooOol00Woo00<007ooOol0T7oo0P008Woo0P00>Woo000NOol01@00Oomoogoo000037oo1000
1Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo099oo`<001aoo`<0
03aoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogoo
Ool0000<Ool00`00Oomoo`06Ool00`00Oomoo`2EOol2000HOol2000oOol001ioo`05001oogooOol0
000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P00V7oo
0P0057oo0P00@Goo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00
Oomoo`2IOol3000>Ool30013Ool003Qoo`03001oogoo0?moobMoo`03001oogoo09aoo`h004Ioo`00
>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2
003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol001Moo`<000Ioo`8000Ioo`03001o
ogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03
001oogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009o
o`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00ogoo1Woo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?5oo`005Woo00D007ooOomo
o`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00
Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001o
ogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo00<007ooOol0l7oo000GOol3000<Ool50004Ool40005Ool2003oOol7Ool3000<Ool50004
Ool40005Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00
;goo1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001o
ogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3
003oOolWOol3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo1@00
ogoo1Goo0`0000Aoo`00000001Moo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001o
ogoo0?moo`Ioo`05001oogooOol00009Ool6000:Ool01000Oomoo`00M7oo002FOol01@00Oomoogoo
00006goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001Yoo`03001oogoo07Aoo`00UWoo00D007oo
Oomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000<Ool00`00Oomo
o`1cOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo000077oo00<0
07ooOol0LWoo002EOol5000LOol00`00Oomoo`3oOol5Ool5000MOol00`00Oomoo`1bOol00;Ioo`03
001oogoo0?moob=oo`05001oogooOol0001dOol00;Aoo`<00?moobIoo`<007Eoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .40229 L
.08255 .4463 L
.10458 .48823 L
.12507 .51966 L
.14415 .54119 L
.14918 .54552 L
.15465 .54955 L
.15946 .55253 L
.16457 .55507 L
.16917 .55683 L
.17178 .5576 L
.17423 .55817 L
.17538 .55839 L
.17647 .55857 L
.17746 .5587 L
.17852 .55882 L
.17967 .55892 L
.18073 .55898 L
.182 .55901 L
.18314 .55901 L
.18435 .55898 L
.18547 .55891 L
.1867 .55881 L
.18802 .55865 L
.19071 .5582 L
.19317 .55764 L
.1979 .55613 L
.20239 .55421 L
.21236 .54821 L
.22321 .53904 L
.24299 .51561 L
.26399 .4821 L
.30174 .40433 L
.34195 .30734 L
.38063 .21407 L
.40028 .17118 L
.42177 .13026 L
.44253 .09836 L
.4614 .07704 L
.47149 .0689 L
.47611 .06597 L
.48101 .06342 L
.4835 .06234 L
.48624 .06133 L
.48876 .06056 L
.49106 .05999 L
.49378 .05949 L
.49527 .05929 L
.49596 .05922 L
Mistroke
.49669 .05915 L
.498 .05907 L
.49921 .05902 L
.49996 .05902 L
.50065 .05902 L
.50196 .05906 L
.50313 .05914 L
.50438 .05925 L
.50556 .05939 L
.50663 .05955 L
.50926 .06007 L
.51175 .0607 L
.5167 .06242 L
.52208 .06496 L
.53169 .07121 L
.54056 .07889 L
.55926 .10079 L
.57988 .13315 L
.62014 .21584 L
.65888 .30938 L
.70007 .40846 L
.72063 .45277 L
.73974 .48866 L
.75939 .51886 L
.77791 .54011 L
.78775 .54829 L
.79293 .55168 L
.7984 .55458 L
.80302 .55647 L
.80546 .55726 L
.80809 .55794 L
.8105 .55842 L
.8127 .55874 L
.81375 .55885 L
.81491 .55894 L
.81599 .55899 L
.817 .55901 L
.81818 .55901 L
.81941 .55897 L
.82047 .55891 L
.82163 .5588 L
.82287 .55866 L
.82421 .55846 L
.82661 .55799 L
.82905 .55738 L
.83134 .55666 L
.83564 .55498 L
.84078 .55239 L
.84552 .54944 L
.85624 .54084 L
Mistroke
.87498 .5196 L
.89561 .48791 L
.93591 .40604 L
.97471 .31269 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35562 L
.08255 .37584 L
.0932 .38473 L
.10458 .39259 L
.11009 .39572 L
.11531 .39827 L
.12038 .40034 L
.12507 .40189 L
.12951 .40303 L
.13178 .40349 L
.13422 .40389 L
.13549 .40406 L
.13666 .40419 L
.13784 .4043 L
.13895 .40438 L
.14022 .40445 L
.1409 .40448 L
.14161 .4045 L
.1423 .40451 L
.14295 .40451 L
.14415 .40449 L
.14531 .40446 L
.14656 .40439 L
.14773 .40431 L
.14881 .40421 L
.15143 .4039 L
.15392 .40349 L
.15886 .40239 L
.16423 .40074 L
.17383 .39665 L
.1827 .39161 L
.20137 .37744 L
.22197 .35704 L
.26217 .30868 L
.30086 .26207 L
.32051 .24232 L
.3309 .23361 L
.342 .22586 L
.35275 .22006 L
.35784 .21793 L
.36253 .21633 L
.36724 .21508 L
.36972 .21457 L
.37235 .21414 L
.37463 .21386 L
.37573 .21375 L
.37677 .21367 L
.37799 .2136 L
.37911 .21355 L
Mistroke
.38031 .21353 L
.38162 .21353 L
.38227 .21354 L
.38296 .21356 L
.38419 .21361 L
.38551 .2137 L
.38695 .21382 L
.38955 .21414 L
.39197 .21453 L
.39649 .21553 L
.40134 .21696 L
.40698 .2191 L
.41232 .22159 L
.42232 .2274 L
.44227 .24311 L
.4607 .26169 L
.50002 .30904 L
.53782 .35472 L
.55884 .37593 L
.56803 .38368 L
.57808 .39089 L
.58722 .39621 L
.59696 .40048 L
.60236 .4022 L
.60726 .40336 L
.60962 .40377 L
.61086 .40395 L
.61218 .40412 L
.61333 .40424 L
.61459 .40434 L
.61574 .40442 L
.61682 .40447 L
.61808 .4045 L
.61871 .40451 L
.61941 .40451 L
.62065 .40449 L
.62181 .40444 L
.62248 .40441 L
.62318 .40437 L
.62443 .40427 L
.62578 .40413 L
.62725 .40395 L
.62973 .40356 L
.63238 .40304 L
.63715 .4018 L
.64214 .40011 L
.64686 .39815 L
.6557 .39356 L
.67568 .37906 L
.69413 .36136 L
Mistroke
.7335 .3148 L
.77136 .26844 L
.79241 .24629 L
.81166 .23021 L
.82118 .22408 L
.8262 .22137 L
.83155 .21892 L
.8367 .21698 L
.84136 .21559 L
.84361 .21504 L
.84604 .21455 L
.84835 .21417 L
.85045 .2139 L
.85159 .21378 L
.85283 .21368 L
.85414 .2136 L
.85538 .21355 L
.85653 .21353 L
.85776 .21353 L
.85881 .21355 L
.85997 .21359 L
.86063 .21363 L
.86132 .21367 L
.86256 .21377 L
.86535 .21409 L
.86777 .21446 L
.87041 .21498 L
.87569 .21637 L
.88133 .21835 L
.89148 .22316 L
.90173 .22958 L
.91284 .23817 L
.933 .25749 L
.97393 .30617 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .29688 L
.10458 .28387 L
.14415 .2721 L
.18221 .26136 L
.22272 .25076 L
.26171 .24154 L
.30316 .23296 L
.34309 .22603 L
.3815 .22073 L
.40095 .21858 L
.42237 .21664 L
.44268 .21523 L
.45178 .21473 L
.46172 .21429 L
.4671 .21409 L
.4721 .21393 L
.47727 .21379 L
.48196 .21369 L
.48658 .21362 L
.4887 .21359 L
.49093 .21357 L
.49332 .21355 L
.49438 .21354 L
.49552 .21354 L
.49675 .21353 L
.49789 .21353 L
.49859 .21353 L
.49925 .21353 L
.50049 .21353 L
.50163 .21353 L
.50286 .21353 L
.50401 .21353 L
.50508 .21354 L
.50754 .21356 L
.51014 .21358 L
.51268 .21361 L
.51504 .21364 L
.5204 .21374 L
.5293 .21397 L
.53882 .21431 L
.54906 .21477 L
.56016 .2154 L
.58032 .21686 L
.62123 .22106 L
.66064 .22662 L
.69852 .23328 L
.73886 .24167 L
.77769 .25086 L
.81897 .26168 L
Mistroke
.85873 .27294 L
.89697 .28435 L
.93767 .29692 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .24598 L
.10458 .18202 L
.14415 .13074 L
.18221 .09278 L
.20178 .07843 L
.21267 .07209 L
.22272 .06733 L
.23293 .06357 L
.23832 .06204 L
.24402 .06075 L
.24641 .06032 L
.24897 .05993 L
.25119 .05964 L
.25361 .05939 L
.25507 .05927 L
.25643 .05918 L
.25773 .05911 L
.2584 .05908 L
.25912 .05906 L
.25983 .05904 L
.26048 .05903 L
.26176 .05902 L
.26293 .05902 L
.26416 .05904 L
.26538 .05908 L
.26607 .05911 L
.26671 .05914 L
.26912 .0593 L
.27131 .0595 L
.27364 .05977 L
.27847 .06051 L
.2838 .06162 L
.29326 .06435 L
.30213 .06777 L
.32232 .07861 L
.34082 .09214 L
.38045 .13165 L
.41855 .18106 L
.45912 .2424 L
.49816 .30598 L
.53966 .37368 L
.57964 .43441 L
.61811 .48469 L
.63759 .50605 L
.65902 .52577 L
.67938 .5405 L
.69843 .5505 L
.70884 .55437 L
.71396 .55585 L
Mistroke
.71872 .55698 L
.72301 .55778 L
.72758 .55842 L
.7302 .55868 L
.73148 .55878 L
.73266 .55886 L
.73371 .55891 L
.73487 .55896 L
.73603 .55899 L
.73725 .55901 L
.73856 .55902 L
.73977 .559 L
.7404 .55899 L
.7411 .55897 L
.74251 .55891 L
.74375 .55884 L
.74508 .55875 L
.74748 .55854 L
.74985 .55827 L
.75235 .55791 L
.7568 .55712 L
.76198 .55592 L
.7668 .55455 L
.77773 .55052 L
.78828 .54544 L
.79823 .5396 L
.81683 .52604 L
.85534 .48788 L
.89632 .43474 L
.93577 .3749 L
.97371 .31311 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`1XOol7002gOol00`00Oomoo`3`Ool003Qoo`8006Moo`8000Moo`<00;Aoo`800?5oo`00
5goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0I7oo0P0037oo00<007ooOol0
T7oo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0Hgoo00<007ooOol03Goo
0P00Sgoo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo
0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8006=o
o`03001oogoo011oo`03001oogoo08Aoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`1ROol00`00Oomoo`0@Ool00`00Oomoo`2<Ool01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol0
0goo10001Goo00<007ooOol0HGoo00<007ooOol04Woo00<007ooOol0Rgoo00D007ooOomoo`0000io
o`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo061oo`03001oogoo01Aoo`03001oogoo08Yoo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0
000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00H7oo00<007ooOol05Goo00<007ooOol0
RWoo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003aOol001Moo`<0
00aoo`D000Aoo`@000Eoo`03001oogoo05ioo`03001oogoo01Moo`03001oogoo08Yoo`<000aoo`D0
00Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0GWoo00<007ooOol067oo00<007ooOol0
ZWoo00<007ooOol0l7oo000hOol2001NOol00`00Oomoo`0IOol00`00Oomoo`2ZOol2003aOol003Qo
o`03001oogoo05aoo`03001oogoo01]oo`03001oogoo0:Uoo`03001oogoo0?1oo`00>7oo00<007oo
Ool0Fgoo00<007ooOol07Goo00<007ooOol0Z7oo00<007ooOol0l7oo000hOol00`00Oomoo`1KOol0
0`00Oomoo`0NOol00`00Oomoo`2WOol00`00Oomoo`3`Ool003Qoo`8005]oo`03001oogoo01moo`03
001oogoo0:Moo`800?5oo`00>7oo00<007ooOol0FGoo00<007ooOol08Goo00<007ooOol0YWoo00<0
07ooOol0l7oo000hOol00`00Oomoo`1IOol00`00Oomoo`0ROol00`00Oomoo`2UOol00`00Oomoo`3`
Ool003Qoo`8005Uoo`03001oogoo02=oo`03001oogoo0:Eoo`800?5oo`007goo0`001Woo0P001Goo
10001Goo00<007ooOol0F7oo00<007ooOol097oo00<007ooOol0Rgoo0`001Woo0P001Goo10001Goo
00<007ooOol0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0
Egoo00<007ooOol09Goo00<007ooOol0RWoo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009o
o`03001oogoo0?1oo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo
05Moo`03001oogoo02Ioo`03001oogoo085oo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02
Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2001GOol00`00Oomo
o`0WOol00`00Oomoo`29Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00
Oomoogoo000037oo10001Goo00<007ooOol0EWoo00<007ooOol0:7oo00<007ooOol0R7oo00D007oo
Oomoo`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Io
o`03001oogoo05Eoo`03001oogoo02Uoo`03001oogoo08Qoo`05001oogooOol0000<Ool00`00Oomo
o`06Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1E
Ool00`00Oomoo`0ZOol00`00Oomoo`27Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007oo
Ool0l7oo000OOol3000=Ool40005Ool2001EOol00`00Oomoo`0[Ool00`00Oomoo`28Ool3000=Ool4
0005Ool2003aOol003Qoo`03001oogoo05Aoo`03001oogoo02aoo`03001oogoo0:1oo`03001oogoo
0?1oo`00>7oo00<007ooOol0Dgoo00<007ooOol0;Goo00<007ooOol0X7oo00<007ooOol0l7oo000h
Ool2001DOol00`00Oomoo`0]Ool00`00Oomoo`2POol2003aOol003Qoo`03001oogoo05=oo`03001o
ogoo02ioo`03001oogoo09moo`03001oogoo0?1oo`00>7oo00<007ooOol0DWoo00<007ooOol0;goo
00<007ooOol0Wgoo00<007ooOol0l7oo000hOol00`00Oomoo`1BOol00`00Oomoo`0`Ool00`00Oomo
o`2NOol00`00Oomoo`3`Ool003Qoo`80059oo`03001oogoo035oo`03001oogoo09ioo`800?5oo`00
>7oo00<007ooOol0DGoo00<007ooOol0<Woo00<007ooOol0WGoo00<007ooOol0l7oo000hOol00`00
Oomoo`1AOol00`00Oomoo`0bOol00`00Oomoo`2MOol00`00Oomoo`3`Ool003Qoo`80055oo`03001o
ogoo03Aoo`03001oogoo09aoo`8004aoo`/006=oo`/002aoo`005goo0`001Woo0P0017oo1@0017oo
10001Goo00<007ooOol0D7oo00<007ooOol0=7oo00<007ooOol0Ngoo0`001Woo0P0017oo1@0017oo
10001Goo00<007ooOol0BGoo0P002goo00<007ooOol0GWoo0P002goo0P00:Woo000FOol01@00Oomo
ogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo04moo`03001oogoo
03Ioo`03001oogoo07Uoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol0
0Woo00<007ooOol0B7oo00<007ooOol037oo0P00G7oo0P003goo0P00:7oo000>Ool60002Ool01@00
Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0Cgoo00<007ooOol0=Woo
00<007ooOol0LGoo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo04Ioo`80015oo`8005Uoo`03001oogoo015oo`8002Ioo`005Woo00D007ooOomoo`0000io
o`03001oogoo00Moo`03001oogoo009oo`8004moo`03001oogoo03Moo`03001oogoo07Uoo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20015Ool2000EOol00`00Oomoo`1DOol2
000FOol00`00Oomoo`0SOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00
Oomoo`1>Ool00`00Oomoo`0hOol00`00Oomoo`1hOol01@00Oomoogoo00003goo00<007ooOol00Woo
10001Goo00<007ooOol0@goo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05goo00<007oo
Ool08Woo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
CWoo00<007ooOol0>7oo00<007ooOol0N7oo00D007ooOomoo`0000moo`03001oogoo009oo`03001o
ogoo00Ioo`03001oogoo049oo`03001oogoo01Qoo`03001oogoo051oo`03001oogoo01Qoo`03001o
ogoo029oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001>
Ool00`00Oomoo`0jOol00`00Oomoo`1gOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03
001oogoo00Ioo`80049oo`03001oogoo01Yoo`03001oogoo04ioo`03001oogoo01Yoo`03001oogoo
025oo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0CGoo00<007ooOol0>Woo00<007ooOol0
N7oo0`003Goo0`001Goo10001Goo00<007ooOol0@7oo00<007ooOol077oo00<007ooOol0C7oo00<0
07ooOol077oo00<007ooOol087oo000hOol00`00Oomoo`1<Ool00`00Oomoo`0kOol00`00Oomoo`2I
Ool00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`0O
Ool003Qoo`03001oogoo01moo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Io
o`8000Eoo`<00003Ool007oo01Moo`<000Ioo`8000Eoo`<0025oo`D004Uoo`03001oogoo01moo`<0
00Ioo`8000Aoo`D000]oo`03001oogoo00Yoo`<000Ioo`8000Ioo`<0009oo`03001oogoo01=oo`<0
00Ioo`8000Eoo`<001Uoo`<000Ioo`8000Eoo`<001Uoo`03001oogoo00Eoo`D001Aoo`00>7oo0P00
7goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol20002Ool00`00Oomoo`03Ool20007
Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00@007ooOomoo`8001Moo`05001oogoo
Ool00005Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo0P007goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo000:Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P001goo00<0
07ooOol00Woo00<007ooOol04Goo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000GOol0
1@00Oomoogoo000017oo0`0017oo00D007ooOomoo`0001Qoo`03001oogoo00Moo`03001oogoo01Ao
o`00>7oo00<007ooOol07Woo00D007ooOomoo`0000eoo`03001oogoo01Moo`80009oo`03001oogoo
00Uoo`D001Moo`05001oogooOol0000;Ool01`00Oomoogoo001oo`0001Ioo`05001oogooOol0000;
Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000eoo`03
001oogoo00Yoo`03001oogoo00Yoo`05001oogooOol0000;Ool50003Ool00`00Oomoo`0AOol01@00
Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol00003Ool00`00Oomoo`05Ool01@00
Oomoogoo00006Goo00<007ooOol01Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomo
ogoo00003Woo00<007ooOol05Woo0P000Woo00<007ooOol02Goo00@007ooOol001Qoo`05001oogoo
Ool0000;Ool01`00Oomoogoo001oo`0001Ioo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo
00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo00Qoo`03001oogoo
00]oo`05001oogooOol0000;Ool01000Oomoo`001Goo00<007ooOol047oo00D007ooOomoo`0000]o
o`05001oogooOol0000GOol01@00Oomoogoo00000goo00<007ooOol01Goo00D007ooOomoo`0001Yo
o`03001oogoo00Eoo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000moo`03
001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10000goo
00<007ooOol04goo00D007ooOomoo`0000aoo`<002=oo`03001oogoo04Uoo`03001oogoo01ioo`05
001oogooOol0000?Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool01@00Oomoogoo000037oo00<007oo
00001Woo00<007ooOol03goo00D007ooOomoo`0000]oo`@001Qoo`05001oogooOol00002Ool00`00
Oomoo`07Ool3000LOol00`00Oomoo`04Ool00`00Oomoo`0DOol003Qoo`8001moo`05001oogooOol0
000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`0000]o
o`03001oogoo00Aoo`03001oogoo01=oo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<0
07ooOol0BGoo0P007goo00D007ooOomoo`0000moo`03001oogoo00Eoo`03001oogoo00eoo`05001o
ogooOol0000<Ool00`00Ool00007Ool00`00Oomoo`0>Ool01@00Oomoogoo00002goo00<007ooOol0
6Goo00L007ooOomoo`00Ool00009Ool01@00Oomoogoo000077oo00<007ooOol00goo00<007ooOol0
57oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00002goo00D007ooOomoo`0001Ioo`8000=oo`03
001oogoo00]oo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`03Ool00`00Oomoo`0COol01@00
Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03001oogoo01ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo00001Woo00<007ooOol03Woo00D007ooOomoo`0000eoo`8000Qoo`03
001oogoo00eoo`05001oogooOol0000<Ool00`00Oomoo`0HOol01000Oomoogoo0P002Woo00D007oo
Oomoo`0001eoo`03001oogoo009oo`03001oogoo01Aoo`00>7oo00<007ooOol07goo0`003Goo0`00
5goo00<007oo00000P003goo00<007ooOol05goo0`003Woo0`000goo00<007ooOol04goo0`003Goo
0`008Goo0`00Bgoo00<007ooOol07goo0`003Goo0`001Woo00<007ooOol047oo0`003goo00<007oo
Ool01goo00<007ooOol03Goo0`003Woo0`0067oo100037oo0`007goo00<007oo00000P005Woo000h
Ool20019Ool00`00Oomoo`13Ool00`00Oomoo`2EOol2000iOol00`00Oomoo`0/Ool00`00Oomoo`0k
Ool00`00Oomoo`0^Ool00`00Oomoo`0GOol003Qoo`03001oogoo04Qoo`03001oogoo04Aoo`03001o
ogoo09Aoo`03001oogoo03Moo`03001oogoo02ioo`03001oogoo03Yoo`03001oogoo02moo`03001o
ogoo01Ioo`00>7oo00<007ooOol0B7oo00<007ooOol0A7oo00<007ooOol0U7oo00<007ooOol0=Woo
00<007ooOol0<7oo00<007ooOol0>7oo00<007ooOol0<Goo00<007ooOol05Goo000hOol00`00Oomo
o`17Ool00`00Oomoo`15Ool00`00Oomoo`2DOol00`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomo
o`0fOol00`00Oomoo`0cOol00`00Oomoo`0DOol0039oonT0041oonT0011oo`00>7oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol017oo00D007ooOomoo`0000Yoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`05001oogooOol00006Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool2
001;Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool2000:Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`0DOol003Qoo`8004Moo`03001oogoo04Qoo`03001oogoo04Eoo`03001oogoo04Yoo`80
03Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo0P00AWoo00<007ooOol0
BGoo00<007ooOol0A7oo00<007ooOol0Bgoo0`00<Woo00<007ooOol0>7oo00<007ooOol0<7oo00<0
07ooOol0CGoo000hOol00`00Ool00015Ool00`00Oomoo`1:Ool00`00Oomoo`13Ool00`00Oomoo`1;
Ool01000Oomoo`00<7oo00<007ooOol0>Woo00<007ooOol0;Woo00<007ooOol0CWoo000hOol00`00
Ool00015Ool00`00Oomoo`1:Ool00`00Oomoo`12Ool00`00Oomoo`1<Ool01@00Oomoogoo0000;Woo
00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo000hOol00`00Ool00014Ool00`00Oomo
o`1;Ool00`00Oomoo`12Ool00`00Oomoo`1<Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomo
o`0nOol00`00Oomoo`0ZOol00`00Oomoo`1@Ool003Qoo`800003Ool007oo049oo`03001oogoo04ao
o`03001oogoo045oo`03001oogoo04aoo`8000=oo`03001oogoo02Yoo`03001oogoo03moo`03001o
ogoo02Qoo`03001oogoo055oo`00>7oo00@007ooOol0049oo`03001oogoo04eoo`03001oogoo041o
o`03001oogoo04eoo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo045oo`03001oogoo02Mo
o`03001oogoo055oo`00>7oo00D007ooOomoo`00045oo`03001oogoo04ioo`03001oogoo03moo`03
001oogoo04eoo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03
001oogoo059oo`00>7oo00D007ooOomoo`00041oo`03001oogoo04moo`03001oogoo03ioo`03001o
ogoo04ioo`03001oogoo00Eoo`03001oogoo02Aoo`03001oogoo04Eoo`03001oogoo02=oo`03001o
ogoo05=oo`00>7oo0P000goo00<007ooOol0?Goo00<007ooOol0D7oo00<007ooOol0?Goo00<007oo
Ool0CWoo0P001goo00<007ooOol08Woo00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol0E7oo
000hOol00`00Oomoo`02Ool00`00Oomoo`0mOol00`00Oomoo`1@Ool00`00Oomoo`0lOol00`00Oomo
o`1?Ool00`00Oomoo`07Ool00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomo
o`1EOol003Qoo`03001oogoo009oo`03001oogoo03aoo`03001oogoo055oo`03001oogoo03aoo`03
001oogoo04moo`03001oogoo00Qoo`03001oogoo01ioo`03001oogoo04]oo`03001oogoo01eoo`03
001oogoo05Ioo`00>7oo0P0017oo00<007ooOol0>goo00<007ooOol0DWoo00<007ooOol0>goo00<0
07ooOol0Cgoo0P002Woo00<007ooOol077oo00<007ooOol0CGoo00<007ooOol06goo00<007ooOol0
Egoo000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`03Ool00`00Oomoo`0jOol00`00
Oomoo`1COol00`00Oomoo`0jOol00`00Oomoo`0_Ool30006Ool20004Ool50004Ool40005Ool00`00
Oomoo`0:Ool2000KOol00`00Oomoo`1?Ool00`00Oomoo`0IOol00`00Oomoo`1HOol001Ioo`05001o
ogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool0>Goo00<007ooOol0E7oo00<007ooOol0>Goo00<007ooOol0;Woo00D007ooOomoo`0000Eoo`80
00Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0FOol2001COol0
0`00Oomoo`0FOol2001KOol001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Oomoo`0hOol00`00Oomoo`1EOol00`00Oomoo`0hOol00`00Oomoo`0_
Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol03Goo00<007oo
Ool057oo00<007ooOol0E7oo00<007ooOol04goo0P00GGoo000FOol01@00Oomoogoo00003Woo00<0
07ooOol01goo00<007ooOol00Woo0P001Woo00<007ooOol0=goo00<007ooOol0EWoo00<007ooOol0
=goo00<007ooOol0;goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000mo
o`03001oogoo019oo`03001oogoo05Ioo`03001oogoo015oo`03001oogoo05eoo`005Woo00D007oo
Oomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00Eoo`03001oogoo03Moo`03001oogoo
05Ioo`03001oogoo03Ioo`03001oogoo031oo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005
Ool00`00Oomoo`0?Ool2000@Ool2001JOol2000?Ool2001POol001Ioo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`1GOol0
0`00Oomoo`0fOol00`00Oomoo`0`Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
1Woo00<007ooOol04Goo0P0037oo0P00GWoo0`002goo00<007ooOol0H7oo000FOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000Moo`03001oogoo03Eoo`03001oogoo
05Qoo`03001oogoo03Eoo`03001oogoo031oo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol01Woo0P0057oo0P001goo0`00Hgoo0P001goo0P00Hgoo000GOol3000=Ool30005Ool4
0005Ool00`00Oomoo`06Ool00`00Oomoo`0dOol00`00Oomoo`1IOol00`00Oomoo`0dOol00`00Oomo
o`0bOol3000=Ool30005Ool40005Ool00`00Oomoo`0EOol7001XOol7001UOol003Qoo`03001oogoo
00Moo`03001oogoo03=oo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo05=oo`03001oogoo
0?1oo`00>7oo00<007ooOol01goo00<007ooOol0<Woo00<007ooOol0Fgoo00<007ooOol0<Woo00<0
07ooOol0E7oo00<007ooOol0l7oo000hOol20009Ool00`00Oomoo`0aOol00`00Oomoo`1LOol00`00
Oomoo`0aOol00`00Oomoo`1DOol2003aOol003Qoo`03001oogoo00Qoo`03001oogoo031oo`03001o
ogoo05eoo`03001oogoo031oo`03001oogoo05Eoo`03001oogoo0?1oo`00>7oo00<007ooOol02Goo
00<007ooOol0;goo00<007ooOol0GGoo00<007ooOol0<7oo00<007ooOol0EGoo00<007ooOol0l7oo
000hOol2000:Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0^Ool00`00Oomoo`1FOol2
003aOol003Qoo`03001oogoo00Uoo`03001oogoo02ioo`03001oogoo05moo`03001oogoo02ioo`03
001oogoo05Ioo`03001oogoo0?1oo`00>7oo00<007ooOol02Woo00<007ooOol0;Goo00<007ooOol0
H7oo00<007ooOol0;7oo00<007ooOol0Egoo00<007ooOol0l7oo000hOol00`00Oomoo`0:Ool00`00
Oomoo`0/Ool00`00Oomoo`1QOol00`00Oomoo`0/Ool00`00Oomoo`1GOol00`00Oomoo`3`Ool003Qo
o`8000aoo`03001oogoo02]oo`03001oogoo065oo`03001oogoo02]oo`03001oogoo05Qoo`800?5o
o`007goo0`001Woo0P001Goo10001Goo00<007ooOol02goo00<007ooOol0:Woo00<007ooOol0Hgoo
00<007ooOol0:Woo00<007ooOol0?goo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol0
1@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0:Goo00<0
07ooOol0Hgoo00<007ooOol0:Woo00<007ooOol0?Woo00D007ooOomoo`0000Eoo`8000Uoo`03001o
ogoo009oo`03001oogoo0?1oo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo
00aoo`03001oogoo02Qoo`03001oogoo06Eoo`03001oogoo02Qoo`03001oogoo03moo`05001oogoo
Ool0000@Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool00`00Oomo
o`02Ool2000>Ool00`00Oomoo`0WOol00`00Oomoo`1VOol00`00Oomoo`0WOol00`00Oomoo`0oOol0
1@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomoogoo000037oo10001Goo
00<007ooOol03Woo00<007ooOol09Woo00<007ooOol0IWoo00<007ooOol09Woo00<007ooOol0@7oo
00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`03001oogoo00ioo`03001oogoo02Eoo`03001oogoo06Qoo`03001oogoo02Eoo`03001o
ogoo041oo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001oogoo
Ool0000<Ool00`00Oomoo`06Ool2000@Ool00`00Oomoo`0TOol00`00Oomoo`1XOol00`00Oomoo`0T
Ool00`00Oomoo`11Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P00lGoo000OOol3000=Ool4
0005Ool00`00Oomoo`0?Ool00`00Oomoo`0SOol00`00Oomoo`1ZOol00`00Oomoo`0SOol00`00Oomo
o`12Ool3000=Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo011oo`03001oogoo029oo`03
001oogoo06]oo`03001oogoo025oo`03001oogoo05aoo`03001oogoo0?1oo`00>7oo00<007ooOol0
47oo00<007ooOol08Goo00<007ooOol0K7oo00<007ooOol08Goo00<007ooOol0G7oo00<007ooOol0
l7oo000hOol2000BOol00`00Oomoo`0OOol00`00Oomoo`1^Ool00`00Oomoo`0OOol00`00Oomoo`1M
Ool2003aOol003Qoo`03001oogoo015oo`03001oogoo01moo`03001oogoo06ioo`03001oogoo01io
o`03001oogoo05ioo`03001oogoo0?1oo`00>7oo00<007ooOol04Woo00<007ooOol07Goo00<007oo
Ool0L7oo00<007ooOol07Goo00<007ooOol0GWoo00<007ooOol0l7oo000hOol2000COol00`00Oomo
o`0MOol00`00Oomoo`1aOol00`00Oomoo`0KOol00`00Oomoo`1OOol2003aOol003Qoo`03001oogoo
01=oo`03001oogoo01]oo`03001oogoo079oo`03001oogoo01]oo`03001oogoo05moo`03001oogoo
0?1oo`00>7oo00<007ooOol04goo00<007ooOol06Woo00<007ooOol0M7oo00<007ooOol06Goo00<0
07ooOol0H7oo00<007ooOol0l7oo000hOol00`00Oomoo`0DOol00`00Oomoo`0HOol00`00Oomoo`1f
Ool00`00Oomoo`0GOol00`00Oomoo`1QOol00`00Oomoo`3`Ool003Qoo`8001Ioo`03001oogoo01Io
o`03001oogoo07Qoo`03001oogoo01Ioo`03001oogoo065oo`800?5oo`005goo0`001Woo0P001Woo
00<007ooOol017oo10001Goo00<007ooOol05Woo00<007ooOol057oo00<007ooOol0NWoo00<007oo
Ool057oo00<007ooOol0@Goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0l7oo
000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0
5goo00<007ooOol04Woo00<007ooOol0O7oo00<007ooOol04Woo00<007ooOol0@Goo00D007ooOomo
o`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`005Woo00D007oo
Oomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo01Qoo`03001oogoo011oo`03
001oogoo07ioo`03001oogoo011oo`03001oogoo049oo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool2000JOol00`00Oomoo`0>Ool00`00Oomoo`20Ool00`00Oomoo`0=Ool20015Ool0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00lGoo000FOol01@00Oomoogoo
00003Woo00<007ooOol00goo10001Goo00<007ooOol06Woo00<007ooOol02goo0P00Q7oo00<007oo
Ool02goo00<007ooOol0AGoo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo
0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01]o
o`<000Uoo`03001oogoo08Eoo`03001oogoo00Qoo`8004Qoo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo
000017oo00<007ooOol01Woo0P007goo0P0017oo0`00RGoo10000goo0`00BWoo00D007ooOomoo`00
00]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eo
o`03001oogoo021oo`D008ioo`@004ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000_Ool50004Ool00`00Oomoo`3o
OolNOol50004Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001o
ogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00
lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001o
ogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<0
0004Ool00000000HOol3003oOol7Ool3000017oo000000006Goo0`00M7oo002FOol01@00Oomoogoo
00002Goo1P002Goo00D007ooOomoo`000?moo`Moo`05001oogooOol00009Ool6000<Ool00`00Oomo
o`1cOol009Ioo`05001oogooOol0000LOol00`00Oomoo`3oOol5Ool01@00Oomoogoo000067oo1@00
M7oo002FOol01@00Oomoogoo00002Goo1P003Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Uo
o`H000Uoo`04001oogoo001eOol009Ioo`05001oogooOol0000JOol2003oOol8Ool01@00Oomoogoo
00006Goo00<007oo0000MGoo002EOol5000MOol00`00Oomoo`3oOol4Ool5000JOol00`00Ool0001e
Ool00;=oo`05001oogooOol0003oOolVOol2001eOol00;Aoo`<00?moobQoo`03001oogoo07=oo`00
ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
000_Ool5003oOolUOol5003gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`009Woo1P00
1Goo00<007ooOol0ogoo77oo1P001Goo00<007ooOol0mgoo000aOol00`00Oomoo`04Ool2003oOolQ
Ool00`00Oomoo`04Ool2003aOol0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo
00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo
00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol002mo
o`<000Ioo`03001oogoo0?mooaioo`<000Ioo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo
00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`80
0?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo
035oo`L00;Qoo`00>7oo0P00ogoo:7oo0P00;Goo1P001Woo0`00]Goo000GOol30006Ool20006Ool0
0`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomoo`04Ool40005
Ool00`00Oomoo`0ZOol2000?Ool4002aOol001Ioo`05001oogooOol00005Ool20006Ool00`00Oomo
o`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Woo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol0:7oo0P005Goo0P00[goo000>Ool60002Ool01@00Oomo
ogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0o7oo1P000Woo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo02Moo`03001oogoo01Moo`03001o
ogoo0:aoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Io
o`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000VOol2000KOol2002/Ool0
01Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomo
ogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol08goo0P007goo00<007ooOol0ZGoo000F
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo021o
o`03001oogoo0:Qoo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06
Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`80029o
o`03001oogoo029oo`03001oogoo0:Moo`005goo0`0037oo1@0017oo10001Goo00<007ooOol0ogoo
1Woo0`0037oo1@0017oo10001Goo00<007ooOol08Goo00<007ooOol08goo00<007ooOol0YWoo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`0POol00`00Oomoo`0UOol00`00Oomoo`2UOol003Qoo`03
001oogoo0?moobMoo`03001oogoo01moo`03001oogoo02Moo`03001oogoo0:Aoo`00>7oo0P00ogoo
:7oo0P007goo00<007ooOol0:Goo00<007ooOol0Xgoo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`0MOol00`00Oomoo`0[Ool00`00Oomoo`2ROol003Qoo`03001oogoo0?moobMoo`03001oogoo01ao
o`03001oogoo02eoo`03001oogoo0:5oo`00>7oo0P00ogoo:7oo0P0077oo00<007ooOol0;goo00<0
07ooOol0X7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0JOol00`00Oomoo`0aOol00`00Oomo
o`2OOol003Qoo`03001oogoo0?moobMoo`03001oogoo01Uoo`03001oogoo03=oo`03001oogoo09io
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol06Goo00<007ooOol0<goo00<007ooOol0WWoo000h
Ool2003oOolXOol2000IOol00`00Oomoo`0eOol00`00Oomoo`2MOol001moo`<000Ioo`8000Eoo`@0
00Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo01Moo`03001oogoo03Mo
o`03001oogoo09aoo`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo
0?moo`eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0FOol00`00Oomo
o`0iOol00`00Oomoo`2KOol001Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003o
Ool6Ool60002Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P005Woo00<007ooOol0>Woo00<0
07ooOol0Vgoo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`00011oo`03001oogoo009oo`03001oogoo01Aoo`03001oogoo03aoo`03001oogoo09Yo
o`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool4
0005Ool00`00Oomoo`0DOol00`00Oomoo`0mOol00`00Oomoo`2IOol001ioo`05001oogooOol0000<
Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<0
07ooOol04goo00<007ooOol0?goo00<007ooOol0V7oo000NOol01@00Oomoogoo000037oo00<007oo
Ool01Woo0P00ogoo3Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`8001=oo`03001oogoo041o
o`03001oogoo09Qoo`007goo0`003Goo10001Goo00<007ooOol0ogoo3Woo0`003Goo10001Goo00<0
07ooOol04Goo00<007ooOol0@Woo00<007ooOol0Ugoo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`0@Ool00`00Oomoo`14Ool00`00Oomoo`2FOol003Qoo`03001oogoo0?moobMoo`03001oogoo00mo
o`03001oogoo04Ioo`03001oogoo09Eoo`00>7oo0P00ogoo:7oo0P0047oo00<007ooOol0AWoo00<0
07ooOol0UGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0>Ool00`00Oomoo`18Ool00`00Oomo
o`2DOol003Qoo`03001oogoo0?moobMoo`03001oogoo00eoo`03001oogoo04Yoo`03001oogoo09=o
o`00>7oo0P00ogoo:7oo0P003Woo00<007ooOol0Bgoo00<007ooOol0TWoo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`0<Ool00`00Oomoo`1<Ool00`00Oomoo`2BOol003Qoo`03001oogoo0?moobMo
o`03001oogoo00aoo`03001oogoo04eoo`03001oogoo095oo`00>7oo00<007ooOol0Ggoo6P00[Goo
00<007ooOol02goo00<007ooOol0Cgoo00<007ooOol0T7oo000hOol2001COol=000JOol;002ROol2
000;Ool00`00Oomoo`1@Ool00`00Oomoo`2@Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03
001oogoo04aoo`H0039oo`T007Qoo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Yoo`03
001oogoo055oo`03001oogoo08moo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008
Ool00`00Oomoo`02Ool00`00Oomoo`15Ool70011Ool7001`Ool01@00Oomoogoo00001Goo0P001Goo
00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo05=oo`03001oogoo08io
o`003Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`80045oo`D0
04moo`@006Aoo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000:
Ool00`00Oomoo`1DOol00`00Oomoo`2=Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`0lOol4001HOol5001WOol01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0EGoo00<007ooOol0SGoo000FOol01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0=goo1@00HGoo1@00HWoo00D007oo
Oomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00Moo`03001oogoo05Moo`03001oogoo
08aoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo039o
o`D006]oo`@005ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`1HOol00`00Oomoo`2;Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo
000017oo00<007ooOol01Woo0P00;Woo1@00M7oo1@00FGoo00D007ooOomoo`0000]oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool20007Ool00`00Oomoo`1IOol00`00Oomoo`2;Ool001Moo`<000eo
o`<000Eoo`@000Eoo`03001oogoo02Uoo`@007ioo`@005Ioo`<000eoo`<000Eoo`@000Eoo`03001o
ogoo00Ioo`03001oogoo05Yoo`03001oogoo08Yoo`00>7oo00<007ooOol07goo0`000Woo1P0017oo
1@0067oo0`001Woo0P001Woo0`0067oo0`001Woo0P001Goo0`006Woo0`001Woo2P008Goo1@00BGoo
00<007ooOol01Goo00<007ooOol05goo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`001Goo
00<007ooOol047oo0`001Woo0P001Goo0`006Goo0`001Woo0P001Goo0`008Goo1@0057oo000hOol2
000OOol00`00Oomoo`030004Ool20005Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Mo
o`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool01@00Oomoogoo000067oo00D007ooOomo
o`0000Eoo`8000Aoo`D0029oo`03001oogoo04Uoo`8000Eoo`03001oogoo01Moo`05001oogooOol0
0005Ool20005Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo00Aoo`03
001oogoo00moo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00005goo00D007ooOomoo`00
00Eoo`8000Aoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`<00003
Ool007oo00aoo`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo
00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01000Oomoogoo10007goo00<007ooOol0BGoo
00<007ooOol017oo00<007ooOol05goo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogoo
Ool0000;Ool50006Ool00`00Oomoo`0>Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05
001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0KOol4
0003Ool00`00Oomoo`0<Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol001Qoo`05
001oogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogooOol00003
Ool3000LOol00`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`0HOol01@00Oomoogoo00003Woo
00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo0007Ool00`00Oomoo`0>Ool01@00Oomo
ogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<0
07ooOol057oo000hOol00`00Oomoo`0GOol40003Ool01@00Oomoogoo00003goo00<007ooOol05Goo
00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool4000IOol01@00Oomoogoo
000037oo0`001goo0`006Goo00<007ooOol0BGoo00<007ooOol00Woo00<007ooOol06Goo00D007oo
Oomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool00008Ool00`00Oomoo`0=
Ool01@00Oomoogoo00002goo100067oo00D007ooOomoo`0000aoo`<002=oo`03001oogoo01Aoo`00
>7oo0P004goo1@001goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool0
0`00Ool0000HOol01@00Oomoogoo00002goo00<007ooOol06Woo00D007ooOomoo`0000]oo`05001o
ogooOol00009Ool3000FOol00`00Oomoo`19Ool20003Ool00`00Oomoo`0IOol01@00Oomoogoo0000
3goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0000Uoo`03001oogoo00aoo`05001o
ogooOol0000;Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001o
ogoo01Aoo`00>7oo00<007ooOol03Woo100037oo00D007ooOomoo`0000]oo`05001oogooOol0000G
Ool01@00Oomoogoo00003Goo0P0067oo00D007ooOomoo`0000aoo`03001oogoo01Uoo`05001oogoo
Ool0000;Ool01@00Oomoogoo000037oo0`004goo00<007ooOol0BGoo00D007ooOomoo`0001aoo`05
001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8000Uoo`03001oogoo
00aoo`05001oogooOol0000<Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007ooOomoo`00
029oo`03001oogoo01Aoo`00>7oo00<007ooOol02goo0`004Goo0`003Goo0`006Goo0`003goo00<0
07ooOol05goo0`003Woo0`006Goo0`003Goo0`0047oo10003Goo0`00Bgoo00D007ooOomoo`0001eo
o`<000eoo`<001Uoo`<000moo`03001oogoo00Qoo`03001oogoo00aoo`<000ioo`<001Qoo`<000eo
o`<0025oo`<001Ioo`00>7oo00<007ooOol027oo0`00`7oo1@00EWoo00@007ooOol006Moo`03001o
ogoo08Eoo`00>7oo0P001Woo0`00b7oo1000DWoo0`00JGoo00<007ooOol0Q7oo000hOol00`00Oomo
o`02Ool3003?Ool3001?Ool00`00Ool0001ZOol00`00Oomoo`23Ool003Qoo`03001oo`0000800=Eo
o`<004aoo`8006]oo`03001oogoo08=oo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`19Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`0DOol003Qoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo
02Yoo`03001oogoo02Uoo`03001oogoo04Uoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo
01Aoo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo01Aoo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0KGoo00<007ooOol0J7oo00<007ooOol05Goo000hOol2003oOolX
Ool2001^Ool00`00Oomoo`1WOol00`00Oomoo`0FOol003Qoo`03001oogoo0?moobMoo`03001oogoo
06ioo`03001oogoo06Ioo`03001oogoo01Ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0KWoo
00<007ooOol0IGoo00<007ooOol05goo000hOol2003oOolXOol2001`Ool00`00Oomoo`1TOol00`00
Oomoo`0GOol003Qoo`03001oogoo0?moobMoo`03001oogoo071oo`03001oogoo069oo`03001oogoo
01Qoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0L7oo00<007ooOol0HGoo00<007ooOol06Goo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1aOol00`00Oomoo`1POol00`00Oomoo`0IOol003Qo
o`800?moobQoo`80079oo`03001oogoo05moo`03001oogoo01Yoo`00>7oo00<007ooOol0ogoo9goo
00<007ooOol0LWoo00<007ooOol0GWoo00<007ooOol06Woo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`1cOol00`00Oomoo`1LOol00`00Oomoo`0KOol003Qoo`03001oogoo0?moobMoo`03001oogoo
07=oo`03001oogoo05]oo`03001oogoo01aoo`00>7oo0P00ogoo:7oo0P00MGoo00<007ooOol0FWoo
00<007ooOol077oo000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool30006
Ool20004Ool50004Ool40005Ool00`00Oomoo`1dOol00`00Oomoo`1IOol00`00Oomoo`0MOol001Io
o`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`1e
Ool00`00Oomoo`1HOol00`00Oomoo`0MOol001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool0
0`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo
0P00Mgoo00<007ooOol0EWoo00<007ooOol07Woo000FOol01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo07Moo`03001oogoo05Aoo`03001oogoo01moo`005Woo00D007ooOomo
o`0000moo`03001oogoo009oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00
Oomoo`02Ool40005Ool00`00Oomoo`1gOol00`00Oomoo`1DOol00`00Oomoo`0OOol001Ioo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0N7oo00<007ooOol0DWoo00<007oo
Ool087oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?mo
o`Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00NWoo00<007oo
Ool0D7oo00<007ooOol08Goo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`3oOol6Ool3000=
Ool30005Ool40005Ool00`00Oomoo`1iOol00`00Oomoo`1?Ool00`00Oomoo`0ROol003Qoo`03001o
ogoo0?moobMoo`03001oogoo07Yoo`03001oogoo04ioo`03001oogoo029oo`00>7oo0P00ogoo:7oo
0P00O7oo00<007ooOol0C7oo00<007ooOol08goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1l
Ool00`00Oomoo`1:Ool00`00Oomoo`0TOol003Qoo`03001oogoo0?moobMoo`03001oogoo07aoo`03
001oogoo04Yoo`03001oogoo02Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0OGoo00<007oo
Ool0B7oo00<007ooOol09Goo000hOol2003oOolXOol2001oOol00`00Oomoo`16Ool00`00Oomoo`0V
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo07ioo`03001oogoo04Ioo`03001oogoo02Ioo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0Ogoo00<007ooOol0A7oo00<007ooOol09goo000hOol2
003oOolXOol20021Ool00`00Oomoo`12Ool00`00Oomoo`0XOol003Qoo`03001oogoo0?moobMoo`03
001oogoo085oo`03001oogoo041oo`03001oogoo02Uoo`007goo0`001Woo0P001Goo10001Goo00<0
07ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0PGoo00<007ooOol0@7oo00<007oo
Ool0:Goo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo
00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo089oo`03001oogoo03ioo`03
001oogoo02Yoo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`ioo`05001oogoo
Ool0000@Ool00`00Oomoo`02Ool20024Ool00`00Oomoo`0lOol00`00Oomoo`0[Ool001ioo`05001o
ogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007oo
Ool00Woo00<007ooOol0Q7oo00<007ooOol0>Woo00<007ooOol0;7oo000NOol01@00Oomoogoo0000
37oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo08Aoo`03
001oogoo03Uoo`03001oogoo02eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001o
ogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`25Ool00`00Oomoo`0h
Ool00`00Oomoo`0]Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00
Oomoogoo000037oo00<007ooOol01Woo0P00Qgoo00<007ooOol0=Woo00<007ooOol0;Woo000OOol3
000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`27Ool00`00Oomoo`0d
Ool00`00Oomoo`0_Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Moo`03001oogoo03=oo`03
001oogoo031oo`00>7oo0P00ogoo:7oo0P00RGoo00<007ooOol0<Woo00<007ooOol0<7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`29Ool00`00Oomoo`0`Ool00`00Oomoo`0aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo08Yoo`03001oogoo02ioo`03001oogoo039oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0Rgoo0P00;Goo00<007ooOol0<goo000hOol2003oOolXOol2002>Ool00`00
Oomoo`0YOol00`00Oomoo`0dOol003Qoo`03001oogoo0?moobMoo`03001oogoo08ioo`03001oogoo
02Moo`03001oogoo03Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Sgoo00<007ooOol09Goo
00<007ooOol0=Woo000hOol2003oOolXOol2002AOol2000TOol00`00Oomoo`0gOol001Moo`<000Io
o`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo
00Aoo`@000Eoo`03001oogoo099oo`03001oogoo01moo`8003Yoo`005Woo00D007ooOomoo`0000Eo
o`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005
Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`2COol00`00Oomoo`0LOol2000l
Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0U7oo00<007oo
Ool06Woo00<007ooOol0?7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8009Ioo`80
01Qoo`8003moo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?mo
o`Eoo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`2GOol2000DOol20011
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0VGoo0`003Woo
0`00@goo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001o
ogoo0?moo`Eoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007oo
Ool0W7oo0P002Woo0P00AWoo000GOol3000<Ool50004Ool40005Ool2003oOol7Ool3000<Ool50004
Ool40005Ool2002OOol:0018Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo
00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`80
0?5oo`00;goo1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo000aOol00`00Oomo
o`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Ao
o`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00
ogoo8Goo00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035o
o`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo
000_Ool3003oOolWOol3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo00000000
67oo1@00ogoo1Goo0`0000Aoo`00000001Moo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000ao
o`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000:Ool01000Oomoo`00M7oo002FOol01@00
Oomoogoo00006goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001Yoo`03001oogoo07Aoo`00UWoo
00D007ooOomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000<Ool0
0`00Oomoo`1cOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo0000
77oo00<007ooOol0LWoo002EOol5000LOol00`00Oomoo`3oOol5Ool5000MOol00`00Oomoo`1bOol0
0;Ioo`03001oogoo0?moob=oo`05001oogooOol0001dOol00;Aoo`<00?moobIoo`<007Eoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36136 L
.08255 .38606 L
.10458 .40959 L
.12507 .42722 L
.14415 .43931 L
.14918 .44173 L
.15465 .444 L
.15946 .44567 L
.16457 .4471 L
.16917 .44808 L
.17178 .44851 L
.17423 .44883 L
.17538 .44896 L
.17647 .44905 L
.17746 .44913 L
.17852 .4492 L
.17967 .44925 L
.18073 .44929 L
.182 .44931 L
.18314 .44931 L
.18435 .44929 L
.18547 .44925 L
.1867 .44919 L
.18802 .4491 L
.19071 .44885 L
.19317 .44853 L
.1979 .44769 L
.20239 .44661 L
.21236 .44324 L
.22321 .4381 L
.24299 .42495 L
.26399 .40615 L
.30174 .3625 L
.34195 .30808 L
.38063 .25574 L
.40028 .23167 L
.42177 .2087 L
.44253 .19081 L
.4614 .17884 L
.47149 .17427 L
.47611 .17263 L
.48101 .1712 L
.4835 .17059 L
.48624 .17002 L
.48876 .16959 L
.49106 .16927 L
.49378 .16899 L
.49527 .16888 L
.49596 .16884 L
Mistroke
.49669 .1688 L
.498 .16875 L
.49921 .16873 L
.49996 .16873 L
.50065 .16873 L
.50196 .16875 L
.50313 .16879 L
.50438 .16886 L
.50556 .16894 L
.50663 .16903 L
.50926 .16931 L
.51175 .16967 L
.5167 .17064 L
.52208 .17206 L
.53169 .17557 L
.54056 .17988 L
.55926 .19217 L
.57988 .21032 L
.62014 .25673 L
.65888 .30922 L
.70007 .36482 L
.72063 .38968 L
.73974 .40982 L
.75939 .42677 L
.77791 .4387 L
.78775 .44329 L
.79293 .44519 L
.7984 .44682 L
.80302 .44788 L
.80546 .44832 L
.80809 .4487 L
.8105 .44897 L
.8127 .44915 L
.81375 .44921 L
.81491 .44926 L
.81599 .44929 L
.817 .44931 L
.81818 .4493 L
.81941 .44928 L
.82047 .44925 L
.82163 .44919 L
.82287 .44911 L
.82421 .449 L
.82661 .44873 L
.82905 .44839 L
.83134 .44799 L
.83564 .44704 L
.84078 .44559 L
.84552 .44393 L
.85624 .43911 L
Mistroke
.87498 .42719 L
.89561 .40941 L
.93591 .36346 L
.97471 .31108 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .43101 L
.08255 .48397 L
.0932 .50724 L
.10458 .5278 L
.11009 .53602 L
.11531 .54268 L
.12038 .5481 L
.12507 .55216 L
.12951 .55515 L
.13178 .55635 L
.13422 .55739 L
.13549 .55784 L
.13666 .55818 L
.13784 .55847 L
.13895 .55868 L
.14022 .55887 L
.1409 .55893 L
.14161 .55898 L
.1423 .55901 L
.14295 .55902 L
.14415 .55898 L
.14531 .55889 L
.14656 .55872 L
.14773 .5585 L
.14881 .55825 L
.15143 .55742 L
.15392 .55636 L
.15886 .55347 L
.16423 .54914 L
.17383 .53844 L
.1827 .52525 L
.20137 .48814 L
.22197 .43474 L
.26217 .30814 L
.30086 .1861 L
.32051 .1344 L
.3309 .11159 L
.342 .09132 L
.35275 .07612 L
.35784 .07055 L
.36253 .06637 L
.36724 .0631 L
.36972 .06176 L
.37235 .06063 L
.37463 .05989 L
.37573 .05961 L
.37677 .0594 L
.37799 .05921 L
.37911 .05909 L
Mistroke
.38031 .05903 L
.38162 .05903 L
.38227 .05905 L
.38296 .0591 L
.38419 .05924 L
.38551 .05947 L
.38695 .0598 L
.38955 .06062 L
.39197 .06165 L
.39649 .06425 L
.40134 .068 L
.40698 .07361 L
.41232 .08012 L
.42232 .09535 L
.44227 .13647 L
.4607 .18512 L
.50002 .30909 L
.53782 .42867 L
.55884 .48419 L
.56803 .50449 L
.57808 .52337 L
.58722 .53729 L
.59696 .54848 L
.60236 .55298 L
.60726 .556 L
.60962 .55709 L
.61086 .55756 L
.61218 .55799 L
.61333 .55831 L
.61459 .55859 L
.61574 .55878 L
.61682 .55891 L
.61808 .559 L
.61871 .55901 L
.61941 .55901 L
.62065 .55896 L
.62181 .55885 L
.62248 .55876 L
.62318 .55865 L
.62443 .55839 L
.62578 .55803 L
.62725 .55755 L
.62973 .55654 L
.63238 .55516 L
.63715 .55192 L
.64214 .5475 L
.64686 .54237 L
.6557 .53035 L
.67568 .4924 L
.69413 .44605 L
Mistroke
.7335 .32417 L
.77136 .20279 L
.79241 .1448 L
.81166 .1027 L
.82118 .08664 L
.8262 .07956 L
.83155 .07313 L
.8367 .06806 L
.84136 .06442 L
.84361 .06299 L
.84604 .06169 L
.84835 .0607 L
.85045 .05999 L
.85159 .05969 L
.85283 .05942 L
.85414 .05921 L
.85538 .05908 L
.85653 .05903 L
.85776 .05903 L
.85881 .05908 L
.85997 .05919 L
.86063 .05928 L
.86132 .0594 L
.86256 .05966 L
.86535 .06048 L
.86777 .06147 L
.87041 .06284 L
.87569 .06646 L
.88133 .07164 L
.89148 .08424 L
.90173 .10105 L
.91284 .12354 L
.933 .17412 L
.97393 .30158 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30287 L
.10458 .29629 L
.14415 .29033 L
.18221 .28489 L
.22272 .27953 L
.26171 .27486 L
.30316 .27051 L
.34309 .26701 L
.3815 .26432 L
.40095 .26323 L
.42237 .26225 L
.44268 .26154 L
.45178 .26129 L
.46172 .26106 L
.4671 .26096 L
.4721 .26088 L
.47727 .26081 L
.48196 .26076 L
.48658 .26072 L
.4887 .26071 L
.49093 .2607 L
.49332 .26069 L
.49438 .26068 L
.49552 .26068 L
.49675 .26068 L
.49789 .26068 L
.49859 .26068 L
.49925 .26068 L
.50049 .26068 L
.50163 .26068 L
.50286 .26068 L
.50401 .26068 L
.50508 .26068 L
.50754 .26069 L
.51014 .2607 L
.51268 .26072 L
.51504 .26074 L
.5204 .26079 L
.5293 .2609 L
.53882 .26107 L
.54906 .26131 L
.56016 .26162 L
.58032 .26236 L
.62123 .26449 L
.66064 .26731 L
.69852 .27068 L
.73886 .27492 L
.77769 .27958 L
.81897 .28505 L
Mistroke
.85873 .29075 L
.89697 .29653 L
.93767 .30289 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .23492 L
.10458 .15972 L
.14415 .09944 L
.18221 .05482 L
.20178 .03794 L
.21267 .03049 L
.22272 .02489 L
.23293 .02048 L
.23832 .01868 L
.24402 .01717 L
.24641 .01666 L
.24897 .01619 L
.25119 .01586 L
.25361 .01556 L
.25507 .01542 L
.25643 .01532 L
.25773 .01524 L
.2584 .0152 L
.25912 .01517 L
.25983 .01515 L
.26048 .01514 L
.26176 .01512 L
.26293 .01513 L
.26416 .01516 L
.26538 .0152 L
.26607 .01524 L
.26671 .01527 L
.26912 .01546 L
.27131 .01569 L
.27364 .016 L
.27847 .01688 L
.2838 .01819 L
.29326 .02139 L
.30213 .02541 L
.32232 .03816 L
.34082 .05406 L
.38045 .10051 L
.41855 .15859 L
.45912 .2307 L
.49816 .30545 L
.53966 .38504 L
.57964 .45642 L
.61811 .51554 L
.63759 .54064 L
.65902 .56382 L
.67938 .58114 L
.69843 .5929 L
.70884 .59745 L
.71396 .59919 L
Mistroke
.71872 .60051 L
.72301 .60146 L
.72758 .6022 L
.7302 .60251 L
.73148 .60263 L
.73266 .60272 L
.73371 .60279 L
.73487 .60284 L
.73603 .60288 L
.73725 .60291 L
.73856 .60291 L
.73977 .60289 L
.7404 .60288 L
.7411 .60285 L
.74251 .60278 L
.74375 .60271 L
.74508 .6026 L
.74748 .60235 L
.74985 .60203 L
.75235 .60161 L
.7568 .60067 L
.76198 .59927 L
.7668 .59765 L
.77773 .59292 L
.78828 .58695 L
.79823 .58009 L
.81683 .56415 L
.85534 .51928 L
.89632 .45682 L
.93577 .38646 L
.97371 .31383 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`1=Ool6001XOol6000_Ool003Qoo`800?moobQoo`8004eoo`03
001oogoo00Aoo`03001oogoo06Aoo`8000Eoo`03001oogoo02aoo`005goo0`001Woo0P001Woo00<0
07ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo
00<007ooOol0Bgoo00<007ooOol01Woo0P00Hgoo00<007ooOol01Woo0P00;7oo000FOol01@00Oomo
ogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007oo
Oomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04Yoo`03001oogoo
00Uoo`03001oogoo05moo`03001oogoo00Uoo`03001oogoo02Uoo`003Woo1P000Woo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool2001:Ool00`00Oomoo`0:Ool00`00Oomoo`1OOol00`00Oomo
o`09Ool00`00Oomoo`0YOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol0BGoo00<007ooOol02goo00<007ooOol0GGoo00<007ooOol02goo00<007ooOol0:7oo000F
Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo04Qoo`03001oogoo00aoo`03001oogoo05ao
o`03001oogoo00eoo`03001oogoo02Moo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`17Ool00`00Oomoo`0>Ool00`00Oomoo`1KOol00`00Oomoo`0=Ool00`00Oomo
o`0WOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo
1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20018Ool00`00Oomo
o`0?Ool00`00Oomoo`1IOol00`00Oomoo`0?Ool00`00Oomoo`0VOol001Moo`<000aoo`D000Aoo`@0
00Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo04Ioo`03001oogoo011o
o`03001oogoo05Qoo`03001oogoo011oo`03001oogoo02Ioo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0AGoo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol09Goo000h
Ool2003oOolXOol20016Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol00`00Oomo
o`0UOol003Qoo`03001oogoo0?moobMoo`03001oogoo04Aoo`03001oogoo01Aoo`03001oogoo05Ao
o`03001oogoo01Aoo`03001oogoo02Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0A7oo00<0
07ooOol057oo00<007ooOol0E7oo00<007ooOol05Goo00<007ooOol08goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`13Ool00`00Oomoo`0FOol00`00Oomoo`1COol00`00Oomoo`0EOol00`00Oomo
o`0SOol003Qoo`800?moobQoo`8004Aoo`03001oogoo01Ioo`03001oogoo059oo`03001oogoo01Mo
o`03001oogoo029oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0@goo00<007ooOol05goo00<0
07ooOol0DGoo00<007ooOol05goo00<007ooOol08Woo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`12Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`0QOol003Qoo`80
0?moobQoo`8004=oo`03001oogoo01Uoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025o
o`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<0
07ooOol0@Goo00<007ooOol06Woo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol08Goo000N
Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomo
o`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo045oo`03001oogoo01]oo`03001oogoo04eo
o`03001oogoo01]oo`03001oogoo021oo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo
009oo`03001oogoo0?moo`Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomo
o`11Ool00`00Oomoo`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`0POol001ioo`05
001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<007ooOol0
0Woo0P00@Goo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol087oo000N
Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eo
o`03001oogoo041oo`03001oogoo01eoo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo01mo
o`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0
000<Ool00`00Oomoo`06Ool00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1;Ool00`00Oomo
o`0MOol00`00Oomoo`0OOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1Y
Ool5002NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0?goo00<007ooOol07Woo
00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol07goo000OOol3000=Ool40005Ool2001WOol3
0005Ool5002JOol3000=Ool40005Ool2000oOol00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomo
o`0OOol00`00Oomoo`0NOol003Qoo`03001oogoo06Aoo`8000eoo`800;5oo`03001oogoo03ioo`03
001oogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001oogoo01ioo`00>7oo00<007ooOol0
HGoo0`004Goo0P00[goo00<007ooOol0?Woo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol0
87oo00<007ooOol07Woo000hOol2001POol2000FOol00`00Oomoo`2/Ool2000nOol00`00Oomoo`0R
Ool00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`0MOol003Qoo`03001oogoo05ioo`03001o
ogoo01Moo`03001oogoo0:]oo`03001oogoo03eoo`03001oogoo029oo`03001oogoo04Ioo`03001o
ogoo029oo`03001oogoo01eoo`00>7oo00<007ooOol0GGoo00<007ooOol06Goo0P00Zgoo00<007oo
Ool0?Goo00<007ooOol08Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol07Goo000hOol0
0`00Oomoo`1LOol00`00Oomoo`0LOol00`00Oomoo`2XOol00`00Oomoo`0lOol00`00Oomoo`0TOol0
0`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`0LOol003Qoo`8005aoo`03001oogoo01ioo`03
001oogoo0:Moo`8003eoo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo
01aoo`00>7oo00<007ooOol0FWoo00<007ooOol087oo00<007ooOol0YWoo00<007ooOol0?7oo00<0
07ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol077oo000hOol00`00Oomoo`1I
Ool00`00Oomoo`0ROol00`00Oomoo`2UOol00`00Oomoo`0kOol00`00Oomoo`0VOol00`00Oomoo`13
Ool00`00Oomoo`0UOol00`00Oomoo`0KOol003Qoo`8005Uoo`03001oogoo02=oo`03001oogoo0:Eo
o`8003aoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01]oo`005goo
0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0Egoo00<007ooOol09Goo00<007ooOol0Pgoo
0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0>goo00<007ooOol09Woo00<007ooOol0@Woo
00<007ooOol09Woo00<007ooOol06goo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol0
00Qoo`03001oogoo009oo`03001oogoo05Ioo`03001oogoo02Moo`03001oogoo085oo`05001oogoo
Ool00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol0
:7oo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol06Woo000>Ool60002Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0EGoo00<007ooOol0:Goo00<007oo
Ool0N7oo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo
03Yoo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo01Yoo`005Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8005Eoo`03001oogoo02]oo`03001o
ogoo07moo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000kOol00`00Oomo
o`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`0JOol001Ioo`05001oogooOol0000?
Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1DOol00`00Oomoo`0/Ool00`00Oomoo`1nOol01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0>Goo00<007ooOol0:Woo00<007oo
Ool0?goo00<007ooOol0:Goo00<007ooOol06Goo000FOol01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol0Dgoo00<007ooOol0;Goo00<007ooOol0OWoo00D007ooOomo
o`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo03Uoo`03001oogoo02Yoo`03001o
ogoo03ioo`03001oogoo02Yoo`03001oogoo01Uoo`005Woo00D007ooOomoo`0000]oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool2001COol00`00Oomoo`0_Ool00`00Oomoo`1mOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8003Yoo`03001oogoo02Yoo`03001oogoo
03ioo`03001oogoo02Yoo`03001oogoo01Uoo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0
DGoo00<007ooOol0<Goo00<007ooOol0OGoo0`003Goo0`001Goo10001Goo00<007ooOol0>7oo00<0
07ooOol0;7oo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol067oo000hOol00`00Oomoo`1@
Ool00`00Oomoo`0cOol00`00Oomoo`2MOol00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00Oomoo`0l
Ool00`00Oomoo`0/Ool00`00Oomoo`0HOol003Qoo`03001oogoo01moo`<000Ioo`8000Aoo`D001Qo
o`<0009oo`04001oogooOol20006Ool3000HOol30006Ool20005Ool3000JOol30006Ool20005Ool3
000QOol50019Ool00`00Oomoo`0OOol30006Ool20004Ool50005Ool00`00Oomoo`0@Ool30006Ool2
0006Ool30008Ool00`00Oomoo`0=Ool30006Ool20005Ool3000IOol40005Ool20005Ool3000OOol0
0`00Ool00004000DOol003Qoo`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`005goo
00@007ooOomoo`8000Aoo`8000Moo`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool20002
Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo
04Uoo`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`001Goo00<007ooOol03goo00D0
07ooOomoo`0000Eoo`8000Moo`03001oogoo00Moo`03001oogoo00aoo`05001oogooOol00005Ool2
0004Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000OOol0
1000Oomoo`005Woo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol05goo00D0
07ooOomoo`0000]oo`D001Moo`05001oogooOol0000;Ool01@00Ool007oo000067oo00D007ooOomo
o`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo0000
3Goo00<007ooOol017oo00<007ooOol047oo00D007ooOomoo`0000]oo`D000Uoo`03001oogoo00]o
o`05001oogooOol0000;Ool01@00Oomoogoo00005goo00<007ooOol00P002goo00D007ooOomoo`00
01moo`04001oogoo000FOol003Qoo`03001oogoo01ioo`05001oogooOol0000>Ool00`00Oomoo`0F
Ool01@00Oomoogoo00002goo00@007ooOol001Qoo`05001oogooOol0000;Ool00`00Oomoo`02000H
Ool01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03001oogoo01ioo`05
001oogooOol0000>Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool01@00Oomoogoo00002goo00@007oo
Ool000Yoo`03001oogoo00]oo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00<007ooOol0
0P002goo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`03001oogoo01ioo`05001oogoo
Ool0000?Ool00`00Oomoo`0EOol00`00Oomoo`02000<Ool00`00Ool0000HOol01@00Oomoogoo0000
2goo1@0067oo00D007ooOomoo`0000aoo`<002=oo`03001oogoo04Uoo`03001oogoo01ioo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool01@00Oomoogoo000037oo00<007oo0000
2Woo00<007ooOol02goo00D007ooOomoo`0000]oo`@001Qoo`03001oogoo008000aoo`<0025oo`03
001oo`0001Ioo`00>7oo0P007goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oo`00Ool0
000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0
000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo0P007goo00D007ooOomoo`0000moo`05001o
ogooOol0000COol01@00Oomoogoo000037oo00<007oo00002goo00<007ooOol02Woo00D007ooOomo
o`0000]oo`03001oogoo01Uoo`05001oo`00Ool0000;Ool01@00Oomoogoo000087oo00<007oo0000
5Woo000hOol00`00Oomoo`0NOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`80009oo`03
001oogoo00]oo`8001Qoo`05001oogooOol0000<Ool01@00Oomoogoo00005goo00D007ooOomoo`00
00]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00002goo
00D007ooOomoo`0000=oo`03001oogoo015oo`05001oogooOol0000=Ool2000;Ool00`00Oomoo`0:
Ool01@00Oomoogoo000037oo00<007ooOol067oo00D007oo001oo`0000]oo`05001oogooOol0000P
Ool00`00Ool0000FOol003Qoo`03001oogoo01moo`<000eoo`<001Uoo`<000moo`03001oogoo01Mo
o`<000ioo`<00003Ool007oo01Ioo`<000eoo`<0025oo`<004]oo`03001oogoo01moo`<000eoo`<0
00Aoo`03001oogoo019oo`<000moo`03001oogoo00Uoo`03001oogoo00]oo`<000ioo`<001Qoo`<0
00eoo`<0025oo`<001Ioo`00>7oo0P00Bgoo00<007ooOol0@7oo00<007ooOol0UWoo0P00=Woo00<0
07ooOol0<Woo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol05Goo000hOol00`00Oomoo`19
Ool00`00Oomoo`11Ool00`00Oomoo`2FOol00`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomoo`0f
Ool00`00Oomoo`0bOol00`00Oomoo`0EOol003Qoo`03001oogoo04Uoo`03001oogoo049oo`03001o
ogoo09Eoo`03001oogoo03Eoo`03001oogoo039oo`03001oogoo03Ioo`03001oogoo03=oo`03001o
ogoo01Aoo`00>7oo00<007ooOol0B7oo00<007ooOol0A7oo00<007ooOol0U7oo00<007ooOol0=7oo
00<007ooOol0=7oo00<007ooOol0=7oo00<007ooOol0=7oo00<007ooOol057oo000bOooY0010OooY
000@Ool003Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Eoo`04001oogoo000:Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool01@00Oomoogoo0000
1Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01goo0P00Bgoo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol057oo000hOol20017Ool00`00Oomoo`18Ool00`00
Oomoo`14Ool00`00Oomoo`1;Ool00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0cOol00`00
Oomoo`1<Ool003Qoo`<004Eoo`03001oogoo04Yoo`03001oogoo049oo`03001oogoo04aoo`8003Ao
o`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo00@007ooOol004=oo`03001o
ogoo04aoo`03001oogoo041oo`03001oogoo04eoo`8003Aoo`03001oogoo03Ioo`03001oogoo039o
o`03001oogoo04aoo`00>7oo00@007ooOol0049oo`03001oogoo04eoo`03001oogoo041oo`03001o
ogoo04eoo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo00D007oo
Oomoo`00041oo`03001oogoo04moo`03001oogoo03ioo`03001oogoo04ioo`03001oo`00039oo`03
001oogoo03Qoo`03001oogoo031oo`03001oogoo04eoo`00>7oo0P000goo00<007ooOol0?Goo00<0
07ooOol0D7oo00<007ooOol0?7oo00<007ooOol0Cgoo0`00<Woo00<007ooOol0>7oo00<007ooOol0
<7oo00<007ooOol0CGoo000hOol00`00Oomoo`03Ool00`00Oomoo`0kOol00`00Oomoo`1BOol00`00
Oomoo`0jOol00`00Oomoo`1@Ool00`00Ool0000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00
Oomoo`1=Ool003Qoo`03001oogoo00=oo`03001oogoo03Yoo`03001oogoo05Aoo`03001oogoo03Uo
o`03001oogoo051oo`04001oogoo000`Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`1>
Ool003Qoo`03001oogoo00Aoo`03001oogoo03Qoo`03001oogoo05Eoo`03001oogoo03Qoo`03001o
ogoo055oo`04001oogoo000`Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`1>Ool003Qo
o`8000Ioo`03001oogoo03Ioo`03001oogoo05Moo`03001oogoo03Ioo`03001oogoo059oo`800003
Ool007oo02moo`03001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo00<007ooOol0
1Woo00<007ooOol0=7oo00<007ooOol0FGoo00<007ooOol0=7oo00<007ooOol0Dgoo00D007ooOomo
o`0002ioo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo04moo`00>7oo00<007ooOol01Woo
00<007ooOol0=7oo00<007ooOol0FWoo00<007ooOol0<goo00<007ooOol0Dgoo00D007ooOomoo`00
02ioo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo04moo`00>7oo0P0027oo00<007ooOol0
<Woo00<007ooOol0Fgoo00<007ooOol0<Woo00<007ooOol0E7oo0P000Woo00<007ooOol0;7oo00<0
07ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo000GOol30006Ool20004Ool50004Ool40005
Ool00`00Oomoo`08Ool00`00Oomoo`0`Ool00`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomoo`0d
Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`0n
Ool00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05001oogooOol00005Ool20005Ool01000Oomo
o`0027oo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0;Woo00<007ooOol0Ggoo00<007oo
Ool0;Woo00<007ooOol0=7oo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00Oomo
o`1@Ool001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool00`00Oomoo`0/Ool00`00Oomoo`1QOol00`00Oomoo`0/Ool00`00Oomoo`0eOol01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0:Woo00<007oo
Ool0?Woo00<007ooOol0:Woo00<007ooOol0D7oo000FOol01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo0P0037oo00<007ooOol0:goo00<007ooOol0HWoo00<007ooOol0:Woo00<0
07ooOol0=Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000Aoo`03001o
ogoo02Uoo`03001oogoo03moo`03001oogoo02Qoo`03001oogoo055oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`@000Eoo`03001oogoo00aoo`03001oogoo02Uoo`03001oogoo06Aoo`03
001oogoo02Uoo`03001oogoo03Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00
Oomoo`03Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`1AOol001Io
o`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0=Ool00`00Oomo
o`0WOol00`00Oomoo`1VOol00`00Oomoo`0WOol00`00Oomoo`0gOol01@00Oomoogoo00003goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0:7oo00<007ooOol0@7oo00<0
07ooOol0:7oo00<007ooOol0DGoo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03
001oogoo00Ioo`8000moo`03001oogoo02Eoo`03001oogoo06Qoo`03001oogoo02Eoo`03001oogoo
03Qoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P001Goo00<007oo
Ool09goo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol0DGoo000GOol3000=Ool30005Ool4
0005Ool00`00Oomoo`0?Ool00`00Oomoo`0SOol00`00Oomoo`1ZOol00`00Oomoo`0SOol00`00Oomo
o`0jOol3000=Ool30005Ool40005Ool00`00Oomoo`04Ool00`00Oomoo`0VOol00`00Oomoo`12Ool0
0`00Oomoo`0VOol00`00Oomoo`1BOol003Qoo`03001oogoo011oo`03001oogoo025oo`03001oogoo
06aoo`03001oogoo021oo`8005ioo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo049oo`03
001oogoo02Ioo`03001oogoo059oo`00>7oo00<007ooOol04Goo00<007ooOol07goo00<007ooOol0
KWoo00<007ooOol07Woo00<007ooOol0GWoo00<007ooOol01Goo00<007ooOol09Goo00<007ooOol0
@goo00<007ooOol09Goo00<007ooOol0DWoo000hOol2000COol00`00Oomoo`0MOol00`00Oomoo`1`
Ool00`00Oomoo`0LOol00`00Oomoo`1OOol20006Ool00`00Oomoo`0TOol00`00Oomoo`14Ool00`00
Oomoo`0TOol00`00Oomoo`1COol003Qoo`03001oogoo01=oo`03001oogoo01]oo`03001oogoo079o
o`03001oogoo01Yoo`03001oogoo061oo`03001oogoo00Eoo`03001oogoo02Aoo`03001oogoo04Ao
o`03001oogoo02Aoo`03001oogoo05=oo`00>7oo00<007ooOol057oo0P006Goo0P00MWoo0P0067oo
0P00Hgoo00<007ooOol01Woo00<007ooOol08goo00<007ooOol0AGoo00<007ooOol08goo00<007oo
Ool0Dgoo000hOol2000GOol2000EOol2001jOol2000EOol00`00Oomoo`1SOol20007Ool00`00Oomo
o`0ROol00`00Oomoo`16Ool00`00Oomoo`0ROol00`00Oomoo`1DOol003Qoo`03001oogoo01Qoo`03
001oogoo015oo`03001oogoo07aoo`03001oogoo015oo`03001oogoo06Aoo`03001oogoo00Ioo`03
001oogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo05Aoo`00>7oo00<007ooOol0
6Goo00<007ooOol03Woo0P00P7oo0P003goo0P00Igoo00<007ooOol01goo00<007ooOol08Goo00<0
07ooOol0Agoo00<007ooOol08Goo00<007ooOol0E7oo000hOol00`00Oomoo`0JOol4000:Ool20024
Ool2000:Ool3001YOol00`00Oomoo`07Ool00`00Oomoo`0POol00`00Oomoo`18Ool00`00Oomoo`0P
Ool00`00Oomoo`1EOol003Qoo`8001moo`X008Qoo`X006aoo`8000Qoo`03001oogoo021oo`03001o
ogoo04Qoo`03001oogoo021oo`03001oogoo05Eoo`007goo0`001Woo0P001Goo10001Goo00<007oo
Ool0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol027oo00<007ooOol07goo00<007ooOol0
BGoo00<007ooOol07goo00<007ooOol0EGoo000NOol01@00Oomoogoo00001Goo0P002Goo00<007oo
Ool00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo01ioo`03001oogoo04Yoo`03001oogoo01ioo`03001oogoo05Ioo`007Woo
00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool0
0`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`0NOol00`00Oomoo`1;Ool00`00Oomoo`0MOol0
0`00Oomoo`1FOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomo
ogoo000047oo00<007ooOol00Woo0P002Woo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol0
7Goo00<007ooOol0EWoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D0
07ooOomoo`0000aoo`@000Eoo`03001oogoo00Uoo`03001oogoo01aoo`03001oogoo04eoo`03001o
ogoo01]oo`03001oogoo05Moo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo
0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0KOol0
0`00Oomoo`1>Ool00`00Oomoo`0KOol00`00Oomoo`1GOol001ioo`05001oogooOol0000<Ool00`00
Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P002goo00<007ooOol0
6Woo00<007ooOol0CWoo00<007ooOol06Woo00<007ooOol0F7oo000OOol3000=Ool40005Ool00`00
Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`0:Ool00`00Oomoo`0JOol00`00Oomoo`1?Ool0
0`00Oomoo`0IOol00`00Oomoo`1HOol003Qoo`03001oogoo0?moobMoo`03001oogoo00Yoo`03001o
ogoo01Uoo`03001oogoo051oo`03001oogoo01Uoo`03001oogoo05Qoo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol02goo00<007ooOol067oo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol0
FGoo000hOol2003oOolXOol2000<Ool00`00Oomoo`0GOol00`00Oomoo`1BOol00`00Oomoo`0GOol0
0`00Oomoo`1IOol003Qoo`03001oogoo0?moobMoo`03001oogoo00aoo`03001oogoo01Ioo`03001o
ogoo059oo`03001oogoo01Ioo`03001oogoo05Yoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
37oo00<007ooOol05Goo00<007ooOol0E7oo00<007ooOol05Goo00<007ooOol0FWoo000hOol2003o
OolXOol2000>Ool00`00Oomoo`0DOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`1KOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo00eoo`03001oogoo01Aoo`03001oogoo05Eoo`03001o
ogoo019oo`03001oogoo05aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol03Woo00<007ooOol0
4Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0G7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`1GOol00`00Oomoo`0@Ool00`00Oomoo`1MOol0
03Qoo`800?moobQoo`8000moo`03001oogoo015oo`03001oogoo05Qoo`03001oogoo011oo`03001o
ogoo05eoo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`00
1Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol03goo0P004Goo00<007ooOol0FGoo00<0
07ooOol03Woo00<007ooOol0GWoo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo
00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qo
o`03001oogoo009oo`03001oogoo015oo`03001oogoo00eoo`03001oogoo05Yoo`03001oogoo00io
o`03001oogoo05ioo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03
001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomo
o`0AOol00`00Oomoo`0;Ool2001NOol2000=Ool00`00Oomoo`1OOol001Ioo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo0P004goo00<007ooOol02Goo00<007ooOol0H7oo00<007ooOol02Goo00<0
07ooOol0H7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo01=oo`03001oogoo00Mo
o`03001oogoo069oo`03001oogoo00Moo`03001oogoo065oo`005Woo00D007ooOomoo`0000moo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`0DOol00`00Oomoo`05Ool00`00Oomoo`1TOol00`00Oomo
o`05Ool00`00Oomoo`1ROol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2
000FOol30002Ool2001XOol20003Ool2001UOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo
0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo01Moo`@006Yoo`@006Moo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`80
0?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMo
o`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000_Ool50004Ool00`00Oomoo`3oOolNOol5
0004Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Ao
o`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000a
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Mo
o`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomo
o`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<00004Ool0
0000000HOol3003oOol7Ool3000017oo000000006Goo0`00M7oo002FOol01@00Oomoogoo00002Goo
1P002Goo00D007ooOomoo`000?moo`Moo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1cOol0
09Ioo`05001oogooOol0000LOol00`00Oomoo`3oOol5Ool01@00Oomoogoo000067oo1@00M7oo002F
Ool01@00Oomoogoo00002Goo1P003Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Uoo`H000Uo
o`04001oogoo001eOol009Ioo`05001oogooOol0000JOol2003oOol8Ool01@00Oomoogoo00006Goo
00<007oo0000MGoo002EOol5000MOol00`00Oomoo`3oOol4Ool5000JOol00`00Ool0001eOol00;=o
o`05001oogooOol0003oOolVOol2001eOol00;Aoo`<00?moobQoo`03001oogoo07=oo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo000_Ool5
003oOolUOol5003gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`009Woo1P001Goo00<0
07ooOol0ogoo77oo1P001Goo00<007ooOol0mgoo000aOol00`00Oomoo`04Ool2003oOolQOol00`00
Oomoo`04Ool2003aOol0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03
001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007oo
Ool0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2000aOol8002hOol002mo
o`<000Ioo`03001oogoo0?mooaioo`<000Ioo`03001oogoo02aoo`D000Moo`<00;Eoo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0:goo00<007ooOol03Goo0P00/goo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`0ZOol00`00Oomoo`0@Ool2002aOol003Qoo`800?moobQoo`8002Uoo`8001Eoo`<0
0:ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol09Goo0`006Woo00<007ooOol0Zgoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`0TOol00`00Oomoo`0LOol00`00Oomoo`2ZOol003Qoo`800?mo
obQoo`8002Aoo`03001oogoo01ioo`03001oogoo0:Uoo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool08Woo00<007ooOol087oo00<007ooOol0Z7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0Q
Ool00`00Oomoo`0ROol00`00Oomoo`2WOol003Qoo`03001oogoo0?moobMoo`03001oogoo025oo`03
001oogoo029oo`03001oogoo0:Moo`00>7oo0P00ogoo:7oo0P008Goo00<007ooOol097oo00<007oo
Ool0YWoo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool30006
Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`0OOol00`00Oomoo`0VOol00`00Oomoo`2U
Ool001Ioo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomo
o`3oOol5Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007oo
Ool07Woo00<007ooOol0:7oo00<007ooOol0Y7oo000>Ool60002Ool01@00Oomoogoo00003Woo00<0
07ooOol01goo00<007ooOol00Woo00<007ooOol0o7oo1P000Woo00D007ooOomoo`0000ioo`03001o
ogoo00Moo`03001oogoo009oo`03001oogoo01ioo`03001oogoo02Uoo`03001oogoo0:=oo`005Woo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000NOol00`00Oomoo`0[Ool00`00Oomoo`2ROol0
01Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomo
ogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol077oo00<007ooOol0;7oo00<007ooOol0
XWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01aoo`03001o
ogoo02eoo`03001oogoo0:5oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Io
o`8001aoo`03001oogoo02moo`03001oogoo0:1oo`005goo0`0037oo1@0017oo10001Goo00<007oo
Ool0ogoo1Woo0`0037oo1@0017oo10001Goo00<007ooOol06Woo00<007ooOol0<Goo00<007ooOol0
Wgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0IOol00`00Oomoo`0cOol00`00Oomoo`2NOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo01Uoo`03001oogoo03=oo`03001oogoo09ioo`00>7oo
0P00ogoo:7oo0P006Goo00<007ooOol0=Goo00<007ooOol0WGoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0GOol00`00Oomoo`0gOol00`00Oomoo`2LOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo01Ioo`03001oogoo03Qoo`03001oogoo09aoo`00>7oo0P00ogoo:7oo0P005goo00<007ooOol0
>Goo00<007ooOol0Vgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0EOol00`00Oomoo`0kOol0
0`00Oomoo`2JOol003Qoo`03001oogoo0?moobMoo`03001oogoo01Aoo`03001oogoo03eoo`03001o
ogoo09Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol057oo00<007ooOol0?Goo00<007ooOol0
VGoo000hOol2003oOolXOol2000DOol00`00Oomoo`0oOol00`00Oomoo`2HOol001moo`<000Ioo`80
00Eoo`@000Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo019oo`03001o
ogoo045oo`03001oogoo09Moo`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03
001oogoo0?moo`eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`12Ool00`00Oomoo`2GOol001Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02
Ool2003oOol6Ool60002Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P004Woo00<007ooOol0
@goo00<007ooOol0UWoo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0ogoo
3Goo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo011oo`03001oogoo04Eoo`03001o
ogoo09Eoo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?moo`eoo`05001oogooOol0
000<Ool40005Ool00`00Oomoo`0?Ool00`00Oomoo`16Ool00`00Oomoo`2EOol001ioo`05001oogoo
Ool0000<Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol0
1Woo00<007ooOol03goo00<007ooOol0Agoo00<007ooOol0U7oo000NOol01@00Oomoogoo000037oo
00<007ooOol01Woo0P00ogoo3Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`8000moo`03001o
ogoo04Qoo`03001oogoo09Aoo`007goo0`003Goo10001Goo00<007ooOol0ogoo3Woo0`003Goo1000
1Goo00<007ooOol03Woo00<007ooOol0BGoo00<007ooOol0Tgoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0=Ool00`00Oomoo`1;Ool00`00Oomoo`2BOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo00eoo`03001oogoo04]oo`03001oogoo099oo`00>7oo0P00ogoo:7oo0P003Goo00<007ooOol0
CGoo00<007ooOol0TGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0<Ool00`00Oomoo`1=Ool0
0`00Oomoo`2AOol003Qoo`03001oogoo0?moobMoo`03001oogoo00]oo`03001oogoo04moo`03001o
ogoo091oo`00>7oo0P00ogoo:7oo0P002goo00<007ooOol0DGoo00<007ooOol0Sgoo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`0:Ool00`00Oomoo`1AOol00`00Oomoo`2?Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo00Uoo`03001oogoo05=oo`03001oogoo08ioo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol02Goo00<007ooOol0Dgoo00<007ooOol0SWoo000hOol2003oOolXOol20009Ool0
0`00Oomoo`1EOol00`00Oomoo`2=Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo
0?moo`Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Qoo`03001oogoo05Ioo`03001o
ogoo08aoo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009o
o`03001oogoo00Moo`03001oogoo05Moo`03001oogoo08aoo`003Woo1P000Woo00D007ooOomoo`00
00eoo`03001oogoo00Qoo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000=Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`1HOol00`00Oomoo`2;Ool001Ioo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0FGoo00<007oo
Ool0Rgoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00Ioo`03001oogoo05Yoo`03
001oogoo08Yoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool00`00Oomoo`1KOol00`00Oomoo`2:Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool20006Ool00`00Oomoo`1LOol00`00Oomoo`29Ool001Moo`<000eoo`<000Eoo`@000Eo
o`03001oogoo0?moo`Ioo`<000eoo`<000Eoo`@000Eoo`03001oogoo00Aoo`03001oogoo05eoo`03
001oogoo08Uoo`00>7oo00<007ooOol07goo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`00
67oo0`001Woo0P001Goo0`006Woo0`001Woo0P001Goo0`008Goo1@00BGoo00<007ooOol017oo00<0
07ooOol067oo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`001Woo00<007ooOol03goo0`00
1Woo0P001Goo0`006Goo0`001Woo0P001Goo0`008Goo1@0057oo000hOol2000OOol01@00Oomoogoo
00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool200000goo0000000[0002Ool0
1@00Oomoogoo000067oo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000ROol00`00Oomo
o`19Ool20004Ool00`00Oomoo`0HOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05
001oogooOol00005Ool20007Ool00`00Oomoo`05Ool00`00Oomoo`0>Ool01@00Oomoogoo00001Goo
0P0017oo00D007ooOomoo`0001Moo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00008Woo
00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol05goo00<0
07oo00002P000goo1@005goo00D007ooOomoo`0000Uoo`T001Ioo`05001oogooOol0000;Ool01@00
Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol067oo00D007ooOomoo`00
00eoo`03001oogoo01Moo`05001oogooOol0000;Ool50007Ool00`00Oomoo`0=Ool01@00Oomoogoo
00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007oo
Ool057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Woo00<007ooOol01Goo4`000Woo00<0
07ooOol02Goo00@007ooOol001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00000Woo4P0017oo
00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`02Ool00`00
Oomoo`0IOol01@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo
0009Ool00`00Oomoo`0<Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0
000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo
00003Goo2@004Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool4000E
Ool:000;Ool3000SOol00`00Oomoo`19Ool01@00Oomoogoo000077oo00D007ooOomoo`0000moo`03
001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool00009Ool00`00Oomoo`0<Ool01@00Oomoogoo
00002goo100067oo00D007ooOomoo`0000aoo`<002=oo`03001oogoo01Aoo`00>7oo0P007goo00D0
07ooOomoo`0000Ioo`L0009oo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol0
1@00Oomoogoo00002goo00<007ooOol06Woo00H007ooOomoo`00Ool60004Ool01@00Oomoogoo0000
8Woo00<007ooOol0BGoo0P000Woo00<007ooOol06Woo00D007ooOomoo`0000moo`03001oogoo01Eo
o`05001oogooOol0000<Ool00`00Ool0000:Ool00`00Oomoo`0;Ool01@00Oomoogoo00002goo00<0
07ooOol06Goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03
001oogoo01ioo`06001oogooOol007oo1@001Goo00D007ooOomoo`0001Moo`05001oogooOol0000=
Ool2000HOol01@00Oomoogoo000037oo00<007ooOol06Goo00D007ooOomoo`0000Moo`D000=oo`03
001oogoo021oo`03001oogoo04Uoo`04001oogoo000MOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Moo`05001oogooOol0000=Ool2000:Ool00`00Oomoo`0;Ool01@00Oomoogoo000037oo00<0
07ooOol067oo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03
001oogoo01ioo`H000]oo`<001Uoo`<000moo`03001oogoo01Moo`<000ioo`<001Uoo`<000eoo`L0
01eoo`<004]oo`04001oogoo000NOol3000=Ool3000IOol3000?Ool00`00Oomoo`09Ool00`00Oomo
o`0;Ool3000>Ool3000HOol3000=Ool3000QOol3000FOol003Qoo`03001oogoo01Eoo`T009eoo`T0
069oo`03001oo`0006Uoo`03001oogoo08Aoo`00>7oo0P003goo1`00[goo1`00Fgoo0`00JWoo00<0
07ooOol0Pgoo000hOol00`00Oomoo`09Ool5002mOol5001FOol2001[Ool00`00Oomoo`23Ool003Qo
o`03001oogoo009oo`L00<Moo`L004moo`8006aoo`03001oogoo089oo`00<Wooj@00@7ooj@0047oo
000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool20009Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`0DOol003Qoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo
02Uoo`03001oogoo02Yoo`03001oogoo02Uoo`03001oogoo04Uoo`03001oogoo02Uoo`03001oogoo
02Uoo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo
01Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0KGoo00<007ooOol0J7oo00<007ooOol05Goo
000hOol2003oOolXOol2001^Ool00`00Oomoo`1XOol00`00Oomoo`0EOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo06ioo`03001oogoo06Ioo`03001oogoo01Ioo`00>7oo00<007ooOol0ogoo9goo
00<007ooOol0KWoo00<007ooOol0IWoo00<007ooOol05Woo000hOol2003oOolXOol2001`Ool00`00
Oomoo`1TOol00`00Oomoo`0GOol003Qoo`03001oogoo0?moobMoo`03001oogoo06moo`03001oogoo
06Aoo`03001oogoo01Moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0L7oo00<007ooOol0HWoo
00<007ooOol067oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1`Ool00`00Oomoo`1QOol00`00
Oomoo`0IOol003Qoo`800?moobQoo`80075oo`03001oogoo065oo`03001oogoo01Uoo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0LGoo00<007ooOol0Ggoo00<007ooOol06Woo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`1aOol00`00Oomoo`1OOol00`00Oomoo`0JOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo079oo`03001oogoo05eoo`03001oogoo01]oo`00>7oo0P00ogoo:7oo0P00Lgoo
00<007ooOol0GGoo00<007ooOol06goo000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomo
o`3oOol6Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`1cOol00`00Oomoo`1KOol00`00
Oomoo`0LOol001Ioo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo
00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02
Ool00`00Oomoo`1cOol00`00Oomoo`1KOol00`00Oomoo`0LOol001Ioo`05001oogooOol0000=Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Goo00<007ooOol027oo
00<007ooOol00Woo0P00MGoo00<007ooOol0FGoo00<007ooOol07Goo000FOol01@00Oomoogoo0000
3Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo07Aoo`03001oogoo05Uoo`03001oogoo01eoo`00
5Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1eOol00`00Oomoo`1GOol00`00Oomoo`0N
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0MWoo00<007oo
Ool0EWoo00<007ooOol07Woo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001o
ogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo
0P00Mgoo00<007ooOol0EGoo00<007ooOol07goo000GOol3000=Ool30005Ool40005Ool00`00Oomo
o`3oOol6Ool3000=Ool30005Ool40005Ool00`00Oomoo`1gOol00`00Oomoo`1COol00`00Oomoo`0P
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo07Moo`03001oogoo05=oo`03001oogoo021oo`00
>7oo0P00ogoo:7oo0P00NGoo00<007ooOol0DGoo00<007ooOol08Goo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`1iOol00`00Oomoo`1@Ool00`00Oomoo`0QOol003Qoo`03001oogoo0?moobMoo`03
001oogoo07Uoo`03001oogoo04moo`03001oogoo029oo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0NWoo00<007ooOol0CWoo00<007ooOol08Woo000hOol2003oOolXOol2001lOol00`00Oomoo`1<
Ool00`00Oomoo`0SOol003Qoo`03001oogoo0?moobMoo`03001oogoo07]oo`03001oogoo04aoo`03
001oogoo02=oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0O7oo00<007ooOol0BWoo00<007oo
Ool097oo000hOol2003oOolXOol2001mOol00`00Oomoo`19Ool00`00Oomoo`0UOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo07eoo`03001oogoo04Qoo`03001oogoo02Eoo`007goo0`001Woo0P00
1Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0OWoo00<007oo
Ool0AWoo00<007ooOol09Woo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<0
07ooOol0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo07ioo`03
001oogoo04Ioo`03001oogoo02Ioo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?mo
o`ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool20020Ool00`00Oomoo`14Ool00`00Oomoo`0W
Ool001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo
000047oo00<007ooOol00Woo00<007ooOol0P7oo00<007ooOol0@Woo00<007ooOol0:7oo000NOol0
1@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03
001oogoo081oo`03001oogoo049oo`03001oogoo02Qoo`007Woo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`21
Ool00`00Oomoo`10Ool00`00Oomoo`0YOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2
003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P00Pgoo00<007ooOol0?Woo00<007oo
Ool0:Woo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`22
Ool00`00Oomoo`0nOol00`00Oomoo`0ZOol003Qoo`03001oogoo0?moobMoo`03001oogoo08=oo`03
001oogoo03aoo`03001oogoo02]oo`00>7oo0P00ogoo:7oo0P00Q7oo00<007ooOol0>goo00<007oo
Ool0;7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`24Ool00`00Oomoo`0jOol00`00Oomoo`0/
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Eoo`03001oogoo03Qoo`03001oogoo02eoo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0QGoo00<007ooOol0=goo00<007ooOol0;Woo000hOol2
003oOolXOol20027Ool00`00Oomoo`0fOol00`00Oomoo`0^Ool003Qoo`03001oogoo0?moobMoo`03
001oogoo08Moo`03001oogoo03Aoo`03001oogoo02moo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0Qgoo00<007ooOol0<goo00<007ooOol0<7oo000hOol2003oOolXOol20029Ool00`00Oomoo`0b
Ool00`00Oomoo`0`Ool001Moo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?mo
o`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo08Uoo`03001oogoo031oo`03
001oogoo035oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009o
o`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`29Ool00`00Oomoo`0_Ool00`00Oomoo`0bOol001Ioo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol0RWoo00<007ooOol0;Goo00<007ooOol0<goo000FOol0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00ogoo1Woo00D007ooOomoo`00
00ioo`03001oogoo00Moo`03001oogoo009oo`8008aoo`03001oogoo02]oo`03001oogoo03Aoo`00
5Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogoo
Ool0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`2<Ool00`00Oomoo`0ZOol00`00Oomoo`0d
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0SGoo00<007oo
Ool0:7oo00<007ooOol0=Goo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001o
ogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo00<007ooOol0SWoo00<007ooOol09Woo00<007ooOol0=Woo000GOol3000<Ool50004Ool4
0005Ool2003oOol7Ool3000<Ool50004Ool40005Ool2002@Ool00`00Oomoo`0TOol00`00Oomoo`0g
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo091oo`80029oo`8003Yoo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0TWoo00<007ooOol07Woo00<007ooOol0>Woo000hOol2003oOolXOol2002D
Ool00`00Oomoo`0LOol00`00Oomoo`0kOol003Qoo`03001oogoo0?moobMoo`03001oogoo09Aoo`03
001oogoo01Yoo`03001oogoo03aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0UGoo0P006Goo
00<007ooOol0?Goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2GOol00`00Oomoo`0EOol00`00
Oomoo`0nOol003Qoo`800?moobQoo`8009Uoo`03001oogoo019oo`80045oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0VGoo0`003Woo0`00@goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2L
Ool2000;Ool00`00Oomoo`14Ool003Qoo`800?moobQoo`8009moo`/004Moo`00;goo1@0017oo00<0
07ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolP
Ool00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03
001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo
0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03
001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3003oOolWOol3003i
Ool00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo1@00ogoo1Goo0`0000Ao
o`00000001Moo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05
001oogooOol00009Ool6000:Ool01000Oomoo`00M7oo002FOol01@00Oomoogoo00006goo00<007oo
Ool0ogoo1Woo00D007ooOomoo`0001Yoo`03001oogoo07Aoo`00UWoo00D007ooOomoo`0000Uoo`H0
00aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05
001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo000077oo00<007ooOol0LWoo002E
Ool5000LOol00`00Oomoo`3oOol5Ool5000MOol00`00Oomoo`1bOol00;Ioo`03001oogoo0?moob=o
o`05001oogooOol0001dOol00;Aoo`<00?moobIoo`<007Eoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.14918 .30902 L
.15465 .30902 L
.15946 .30902 L
.16457 .30902 L
.16917 .30902 L
.17178 .30902 L
.17423 .30902 L
.17538 .30902 L
.17647 .30902 L
.17746 .30902 L
.17852 .30902 L
.17967 .30902 L
.18073 .30902 L
.182 .30902 L
.18314 .30902 L
.18435 .30902 L
.18547 .30902 L
.1867 .30902 L
.18802 .30902 L
.19071 .30902 L
.19317 .30902 L
.1979 .30902 L
.20239 .30902 L
.21236 .30902 L
.22321 .30902 L
.24299 .30902 L
.26399 .30902 L
.30174 .30902 L
.34195 .30902 L
.38063 .30902 L
.40028 .30902 L
.42177 .30902 L
.44253 .30902 L
.4614 .30902 L
.47149 .30902 L
.47611 .30902 L
.48101 .30902 L
.4835 .30902 L
.48624 .30902 L
.48876 .30902 L
.49106 .30902 L
.49378 .30902 L
.49527 .30902 L
.49596 .30902 L
Mistroke
.49669 .30902 L
.498 .30902 L
.49921 .30902 L
.49996 .30902 L
.50065 .30902 L
.50196 .30902 L
.50313 .30902 L
.50438 .30902 L
.50556 .30902 L
.50663 .30902 L
.50926 .30902 L
.51175 .30902 L
.5167 .30902 L
.52208 .30902 L
.53169 .30902 L
.54056 .30902 L
.55926 .30902 L
.57988 .30902 L
.62014 .30902 L
.65888 .30902 L
.70007 .30902 L
.72063 .30902 L
.73974 .30902 L
.75939 .30902 L
.77791 .30902 L
.78775 .30902 L
.79293 .30902 L
.7984 .30902 L
.80302 .30902 L
.80546 .30902 L
.80809 .30902 L
.8105 .30902 L
.8127 .30902 L
.81375 .30902 L
.81491 .30902 L
.81599 .30902 L
.817 .30902 L
.81818 .30902 L
.81941 .30902 L
.82047 .30902 L
.82163 .30902 L
.82287 .30902 L
.82421 .30902 L
.82661 .30902 L
.82905 .30902 L
.83134 .30902 L
.83564 .30902 L
.84078 .30902 L
.84552 .30902 L
.85624 .30902 L
Mistroke
.87498 .30902 L
.89561 .30902 L
.93591 .30902 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .45981 L
.08255 .52527 L
.0932 .55403 L
.10458 .57945 L
.11009 .58961 L
.11531 .59784 L
.12038 .60454 L
.12507 .60956 L
.12951 .61325 L
.13178 .61474 L
.13422 .61603 L
.13549 .61658 L
.13666 .617 L
.13784 .61736 L
.13895 .61762 L
.14022 .61785 L
.1409 .61793 L
.14161 .61799 L
.1423 .61803 L
.14295 .61803 L
.14415 .61799 L
.14531 .61787 L
.14656 .61767 L
.14773 .61739 L
.14881 .61708 L
.15143 .61606 L
.15392 .61475 L
.15886 .61117 L
.16423 .60583 L
.17383 .59259 L
.1827 .5763 L
.20137 .53043 L
.22197 .46442 L
.26217 .30793 L
.30086 .15709 L
.32051 .09318 L
.3309 .06498 L
.342 .03993 L
.35275 .02114 L
.35784 .01426 L
.36253 .00909 L
.36724 .00504 L
.36972 .00339 L
.37235 .00199 L
.37463 .00107 L
.37573 .00073 L
.37677 .00047 L
.37799 .00024 L
.37911 9e-05 L
Mistroke
.38031 1e-05 L
.38162 1e-05 L
.38227 5e-05 L
.38296 .00011 L
.38419 .00028 L
.38551 .00056 L
.38695 .00097 L
.38955 .00199 L
.39197 .00326 L
.39649 .00647 L
.40134 .01111 L
.40698 .01804 L
.41232 .02609 L
.42232 .0449 L
.44227 .09574 L
.4607 .15587 L
.50002 .3091 L
.53782 .45692 L
.55884 .52554 L
.56803 .55063 L
.57808 .57397 L
.58722 .59118 L
.59696 .60501 L
.60236 .61057 L
.60726 .6143 L
.60962 .61565 L
.61086 .61623 L
.61218 .61677 L
.61333 .61715 L
.61459 .6175 L
.61574 .61774 L
.61682 .6179 L
.61808 .61801 L
.61871 .61803 L
.61941 .61803 L
.62065 .61796 L
.62181 .61783 L
.62248 .61772 L
.62318 .61757 L
.62443 .61725 L
.62578 .61682 L
.62725 .61622 L
.62973 .61497 L
.63238 .61327 L
.63715 .60926 L
.64214 .6038 L
.64686 .59746 L
.6557 .5826 L
.67568 .53569 L
.69413 .4784 L
Mistroke
.7335 .32774 L
.77136 .17771 L
.79241 .10603 L
.81166 .05399 L
.82118 .03415 L
.8262 .0254 L
.83155 .01745 L
.8367 .01118 L
.84136 .00668 L
.84361 .00491 L
.84604 .00331 L
.84835 .00208 L
.85045 .0012 L
.85159 .00083 L
.85283 .0005 L
.85414 .00024 L
.85538 8e-05 L
.85653 1e-05 L
.85776 1e-05 L
.85881 7e-05 L
.85997 .00021 L
.86063 .00033 L
.86132 .00047 L
.86256 .00079 L
.86535 .00181 L
.86777 .00303 L
.87041 .00472 L
.87569 .00921 L
.88133 .0156 L
.89148 .03117 L
.90173 .05195 L
.91284 .07976 L
.933 .14228 L
.97393 .29982 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.44268 .30902 L
.45178 .30902 L
.46172 .30902 L
.4671 .30902 L
.4721 .30902 L
.47727 .30902 L
.48196 .30902 L
.48658 .30902 L
.4887 .30902 L
.49093 .30902 L
.49332 .30902 L
.49438 .30902 L
.49552 .30902 L
.49675 .30902 L
.49789 .30902 L
.49859 .30902 L
.49925 .30902 L
.50049 .30902 L
.50163 .30902 L
.50286 .30902 L
.50401 .30902 L
.50508 .30902 L
.50754 .30902 L
.51014 .30902 L
.51268 .30902 L
.51504 .30902 L
.5204 .30902 L
.5293 .30902 L
.53882 .30902 L
.54906 .30902 L
.56016 .30902 L
.58032 .30902 L
.62123 .30902 L
.66064 .30902 L
.69852 .30902 L
.73886 .30902 L
.77769 .30902 L
.81897 .30902 L
Mistroke
.85873 .30902 L
.89697 .30902 L
.93767 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .2311 L
.10458 .15203 L
.14415 .08865 L
.18221 .04174 L
.20178 .02399 L
.21267 .01616 L
.22272 .01027 L
.23293 .00563 L
.23832 .00373 L
.24402 .00215 L
.24641 .00161 L
.24897 .00112 L
.25119 .00077 L
.25361 .00046 L
.25507 .00031 L
.25643 .0002 L
.25773 .00012 L
.2584 8e-05 L
.25912 5e-05 L
.25983 3e-05 L
.26048 1e-05 L
.26176 0 L
.26293 1e-05 L
.26416 3e-05 L
.26538 8e-05 L
.26607 .00012 L
.26671 .00016 L
.26912 .00035 L
.27131 .00059 L
.27364 .00093 L
.27847 .00184 L
.2838 .00322 L
.29326 .00659 L
.30213 .01082 L
.32232 .02422 L
.34082 .04094 L
.38045 .08978 L
.41855 .15085 L
.45912 .22667 L
.49816 .30527 L
.53966 .38895 L
.57964 .46401 L
.61811 .52616 L
.63759 .55256 L
.65902 .57693 L
.67938 .59514 L
.69843 .60751 L
.70884 .61229 L
.71396 .61413 L
Mistroke
.71872 .61551 L
.72301 .61651 L
.72758 .61729 L
.7302 .61761 L
.73148 .61774 L
.73266 .61784 L
.73371 .6179 L
.73487 .61796 L
.73603 .61801 L
.73725 .61803 L
.73856 .61803 L
.73977 .61802 L
.7404 .618 L
.7411 .61797 L
.74251 .6179 L
.74375 .61782 L
.74508 .61771 L
.74748 .61744 L
.74985 .6171 L
.75235 .61667 L
.7568 .61568 L
.76198 .6142 L
.7668 .61251 L
.77773 .60753 L
.78828 .60125 L
.79823 .59404 L
.81683 .57728 L
.85534 .5301 L
.89632 .46443 L
.93577 .39045 L
.97371 .31407 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`8004moo`@006Yoo`@0031oo`00
<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0C7oo0`000goo
00<007ooOol0IWoo0P000goo0P00;Woo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00
Oomoo`04Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool00`00Oomoo`1TOol00`00Oomoo`05Ool00`00
Oomoo`0[Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo
04Yoo`03001oogoo00Moo`8006=oo`03001oogoo00Moo`03001oogoo02Yoo`00<Goo00<007ooOol0
17oo0P00ogoo8Goo00<007ooOol017oo0P00Bgoo00<007ooOol02Goo00<007ooOol0Ggoo00<007oo
Ool02Goo00<007ooOol0:Goo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`19
Ool00`00Oomoo`0:Ool00`00Oomoo`1OOol00`00Oomoo`09Ool00`00Oomoo`0YOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo04Uoo`03001oogoo00]oo`03001oogoo05eoo`03001oogoo00]oo`03
001oogoo02Qoo`00>7oo0P00ogoo:7oo0P00BGoo00<007ooOol037oo00<007ooOol0GGoo00<007oo
Ool037oo00<007ooOol09goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`18Ool00`00Oomoo`0=
Ool00`00Oomoo`1KOol00`00Oomoo`0=Ool00`00Oomoo`0WOol003Qoo`03001oogoo0?moobMoo`03
001oogoo04Moo`03001oogoo00ioo`03001oogoo05]oo`03001oogoo00ioo`03001oogoo02Ioo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0Agoo00<007ooOol03Woo00<007ooOol0FWoo00<007oo
Ool03goo00<007ooOol09Woo000hOol2003oOolXOol20017Ool00`00Oomoo`0@Ool00`00Oomoo`1H
Ool00`00Oomoo`0@Ool00`00Oomoo`0VOol003Qoo`03001oogoo0?moobMoo`03001oogoo04Ioo`03
001oogoo011oo`03001oogoo05Qoo`03001oogoo015oo`03001oogoo02Eoo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0AGoo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007oo
Ool09Goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`15Ool00`00Oomoo`0BOol00`00Oomoo`1F
Ool00`00Oomoo`0COol00`00Oomoo`0TOol003Qoo`800?moobQoo`8004Eoo`03001oogoo01Aoo`03
001oogoo05Aoo`03001oogoo01Aoo`03001oogoo02Aoo`005goo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool0A7oo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol05Goo00<007ooOol08goo000FOol0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04Aoo`03
001oogoo01Eoo`03001oogoo05=oo`03001oogoo01Eoo`03001oogoo02=oo`003Woo1P000Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20014Ool00`00Oomoo`0FOol00`00Oomoo`1BOol0
0`00Oomoo`0FOol00`00Oomoo`0SOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol0@goo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05goo00<007ooOol0
8Woo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo04=oo`03001oogoo01Moo`03001o
ogoo055oo`03001oogoo01Moo`03001oogoo029oo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`12Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0HOol0
0`00Oomoo`0ROol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo
0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20013Ool0
0`00Oomoo`0IOol00`00Oomoo`1?Ool00`00Oomoo`0IOol00`00Oomoo`0QOol001Moo`<000aoo`D0
00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo049oo`03001o
ogoo01Uoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0@Goo00<007ooOol06Woo00<007ooOol0CWoo00<007ooOol06Woo00<007ooOol0
8Goo000hOol2003oOolXOol20012Ool00`00Oomoo`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol0
0`00Oomoo`0POol003Qoo`03001oogoo0?moobMoo`03001oogoo045oo`03001oogoo01]oo`03001o
ogoo04eoo`03001oogoo01]oo`03001oogoo021oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
@7oo00<007ooOol077oo00<007ooOol0CGoo00<007ooOol06goo00<007ooOol087oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`10Ool00`00Oomoo`0MOol00`00Oomoo`1;Ool00`00Oomoo`0LOol0
0`00Oomoo`0POol003Qoo`800?moobQoo`80045oo`03001oogoo01eoo`03001oogoo04]oo`03001o
ogoo01eoo`03001oogoo01moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0?goo00<007ooOol0
7Woo00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol07goo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`0OOol0
03Qoo`800?moobQoo`80041oo`03001oogoo01moo`03001oogoo04Uoo`03001oogoo01moo`03001o
ogoo01ioo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo1000
1Goo00<007ooOol0?Woo00<007ooOol087oo00<007ooOol0BGoo00<007ooOol07goo00<007ooOol0
7Woo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo03ioo`03001oogoo021oo`03001o
ogoo04Qoo`03001oogoo021oo`03001oogoo01ioo`005Woo1P000Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo0?moo`Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`0nOol00`00Oomoo`0QOol00`00Oomoo`17Ool00`00Oomoo`0POol00`00Oomoo`0NOol0
01ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<0
07ooOol00Woo0P00?Woo00<007ooOol08Woo00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol0
7Goo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000ao
o`@000Eoo`03001oogoo03eoo`03001oogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001o
ogoo01eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0mOol00`00Oomoo`0ROol00`00Oomoo`16Ool0
0`00Oomoo`0ROol00`00Oomoo`0MOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00
Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0?Goo00<007ooOol0
8goo00<007ooOol0AGoo00<007ooOol08Woo00<007ooOol07Goo000OOol3000=Ool40005Ool2003o
Ool?Ool3000=Ool40005Ool2000mOol00`00Oomoo`0TOol00`00Oomoo`14Ool00`00Oomoo`0TOol0
0`00Oomoo`0LOol003Qoo`03001oogoo0?moobMoo`03001oogoo03aoo`03001oogoo02Aoo`03001o
ogoo04Aoo`03001oogoo02Aoo`03001oogoo01aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
?7oo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol077oo000hOol2003o
OolXOol2000mOol00`00Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`0KOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo03]oo`03001oogoo02Ioo`03001oogoo049oo`03001o
ogoo02Ioo`03001oogoo01]oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0>goo00<007ooOol0
9Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol06goo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0kOol00`00Oomoo`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomoo`0KOol0
03Qoo`800?moobQoo`8003aoo`03001oogoo02Moo`03001oogoo045oo`03001oogoo02Moo`03001o
ogoo01Yoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol0
@7oo00<007ooOol0:7oo00<007ooOol06Woo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0jOol0
0`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`0JOol003Qoo`800?moobQo
o`8003]oo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo01Yoo`005goo
0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P0017oo1@0017oo1000
1Goo00<007ooOol0>Woo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol0
6Goo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001o
ogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<0
07ooOol0>Goo00<007ooOol0:Woo00<007ooOol0?Woo00<007ooOol0:Woo00<007ooOol06Goo000>
Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0o7oo
1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo03Uoo`03
001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo01Uoo`005Woo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool2000jOol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0[
Ool00`00Oomoo`0HOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomo
o`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0>7oo00<007oo
Ool0;7oo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol067oo000FOol01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo03Qoo`03001oogoo02aoo`03001oogoo03aoo`03
001oogoo02aoo`03001oogoo01Qoo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool0
0`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo
00Ioo`8003Uoo`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo01Qoo`00
5goo0`003Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo0`003Goo0`001Goo10001Goo00<007oo
Ool0>7oo00<007ooOol0;7oo00<007ooOol0?7oo00<007ooOol0;Goo00<007ooOol05goo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`0gOol00`00Oomoo`0^Ool00`00Oomoo`0jOol00`00Oomoo`0^
Ool00`00Oomoo`0GOol003Qoo`03001oogoo01moo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Io
o`<001Qoo`<000Ioo`8000Eoo`<001Yoo`<000Ioo`8000Eoo`<0025oo`D004Uoo`03001oogoo01mo
o`<000Ioo`8000Aoo`D000Aoo`03001oogoo015oo`<000Ioo`8000Ioo`<000Uoo`03001oogoo00ao
o`<000Ioo`8000Eoo`<001Uoo`<000Ioo`8000Eoo`<0021oo`H001Aoo`00>7oo0P007goo00D007oo
Oomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomoogoo00001Goo0P001goo00<007ooOol0
5Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000HOol01@00Oomoogoo00001Goo0P00
17oo00D007ooOomoo`00029oo`03001oogoo04Uoo`8001moo`05001oogooOol00005Ool20005Ool0
1000Oomoo`0017oo00<007ooOol047oo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo00Qoo`03
001oogoo00]oo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00005goo00<007ooOol00P00
1Goo0P0017oo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`03001oogoo01ioo`05001o
ogooOol0000=Ool00`00Oomoo`0GOol01@00Oomoogoo00002goo1@005goo00D007ooOomoo`0000]o
o`05001oogooOol0000HOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uo
o`03001oogoo01ioo`05001oogooOol0000=Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool01@00Oomo
ogoo00002goo1@002Goo00<007ooOol02goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol0
0`00Oomoo`02000;Ool01@00Oomoogoo000087oo00<007oo00005Woo000hOol00`00Oomoo`0NOol0
1@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00
Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo
00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo009oo`03001oogoo
015oo`05001oogooOol0000;Ool01000Oomoo`002goo00<007ooOol02Woo00D007ooOomoo`0000]o
o`05001oogooOol0000GOol01@00Ool007oo00002goo00D007ooOomoo`00021oo`03001oo`0001Io
o`00>7oo00<007ooOol07Woo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<
Ool00`00Ool0000HOol01@00Oomoogoo00002goo10006Goo00D007ooOomoo`0000aoo`<002=oo`03
001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000?Ool01@00Oomoogoo00004goo00D007oo
Oomoo`0000aoo`03001oo`0000]oo`03001oogoo00Yoo`05001oogooOol0000;Ool4000HOol01@00
Ool007oo000037oo0`008Goo00<007oo00005Woo000hOol2000OOol01@00Oomoogoo00003goo00<0
07ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomo
o`0JOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`8001moo`05001o
ogooOol0000?Ool01@00Oomoogoo00004goo00D007ooOomoo`0000aoo`03001oo`0000]oo`03001o
ogoo00Yoo`05001oogooOol0000;Ool00`00Oomoo`0IOol01@00Ool007oo00002goo00D007ooOomo
o`00025oo`8001Ioo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000]oo`05001oogooOol0000G
Ool01@00Oomoogoo00003Goo0P0067oo00D007ooOomoo`0000aoo`03001oogoo01Uoo`05001oogoo
Ool0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`00
00]oo`05001oogooOol00003Ool00`00Oomoo`0AOol01@00Oomoogoo00003Goo0P002goo00<007oo
Ool02Woo00D007ooOomoo`0000aoo`03001oogoo01Qoo`05001oo`00Ool0000;Ool01@00Oomoogoo
00008Goo0P005Woo000hOol00`00Oomoo`0OOol3000=Ool3000IOol3000?Ool00`00Oomoo`0GOol3
000>Ool3000IOol3000=Ool3000QOol3001;Ool00`00Oomoo`0OOol3000=Ool30003Ool00`00Oomo
o`0COol3000?Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool3000>Ool3000HOol3000=Ool3000QOol3
000FOol003Qoo`800?moobQoo`8003Ioo`03001oogoo039oo`03001oogoo03Ioo`03001oogoo039o
o`03001oogoo01Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0=Goo00<007ooOol0<Woo00<0
07ooOol0=Woo00<007ooOol0<goo00<007ooOol057oo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`0eOol00`00Oomoo`0bOol00`00Oomoo`0fOol00`00Oomoo`0cOol00`00Oomoo`0DOol003Qoo`03
001oogoo0?moobMoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo03Ao
o`03001oogoo01Aoo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`19Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0DOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001o
ogoo04]oo`00>7oo0P00ogoo:7oo0P00=7oo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol0
C7oo000hOol00`00Oomoo`3oOolWOol2000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomo
o`1<Ool003Qoo`03001oogoo0?moobMoo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03001o
ogoo04aoo`00>7oo00<007ooOol0ogoo9goo0P00=7oo00<007ooOol0=Woo00<007ooOol0<Woo00<0
07ooOol0C7oo000hOol2003oOolXOol3000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomo
o`1=Ool003Qoo`03001oogoo0?moobMoo`03001oo`00039oo`03001oogoo03Qoo`03001oogoo031o
o`03001oogoo04eoo`00>7oo00<007ooOol0ogoo9goo00<007oo0000<Woo00<007ooOol0>7oo00<0
07ooOol0<7oo00<007ooOol0CGoo000hOol00`00Oomoo`3oOolWOol00`00Ool0000bOol00`00Oomo
o`0iOol00`00Oomoo`0_Ool00`00Oomoo`1=Ool003Qoo`800?moobQoo`800003Ool007oo02moo`03
001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo00<007ooOol0ogoo9goo00@007oo
Ool0031oo`03001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo00<007ooOol0ogoo
9goo00@007ooOol0031oo`03001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo0P00
ogoo:7oo0P0000=oo`00Ool0;goo00<007ooOol0>goo00<007ooOol0;Goo00<007ooOol0CWoo000G
Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20004Ool50004Ool4
0005Ool01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo000F
Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo0?mo
o`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00D007ooOomo
o`0002ioo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo04moo`005Woo00D007ooOomoo`00
00eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000=Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007ooOol0
;7oo00<007ooOol0Cgoo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo
0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000=oo`03001o
ogoo02]oo`03001oogoo03eoo`03001oogoo02]oo`03001oogoo04moo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomo
o`02Ool40005Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol0
0`00Oomoo`1@Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
0Woo00<007ooOol0:Woo00<007ooOol0?Woo00<007ooOol0:Woo00<007ooOol0D7oo000FOol01@00
Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0
000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P000goo00<007ooOol0:Woo00<007ooOol0
?Woo00<007ooOol0:Woo00<007ooOol0D7oo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`3o
Ool6Ool3000=Ool30005Ool40005Ool00`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomoo`0oOol0
0`00Oomoo`0XOol00`00Oomoo`1AOol003Qoo`03001oogoo0?moobMoo`03001oogoo00=oo`03001o
ogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo055oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol00goo00<007ooOol0:7oo00<007ooOol0@7oo00<007ooOol0:7oo00<007ooOol0
DGoo000hOol2003oOolXOol20004Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol0
0`00Oomoo`1AOol003Qoo`03001oogoo0?moobMoo`03001oogoo00Aoo`03001oogoo02Moo`03001o
ogoo045oo`03001oogoo02Ioo`03001oogoo059oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
17oo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol0DWoo000hOol2003o
OolXOol20005Ool00`00Oomoo`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomoo`1BOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo04=oo`03001o
ogoo02Eoo`03001oogoo059oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol01Goo00<007ooOol0
9Goo00<007ooOol0@goo00<007ooOol097oo00<007ooOol0Dgoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`05Ool00`00Oomoo`0TOol00`00Oomoo`14Ool00`00Oomoo`0TOol00`00Oomoo`1COol0
03Qoo`800?moobQoo`8000Ioo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001o
ogoo05=oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo1000
1Goo00<007ooOol01Goo00<007ooOol097oo00<007ooOol0AGoo00<007ooOol08goo00<007ooOol0
Dgoo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo02=oo`03001o
ogoo04Eoo`03001oogoo029oo`03001oogoo05Aoo`007Woo00D007ooOomoo`00011oo`03001oogoo
009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0
0`00Oomoo`0ROol00`00Oomoo`16Ool00`00Oomoo`0ROol00`00Oomoo`1DOol001ioo`05001oogoo
Ool0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00
1goo00<007ooOol08Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol0E7oo000NOol01@00
Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001o
ogoo00Ioo`03001oogoo029oo`03001oogoo04Moo`03001oogoo025oo`03001oogoo05Aoo`007Woo
00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0POol00`00Oomoo`18Ool00`00Oomoo`0POol0
0`00Oomoo`1EOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomo
ogoo000037oo00<007ooOol01Woo0P0027oo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol0
87oo00<007ooOol0EGoo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool0
0`00Oomoo`07Ool00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`1EOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo00Moo`03001oogoo01moo`03001oogoo04Yoo`03001o
ogoo01moo`03001oogoo05Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol027oo00<007ooOol0
7Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000hOol2003oOolXOol20009Ool0
0`00Oomoo`0NOol00`00Oomoo`1;Ool00`00Oomoo`0MOol00`00Oomoo`1FOol003Qoo`03001oogoo
0?moobMoo`03001oogoo00Qoo`03001oogoo01eoo`03001oogoo04aoo`03001oogoo01eoo`03001o
ogoo05Ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol02Goo00<007ooOol077oo00<007ooOol0
C7oo00<007ooOol077oo00<007ooOol0Egoo000hOol2003oOolXOol2000:Ool00`00Oomoo`0LOol0
0`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`1GOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo00Uoo`03001oogoo01]oo`03001oogoo04ioo`03001oogoo01]oo`03001oogoo05Moo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol02Goo00<007ooOol06goo00<007ooOol0CWoo00<007ooOol0
6Woo00<007ooOol0F7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0:Ool00`00Oomoo`0JOol0
0`00Oomoo`1?Ool00`00Oomoo`0IOol00`00Oomoo`1HOol003Qoo`800?moobQoo`8000]oo`03001o
ogoo01Uoo`03001oogoo051oo`03001oogoo01Uoo`03001oogoo05Qoo`005goo0`001Woo0P001Woo
00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo1000
1Goo00<007ooOol02Woo00<007ooOol06Goo00<007ooOol0D7oo00<007ooOol067oo00<007ooOol0
FGoo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007oo
Ool0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001o
ogoo00]oo`03001oogoo01Qoo`03001oogoo055oo`03001oogoo01Moo`03001oogoo05Uoo`005Woo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0GOol0
0`00Oomoo`1BOol00`00Oomoo`0GOol00`00Oomoo`1IOol001Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P003Goo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05Woo00<007ooOol0
FWoo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo00aoo`03001oogoo01Ioo`03001o
ogoo05=oo`03001oogoo01Eoo`03001oogoo05Yoo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`0EOol00`00Oomoo`1DOol00`00Oomoo`0DOol0
0`00Oomoo`1KOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo
0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000>Ool0
0`00Oomoo`0DOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`1KOol001Moo`<000aoo`D0
00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo00eoo`03001o
ogoo01Aoo`03001oogoo05Eoo`03001oogoo019oo`03001oogoo05aoo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0
G7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`1FOol0
0`00Oomoo`0BOol00`00Oomoo`1LOol003Qoo`800?moobQoo`8000moo`03001oogoo019oo`03001o
ogoo05Moo`03001oogoo011oo`03001oogoo05eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol0F7oo00<007ooOol047oo00<007ooOol0GGoo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`1IOol00`00Oomoo`0>Ool0
0`00Oomoo`1NOol003Qoo`800?moobQoo`80015oo`03001oogoo00ioo`03001oogoo05Yoo`03001o
ogoo00ioo`03001oogoo05ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol04Goo00<007ooOol0
3Goo00<007ooOol0Fgoo00<007ooOol037oo00<007ooOol0Ggoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0AOol00`00Oomoo`0<Ool00`00Oomoo`1MOol00`00Oomoo`0;Ool00`00Oomoo`1OOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo019oo`03001oogoo00Yoo`03001oogoo05moo`03001o
ogoo00Uoo`03001oogoo061oo`00>7oo0P00ogoo:7oo0P0057oo00<007ooOol027oo00<007ooOol0
HGoo00<007ooOol01goo00<007ooOol0HGoo000_Ool50004Ool00`00Oomoo`3oOolNOol50004Ool0
0`00Oomoo`0DOol00`00Oomoo`06Ool00`00Oomoo`1ROol00`00Oomoo`06Ool00`00Oomoo`1ROol0
035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo01Eoo`03001o
ogoo00Aoo`03001oogoo06Aoo`03001oogoo00Aoo`03001oogoo06=oo`00<Goo00<007ooOol017oo
0P00ogoo8Goo00<007ooOol017oo0P005goo1P00J7oo1P00IWoo000aOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo
9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMo
o`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<00004Ool00000000HOol3003oOol7Ool3
000017oo000000006Goo0`00M7oo002FOol01@00Oomoogoo00002Goo1P002Goo00D007ooOomoo`00
0?moo`Moo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05001oogooOol0000L
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo000067oo1@00M7oo002FOol01@00Oomoogoo00002Goo
1P003Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Uoo`H000Uoo`04001oogoo001eOol009Io
o`05001oogooOol0000JOol2003oOol8Ool01@00Oomoogoo00006Goo00<007oo0000MGoo002EOol5
000MOol00`00Oomoo`3oOol4Ool5000JOol00`00Ool0001eOol00;=oo`05001oogooOol0003oOolV
Ool2001eOol00;Aoo`<00?moobQoo`03001oogoo07=oo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomF
Ool00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo000_Ool5003oOolUOol5003gOol0035o
o`03001oogoo0?moobMoo`03001oogoo0?Moo`009Woo1P001Goo00<007ooOol0ogoo77oo1P001Goo
00<007ooOol0mgoo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2000_Ool=002e
Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo02aoo`80
00eoo`800;=oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007oo
Ool0:Woo0P004Goo0P00/Goo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2000Y
Ool2000EOol2002_Ool002moo`<000Ioo`03001oogoo0?mooaioo`<000Ioo`03001oogoo02Moo`03
001oogoo01Moo`03001oogoo0:aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol09Goo0P006goo
00<007ooOol0Zgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0TOol00`00Oomoo`0LOol00`00
Oomoo`2ZOol003Qoo`800?moobQoo`8002Aoo`03001oogoo01ioo`03001oogoo0:Uoo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol08Woo00<007ooOol087oo00<007ooOol0Z7oo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`0QOol00`00Oomoo`0ROol00`00Oomoo`2WOol003Qoo`800?moobQoo`80
029oo`03001oogoo029oo`03001oogoo0:Moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol087oo
00<007ooOol097oo00<007ooOol0YWoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0OOol00`00
Oomoo`0VOol00`00Oomoo`2UOol003Qoo`03001oogoo0?moobMoo`03001oogoo01ioo`03001oogoo
02Qoo`03001oogoo0:Aoo`00>7oo0P00ogoo:7oo0P007goo00<007ooOol0:Goo00<007ooOol0Xgoo
000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20006
Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`0MOol00`00Oomoo`0[Ool00`00Oomoo`2ROol001Io
o`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol077oo
00<007ooOol0;7oo00<007ooOol0XWoo000>Ool60002Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol0o7oo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo01aoo`03001oogoo02eoo`03001oogoo0:5oo`005Woo00D007oo
Oomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool2000LOol00`00Oomoo`0_Ool00`00Oomoo`2POol001Ioo`05
001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo0000
3Woo00<007ooOol00goo10001Goo00<007ooOol06Woo00<007ooOol0<Goo00<007ooOol0Wgoo000F
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01Uoo`03001oogoo03=o
o`03001oogoo09ioo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06
Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8001Yo
o`03001oogoo03=oo`03001oogoo09ioo`005goo0`0037oo1@0017oo10001Goo00<007ooOol0ogoo
1Woo0`0037oo1@0017oo10001Goo00<007ooOol067oo00<007ooOol0=Goo00<007ooOol0WGoo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`0GOol00`00Oomoo`0gOol00`00Oomoo`2LOol003Qoo`03
001oogoo0?moobMoo`03001oogoo01Moo`03001oogoo03Moo`03001oogoo09aoo`00>7oo0P00ogoo
:7oo0P005goo00<007ooOol0>Goo00<007ooOol0Vgoo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`0EOol00`00Oomoo`0jOol00`00Oomoo`2KOol003Qoo`03001oogoo0?moobMoo`03001oogoo01Eo
o`03001oogoo03]oo`03001oogoo09Yoo`00>7oo0P00ogoo:7oo0P005Goo00<007ooOol0?Goo00<0
07ooOol0VGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0COol00`00Oomoo`0nOol00`00Oomo
o`2IOol003Qoo`03001oogoo0?moobMoo`03001oogoo01=oo`03001oogoo03moo`03001oogoo09Qo
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol04Woo00<007ooOol0@7oo00<007ooOol0V7oo000h
Ool2003oOolXOol2000BOol00`00Oomoo`12Ool00`00Oomoo`2GOol001moo`<000Ioo`8000Eoo`@0
00Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo015oo`03001oogoo04=o
o`03001oogoo09Ioo`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo
0?moo`eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomo
o`14Ool00`00Oomoo`2FOol001Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003o
Ool6Ool60002Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P0047oo00<007ooOol0AWoo00<0
07ooOol0UGoo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`00011oo`03001oogoo009oo`03001oogoo00moo`03001oogoo04Ioo`03001oogoo09Eo
o`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool4
0005Ool00`00Oomoo`0>Ool00`00Oomoo`18Ool00`00Oomoo`2DOol001ioo`05001oogooOol0000<
Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<0
07ooOol03Woo00<007ooOol0B7oo00<007ooOol0U7oo000NOol01@00Oomoogoo000037oo00<007oo
Ool01Woo0P00ogoo3Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`8000ioo`03001oogoo04Yo
o`03001oogoo09=oo`007goo0`003Goo10001Goo00<007ooOol0ogoo3Woo0`003Goo10001Goo00<0
07ooOol03Goo00<007ooOol0Bgoo00<007ooOol0TWoo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`0<Ool00`00Oomoo`1<Ool00`00Oomoo`2BOol003Qoo`03001oogoo0?moobMoo`03001oogoo00ao
o`03001oogoo04eoo`03001oogoo095oo`00>7oo0P00ogoo:7oo0P0037oo00<007ooOol0CWoo00<0
07ooOol0TGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0;Ool00`00Oomoo`1?Ool00`00Oomo
o`2@Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Yoo`03001oogoo055oo`03001oogoo08mo
o`00>7oo0P00ogoo:7oo0P002goo00<007ooOol0DGoo00<007ooOol0Sgoo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`09Ool00`00Oomoo`1COol00`00Oomoo`2>Ool003Qoo`03001oogoo0?moobMo
o`03001oogoo00Uoo`03001oogoo05=oo`03001oogoo08ioo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol027oo00<007ooOol0EGoo00<007ooOol0SGoo000hOol2003oOolXOol20009Ool00`00Oomo
o`1FOol00`00Oomoo`2<Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Io
o`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Moo`03001oogoo05Moo`03001oogoo08ao
o`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomo
o`3oOol5Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001o
ogoo00Moo`03001oogoo05Qoo`03001oogoo08]oo`003Woo1P000Woo00D007ooOomoo`0000eoo`03
001oogoo00Qoo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`1IOol00`00Oomoo`2;Ool001Ioo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0FWoo00<007ooOol0RWoo
000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0ogoo1Goo00D007oo
Oomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00Eoo`03001oogoo05]oo`03001oogoo
08Yoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?mo
o`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`1LOol00`00Oomoo`29Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<0
07ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06
Ool20005Ool00`00Oomoo`1MOol00`00Oomoo`29Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001o
ogoo0?moo`Ioo`<000eoo`<000Eoo`@000Eoo`03001oogoo00Aoo`03001oogoo05ioo`03001oogoo
08Qoo`00>7oo00<007ooOol07goo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`0067oo0`00
1Woo0P001Goo0`006Woo0`001Woo0P001Goo0`008Goo1@00BGoo00<007ooOol00goo00<007ooOol0
6Goo0`001Woo0P0017oo1@0067oo0`001Woo0P001Woo0`001Woo00<007ooOol03goo0`001Woo0P00
1Goo0`006Goo0`001Woo0P001Goo0`008Goo1@0057oo000hOol2000OOol01@00Oomoogoo00001Goo
0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00Oomoo`0FOol01@00Oomo
ogoo00001Goo0P0017oo00D007ooOomoo`0001Qoo`05001oogooOol00005Ool20004Ool01@00Oomo
ogoo00008Woo00<007ooOol0BGoo0P0017oo00<007ooOol067oo00D007ooOomoo`0000Eoo`8000Eo
o`04001oogoo000GOol01@00Oomoogoo00001Goo0P001goo00<007ooOol01Woo00<007ooOol03Goo
00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000GOol01@00Oomoogoo00001Goo0P0017oo
00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000eo
o`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol0
0Woo00<007ooOol06Goo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5
0007Ool00`00Oomoo`0=Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0
000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo
00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo0000
2goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0
BGoo00<007ooOol00Woo00<007ooOol06Goo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001o
ogooOol0000;Ool01000Oomoo`002Goo00<007ooOol037oo00D007ooOomoo`0000]oo`05001oogoo
Ool0000GOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<0
07ooOol07Woo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0
000HOol01@00Oomoogoo00002goo10006Goo00D007ooOomoo`0000aoo`<002=oo`03001oogoo04Uo
o`05001oogooOol0000LOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000ao
o`03001oo`0000Uoo`03001oogoo00aoo`05001oogooOol0000;Ool4000HOol01@00Oomoogoo0000
37oo0`008goo00<007ooOol057oo000hOol2000OOol01@00Oomoogoo00003goo00<007ooOol05Goo
00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`0JOol01@00
Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`80009oo`03001oogoo01Yoo`05
001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo00002Woo00<007oo
Ool02goo00D007ooOomoo`0000]oo`03001oogoo01Uoo`05001oogooOol0000;Ool01@00Oomoogoo
00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Moo`05001oogooOol0000=Ool2000HOol01@00Oomoogoo000037oo00<007ooOol06Goo00D0
07ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool01000Oomoo`007Goo00D007oo
Oomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00003Goo0P002Woo00<007ooOol02goo
00D007ooOomoo`0000aoo`03001oogoo01Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo
00<007ooOol057oo000hOol00`00Oomoo`0OOol3000=Ool3000IOol3000?Ool00`00Oomoo`0GOol3
000>Ool3000IOol3000=Ool3000QOol3001;Ool01000Oomoo`007Woo0`003Goo0`006Goo0`003goo
00<007ooOol02Goo00<007ooOol02goo0`003Woo0`0067oo0`003Goo0`008Goo0`005Woo000hOol0
0`00Oomoo`3oOolWOol00`00Ool0001YOol00`00Oomoo`24Ool003Qoo`800?moobQoo`<006Yoo`03
001oogoo08=oo`00>7oo00<007ooOol0ogoo9goo0P00Jgoo00<007ooOol0Pgoo000hOol00`00Oomo
o`3oOolWOol2001/Ool00`00Oomoo`22Ool0039oonT0041oonT0011oo`00>7oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0BGoo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
0P002Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool057oo000hOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0ZOol0
0`00Oomoo`0YOol00`00Oomoo`19Ool00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0DOol0
0`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0DOol003Qoo`03001oogoo
0?moobMoo`03001oogoo06eoo`03001oogoo06Qoo`03001oogoo01Eoo`00>7oo0P00ogoo:7oo0P00
KWoo00<007ooOol0J7oo00<007ooOol05Goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1]Ool0
0`00Oomoo`1WOol00`00Oomoo`0FOol003Qoo`03001oogoo0?moobMoo`03001oogoo06ioo`03001o
ogoo06Ioo`03001oogoo01Ioo`00>7oo0P00ogoo:7oo0P00Kgoo00<007ooOol0IGoo00<007ooOol0
5goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1_Ool00`00Oomoo`1TOol00`00Oomoo`0GOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo06moo`03001oogoo06=oo`03001oogoo01Qoo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0L7oo00<007ooOol0HWoo00<007ooOol067oo000hOol2003o
OolXOol2001aOol00`00Oomoo`1QOol00`00Oomoo`0IOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo075oo`03001oogoo061oo`03001oogoo01Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
LGoo00<007ooOol0Ggoo00<007ooOol06Woo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1bOol0
0`00Oomoo`1NOol00`00Oomoo`0JOol003Qoo`800?moobQoo`8007=oo`03001oogoo05eoo`03001o
ogoo01]oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P00
17oo1@0017oo10001Goo00<007ooOol0LWoo00<007ooOol0GGoo00<007ooOol06goo000FOol01@00
Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05
001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0Lgoo00<0
07ooOol0Fgoo00<007ooOol077oo000FOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007oo
Ool00Woo0P00ogoo1Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8007Ao
o`03001oogoo05]oo`03001oogoo01aoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`1dOol00`00Oomoo`1IOol00`00Oomoo`0MOol001Ioo`05001oogooOol0000?
Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol0
0Woo10001Goo00<007ooOol0M7oo00<007ooOol0FGoo00<007ooOol07Goo000FOol01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000mo
o`03001oogoo009oo`03001oogoo00Ioo`03001oogoo07Eoo`03001oogoo05Moo`03001oogoo01io
o`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool0
1@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8007Ioo`03001oogoo05Mo
o`03001oogoo01ioo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo0`003Goo0`00
1Goo10001Goo00<007ooOol0MWoo00<007ooOol0EGoo00<007ooOol07goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`1gOol00`00Oomoo`1DOol00`00Oomoo`0OOol003Qoo`800?moobQoo`8007Qo
o`03001oogoo05=oo`03001oogoo021oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0N7oo00<0
07ooOol0DWoo00<007ooOol087oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1hOol00`00Oomo
o`1AOol00`00Oomoo`0QOol003Qoo`03001oogoo0?moobMoo`03001oogoo07Uoo`03001oogoo04mo
o`03001oogoo029oo`00>7oo0P00ogoo:7oo0P00Ngoo00<007ooOol0CWoo00<007ooOol08Woo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`1jOol00`00Oomoo`1=Ool00`00Oomoo`0SOol003Qoo`03
001oogoo0?moobMoo`03001oogoo07]oo`03001oogoo04aoo`03001oogoo02=oo`00>7oo0P00ogoo
:7oo0P00O7oo00<007ooOol0Bgoo00<007ooOol097oo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`1lOol00`00Oomoo`1:Ool00`00Oomoo`0TOol001moo`<000Ioo`8000Eoo`@000Eoo`03001oogoo
0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo07eoo`03001oogoo04Qoo`03001oogoo02Eo
o`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?moo`eoo`05001o
ogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`1mOol00`00Oomoo`18Ool00`00Oomo
o`0UOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomoogoo0000
47oo00<007ooOol00Woo0P00Ogoo00<007ooOol0AWoo00<007ooOol09Woo000NOol01@00Oomoogoo
000047oo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`00011oo`03001oogoo009o
o`03001oogoo07ioo`03001oogoo04Ioo`03001oogoo02Ioo`007Woo00D007ooOomoo`0000aoo`@0
00Eoo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool40005Ool00`00Oomoo`1oOol00`00Oomo
o`14Ool00`00Oomoo`0WOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3o
Ool=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0P7oo00<007ooOol0@Woo00<0
07ooOol0:7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00ogoo3Woo00D007ooOomo
o`0000aoo`03001oogoo00Ioo`80085oo`03001oogoo049oo`03001oogoo02Qoo`007goo0`003Goo
10001Goo00<007ooOol0ogoo3Woo0`003Goo10001Goo00<007ooOol0PGoo00<007ooOol0@7oo00<0
07ooOol0:Goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`21Ool00`00Oomoo`0oOol00`00Oomo
o`0ZOol003Qoo`800?moobQoo`8008=oo`03001oogoo03ioo`03001oogoo02Yoo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0Pgoo00<007ooOol0?7oo00<007ooOol0:goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`23Ool00`00Oomoo`0kOol00`00Oomoo`0/Ool003Qoo`03001oogoo0?moobMo
o`03001oogoo08Aoo`03001oogoo03Yoo`03001oogoo02aoo`00>7oo0P00ogoo:7oo0P00QGoo00<0
07ooOol0>Goo00<007ooOol0;Goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`25Ool00`00Oomo
o`0gOol00`00Oomoo`0^Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Ioo`03001oogoo03Io
o`03001oogoo02ioo`00>7oo0P00ogoo:7oo0P00Qgoo00<007ooOol0=Goo00<007ooOol0;goo000G
Ool30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20006Ool0
0`00Oomoo`04Ool40005Ool00`00Oomoo`27Ool00`00Oomoo`0cOol00`00Oomoo`0`Ool001Ioo`05
001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0Qgoo00<0
07ooOol0<goo00<007ooOol0<7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`03001oogoo08Qoo`03001oogoo035oo`03001oogoo035oo`005Woo00D007ooOomoo`0000ioo`03
001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool2002:Ool00`00Oomoo`0_Ool00`00Oomoo`0bOol001Ioo`05001oogooOol0000>
Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol0
0goo10001Goo00<007ooOol0RGoo00<007ooOol0;Woo00<007ooOol0<goo000FOol01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000mo
o`03001oogoo009oo`03001oogoo00Ioo`03001oogoo08Yoo`03001oogoo02eoo`03001oogoo03=o
o`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`3o
Ool5Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo08]o
o`03001oogoo02]oo`03001oogoo03Aoo`005goo0`0037oo1@0017oo10001Goo0P00ogoo1goo0`00
37oo1@0017oo10001Goo0P00SGoo00<007ooOol0:Goo00<007ooOol0=Goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`2=Ool00`00Oomoo`0XOol00`00Oomoo`0eOol003Qoo`03001oogoo0?moobMo
o`03001oogoo08ioo`03001oogoo02Ioo`03001oogoo03Ioo`00>7oo0P00ogoo:7oo0P00T7oo00<0
07ooOol097oo00<007ooOol0=goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2@Ool00`00Oomo
o`0QOol2000jOol003Qoo`03001oogoo0?moobMoo`03001oogoo095oo`03001oogoo01moo`03001o
ogoo03Yoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0TWoo00<007ooOol07Goo00<007ooOol0
>goo000hOol2003oOolXOol2002DOol00`00Oomoo`0KOol00`00Oomoo`0lOol003Qoo`03001oogoo
0?moobMoo`03001oogoo09Aoo`03001oogoo01Uoo`03001oogoo03eoo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0UGoo0P0067oo00<007ooOol0?Woo000hOol2003oOolXOol2002HOol2000DOol2
0011Ool002moo`D000Aoo`03001oogoo0?mooaioo`D000Aoo`03001oogoo09Uoo`80011oo`8004=o
o`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0Vgoo00<0
07ooOol037oo00<007ooOol0@goo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomo
o`04Ool00`00Oomoo`2LOol40007Ool30016Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001o
ogoo00Aoo`800:5oo`L004Uoo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00
Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00;goo
0`00ogoo9goo0`00nGoo003oOoooOomFOol00?mooomooeIoo`00UGoo0`0000Aoo`00000001Qoo`D0
0?moo`Eoo`<00004Ool00000000GOol5001dOol009Ioo`05001oogooOol00009Ool6000<Ool00`00
Oomoo`3oOol6Ool01@00Oomoogoo00002Goo1P002Woo00@007ooOol007Aoo`00UWoo00D007ooOomo
o`0001]oo`03001oogoo0?moo`Ioo`05001oogooOol0000JOol00`00Oomoo`1dOol009Ioo`05001o
ogooOol00009Ool6000<Ool00`00Oomoo`3oOol6Ool01@00Oomoogoo00002Goo1P0037oo00<007oo
Ool0Lgoo002FOol01@00Oomoogoo00006goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001aoo`03
001oogoo079oo`00UGoo1@0077oo00<007ooOol0ogoo1Goo1@007Goo00<007ooOol0LWoo002fOol0
0`00Oomoo`3oOolSOol01@00Oomoogoo0000M7oo002dOol3003oOolVOol3001eOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomF
Ool00001\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25668 L
.08255 .23198 L
.10458 .20845 L
.12507 .19081 L
.14415 .17873 L
.14918 .1763 L
.15465 .17404 L
.15946 .17237 L
.16457 .17094 L
.16917 .16995 L
.17178 .16952 L
.17423 .1692 L
.17538 .16908 L
.17647 .16898 L
.17746 .1689 L
.17852 .16884 L
.17967 .16878 L
.18073 .16875 L
.182 .16873 L
.18314 .16873 L
.18435 .16875 L
.18547 .16879 L
.1867 .16885 L
.18802 .16893 L
.19071 .16918 L
.19317 .1695 L
.1979 .17034 L
.20239 .17142 L
.21236 .17479 L
.22321 .17994 L
.24299 .19309 L
.26399 .21189 L
.30174 .25553 L
.34195 .30996 L
.38063 .3623 L
.40028 .38637 L
.42177 .40933 L
.44253 .42723 L
.4614 .4392 L
.47149 .44376 L
.47611 .44541 L
.48101 .44684 L
.4835 .44744 L
.48624 .44801 L
.48876 .44844 L
.49106 .44876 L
.49378 .44904 L
.49527 .44915 L
.49596 .4492 L
Mistroke
.49669 .44923 L
.498 .44928 L
.49921 .4493 L
.49996 .44931 L
.50065 .4493 L
.50196 .44928 L
.50313 .44924 L
.50438 .44918 L
.50556 .4491 L
.50663 .44901 L
.50926 .44872 L
.51175 .44836 L
.5167 .4474 L
.52208 .44597 L
.53169 .44247 L
.54056 .43816 L
.55926 .42586 L
.57988 .40771 L
.62014 .3613 L
.65888 .30881 L
.70007 .25321 L
.72063 .22835 L
.73974 .20821 L
.75939 .19126 L
.77791 .17934 L
.78775 .17475 L
.79293 .17284 L
.7984 .17121 L
.80302 .17016 L
.80546 .16971 L
.80809 .16933 L
.8105 .16906 L
.8127 .16888 L
.81375 .16882 L
.81491 .16877 L
.81599 .16874 L
.817 .16873 L
.81818 .16873 L
.81941 .16875 L
.82047 .16879 L
.82163 .16885 L
.82287 .16893 L
.82421 .16904 L
.82661 .1693 L
.82905 .16965 L
.83134 .17005 L
.83564 .17099 L
.84078 .17245 L
.84552 .1741 L
.85624 .17893 L
Mistroke
.87498 .19084 L
.89561 .20863 L
.93591 .25457 L
.97471 .30696 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .43101 L
.08255 .48397 L
.0932 .50724 L
.10458 .5278 L
.11009 .53602 L
.11531 .54268 L
.12038 .5481 L
.12507 .55216 L
.12951 .55515 L
.13178 .55635 L
.13422 .55739 L
.13549 .55784 L
.13666 .55818 L
.13784 .55847 L
.13895 .55868 L
.14022 .55887 L
.1409 .55893 L
.14161 .55898 L
.1423 .55901 L
.14295 .55902 L
.14415 .55898 L
.14531 .55889 L
.14656 .55872 L
.14773 .5585 L
.14881 .55825 L
.15143 .55742 L
.15392 .55636 L
.15886 .55347 L
.16423 .54914 L
.17383 .53844 L
.1827 .52525 L
.20137 .48814 L
.22197 .43474 L
.26217 .30814 L
.30086 .1861 L
.32051 .1344 L
.3309 .11159 L
.342 .09132 L
.35275 .07612 L
.35784 .07055 L
.36253 .06637 L
.36724 .0631 L
.36972 .06176 L
.37235 .06063 L
.37463 .05989 L
.37573 .05961 L
.37677 .0594 L
.37799 .05921 L
.37911 .05909 L
Mistroke
.38031 .05903 L
.38162 .05903 L
.38227 .05905 L
.38296 .0591 L
.38419 .05924 L
.38551 .05947 L
.38695 .0598 L
.38955 .06062 L
.39197 .06165 L
.39649 .06425 L
.40134 .068 L
.40698 .07361 L
.41232 .08012 L
.42232 .09535 L
.44227 .13647 L
.4607 .18512 L
.50002 .30909 L
.53782 .42867 L
.55884 .48419 L
.56803 .50449 L
.57808 .52337 L
.58722 .53729 L
.59696 .54848 L
.60236 .55298 L
.60726 .556 L
.60962 .55709 L
.61086 .55756 L
.61218 .55799 L
.61333 .55831 L
.61459 .55859 L
.61574 .55878 L
.61682 .55891 L
.61808 .559 L
.61871 .55901 L
.61941 .55901 L
.62065 .55896 L
.62181 .55885 L
.62248 .55876 L
.62318 .55865 L
.62443 .55839 L
.62578 .55803 L
.62725 .55755 L
.62973 .55654 L
.63238 .55516 L
.63715 .55192 L
.64214 .5475 L
.64686 .54237 L
.6557 .53035 L
.67568 .4924 L
.69413 .44605 L
Mistroke
.7335 .32417 L
.77136 .20279 L
.79241 .1448 L
.81166 .1027 L
.82118 .08664 L
.8262 .07956 L
.83155 .07313 L
.8367 .06806 L
.84136 .06442 L
.84361 .06299 L
.84604 .06169 L
.84835 .0607 L
.85045 .05999 L
.85159 .05969 L
.85283 .05942 L
.85414 .05921 L
.85538 .05908 L
.85653 .05903 L
.85776 .05903 L
.85881 .05908 L
.85997 .05919 L
.86063 .05928 L
.86132 .0594 L
.86256 .05966 L
.86535 .06048 L
.86777 .06147 L
.87041 .06284 L
.87569 .06646 L
.88133 .07164 L
.89148 .08424 L
.90173 .10105 L
.91284 .12354 L
.933 .17412 L
.97393 .30158 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31516 L
.10458 .32174 L
.14415 .32771 L
.18221 .33314 L
.22272 .33851 L
.26171 .34318 L
.30316 .34752 L
.34309 .35103 L
.3815 .35371 L
.40095 .3548 L
.42237 .35578 L
.44268 .3565 L
.45178 .35675 L
.46172 .35697 L
.4671 .35707 L
.4721 .35715 L
.47727 .35722 L
.48196 .35727 L
.48658 .35731 L
.4887 .35732 L
.49093 .35734 L
.49332 .35735 L
.49438 .35735 L
.49552 .35735 L
.49675 .35736 L
.49789 .35736 L
.49859 .35736 L
.49925 .35736 L
.50049 .35736 L
.50163 .35736 L
.50286 .35736 L
.50401 .35735 L
.50508 .35735 L
.50754 .35734 L
.51014 .35733 L
.51268 .35732 L
.51504 .3573 L
.5204 .35725 L
.5293 .35713 L
.53882 .35696 L
.54906 .35673 L
.56016 .35641 L
.58032 .35567 L
.62123 .35354 L
.66064 .35073 L
.69852 .34736 L
.73886 .34311 L
.77769 .33846 L
.81897 .33298 L
Mistroke
.85873 .32728 L
.89697 .32151 L
.93767 .31514 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .23492 L
.10458 .15972 L
.14415 .09944 L
.18221 .05482 L
.20178 .03794 L
.21267 .03049 L
.22272 .02489 L
.23293 .02048 L
.23832 .01868 L
.24402 .01717 L
.24641 .01666 L
.24897 .01619 L
.25119 .01586 L
.25361 .01556 L
.25507 .01542 L
.25643 .01532 L
.25773 .01524 L
.2584 .0152 L
.25912 .01517 L
.25983 .01515 L
.26048 .01514 L
.26176 .01512 L
.26293 .01513 L
.26416 .01516 L
.26538 .0152 L
.26607 .01524 L
.26671 .01527 L
.26912 .01546 L
.27131 .01569 L
.27364 .016 L
.27847 .01688 L
.2838 .01819 L
.29326 .02139 L
.30213 .02541 L
.32232 .03816 L
.34082 .05406 L
.38045 .10051 L
.41855 .15859 L
.45912 .2307 L
.49816 .30545 L
.53966 .38504 L
.57964 .45642 L
.61811 .51554 L
.63759 .54064 L
.65902 .56382 L
.67938 .58114 L
.69843 .5929 L
.70884 .59745 L
.71396 .59919 L
Mistroke
.71872 .60051 L
.72301 .60146 L
.72758 .6022 L
.7302 .60251 L
.73148 .60263 L
.73266 .60272 L
.73371 .60279 L
.73487 .60284 L
.73603 .60288 L
.73725 .60291 L
.73856 .60291 L
.73977 .60289 L
.7404 .60288 L
.7411 .60285 L
.74251 .60278 L
.74375 .60271 L
.74508 .6026 L
.74748 .60235 L
.74985 .60203 L
.75235 .60161 L
.7568 .60067 L
.76198 .59927 L
.7668 .59765 L
.77773 .59292 L
.78828 .58695 L
.79823 .58009 L
.81683 .56415 L
.85534 .51928 L
.89632 .45682 L
.93577 .38646 L
.97371 .31383 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`1=Ool6001XOol6000_Ool003Qoo`800?moobQoo`8004eoo`03
001oogoo00Aoo`03001oogoo06Aoo`8000Eoo`03001oogoo02aoo`005goo0`001Woo0P001Woo00<0
07ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo
00<007ooOol0Bgoo00<007ooOol01Woo0P00Hgoo00<007ooOol01Woo0P00;7oo000FOol01@00Oomo
ogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007oo
Oomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04Yoo`03001oogoo
00Uoo`03001oogoo05moo`03001oogoo00Uoo`03001oogoo02Uoo`003Woo1P000Woo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool2001:Ool00`00Oomoo`0:Ool00`00Oomoo`1OOol00`00Oomo
o`09Ool00`00Oomoo`0YOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol0BGoo00<007ooOol02goo00<007ooOol0GGoo00<007ooOol02goo00<007ooOol0:7oo000F
Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo04Qoo`03001oogoo00aoo`03001oogoo05ao
o`03001oogoo00eoo`03001oogoo02Moo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`17Ool00`00Oomoo`0>Ool00`00Oomoo`1KOol00`00Oomoo`0=Ool00`00Oomo
o`0WOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo
1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20018Ool00`00Oomo
o`0?Ool00`00Oomoo`1IOol00`00Oomoo`0?Ool00`00Oomoo`0VOol001Moo`<000aoo`D000Aoo`@0
00Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo04Ioo`03001oogoo011o
o`03001oogoo05Qoo`03001oogoo011oo`03001oogoo02Ioo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0AGoo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol09Goo000h
Ool2003oOolXOol20016Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol00`00Oomo
o`0UOol003Qoo`03001oogoo0?moobMoo`03001oogoo04Aoo`03001oogoo01Aoo`03001oogoo05Ao
o`03001oogoo01Aoo`03001oogoo02Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0A7oo00<0
07ooOol057oo00<007ooOol0E7oo00<007ooOol05Goo00<007ooOol08goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`13Ool00`00Oomoo`0FOol00`00Oomoo`1COol00`00Oomoo`0EOol00`00Oomo
o`0SOol003Qoo`800?moobQoo`8004Aoo`03001oogoo01Ioo`03001oogoo059oo`03001oogoo01Mo
o`03001oogoo029oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0@goo00<007ooOol05goo00<0
07ooOol0DGoo00<007ooOol05goo00<007ooOol08Woo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`12Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`0QOol003Qoo`80
0?moobQoo`8004=oo`03001oogoo01Uoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025o
o`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<0
07ooOol0@Goo00<007ooOol06Woo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol08Goo000N
Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomo
o`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo045oo`03001oogoo01]oo`03001oogoo04eo
o`03001oogoo01]oo`03001oogoo021oo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo
009oo`03001oogoo0?moo`Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomo
o`11Ool00`00Oomoo`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`0POol001ioo`05
001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<007ooOol0
0Woo0P00@Goo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol087oo000N
Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eo
o`03001oogoo041oo`03001oogoo01eoo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo01mo
o`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0
000<Ool00`00Oomoo`06Ool00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1;Ool00`00Oomo
o`0MOol00`00Oomoo`0OOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0O
Ool6002>Ool5001DOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0?goo00<007oo
Ool07Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol07goo000OOol3000=Ool40005Ool2
000MOol40005Ool40026Ool40005Ool3001BOol3000=Ool40005Ool2000oOol00`00Oomoo`0POol0
0`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`0NOol003Qoo`03001oogoo01Yoo`8000eoo`80
089oo`8000aoo`<006Qoo`03001oogoo03ioo`03001oogoo021oo`03001oogoo04Qoo`03001oogoo
021oo`03001oogoo01ioo`00>7oo00<007ooOol067oo0P004Goo0P00OWoo0P004Goo0P00IWoo00<0
07ooOol0?Woo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol087oo00<007ooOol07Woo000h
Ool2000FOol3000EOol2001jOol2000EOol2001TOol2000nOol00`00Oomoo`0ROol00`00Oomoo`17
Ool00`00Oomoo`0QOol00`00Oomoo`0MOol003Qoo`03001oogoo01Aoo`03001oogoo01Qoo`03001o
ogoo07Ioo`03001oogoo01Moo`03001oogoo065oo`03001oogoo03eoo`03001oogoo029oo`03001o
ogoo04Ioo`03001oogoo029oo`03001oogoo01eoo`00>7oo00<007ooOol04goo00<007ooOol06Woo
0P00M7oo0P006goo00<007ooOol0H7oo00<007ooOol0?Goo00<007ooOol08Woo00<007ooOol0AWoo
00<007ooOol08Woo00<007ooOol07Goo000hOol00`00Oomoo`0BOol00`00Oomoo`0MOol00`00Oomo
o`1`Ool00`00Oomoo`0LOol00`00Oomoo`1OOol00`00Oomoo`0lOol00`00Oomoo`0TOol00`00Oomo
o`15Ool00`00Oomoo`0SOol00`00Oomoo`0LOol003Qoo`80019oo`03001oogoo01moo`03001oogoo
06ioo`03001oogoo01ioo`03001oogoo05ioo`8003eoo`03001oogoo02Aoo`03001oogoo04Aoo`03
001oogoo02Aoo`03001oogoo01aoo`00>7oo00<007ooOol047oo00<007ooOol08Goo00<007ooOol0
K7oo00<007ooOol087oo00<007ooOol0GGoo00<007ooOol0?7oo00<007ooOol097oo00<007ooOol0
A7oo00<007ooOol097oo00<007ooOol077oo000hOol00`00Oomoo`0@Ool00`00Oomoo`0ROol00`00
Oomoo`1ZOol00`00Oomoo`0ROol00`00Oomoo`1LOol00`00Oomoo`0kOol00`00Oomoo`0VOol00`00
Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`0KOol003Qoo`80011oo`03001oogoo02=oo`03001o
ogoo06Uoo`03001oogoo02=oo`03001oogoo05aoo`8003aoo`03001oogoo02Ioo`03001oogoo049o
o`03001oogoo02Ioo`03001oogoo01]oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007oo
Ool03Woo00<007ooOol09Goo00<007ooOol0Igoo00<007ooOol09Goo00<007ooOol0>Woo0`001Woo
0P0017oo1@0017oo10001Goo00<007ooOol0>goo00<007ooOol09Woo00<007ooOol0@Woo00<007oo
Ool09Woo00<007ooOol06goo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03
001oogoo009oo`03001oogoo00eoo`03001oogoo02Moo`03001oogoo06Eoo`03001oogoo02Moo`03
001oogoo03Qoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<0
07ooOol0>Woo00<007ooOol0:7oo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol06Woo000>
Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol037oo
00<007ooOol0:Goo00<007ooOol0Hgoo00<007ooOol0:Goo00<007ooOol0;goo1P000Woo00D007oo
Oomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo03Yoo`03001oogoo02Qoo`03
001oogoo041oo`03001oogoo02Qoo`03001oogoo01Yoo`005Woo00D007ooOomoo`0000ioo`03001o
ogoo00Moo`03001oogoo009oo`8000aoo`03001oogoo02]oo`03001oogoo069oo`03001oogoo02Yo
o`03001oogoo03Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000kOol0
0`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`0JOol001Ioo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`0;Ool00`00Oomoo`0[Ool00`00Oomoo`1Q
Ool00`00Oomoo`0/Ool00`00Oomoo`0eOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo
00<007ooOol0>Goo00<007ooOol0:Woo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol06Goo
000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol02Woo00<0
07ooOol0;Goo00<007ooOol0Ggoo00<007ooOol0;Woo00<007ooOol0=7oo00D007ooOomoo`0000mo
o`03001oogoo009oo`03001oogoo00Ioo`03001oogoo03Uoo`03001oogoo02Yoo`03001oogoo03io
o`03001oogoo02Yoo`03001oogoo01Uoo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004
Ool00`00Oomoo`06Ool2000:Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool00`00
Oomoo`0cOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8003Yoo`03
001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo01Uoo`005goo0`003Goo0`00
1Goo10001Goo00<007ooOol027oo00<007ooOol0<Goo00<007ooOol0G7oo00<007ooOol0<Goo00<0
07ooOol0<goo0`003Goo0`001Goo10001Goo00<007ooOol0>7oo00<007ooOol0;7oo00<007ooOol0
?Goo00<007ooOol0:goo00<007ooOol067oo000hOol00`00Oomoo`07Ool00`00Oomoo`0cOol00`00
Oomoo`1JOol00`00Oomoo`0cOol00`00Oomoo`1COol00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00
Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`0HOol003Qoo`03001oogoo00Ioo`03001oogoo01Io
o`<000Ioo`8000Aoo`D000Yoo`03001oogoo00]oo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eo
o`<0011oo`03001oogoo00Moo`<000Ioo`8000Eoo`<001Uoo`03001oogoo00Eoo`D004Uoo`03001o
ogoo01moo`<000Ioo`8000Aoo`D000Eoo`03001oogoo011oo`<000Ioo`8000Ioo`<000Qoo`03001o
ogoo00eoo`<000Ioo`8000Eoo`<001Uoo`@000Eoo`8000Eoo`<001moo`03001oo`0000@001Aoo`00
>7oo0P001goo00<007ooOol05Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000;Ool00`00
Oomoo`09Ool01@00Oomoogoo00001Goo0P001goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`80
00Aoo`05001oogooOol0000>Ool00`00Oomoo`07Ool01@00Oomoogoo00001Goo0P0017oo00D007oo
Oomoo`0001Uoo`03001oogoo00Ioo`03001oogoo04Uoo`8001moo`05001oogooOol00005Ool20005
Ool01000Oomoo`001Goo00<007ooOol03goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo00Mo
o`03001oogoo00aoo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00005goo00D007ooOomo
o`0000Eoo`8000Aoo`05001oogooOol0000OOol01000Oomoo`005Woo000hOol00`00Oomoo`05Ool0
0`00Oomoo`0FOol01@00Oomoogoo00003Goo00<007ooOol037oo00<007ooOol027oo00D007ooOomo
o`0000]oo`D001Moo`05001oogooOol0000;Ool01@00Oomoogoo00003Goo00<007ooOol027oo00D0
07ooOomoo`0000]oo`05001oogooOol0000JOol00`00Oomoo`05Ool00`00Oomoo`19Ool00`00Oomo
o`0NOol01@00Oomoogoo00003Goo00<007ooOol017oo00<007ooOol047oo00D007ooOomoo`0000]o
o`D000Uoo`03001oogoo00]oo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00<007ooOol0
0P002goo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`03001oogoo00Aoo`03001oogoo
01Moo`05001oogooOol0000>Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool01@00Oomoogoo00002goo
00@007ooOol001Qoo`05001oogooOol0000;Ool01@00Oomoogoo000037oo00<007ooOol02Goo00D0
07ooOomoo`0000]oo`05001oogooOol0000KOol00`00Oomoo`04Ool00`00Oomoo`19Ool00`00Oomo
o`0NOol01@00Oomoogoo00003Woo00<007ooOol00goo00<007ooOol047oo00D007ooOomoo`0000]o
o`04001oogoo000:Ool00`00Oomoo`0;Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`03
001oogoo008000]oo`05001oogooOol0000OOol01000Oomoo`005Woo000hOol00`00Oomoo`03Ool0
0`00Oomoo`0HOol01@00Oomoogoo00003goo00<007ooOol02goo00<007ooOol01goo00D007ooOomo
o`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool4000=Ool00`00Oomoo`09Ool01@00Oomo
ogoo000037oo0`0077oo00<007ooOol017oo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomo
o`0000moo`03001oogoo009oo`03001oogoo011oo`05001oogooOol0000<Ool00`00Ool0000:Ool0
0`00Oomoo`0;Ool01@00Oomoogoo00002goo100067oo00<007ooOol00P0037oo0`008Goo00<007oo
00005Woo000hOol20004Ool00`00Oomoo`0HOol01@00Oomoogoo00003goo00<007ooOol037oo00<0
07ooOol01Woo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomo
o`0=Ool00`00Oomoo`0:Ool01@00Oomoogoo00002goo00D007ooOomoo`0001aoo`03001oogoo00=o
o`03001oogoo04Uoo`8001moo`05001oogooOol0000?Ool01@00Oomoogoo00004goo00D007ooOomo
o`0000aoo`03001oo`0000]oo`03001oogoo00Yoo`05001oogooOol0000;Ool00`00Oomoo`0IOol0
1@00Ool007oo00002goo00D007ooOomoo`00021oo`03001oo`0001Ioo`00>7oo00<007ooOol00Woo
00<007ooOol06Goo00D007ooOomoo`0000]oo`05001oogooOol0000?Ool00`00Oomoo`05Ool01@00
Oomoogoo00003Goo0P0067oo00D007ooOomoo`0000aoo`03001oogoo00]oo`03001oogoo00]oo`05
001oogooOol0000;Ool01@00Oomoogoo00007Goo00<007ooOol00Woo00<007ooOol0BGoo00<007oo
Ool07Woo00D007ooOomoo`0000]oo`05001oogooOol00003Ool00`00Oomoo`0AOol01@00Oomoogoo
00003Goo0P002goo00<007ooOol02Woo00D007ooOomoo`0000aoo`03001oogoo01Qoo`05001oo`00
Ool0000;Ool01@00Oomoogoo000087oo00<007oo00005Woo000hOol01@00Oomoogoo00007Goo0`00
3Goo0`004Goo00<007ooOol01Goo0`003goo00<007ooOol05goo0`003Woo0`002Goo00<007ooOol0
3Goo0`003Goo0`007goo00<007oo00000P00Bgoo00<007ooOol07goo0`003Goo0`0017oo00<007oo
Ool04Woo0`003goo00<007ooOol02Goo00<007ooOol02goo0`003Woo0`0067oo0`003Goo0`008Goo
0`005Woo000hOol200000goo001oo`12Ool00`00Oomoo`1<Ool00`00Oomoo`10Ool00`00Oomoo`1=
Ool2000fOol00`00Oomoo`0bOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`0EOol003Qo
o`04001oogoo0013Ool00`00Oomoo`1<Ool00`00Oomoo`11Ool00`00Oomoo`1<Ool00`00Oomoo`0e
Ool00`00Oomoo`0bOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`0EOol003Qoo`03001o
o`0004Eoo`03001oogoo04Yoo`03001oogoo04=oo`03001oogoo04]oo`03001oogoo03Eoo`03001o
ogoo039oo`03001oogoo03Ioo`03001oogoo03=oo`03001oogoo01Aoo`00>7oo0P00Agoo00<007oo
Ool0B7oo00<007ooOol0AGoo00<007ooOol0BWoo00<007ooOol0=7oo00<007ooOol0=7oo00<007oo
Ool0=7oo00<007ooOol0=7oo00<007ooOol057oo000bOooY0010OooY000@Ool003Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Eoo`04001oogoo000:Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool01@00Oomoogoo00001Woo00<007ooOol027oo00<0
07ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol0BGoo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol057oo000hOol00`00Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`2D
Ool00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0cOol00`00Oomoo`1<Ool003Qoo`8004Yo
o`03001oogoo049oo`03001oogoo09Eoo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03001o
ogoo04aoo`00>7oo00<007ooOol0BWoo00<007ooOol0@7oo00<007ooOol0UWoo0P00=7oo00<007oo
Ool0=Woo00<007ooOol0<Woo00<007ooOol0C7oo000hOol00`00Oomoo`1:Ool00`00Oomoo`10Ool0
0`00Oomoo`2FOol2000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`1<Ool003Qoo`03
001oogoo04]oo`03001oogoo03ioo`03001oogoo09Moo`03001oo`00039oo`03001oogoo03Qoo`03
001oogoo031oo`03001oogoo04eoo`00>7oo0P00CGoo00<007ooOol0?7oo00<007ooOol0V7oo0`00
<Woo00<007ooOol0>7oo00<007ooOol0<7oo00<007ooOol0CGoo000hOol00`00Oomoo`1=Ool00`00
Oomoo`0jOol00`00Oomoo`2IOol00`00Ool0000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00
Oomoo`1=Ool003Qoo`03001oogoo04eoo`03001oogoo03Yoo`03001oogoo09Uoo`04001oogoo000`
Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`1>Ool003Qoo`03001oogoo04ioo`03001o
ogoo03Qoo`03001oogoo09Yoo`04001oogoo000`Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00
Oomoo`1>Ool003Qoo`80051oo`03001oogoo03Ioo`03001oogoo09]oo`800003Ool007oo02moo`03
001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo00<007ooOol0D7oo00<007ooOol0
=7oo00<007ooOol0W7oo00D007ooOomoo`0002ioo`03001oogoo03aoo`03001oogoo02aoo`03001o
ogoo04moo`00>7oo00<007ooOol0D7oo00<007ooOol0=7oo00<007ooOol0W7oo00D007ooOomoo`00
02ioo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo04moo`00>7oo0P00DWoo00<007ooOol0
<Woo00<007ooOol0WGoo0P000Woo00<007ooOol0;7oo00<007ooOol0?7oo00<007ooOol0;7oo00<0
07ooOol0Cgoo000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`1BOol00`00Oomoo`0`
Ool00`00Oomoo`1mOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`02Ool00`00Oomoo`0Z
Ool00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05001oogooOol00005Ool2
0005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0DWoo00<007ooOol0;goo00<007oo
Ool0OGoo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05
001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`0]
Ool00`00Oomoo`1nOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol0:Woo00<007ooOol0?Woo00<007ooOol0:Woo00<007ooOol0D7oo000FOol0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00EGoo00<007ooOol0:goo00<0
07ooOol0Ogoo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000Aoo`03001o
ogoo02Uoo`03001oogoo03moo`03001oogoo02Qoo`03001oogoo055oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`@000Eoo`03001oogoo05Eoo`03001oogoo02Yoo`03001oogoo07moo`05
001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`03Ool00`00Oomoo`0XOol00`00
Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`1AOol001Ioo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`1FOol00`00Oomoo`0XOol00`00Oomoo`20Ool01@00Oomo
ogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0:7oo00<0
07ooOol0@7oo00<007ooOol0:7oo00<007ooOol0DGoo000FOol01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`8005Qoo`03001oogoo02Ioo`03001oogoo085oo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P001Goo00<007ooOol09goo00<007oo
Ool0@Goo00<007ooOol09goo00<007ooOol0DGoo000GOol3000=Ool30005Ool40005Ool00`00Oomo
o`1HOol00`00Oomoo`0TOol00`00Oomoo`23Ool3000=Ool30005Ool40005Ool00`00Oomoo`04Ool0
0`00Oomoo`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomoo`1BOol003Qoo`03001oogoo
05Uoo`80029oo`800:Moo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo
02Ioo`03001oogoo059oo`00>7oo00<007ooOol0Fgoo00<007ooOol07Woo00<007ooOol0Ygoo00<0
07ooOol01Goo00<007ooOol09Goo00<007ooOol0@goo00<007ooOol09Goo00<007ooOol0DWoo000h
Ool2001MOol00`00Oomoo`0LOol00`00Oomoo`2XOol20006Ool00`00Oomoo`0TOol00`00Oomoo`14
Ool00`00Oomoo`0TOol00`00Oomoo`1COol003Qoo`03001oogoo05eoo`03001oogoo01Yoo`03001o
ogoo0:Uoo`03001oogoo00Eoo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001o
ogoo05=oo`00>7oo00<007ooOol0GWoo0P0067oo0P00[7oo00<007ooOol01Woo00<007ooOol08goo
00<007ooOol0AGoo00<007ooOol08goo00<007ooOol0Dgoo000hOol2001QOol00`00Oomoo`0DOol0
0`00Oomoo`2/Ool20007Ool00`00Oomoo`0ROol00`00Oomoo`16Ool00`00Oomoo`0ROol00`00Oomo
o`1DOol003Qoo`03001oogoo065oo`03001oogoo019oo`03001oogoo0:eoo`03001oogoo00Ioo`03
001oogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo05Aoo`00>7oo00<007ooOol0
HWoo0`003goo0P00/7oo00<007ooOol01goo00<007ooOol08Goo00<007ooOol0Agoo00<007ooOol0
8Goo00<007ooOol0E7oo000hOol00`00Oomoo`1UOol2000;Ool2002bOol00`00Oomoo`07Ool00`00
Oomoo`0POol00`00Oomoo`18Ool00`00Oomoo`0POol00`00Oomoo`1EOol003Qoo`8006Qoo`/00;Ao
o`8000Qoo`03001oogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001oogoo05Eoo`007goo
0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0
27oo00<007ooOol07goo00<007ooOol0BGoo00<007ooOol07goo00<007ooOol0EGoo000NOol01@00
Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eo
o`8000Uoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo01ioo`03001oogoo04Yoo`03001o
ogoo01ioo`03001oogoo05Ioo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo
0?moo`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`0NOol0
0`00Oomoo`1;Ool00`00Oomoo`0MOol00`00Oomoo`1FOol001ioo`05001oogooOol0000@Ool00`00
Oomoo`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P002Woo00<007ooOol0
77oo00<007ooOol0C7oo00<007ooOol07Goo00<007ooOol0EWoo000NOol01@00Oomoogoo000037oo
10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo00Uoo`03001o
ogoo01aoo`03001oogoo04eoo`03001oogoo01]oo`03001oogoo05Moo`007Woo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool0
0`00Oomoo`09Ool00`00Oomoo`0KOol00`00Oomoo`1>Ool00`00Oomoo`0KOol00`00Oomoo`1GOol0
01ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<0
07ooOol01Woo0P002goo00<007ooOol06Woo00<007ooOol0CWoo00<007ooOol06Woo00<007ooOol0
F7oo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`0:Ool0
0`00Oomoo`0JOol00`00Oomoo`1?Ool00`00Oomoo`0IOol00`00Oomoo`1HOol003Qoo`03001oogoo
0?moobMoo`03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo051oo`03001oogoo01Uoo`03001o
ogoo05Qoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol02goo00<007ooOol067oo00<007ooOol0
DGoo00<007ooOol05goo00<007ooOol0FGoo000hOol2003oOolXOol2000<Ool00`00Oomoo`0GOol0
0`00Oomoo`1BOol00`00Oomoo`0GOol00`00Oomoo`1IOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo00aoo`03001oogoo01Ioo`03001oogoo059oo`03001oogoo01Ioo`03001oogoo05Yoo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol037oo00<007ooOol05Goo00<007ooOol0E7oo00<007ooOol0
5Goo00<007ooOol0FWoo000hOol2003oOolXOol2000>Ool00`00Oomoo`0DOol00`00Oomoo`1DOol0
0`00Oomoo`0DOol00`00Oomoo`1KOol003Qoo`03001oogoo0?moobMoo`03001oogoo00eoo`03001o
ogoo01Aoo`03001oogoo05Eoo`03001oogoo019oo`03001oogoo05aoo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0
G7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`1GOol0
0`00Oomoo`0@Ool00`00Oomoo`1MOol003Qoo`800?moobQoo`8000moo`03001oogoo015oo`03001o
ogoo05Qoo`03001oogoo011oo`03001oogoo05eoo`005goo0`001Woo0P001Woo00<007ooOol017oo
10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0
3goo0P004Goo00<007ooOol0FGoo00<007ooOol03Woo00<007ooOol0GWoo000FOol01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo015oo`03001oogoo00eo
o`03001oogoo05Yoo`03001oogoo00ioo`03001oogoo05ioo`005Woo00D007ooOomoo`0000ioo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`0;Ool2001NOol2000=Ool00`00Oomo
o`1OOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P004goo00<007ooOol02Goo00<0
07ooOol0H7oo00<007ooOol02Goo00<007ooOol0H7oo000FOol01@00Oomoogoo00003Woo00<007oo
Ool00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eo
o`03001oogoo01=oo`03001oogoo00Moo`03001oogoo069oo`03001oogoo00Moo`03001oogoo065o
o`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eo
o`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0DOol00`00Oomo
o`05Ool00`00Oomoo`1TOol00`00Oomoo`05Ool00`00Oomoo`1ROol001Ioo`05001oogooOol0000;
Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001o
ogooOol00004Ool00`00Oomoo`06Ool2000FOol30002Ool2001XOol20003Ool2001UOol001Moo`<0
00aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo01Mo
o`@006Yoo`@006Moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000_
Ool50004Ool00`00Oomoo`3oOolNOol50004Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03
001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo
8Goo00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03
001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000a
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo
003oOoooOomFOol009Eoo`<00004Ool00000000HOol3003oOol7Ool3000017oo000000006Goo0`00
M7oo002FOol01@00Oomoogoo00002Goo1P002Goo00D007ooOomoo`000?moo`Moo`05001oogooOol0
0009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05001oogooOol0000LOol00`00Oomoo`3oOol5Ool0
1@00Oomoogoo000067oo1@00M7oo002FOol01@00Oomoogoo00002Goo1P003Goo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000Uoo`H000Uoo`04001oogoo001eOol009Ioo`05001oogooOol0000JOol2
003oOol8Ool01@00Oomoogoo00006Goo00<007oo0000MGoo002EOol5000MOol00`00Oomoo`3oOol4
Ool5000JOol00`00Ool0001eOol00;=oo`05001oogooOol0003oOolVOol2001eOol00;Aoo`<00?mo
obQoo`03001oogoo07=oo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo000_Ool5003oOolUOol5003gOol0035oo`03001oogoo0?moobMoo`03
001oogoo0?Moo`009Woo1P001Goo00<007ooOol0ogoo77oo1P001Goo00<007ooOol0mgoo000aOol0
0`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0
ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00
Oomoo`04Ool2000aOol8002hOol002moo`<000Ioo`03001oogoo0?mooaioo`<000Ioo`03001oogoo
02aoo`D000Moo`<00;Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0:goo00<007ooOol03Goo
0P00/goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0ZOol00`00Oomoo`0@Ool2002aOol003Qo
o`800?moobQoo`8002Uoo`8001Eoo`<00:ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol09Goo
0`006Woo00<007ooOol0Zgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0TOol00`00Oomoo`0L
Ool00`00Oomoo`2ZOol003Qoo`800?moobQoo`8002Aoo`03001oogoo01ioo`03001oogoo0:Uoo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol08Woo00<007ooOol087oo00<007ooOol0Z7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`0QOol00`00Oomoo`0ROol00`00Oomoo`2WOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo025oo`03001oogoo029oo`03001oogoo0:Moo`00>7oo0P00ogoo:7oo
0P008Goo00<007ooOol097oo00<007ooOol0YWoo000GOol30006Ool20006Ool00`00Oomoo`04Ool4
0005Ool00`00Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`0O
Ool00`00Oomoo`0VOol00`00Oomoo`2UOol001Ioo`05001oogooOol00005Ool20006Ool00`00Oomo
o`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Woo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol0:7oo00<007ooOol0Y7oo000>Ool6
0002Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0o7oo1P00
0Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo01ioo`03001o
ogoo02Uoo`03001oogoo0:=oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo
009oo`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000NOol0
0`00Oomoo`0[Ool00`00Oomoo`2ROol001Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0
77oo00<007ooOol0;7oo00<007ooOol0XWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001o
ogoo00Ioo`03001oogoo01aoo`03001oogoo02eoo`03001oogoo0:5oo`005Woo00D007ooOomoo`00
00]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D0
07ooOomoo`0000Aoo`03001oogoo00Ioo`8001aoo`03001oogoo02moo`03001oogoo0:1oo`005goo
0`0037oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`0037oo1@0017oo10001Goo00<007ooOol0
6Woo00<007ooOol0<Goo00<007ooOol0Wgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0IOol0
0`00Oomoo`0cOol00`00Oomoo`2NOol003Qoo`03001oogoo0?moobMoo`03001oogoo01Uoo`03001o
ogoo03=oo`03001oogoo09ioo`00>7oo0P00ogoo:7oo0P006Goo00<007ooOol0=Goo00<007ooOol0
WGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0GOol00`00Oomoo`0gOol00`00Oomoo`2LOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo01Ioo`03001oogoo03Qoo`03001oogoo09aoo`00>7oo
0P00ogoo:7oo0P005goo00<007ooOol0>Goo00<007ooOol0Vgoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0EOol00`00Oomoo`0kOol00`00Oomoo`2JOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo01Aoo`03001oogoo03eoo`03001oogoo09Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
57oo00<007ooOol0?Goo00<007ooOol0VGoo000hOol2003oOolXOol2000DOol00`00Oomoo`0oOol0
0`00Oomoo`2HOol001moo`<000Ioo`8000Eoo`@000Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eo
o`@000Eoo`03001oogoo019oo`03001oogoo045oo`03001oogoo09Moo`007Woo00D007ooOomoo`00
00Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol00005Ool20009Ool0
0`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`12Ool00`00Oomoo`2GOol001Ioo`H0009oo`05
001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol6Ool60002Ool01@00Oomoogoo000047oo00<0
07ooOol00Woo0P004Woo00<007ooOol0@goo00<007ooOol0UWoo000NOol01@00Oomoogoo000047oo
00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`00011oo`03001oogoo009oo`03001o
ogoo011oo`03001oogoo04Eoo`03001oogoo09Eoo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03
001oogoo0?moo`eoo`05001oogooOol0000<Ool40005Ool00`00Oomoo`0?Ool00`00Oomoo`16Ool0
0`00Oomoo`2EOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool0
1@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol03goo00<007ooOol0Agoo00<007ooOol0
U7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00ogoo3Woo00D007ooOomoo`0000ao
o`03001oogoo00Ioo`8000moo`03001oogoo04Qoo`03001oogoo09Aoo`007goo0`003Goo10001Goo
00<007ooOol0ogoo3Woo0`003Goo10001Goo00<007ooOol03Woo00<007ooOol0BGoo00<007ooOol0
Tgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0=Ool00`00Oomoo`1;Ool00`00Oomoo`2BOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo00eoo`03001oogoo04]oo`03001oogoo099oo`00>7oo
0P00ogoo:7oo0P003Goo00<007ooOol0CGoo00<007ooOol0TGoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0<Ool00`00Oomoo`1=Ool00`00Oomoo`2AOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo00]oo`03001oogoo04moo`03001oogoo091oo`00>7oo0P00ogoo:7oo0P002goo00<007ooOol0
DGoo00<007ooOol0Sgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0:Ool00`00Oomoo`1AOol0
0`00Oomoo`2?Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00Uoo`03001oogoo05=oo`03001o
ogoo08ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol02Goo00<007ooOol0Dgoo00<007ooOol0
SWoo000hOol2003oOolXOol20009Ool00`00Oomoo`1EOol00`00Oomoo`2=Ool001Moo`<000Ioo`80
00Aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001o
ogoo00Qoo`03001oogoo05Ioo`03001oogoo08aoo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04
001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Goo
00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo05Moo`03001oogoo08ao
o`003Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`800?eoo`H0
009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`1H
Ool00`00Oomoo`2;Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol0FGoo00<007ooOol0Rgoo000FOol01@00Oomoogoo00003goo00<007ooOol0
0Woo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03
001oogoo00Ioo`03001oogoo05Yoo`03001oogoo08Yoo`005Woo00D007ooOomoo`0000moo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`1KOol00`00Oomoo`2:Ool001Ioo`05001o
ogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`00
00]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20006Ool00`00Oomoo`1LOol00`00Oomoo`29
Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo0?moo`Ioo`<000eoo`<000Eoo`@000Eoo`03
001oogoo00Aoo`03001oogoo05eoo`03001oogoo08Uoo`00>7oo00<007ooOol07goo0`001Woo0P00
17oo1@0067oo0`001Woo0P001Woo0`0067oo0`001Woo0P001Goo0`006Woo0`001Woo0P001Goo0`00
8Goo1@00BGoo00<007ooOol017oo00<007ooOol067oo0`001Woo0P0017oo1@0067oo0`001Woo0P00
1Woo0`001Woo00<007ooOol03goo0`001Woo0P001Goo0`006Goo0`001Woo0P001Goo0`008Goo1@00
57oo000hOol2000OOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol0
0005Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Qo
o`05001oogooOol00005Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo0P0017oo00<0
07ooOol067oo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomoogoo00001Goo
0P001goo00<007ooOol01Goo00<007ooOol03Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogoo
Ool0000GOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo01Aoo`00
>7oo00<007ooOol07Woo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5
000GOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomo
ogoo00008Woo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol067oo00D007ooOomoo`0000eo
o`03001oogoo01Moo`05001oogooOol0000;Ool50007Ool00`00Oomoo`0=Ool01@00Oomoogoo0000
2goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0
57oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`00
00]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0
000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol00Woo00<007ooOol06Goo00D0
07ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000Oomoo`002Goo00<007oo
Ool037oo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00002goo00D007oo
Oomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000moo`03001o
ogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10006Goo00D0
07ooOomoo`0000aoo`<002=oo`03001oogoo04Uoo`05001oogooOol0000LOol01@00Oomoogoo0000
3goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0000Uoo`03001oogoo00aoo`05001o
ogooOol0000;Ool4000HOol01@00Oomoogoo000037oo0`008goo00<007ooOol057oo000hOol2000O
Ool01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05
001oogooOol0000;Ool00`00Oomoo`0JOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03
001oogoo04Uoo`80009oo`03001oogoo01Yoo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00
Oomoogoo000037oo00<007oo00002Woo00<007ooOol02goo00D007ooOomoo`0000]oo`03001oogoo
01Uoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomo
o`0NOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000=Ool2000HOol0
1@00Oomoogoo000037oo00<007ooOol06Goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol0
0`00Oomoo`19Ool01000Oomoo`007Goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00
Oomoogoo00003Goo0P002Woo00<007ooOol02goo00D007ooOomoo`0000aoo`03001oogoo01Qoo`05
001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0OOol3
000=Ool3000IOol3000?Ool00`00Oomoo`0GOol3000>Ool3000IOol3000=Ool3000QOol3001;Ool0
1000Oomoo`007Woo0`003Goo0`006Goo0`003goo00<007ooOol02Goo00<007ooOol02goo0`003Woo
0`0067oo0`003Goo0`008Goo0`005Woo000hOol00`00Oomoo`3oOolWOol00`00Ool0001YOol00`00
Oomoo`24Ool003Qoo`800?moobQoo`<006Yoo`03001oogoo08=oo`00>7oo00<007ooOol0ogoo9goo
0P00Jgoo00<007ooOol0Pgoo000hOol00`00Oomoo`3oOolWOol2001/Ool00`00Oomoo`22Ool0039o
onT0041oonT0011oo`00>7oo00<007ooOol01@000goo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00@007ooOomoo`D0009oo`03001oogoo04Uoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`8000Uoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo00<007ooOol01Goo
1`007Goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol06goo1`001goo
00<007ooOol0BGoo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol057oo00<007ooOol04Woo
00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol057oo000hOol00`00Oomoo`0<Ool7002`Ool9
001JOol00`00Oomoo`1]Ool00`00Oomoo`1XOol00`00Oomoo`0EOol003Qoo`8001Aoo`D00:Aoo`L0
06=oo`8006ioo`03001oogoo06Qoo`03001oogoo01Eoo`00>7oo00<007ooOol067oo1`00V7oo1@00
JWoo00<007ooOol0KWoo00<007ooOol0IWoo00<007ooOol05Woo000hOol00`00Oomoo`0OOol90029
Ool6001_Ool00`00Oomoo`1^Ool00`00Oomoo`1VOol00`00Oomoo`0FOol003Qoo`8002Uoo`T007Mo
o`T007Eoo`80071oo`03001oogoo06Aoo`03001oogoo01Moo`00>7oo00<007ooOol0<Goo2@00I7oo
2P00OWoo00<007ooOol0Kgoo00<007ooOol0I7oo00<007ooOol05goo000hOol00`00Oomoo`0jOol:
001AOol90028Ool00`00Oomoo`1`Ool00`00Oomoo`1ROol00`00Oomoo`0HOol003Qoo`03001oogoo
04Aoo`T003moo`T0095oo`03001oogoo071oo`03001oogoo065oo`03001oogoo01Uoo`00>7oo0P00
CWoo?`00VWoo0P00LGoo00<007ooOol0HGoo00<007ooOol06Goo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`1aOol00`00Oomoo`1OOol00`00Oomoo`0JOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo075oo`03001oogoo05moo`03001oogoo01Yoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
LWoo00<007ooOol0GGoo00<007ooOol06goo000hOol2003oOolXOol2001cOol00`00Oomoo`1MOol0
0`00Oomoo`0KOol001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Io
o`8000Aoo`D000Aoo`@000Eoo`03001oogoo07=oo`03001oogoo05]oo`03001oogoo01aoo`005Woo
00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo07=o
o`03001oogoo05]oo`03001oogoo01aoo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03
001oogoo009oo`800?moo`Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2
001eOol00`00Oomoo`1IOol00`00Oomoo`0MOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol0M7oo00<007ooOol0FGoo00<007ooOol07Goo000FOol01@00Oomoogoo
00003goo00<007ooOol00Woo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001o
ogoo009oo`@000Eoo`03001oogoo07Eoo`03001oogoo05Moo`03001oogoo01ioo`005Woo00D007oo
Oomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0
000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`1fOol00`00Oomoo`1FOol00`00Oomo
o`0NOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo
1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001gOol00`00Oomo
o`1EOol00`00Oomoo`0OOol001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo0?moo`Ioo`<000eo
o`<000Eoo`@000Eoo`03001oogoo07Moo`03001oogoo05=oo`03001oogoo021oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0Mgoo00<007ooOol0Dgoo00<007ooOol087oo000hOol2003oOolXOol2
001iOol00`00Oomoo`1AOol00`00Oomoo`0QOol003Qoo`03001oogoo0?moobMoo`03001oogoo07Uo
o`03001oogoo051oo`03001oogoo025oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0NGoo00<0
07ooOol0Cgoo00<007ooOol08Woo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1jOol00`00Oomo
o`1>Ool00`00Oomoo`0ROol003Qoo`800?moobQoo`8007aoo`03001oogoo04aoo`03001oogoo02=o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Ngoo00<007ooOol0C7oo00<007ooOol08goo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`1lOol00`00Oomoo`1:Ool00`00Oomoo`0TOol003Qoo`80
0?moobQoo`8007eoo`03001oogoo04Uoo`03001oogoo02Eoo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0OGoo00<007ooOol0B7oo00<007ooOol09Goo000OOol30006Ool20005Ool40005Ool00`00
Oomoo`3oOol>Ool30006Ool20005Ool40005Ool00`00Oomoo`1nOol00`00Oomoo`16Ool00`00Oomo
o`0VOol001ioo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool0
1@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0OWoo00<007ooOol0AWoo00<0
07ooOol09Woo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00ogoo3Woo00D007ooOomo
o`00011oo`03001oogoo009oo`80081oo`03001oogoo04Aoo`03001oogoo02Moo`007Woo00D007oo
Oomoo`00011oo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool00`00Oomo
o`02Ool00`00Oomoo`20Ool00`00Oomoo`12Ool00`00Oomoo`0XOol001ioo`05001oogooOol0000<
Ool40005Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0P7oo00<0
07ooOol0@Woo00<007ooOol0:7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007oo
Ool0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo085oo`03001oogoo041o
o`03001oogoo02Uoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?moo`ioo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool20023Ool00`00Oomoo`0nOol00`00Oomoo`0ZOol001moo`<0
00eoo`@000Eoo`03001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo089oo`03001oogoo03io
o`03001oogoo02Yoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Pgoo00<007ooOol0?7oo00<0
07ooOol0:goo000hOol2003oOolXOol20024Ool00`00Oomoo`0kOol00`00Oomoo`0/Ool003Qoo`03
001oogoo0?moobMoo`03001oogoo08Aoo`03001oogoo03Yoo`03001oogoo02aoo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0QGoo00<007ooOol0>7oo00<007ooOol0;Goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`25Ool00`00Oomoo`0gOol00`00Oomoo`0^Ool003Qoo`800?moobQoo`8008Mo
o`03001oogoo03Ioo`03001oogoo02ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Qgoo00<0
07ooOol0=7oo00<007ooOol0;goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`27Ool00`00Oomo
o`0cOol00`00Oomoo`0`Ool003Qoo`800?moobQoo`8008Uoo`03001oogoo039oo`03001oogoo031o
o`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P00
1Woo00<007ooOol017oo10001Goo00<007ooOol0RGoo00<007ooOol0<7oo00<007ooOol0<Goo000F
Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo08Uo
o`03001oogoo02moo`03001oogoo039oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`2:Ool00`00Oomoo`0]Ool00`00Oomoo`0cOol001Ioo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo0P00S7oo00<007ooOol0:goo00<007ooOol0=7oo000FOol01@00Oomoogoo
00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001o
ogoo00=oo`@000Eoo`03001oogoo08aoo`03001oogoo02Yoo`03001oogoo03Aoo`005Woo00D007oo
Oomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0
000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`2=Ool00`00Oomoo`0XOol00`00Oomo
o`0eOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007oo
Ool0ogoo1Goo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomo
o`2>Ool00`00Oomoo`0VOol00`00Oomoo`0fOol001Moo`<000aoo`D000Aoo`@000Eoo`800?moo`Mo
o`<000aoo`D000Aoo`@000Eoo`80091oo`03001oogoo02Aoo`03001oogoo03Moo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0T7oo0P008Woo0P00>Woo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`2BOol00`00Oomoo`0NOol00`00Oomoo`0jOol003Qoo`800?moobQoo`8009Aoo`03001oogoo01ao
o`03001oogoo03]oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0U7oo00<007ooOol06Woo00<0
07ooOol0?7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2EOol2000IOol00`00Oomoo`0mOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo09Moo`03001oogoo01Eoo`03001oogoo03ioo`00>7oo
0P00ogoo:7oo0P00VGoo00<007ooOol04Woo0P00@Goo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`2IOol3000>Ool30013Ool003Qoo`03001oogoo0?moobMoo`03001oogoo09aoo`8000]oo`03001o
ogoo04Aoo`00>7oo0P00ogoo:7oo0P00Wgoo2`00Agoo000_Ool50004Ool00`00Oomoo`3oOolNOol5
0004Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Ao
o`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<0
07ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03
001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000a
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo
003oOoooOomFOol009Eoo`<00004Ool00000000HOol5003oOol5Ool3000017oo000000005goo1@00
M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uo
o`H000Yoo`04001oogoo001dOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00
Oomoogoo00006Woo00<007ooOol0M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0
ogoo1Woo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001]o
o`03001oogoo0?moo`Ioo`05001oogooOol0000LOol00`00Oomoo`1bOol009Eoo`D001aoo`03001o
ogoo0?moo`Eoo`D001eoo`03001oogoo079oo`00]Woo00<007ooOol0ogoo8goo00D007ooOomoo`00
07Aoo`00]7oo0`00ogoo9Woo0`00MGoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .21575 L
.08255 .17173 L
.10458 .1298 L
.12507 .09837 L
.14415 .07684 L
.14918 .07251 L
.15465 .06848 L
.15946 .06551 L
.16457 .06296 L
.16917 .0612 L
.17178 .06043 L
.17423 .05986 L
.17538 .05964 L
.17647 .05947 L
.17746 .05933 L
.17852 .05921 L
.17967 .05912 L
.18073 .05906 L
.182 .05902 L
.18314 .05902 L
.18435 .05906 L
.18547 .05912 L
.1867 .05923 L
.18802 .05938 L
.19071 .05983 L
.19317 .0604 L
.1979 .0619 L
.20239 .06383 L
.21236 .06983 L
.22321 .07899 L
.24299 .10243 L
.26399 .13593 L
.30174 .2137 L
.34195 .31069 L
.38063 .40396 L
.40028 .44686 L
.42177 .48778 L
.44253 .51967 L
.4614 .541 L
.47149 .54913 L
.47611 .55206 L
.48101 .55462 L
.4835 .55569 L
.48624 .5567 L
.48876 .55747 L
.49106 .55804 L
.49378 .55854 L
.49527 .55874 L
.49596 .55882 L
Mistroke
.49669 .55888 L
.498 .55897 L
.49921 .55901 L
.49996 .55902 L
.50065 .55901 L
.50196 .55897 L
.50313 .5589 L
.50438 .55878 L
.50556 .55864 L
.50663 .55848 L
.50926 .55797 L
.51175 .55733 L
.5167 .55561 L
.52208 .55307 L
.53169 .54683 L
.54056 .53915 L
.55926 .51724 L
.57988 .48489 L
.62014 .40219 L
.65888 .30866 L
.70007 .20958 L
.72063 .16527 L
.73974 .12938 L
.75939 .09918 L
.77791 .07793 L
.78775 .06975 L
.79293 .06635 L
.7984 .06345 L
.80302 .06157 L
.80546 .06078 L
.80809 .06009 L
.8105 .05961 L
.8127 .05929 L
.81375 .05919 L
.81491 .0591 L
.81599 .05904 L
.817 .05902 L
.81818 .05902 L
.81941 .05906 L
.82047 .05913 L
.82163 .05923 L
.82287 .05938 L
.82421 .05957 L
.82661 .06004 L
.82905 .06066 L
.83134 .06137 L
.83564 .06305 L
.84078 .06564 L
.84552 .06859 L
.85624 .0772 L
Mistroke
.87498 .09843 L
.89561 .13012 L
.93591 .21199 L
.97471 .30535 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35562 L
.08255 .37584 L
.0932 .38473 L
.10458 .39259 L
.11009 .39572 L
.11531 .39827 L
.12038 .40034 L
.12507 .40189 L
.12951 .40303 L
.13178 .40349 L
.13422 .40389 L
.13549 .40406 L
.13666 .40419 L
.13784 .4043 L
.13895 .40438 L
.14022 .40445 L
.1409 .40448 L
.14161 .4045 L
.1423 .40451 L
.14295 .40451 L
.14415 .40449 L
.14531 .40446 L
.14656 .40439 L
.14773 .40431 L
.14881 .40421 L
.15143 .4039 L
.15392 .40349 L
.15886 .40239 L
.16423 .40074 L
.17383 .39665 L
.1827 .39161 L
.20137 .37744 L
.22197 .35704 L
.26217 .30868 L
.30086 .26207 L
.32051 .24232 L
.3309 .23361 L
.342 .22586 L
.35275 .22006 L
.35784 .21793 L
.36253 .21633 L
.36724 .21508 L
.36972 .21457 L
.37235 .21414 L
.37463 .21386 L
.37573 .21375 L
.37677 .21367 L
.37799 .2136 L
.37911 .21355 L
Mistroke
.38031 .21353 L
.38162 .21353 L
.38227 .21354 L
.38296 .21356 L
.38419 .21361 L
.38551 .2137 L
.38695 .21382 L
.38955 .21414 L
.39197 .21453 L
.39649 .21553 L
.40134 .21696 L
.40698 .2191 L
.41232 .22159 L
.42232 .2274 L
.44227 .24311 L
.4607 .26169 L
.50002 .30904 L
.53782 .35472 L
.55884 .37593 L
.56803 .38368 L
.57808 .39089 L
.58722 .39621 L
.59696 .40048 L
.60236 .4022 L
.60726 .40336 L
.60962 .40377 L
.61086 .40395 L
.61218 .40412 L
.61333 .40424 L
.61459 .40434 L
.61574 .40442 L
.61682 .40447 L
.61808 .4045 L
.61871 .40451 L
.61941 .40451 L
.62065 .40449 L
.62181 .40444 L
.62248 .40441 L
.62318 .40437 L
.62443 .40427 L
.62578 .40413 L
.62725 .40395 L
.62973 .40356 L
.63238 .40304 L
.63715 .4018 L
.64214 .40011 L
.64686 .39815 L
.6557 .39356 L
.67568 .37906 L
.69413 .36136 L
Mistroke
.7335 .3148 L
.77136 .26844 L
.79241 .24629 L
.81166 .23021 L
.82118 .22408 L
.8262 .22137 L
.83155 .21892 L
.8367 .21698 L
.84136 .21559 L
.84361 .21504 L
.84604 .21455 L
.84835 .21417 L
.85045 .2139 L
.85159 .21378 L
.85283 .21368 L
.85414 .2136 L
.85538 .21355 L
.85653 .21353 L
.85776 .21353 L
.85881 .21355 L
.85997 .21359 L
.86063 .21363 L
.86132 .21367 L
.86256 .21377 L
.86535 .21409 L
.86777 .21446 L
.87041 .21498 L
.87569 .21637 L
.88133 .21835 L
.89148 .22316 L
.90173 .22958 L
.91284 .23817 L
.933 .25749 L
.97393 .30617 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32115 L
.10458 .33416 L
.14415 .34594 L
.18221 .35667 L
.22272 .36727 L
.26171 .3765 L
.30316 .38508 L
.34309 .392 L
.3815 .39731 L
.40095 .39946 L
.42237 .40139 L
.44268 .40281 L
.45178 .4033 L
.46172 .40375 L
.4671 .40395 L
.4721 .4041 L
.47727 .40424 L
.48196 .40434 L
.48658 .40441 L
.4887 .40444 L
.49093 .40447 L
.49332 .40449 L
.49438 .40449 L
.49552 .4045 L
.49675 .4045 L
.49789 .40451 L
.49859 .40451 L
.49925 .40451 L
.50049 .40451 L
.50163 .40451 L
.50286 .4045 L
.50401 .4045 L
.50508 .4045 L
.50754 .40448 L
.51014 .40446 L
.51268 .40442 L
.51504 .40439 L
.5204 .40429 L
.5293 .40406 L
.53882 .40373 L
.54906 .40326 L
.56016 .40263 L
.58032 .40118 L
.62123 .39697 L
.66064 .39141 L
.69852 .38475 L
.73886 .37637 L
.77769 .36717 L
.81897 .35635 L
Mistroke
.85873 .3451 L
.89697 .33369 L
.93767 .32112 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .24598 L
.10458 .18202 L
.14415 .13074 L
.18221 .09278 L
.20178 .07843 L
.21267 .07209 L
.22272 .06733 L
.23293 .06357 L
.23832 .06204 L
.24402 .06075 L
.24641 .06032 L
.24897 .05993 L
.25119 .05964 L
.25361 .05939 L
.25507 .05927 L
.25643 .05918 L
.25773 .05911 L
.2584 .05908 L
.25912 .05906 L
.25983 .05904 L
.26048 .05903 L
.26176 .05902 L
.26293 .05902 L
.26416 .05904 L
.26538 .05908 L
.26607 .05911 L
.26671 .05914 L
.26912 .0593 L
.27131 .0595 L
.27364 .05977 L
.27847 .06051 L
.2838 .06162 L
.29326 .06435 L
.30213 .06777 L
.32232 .07861 L
.34082 .09214 L
.38045 .13165 L
.41855 .18106 L
.45912 .2424 L
.49816 .30598 L
.53966 .37368 L
.57964 .43441 L
.61811 .48469 L
.63759 .50605 L
.65902 .52577 L
.67938 .5405 L
.69843 .5505 L
.70884 .55437 L
.71396 .55585 L
Mistroke
.71872 .55698 L
.72301 .55778 L
.72758 .55842 L
.7302 .55868 L
.73148 .55878 L
.73266 .55886 L
.73371 .55891 L
.73487 .55896 L
.73603 .55899 L
.73725 .55901 L
.73856 .55902 L
.73977 .559 L
.7404 .55899 L
.7411 .55897 L
.74251 .55891 L
.74375 .55884 L
.74508 .55875 L
.74748 .55854 L
.74985 .55827 L
.75235 .55791 L
.7568 .55712 L
.76198 .55592 L
.7668 .55455 L
.77773 .55052 L
.78828 .54544 L
.79823 .5396 L
.81683 .52604 L
.85534 .48788 L
.89632 .43474 L
.93577 .3749 L
.97371 .31311 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`0OOol6002<Ool8001]Ool00`00Oomoo`3`Ool003Qoo`8001eoo`<000Ioo`@008Moo`03
001oogoo00Ioo`8006]oo`800?5oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<0
07ooOol06goo00<007ooOol02goo00<007ooOol0PWoo0P002goo0P00B7oo0`001Woo0P001Woo00<0
07ooOol017oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol06Woo00<007ooOol03Goo00<007ooOol0P7oo00<007oo
Ool03Goo00<007ooOol0A7oo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001o
ogoo009oo`8001Yoo`03001oogoo00moo`03001oogoo07ioo`03001oogoo00moo`03001oogoo03]o
o`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05
001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`0@
Ool00`00Oomoo`1mOol00`00Oomoo`0@Ool00`00Oomoo`13Ool01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol0
0goo10001Goo00<007ooOol05goo00<007ooOol04Woo00<007ooOol0Ngoo00<007ooOol04Woo00<0
07ooOol0@Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo
00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01Ioo`03001oogoo
01Aoo`03001oogoo07Uoo`03001oogoo01Aoo`03001oogoo045oo`05001oogooOol0000?Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomo
ogoo000017oo00<007ooOol01Woo0P005Woo00<007ooOol05Woo00<007ooOol0Mgoo00<007ooOol0
5Woo00<007ooOol0@7oo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2
003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo01Aoo`03001oogoo01Qoo`03001oogoo
07Eoo`03001oogoo01Qoo`03001oogoo041oo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00
>7oo00<007ooOol057oo00<007ooOol06Goo00<007ooOol0M7oo00<007ooOol067oo00<007ooOol0
HGoo00<007ooOol0l7oo000hOol2000DOol00`00Oomoo`0JOol00`00Oomoo`1cOol00`00Oomoo`0J
Ool00`00Oomoo`1POol2003aOol003Qoo`03001oogoo01=oo`03001oogoo01]oo`03001oogoo079o
o`03001oogoo01]oo`03001oogoo05moo`03001oogoo0?1oo`00>7oo00<007ooOol04Woo00<007oo
Ool07Goo00<007ooOol0L7oo00<007ooOol07Goo00<007ooOol0GWoo00<007ooOol0l7oo000hOol0
0`00Oomoo`0AOol00`00Oomoo`0NOol00`00Oomoo`1_Ool00`00Oomoo`0NOol00`00Oomoo`1NOol0
0`00Oomoo`3`Ool003Qoo`80019oo`03001oogoo01moo`03001oogoo06ioo`03001oogoo01moo`03
001oogoo05eoo`800?5oo`00>7oo00<007ooOol047oo00<007ooOol087oo00<007ooOol0KGoo00<0
07ooOol08Goo00<007ooOol0G7oo00<007ooOol0l7oo000hOol00`00Oomoo`0@Ool00`00Oomoo`0Q
Ool00`00Oomoo`1/Ool00`00Oomoo`0QOol00`00Oomoo`1LOol00`00Oomoo`3`Ool003Qoo`80011o
o`03001oogoo02=oo`03001oogoo06Yoo`03001oogoo02=oo`03001oogoo05]oo`800?5oo`007goo
0`001Woo0P001Goo10001Goo00<007ooOol03goo00<007ooOol08goo00<007ooOol0JGoo00<007oo
Ool097oo00<007ooOol0@Woo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00Oomo
ogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol09Goo00<007ooOol0
J7oo00<007ooOol09Goo00<007ooOol0@7oo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009o
o`03001oogoo0?1oo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo
00ioo`03001oogoo02Eoo`03001oogoo06Moo`03001oogoo02Ioo`03001oogoo03Qoo`H0009oo`05
001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool0
0`00Oomoo`02Ool2000>Ool00`00Oomoo`0WOol00`00Oomoo`1VOol00`00Oomoo`0WOol00`00Oomo
o`0oOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomoogoo000037oo
10001Goo00<007ooOol03Goo00<007ooOol09goo00<007ooOol0IGoo00<007ooOol0:7oo00<007oo
Ool0?goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000ao
o`03001oogoo00Ioo`03001oogoo00aoo`03001oogoo02Qoo`03001oogoo06Aoo`03001oogoo02Yo
o`03001oogoo03ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05
001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`0YOol00`00Oomoo`1S
Ool00`00Oomoo`0ZOol00`00Oomoo`0nOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007oo
Ool0l7oo000OOol3000=Ool40005Ool2000<Ool00`00Oomoo`0ZOol00`00Oomoo`1ROol00`00Oomo
o`0/Ool00`00Oomoo`0nOol3000=Ool40005Ool2003aOol003Qoo`03001oogoo00]oo`03001oogoo
02]oo`03001oogoo065oo`03001oogoo02aoo`03001oogoo05Moo`03001oogoo0?1oo`00>7oo00<0
07ooOol02Woo00<007ooOol0;7oo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0Egoo00<0
07ooOol0l7oo000hOol2000;Ool00`00Oomoo`0]Ool00`00Oomoo`1OOol00`00Oomoo`0^Ool00`00
Oomoo`1FOol2003aOol003Qoo`03001oogoo00Uoo`03001oogoo02ioo`03001oogoo05moo`03001o
ogoo02ioo`03001oogoo05Ioo`03001oogoo0?1oo`00>7oo00<007ooOol02Goo00<007ooOol0;goo
00<007ooOol0GWoo00<007ooOol0;goo00<007ooOol0EGoo00<007ooOol0l7oo000hOol00`00Oomo
o`08Ool00`00Oomoo`0`Ool00`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomoo`1EOol00`00Oomo
o`3`Ool003Qoo`8000Uoo`03001oogoo031oo`03001oogoo05eoo`03001oogoo035oo`03001oogoo
05Aoo`800?5oo`00>7oo00<007ooOol01goo00<007ooOol0<Woo00<007ooOol0G7oo00<007ooOol0
<Goo00<007ooOol0E7oo00<007ooOol0l7oo000hOol00`00Oomoo`07Ool00`00Oomoo`0bOol00`00
Oomoo`1KOol00`00Oomoo`0cOol00`00Oomoo`1COol00`00Oomoo`3`Ool003Qoo`8000Moo`03001o
ogoo03Aoo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo05=oo`8004aoo`/006=oo`/002ao
o`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol01Woo00<007ooOol0=7oo00<007oo
Ool0FGoo00<007ooOol0=Goo00<007ooOol0<Goo0`001Woo0P0017oo1@0017oo10001Goo00<007oo
Ool0BGoo0P002goo00<007ooOol0GWoo0P002goo0P00:Woo000FOol01@00Oomoogoo00001Goo0P00
1Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo03Ioo`03001oogoo
05Qoo`03001oogoo03Eoo`03001oogoo031oo`05001oogooOol00005Ool20005Ool01000Oomoo`00
27oo00<007ooOol00Woo00<007ooOol0B7oo00<007ooOol037oo0P00G7oo0P003goo0P00:7oo000>
Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol01Goo
00<007ooOol0=Woo00<007ooOol0Egoo00<007ooOol0=Woo00<007ooOol0:7oo1P000Woo00D007oo
Oomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04Ioo`80015oo`8005Uoo`03
001oogoo015oo`8002Ioo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`8000Ioo`03001oogoo03Moo`03001oogoo05Ioo`03001oogoo03Moo`03001oogoo02moo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20015Ool2000EOol00`00Oomoo`1DOol2
000FOol00`00Oomoo`0SOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00
Oomoo`04Ool00`00Oomoo`0hOol00`00Oomoo`1FOol00`00Oomoo`0gOol00`00Oomoo`0_Ool01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0@goo00<007ooOol05Woo00<007oo
Ool0DWoo00<007ooOol05goo00<007ooOol08Woo000FOol01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0>Goo00<007ooOol0E7oo00<007ooOol0
>Goo00<007ooOol0;Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo049oo`03001oogoo01Qoo`03001oogoo051oo`03001oogoo01Qoo`03001oogoo029oo`005Woo
00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20004Ool00`00Oomoo`0j
Ool00`00Oomoo`1DOol00`00Oomoo`0iOol00`00Oomoo`0^Ool01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`80049oo`03001oogoo01Yoo`03001oogoo04ioo`03001oogoo
01Yoo`03001oogoo025oo`005goo0`003Goo0`001Goo10001Goo00<007ooOol00goo00<007ooOol0
>Woo00<007ooOol0Dgoo00<007ooOol0>Woo00<007ooOol0;goo0`003Goo0`001Goo10001Goo00<0
07ooOol0@7oo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol087oo000h
Ool00`00Oomoo`03Ool00`00Oomoo`0kOol00`00Oomoo`1BOol00`00Oomoo`0kOol00`00Oomoo`1?
Ool00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`0O
Ool003Qoo`03001oogoo009oo`03001oogoo01Yoo`<000Ioo`8000Aoo`D000ioo`03001oogoo00Mo
o`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<000]oo`03001oogoo00aoo`<000Ioo`8000Eo
o`<001eoo`04001oogooOol50019Ool00`00Oomoo`0OOol30006Ool20004Ool5000;Ool00`00Oomo
o`0:Ool30006Ool20006Ool30002Ool00`00Oomoo`0COol30006Ool20005Ool3000IOol30006Ool2
0005Ool3000IOol00`00Oomoo`05Ool5000DOol003Qoo`8000=oo`03001oogoo01Uoo`05001oogoo
Ool00005Ool20005Ool01000Oomoo`003goo00<007ooOol01Goo00D007ooOomoo`0000Eoo`8000Mo
o`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00002Woo00<007ooOol0
2goo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000MOol00`00Oomoo`02Ool00`00Oomo
o`19Ool2000OOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Yoo`03001oogoo00Yoo`05
001oogooOol00005Ool20007Ool00`00Oomoo`02Ool00`00Oomoo`0AOol01@00Oomoogoo00001Goo
0P0017oo00D007ooOomoo`0001Moo`05001oogooOol00004Ool30004Ool01@00Oomoogoo000067oo
00<007ooOol01goo00<007ooOol057oo000hOol01@00Oomoogoo000077oo00D007ooOomoo`0000eo
o`03001oogoo00moo`03001oogoo00Eoo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo0000
2goo00D007ooOomoo`0000Yoo`03001oogoo00]oo`05001oogooOol0000;Ool01@00Oomoogoo0000
7Goo00<007ooOol00Woo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000eoo`03001o
ogoo00Yoo`03001oogoo00Yoo`05001oogooOol0000;Ool50003Ool00`00Oomoo`0AOol01@00Oomo
ogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol00003Ool00`00Oomoo`05Ool01@00Oomo
ogoo00006Goo00<007ooOol01Woo00<007ooOol057oo000hOol01@00Oomoogoo000077oo00D007oo
Oomoo`0000ioo`03001oogoo00moo`03001oogoo00Aoo`05001oogooOol0000;Ool01000Oomoo`00
67oo00D007ooOomoo`0000]oo`05001oogooOol00009Ool00`00Oomoo`0<Ool01@00Oomoogoo0000
2goo00D007ooOomoo`0001ioo`05001oogooOol0001;Ool00`00Oomoo`0NOol01@00Oomoogoo0000
3Woo00<007ooOol027oo00<007ooOol02goo00D007ooOomoo`0000]oo`04001oogoo0005Ool00`00
Oomoo`0@Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol00003Ool00`00
Oomoo`05Ool01@00Oomoogoo00006Woo00<007ooOol01Goo00<007ooOol057oo000hOol01000Oomo
o`007Goo00D007ooOomoo`0000moo`03001oogoo00ioo`03001oogoo00Aoo`05001oogooOol0000<
Ool00`00Ool0000HOol01@00Oomoogoo00002goo10002Woo00<007ooOol037oo00D007ooOomoo`00
00aoo`<001moo`05001oogooOol0001;Ool00`00Oomoo`0NOol01@00Oomoogoo00003goo00<007oo
Ool01Woo00<007ooOol037oo00D007ooOomoo`0000aoo`03001oo`0000Ioo`03001oogoo00moo`05
001oogooOol0000;Ool4000HOol01@00Oomoogoo00000Woo00<007ooOol01goo0`0077oo00<007oo
Ool017oo00<007ooOol057oo000hOol200000goo001oo`0LOol01@00Oomoogoo00003goo00<007oo
Ool03goo00<007ooOol00goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;
Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool01@00Oomoogoo00002goo00D007ooOomoo`0001ioo`05
001oogooOol0001;Ool2000OOol01@00Oomoogoo00003goo00<007ooOol01Goo00<007ooOol03Goo
00D007ooOomoo`0000aoo`03001oo`0000Moo`03001oogoo00ioo`05001oogooOol0000;Ool00`00
Oomoo`0IOol01`00Oomoogoo001oo`0000Uoo`05001oogooOol0000LOol00`00Oomoo`03Ool00`00
Oomoo`0DOol003Qoo`04001oogoo000MOol01@00Oomoogoo00002goo00D007ooOomoo`00015oo`03
001oogoo00=oo`05001oogooOol0000=Ool2000HOol01@00Oomoogoo000037oo00<007ooOol02Goo
00<007ooOol03Goo00D007ooOomoo`0000]oo`05001oogooOol0000OOol01000Oomoo`00Bgoo00<0
07ooOol07Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool00`00Oomoo`0>Ool01@00Oomo
ogoo00003Goo0P0027oo00<007ooOol03Goo00D007ooOomoo`0000aoo`03001oogoo01Qoo`04001o
ogooOol2000:Ool01@00Oomoogoo00007Goo00<007ooOol00Woo00<007ooOol057oo000hOol00`00
Ool0000OOol3000=Ool3000COol00`00Oomoo`03Ool3000?Ool00`00Oomoo`0GOol3000>Ool30007
Ool00`00Oomoo`0?Ool3000=Ool3000POol4001;Ool00`00Oomoo`0OOol3000=Ool30006Ool00`00
Oomoo`0@Ool3000?Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool3000>Ool3000HOol4000<Ool3000O
Ool00`00Ool00002000FOol003Qoo`<004Eoo`03001oogoo04Yoo`03001oogoo04=oo`03001oogoo
04]oo`8003Uoo`03001oogoo02aoo`03001oogoo03]oo`03001oogoo02ioo`03001oogoo01Moo`00
>7oo0P00AWoo00<007ooOol0BWoo00<007ooOol0@goo00<007ooOol0Bgoo00<007ooOol0=goo00<0
07ooOol0;Woo00<007ooOol0>Woo00<007ooOol0;goo00<007ooOol05Woo000hOol20017Ool00`00
Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`1;Ool00`00Oomoo`0fOol00`00Oomoo`0`Ool00`00
Oomoo`0hOol00`00Oomoo`0aOol00`00Oomoo`0EOol003Qoo`8004Moo`03001oogoo04Qoo`03001o
ogoo04Eoo`03001oogoo04Yoo`03001oogoo03Eoo`03001oogoo039oo`03001oogoo03Ioo`03001o
ogoo03=oo`03001oogoo01Aoo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`05Ool01000Oomoo`002Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00D007ooOomoo`0000Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo04Uoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`80
00Yoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
01Aoo`00>7oo00<007ooOol0B7oo00<007ooOol0A7oo00<007ooOol0U7oo0P00=7oo00<007ooOol0
=Woo00<007ooOol0<Woo00<007ooOol0C7oo000hOol20019Ool00`00Oomoo`14Ool00`00Oomoo`2D
Ool3000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`1=Ool003Qoo`03001oogoo04Qo
o`03001oogoo04=oo`03001oogoo09Eoo`04001oogoo000`Ool00`00Oomoo`0jOol00`00Oomoo`0^
Ool00`00Oomoo`1>Ool003Qoo`03001oogoo04Uoo`03001oogoo049oo`03001oogoo09Eoo`05001o
ogooOol0000^Ool00`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`1?Ool003Qoo`03001oogoo
04Uoo`03001oogoo049oo`03001oogoo09Eoo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo
03ioo`03001oogoo02Yoo`03001oogoo051oo`00>7oo0P00Bgoo00<007ooOol0@7oo00<007ooOol0
UWoo0P000goo00<007ooOol0:Woo00<007ooOol0?goo00<007ooOol0:7oo00<007ooOol0DGoo000h
Ool00`00Oomoo`1:Ool00`00Oomoo`10Ool00`00Oomoo`2FOol00`00Oomoo`03Ool00`00Oomoo`0X
Ool00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`1AOol003Qoo`03001oogoo04Yoo`03001o
ogoo03moo`03001oogoo09Moo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo04=oo`03001o
ogoo02Eoo`03001oogoo059oo`00>7oo00<007ooOol0Bgoo00<007ooOol0?Woo00<007ooOol0Ugoo
00<007ooOol01Goo00<007ooOol097oo00<007ooOol0AGoo00<007ooOol08goo00<007ooOol0Dgoo
000hOol2001<Ool00`00Oomoo`0mOol00`00Oomoo`2HOol20007Ool00`00Oomoo`0ROol00`00Oomo
o`17Ool00`00Oomoo`0QOol00`00Oomoo`1DOol003Qoo`03001oogoo04aoo`03001oogoo03aoo`03
001oogoo09Qoo`03001oogoo00Moo`03001oogoo021oo`03001oogoo04Uoo`03001oogoo01moo`03
001oogoo05Eoo`00>7oo00<007ooOol0C7oo00<007ooOol0?7oo00<007ooOol0V7oo00<007ooOol0
27oo00<007ooOol07Woo00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol0EWoo000hOol2001>
Ool00`00Oomoo`0jOol00`00Oomoo`2IOol2000:Ool00`00Oomoo`0LOol00`00Oomoo`1=Ool00`00
Oomoo`0KOol00`00Oomoo`1GOol001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo04eo
o`03001oogoo03Yoo`03001oogoo07Qoo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Yo
o`8001]oo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo05Qoo`005Woo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool00`00Oomoo`0iOol0
0`00Oomoo`1hOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03
001oogoo00aoo`03001oogoo01Ioo`8005=oo`03001oogoo01Ioo`8005]oo`005Woo00D007ooOomo
o`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04ioo`03001oogoo03Qoo`03001o
ogoo07Qoo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool0
0`00Oomoo`0DOol00`00Oomoo`1DOol00`00Oomoo`0COol2001MOol001Ioo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2001?Ool00`00Oomoo`0gOol00`00Oomoo`1iOol01@00
Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P003goo00<007ooOol04Woo00<007oo
Ool0EWoo00<007ooOol04Goo00<007ooOol0GGoo000FOol01@00Oomoogoo00003goo00<007ooOol0
0Woo10001Goo00<007ooOol0Cgoo00<007ooOol0=Woo00<007ooOol0NGoo00D007ooOomoo`0000mo
o`03001oogoo009oo`@000Eoo`03001oogoo00moo`80011oo`8005Yoo`8000moo`80061oo`005Woo
00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo04moo`03001oogoo
03Ioo`03001oogoo07Uoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`0AOol2000<Ool2001NOol3000;Ool00`00Oomoo`1POol001Ioo`05001oogooOol0000;Ool0
1@00Oomoogoo000017oo00<007ooOol01Woo0P00D7oo00<007ooOol0=Goo00<007ooOol0NWoo00D0
07ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000DOol20007Ool3001SOol2
0007Ool2001SOol001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo051oo`03001oogoo03Aoo`03
001oogoo07]oo`<000eoo`<000Eoo`@000Eoo`03001oogoo01Eoo`L006Qoo`L006Eoo`00>7oo00<0
07ooOol0D7oo00<007ooOol0<goo00<007ooOol0WGoo00<007ooOol0l7oo000hOol00`00Oomoo`1A
Ool00`00Oomoo`0bOol00`00Oomoo`2MOol00`00Oomoo`3`Ool003Qoo`80059oo`03001oogoo035o
o`03001oogoo09ioo`800?5oo`00>7oo00<007ooOol0DGoo00<007ooOol0<Goo00<007ooOol0WWoo
00<007ooOol0l7oo000hOol00`00Oomoo`1BOol00`00Oomoo`0`Ool00`00Oomoo`2NOol00`00Oomo
o`3`Ool003Qoo`8005=oo`03001oogoo02moo`03001oogoo09moo`800?5oo`00>7oo00<007ooOol0
Dgoo00<007ooOol0;Woo00<007ooOol0Wgoo00<007ooOol0l7oo000hOol00`00Oomoo`1COol00`00
Oomoo`0]Ool00`00Oomoo`2POol00`00Oomoo`3`Ool003Qoo`03001oogoo05=oo`03001oogoo02eo
o`03001oogoo0:1oo`03001oogoo0?1oo`00>7oo0P00EGoo00<007ooOol0:goo00<007ooOol0XGoo
0P00lGoo000OOol30006Ool20005Ool40005Ool00`00Oomoo`1DOol00`00Oomoo`0[Ool00`00Oomo
o`28Ool30006Ool20005Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol00005Ool20009
Ool00`00Oomoo`02Ool00`00Oomoo`1EOol00`00Oomoo`0YOol00`00Oomoo`28Ool01@00Oomoogoo
00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000047oo00<0
07ooOol00Woo00<007ooOol0EGoo00<007ooOol0:Goo00<007ooOol0R7oo00D007ooOomoo`00011o
o`03001oogoo009oo`03001oogoo0?1oo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`80
05Moo`03001oogoo02Moo`03001oogoo08Uoo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003a
Ool001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`1GOol00`00Oomoo`0VOol00`00Oomo
o`29Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo
00<007ooOol01Woo00<007ooOol0Egoo00<007ooOol09Woo00<007ooOol0RGoo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Io
o`8005Uoo`03001oogoo02Aoo`03001oogoo08Yoo`05001oogooOol0000<Ool00`00Oomoo`06Ool2
003aOol001moo`<000eoo`@000Eoo`03001oogoo05Qoo`03001oogoo02Aoo`03001oogoo08]oo`<0
00eoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0FGoo00<007ooOol08Woo00<007ooOol0
YGoo00<007ooOol0l7oo000hOol00`00Oomoo`1IOol00`00Oomoo`0ROol00`00Oomoo`2UOol00`00
Oomoo`3`Ool003Qoo`8005]oo`03001oogoo021oo`03001oogoo0:Ioo`800?5oo`00>7oo00<007oo
Ool0Fgoo00<007ooOol07Woo00<007ooOol0Ygoo00<007ooOol0l7oo000hOol00`00Oomoo`1KOol0
0`00Oomoo`0MOol00`00Oomoo`2XOol00`00Oomoo`3`Ool003Qoo`8005eoo`03001oogoo01aoo`03
001oogoo0:Qoo`800?5oo`00>7oo00<007ooOol0G7oo00<007ooOol06goo00<007ooOol0ZGoo00<0
07ooOol0l7oo000hOol00`00Oomoo`1MOol00`00Oomoo`0IOol00`00Oomoo`2ZOol00`00Oomoo`3`
Ool003Qoo`03001oogoo05ioo`03001oogoo01Qoo`03001oogoo0:Yoo`03001oogoo0?1oo`00>7oo
0P00Ggoo00<007ooOol05goo00<007ooOol0Zgoo0P00lGoo000GOol30006Ool20006Ool00`00Oomo
o`04Ool40005Ool00`00Oomoo`1OOol00`00Oomoo`0EOol00`00Oomoo`2;Ool30006Ool20006Ool0
0`00Oomoo`04Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol00005Ool20006Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`1POol00`00Oomoo`0COol00`00Oomoo`2;Ool01@00
Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0l7oo000FOol0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0HGoo00<007ooOol0
4Goo00<007ooOol0S7oo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo0?1oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8006=oo`<0
00moo`03001oogoo08eoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003a
Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`1UOol00`00Oomo
o`0:Ool2002@Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0l7oo000F
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0IWoo00<007oo
Ool01goo0P00TWoo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
0?1oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001XOol3
0003Ool3002DOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?5o
o`005goo0`0037oo1@0017oo10001Goo00<007ooOol0JGoo1@00Ugoo0`0037oo1@0017oo10001Goo
00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?mo
obMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol002mo
o`D000Aoo`03001oogoo0?mooaioo`D000Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<0
07ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQ
Ool00`00Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<0
07ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035o
o`03001oogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00nGoo003oOoooOomFOol0
0?mooomooeIoo`00UGoo0`0000Aoo`00000001Qoo`<00?moo`Moo`<00004Ool00000000IOol3001d
Ool009Ioo`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000ogoo1goo00D007ooOomoo`00
00Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001aoo`03001oogoo0?moo`Eoo`05
001oogooOol0000HOol5001dOol009Ioo`05001oogooOol00009Ool6000=Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00002Goo1P002Goo00@007ooOol007Eoo`00UWoo00D007ooOomoo`0001Yoo`80
0?moo`Qoo`05001oogooOol0000IOol00`00Ool0001eOol009Eoo`D001eoo`03001oogoo0?moo`Ao
o`D001Yoo`03001oo`0007Eoo`00/goo00D007ooOomoo`000?moobIoo`8007Eoo`00]7oo0`00ogoo
:7oo00<007ooOol0Lgoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol002moo`D00?moobEoo`D00?Moo`00<Goo00<007ooOol0ogoo9goo00<0
07ooOol0mgoo000VOol60005Ool00`00Oomoo`3oOolLOol60005Ool00`00Oomoo`3gOol0035oo`03
001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol017oo00<007oo
Ool0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3o
OolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001o
ogoo00Aoo`800?5oo`00;goo0`001Woo00<007ooOol0ogoo7Woo0`001Woo00<007ooOol0l7oo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03
001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0<Goo1`00^7oo000hOol2003oOolXOol2000]Ool60006Ool3002eOol0
01Moo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@000Eoo`03001oogoo02Yoo`8000moo`@00;5oo`005Woo00D007ooOomoo`00
00Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0
0005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0XOol2000EOol2002_Ool0
00ioo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3l
Ool60002Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol09goo
00<007ooOol05goo00<007ooOol0[7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80
02Ioo`8001]oo`800:aoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001o
ogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`0SOol2000O
Ool00`00Oomoo`2YOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0
0`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool08Woo00<007ooOol087oo00<007ooOol0Z7oo000FOol01@00Oomoogoo00002goo00D007ooOomo
o`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol01Woo0P008Woo00<007ooOol08Woo00<007ooOol0Ygoo000GOol3000<Ool50004Ool4
0005Ool00`00Oomoo`3oOol6Ool3000<Ool50004Ool40005Ool00`00Oomoo`0QOol00`00Oomoo`0S
Ool00`00Oomoo`2VOol003Qoo`03001oogoo0?moobMoo`03001oogoo021oo`03001oogoo02Eoo`03
001oogoo0:Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol07goo00<007ooOol09goo00<007oo
Ool0Y7oo000hOol2003oOolXOol2000OOol00`00Oomoo`0YOol00`00Oomoo`2SOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo01eoo`03001oogoo02]oo`03001oogoo0:9oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol077oo00<007ooOol0;Goo00<007ooOol0XGoo000hOol2003oOolXOol2000L
Ool00`00Oomoo`0_Ool00`00Oomoo`2POol003Qoo`03001oogoo0?moobMoo`03001oogoo01Yoo`03
001oogoo035oo`03001oogoo09moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol06Goo00<007oo
Ool0<goo00<007ooOol0WWoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0IOol00`00Oomoo`0c
Ool00`00Oomoo`2NOol003Qoo`800?moobQoo`8001Uoo`03001oogoo03Eoo`03001oogoo09eoo`00
7goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007oo
Ool05goo00<007ooOol0=goo00<007ooOol0W7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03
001oogoo01Ioo`03001oogoo03Uoo`03001oogoo09]oo`005Woo1P000Woo00D007ooOomoo`00011o
o`03001oogoo009oo`800?moo`Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000F
Ool00`00Oomoo`0jOol00`00Oomoo`2KOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol057oo00<007oo
Ool0?7oo00<007ooOol0VWoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo
00D007ooOomoo`0000aoo`@000Eoo`03001oogoo01Aoo`03001oogoo03eoo`03001oogoo09Uoo`00
7Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<
Ool00`00Oomoo`06Ool00`00Oomoo`0COol00`00Oomoo`0oOol00`00Oomoo`2HOol001ioo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo
0P004goo00<007ooOol0@7oo00<007ooOol0V7oo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>
Ool3000=Ool40005Ool00`00Oomoo`0AOol00`00Oomoo`12Ool00`00Oomoo`2GOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo011oo`03001oogoo04Aoo`03001oogoo09Ioo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol03goo00<007ooOol0AWoo00<007ooOol0UGoo000hOol2003oOolXOol2000@
Ool00`00Oomoo`16Ool00`00Oomoo`2EOol003Qoo`03001oogoo0?moobMoo`03001oogoo00ioo`03
001oogoo04Qoo`03001oogoo09Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol03Goo00<007oo
Ool0BWoo00<007ooOol0Tgoo000hOol2003oOolXOol2000>Ool00`00Oomoo`1;Ool00`00Oomoo`2B
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo00aoo`03001oogoo04aoo`03001oogoo099oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol037oo00<007ooOol0CGoo00<007ooOol0TGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`0;Ool00`00Oomoo`1?Ool00`00Oomoo`2@Ool003Qoo`800?mo
obQoo`8000]oo`03001oogoo051oo`03001oogoo091oo`005goo0`001Woo0P0017oo1@0017oo1000
1Goo00<007ooOol0ogoo1Woo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol02Woo00<007oo
Ool0DGoo00<007ooOol0Sgoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03
001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo
00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0Dgoo00<007ooOol0SWoo000>Ool60002Ool0
1@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P00oGoo1P000Woo00D007ooOomo
o`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8000Yoo`03001oogoo05Aoo`03001oogoo08eo
o`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eo
o`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomo
o`1EOol00`00Oomoo`2=Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00
Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol01goo00<0
07ooOol0Egoo00<007ooOol0S7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo05Qoo`03001oogoo08]oo`005Woo00D007ooOomoo`0000]oo`05
001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomo
o`0000Aoo`03001oogoo00Ioo`8000Moo`03001oogoo05Uoo`03001oogoo08]oo`005goo0`003Goo
0`001Goo10001Goo00<007ooOol0ogoo1Woo0`003Goo0`001Goo10001Goo00<007ooOol01Woo00<0
07ooOol0FWoo00<007ooOol0RWoo000hOol00`00Oomoo`0OOol30006Ool20004Ool5000HOol30006
Ool20006Ool3000HOol30006Ool20005Ool3000JOol30006Ool20005Ool3000QOol50019Ool00`00
Oomoo`05Ool00`00Oomoo`0GOol30006Ool20004Ool5000HOol30006Ool20006Ool30005Ool00`00
Oomoo`0@Ool30006Ool20005Ool3000IOol30006Ool20005Ool3000QOol5000DOol003Qoo`8001mo
o`05001oogooOol00005Ool20005Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03
001oogoo01Ioo`05001oogooOol00005Ool20004Ool01@00Oomoogoo000067oo00D007ooOomoo`00
00Eoo`8000Aoo`05001oogooOol0000ROol00`00Oomoo`19Ool20005Ool00`00Oomoo`0GOol01@00
Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00Oomo
o`04Ool00`00Oomoo`0?Ool01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Moo`05001o
ogooOol00005Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0N
Ool01@00Oomoogoo00003Goo00<007ooOol05goo00D007ooOomoo`0000]oo`D001Moo`05001oogoo
Ool0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00
Oomoo`19Ool00`00Oomoo`04Ool00`00Oomoo`0GOol01@00Oomoogoo00003Goo00<007ooOol05goo
00D007ooOomoo`0000]oo`D000Ioo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo
00005goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001o
ogoo01ioo`05001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol0
01Qoo`05001oogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogoo
Ool0000ROol00`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`0HOol01@00Oomoogoo00003Woo
00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo0007Ool00`00Oomoo`0>Ool01@00Oomo
ogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<0
07ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007oo
Oomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool4000IOol01@00Oomoogoo000037oo
0`008goo00<007ooOol0BGoo00<007ooOol00Woo00<007ooOol06Goo00D007ooOomoo`0000moo`03
001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool00008Ool00`00Oomoo`0=Ool01@00Oomoogoo
00002goo100067oo00D007ooOomoo`0000aoo`<002=oo`03001oogoo01Aoo`00>7oo0P007goo00D0
07ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomo
ogoo00002goo00<007ooOol06Woo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomo
o`19Ool20003Ool00`00Oomoo`0IOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomo
o`0000aoo`03001oo`0000Uoo`03001oogoo00aoo`05001oogooOol0000;Ool00`00Oomoo`0IOol0
1@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo
00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00003Goo0P0067oo00D007oo
Oomoo`0000aoo`03001oogoo01Uoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007oo
Ool0BGoo00D007ooOomoo`0001aoo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007oo
Oomoo`0000eoo`8000Uoo`03001oogoo00aoo`05001oogooOol0000<Ool00`00Oomoo`0HOol01@00
Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07goo0`00
3Goo0`006Goo0`003goo00<007ooOol05goo0`003Woo0`006Goo0`003Goo0`008Goo0`00Bgoo00D0
07ooOomoo`0001eoo`<000eoo`<001Uoo`<000moo`03001oogoo00Qoo`03001oogoo00aoo`<000io
o`<001Qoo`<000eoo`<0025oo`<001Ioo`00>7oo00<007ooOol0ogoo9goo00@007ooOol006Moo`03
001oogoo08Eoo`00>7oo0P00ogoo:7oo0`00JGoo00<007ooOol0Q7oo000hOol00`00Oomoo`3oOolW
Ool00`00Ool0001ZOol00`00Oomoo`23Ool003Qoo`03001oogoo0?moobMoo`8006]oo`03001oogoo
08=oo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`030005Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`04Ool300000goo001oo`1:Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0DOol003Qo
o`03001oogoo00=oo`<002=oo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Yoo`03001o
ogoo029oo`<000Aoo`03001oogoo04Uoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo01Ao
o`03001oogoo019oo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo01Aoo`00>7oo00<007oo
Ool01Woo0`00aWoo1000Dgoo00<007ooOol0KGoo00<007ooOol0J7oo00<007ooOol05Goo000hOol2
000:Ool30030Ool3001GOol2001^Ool00`00Oomoo`1WOol00`00Oomoo`0FOol003Qoo`03001oogoo
00aoo`<00;Yoo`<005Yoo`03001oogoo06ioo`03001oogoo06Ioo`03001oogoo01Ioo`00>7oo00<0
07ooOol03goo1000/goo0`00GGoo00<007ooOol0KWoo00<007ooOol0IGoo00<007ooOol05goo000h
Ool2000DOol3002]Ool3001POol2001`Ool00`00Oomoo`1TOol00`00Oomoo`0GOol003Qoo`03001o
ogoo01Ioo`<00:Moo`<006=oo`03001oogoo071oo`03001oogoo069oo`03001oogoo01Qoo`00>7oo
00<007ooOol06Goo0`00X7oo1000IWoo00<007ooOol0L7oo00<007ooOol0HGoo00<007ooOol06Goo
000hOol00`00Oomoo`0LOol5002FOol5001ZOol00`00Oomoo`1aOol00`00Oomoo`1POol00`00Oomo
o`0IOol003Qoo`80029oo`@008moo`<006moo`80079oo`03001oogoo05moo`03001oogoo01Yoo`00
>7oo00<007ooOol09Goo0`00RGoo0`00LWoo00<007ooOol0LWoo00<007ooOol0GWoo00<007ooOol0
6Woo000hOol00`00Oomoo`0XOol30023Ool3001eOol00`00Oomoo`1cOol00`00Oomoo`1LOol00`00
Oomoo`0KOol003Qoo`03001oogoo02]oo`<007aoo`@007Qoo`03001oogoo07=oo`03001oogoo05]o
o`03001oogoo01aoo`00>7oo0P00;goo1@00LWoo1@00O7oo0P00MGoo00<007ooOol0FWoo00<007oo
Ool077oo000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`0cOol5001YOol4001POol3
0006Ool20004Ool50004Ool40005Ool00`00Oomoo`1dOol00`00Oomoo`1IOol00`00Oomoo`0MOol0
01Ioo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0
>7oo1@00Ggoo1@00Hgoo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02
Ool00`00Oomoo`1eOol00`00Oomoo`1HOol00`00Oomoo`0MOol001Ioo`05001oogooOol0000=Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool2000nOol7001AOol7001XOol01@00Oomoogoo00003Goo00<0
07ooOol027oo00<007ooOol00Woo0P00Mgoo00<007ooOol0EWoo00<007ooOol07Woo000FOol01@00
Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0A7oo1P00AGoo1P00Kgoo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo07Moo`03001oogoo
05Aoo`03001oogoo01moo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001o
ogoo04Yoo`D003]oo`D007Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomo
o`1gOol00`00Oomoo`1DOol00`00Oomoo`0OOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`1?Ool9000[Ool7001jOol01@00Oomoogoo00003goo00<007oo
Ool00Woo00<007ooOol01Woo00<007ooOol0N7oo00<007ooOol0DWoo00<007ooOol087oo000FOol0
1@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8005Uoob/0085oo`05001o
ogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00NWoo00<007ooOol0D7oo00<0
07ooOol08Goo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`3oOol6Ool3000=Ool30005Ool4
0005Ool00`00Oomoo`1iOol00`00Oomoo`1?Ool00`00Oomoo`0ROol003Qoo`03001oogoo0?moobMo
o`03001oogoo07Yoo`03001oogoo04ioo`03001oogoo029oo`00>7oo0P00ogoo:7oo0P00O7oo00<0
07ooOol0C7oo00<007ooOol08goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1lOol00`00Oomo
o`1:Ool00`00Oomoo`0TOol003Qoo`03001oogoo0?moobMoo`03001oogoo07aoo`03001oogoo04Yo
o`03001oogoo02Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0OGoo00<007ooOol0B7oo00<0
07ooOol09Goo000hOol2003oOolXOol2001oOol00`00Oomoo`16Ool00`00Oomoo`0VOol003Qoo`03
001oogoo0?moobMoo`03001oogoo07ioo`03001oogoo04Ioo`03001oogoo02Ioo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0Ogoo00<007ooOol0A7oo00<007ooOol09goo000hOol2003oOolXOol2
0021Ool00`00Oomoo`12Ool00`00Oomoo`0XOol003Qoo`03001oogoo0?moobMoo`03001oogoo085o
o`03001oogoo041oo`03001oogoo02Uoo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo
3Woo0`001Woo0P001Goo10001Goo00<007ooOol0PGoo00<007ooOol0@7oo00<007ooOol0:Goo000N
Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomo
o`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo089oo`03001oogoo03ioo`03001oogoo02Yo
o`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`ioo`05001oogooOol0000@Ool0
0`00Oomoo`02Ool20024Ool00`00Oomoo`0lOol00`00Oomoo`0[Ool001ioo`05001oogooOol0000@
Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<0
07ooOol0Q7oo00<007ooOol0>Woo00<007ooOol0;7oo000NOol01@00Oomoogoo000037oo10001Goo
00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo08Aoo`03001oogoo03Uo
o`03001oogoo02eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eo
o`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`25Ool00`00Oomoo`0hOol00`00Oomo
o`0]Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomoogoo0000
37oo00<007ooOol01Woo0P00Qgoo00<007ooOol0=Woo00<007ooOol0;Woo000OOol3000=Ool40005
Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`27Ool00`00Oomoo`0dOol00`00Oomo
o`0_Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Moo`03001oogoo03=oo`03001oogoo031o
o`00>7oo0P00ogoo:7oo0P00RGoo00<007ooOol0<Woo00<007ooOol0<7oo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`29Ool00`00Oomoo`0`Ool00`00Oomoo`0aOol003Qoo`03001oogoo0?moobMo
o`03001oogoo08Yoo`03001oogoo02ioo`03001oogoo039oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0Rgoo0P00;Goo00<007ooOol0<goo000hOol2003oOolXOol2002>Ool00`00Oomoo`0YOol0
0`00Oomoo`0dOol003Qoo`03001oogoo0?moobMoo`03001oogoo08ioo`03001oogoo02Moo`03001o
ogoo03Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Sgoo00<007ooOol09Goo00<007ooOol0
=Woo000hOol2003oOolXOol2002AOol2000TOol00`00Oomoo`0gOol001Moo`<000Ioo`8000Ioo`03
001oogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eo
o`03001oogoo099oo`03001oogoo01moo`8003Yoo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`2COol00`00Oomoo`0LOol2000lOol001Ioo`05
001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomo
ogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0U7oo00<007ooOol06Woo00<0
07ooOol0?7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00ogoo
1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8009Ioo`8001Qoo`8003mo
o`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001o
ogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`2GOol2000DOol20011Ool001Ioo`05
001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomo
ogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0VGoo0`003Woo0`00@goo000F
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo0?moo`Eo
o`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0W7oo0P00
2Woo0P00AWoo000GOol3000<Ool50004Ool40005Ool2003oOol7Ool3000<Ool50004Ool40005Ool2
002OOol:0018Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00;goo
1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00
Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo
0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<0
07ooOol017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo
0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3003o
OolWOol3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo1@00ogoo
1Goo0`0000Aoo`00000001Moo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo
0?moo`Ioo`05001oogooOol00009Ool6000:Ool01000Oomoo`00M7oo002FOol01@00Oomoogoo0000
6goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001Yoo`03001oogoo07Aoo`00UWoo00D007ooOomo
o`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1c
Ool009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo000077oo00<007oo
Ool0LWoo002EOol5000LOol00`00Oomoo`3oOol5Ool5000MOol00`00Oomoo`1bOol00;Ioo`03001o
ogoo0?moob=oo`05001oogooOol0001dOol00;Aoo`<00?moobIoo`<007Eoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .19515 L
.08255 .14141 L
.10458 .09022 L
.12507 .05185 L
.14415 .02556 L
.14918 .02028 L
.15465 .01536 L
.15946 .01173 L
.16457 .00862 L
.16917 .00647 L
.17178 .00553 L
.17423 .00484 L
.17538 .00457 L
.17647 .00435 L
.17746 .00419 L
.17852 .00405 L
.17967 .00393 L
.18073 .00385 L
.182 .00381 L
.18314 .00381 L
.18435 .00385 L
.18547 .00393 L
.1867 .00406 L
.18802 .00425 L
.19071 .0048 L
.19317 .00549 L
.1979 .00733 L
.20239 .00968 L
.21236 .017 L
.22321 .02819 L
.24299 .0568 L
.26399 .09771 L
.30174 .19265 L
.34195 .31106 L
.38063 .42493 L
.40028 .4773 L
.42177 .52725 L
.44253 .56619 L
.4614 .59223 L
.47149 .60216 L
.47611 .60574 L
.48101 .60886 L
.4835 .61017 L
.48624 .6114 L
.48876 .61234 L
.49106 .61304 L
.49378 .61365 L
.49527 .6139 L
.49596 .61399 L
Mistroke
.49669 .61407 L
.498 .61417 L
.49921 .61422 L
.49996 .61423 L
.50065 .61422 L
.50196 .61417 L
.50313 .61408 L
.50438 .61394 L
.50556 .61377 L
.50663 .61357 L
.50926 .61295 L
.51175 .61217 L
.5167 .61007 L
.52208 .60697 L
.53169 .59935 L
.54056 .58997 L
.55926 .56323 L
.57988 .52373 L
.62014 .42277 L
.65888 .30858 L
.70007 .18761 L
.72063 .13352 L
.73974 .08971 L
.75939 .05284 L
.77791 .02689 L
.78775 .0169 L
.79293 .01276 L
.7984 .00922 L
.80302 .00692 L
.80546 .00595 L
.80809 .00512 L
.8105 .00453 L
.8127 .00414 L
.81375 .00401 L
.81491 .0039 L
.81599 .00384 L
.817 .00381 L
.81818 .00381 L
.81941 .00386 L
.82047 .00394 L
.82163 .00406 L
.82287 .00424 L
.82421 .00448 L
.82661 .00506 L
.82905 .00581 L
.83134 .00668 L
.83564 .00873 L
.84078 .0119 L
.84552 .0155 L
.85624 .026 L
Mistroke
.87498 .05192 L
.89561 .09061 L
.93591 .19056 L
.97471 .30454 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .26242 L
.08255 .24219 L
.0932 .2333 L
.10458 .22545 L
.11009 .22231 L
.11531 .21977 L
.12038 .21769 L
.12507 .21614 L
.12951 .215 L
.13178 .21454 L
.13422 .21415 L
.13549 .21398 L
.13666 .21384 L
.13784 .21373 L
.13895 .21365 L
.14022 .21358 L
.1409 .21356 L
.14161 .21354 L
.1423 .21353 L
.14295 .21353 L
.14415 .21354 L
.14531 .21358 L
.14656 .21364 L
.14773 .21372 L
.14881 .21382 L
.15143 .21414 L
.15392 .21454 L
.15886 .21565 L
.16423 .2173 L
.17383 .22139 L
.1827 .22642 L
.20137 .2406 L
.22197 .261 L
.26217 .30935 L
.30086 .35597 L
.32051 .37571 L
.3309 .38443 L
.342 .39217 L
.35275 .39797 L
.35784 .4001 L
.36253 .4017 L
.36724 .40295 L
.36972 .40346 L
.37235 .40389 L
.37463 .40418 L
.37573 .40428 L
.37677 .40436 L
.37799 .40444 L
.37911 .40448 L
Mistroke
.38031 .40451 L
.38162 .4045 L
.38227 .40449 L
.38296 .40448 L
.38419 .40442 L
.38551 .40434 L
.38695 .40421 L
.38955 .40389 L
.39197 .4035 L
.39649 .40251 L
.40134 .40108 L
.40698 .39893 L
.41232 .39645 L
.42232 .39063 L
.44227 .37492 L
.4607 .35634 L
.50002 .30899 L
.53782 .26331 L
.55884 .24211 L
.56803 .23435 L
.57808 .22714 L
.58722 .22183 L
.59696 .21755 L
.60236 .21583 L
.60726 .21468 L
.60962 .21426 L
.61086 .21408 L
.61218 .21392 L
.61333 .2138 L
.61459 .21369 L
.61574 .21362 L
.61682 .21357 L
.61808 .21353 L
.61871 .21353 L
.61941 .21353 L
.62065 .21355 L
.62181 .21359 L
.62248 .21362 L
.62318 .21367 L
.62443 .21377 L
.62578 .2139 L
.62725 .21408 L
.62973 .21447 L
.63238 .215 L
.63715 .21624 L
.64214 .21792 L
.64686 .21988 L
.6557 .22447 L
.67568 .23897 L
.69413 .25668 L
Mistroke
.7335 .30323 L
.77136 .34959 L
.79241 .37174 L
.81166 .38782 L
.82118 .39396 L
.8262 .39666 L
.83155 .39912 L
.8367 .40105 L
.84136 .40244 L
.84361 .40299 L
.84604 .40349 L
.84835 .40387 L
.85045 .40414 L
.85159 .40425 L
.85283 .40435 L
.85414 .40443 L
.85538 .40448 L
.85653 .40451 L
.85776 .40451 L
.85881 .40449 L
.85997 .40444 L
.86063 .40441 L
.86132 .40436 L
.86256 .40426 L
.86535 .40395 L
.86777 .40357 L
.87041 .40305 L
.87569 .40166 L
.88133 .39969 L
.89148 .39488 L
.90173 .38845 L
.91284 .37986 L
.933 .36054 L
.97393 .31186 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32685 L
.10458 .34595 L
.14415 .36326 L
.18221 .37903 L
.22272 .3946 L
.26171 .40815 L
.30316 .42076 L
.34309 .43093 L
.3815 .43873 L
.40095 .44189 L
.42237 .44473 L
.44268 .44681 L
.45178 .44754 L
.46172 .44819 L
.4671 .44848 L
.4721 .44871 L
.47727 .44891 L
.48196 .44906 L
.48658 .44917 L
.4887 .44921 L
.49093 .44924 L
.49332 .44927 L
.49438 .44928 L
.49552 .44929 L
.49675 .4493 L
.49789 .4493 L
.49859 .44931 L
.49925 .44931 L
.50049 .44931 L
.50163 .44931 L
.50286 .4493 L
.50401 .4493 L
.50508 .44929 L
.50754 .44926 L
.51014 .44923 L
.51268 .44919 L
.51504 .44914 L
.5204 .44899 L
.5293 .44865 L
.53882 .44816 L
.54906 .44747 L
.56016 .44655 L
.58032 .44441 L
.62123 .43824 L
.66064 .43007 L
.69852 .42029 L
.73886 .40797 L
.77769 .39445 L
.81897 .37856 L
Mistroke
.85873 .36203 L
.89697 .34526 L
.93767 .3268 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .26322 L
.10458 .21674 L
.14415 .17949 L
.18221 .15192 L
.20178 .14148 L
.21267 .13688 L
.22272 .13342 L
.23293 .13069 L
.23832 .12958 L
.24402 .12864 L
.24641 .12833 L
.24897 .12804 L
.25119 .12784 L
.25361 .12765 L
.25507 .12757 L
.25643 .1275 L
.25773 .12745 L
.2584 .12743 L
.25912 .12741 L
.25983 .1274 L
.26048 .12739 L
.26176 .12738 L
.26293 .12739 L
.26416 .1274 L
.26538 .12743 L
.26607 .12745 L
.26671 .12747 L
.26912 .12759 L
.27131 .12773 L
.27364 .12793 L
.27847 .12846 L
.2838 .12927 L
.29326 .13125 L
.30213 .13374 L
.32232 .14162 L
.34082 .15145 L
.38045 .18015 L
.41855 .21605 L
.45912 .26062 L
.49816 .30681 L
.53966 .356 L
.57964 .40012 L
.61811 .43665 L
.63759 .45217 L
.65902 .46649 L
.67938 .4772 L
.69843 .48447 L
.70884 .48728 L
.71396 .48836 L
Mistroke
.71872 .48917 L
.72301 .48975 L
.72758 .49022 L
.7302 .49041 L
.73148 .49048 L
.73266 .49054 L
.73371 .49058 L
.73487 .49061 L
.73603 .49064 L
.73725 .49065 L
.73856 .49065 L
.73977 .49064 L
.7404 .49063 L
.7411 .49062 L
.74251 .49058 L
.74375 .49053 L
.74508 .49046 L
.74748 .4903 L
.74985 .49011 L
.75235 .48985 L
.7568 .48927 L
.76198 .4884 L
.7668 .4874 L
.77773 .48448 L
.78828 .48079 L
.79823 .47655 L
.81683 .4667 L
.85534 .43897 L
.89632 .40036 L
.93577 .35688 L
.97371 .31199 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol07goo1P00SWoo1@00Igoo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00
Oomoo`04Ool00`00Oomoo`0MOol30005Ool30028Ool30005Ool2001UOol00`00Oomoo`04Ool00`00
Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo01aoo`03001oogoo00Uoo`03001oogoo08Ao
o`03001oogoo00Qoo`03001oogoo069oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007oo
Ool017oo0P0077oo00<007ooOol02goo00<007ooOol0PWoo00<007ooOol02Woo0P00HWoo00<007oo
Ool017oo0P00lGoo000_Ool30006Ool00`00Oomoo`0JOol00`00Oomoo`0<Ool00`00Oomoo`21Ool0
0`00Oomoo`0=Ool00`00Oomoo`1MOol30006Ool00`00Oomoo`3`Ool003Qoo`03001oogoo01Uoo`03
001oogoo00ioo`03001oogoo07moo`03001oogoo00moo`03001oogoo06Eoo`03001oogoo0?1oo`00
>7oo0P006Woo00<007ooOol03goo00<007ooOol0OWoo00<007ooOol03goo00<007ooOol0IGoo0P00
lGoo000hOol00`00Oomoo`0HOol00`00Oomoo`0@Ool00`00Oomoo`1mOol00`00Oomoo`0AOol00`00
Oomoo`1TOol00`00Oomoo`3`Ool003Qoo`03001oogoo01Moo`03001oogoo019oo`03001oogoo07]o
o`03001oogoo01=oo`03001oogoo06=oo`03001oogoo0?1oo`00>7oo00<007ooOol05Woo00<007oo
Ool057oo00<007ooOol0NGoo00<007ooOol057oo00<007ooOol0Hgoo00<007ooOol0l7oo000hOol2
000FOol00`00Oomoo`0FOol00`00Oomoo`1gOol00`00Oomoo`0FOol00`00Oomoo`1ROol2003aOol0
03Qoo`03001oogoo01Aoo`03001oogoo01Qoo`03001oogoo07Eoo`03001oogoo01Qoo`03001oogoo
065oo`03001oogoo0?1oo`00>7oo00<007ooOol057oo00<007ooOol06Goo00<007ooOol0M7oo00<0
07ooOol067oo00<007ooOol0HGoo00<007ooOol0l7oo000hOol00`00Oomoo`0COol00`00Oomoo`0J
Ool00`00Oomoo`1cOol00`00Oomoo`0JOol00`00Oomoo`1POol00`00Oomoo`3`Ool003Qoo`8001Ao
o`03001oogoo01]oo`03001oogoo079oo`03001oogoo01Yoo`03001oogoo061oo`800?5oo`005goo
0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol04Woo00<007ooOol077oo00<007oo
Ool0LGoo00<007ooOol077oo00<007ooOol0?Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo
00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol04Woo00<007ooOol07Goo00<007ooOol0L7oo00<007ooOol07Goo00<007ooOol0
?7oo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1o
o`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8001=oo`03
001oogoo01eoo`03001oogoo071oo`03001oogoo01eoo`03001oogoo03Aoo`H0009oo`05001oogoo
Ool0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`0OOol00`00Oomoo`1^Ool0
0`00Oomoo`0OOol00`00Oomoo`0kOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007oo
Ool04Goo00<007ooOol07goo00<007ooOol0KWoo00<007ooOol07goo00<007ooOol0>goo00D007oo
Oomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000mo
o`03001oogoo009oo`03001oogoo00Ioo`03001oogoo011oo`03001oogoo025oo`03001oogoo06ao
o`03001oogoo025oo`03001oogoo03Yoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P004Goo00<007ooOol08Goo00<007ooOol0K7oo00<007ooOol08Goo00<007ooOol0>Woo
00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003aOol001Moo`<000ao
o`D000Aoo`@000Eoo`03001oogoo00moo`03001oogoo02=oo`03001oogoo06Yoo`03001oogoo02=o
o`03001oogoo03Yoo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol03goo
00<007ooOol08goo00<007ooOol0JWoo00<007ooOol08goo00<007ooOol0Fgoo00<007ooOol0l7oo
000hOol2000@Ool00`00Oomoo`0TOol00`00Oomoo`1XOol00`00Oomoo`0TOol00`00Oomoo`1KOol2
003aOol003Qoo`03001oogoo00ioo`03001oogoo02Eoo`03001oogoo06Qoo`03001oogoo02Eoo`03
001oogoo05Yoo`03001oogoo0?1oo`00>7oo00<007ooOol03Woo00<007ooOol09Goo00<007ooOol0
Igoo00<007ooOol09Woo00<007ooOol0FWoo00<007ooOol0l7oo000hOol00`00Oomoo`0=Ool00`00
Oomoo`0WOol00`00Oomoo`1VOol00`00Oomoo`0WOol00`00Oomoo`1IOol00`00Oomoo`3`Ool003Qo
o`8000ioo`03001oogoo02Moo`03001oogoo06Eoo`03001oogoo02Qoo`03001oogoo05Uoo`800?5o
o`00>7oo00<007ooOol037oo00<007ooOol0:7oo00<007ooOol0IGoo00<007ooOol0:7oo00<007oo
Ool0FGoo00<007ooOol0l7oo000hOol00`00Oomoo`0<Ool00`00Oomoo`0YOol00`00Oomoo`1SOol0
0`00Oomoo`0ZOol00`00Oomoo`1HOol00`00Oomoo`3`Ool003Qoo`8000eoo`03001oogoo02Uoo`03
001oogoo06=oo`03001oogoo02Yoo`03001oogoo05Qoo`800?5oo`007goo0`001Woo0P001Goo1000
1Goo00<007ooOol02goo00<007ooOol0:Woo00<007ooOol0Hgoo00<007ooOol0:goo00<007ooOol0
?Woo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo
00<007ooOol00Woo00<007ooOol02goo00<007ooOol0:goo00<007ooOol0HGoo00<007ooOol0;7oo
00<007ooOol0?Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`00
5Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo02ao
o`03001oogoo065oo`03001oogoo02aoo`03001oogoo03Eoo`H0009oo`05001oogooOol0000@Ool0
0`00Oomoo`02Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000;
Ool00`00Oomoo`0]Ool00`00Oomoo`1POol00`00Oomoo`0]Ool00`00Oomoo`0lOol01@00Oomoogoo
000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0
2Woo00<007ooOol0;Goo00<007ooOol0Ggoo00<007ooOol0;Woo00<007ooOol0?7oo00D007ooOomo
o`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03
001oogoo00Uoo`03001oogoo02ioo`03001oogoo05moo`03001oogoo02ioo`03001oogoo03aoo`05
001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool0
0`00Oomoo`0kOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0l7oo000OOol3000=
Ool40005Ool20009Ool00`00Oomoo`0`Ool00`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomoo`0l
Ool3000=Ool40005Ool2003aOol003Qoo`03001oogoo00Qoo`03001oogoo031oo`03001oogoo05eo
o`03001oogoo035oo`03001oogoo05Aoo`03001oogoo0?1oo`00>7oo00<007ooOol01goo00<007oo
Ool0<Woo00<007ooOol0G7oo00<007ooOol0<Goo00<007ooOol0E7oo00<007ooOol0l7oo000hOol2
0008Ool00`00Oomoo`0bOol00`00Oomoo`1KOol00`00Oomoo`0bOol00`00Oomoo`1DOol2003aOol0
03Qoo`03001oogoo00Moo`03001oogoo039oo`03001oogoo05]oo`03001oogoo03=oo`03001oogoo
05=oo`03001oogoo0?1oo`00>7oo00<007ooOol01Woo00<007ooOol0=7oo00<007ooOol0FWoo00<0
07ooOol0<goo00<007ooOol0Dgoo00<007ooOol0l7oo000hOol00`00Oomoo`06Ool00`00Oomoo`0d
Ool00`00Oomoo`1IOol00`00Oomoo`0eOol00`00Oomoo`1BOol00`00Oomoo`3`Ool003Qoo`8000Io
o`03001oogoo03Ioo`03001oogoo05Qoo`03001oogoo03Eoo`03001oogoo059oo`800?5oo`00>7oo
00<007ooOol01Goo00<007ooOol0=Woo00<007ooOol0F7oo00<007ooOol0=Goo00<007ooOol0DWoo
00<007ooOol0l7oo000hOol00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`1GOol00`00Oomo
o`0gOol00`00Oomoo`1AOol00`00Oomoo`3`Ool003Qoo`8000Eoo`03001oogoo03Qoo`03001oogoo
05Ioo`03001oogoo03Moo`03001oogoo055oo`8001Eoo`T006Ioo`T006Aoo`005goo0`001Woo0P00
17oo1@0017oo10001Goo00<007ooOol017oo00<007ooOol0>7oo00<007ooOol0EWoo00<007ooOol0
=goo00<007ooOol0<7oo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol04Woo0P002Goo1000
H7oo0P002Goo0`00HGoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001o
ogoo009oo`03001oogoo00Aoo`03001oogoo03Qoo`03001oogoo05Eoo`03001oogoo03Uoo`03001o
ogoo02ioo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007oo
Ool03goo0`003goo00<007ooOol0FWoo0`003Woo0P00Ggoo000>Ool60002Ool01@00Oomoogoo0000
3Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0>Woo00<007ooOol0
E7oo00<007ooOol0>Goo00<007ooOol09Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qo
o`03001oogoo009oo`03001oogoo00ioo`03001oogoo015oo`8005Qoo`8001=oo`03001oogoo05ao
o`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000Aoo`03001oogoo
03Yoo`03001oogoo05Aoo`03001oogoo03Uoo`03001oogoo02ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool2000=Ool2000FOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00
Oomoo`1KOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`03Ool0
0`00Oomoo`0kOol00`00Oomoo`1BOol00`00Oomoo`0kOol00`00Oomoo`0]Ool01@00Oomoogoo0000
3goo00<007ooOol00Woo10001Goo00<007ooOol02goo00<007ooOol05goo00<007ooOol0DWoo00<0
07ooOol05Woo00<007ooOol0FWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol00Woo00<007ooOol0?7oo00<007ooOol0DWoo00<007ooOol0>goo00<007oo
Ool0;Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Yoo`03
001oogoo01Uoo`03001oogoo051oo`03001oogoo01Qoo`03001oogoo05Uoo`005Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20003Ool00`00Oomoo`0lOol00`00Oomo
o`1BOol00`00Oomoo`0kOol00`00Oomoo`0]Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Ao
o`03001oogoo00Ioo`8000]oo`03001oogoo01Yoo`03001oogoo04ioo`03001oogoo01Yoo`03001o
ogoo05Qoo`005goo0`003Goo0`001Goo10001Goo00<007ooOol00Woo00<007ooOol0?Goo00<007oo
Ool0D7oo00<007ooOol0?Goo00<007ooOol0;Goo0`003Goo0`001Goo10001Goo00<007ooOol02Goo
00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol0Egoo000hOol01@00Oomo
ogoo0000@7oo00<007ooOol0D7oo00<007ooOol0?Goo00<007ooOol0CWoo00<007ooOol027oo00<0
07ooOol07Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000hOol01@00Oomoogoo
00007Goo0`001Woo0P0017oo1@003goo00<007ooOol01Woo0`001Woo0P001Woo0`0067oo0`001Woo
0P001Goo0`002Woo00<007ooOol03Goo0`001Woo0P001Goo0`007Woo00<007ooOol01@00BGoo00<0
07ooOol01goo00<007ooOol05Goo0`001Woo0`000goo1@0067oo0`001Woo0P001Woo0`005Woo00<0
07oo00000P001Woo0P001Goo0`003Woo00<007ooOol027oo0`001Woo0P001Goo0`008Goo1@0057oo
000hOol20002Ool00`00Oomoo`0JOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol0011oo`03
001oogoo00Aoo`05001oogooOol00005Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo
0P0017oo00D007ooOomoo`0000Uoo`03001oogoo00aoo`05001oogooOol00005Ool20004Ool01@00
Oomoogoo00007Woo00D007ooOomoo`0004]oo`8000Moo`03001oogoo01Eoo`05001oogooOol00005
Ool200000goo001oo`02Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo
01Aoo`03001oo`0000=oo`03001oogoo00=oo`8000Aoo`05001oogooOol0000=Ool00`00Oomoo`07
Ool01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00@0
07ooOol001eoo`05001oogooOol0000=Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool01@00Oomoogoo
00002goo1@005goo00D007ooOomoo`0000]oo`05001oogooOol00009Ool00`00Oomoo`0<Ool01@00
Oomoogoo00002goo00D007ooOomoo`0001ioo`05001oogooOol0001;Ool00`00Oomoo`06Ool00`00
Oomoo`0EOol01@00Oomoogoo000027oo00<007ooOol00Woo00<007ooOol05goo00D007ooOomoo`00
00]oo`D001Eoo`03001oo`0000=oo`03001oogoo00Uoo`05001oogooOol0000>Ool00`00Oomoo`06
Ool01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00@007ooOol0
01eoo`05001oogooOol0000>Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool01@00Oomoogoo00002goo
00@007ooOol001Qoo`05001oogooOol0000;Ool01@00Oomoogoo000027oo00<007ooOol03Goo00D0
07ooOomoo`0000]oo`05001oogooOol0000NOol01@00Oomoogoo0000Bgoo00<007ooOol01Goo00<0
07ooOol05Woo00D007ooOomoo`0000Uoo`03001oogoo009oo`03001oogoo01Ioo`05001oogooOol0
000;Ool01000Oomoo`005Goo00@007ooOol000=oo`03001oogoo00Uoo`05001oogooOol0000?Ool0
0`00Oomoo`05Ool01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo
00@007ooOol001eoo`05001oogooOol0000?Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool01@00Oomo
ogoo000037oo00<007oo000067oo00D007ooOomoo`0000]oo`@000Uoo`03001oogoo00eoo`05001o
ogooOol0000<Ool3000POol01000Oomoo`00Bgoo00<007ooOol017oo00<007ooOol05goo00D007oo
Oomoo`0000Yoo`03001oogoo009oo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000D
Ool01@00Oomoogoo00000goo00<007ooOol02Goo10004Goo00<007ooOol017oo00D007ooOomoo`00
00aoo`<002=oo`03001oogoo01Aoo`00>7oo0`007Woo00D007ooOomoo`0000moo`03001oogoo00mo
o`03001oogoo00=oo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo00<0
07ooOol02Woo00<007ooOol03Goo00D007ooOomoo`0000]oo`05001oogooOol0000OOol01000Oomo
o`00Bgoo0P0017oo00<007ooOol067oo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00
Oomoogoo000037oo00<007oo00004goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo
01=oo`03001oogoo00=oo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo
000hOol00`00Ool0000NOol01@00Oomoogoo00002goo00D007ooOomoo`00019oo`03001oogoo009o
o`05001oogooOol0000=Ool2000HOol01@00Oomoogoo000037oo00<007ooOol027oo00<007ooOol0
3Woo00D007ooOomoo`0000]oo`05001oogooOol0000OOol01000Oomoo`00Bgoo00<007ooOol00Woo
00<007ooOol06Goo00D007ooOomoo`0000]oo`80009oo`03001oogoo01Eoo`05001oogooOol0000=
Ool2000BOol00`00Oomoo`03Ool01@00Oomoogoo000037oo00<007ooOol04goo00<007ooOol00Woo
00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oo`0001mo
o`<000eoo`<001=oo`03001oogoo00=oo`<000moo`03001oogoo01Moo`<000ioo`<000Moo`03001o
ogoo00moo`<000eoo`<0025oo`<004]oo`05001oogooOol0000MOol3000=Ool3000IOol3000?Ool0
0`00Oomoo`0?Ool00`00Oomoo`05Ool3000>Ool3000COol00`00Oomoo`02Ool3000=Ool3000QOol3
000FOol003Qoo`8004Ioo`03001oogoo04Yoo`03001oogoo04=oo`03001oogoo04]oo`80009oo`03
001oogoo02aoo`03001oogoo03aoo`03001oogoo02eoo`03001oogoo04ioo`00>7oo0P00Agoo00<0
07ooOol0B7oo00<007ooOol0A7oo00<007ooOol0Bgoo00@007ooOol0031oo`03001oogoo03Yoo`03
001oogoo02moo`03001oogoo04eoo`00>7oo0P00Agoo00<007ooOol0B7oo00<007ooOol0AGoo00<0
07ooOol0BWoo00<007oo0000<Woo00<007ooOol0>7oo00<007ooOol0<Goo00<007ooOol0C7oo000h
Ool00`00Oomoo`16Ool00`00Oomoo`18Ool00`00Oomoo`15Ool00`00Oomoo`1:Ool2000dOol00`00
Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`1<Ool0039oonT0041oonT0011oo`00>7oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol01Goo00@007ooOol000Yoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`05001oogooOol00006Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool20009Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`0DOol003Qoo`03001oogoo04Qoo`03001oogoo04Aoo`03001oogoo09Aoo`03
001oogoo03Eoo`03001oogoo039oo`03001oogoo03Moo`03001oogoo035oo`03001oogoo01Eoo`00
>7oo0P00BGoo00<007ooOol0A7oo00<007ooOol0U7oo0P00=goo00<007ooOol0<7oo00<007ooOol0
>Goo00<007ooOol0;goo00<007ooOol05Woo000hOol00`00Oomoo`18Ool00`00Oomoo`14Ool00`00
Oomoo`2DOol00`00Oomoo`0gOol00`00Oomoo`0^Ool00`00Oomoo`0kOol00`00Oomoo`0]Ool00`00
Oomoo`0GOol003Qoo`03001oogoo04Uoo`03001oogoo049oo`03001oogoo09Eoo`03001oogoo03Qo
o`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo01Qoo`00>7oo00<007oo
Ool0BGoo00<007ooOol0@Woo00<007ooOol0UGoo00<007ooOol0>Goo00<007ooOol0:Woo00<007oo
Ool0?Woo00<007ooOol0:Woo00<007ooOol06Goo000hOol2001:Ool00`00Oomoo`12Ool00`00Oomo
o`2EOol2000jOol00`00Oomoo`0ZOol00`00Oomoo`0oOol00`00Oomoo`0YOol00`00Oomoo`0IOol0
03Qoo`03001oogoo04Yoo`03001oogoo041oo`03001oogoo09Ioo`03001oogoo03Yoo`03001oogoo
02Qoo`03001oogoo045oo`03001oogoo02Moo`03001oogoo01Yoo`00>7oo00<007ooOol0BWoo00<0
07ooOol0@7oo00<007ooOol0UWoo00<007ooOol0>goo00<007ooOol09Woo00<007ooOol0@goo00<0
07ooOol09Goo00<007ooOol06goo000hOol00`00Oomoo`1:Ool00`00Oomoo`10Ool00`00Oomoo`2F
Ool00`00Oomoo`0lOol00`00Oomoo`0TOol00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`0L
Ool003Qoo`8004aoo`03001oogoo03ioo`03001oogoo09Moo`8003ioo`8002=oo`03001oogoo04Mo
o`03001oogoo025oo`03001oogoo01eoo`00>7oo00<007ooOol0Bgoo00<007ooOol0?Woo00<007oo
Ool0Ugoo00<007ooOol0?goo00<007ooOol07goo00<007ooOol0BGoo00<007ooOol07goo00<007oo
Ool07Woo000hOol00`00Oomoo`1;Ool00`00Oomoo`0nOol00`00Oomoo`2GOol00`00Oomoo`10Ool0
0`00Oomoo`0MOol00`00Oomoo`1;Ool00`00Oomoo`0MOol00`00Oomoo`0OOol003Qoo`8004eoo`03
001oogoo03aoo`03001oogoo09Qoo`80049oo`03001oogoo01]oo`03001oogoo04eoo`03001oogoo
01]oo`03001oogoo021oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0C7oo00<0
07ooOol0?7oo00<007ooOol0Mgoo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0@Woo00<0
07ooOol067oo0P00DGoo00<007ooOol06Goo00<007ooOol08Goo000FOol01@00Oomoogoo00001Goo
0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo04aoo`03001oogoo03aoo`03001o
ogoo07Ioo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007oo
Ool0@goo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05Woo0P0097oo000FOol01@00Oomo
ogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0CGoo00<007ooOol0>Woo00<0
07ooOol0Mgoo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04Ao
o`8001Eoo`03001oogoo05Aoo`03001oogoo01Aoo`03001oogoo02Aoo`005Woo00D007ooOomoo`00
00ioo`03001oogoo00Moo`03001oogoo009oo`8004ioo`03001oogoo03Yoo`03001oogoo07Moo`05
001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20017Ool00`00Oomoo`0AOol00`00
Oomoo`1FOol3000BOol00`00Oomoo`0UOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool4
0005Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00Oomoo`1gOol01@00Oomoogoo00003goo00<0
07ooOol00Woo10001Goo00<007ooOol0Agoo0P003goo0P00G7oo00<007ooOol03Woo00<007ooOol0
9Woo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0CWoo
00<007ooOol0>7oo00<007ooOol0N7oo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo
00Ioo`03001oogoo04Uoo`03001oogoo00]oo`03001oogoo05eoo`03001oogoo00]oo`8002Uoo`00
5Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001?Ool00`00Oomo
o`0hOol00`00Oomoo`1hOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Io
o`8004]oo`8000Moo`@0065oo`<000Moo`<002]oo`005goo0`003Goo0`001Goo10001Goo00<007oo
Ool0CWoo00<007ooOol0>7oo00<007ooOol0NGoo0`003Goo0`001Goo10001Goo00<007ooOol0C7oo
1`00J7oo1`00;Woo000hOol00`00Oomoo`1?Ool00`00Oomoo`0fOol00`00Oomoo`2KOol00`00Oomo
o`3`Ool003Qoo`03001oogoo04moo`03001oogoo03Ioo`03001oogoo09]oo`03001oogoo0?1oo`00
>7oo0P00D7oo00<007ooOol0=Woo00<007ooOol0Vgoo0P00lGoo000hOol00`00Oomoo`1@Ool00`00
Oomoo`0dOol00`00Oomoo`2LOol00`00Oomoo`3`Ool003Qoo`03001oogoo051oo`03001oogoo03Ao
o`03001oogoo09aoo`03001oogoo0?1oo`00>7oo0P00DGoo00<007ooOol0<goo00<007ooOol0WGoo
0P00lGoo000hOol00`00Oomoo`1AOol00`00Oomoo`0bOol00`00Oomoo`2MOol00`00Oomoo`3`Ool0
03Qoo`03001oogoo055oo`03001oogoo039oo`03001oogoo09eoo`03001oogoo0?1oo`00>7oo00<0
07ooOol0DGoo00<007ooOol0<Goo00<007ooOol0WWoo00<007ooOol0l7oo000hOol2001COol00`00
Oomoo`0`Ool00`00Oomoo`2NOol2003aOol001moo`<000Ioo`8000Eoo`@000Eoo`03001oogoo059o
o`03001oogoo031oo`03001oogoo08Eoo`<000Ioo`8000Eoo`@000Eoo`03001oogoo0?1oo`007Woo
00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo059oo`03001oogoo02moo`03
001oogoo08Eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001io
o`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`0^Ool00`00Oomo
o`25Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0l7oo000NOol01@00Oomoogoo
000047oo00<007ooOol00Woo0P00E7oo00<007ooOol0;Goo00<007ooOol0QWoo00D007ooOomoo`00
011oo`03001oogoo009oo`800?5oo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo05=o
o`03001oogoo02eoo`03001oogoo08Ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3`Ool0
01ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1DOol00`00Oomoo`0/Ool00`00
Oomoo`26Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0l7oo000NOol01@00Oomo
ogoo000037oo00<007ooOol01Woo0P00EGoo00<007ooOol0:goo00<007ooOol0Qgoo00D007ooOomo
o`0000aoo`03001oogoo00Ioo`800?5oo`007goo0`003Goo10001Goo00<007ooOol0E7oo00<007oo
Ool0:goo00<007ooOol0R7oo0`003Goo10001Goo00<007ooOol0l7oo000hOol00`00Oomoo`1EOol0
0`00Oomoo`0ZOol00`00Oomoo`2QOol00`00Oomoo`3`Ool003Qoo`03001oogoo05Eoo`03001oogoo
02Uoo`03001oogoo0:9oo`03001oogoo0?1oo`00>7oo0P00Egoo00<007ooOol0:7oo00<007ooOol0
XWoo0P00lGoo000hOol00`00Oomoo`1FOol00`00Oomoo`0WOol00`00Oomoo`2SOol00`00Oomoo`3`
Ool003Qoo`03001oogoo05Moo`03001oogoo02Ioo`03001oogoo0:=oo`03001oogoo0?1oo`00>7oo
0P00F7oo00<007ooOol09Woo00<007ooOol0Xgoo0P00lGoo000hOol00`00Oomoo`1GOol00`00Oomo
o`0UOol00`00Oomoo`2TOol00`00Oomoo`3`Ool003Qoo`03001oogoo05Qoo`03001oogoo02Aoo`03
001oogoo0:Aoo`03001oogoo0?1oo`00>7oo00<007ooOol0F7oo00<007ooOol097oo00<007ooOol0
Y7oo00<007ooOol0l7oo000hOol2001JOol00`00Oomoo`0ROol00`00Oomoo`2UOol2003aOol001Mo
o`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo05Uoo`03001oogoo029oo`03001o
ogoo08Aoo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007oo
Oomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo05Yoo`03001oogoo
021oo`03001oogoo08Aoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`1JOol00`00Oomoo`0POol00`00Oomoo`24Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo0P00G7oo00<007ooOol07Woo00<007ooOol0QGoo00D007ooOomoo`0000ioo`03
001oogoo00Moo`03001oogoo009oo`800?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=o
o`@000Eoo`03001oogoo05aoo`03001oogoo01aoo`03001oogoo08Ioo`05001oogooOol0000>Ool0
0`00Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`1LOol00`00Oomoo`0LOol00`00Oomoo`26Ool01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo0000
2goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8005ioo`03001oogoo01Yoo`03001oogoo08Mo
o`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00lGoo000GOol3000<
Ool50004Ool40005Ool00`00Oomoo`1MOol00`00Oomoo`0JOol00`00Oomoo`28Ool3000<Ool50004
Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo05ioo`03001oogoo01Qoo`03001oogoo0:Yo
o`03001oogoo0?1oo`00>7oo00<007ooOol0GWoo00<007ooOol067oo00<007ooOol0ZWoo00<007oo
Ool0l7oo000hOol2001POol00`00Oomoo`0FOol00`00Oomoo`2[Ool2003aOol003Qoo`03001oogoo
061oo`03001oogoo01Aoo`03001oogoo0:aoo`03001oogoo0?1oo`00>7oo00<007ooOol0H7oo00<0
07ooOol057oo00<007ooOol0[7oo00<007ooOol0l7oo000hOol2001ROol00`00Oomoo`0BOol00`00
Oomoo`2]Ool2003aOol003Qoo`03001oogoo069oo`03001oogoo011oo`03001oogoo0:ioo`03001o
ogoo0?1oo`00>7oo00<007ooOol0Hgoo00<007ooOol03Woo00<007ooOol0[goo00<007ooOol0l7oo
000hOol00`00Oomoo`1TOol00`00Oomoo`0;Ool2002bOol00`00Oomoo`3`Ool003Qoo`8006Ioo`03
001oogoo00Uoo`03001oogoo0;9oo`800?5oo`00;goo1@0017oo00<007ooOol0IWoo0P0027oo00<0
07ooOol0ZWoo1@0017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`1WOol9002_
Ool00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`8006aoo`800;9oo`03001o
ogoo00Aoo`800?5oo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3o
OolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007oo
Ool0ogoo9goo00<007ooOol0mgoo000_Ool3003oOolWOol3003iOol00?mooomooeIoo`00ogooogoo
EWoo002EOol3000017oo0000000067oo0`00ogoo1goo0`0000Aoo`00000001Uoo`<007Aoo`00UWoo
00D007ooOomoo`0000Uoo`H000Uoo`05001oogooOol0003oOol7Ool01@00Oomoogoo00002Goo1P00
37oo00<007ooOol0Lgoo002FOol01@00Oomoogoo000077oo00<007ooOol0ogoo1Goo00D007ooOomo
o`0001Qoo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000eoo`03001oogoo0?moo`Eoo`05001o
ogooOol00009Ool60009Ool01000Oomoo`00MGoo002FOol01@00Oomoogoo00006Woo0P00ogoo27oo
00D007ooOomoo`0001Uoo`03001oo`0007Eoo`00UGoo1@007Goo00<007ooOol0ogoo17oo1@006Woo
00<007oo0000MGoo002cOol01@00Oomoogoo0000ogoo9Woo0P00MGoo002dOol3003oOolXOol00`00
Oomoo`1cOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3g
Ool002Ioo`H000Eoo`03001oogoo0?mooaaoo`H000Eoo`03001oogoo0?Moo`00<Goo00<007ooOol0
17oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolP
Ool00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03
001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo
0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2
003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<0
07ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`03001oogoo0?aoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003o
Ool6Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00lGoo000FOol01@00
Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000io
o`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomo
o`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Ao
o`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0;goo2P00]goo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`0/Ool3000:Ool4002cOol003Qoo`03001oogoo0?moobMoo`03001oogoo02Qo
o`@0015oo`@00:moo`00>7oo0P00ogoo:7oo0P009Woo0`006Goo0`00[7oo000OOol30006Ool20005
Ool40005Ool00`00Oomoo`3oOol>Ool30006Ool20005Ool40005Ool00`00Oomoo`0SOol2000OOol0
0`00Oomoo`2YOol001ioo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3o
Ool=Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol08Woo00<007ooOol0
87oo00<007ooOol0Z7oo000FOol60002Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00ogoo
1Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`80025oo`8002Aoo`800:Qoo`007Woo
00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool0
0`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`0VOol00`00Oomoo`2UOol001ioo`05001oogoo
Ool0000<Ool40005Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0
7Woo00<007ooOol0:7oo0P00YGoo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007oo
Ool0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo01aoo`8002eoo`03001o
ogoo0:9oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?moo`ioo`05001oogooOol0
000<Ool00`00Oomoo`06Ool2000LOol00`00Oomoo`0^Ool2002ROol001moo`<000eoo`@000Eoo`03
001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo01Yoo`03001oogoo035oo`03001oogoo09mo
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol067oo0P00=Goo00<007ooOol0WWoo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`0GOol00`00Oomoo`0fOol00`00Oomoo`2MOol003Qoo`800?moobQo
o`8001Moo`03001oogoo03Qoo`03001oogoo09aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
5Goo00<007ooOol0>Woo00<007ooOol0Vgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0DOol0
0`00Oomoo`0lOol00`00Oomoo`2JOol003Qoo`800?moobQoo`8001Aoo`03001oogoo03ioo`03001o
ogoo09Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol04Woo00<007ooOol0@7oo00<007ooOol0
V7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0AOol00`00Oomoo`12Ool00`00Oomoo`2GOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo011oo`03001oogoo04Aoo`03001oogoo09Ioo`00>7oo
0P00ogoo:7oo0P0047oo00<007ooOol0AWoo00<007ooOol0UGoo000GOol30006Ool20004Ool50004
Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`0?Ool0
0`00Oomoo`17Ool00`00Oomoo`2DOol001Ioo`05001oogooOol00005Ool20005Ool01000Oomoo`00
27oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo
0008Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`19Ool00`00Oomoo`2COol000ioo`H0
009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2003mOol60002Ool01@00
Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P003Woo00<007ooOol0Bgoo00<007oo
Ool0TWoo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00aoo`03
001oogoo04eoo`03001oogoo095oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eo
o`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`0;
Ool00`00Oomoo`1?Ool00`00Oomoo`2@Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol02Woo00<007ooOol0DGoo00<007ooOol0Sgoo000FOol01@00Oomoogoo0000
2goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00
Oomoogoo000017oo00<007ooOol01Woo0P002goo00<007ooOol0DWoo00<007ooOol0SWoo000GOol3
000=Ool30005Ool40005Ool00`00Oomoo`3oOol6Ool3000=Ool30005Ool40005Ool00`00Oomoo`09
Ool00`00Oomoo`1DOol00`00Oomoo`2=Ool003Qoo`03001oogoo01moo`<000Ioo`8000Aoo`D001Qo
o`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<001Yoo`<000Ioo`8000Eoo`<0025oo`D004Uo
o`03001oogoo00Qoo`03001oogoo01Aoo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<0009o
o`03001oogoo01=oo`<000Ioo`8000Eoo`<001Uoo`<000Ioo`8000Eoo`<0025oo`D001Aoo`00>7oo
0P007goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomoogoo00001Goo0P00
1goo00<007ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000HOol01@00Oomo
ogoo00001Goo0P0017oo00D007ooOomoo`00029oo`03001oogoo04Uoo`8000Qoo`03001oogoo01Ao
o`05001oogooOol00005Ool20005Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03
001oogoo009oo`03001oogoo015oo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00005goo
00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001o
ogoo01ioo`05001oogooOol0000=Ool00`00Oomoo`0GOol01@00Oomoogoo00002goo1@005goo00D0
07ooOomoo`0000]oo`05001oogooOol0000HOol01@00Oomoogoo00002goo00D007ooOomoo`00029o
o`03001oogoo04Uoo`03001oogoo00Ioo`03001oogoo01Eoo`05001oogooOol0000=Ool00`00Oomo
o`0GOol01@00Oomoogoo00002goo1@000goo00<007ooOol04Goo00D007ooOomoo`0000]oo`05001o
ogooOol0000GOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo
00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000
Oomoo`0067oo00D007ooOomoo`0000]oo`05001oogooOol0000HOol01@00Oomoogoo00002goo00D0
07ooOomoo`00029oo`03001oogoo04Uoo`03001oogoo00Ioo`03001oogoo01Eoo`05001oogooOol0
000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol000Eoo`03001oogoo011oo`05
001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000]oo`05001oogooOol0000R
Ool00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol0
1@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`0000]oo`@001Uoo`05001oogooOol0
000<Ool3000SOol00`00Oomoo`19Ool00`00Oomoo`05Ool00`00Oomoo`0FOol01@00Oomoogoo0000
3goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0000Ioo`03001oogoo00moo`05001o
ogooOol0000;Ool4000HOol01@00Oomoogoo000037oo0`008goo00<007ooOol057oo000hOol2000O
Ool01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05
001oogooOol0000;Ool00`00Oomoo`0JOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03
001oogoo04Uoo`8000Eoo`03001oogoo01Moo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00
Oomoogoo000037oo00<007oo00001goo00<007ooOol03Woo00D007ooOomoo`0000]oo`03001oogoo
01Uoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomo
o`0NOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000=Ool2000HOol0
1@00Oomoogoo000037oo00<007ooOol06Goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol0
0`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Moo`05001oogooOol0000=Ool20008Ool00`00Oomoo`0=Ool01@00Oomoogoo000037oo00<0
07ooOol067oo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03
001oogoo01moo`<000eoo`<001Uoo`<000moo`03001oogoo01Moo`<000ioo`<001Uoo`<000eoo`<0
025oo`<004]oo`03001oogoo009oo`03001oogoo01Yoo`<000eoo`<001Uoo`<000moo`03001oogoo
00Moo`03001oogoo00eoo`<000ioo`<001Qoo`<000eoo`<0025oo`<001Ioo`00>7oo00<007ooOol0
ogoo9goo00D007ooOomoo`0006Eoo`03001oogoo08Ioo`00>7oo0P00ogoo:7oo0P0000=oo`00Ool0
IWoo00<007ooOol0QGoo000hOol00`00Oomoo`3oOolWOol00`00Ool0001YOol00`00Oomoo`24Ool0
03Qoo`03001oogoo0?moobMoo`8006]oo`03001oogoo08=oo`00<Wooj@00@7ooj@0047oo000hOol0
1000Ool000001goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol01Goo
0P0000=oo`00Ool0BWoo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol057oo000hOol01000Oomoogoo0`009Goo00<007ooOol0:Goo
00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol08goo0`000goo00<007ooOol0BGoo00<007oo
Ool0:Goo00<007ooOol0:Goo00<007ooOol057oo00<007ooOol04Woo00<007ooOol0:Goo00<007oo
Ool0:Goo00<007ooOol057oo000hOol00`00Oomoo`04Ool2003<Ool2001BOol00`00Oomoo`1]Ool0
0`00Oomoo`1XOol00`00Oomoo`0EOol003Qoo`8000Moo`800<Qoo`8005Aoo`8006moo`03001oogoo
06Ioo`03001oogoo01Ioo`00>7oo00<007ooOol027oo0P00a7oo0P00EWoo00<007ooOol0Kgoo00<0
07ooOol0I7oo00<007ooOol05goo000hOol00`00Oomoo`0:Ool20030Ool2001HOol00`00Oomoo`1`
Ool00`00Oomoo`1ROol00`00Oomoo`0HOol003Qoo`8000eoo`800;aoo`8005Yoo`80075oo`03001o
ogoo065oo`03001oogoo01Uoo`00>7oo00<007ooOol03Woo0P00^7oo0P00G7oo00<007ooOol0LGoo
00<007ooOol0Ggoo00<007ooOol06Woo000hOol00`00Oomoo`0@Ool2002dOol2001NOol00`00Oomo
o`1bOol00`00Oomoo`1MOol00`00Oomoo`0KOol003Qoo`03001oogoo019oo`800;1oo`80061oo`03
001oogoo07=oo`03001oogoo05]oo`03001oogoo01aoo`00>7oo0P005Goo0`00ZWoo0`00HWoo0P00
MGoo00<007ooOol0FGoo00<007ooOol07Goo000hOol00`00Oomoo`0GOol2002VOol2001UOol00`00
Oomoo`1eOol00`00Oomoo`1HOol00`00Oomoo`0MOol003Qoo`03001oogoo01Uoo`<00:5oo`8006Mo
o`03001oogoo07Ioo`03001oogoo05Ioo`03001oogoo01ioo`00>7oo00<007ooOol077oo0`00Vgoo
0`00JGoo00<007ooOol0Mgoo00<007ooOol0E7oo00<007ooOol07goo000hOol2000POol3002EOol3
001/Ool2001iOol00`00Oomoo`1BOol00`00Oomoo`0POol001Moo`<000Ioo`8000Aoo`D000Aoo`@0
00Eoo`03001oogoo029oo`80091oo`<004ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo
07Uoo`03001oogoo051oo`03001oogoo025oo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001o
ogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`0TOol2002<Ool2001@Ool01@00Oomoogoo00001Goo
0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo07Yoo`03001oogoo04ioo`03001o
ogoo029oo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8002Moo`<0
08Ioo`<0059oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2001lOol00`00
Oomoo`1<Ool00`00Oomoo`0SOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`0YOol20022Ool2001EOol01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol0O7oo00<007ooOol0BWoo00<007ooOol097oo000FOol01@00Oomoogoo
00003goo00<007ooOol00Woo10001Goo00<007ooOol0:goo0`00OGoo0P00Egoo00D007ooOomoo`00
00moo`03001oogoo009oo`@000Eoo`03001oogoo07eoo`03001oogoo04Qoo`03001oogoo02Eoo`00
5Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo02ioo`<007Mo
o`<005Uoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`1nOol0
0`00Oomoo`15Ool2000XOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P00<Woo0`00LGoo0`00G7oo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool20020Ool00`00Oomoo`13Ool00`00Oomoo`0XOol001Moo`<000eoo`<000Eoo`@000Eo
o`03001oogoo03Aoo`<006Yoo`@0061oo`<000eoo`<000Eoo`@000Eoo`03001oogoo081oo`03001o
ogoo045oo`03001oogoo02Uoo`00>7oo00<007ooOol0=goo0`00I7oo0`00QGoo00<007ooOol0PGoo
00<007ooOol0?goo00<007ooOol0:Woo000hOol2000kOol3001NOol30028Ool20023Ool00`00Oomo
o`0mOol00`00Oomoo`0[Ool003Qoo`03001oogoo03eoo`@005Ioo`@008]oo`03001oogoo08=oo`03
001oogoo03]oo`03001oogoo02aoo`00>7oo00<007ooOol0@Goo1@00CGoo1000Sgoo00<007ooOol0
Q7oo00<007ooOol0>Goo00<007ooOol0;Goo000hOol00`00Oomoo`16Ool40015Ool4002COol00`00
Oomoo`25Ool00`00Oomoo`0gOol00`00Oomoo`0^Ool003Qoo`8004]oo`D003]oo`D009Moo`8008Mo
o`03001oogoo03Eoo`03001oogoo02moo`00>7oo00<007ooOol0Cgoo1000<Woo1@00W7oo00<007oo
Ool0Qgoo0P00<goo0P00<Woo000hOol00`00Oomoo`1COol5000XOol5002QOol00`00Oomoo`29Ool0
0`00Oomoo`0_Ool00`00Oomoo`0bOol003Qoo`8005Uoo``000moo`d00:Ioo`8008]oo`03001oogoo
02eoo`03001oogoo03=oo`00>7oo00<007ooOol0I7oo3`00/goo00<007ooOol0Rgoo0P00;7oo00<0
07ooOol0=7oo000OOol30006Ool20005Ool40005Ool00`00Oomoo`3oOol>Ool30006Ool20005Ool4
0005Ool00`00Oomoo`2=Ool00`00Oomoo`0XOol00`00Oomoo`0eOol001ioo`05001oogooOol00005
Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol00Woo00<007ooOol0SWoo00<007ooOol09Woo00<007ooOol0=Woo000NOol01@00Oomoogoo
000047oo00<007ooOol00Woo0P00ogoo3Woo00D007ooOomoo`00011oo`03001oogoo009oo`80091o
o`03001oogoo02Aoo`03001oogoo03Moo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03
001oogoo0?moo`eoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`2@Ool2000ROol2
000jOol001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo0000
37oo10001Goo00<007ooOol0TWoo0`0077oo0`00?7oo000NOol01@00Oomoogoo000037oo00<007oo
Ool01Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo09Eo
o`8001Qoo`8003moo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?moo`ioo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool2002HOol2000DOol20011Ool001moo`<000eoo`@000Eoo`03
001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo09Uoo`<000ioo`<004=oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0W7oo3P00AWoo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`800?5oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`00
1Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo
0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eo
o`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`005Woo00D007ooOomoo`00
00ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P00lGoo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007oo
Ool0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo
00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Moo`<000aoo`D0
00Aoo`@000Eoo`800?moo`Moo`<000aoo`D000Aoo`@000Eoo`800?5oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00
lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000_Ool50004Ool00`00Oomoo`3oOolNOol50004Ool0
0`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001o
ogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0
l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001oogoo
0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00
Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOooo
OomFOol009Eoo`<00004Ool00000000HOol5003oOol5Ool3000017oo000000005goo1@00M7oo002F
Ool01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H000Yo
o`04001oogoo001dOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo
00006Woo00<007ooOol0M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo
00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001]oo`03001o
ogoo0?moo`Ioo`05001oogooOol0000LOol00`00Oomoo`1bOol009Eoo`D001aoo`03001oogoo0?mo
o`Eoo`D001eoo`03001oogoo079oo`00]Woo00<007ooOol0ogoo8goo00D007ooOomoo`0007Aoo`00
]7oo0`00ogoo9Woo0`00MGoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomF
Ool00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .19937 L
.08255 .14763 L
.10458 .09833 L
.12507 .06139 L
.14415 .03608 L
.14918 .03099 L
.15465 .02625 L
.15946 .02275 L
.16457 .01976 L
.16917 .01769 L
.17178 .01679 L
.17423 .01612 L
.17538 .01586 L
.17647 .01565 L
.17746 .01549 L
.17852 .01536 L
.17967 .01524 L
.18073 .01517 L
.182 .01513 L
.18314 .01513 L
.18435 .01517 L
.18547 .01525 L
.1867 .01537 L
.18802 .01556 L
.19071 .01609 L
.19317 .01675 L
.1979 .01852 L
.20239 .02078 L
.21236 .02783 L
.22321 .03861 L
.24299 .06615 L
.26399 .10554 L
.30174 .19697 L
.34195 .31099 L
.38063 .42063 L
.40028 .47106 L
.42177 .51916 L
.44253 .55666 L
.4614 .58173 L
.47149 .59129 L
.47611 .59474 L
.48101 .59773 L
.4835 .599 L
.48624 .60019 L
.48876 .60109 L
.49106 .60176 L
.49378 .60235 L
.49527 .60259 L
.49596 .60267 L
Mistroke
.49669 .60275 L
.498 .60285 L
.49921 .6029 L
.49996 .60291 L
.50065 .6029 L
.50196 .60285 L
.50313 .60277 L
.50438 .60263 L
.50556 .60247 L
.50663 .60228 L
.50926 .60168 L
.51175 .60093 L
.5167 .59891 L
.52208 .59592 L
.53169 .58858 L
.54056 .57955 L
.55926 .5538 L
.57988 .51577 L
.62014 .41855 L
.65888 .30859 L
.70007 .19212 L
.72063 .14003 L
.73974 .09784 L
.75939 .06234 L
.77791 .03735 L
.78775 .02774 L
.79293 .02374 L
.7984 .02034 L
.80302 .01812 L
.80546 .01719 L
.80809 .01639 L
.8105 .01582 L
.8127 .01545 L
.81375 .01532 L
.81491 .01522 L
.81599 .01516 L
.817 .01513 L
.81818 .01513 L
.81941 .01518 L
.82047 .01525 L
.82163 .01537 L
.82287 .01555 L
.82421 .01578 L
.82661 .01633 L
.82905 .01705 L
.83134 .01789 L
.83564 .01987 L
.84078 .02292 L
.84552 .02638 L
.85624 .0365 L
Mistroke
.87498 .06146 L
.89561 .09871 L
.93591 .19496 L
.97471 .3047 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .18702 L
.08255 .13407 L
.0932 .1108 L
.10458 .09023 L
.11009 .08202 L
.11531 .07535 L
.12038 .06993 L
.12507 .06587 L
.12951 .06288 L
.13178 .06168 L
.13422 .06064 L
.13549 .0602 L
.13666 .05985 L
.13784 .05956 L
.13895 .05935 L
.14022 .05917 L
.1409 .0591 L
.14161 .05905 L
.1423 .05902 L
.14295 .05902 L
.14415 .05905 L
.14531 .05915 L
.14656 .05932 L
.14773 .05953 L
.14881 .05979 L
.15143 .06061 L
.15392 .06167 L
.15886 .06457 L
.16423 .06889 L
.17383 .0796 L
.1827 .09278 L
.20137 .12989 L
.22197 .18329 L
.26217 .3099 L
.30086 .43193 L
.32051 .48363 L
.3309 .50645 L
.342 .52672 L
.35275 .54191 L
.35784 .54748 L
.36253 .55166 L
.36724 .55494 L
.36972 .55628 L
.37235 .55741 L
.37463 .55815 L
.37573 .55842 L
.37677 .55864 L
.37799 .55883 L
.37911 .55894 L
Mistroke
.38031 .55901 L
.38162 .55901 L
.38227 .55898 L
.38296 .55893 L
.38419 .55879 L
.38551 .55857 L
.38695 .55823 L
.38955 .55741 L
.39197 .55638 L
.39649 .55378 L
.40134 .55003 L
.40698 .54442 L
.41232 .53791 L
.42232 .52269 L
.44227 .48156 L
.4607 .43291 L
.50002 .30895 L
.53782 .18936 L
.55884 .13385 L
.56803 .11355 L
.57808 .09466 L
.58722 .08075 L
.59696 .06956 L
.60236 .06505 L
.60726 .06204 L
.60962 .06095 L
.61086 .06047 L
.61218 .06004 L
.61333 .05973 L
.61459 .05945 L
.61574 .05925 L
.61682 .05913 L
.61808 .05904 L
.61871 .05902 L
.61941 .05902 L
.62065 .05907 L
.62181 .05918 L
.62248 .05927 L
.62318 .05939 L
.62443 .05965 L
.62578 .06 L
.62725 .06048 L
.62973 .0615 L
.63238 .06287 L
.63715 .06611 L
.64214 .07053 L
.64686 .07566 L
.6557 .08768 L
.67568 .12564 L
.69413 .17199 L
Mistroke
.7335 .29387 L
.77136 .41524 L
.79241 .47323 L
.81166 .51534 L
.82118 .53139 L
.8262 .53847 L
.83155 .5449 L
.8367 .54998 L
.84136 .55361 L
.84361 .55504 L
.84604 .55634 L
.84835 .55734 L
.85045 .55804 L
.85159 .55835 L
.85283 .55861 L
.85414 .55882 L
.85538 .55895 L
.85653 .55901 L
.85776 .55901 L
.85881 .55896 L
.85997 .55884 L
.86063 .55875 L
.86132 .55864 L
.86256 .55838 L
.86535 .55755 L
.86777 .55656 L
.87041 .5552 L
.87569 .55157 L
.88133 .5464 L
.89148 .5338 L
.90173 .51699 L
.91284 .49449 L
.933 .44391 L
.97393 .31646 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .3321 L
.10458 .35684 L
.14415 .37924 L
.18221 .39966 L
.22272 .41982 L
.26171 .43737 L
.30316 .45369 L
.34309 .46686 L
.3815 .47695 L
.40095 .48104 L
.42237 .48473 L
.44268 .48742 L
.45178 .48836 L
.46172 .48921 L
.4671 .48958 L
.4721 .48988 L
.47727 .49014 L
.48196 .49033 L
.48658 .49047 L
.4887 .49053 L
.49093 .49057 L
.49332 .49061 L
.49438 .49062 L
.49552 .49063 L
.49675 .49064 L
.49789 .49065 L
.49859 .49065 L
.49925 .49065 L
.50049 .49065 L
.50163 .49065 L
.50286 .49064 L
.50401 .49064 L
.50508 .49063 L
.50754 .4906 L
.51014 .49055 L
.51268 .49049 L
.51504 .49043 L
.5204 .49024 L
.5293 .4898 L
.53882 .48917 L
.54906 .48828 L
.56016 .48709 L
.58032 .48432 L
.62123 .47632 L
.66064 .46574 L
.69852 .45308 L
.73886 .43713 L
.77769 .41963 L
.81897 .39905 L
Mistroke
.85873 .37765 L
.89697 .35594 L
.93767 .33204 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28494 L
.10458 .26051 L
.14415 .24092 L
.18221 .22642 L
.20178 .22094 L
.21267 .21852 L
.22272 .2167 L
.23293 .21526 L
.23832 .21468 L
.24402 .21419 L
.24641 .21402 L
.24897 .21387 L
.25119 .21376 L
.25361 .21367 L
.25507 .21362 L
.25643 .21359 L
.25773 .21356 L
.2584 .21355 L
.25912 .21354 L
.25983 .21353 L
.26048 .21353 L
.26176 .21353 L
.26293 .21353 L
.26416 .21354 L
.26538 .21355 L
.26607 .21356 L
.26671 .21357 L
.26912 .21363 L
.27131 .21371 L
.27364 .21381 L
.27847 .2141 L
.2838 .21452 L
.29326 .21556 L
.30213 .21687 L
.32232 .22101 L
.34082 .22618 L
.38045 .24127 L
.41855 .26014 L
.45912 .28357 L
.49816 .30786 L
.53966 .33372 L
.57964 .35691 L
.61811 .37612 L
.63759 .38428 L
.65902 .39181 L
.67938 .39743 L
.69843 .40126 L
.70884 .40273 L
.71396 .4033 L
Mistroke
.71872 .40373 L
.72301 .40404 L
.72758 .40428 L
.7302 .40438 L
.73148 .40442 L
.73266 .40445 L
.73371 .40447 L
.73487 .40449 L
.73603 .4045 L
.73725 .40451 L
.73856 .40451 L
.73977 .4045 L
.7404 .4045 L
.7411 .40449 L
.74251 .40447 L
.74375 .40444 L
.74508 .40441 L
.74748 .40433 L
.74985 .40422 L
.75235 .40409 L
.7568 .40378 L
.76198 .40332 L
.7668 .4028 L
.77773 .40126 L
.78828 .39932 L
.79823 .39709 L
.81683 .39191 L
.85534 .37734 L
.89632 .35704 L
.93577 .33418 L
.97371 .31058 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P0087oo1`00
Rgoo2000IWoo00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`0LOol30007Ool20028
Ool00`00Oomoo`06Ool2001ROol30006Ool00`00Oomoo`3`Ool003Qoo`03001oogoo01]oo`03001o
ogoo00Yoo`03001oogoo08Aoo`03001oogoo00Uoo`03001oogoo06Qoo`03001oogoo0?1oo`00>7oo
0P006goo00<007ooOol037oo00<007ooOol0PWoo00<007ooOol02goo00<007ooOol0Igoo0P00lGoo
000hOol00`00Oomoo`0JOol00`00Oomoo`0=Ool00`00Oomoo`20Ool00`00Oomoo`0=Ool00`00Oomo
o`1VOol00`00Oomoo`3`Ool003Qoo`03001oogoo01Uoo`03001oogoo00moo`03001oogoo07ioo`03
001oogoo00moo`03001oogoo06Eoo`03001oogoo0?1oo`00>7oo00<007ooOol067oo00<007ooOol0
47oo00<007ooOol0OWoo00<007ooOol03goo00<007ooOol0IGoo00<007ooOol0l7oo000hOol2000H
Ool00`00Oomoo`0BOol00`00Oomoo`1lOol00`00Oomoo`0AOol00`00Oomoo`1TOol2003aOol003Qo
o`03001oogoo01Ioo`03001oogoo01Aoo`03001oogoo07Yoo`03001oogoo01=oo`03001oogoo06=o
o`03001oogoo0?1oo`00>7oo00<007ooOol05Goo00<007ooOol05Woo00<007ooOol0N7oo00<007oo
Ool05Goo00<007ooOol0HWoo00<007ooOol0l7oo000hOol00`00Oomoo`0DOol00`00Oomoo`0GOol0
0`00Oomoo`1gOol00`00Oomoo`0GOol00`00Oomoo`1QOol00`00Oomoo`0FOol6001YOol5001VOol0
03Qoo`8001Eoo`03001oogoo01Qoo`03001oogoo07Eoo`03001oogoo01Qoo`03001oogoo065oo`80
01Eoo`8000Ioo`03001oogoo06Aoo`8000Eoo`03001oogoo06=oo`005goo0`001Woo0P001Woo00<0
07ooOol017oo10001Goo00<007ooOol04goo00<007ooOol06Woo00<007ooOol0M7oo00<007ooOol0
6Goo00<007ooOol0?goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol04goo00<0
07ooOol01goo00<007ooOol0HWoo00<007ooOol01Woo00<007ooOol0HWoo000FOol01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol04goo00<007ooOol06Woo
00<007ooOol0Lgoo00<007ooOol06Woo00<007ooOol0?Woo00D007ooOomoo`0000Eoo`8000Ioo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo061oo`03
001oogoo00Qoo`03001oogoo065oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`8001=oo`03001oogoo01aoo`03001oogoo079oo`03001oogoo01]oo`03001o
ogoo03Eoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000COol0
0`00Oomoo`0:Ool00`00Oomoo`1NOol00`00Oomoo`0:Ool00`00Oomoo`1POol001Ioo`05001oogoo
Ool0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`0LOol00`00
Oomoo`1aOol00`00Oomoo`0MOol00`00Oomoo`0lOol01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol04Goo00<007ooOol037oo00<007ooOol0G7oo00<007ooOol02goo
00<007ooOol0H7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0
4Woo00<007ooOol07Goo00<007ooOol0L7oo00<007ooOol07Goo00<007ooOol0?7oo00D007ooOomo
o`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo011oo`03001oogoo00eoo`03001oogoo05ao
o`03001oogoo00aoo`03001oogoo05moo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo015oo`03001oogoo01moo`03001oogoo06ioo`03001oogoo01moo`03
001oogoo03]oo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0?
Ool00`00Oomoo`0?Ool00`00Oomoo`1JOol00`00Oomoo`0>Ool00`00Oomoo`1NOol001Ioo`05001o
ogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P004Woo00<007ooOol07goo00<0
07ooOol0KWoo00<007ooOol07goo00<007ooOol0>goo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool2000@Ool00`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0?Ool0
0`00Oomoo`1NOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo011oo`03001oogoo025oo`03
001oogoo06aoo`03001oogoo025oo`03001oogoo03]oo`<000aoo`D000Aoo`@000Eoo`03001oogoo
00ioo`03001oogoo015oo`03001oogoo05Qoo`03001oogoo011oo`03001oogoo05eoo`00>7oo00<0
07ooOol047oo00<007ooOol08Goo00<007ooOol0K7oo00<007ooOol08Goo00<007ooOol0G7oo00<0
07ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0G7oo000h
Ool2000@Ool00`00Oomoo`0SOol00`00Oomoo`1ZOol00`00Oomoo`0SOol00`00Oomoo`1KOol2000?
Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol00`00Oomoo`1LOol003Qoo`03001o
ogoo00moo`03001oogoo02=oo`03001oogoo06Yoo`03001oogoo02=oo`03001oogoo05]oo`03001o
ogoo00eoo`03001oogoo01Aoo`03001oogoo05Eoo`03001oogoo01=oo`03001oogoo05]oo`00>7oo
00<007ooOol03Woo00<007ooOol09Goo00<007ooOol0J7oo00<007ooOol097oo00<007ooOol0Fgoo
00<007ooOol03Goo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol057oo00<007ooOol0Fgoo
000hOol00`00Oomoo`0>Ool00`00Oomoo`0UOol00`00Oomoo`1XOol00`00Oomoo`0UOol00`00Oomo
o`1JOol00`00Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomoo`1COol00`00Oomoo`0EOol00`00Oomo
o`1JOol003Qoo`8000ioo`03001oogoo02Ioo`03001oogoo06Moo`03001oogoo02Ioo`03001oogoo
05Yoo`8000aoo`03001oogoo01Moo`03001oogoo059oo`03001oogoo01Moo`03001oogoo05Uoo`00
>7oo00<007ooOol03Goo00<007ooOol09goo00<007ooOol0IWoo00<007ooOol09goo00<007ooOol0
FGoo00<007ooOol02goo00<007ooOol067oo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol0
FGoo000hOol00`00Oomoo`0=Ool00`00Oomoo`0WOol00`00Oomoo`1UOol00`00Oomoo`0XOol00`00
Oomoo`1IOol00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00
Oomoo`1HOol003Qoo`8000eoo`03001oogoo02Qoo`03001oogoo06Eoo`03001oogoo02Qoo`03001o
ogoo05Uoo`8000]oo`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo05Qo
o`007goo0`001Woo0P001Goo10001Goo00<007ooOol037oo00<007ooOol0:Goo00<007ooOol0Hgoo
00<007ooOol0:Woo00<007ooOol0?goo0`001Woo0P001Goo10001Goo00<007ooOol02Woo00<007oo
Ool06Woo00<007ooOol0CWoo00<007ooOol06Woo00<007ooOol0F7oo000NOol01@00Oomoogoo0000
1Goo0P002Goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol0:Woo00<007ooOol0Hgoo00<0
07ooOol0:Woo00<007ooOol0?Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001o
ogoo00Uoo`03001oogoo01]oo`03001oogoo04ioo`03001oogoo01]oo`03001oogoo05Moo`005Woo
1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo00]oo`03001oogoo02]oo`03
001oogoo065oo`03001oogoo02aoo`03001oogoo03Eoo`H0009oo`05001oogooOol0000@Ool00`00
Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0LOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00
Oomoo`1GOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000;Ool00`00Oomoo`0/Ool0
0`00Oomoo`1QOol00`00Oomoo`0/Ool00`00Oomoo`0mOol01@00Oomoogoo000047oo00<007ooOol0
0Woo0P002Woo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol0Egoo000N
Ool01@00Oomoogoo000037oo10001Goo00<007ooOol02Woo00<007ooOol0;7oo00<007ooOol0HGoo
00<007ooOol0;Goo00<007ooOol0?7oo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo00Qoo`03
001oogoo01ioo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo05Ioo`007Woo00D007ooOomo
o`0000aoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo02eoo`03001oogoo05moo`03001o
ogoo02ioo`03001oogoo03aoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`1FOol001ioo`05001oogoo
Ool0000<Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0^Ool00`00Oomoo`1OOol00`00
Oomoo`0^Ool00`00Oomoo`0lOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol027oo
00<007ooOol07Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000OOol3000=Ool4
0005Ool2000:Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool00`00Oomoo`0lOol3
000=Ool40005Ool20008Ool00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomo
o`1EOol003Qoo`03001oogoo00Qoo`03001oogoo031oo`03001oogoo05eoo`03001oogoo031oo`03
001oogoo05Eoo`03001oogoo00Moo`03001oogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03
001oogoo05Eoo`00>7oo00<007ooOol027oo00<007ooOol0<7oo00<007ooOol0GGoo00<007ooOol0
<Goo00<007ooOol0E7oo00<007ooOol01goo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol0
87oo00<007ooOol0EGoo000hOol20008Ool00`00Oomoo`0bOol00`00Oomoo`1LOol00`00Oomoo`0a
Ool00`00Oomoo`1DOol20007Ool00`00Oomoo`0ROol00`00Oomoo`17Ool00`00Oomoo`0QOol00`00
Oomoo`1DOol003Qoo`03001oogoo00Moo`03001oogoo039oo`03001oogoo05]oo`03001oogoo039o
o`03001oogoo05Aoo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo04Ioo`03001oogoo029o
o`03001oogoo05Aoo`00>7oo00<007ooOol01goo00<007ooOol0<Woo00<007ooOol0Fgoo00<007oo
Ool0<goo00<007ooOol0Dgoo00<007ooOol01Woo00<007ooOol08Woo00<007ooOol0AWoo00<007oo
Ool08Woo00<007ooOol0E7oo000hOol00`00Oomoo`06Ool00`00Oomoo`0dOol00`00Oomoo`1JOol0
0`00Oomoo`0cOol00`00Oomoo`1COol00`00Oomoo`06Ool00`00Oomoo`0SOol00`00Oomoo`15Ool0
0`00Oomoo`0SOol00`00Oomoo`1COol003Qoo`8000Moo`03001oogoo03Aoo`03001oogoo05Uoo`03
001oogoo03Eoo`03001oogoo059oo`8000Ioo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo
02Aoo`03001oogoo05=oo`00>7oo00<007ooOol01Goo00<007ooOol0=Woo00<007ooOol0F7oo00<0
07ooOol0=Goo00<007ooOol0DWoo00<007ooOol01Goo00<007ooOol097oo00<007ooOol0A7oo00<0
07ooOol097oo00<007ooOol0Dgoo000hOol00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`1H
Ool00`00Oomoo`0eOol00`00Oomoo`1BOol00`00Oomoo`05Ool00`00Oomoo`0UOol00`00Oomoo`13
Ool00`00Oomoo`0UOol00`00Oomoo`1BOol003Qoo`8000Ioo`03001oogoo03Ioo`03001oogoo05Mo
o`03001oogoo03Moo`03001oogoo055oo`8000Eoo`03001oogoo02Ioo`03001oogoo049oo`03001o
ogoo02Ioo`03001oogoo059oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol017oo
00<007ooOol0>7oo00<007ooOol0EWoo00<007ooOol0=goo00<007ooOol0<7oo0`001Woo0P0017oo
1@0017oo10001Goo00<007ooOol017oo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo
00<007ooOol0DWoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo
009oo`03001oogoo00Aoo`03001oogoo03Qoo`03001oogoo05Ioo`03001oogoo03Moo`03001oogoo
02moo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol09goo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol0DGoo000>Ool60002
Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool0>Goo00<007ooOol0E7oo00<007ooOol0>Goo00<007ooOol09Woo1P000Woo00D007ooOomoo`00
00eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo
041oo`03001oogoo02Qoo`03001oogoo055oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`8000Aoo`03001oogoo03Yoo`03001oogoo05Aoo`03001oogoo03Uoo`03001o
ogoo02ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20004Ool00`00Oomo
o`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`1AOol001Ioo`05001oogooOol0000?
Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`03Ool00`00Oomoo`0jOol00`00Oomoo`1COol00`00
Oomoo`0jOol00`00Oomoo`0^Ool01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007oo
Ool00goo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol0D7oo000FOol0
1@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0
>goo00<007ooOol0DWoo00<007ooOol0>goo00<007ooOol0;Goo00D007ooOomoo`0000moo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03ioo`03001o
ogoo02Yoo`03001oogoo051oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool20003Ool00`00Oomoo`0lOol00`00Oomoo`1BOol00`00Oomoo`0kOol00`00Oomoo`0]
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000=oo`03001oogoo
02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo051oo`005goo0`003Goo0`001Goo1000
1Goo00<007ooOol00Woo00<007ooOol0?7oo00<007ooOol0DGoo00<007ooOol0?7oo00<007ooOol0
;Woo0`003Goo0`001Goo10001Goo00<007ooOol00Woo00<007ooOol0:goo00<007ooOol0?Goo00<0
07ooOol0:goo00<007ooOol0Cgoo000hOol00`00Oomoo`02Ool00`00Oomoo`0mOol00`00Oomoo`1@
Ool00`00Oomoo`0mOol00`00Oomoo`1>Ool01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007oo
Ool0;7oo00<007ooOol0Cgoo000hOol01@00Oomoogoo00007Goo0`001Woo0P0017oo1@003goo00<0
07ooOol01Woo0`001Woo0P001Woo0`0067oo0`001Woo0P001Goo0`002goo00<007ooOol037oo0`00
1Woo0P001Goo0`007Woo00<007ooOol01@00BGoo00D007ooOomoo`0001eoo`<000Ioo`8000Aoo`D0
01Qoo`<000Ioo`8000Ioo`<0011oo`03001oogoo00Eoo`<000Ioo`8000Eoo`<001Aoo`03001oogoo
009oo`<000Ioo`8000Eoo`<0025oo`D001Aoo`00>7oo0P000Woo00<007ooOol06Woo00D007ooOomo
o`0000Eoo`8000Eoo`04001oogoo000@Ool00`00Oomoo`04Ool01@00Oomoogoo00001Goo0P001goo
00<007ooOol05Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol00009Ool00`00Oomoo`0<
Ool01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001eoo`03001oogoo009oo`03001oogoo
04Uoo`80009oo`03001oogoo01Yoo`05001oogooOol00005Ool20005Ool200000goo001oo`0FOol0
1@00Oomoogoo00001Goo0P001goo00<007ooOol03goo00<007ooOol017oo00D007ooOomoo`0000Eo
o`8000Aoo`05001oogooOol0000DOol01000Oomoo`000goo00<007ooOol00goo0P0017oo00D007oo
Oomoo`00029oo`03001oogoo01Aoo`00>7oo00D007ooOomoo`0001aoo`05001oogooOol0000=Ool0
0`00Oomoo`0@Ool00`00Oomoo`04Ool01@00Oomoogoo00002goo1@005goo00D007ooOomoo`0000]o
o`05001oogooOol00009Ool00`00Oomoo`0<Ool01@00Oomoogoo00002goo00D007ooOomoo`0001io
o`05001oogooOol0001;Ool01000Oomoo`007Goo00D007ooOomoo`0000eoo`8001Qoo`05001oogoo
Ool0000;Ool5000?Ool00`00Oomoo`05Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Aoo`04
001oogoo0003Ool00`00Oomoo`09Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol01000
Oomoo`007Goo00D007ooOomoo`0000ioo`03001oogoo00moo`03001oogoo00Aoo`05001oogooOol0
000;Ool01000Oomoo`0067oo00D007ooOomoo`0000]oo`05001oogooOol00009Ool00`00Oomoo`0<
Ool01@00Oomoogoo00002goo00D007ooOomoo`0001ioo`05001oogooOol0001;Ool01000Oomoo`00
7Goo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000Oomoo`0047oo
00<007ooOol01Goo00D007ooOomoo`0000]oo`05001oogooOol0000DOol01000Oomoo`000goo00<0
07ooOol02Goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00@007ooOol001eoo`05001o
ogooOol0000?Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool01@00Oomoogoo000037oo00<007oo0000
67oo00D007ooOomoo`0000]oo`@000Uoo`03001oogoo00eoo`05001oogooOol0000<Ool3000OOol0
1@00Oomoogoo0000Bgoo00@007ooOol001eoo`05001oogooOol0000>Ool2000GOol01@00Oomoogoo
000037oo00<007oo000047oo00<007ooOol01Goo00D007ooOomoo`0000]oo`@001Ioo`03001oo`00
00=oo`03001oogoo00Yoo`<002=oo`03001oogoo01Aoo`00>7oo0P0000=oo`00Ool077oo00D007oo
Oomoo`0000moo`03001oogoo00moo`03001oogoo00=oo`05001oogooOol0000<Ool00`00Ool0000H
Ool01@00Oomoogoo00002goo00<007ooOol02Woo00<007ooOol03Goo00D007ooOomoo`0000]oo`05
001oogooOol0000OOol01000Oomoo`00Bgoo0`007Woo00D007ooOomoo`0000moo`03001oogoo01Eo
o`05001oogooOol0000<Ool00`00Ool0000?Ool00`00Oomoo`06Ool01@00Oomoogoo00002goo00<0
07ooOol05goo00<007oo00000goo00<007ooOol02Goo00D007ooOomoo`00029oo`03001oogoo01Ao
o`00>7oo00<007oo00007Woo00D007ooOomoo`0000]oo`05001oogooOol0000BOol00`00Oomoo`02
Ool01@00Oomoogoo00003Goo0P0067oo00D007ooOomoo`0000aoo`03001oogoo00Qoo`03001oogoo
00ioo`05001oogooOol0000;Ool01@00Oomoogoo00007goo00@007ooOol004]oo`03001oo`0001io
o`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8000moo`03001o
ogoo00Ioo`05001oogooOol0000<Ool00`00Oomoo`0FOol00`00Ool00003Ool00`00Oomoo`09Ool0
1@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Ool0000OOol3000=Ool3000COol00`00
Oomoo`03Ool3000?Ool00`00Oomoo`0GOol3000>Ool30007Ool00`00Oomoo`0?Ool3000=Ool3000P
Ool4001;Ool00`00Ool0000OOol3000=Ool4000HOol3000?Ool00`00Oomoo`0=Ool00`00Oomoo`07
Ool3000>Ool3000FOol00`00Ool00002000=Ool3000QOol3000FOol003Qoo`<004Eoo`03001oogoo
04Yoo`03001oogoo04=oo`03001oogoo04]oo`8003Aoo`03001oogoo03Ioo`03001oogoo039oo`03
001oogoo04aoo`00>7oo0P00Agoo00<007ooOol0B7oo00<007ooOol0A7oo00<007ooOol0Bgoo0P00
=7oo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol0C7oo000hOol20017Ool00`00Oomoo`18
Ool00`00Oomoo`14Ool00`00Oomoo`1;Ool2000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00
Oomoo`1<Ool003Qoo`8004Moo`03001oogoo04Qoo`03001oogoo04Eoo`03001oogoo04Yoo`03001o
ogoo03Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo04]oo`00<Wooj@00@7ooj@0047oo
000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`05Ool01000Oomoo`002Woo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00D007ooOomoo`0000Ioo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo04Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo00<007ooOol0B7oo00<007ooOol0
A7oo00<007ooOol0U7oo00<007ooOol0=7oo00<007ooOol0=7oo00<007ooOol0=Goo00<007ooOol0
<goo00<007ooOol057oo000hOol20019Ool00`00Oomoo`14Ool00`00Oomoo`2DOol2000fOol00`00
Oomoo`0bOol00`00Oomoo`0fOol00`00Oomoo`0cOol00`00Oomoo`0DOol003Qoo`03001oogoo04Qo
o`03001oogoo04Aoo`03001oogoo09Aoo`03001oogoo03Eoo`03001oogoo039oo`03001oogoo03Io
o`03001oogoo039oo`03001oogoo01Eoo`00>7oo00<007ooOol0BGoo00<007ooOol0@Woo00<007oo
Ool0UGoo00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=goo00<007ooOol0<Goo00<007oo
Ool05Goo000hOol00`00Oomoo`19Ool00`00Oomoo`12Ool00`00Oomoo`2EOol00`00Oomoo`0fOol0
0`00Oomoo`0`Ool00`00Oomoo`0hOol00`00Oomoo`0aOol00`00Oomoo`0EOol003Qoo`8004Yoo`03
001oogoo049oo`03001oogoo09Eoo`8003Moo`03001oogoo031oo`03001oogoo03Qoo`03001oogoo
031oo`03001oogoo01Ioo`00>7oo00<007ooOol0BWoo00<007ooOol0@7oo00<007ooOol0UWoo00<0
07ooOol0=Woo00<007ooOol0<7oo00<007ooOol0>Goo00<007ooOol0;goo00<007ooOol05Woo000h
Ool00`00Oomoo`1:Ool00`00Oomoo`10Ool00`00Oomoo`2FOol00`00Oomoo`0gOol00`00Oomoo`0^
Ool00`00Oomoo`0jOol00`00Oomoo`0_Ool00`00Oomoo`0FOol003Qoo`03001oogoo04Yoo`03001o
ogoo041oo`03001oogoo09Ioo`03001oogoo03Moo`03001oogoo02ioo`03001oogoo03Yoo`03001o
ogoo02ioo`03001oogoo01Moo`00>7oo0P00C7oo00<007ooOol0?Woo00<007ooOol0Ugoo0P00>7oo
00<007ooOol0;Woo00<007ooOol0>goo00<007ooOol0;Goo00<007ooOol05goo000hOol00`00Oomo
o`1;Ool00`00Oomoo`0nOol00`00Oomoo`2GOol00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00Oomo
o`0lOol00`00Oomoo`0]Ool00`00Oomoo`0GOol003Qoo`03001oogoo04]oo`03001oogoo03eoo`03
001oogoo09Qoo`03001oogoo03Qoo`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02aoo`03
001oogoo01Qoo`00>7oo0P00CGoo00<007ooOol0?7oo00<007ooOol0V7oo0P00>Goo00<007ooOol0
;7oo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol067oo000GOol30006Ool20004Ool50004
Ool40005Ool00`00Oomoo`1<Ool00`00Oomoo`0lOol00`00Oomoo`1gOol30006Ool20004Ool50004
Ool40005Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0[Ool00`00
Oomoo`0HOol001Ioo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo
00<007ooOol0C7oo00<007ooOol0>goo00<007ooOol0Mgoo00D007ooOomoo`0000Eoo`8000Eoo`04
001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0nOol0
0`00Oomoo`0ZOol00`00Oomoo`0IOol001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00Oomoo`1gOol01@00Oomoogoo00003Goo
00<007ooOol027oo00<007ooOol00Woo00<007ooOol0>Goo00<007ooOol0:Woo00<007ooOol0?goo
00<007ooOol0:Goo00<007ooOol06Goo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P00CWoo00<007ooOol0>Woo00<007ooOol0Mgoo00D007ooOomoo`0000ioo`03001o
ogoo00Moo`03001oogoo009oo`8003]oo`03001oogoo02Uoo`03001oogoo03moo`03001oogoo02Uo
o`03001oogoo01Uoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo
04eoo`03001oogoo03Uoo`03001oogoo07Qoo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005
Ool00`00Oomoo`0jOol00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`0J
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`1>Ool0
0`00Oomoo`0hOol00`00Oomoo`1hOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
1Woo00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol0
6Woo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8004moo`03
001oogoo03Qoo`03001oogoo07Qoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P00?7oo00<007ooOol09goo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol06Woo
000GOol3000=Ool30005Ool40005Ool00`00Oomoo`1>Ool00`00Oomoo`0gOol00`00Oomoo`1jOol3
000=Ool30005Ool40005Ool00`00Oomoo`0kOol00`00Oomoo`0VOol00`00Oomoo`12Ool00`00Oomo
o`0VOol00`00Oomoo`0KOol003Qoo`03001oogoo04moo`03001oogoo03Ioo`03001oogoo09]oo`03
001oogoo03]oo`03001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03001oogoo01]oo`00
>7oo00<007ooOol0Cgoo00<007ooOol0=Woo00<007ooOol0Vgoo00<007ooOol0?7oo00<007ooOol0
9Goo00<007ooOol0@goo00<007ooOol09Goo00<007ooOol06goo000hOol2001@Ool00`00Oomoo`0e
Ool00`00Oomoo`2LOol2000mOol00`00Oomoo`0TOol00`00Oomoo`14Ool00`00Oomoo`0TOol00`00
Oomoo`0LOol003Qoo`03001oogoo051oo`03001oogoo03Aoo`03001oogoo09aoo`03001oogoo03ao
o`03001oogoo02Aoo`03001oogoo04Eoo`03001oogoo02=oo`03001oogoo01aoo`00>7oo00<007oo
Ool0D7oo00<007ooOol0<goo00<007ooOol0WGoo00<007ooOol0?Goo00<007ooOol08goo00<007oo
Ool0AGoo00<007ooOol08goo00<007ooOol077oo000hOol2001BOol00`00Oomoo`0bOol00`00Oomo
o`2MOol2000nOol00`00Oomoo`0ROol00`00Oomoo`16Ool00`00Oomoo`0ROol00`00Oomoo`0MOol0
03Qoo`03001oogoo055oo`03001oogoo039oo`03001oogoo09eoo`03001oogoo03eoo`03001oogoo
029oo`03001oogoo04Moo`03001oogoo025oo`03001oogoo01eoo`00>7oo00<007ooOol0DGoo00<0
07ooOol0<Goo00<007ooOol0WWoo00<007ooOol0?Woo00<007ooOol08Goo00<007ooOol0Agoo00<0
07ooOol08Goo00<007ooOol07Goo000hOol00`00Oomoo`1BOol00`00Oomoo`0`Ool00`00Oomoo`2N
Ool00`00Oomoo`0nOol00`00Oomoo`0POol00`00Oomoo`18Ool00`00Oomoo`0POol00`00Oomoo`0N
Ool003Qoo`8005=oo`03001oogoo02moo`03001oogoo09moo`8003moo`03001oogoo021oo`03001o
ogoo04Uoo`03001oogoo01moo`03001oogoo01ioo`007goo0`001Woo0P001Goo10001Goo00<007oo
Ool0DWoo00<007ooOol0;goo00<007ooOol0QWoo0`001Woo0P001Goo10001Goo00<007ooOol0?goo
00<007ooOol07goo00<007ooOol0BGoo00<007ooOol07Woo00<007ooOol07goo000NOol01@00Oomo
ogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0Dgoo00<007ooOol0;Woo00<007ooOol0
QGoo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo03moo`03001oogoo01io
o`03001oogoo04Yoo`03001oogoo01ioo`03001oogoo01moo`007Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo05=oo`03001oogoo02eoo`03001oogoo08Ioo`05001oogooOol0000@
Ool00`00Oomoo`02Ool00`00Oomoo`10Ool00`00Oomoo`0MOol00`00Oomoo`1;Ool00`00Oomoo`0M
Ool00`00Oomoo`0OOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2001DOol00`00Oomo
o`0]Ool00`00Oomoo`26Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00@Goo00<007ooOol0
7Goo00<007ooOol0Bgoo00<007ooOol077oo00<007ooOol087oo000NOol01@00Oomoogoo000037oo
10001Goo00<007ooOol0E7oo00<007ooOol0:goo00<007ooOol0Qgoo00D007ooOomoo`0000aoo`@0
00Eoo`03001oogoo045oo`03001oogoo01]oo`03001oogoo04aoo`03001oogoo01aoo`03001oogoo
021oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo05Aoo`03001oogoo02]o
o`03001oogoo08Moo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`11Ool00`00Oomo
o`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`0POol001ioo`05001oogooOol0000<
Ool00`00Oomoo`06Ool2001FOol00`00Oomoo`0ZOol00`00Oomoo`27Ool01@00Oomoogoo000037oo
00<007ooOol01Woo0P00@Woo00<007ooOol06goo00<007ooOol0CGoo00<007ooOol06Woo00<007oo
Ool08Goo000OOol3000=Ool40005Ool00`00Oomoo`1EOol00`00Oomoo`0YOol00`00Oomoo`29Ool3
000=Ool40005Ool00`00Oomoo`12Ool00`00Oomoo`0IOol00`00Oomoo`1?Ool00`00Oomoo`0IOol0
0`00Oomoo`0QOol003Qoo`03001oogoo05Eoo`03001oogoo02Uoo`03001oogoo0:9oo`03001oogoo
049oo`03001oogoo01Uoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025oo`00>7oo00<0
07ooOol0EWoo00<007ooOol0:7oo00<007ooOol0XWoo00<007ooOol0@goo00<007ooOol05goo00<0
07ooOol0D7oo00<007ooOol067oo00<007ooOol08Woo000hOol2001GOol00`00Oomoo`0WOol00`00
Oomoo`2SOol20014Ool00`00Oomoo`0GOol00`00Oomoo`1AOol00`00Oomoo`0GOol00`00Oomoo`0R
Ool003Qoo`03001oogoo05Moo`03001oogoo02Ioo`03001oogoo0:=oo`03001oogoo04=oo`03001o
ogoo01Ioo`03001oogoo059oo`03001oogoo01Moo`03001oogoo029oo`00>7oo00<007ooOol0Egoo
00<007ooOol09Goo00<007ooOol0Y7oo00<007ooOol0A7oo00<007ooOol057oo00<007ooOol0E7oo
00<007ooOol05Goo00<007ooOol08goo000hOol2001IOol00`00Oomoo`0TOol00`00Oomoo`2TOol2
0015Ool00`00Oomoo`0DOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`0TOol003Qoo`03
001oogoo05Qoo`03001oogoo02Aoo`03001oogoo0:Aoo`03001oogoo04Aoo`03001oogoo01=oo`03
001oogoo05Eoo`03001oogoo01Aoo`03001oogoo02Aoo`00>7oo00<007ooOol0F7oo00<007ooOol0
8goo00<007ooOol0YGoo00<007ooOol0AGoo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol0
4Woo00<007ooOol09Goo000hOol00`00Oomoo`1IOol00`00Oomoo`0ROol00`00Oomoo`2UOol00`00
Oomoo`16Ool00`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0AOol00`00Oomoo`0UOol003Qo
o`8005Yoo`03001oogoo025oo`03001oogoo0:Ioo`8004Qoo`03001oogoo00moo`03001oogoo05Uo
o`03001oogoo00moo`03001oogoo02Ioo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo
00<007ooOol0FWoo00<007ooOol087oo00<007ooOol0QGoo0`001Woo0P001Woo00<007ooOol017oo
10001Goo00<007ooOol0Agoo00<007ooOol03Woo00<007ooOol0Fgoo00<007ooOol03Woo00<007oo
Ool09Woo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<0
07ooOol0Fgoo00<007ooOol07Woo00<007ooOol0QGoo00D007ooOomoo`0000Eoo`8000Ioo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo04Qoo`03001oogoo00eoo`03001oogoo05]oo`03001o
ogoo00eoo`03001oogoo02Moo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo
009oo`03001oogoo05]oo`03001oogoo01eoo`03001oogoo08Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`18Ool00`00Oomoo`0<Ool00`00Oomoo`1MOol00`00
Oomoo`0<Ool00`00Oomoo`0WOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool2001MOol00`00Oomoo`0LOol00`00Oomoo`26Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo0P00BWoo00<007ooOol02Woo00<007ooOol0Ggoo00<007ooOol02Woo00<0
07ooOol0:7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0G7oo
00<007ooOol06goo00<007ooOol0Qgoo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03
001oogoo04Yoo`03001oogoo00Qoo`03001oogoo061oo`03001oogoo00Qoo`8002]oo`005Woo00D0
07ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo05eoo`03001oogoo01Yo
o`03001oogoo08Moo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`1;Ool00`00Oomoo`06Ool00`00Oomoo`1ROol20007Ool00`00Oomoo`0[Ool001Ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00Ggoo00<007ooOol067oo00<007oo
Ool0R7oo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001=Ool30003
Ool2001WOol20003Ool2000^Ool001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo05ioo`03001o
ogoo01Qoo`03001oogoo08Uoo`<000aoo`D000Aoo`@000Eoo`03001oogoo04ioo`@006Yoo`@0031o
o`00>7oo00<007ooOol0Ggoo00<007ooOol05Woo00<007ooOol0Zgoo00<007ooOol0l7oo000hOol0
0`00Oomoo`1POol00`00Oomoo`0DOol00`00Oomoo`2/Ool00`00Oomoo`3`Ool003Qoo`80065oo`03
001oogoo01=oo`03001oogoo0:eoo`800?5oo`00>7oo00<007ooOol0HGoo00<007ooOol04Goo00<0
07ooOol0[Woo00<007ooOol0l7oo000hOol00`00Oomoo`1ROol2000AOol00`00Oomoo`2^Ool00`00
Oomoo`3`Ool003Qoo`8006Eoo`03001oogoo00eoo`03001oogoo0:moo`800?5oo`00>7oo00<007oo
Ool0IGoo00<007ooOol02Woo0P00/Woo00<007ooOol0l7oo000hOol00`00Oomoo`1VOol00`00Oomo
o`07Ool2002dOol00`00Oomoo`3`Ool003Qoo`03001oogoo06Moo`<000Aoo`800;Ioo`03001oogoo
0?1oo`00>7oo0P00JWoo1@00^7oo0P00lGoo000_Ool50004Ool00`00Oomoo`3oOolNOol50004Ool0
0`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001o
ogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000aOol00`00
Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo
00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0
02moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<00004Ool00000000H
Ool3003oOol7Ool3000017oo000000006Goo0`00M7oo002FOol01@00Oomoogoo00002Goo1P002Goo
00D007ooOomoo`000?moo`Moo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05
001oogooOol0000LOol00`00Oomoo`3oOol5Ool01@00Oomoogoo000067oo1@00M7oo002FOol01@00
Oomoogoo00002Goo1P003Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Uoo`H000Uoo`04001o
ogoo001eOol009Ioo`05001oogooOol0000JOol2003oOol8Ool01@00Oomoogoo00006Goo00<007oo
0000MGoo002EOol5000MOol00`00Oomoo`3oOol4Ool5000JOol00`00Ool0001eOol00;=oo`05001o
ogooOol0003oOolVOol2001eOol00;Aoo`<00?moobQoo`03001oogoo07=oo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo000_Ool5003oOolU
Ool5003gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`009Woo1P001Goo00<007ooOol0
ogoo77oo1P001Goo00<007ooOol0mgoo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04
Ool2003aOol0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo
0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo
000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol002moo`<000Ioo`03001o
ogoo0?mooaioo`<000Ioo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00
ogoo:7oo0P00lGoo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6
Ool30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0
0005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0l7oo000>Ool60002Ool0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0o7oo1P000Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?1oo`005Woo00D007oo
Oomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`03
Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<0
07ooOol0l7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?1o
o`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool0
1@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?5oo`005goo0`0037oo
1@0017oo10001Goo00<007ooOol0ogoo1Woo0`0037oo1@0017oo10001Goo00<007ooOol0l7oo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03
001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol001moo`<000Ioo`8000Eoo`@0
00Eoo`03001oogoo0?moo`ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo0?1oo`007Woo00D007oo
Oomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol00005Ool2
0009Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`H0009oo`05001oogooOol0000@Ool00`00
Oomoo`02Ool2003oOol6Ool60002Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00lGoo000N
Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`00011o
o`03001oogoo009oo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo
0?moo`eoo`05001oogooOol0000<Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<
Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<0
07ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00ogoo3Woo00D007ooOomo
o`0000aoo`03001oogoo00Ioo`800?5oo`007goo0`003Goo10001Goo00<007ooOol0ogoo3Woo0`00
3Goo10001Goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03
001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo
:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMo
o`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0;Woo3@00]Goo000hOol2003o
OolXOol2000YOol6000=Ool6002_Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo
0?moo`Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo02Aoo`@001Uoo`@00:]oo`005Woo
00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5
Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo021o
o`@0025oo`<00:Qoo`003Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo
009oo`800?eoo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000N
Ool3000XOol2002VOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool06Woo0`00;Goo0`00Xgoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<0
07ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo01Qoo`80
03=oo`800:5oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0F
Ool2000gOol2002OOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol0
1Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000E
Ool2000kOol2002MOol001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo0?moo`Ioo`<000eoo`<0
00Eoo`@000Eoo`03001oogoo019oo`8003moo`<009Yoo`00>7oo00<007ooOol07goo0`001Woo0P00
17oo1@0067oo0`001Woo0P001Woo0`0067oo0`001Woo0P001Goo0`006Woo0`001Woo0P001Goo0`00
8Goo1@00BGoo00<007ooOol047oo0P003Goo0`001Woo0P0017oo1@0067oo0`001Woo100017oo0`00
67oo0`001Woo0P001Goo0`006Goo0`001Woo0P001Goo0`008Goo1@0057oo000hOol2000OOol01@00
Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00Oomo
o`0FOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Qoo`05001oogooOol00005Ool2
0004Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo0P003goo0P003Woo00D007ooOomoo`0000Eo
o`8000Eoo`04001oogoo000GOol01@00Oomoogoo00001Goo0P000Woo0P000goo00<007ooOol05Woo
00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000GOol01@00Oomoogoo00001Goo0P0017oo
00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000eo
o`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol0
3Goo00<007ooOol03Woo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5
000GOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomo
ogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Woo00<007oo
Ool05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol0
2goo0P004Goo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000Ool0
000067oo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00002goo00D007oo
Oomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000moo`03001o
ogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10006Goo00D0
07ooOomoo`0000aoo`<002=oo`03001oogoo04Uoo`03001oogoo00Yoo`03001oogoo015oo`05001o
ogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo00000P005Woo00D007oo
Oomoo`0000]oo`@001Qoo`05001oogooOol0000<Ool3000SOol00`00Oomoo`0DOol003Qoo`8001mo
o`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D0
07ooOomoo`0000]oo`03001oogoo01Yoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<0
07ooOol0BGoo0P002Goo0P0057oo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0
000<Ool00`00Ool00002Ool2000DOol01@00Oomoogoo00002goo00<007ooOol06Goo00D007ooOomo
o`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8001Qoo`05001oogooOol0000<
Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03
001oogoo00Moo`03001oogoo01Aoo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007oo
Oomoo`0000eoo`8000Aoo`80019oo`05001oogooOol0000<Ool00`00Oomoo`0HOol01@00Oomoogoo
00002goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07goo0`003Goo0`00
6Goo0`003goo00<007ooOol05goo0`003Woo0`006Goo0`003Goo0`008Goo0`00Bgoo00<007ooOol0
1Goo0P0067oo0`003Goo0`006Goo0`003goo00<007ooOol017oo00<007ooOol047oo0`003Woo0`00
67oo0`003Goo0`008Goo0`005Woo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`03Ool2001POol2
0029Ool003Qoo`800?moobQoo`80009oo`8006Aoo`03001oogoo08Ioo`00>7oo00<007ooOol0ogoo
9goo00@007ooOol006Moo`8008Ioo`00>7oo00<007ooOol0ogoo9goo0`00JWoo00<007ooOol0Pgoo
000bOooY0010OooY000@Ool003Qoo`03001oo`0000Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Ioo`03001oo`0004]oo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oo`0000Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`8001Ioo`00>7oo00<007ooOol00P009goo
00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol09Goo0P000Woo00<007oo
Ool0BGoo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol05Woo0P004Goo00<007ooOol0:Goo
00<007ooOol09Woo0P0000=oo`00Ool05Goo000hOol00`00Oomoo`02Ool00`00Oomoo`3@Ool00`00
Oomoo`1>Ool00`00Oomoo`1`Ool00`00Oomoo`1QOol2000JOol003Qoo`8000Aoo`800<ioo`80055o
o`80079oo`80061oo`03001oogoo01Yoo`00>7oo00<007ooOol01Goo00<007ooOol0bWoo00<007oo
Ool0DGoo00<007ooOol0Lgoo00<007ooOol0Fgoo0P007Goo000hOol00`00Oomoo`06Ool20038Ool2
001DOol00`00Oomoo`1dOol2001IOol2000OOol003Qoo`8000Uoo`800<Aoo`8005Ioo`8007Moo`80
05Eoo`80025oo`00>7oo00<007ooOol02Woo0P00`7oo0P00F7oo00<007ooOol0N7oo0P00DGoo0P00
8goo000hOol00`00Oomoo`0<Ool2002lOol2001JOol00`00Oomoo`1jOol2001>Ool00`00Oomoo`0S
Ool003Qoo`03001oogoo00ioo`800;Qoo`8005aoo`03001oogoo07aoo`8004Yoo`8002Ioo`00>7oo
0P004Goo0P00]7oo0P00GWoo0P00Ogoo0P00AWoo0P00:7oo000hOol00`00Oomoo`0BOol00`00Oomo
o`2_Ool2001POol00`00Oomoo`20Ool20012Ool2000ZOol003Qoo`03001oogoo01=oo`800:eoo`80
069oo`03001oogoo089oo`8003ioo`8002aoo`00>7oo00<007ooOol05Goo00<007ooOol0ZGoo00<0
07ooOol0HWoo00<007ooOol0Q7oo00<007ooOol0>Goo0P00;Woo000hOol2000GOol2002WOol2001U
Ool20026Ool2000gOol2000`Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo01Qo
o`03001oogoo0:9oo`8004Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo08Moo`8003=o
o`80039oo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol2002POol20017Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03
001oogoo009oo`03001oogoo08Uoo`8002ioo`<003Aoo`005Woo00D007ooOomoo`0000eoo`03001o
ogoo00Qoo`03001oogoo009oo`8001aoo`8009aoo`8004Uoo`05001oogooOol0000=Ool00`00Oomo
o`08Ool00`00Oomoo`02Ool2002<Ool4000WOol3000gOol001Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0MOol3002HOol00`00Oomoo`19Ool01@00Oomoogoo
00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0Sgoo0`008Woo0P00>Woo000FOol0
1@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol087oo0P00U7oo0P00C7oo00D0
07ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo099oo`<001aoo`<003aoo`005Woo
00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo029oo`80091oo`80
04ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`2EOol3000E
Ool4000oOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00
9Goo0P00S7oo0P00D7oo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2
002IOolE0013Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo02Ioo`8008Qoo`8005=oo`<0
00eoo`<000Eoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0:7oo00<007ooOol0Q7oo00<0
07ooOol0M7oo00<007ooOol0l7oo000hOol2000ZOol20022Ool2001gOol2003aOol003Qoo`03001o
ogoo02]oo`8007ioo`8007Uoo`03001oogoo0?1oo`00>7oo00<007ooOol0;Goo0P00NWoo0P00Ngoo
00<007ooOol0l7oo000hOol00`00Oomoo`0_Ool3001dOol3001mOol00`00Oomoo`3`Ool003Qoo`80
03=oo`80071oo`80081oo`800?5oo`00>7oo00<007ooOol0=7oo0P00K7oo0P00PWoo00<007ooOol0
l7oo000hOol00`00Oomoo`0fOol3001VOol30024Ool00`00Oomoo`3`Ool003Qoo`8003Yoo`80069o
o`8008Moo`800?5oo`00>7oo00<007ooOol0>goo0`00G7oo0`00RGoo00<007ooOol0l7oo000OOol3
0006Ool20005Ool40005Ool00`00Oomoo`0nOol3001GOol2001cOol30006Ool20005Ool40005Ool0
0`00Oomoo`3`Ool001ioo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`11
Ool3001AOol3001dOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0l7oo
000NOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00AGoo0`00Bgoo0`00Mgoo00D007ooOomo
o`00011oo`03001oogoo009oo`800?5oo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03
001oogoo04Moo`<004Eoo`<007Yoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3`
Ool001ioo`05001oogooOol0000<Ool40005Ool00`00Oomoo`1:Ool5000kOol5001mOol01@00Oomo
ogoo000037oo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo
00<007ooOol0Cgoo1000<Woo1@00PWoo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo
0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`8005Aoo`D002Qoo`D008Moo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool2003aOol001moo`<000eoo`@000Eoo`03001oogoo05Qoo`D0
01moo`@008eoo`<000eoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0GGoo7`00ZWoo00<0
07ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo
0P001Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo
00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qo
o`03001oogoo009oo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool2003oOol6Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00lGoo000F
Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000moo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo
000017oo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Moo`<000aoo`D000Aoo`@000Eoo`800?moo`Mo
o`<000aoo`D000Aoo`@000Eoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03
001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo
:7oo0P00lGoo000_Ool50004Ool00`00Oomoo`3oOolNOol50004Ool00`00Oomoo`3`Ool0035oo`03
001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007oo
Ool017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04
Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Mo
o`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomo
o`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<00004Ool0
0000000HOol5003oOol5Ool3000017oo000000005goo1@00M7oo002FOol01@00Oomoogoo00002Goo
1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H000Yoo`04001oogoo001dOol009Io
o`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo00006Woo00<007ooOol0M7oo
002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H0
00aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001]oo`03001oogoo0?moo`Ioo`05001oogoo
Ool0000LOol00`00Oomoo`1bOol009Eoo`D001aoo`03001oogoo0?moo`Eoo`D001eoo`03001oogoo
079oo`00]Woo00<007ooOol0ogoo8goo00D007ooOomoo`0007Aoo`00]7oo0`00ogoo9Woo0`00MGoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22749 L
.08255 .18903 L
.10458 .15237 L
.12507 .12491 L
.14415 .10609 L
.14918 .10231 L
.15465 .09878 L
.15946 .09618 L
.16457 .09396 L
.16917 .09242 L
.17178 .09175 L
.17423 .09125 L
.17538 .09106 L
.17647 .0909 L
.17746 .09078 L
.17852 .09068 L
.17967 .0906 L
.18073 .09054 L
.182 .09051 L
.18314 .09051 L
.18435 .09054 L
.18547 .0906 L
.1867 .09069 L
.18802 .09083 L
.19071 .09122 L
.19317 .09172 L
.1979 .09303 L
.20239 .09471 L
.21236 .09996 L
.22321 .10797 L
.24299 .12845 L
.26399 .15773 L
.30174 .22571 L
.34195 .31048 L
.38063 .392 L
.40028 .42949 L
.42177 .46526 L
.44253 .49314 L
.4614 .51178 L
.47149 .51888 L
.47611 .52145 L
.48101 .52368 L
.4835 .52462 L
.48624 .5255 L
.48876 .52617 L
.49106 .52667 L
.49378 .52711 L
.49527 .52729 L
.49596 .52735 L
Mistroke
.49669 .52741 L
.498 .52748 L
.49921 .52752 L
.49996 .52752 L
.50065 .52752 L
.50196 .52748 L
.50313 .52742 L
.50438 .52732 L
.50556 .52719 L
.50663 .52705 L
.50926 .52661 L
.51175 .52605 L
.5167 .52455 L
.52208 .52233 L
.53169 .51687 L
.54056 .51016 L
.55926 .49101 L
.57988 .46273 L
.62014 .39046 L
.65888 .3087 L
.70007 .2221 L
.72063 .18337 L
.73974 .15201 L
.75939 .12561 L
.77791 .10704 L
.78775 .09989 L
.79293 .09692 L
.7984 .09438 L
.80302 .09274 L
.80546 .09205 L
.80809 .09145 L
.8105 .09103 L
.8127 .09075 L
.81375 .09066 L
.81491 .09058 L
.81599 .09053 L
.817 .09051 L
.81818 .09051 L
.81941 .09055 L
.82047 .09061 L
.82163 .09069 L
.82287 .09082 L
.82421 .091 L
.82661 .0914 L
.82905 .09194 L
.83134 .09257 L
.83564 .09404 L
.84078 .0963 L
.84552 .09888 L
.85624 .1064 L
Mistroke
.87498 .12496 L
.89561 .15266 L
.93591 .22421 L
.97471 .30581 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .15822 L
.08255 .09277 L
.0932 .064 L
.10458 .03858 L
.11009 .02843 L
.11531 .02019 L
.12038 .01349 L
.12507 .00848 L
.12951 .00478 L
.13178 .0033 L
.13422 .00201 L
.13549 .00146 L
.13666 .00103 L
.13784 .00068 L
.13895 .00041 L
.14022 .00019 L
.1409 .0001 L
.14161 4e-05 L
.1423 1e-05 L
.14295 0 L
.14415 5e-05 L
.14531 .00016 L
.14656 .00037 L
.14773 .00064 L
.14881 .00095 L
.15143 .00197 L
.15392 .00328 L
.15886 .00686 L
.16423 .01221 L
.17383 .02544 L
.1827 .04173 L
.20137 .08761 L
.22197 .15361 L
.26217 .31011 L
.30086 .46095 L
.32051 .52485 L
.3309 .55305 L
.342 .57811 L
.35275 .59689 L
.35784 .60377 L
.36253 .60895 L
.36724 .61299 L
.36972 .61465 L
.37235 .61605 L
.37463 .61696 L
.37573 .6173 L
.37677 .61756 L
.37799 .6178 L
.37911 .61794 L
Mistroke
.38031 .61802 L
.38162 .61802 L
.38227 .61799 L
.38296 .61793 L
.38419 .61775 L
.38551 .61748 L
.38695 .61707 L
.38955 .61605 L
.39197 .61478 L
.39649 .61156 L
.40134 .60693 L
.40698 .59999 L
.41232 .59194 L
.42232 .57313 L
.44227 .52229 L
.4607 .46216 L
.50002 .30893 L
.53782 .16112 L
.55884 .0925 L
.56803 .0674 L
.57808 .04406 L
.58722 .02686 L
.59696 .01303 L
.60236 .00746 L
.60726 .00373 L
.60962 .00239 L
.61086 .0018 L
.61218 .00127 L
.61333 .00088 L
.61459 .00053 L
.61574 .00029 L
.61682 .00013 L
.61808 3e-05 L
.61871 0 L
.61941 0 L
.62065 7e-05 L
.62181 .00021 L
.62248 .00032 L
.62318 .00046 L
.62443 .00078 L
.62578 .00122 L
.62725 .00181 L
.62973 .00306 L
.63238 .00477 L
.63715 .00877 L
.64214 .01424 L
.64686 .02058 L
.6557 .03543 L
.67568 .08235 L
.69413 .13964 L
Mistroke
.7335 .29029 L
.77136 .44032 L
.79241 .512 L
.81166 .56404 L
.82118 .58388 L
.8262 .59264 L
.83155 .60059 L
.8367 .60686 L
.84136 .61136 L
.84361 .61312 L
.84604 .61473 L
.84835 .61596 L
.85045 .61683 L
.85159 .61721 L
.85283 .61753 L
.85414 .61779 L
.85538 .61795 L
.85653 .61802 L
.85776 .61802 L
.85881 .61796 L
.85997 .61782 L
.86063 .61771 L
.86132 .61756 L
.86256 .61724 L
.86535 .61622 L
.86777 .615 L
.87041 .61331 L
.87569 .60883 L
.88133 .60244 L
.89148 .58686 L
.90173 .56608 L
.91284 .53828 L
.933 .47576 L
.97393 .31822 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33679 L
.10458 .36655 L
.14415 .3935 L
.18221 .41806 L
.22272 .44232 L
.26171 .46343 L
.30316 .48306 L
.34309 .4989 L
.3815 .51104 L
.40095 .51596 L
.42237 .5204 L
.44268 .52363 L
.45178 .52477 L
.46172 .52578 L
.4671 .52624 L
.4721 .5266 L
.47727 .52691 L
.48196 .52714 L
.48658 .52731 L
.4887 .52737 L
.49093 .52743 L
.49332 .52747 L
.49438 .52749 L
.49552 .5275 L
.49675 .52751 L
.49789 .52752 L
.49859 .52752 L
.49925 .52752 L
.50049 .52752 L
.50163 .52752 L
.50286 .52752 L
.50401 .52751 L
.50508 .52749 L
.50754 .52746 L
.51014 .5274 L
.51268 .52733 L
.51504 .52726 L
.5204 .52703 L
.5293 .5265 L
.53882 .52574 L
.54906 .52467 L
.56016 .52324 L
.58032 .5199 L
.62123 .51028 L
.66064 .49756 L
.69852 .48232 L
.73886 .46313 L
.77769 .44209 L
.81897 .41733 L
Mistroke
.85873 .39158 L
.89697 .36547 L
.93767 .33671 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20178 .30902 L
.21267 .30902 L
.22272 .30902 L
.23293 .30902 L
.23832 .30902 L
.24402 .30902 L
.24641 .30902 L
.24897 .30902 L
.25119 .30902 L
.25361 .30902 L
.25507 .30902 L
.25643 .30902 L
.25773 .30902 L
.2584 .30902 L
.25912 .30902 L
.25983 .30902 L
.26048 .30902 L
.26176 .30902 L
.26293 .30902 L
.26416 .30902 L
.26538 .30902 L
.26607 .30902 L
.26671 .30902 L
.26912 .30902 L
.27131 .30902 L
.27364 .30902 L
.27847 .30902 L
.2838 .30902 L
.29326 .30902 L
.30213 .30902 L
.32232 .30902 L
.34082 .30902 L
.38045 .30902 L
.41855 .30902 L
.45912 .30902 L
.49816 .30902 L
.53966 .30902 L
.57964 .30902 L
.61811 .30902 L
.63759 .30902 L
.65902 .30902 L
.67938 .30902 L
.69843 .30902 L
.70884 .30902 L
.71396 .30902 L
Mistroke
.71872 .30902 L
.72301 .30902 L
.72758 .30902 L
.7302 .30902 L
.73148 .30902 L
.73266 .30902 L
.73371 .30902 L
.73487 .30902 L
.73603 .30902 L
.73725 .30902 L
.73856 .30902 L
.73977 .30902 L
.7404 .30902 L
.7411 .30902 L
.74251 .30902 L
.74375 .30902 L
.74508 .30902 L
.74748 .30902 L
.74985 .30902 L
.75235 .30902 L
.7568 .30902 L
.76198 .30902 L
.7668 .30902 L
.77773 .30902 L
.78828 .30902 L
.79823 .30902 L
.81683 .30902 L
.85534 .30902 L
.89632 .30902 L
.93577 .30902 L
.97371 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`8001Qoo`@006Yoo`@006Moo`00
<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol05Goo0`000Woo
0P00J7oo0P000goo0P00IGoo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04
Ool00`00Oomoo`0DOol00`00Oomoo`05Ool00`00Oomoo`1TOol00`00Oomoo`05Ool00`00Oomoo`1R
Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo01=oo`03
001oogoo00Moo`03001oogoo069oo`03001oogoo00Moo`03001oogoo065oo`00<Goo00<007ooOol0
17oo0P00ogoo8Goo00<007ooOol017oo0P0057oo00<007ooOol027oo00<007ooOol0H7oo00<007oo
Ool027oo00<007ooOol0HGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`0B
Ool00`00Oomoo`0:Ool00`00Oomoo`1NOol00`00Oomoo`0:Ool00`00Oomoo`1POol003Qoo`03001o
ogoo0?moobMoo`03001oogoo019oo`03001oogoo00]oo`03001oogoo05aoo`03001oogoo00]oo`03
001oogoo061oo`00>7oo0P00ogoo:7oo0P004Woo00<007ooOol037oo00<007ooOol0G7oo00<007oo
Ool037oo00<007ooOol0Ggoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0@Ool00`00Oomoo`0>
Ool00`00Oomoo`1JOol00`00Oomoo`0>Ool00`00Oomoo`1NOol003Qoo`03001oogoo0?moobMoo`03
001oogoo00moo`03001oogoo00moo`03001oogoo05Yoo`03001oogoo00ioo`03001oogoo05ioo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol03goo00<007ooOol047oo00<007ooOol0F7oo00<007oo
Ool047oo00<007ooOol0GGoo000hOol2003oOolXOol2000?Ool00`00Oomoo`0AOol00`00Oomoo`1H
Ool00`00Oomoo`0@Ool00`00Oomoo`1MOol003Qoo`03001oogoo0?moobMoo`03001oogoo00ioo`03
001oogoo019oo`03001oogoo05Ioo`03001oogoo019oo`03001oogoo05aoo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007oo
Ool0G7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0=Ool00`00Oomoo`0COol00`00Oomoo`1F
Ool00`00Oomoo`0COol00`00Oomoo`1KOol003Qoo`800?moobQoo`8000ioo`03001oogoo01Aoo`03
001oogoo05Aoo`03001oogoo01Aoo`03001oogoo05]oo`005goo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool03Goo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol057oo00<007ooOol0Fgoo000FOol0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00aoo`03
001oogoo01Ioo`03001oogoo05=oo`03001oogoo01Eoo`03001oogoo05Yoo`003Woo1P000Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000=Ool00`00Oomoo`0FOol00`00Oomoo`1BOol0
0`00Oomoo`0FOol00`00Oomoo`1JOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol02goo00<007ooOol05goo00<007ooOol0DWoo00<007ooOol05goo00<007ooOol0
FGoo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo00]oo`03001oogoo01Qoo`03001o
ogoo055oo`03001oogoo01Moo`03001oogoo05Uoo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo01moo`H008ioo`H004]oo`05001oogooOol0000?Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool00`00
Oomoo`0HOol00`00Oomoo`1IOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<0
07ooOol01Woo0P007Goo10001Goo1000Qgoo0`001Goo0P00BWoo00D007ooOomoo`0000]oo`05001o
ogooOol00004Ool00`00Oomoo`06Ool2000;Ool00`00Oomoo`0IOol00`00Oomoo`1@Ool00`00Oomo
o`0IOol00`00Oomoo`1HOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo01]oo`03001oogoo
00]oo`03001oogoo089oo`8000Yoo`<004Qoo`<000aoo`D000Aoo`@000Eoo`03001oogoo00Yoo`03
001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo05Qoo`00>7oo00<007ooOol0
6Woo00<007ooOol03Goo00<007ooOol0P7oo00<007ooOol03Goo00<007ooOol0IWoo00<007ooOol0
2Woo00<007ooOol06Woo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol0F7oo000hOol2000I
Ool2000AOol00`00Oomoo`1mOol2000AOol00`00Oomoo`1UOol2000:Ool00`00Oomoo`0KOol00`00
Oomoo`1>Ool00`00Oomoo`0KOol00`00Oomoo`1GOol003Qoo`03001oogoo01Moo`03001oogoo019o
o`03001oogoo07]oo`03001oogoo019oo`03001oogoo06Aoo`03001oogoo00Uoo`03001oogoo01ao
o`03001oogoo04eoo`03001oogoo01]oo`03001oogoo05Moo`00>7oo00<007ooOol05Woo00<007oo
Ool057oo00<007ooOol0NGoo00<007ooOol057oo00<007ooOol0Hgoo00<007ooOol02Goo00<007oo
Ool077oo00<007ooOol0CGoo00<007ooOol06goo00<007ooOol0Egoo000hOol00`00Oomoo`0EOol0
0`00Oomoo`0FOol00`00Oomoo`1gOol00`00Oomoo`0FOol00`00Oomoo`1ROol00`00Oomoo`09Ool0
0`00Oomoo`0LOol00`00Oomoo`1<Ool00`00Oomoo`0LOol00`00Oomoo`1GOol003Qoo`8001Eoo`03
001oogoo01Qoo`03001oogoo07Eoo`03001oogoo01Qoo`03001oogoo065oo`8000Uoo`03001oogoo
01ioo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo05Ioo`00>7oo00<007ooOol057oo00<0
07ooOol06Goo00<007ooOol0M7oo00<007ooOol067oo00<007ooOol0HGoo00<007ooOol027oo00<0
07ooOol07Woo00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol0EWoo000hOol00`00Oomoo`0C
Ool00`00Oomoo`0JOol00`00Oomoo`1cOol00`00Oomoo`0JOol00`00Oomoo`1POol00`00Oomoo`08
Ool00`00Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`1FOol003Qoo`8001=o
o`03001oogoo01aoo`03001oogoo075oo`03001oogoo01aoo`03001oogoo05moo`8000Qoo`03001o
ogoo021oo`03001oogoo04Uoo`03001oogoo01moo`03001oogoo05Eoo`007goo0`001Woo0P001Goo
10001Goo00<007ooOol04Woo00<007ooOol07Goo00<007ooOol0L7oo00<007ooOol07Goo00<007oo
Ool0AGoo0`001Woo0P001Goo10001Goo00<007ooOol01goo00<007ooOol087oo00<007ooOol0BGoo
00<007ooOol07goo00<007ooOol0EGoo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0Woo00<007ooOol04Goo00<007ooOol07goo00<007ooOol0KWoo00<007ooOol07Woo00<007ooOol0
A7oo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo021o
o`03001oogoo04Qoo`03001oogoo021oo`03001oogoo05Eoo`005Woo1P000Woo00D007ooOomoo`00
011oo`03001oogoo009oo`03001oogoo011oo`03001oogoo021oo`03001oogoo06eoo`03001oogoo
021oo`03001oogoo03]oo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`0QOol00`00Oomoo`17Ool00`00Oomoo`0POol00`00Oomoo`1EOol001ioo`05001o
ogooOol0000@Ool00`00Oomoo`02Ool2000AOol00`00Oomoo`0QOol00`00Oomoo`1/Ool00`00Oomo
o`0QOol00`00Oomoo`12Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P001goo00<007ooOol0
8Woo00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol0E7oo000NOol01@00Oomoogoo000037oo
10001Goo00<007ooOol03goo00<007ooOol08goo00<007ooOol0JWoo00<007ooOol08Woo00<007oo
Ool0@Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo
04Ioo`03001oogoo029oo`03001oogoo05Aoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Io
o`03001oogoo00moo`03001oogoo02=oo`03001oogoo06Uoo`03001oogoo02Aoo`03001oogoo045o
o`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0ROol00`00Oomo
o`16Ool00`00Oomoo`0ROol00`00Oomoo`1DOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06
Ool00`00Oomoo`0>Ool00`00Oomoo`0UOol00`00Oomoo`1XOol00`00Oomoo`0TOol00`00Oomoo`11
Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol08goo00<007oo
Ool0AGoo00<007ooOol08Woo00<007ooOol0E7oo000OOol3000=Ool40005Ool2000>Ool00`00Oomo
o`0VOol00`00Oomoo`1WOol00`00Oomoo`0VOol00`00Oomoo`11Ool3000=Ool40005Ool20006Ool0
0`00Oomoo`0TOol00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`1COol003Qoo`03001oogoo
00eoo`03001oogoo02Moo`03001oogoo06Ioo`03001oogoo02Moo`03001oogoo05Uoo`03001oogoo
00Eoo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo05=oo`00>7oo00<0
07ooOol037oo00<007ooOol0:7oo00<007ooOol0IGoo00<007ooOol0:7oo00<007ooOol0FGoo00<0
07ooOol01Goo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol0Dgoo000h
Ool2000=Ool00`00Oomoo`0YOol00`00Oomoo`1SOol00`00Oomoo`0ZOol00`00Oomoo`1HOol20006
Ool00`00Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`1BOol003Qoo`03001o
ogoo00]oo`03001oogoo02Yoo`03001oogoo06=oo`03001oogoo02Yoo`03001oogoo05Qoo`03001o
ogoo00Aoo`03001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03001oogoo059oo`00>7oo
00<007ooOol02goo00<007ooOol0:goo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0Egoo
00<007ooOol017oo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol0DWoo
000hOol00`00Oomoo`0:Ool00`00Oomoo`0]Ool00`00Oomoo`1POol00`00Oomoo`0/Ool00`00Oomo
o`1GOol00`00Oomoo`04Ool00`00Oomoo`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomo
o`1BOol003Qoo`8000]oo`03001oogoo02eoo`03001oogoo05moo`03001oogoo02ioo`03001oogoo
05Ioo`8000Eoo`03001oogoo02Moo`03001oogoo045oo`03001oogoo02Moo`03001oogoo055oo`00
>7oo00<007ooOol02Goo00<007ooOol0;goo00<007ooOol0GWoo00<007ooOol0;Woo00<007ooOol0
EWoo00<007ooOol00goo00<007ooOol0:7oo00<007ooOol0@7oo00<007ooOol0:7oo00<007ooOol0
DGoo000hOol00`00Oomoo`08Ool00`00Oomoo`0`Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool00`00
Oomoo`1EOol00`00Oomoo`03Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00
Oomoo`1AOol003Qoo`8000Uoo`03001oogoo035oo`03001oogoo05aoo`03001oogoo035oo`03001o
ogoo05Aoo`8000Aoo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo055o
o`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol01goo00<007ooOol0<Woo00<007oo
Ool0G7oo00<007ooOol0<Goo00<007ooOol0<goo0`001Woo0P0017oo1@0017oo10001Goo00<007oo
Ool00goo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol0D7oo000FOol0
1@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Moo`03
001oogoo03=oo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo035oo`05001oogooOol00005
Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0:Woo00<0
07ooOol0?Woo00<007ooOol0:Woo00<007ooOol0D7oo000>Ool60002Ool01@00Oomoogoo00003Goo
00<007ooOol027oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0=7oo00<007ooOol0FWoo
00<007ooOol0<goo00<007ooOol0:Goo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03
001oogoo051oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8000Mo
o`03001oogoo03Eoo`03001oogoo05Qoo`03001oogoo03Eoo`03001oogoo031oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`0ZOol00`00Oomoo`0nOol0
0`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005
Ool00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`1HOol00`00Oomoo`0eOol00`00Oomoo`0`
Ool01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00D007ooOomoo`0002ioo`03001oogoo
03eoo`03001oogoo02]oo`03001oogoo04moo`005Woo00D007ooOomoo`0000moo`03001oogoo009o
o`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo03Moo`03001oogoo05Ioo`03001oogoo03Mo
o`03001oogoo02moo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomo
ogoo0000;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo000FOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000Eoo`03001oogoo03Qoo`03001oogoo
05Ioo`03001oogoo03Moo`03001oogoo02moo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol01Woo0P000Woo00<007ooOol0;7oo00<007ooOol0?7oo00<007ooOol0;7oo00<007oo
Ool0Cgoo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`04Ool00`00Oomoo`0iOol00`00Oomo
o`1DOol00`00Oomoo`0iOol00`00Oomoo`0_Ool3000=Ool30005Ool40005Ool01@00Oomoogoo0000
;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo000hOol00`00Oomoo`03Ool00`00
Oomoo`0jOol00`00Oomoo`1DOol00`00Oomoo`0iOol00`00Oomoo`1@Ool01000Oomoo`00<7oo00<0
07ooOol0>goo00<007ooOol0;Goo00<007ooOol0CWoo000hOol00`00Oomoo`03Ool00`00Oomoo`0I
Ool30006Ool20004Ool5000>Ool00`00Oomoo`07Ool30006Ool20006Ool3000HOol30006Ool20005
Ool3000<Ool00`00Oomoo`0;Ool30006Ool20005Ool3000MOol01000Oomoogoo1@00BGoo00@007oo
Ool001ioo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<000moo`03001oogoo00Ioo`<000Io
o`8000Eoo`<001Eoo`04001oogooOol30006Ool20005Ool3000QOol5000DOol003Qoo`8000=oo`03
001oogoo01Uoo`05001oogooOol00005Ool20005Ool01000Oomoo`003Woo00<007ooOol01Woo00D0
07ooOomoo`0000Eoo`8000Moo`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool01@00Oomo
ogoo00002goo00<007ooOol02Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000LOol0
0`00Oomoo`03Ool00`00Oomoo`19Ool200000goo001oo`0LOol01@00Oomoogoo00001Goo0P001Goo
00@007oo000001Moo`05001oogooOol00005Ool20007Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool0
1@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Aoo`04001oogoo0003Ool00`00Oomoo`03
Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`02Ool00`00Oomo
o`0IOol01@00Oomoogoo00003Goo00<007ooOol03goo00<007ooOol01Goo00D007ooOomoo`0000]o
o`D001Moo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00<007ooOol02goo00D007ooOomo
o`0000]oo`05001oogooOol0000MOol00`00Oomoo`02Ool00`00Oomoo`19Ool01000Oomoo`007Goo
00D007ooOomoo`0000eoo`8001Qoo`05001oogooOol0000;Ool5000?Ool00`00Oomoo`05Ool01@00
Oomoogoo00002goo00D007ooOomoo`0001Eoo`03001oo`0000=oo`03001oogoo00Uoo`05001oogoo
Ool0000ROol00`00Oomoo`0DOol003Qoo`05001oogooOol0000LOol01@00Oomoogoo00003Woo00<0
07ooOol03Woo00<007ooOol01Goo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Yoo`03001oogoo00]oo`05001oogooOol0000;Ool01@00Oomoogoo
00007Goo00<007ooOol00Woo00<007ooOol0BGoo00<007oo00007Woo00D007ooOomoo`0000ioo`80
01Moo`05001oogooOol0000;Ool01000Oomoo`0047oo00<007ooOol01Goo00D007ooOomoo`0000]o
o`05001oogooOol0000EOol00`00Ool00003Ool00`00Oomoo`09Ool01@00Oomoogoo00008Woo00<0
07ooOol057oo000hOol01@00Oomoogoo000077oo00D007ooOomoo`0000moo`03001oogoo00ioo`03
001oogoo00Aoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10002Woo
00<007ooOol037oo00D007ooOomoo`0000aoo`<001ioo`03001oogoo009oo`03001oogoo04Uoo`03
001oo`0001ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo
00003goo00<007ooOol01Woo00D007ooOomoo`0000]oo`@001Ioo`03001oo`0000=oo`03001oogoo
00Yoo`<002=oo`03001oogoo01Aoo`00>7oo0P000Woo00<007ooOol06Woo00D007ooOomoo`0000mo
o`03001oogoo00ioo`03001oogoo00Aoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomo
ogoo00002goo00<007ooOol02goo00<007ooOol037oo00D007ooOomoo`0000]oo`05001oogooOol0
000NOol01@00Oomoogoo0000Bgoo0`007Woo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001o
ogooOol0000<Ool00`00Ool0000?Ool00`00Oomoo`06Ool01@00Oomoogoo00002goo00<007ooOol0
5goo00<007oo00000goo00<007ooOol02Goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo
00@007ooOol001eoo`05001oogooOol0000;Ool01@00Oomoogoo00004Goo00<007ooOol00goo00D0
07ooOomoo`0000eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool0
1@00Oomoogoo00002goo00D007ooOomoo`0001ioo`05001oogooOol0001;Ool00`00Ool0000NOol0
1@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000=Ool2000?Ool00`00Oomo
o`06Ool01@00Oomoogoo000037oo00<007ooOol05goo0P000goo00<007ooOol02Goo00D007ooOomo
o`00029oo`03001oogoo01Aoo`00>7oo00@007ooOol001ioo`<000eoo`<0019oo`03001oogoo00Ao
o`<000moo`03001oogoo01Moo`<000ioo`<000Qoo`03001oogoo00ioo`<000eoo`<0021oo`@004]o
o`80021oo`<000eoo`<00003Ool007oo01Ioo`<000moo`03001oogoo00aoo`03001oogoo00Qoo`<0
00ioo`<001Ioo`03001oo`00008000eoo`<0025oo`<001Ioo`00>7oo0`00AGoo00<007ooOol0BWoo
00<007ooOol0@Woo00<007ooOol0C7oo0P00=7oo00<007ooOol0=Woo00<007ooOol0<Woo00<007oo
Ool0C7oo000hOol00`00Ool00015Ool00`00Oomoo`1:Ool00`00Oomoo`13Ool00`00Oomoo`1;Ool2
000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`1<Ool003Qoo`8004Moo`03001oogoo
04Qoo`03001oogoo04Aoo`03001oogoo04]oo`8003Aoo`03001oogoo03Ioo`03001oogoo03=oo`03
001oogoo04]oo`00>7oo0P00Agoo00<007ooOol0B7oo00<007ooOol0AGoo00<007ooOol0BWoo00<0
07ooOol0=7oo00<007ooOol0=7oo00<007ooOol0=7oo00<007ooOol0Bgoo000bOooY0010OooY000@
Ool003Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Eoo`04001oogoo000:Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool01@00Oomoogoo00001Woo
00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol0BGoo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol057oo000hOol00`00Oomoo`18Ool00`00Oomo
o`14Ool00`00Oomoo`2DOol00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0eOol00`00Oomo
o`0cOol00`00Oomoo`0DOol003Qoo`8004Uoo`03001oogoo04Aoo`03001oogoo09Aoo`8003Ioo`03
001oogoo039oo`03001oogoo03Ioo`03001oogoo03=oo`03001oogoo01Aoo`00>7oo00<007ooOol0
BGoo00<007ooOol0@Woo00<007ooOol0UGoo00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0
=Woo00<007ooOol0<goo00<007ooOol057oo000hOol00`00Oomoo`19Ool00`00Oomoo`12Ool00`00
Oomoo`2EOol00`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00
Oomoo`0EOol003Qoo`03001oogoo04Yoo`03001oogoo041oo`03001oogoo09Ioo`03001oogoo03Eo
o`03001oogoo039oo`03001oogoo03Moo`03001oogoo035oo`03001oogoo01Eoo`00>7oo0P00Bgoo
00<007ooOol0@7oo00<007ooOol0UWoo0P00=goo00<007ooOol0<7oo00<007ooOol0>7oo00<007oo
Ool0<Goo00<007ooOol05Goo000hOol00`00Oomoo`1;Ool00`00Oomoo`0nOol00`00Oomoo`2GOol0
0`00Oomoo`0fOol00`00Oomoo`0`Ool00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`0FOol0
03Qoo`03001oogoo04]oo`03001oogoo03ioo`03001oogoo09Moo`03001oogoo03Ioo`03001oogoo
031oo`03001oogoo03Qoo`03001oogoo031oo`03001oogoo01Ioo`00>7oo00<007ooOol0C7oo00<0
07ooOol0?7oo00<007ooOol0V7oo00<007ooOol0=Woo00<007ooOol0<7oo00<007ooOol0>Goo00<0
07ooOol0;goo00<007ooOol05Woo000hOol2001=Ool00`00Oomoo`0lOol00`00Oomoo`2HOol2000h
Ool00`00Oomoo`0^Ool00`00Oomoo`0jOol00`00Oomoo`0_Ool00`00Oomoo`0FOol003Qoo`03001o
ogoo04aoo`03001oogoo03aoo`03001oogoo09Qoo`03001oogoo03Moo`03001oogoo02ioo`03001o
ogoo03Yoo`03001oogoo02ioo`03001oogoo01Moo`00>7oo00<007ooOol0CGoo00<007ooOol0>Woo
00<007ooOol0VGoo00<007ooOol0=goo00<007ooOol0;Woo00<007ooOol0>goo00<007ooOol0;Goo
00<007ooOol05goo000hOol2001>Ool00`00Oomoo`0jOol00`00Oomoo`2IOol2000hOol00`00Oomo
o`0^Ool00`00Oomoo`0kOol00`00Oomoo`0]Ool00`00Oomoo`0GOol001Moo`<000Ioo`8000Aoo`D0
00Aoo`@000Eoo`03001oogoo04ioo`03001oogoo03Qoo`03001oogoo07Uoo`<000Ioo`8000Aoo`D0
00Aoo`@000Eoo`03001oogoo03Qoo`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02eoo`03
001oogoo01Moo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02
Ool00`00Oomoo`1>Ool00`00Oomoo`0hOol00`00Oomoo`1hOol01@00Oomoogoo00001Goo0P001Goo
00@007ooOol000Qoo`03001oogoo009oo`03001oogoo03Qoo`03001oogoo02aoo`03001oogoo03ao
o`03001oogoo02aoo`03001oogoo01Qoo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo04moo`03001oogoo03Ioo`03001oogoo07Uoo`05001oogooOol0000=
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00Oomoo`0m
Ool00`00Oomoo`0[Ool00`00Oomoo`0HOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool2001@Ool00`00Oomoo`0fOol00`00Oomoo`1iOol01@00Oomoogoo00003Woo00<0
07ooOol01goo00<007ooOol00Woo0P00>Woo00<007ooOol0:Woo00<007ooOol0?Woo00<007ooOol0
:goo00<007ooOol067oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007oo
Ool0D7oo00<007ooOol0=7oo00<007ooOol0NWoo00D007ooOomoo`0000moo`03001oogoo009oo`@0
00Eoo`03001oogoo03Uoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo
01Uoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo051o
o`03001oogoo03Aoo`03001oogoo07Yoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00Oomo
o`0IOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00DWoo
00<007ooOol0<Woo00<007ooOol0Ngoo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool2000jOol00`00Oomoo`0ZOol00`00Oomoo`0oOol00`00Oomoo`0YOol00`00Oomoo`0I
Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo055oo`03001oogoo039oo`03001oogoo07ao
o`<000eoo`<000Eoo`@000Eoo`03001oogoo03Yoo`03001oogoo02Qoo`03001oogoo041oo`03001o
ogoo02Uoo`03001oogoo01Uoo`00>7oo00<007ooOol0DWoo00<007ooOol0<7oo00<007ooOol0WWoo
00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol0@7oo00<007ooOol0:7oo00<007ooOol06Woo
000hOol00`00Oomoo`1BOol00`00Oomoo`0_Ool00`00Oomoo`2OOol00`00Oomoo`0jOol00`00Oomo
o`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`0JOol003Qoo`8005=oo`03001oogoo
02moo`03001oogoo09moo`8003]oo`03001oogoo02Qoo`03001oogoo045oo`03001oogoo02Moo`03
001oogoo01Yoo`00>7oo00<007ooOol0Dgoo00<007ooOol0;Goo00<007ooOol0X7oo00<007ooOol0
>goo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol06goo000hOol00`00
Oomoo`1COol00`00Oomoo`0]Ool00`00Oomoo`2POol00`00Oomoo`0kOol00`00Oomoo`0VOol00`00
Oomoo`12Ool00`00Oomoo`0VOol00`00Oomoo`0KOol003Qoo`8005Eoo`03001oogoo02]oo`03001o
ogoo0:5oo`8003aoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01]o
o`00>7oo00<007ooOol0E7oo00<007ooOol0:goo00<007ooOol0XGoo00<007ooOol0>goo00<007oo
Ool09Woo00<007ooOol0@goo00<007ooOol09Goo00<007ooOol06goo000hOol00`00Oomoo`1EOol0
0`00Oomoo`0YOol00`00Oomoo`2ROol00`00Oomoo`0lOol00`00Oomoo`0TOol00`00Oomoo`14Ool0
0`00Oomoo`0TOol00`00Oomoo`0LOol003Qoo`03001oogoo05Ioo`03001oogoo02Qoo`03001oogoo
0:9oo`03001oogoo03aoo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo
01aoo`00>7oo0P00Egoo00<007ooOol09goo00<007ooOol0Xgoo0P00?Goo00<007ooOol097oo00<0
07ooOol0A7oo00<007ooOol097oo00<007ooOol077oo000OOol30006Ool20005Ool40005Ool00`00
Oomoo`1GOol00`00Oomoo`0UOol00`00Oomoo`2;Ool30006Ool20005Ool40005Ool00`00Oomoo`0l
Ool00`00Oomoo`0TOol00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`0LOol001ioo`05001o
ogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`1GOol00`00Oomoo`0UOol00`00Oomo
o`2:Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0?Goo00<007ooOol0
8Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol07Goo000NOol01@00Oomoogoo000047oo
00<007ooOol00Woo00<007ooOol0F7oo00<007ooOol08goo00<007ooOol0Rgoo00D007ooOomoo`00
011oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo029oo`03001oogoo04Ioo`03001oogoo
029oo`03001oogoo01eoo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`8005Yoo`03001o
ogoo029oo`03001oogoo08]oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000nOol00`00Oomo
o`0ROol00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`0MOol001ioo`05001oogooOol0000<
Ool40005Ool00`00Oomoo`1IOol00`00Oomoo`0QOol00`00Oomoo`2<Ool01@00Oomoogoo000037oo
10001Goo00<007ooOol0?Woo00<007ooOol08Goo00<007ooOol0Agoo00<007ooOol087oo00<007oo
Ool07Woo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0FWoo00<007ooOol0
7goo00<007ooOol0SGoo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo03ioo`03001o
ogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001oogoo01ioo`007Woo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`8005aoo`03001oogoo01eoo`03001oogoo08ioo`05001oogooOol0000<
Ool00`00Oomoo`06Ool2000oOol00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00
Oomoo`0NOol001moo`<000eoo`@000Eoo`03001oogoo05aoo`03001oogoo01aoo`03001oogoo08mo
o`<000eoo`@000Eoo`03001oogoo03moo`03001oogoo01moo`03001oogoo04Uoo`03001oogoo01mo
o`03001oogoo01ioo`00>7oo00<007ooOol0GGoo00<007ooOol06Woo00<007ooOol0ZGoo00<007oo
Ool0?goo00<007ooOol07Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol07goo000hOol0
0`00Oomoo`1NOol00`00Oomoo`0HOol00`00Oomoo`2ZOol00`00Oomoo`0oOol00`00Oomoo`0NOol0
0`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`0OOol003Qoo`8005moo`03001oogoo01Moo`03
001oogoo0:]oo`80045oo`03001oogoo01eoo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo
01moo`00>7oo00<007ooOol0Ggoo00<007ooOol05Goo00<007ooOol0[7oo00<007ooOol0@7oo00<0
07ooOol07Goo00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol07goo000hOol00`00Oomoo`1P
Ool00`00Oomoo`0COol00`00Oomoo`2]Ool00`00Oomoo`10Ool00`00Oomoo`0LOol00`00Oomoo`1<
Ool00`00Oomoo`0LOol00`00Oomoo`0POol003Qoo`80069oo`03001oogoo015oo`03001oogoo0:io
o`80049oo`03001oogoo01]oo`03001oogoo04eoo`03001oogoo01]oo`03001oogoo021oo`00>7oo
00<007ooOol0HWoo0`003goo00<007ooOol0[goo00<007ooOol0@Goo00<007ooOol06goo00<007oo
Ool0CGoo00<007ooOol06goo00<007ooOol087oo000hOol00`00Oomoo`1UOol00`00Oomoo`0:Ool2
002bOol00`00Oomoo`11Ool00`00Oomoo`0JOol00`00Oomoo`1>Ool00`00Oomoo`0JOol00`00Oomo
o`0QOol003Qoo`03001oogoo06Ioo`03001oogoo00Moo`800;Aoo`03001oogoo049oo`03001oogoo
01Uoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025oo`00>7oo0P00J7oo2@00]Woo0P00
@goo00<007ooOol06Goo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol08Goo000GOol30006
Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomo
o`04Ool40005Ool00`00Oomoo`12Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0IOol0
0`00Oomoo`0QOol001Ioo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol0@goo00<007ooOol05goo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol0
8Woo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo04=oo`03001o
ogoo01Moo`03001oogoo055oo`03001oogoo01Moo`03001oogoo029oo`005Woo00D007ooOomoo`00
00ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool20014Ool00`00Oomoo`0FOol00`00Oomoo`1BOol00`00Oomoo`0GOol0
0`00Oomoo`0ROol001Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3o
Ool5Ool01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0A7oo00<007ooOol0
5Goo00<007ooOol0Dgoo00<007ooOol05Goo00<007ooOol08goo000FOol01@00Oomoogoo00003goo
00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo04Aoo`03001oogoo01Aoo`03001oogoo05Aoo`03001o
ogoo01Eoo`03001oogoo02=oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Io
o`8004Eoo`03001oogoo01Aoo`03001oogoo05Aoo`03001oogoo01Aoo`03001oogoo02Aoo`005goo
0`0037oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`0037oo1@0017oo10001Goo00<007ooOol0
AGoo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04goo00<007ooOol097oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`15Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol0
0`00Oomoo`0UOol003Qoo`03001oogoo0?moobMoo`03001oogoo04Ioo`03001oogoo015oo`03001o
ogoo05Ioo`03001oogoo019oo`03001oogoo02Eoo`00>7oo0P00ogoo:7oo0P00Agoo00<007ooOol0
47oo00<007ooOol0F7oo00<007ooOol047oo00<007ooOol09Woo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`17Ool00`00Oomoo`0?Ool00`00Oomoo`1IOol00`00Oomoo`0?Ool00`00Oomoo`0VOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo04Moo`03001oogoo00ioo`03001oogoo05]oo`03001o
ogoo00ioo`03001oogoo02Ioo`00>7oo0P00ogoo:7oo0P00BGoo00<007ooOol03Goo00<007ooOol0
Fgoo00<007ooOol03Goo00<007ooOol09goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`18Ool0
0`00Oomoo`0<Ool00`00Oomoo`1MOol00`00Oomoo`0<Ool00`00Oomoo`0WOol003Qoo`03001oogoo
0?moobMoo`03001oogoo04Qoo`03001oogoo00aoo`03001oogoo05eoo`03001oogoo00]oo`03001o
ogoo02Qoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0BGoo00<007ooOol02Woo00<007ooOol0
Ggoo00<007ooOol02Woo00<007ooOol0:7oo000hOol2003oOolXOol2001;Ool00`00Oomoo`08Ool0
0`00Oomoo`1POol00`00Oomoo`08Ool2000[Ool002moo`D000Aoo`03001oogoo0?mooaioo`D000Ao
o`03001oogoo04]oo`03001oogoo00Ioo`03001oogoo069oo`03001oogoo00Ioo`03001oogoo02]o
o`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0C7oo00<0
07ooOol017oo00<007ooOol0I7oo0P001Goo00<007ooOol0;7oo000aOol00`00Oomoo`04Ool2003o
OolQOol00`00Oomoo`04Ool2001>Ool6001XOol6000_Ool0035oo`03001oogoo0?moobMoo`03001o
ogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00
nGoo003oOoooOomFOol00?mooomooeIoo`00UGoo0`0000Aoo`00000001Qoo`<00?moo`Moo`<00004
Ool00000000IOol3001dOol009Ioo`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000ogoo
1goo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001aoo`03
001oogoo0?moo`Eoo`05001oogooOol0000HOol5001dOol009Ioo`05001oogooOol00009Ool6000=
Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00002Goo1P002Goo00@007ooOol007Eoo`00UWoo00D0
07ooOomoo`0001Yoo`800?moo`Qoo`05001oogooOol0000IOol00`00Ool0001eOol009Eoo`D001eo
o`03001oogoo0?moo`Aoo`D001Yoo`03001oo`0007Eoo`00/goo00D007ooOomoo`000?moobIoo`80
07Eoo`00]7oo0`00ogoo:7oo00<007ooOol0Lgoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol002moo`D00?moobEoo`D00?Moo`00<Goo00<0
07ooOol0ogoo9goo00<007ooOol0mgoo000VOol60005Ool00`00Oomoo`3oOolLOol60005Ool00`00
Oomoo`3gOol0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<0
07ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomo
o`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Ao
o`800?moob5oo`03001oogoo00Aoo`800?5oo`00;goo0`001Woo00<007ooOol0ogoo7Woo0`001Woo
00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?mo
obMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol001Mo
o`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03
001oogoo00Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool000ioo`H0009oo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3lOol60002Ool01@00Oomoogoo00003Woo00<0
07ooOol01goo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001o
ogoo009oo`800?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo
0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05
001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomo
ogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo
00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool0
1@00Oomoogoo000017oo00<007ooOol01Woo0P00lGoo000GOol3000<Ool50004Ool40005Ool00`00
Oomoo`3oOol6Ool3000<Ool50004Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMo
o`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2
003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`3`Ool003Qoo`800?moobQoo`800?5oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo
3Woo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo
00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009o
o`03001oogoo0?1oo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`Io
o`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003aOol001ioo`05001oogooOol0000@
Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<0
07ooOol0l7oo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomo
o`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03
001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05
001oogooOol0000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol0
1Woo0P00lGoo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomo
o`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03
001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo
0P0017oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P0017oo1@0017oo10001Goo00<0
07ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009o
o`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol0
0Woo00<007ooOol0l7oo000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007oo
Ool00Woo0P00oGoo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`80
0?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?mo
o`Eoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Io
o`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo
00003goo00<007ooOol00Woo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00003goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03
001oogoo00Ioo`800?5oo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo0`003Goo
0`001Goo10001Goo00<007ooOol0l7oo000hOol00`00Oomoo`0OOol30006Ool20004Ool5000HOol3
0006Ool20006Ool3000HOol30006Ool20005Ool3000JOol30006Ool20005Ool3000QOol50019Ool0
0`00Oomoo`0OOol30006Ool20004Ool5000HOol30006Ool20006Ool3000HOol30006Ool20005Ool3
000IOol30006Ool20005Ool3000QOol5000DOol003Qoo`8001moo`05001oogooOol00005Ool20005
Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo01Ioo`05001oogooOol0
0005Ool20004Ool01@00Oomoogoo000067oo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0
000ROol00`00Oomoo`19Ool2000OOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05
001oogooOol00005Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00D007oo
Oomoo`0001Moo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol057oo
000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol05goo00D007ooOomoo`0000]o
o`D001Moo`05001oogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001o
ogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol0
5goo00D007ooOomoo`0000]oo`D001Moo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D0
07ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05
001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol001Qoo`05001o
ogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogooOol0000ROol0
0`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomo
o`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogoo
Ool0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomo
ogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0
000;Ool4000IOol01@00Oomoogoo000037oo0`008goo00<007ooOol0BGoo00<007ooOol07Woo00D0
07ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00Oomo
ogoo00002goo100067oo00D007ooOomoo`0000aoo`<002=oo`03001oogoo01Aoo`00>7oo0P007goo
00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000HOol01@00
Oomoogoo00002goo00<007ooOol06Woo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00
Oomoo`19Ool2000OOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03
001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007oo
Oomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000]oo`05001o
ogooOol0000GOol01@00Oomoogoo00003Goo0P0067oo00D007ooOomoo`0000aoo`03001oogoo01Uo
o`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol07Woo00D0
07ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00003Goo0P0067oo00D007ooOomo
o`0000aoo`03001oogoo01Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0
57oo000hOol00`00Oomoo`0OOol3000=Ool3000IOol3000?Ool00`00Oomoo`0GOol3000>Ool3000I
Ool3000=Ool3000QOol3001;Ool00`00Oomoo`0OOol3000=Ool3000IOol3000?Ool00`00Oomoo`0G
Ool3000>Ool3000HOol3000=Ool3000QOol3000FOol003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`03001oogoo0?moobMoo`03001oogoo0?1oo`00<Wooj@00@7ooj@0047oo000hOol00`00Ool00008
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Ool0001;
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`0DOol003Qoo`04001oogoo000XOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00
Oomoo`0ZOol00`00Oomoo`0VOol01000Oomoo`00Bgoo00<007ooOol0:Goo00<007ooOol0:Goo00<0
07ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol057oo000hOol01000Oomoogoo
0P00dWoo0P00Cgoo00<007ooOol0l7oo000hOol20004Ool00`00Oomoo`3>Ool00`00Oomoo`1?Ool2
003aOol003Qoo`03001oogoo00Aoo`03001oogoo0<aoo`03001oogoo051oo`03001oogoo0?1oo`00
>7oo00<007ooOol01Goo00<007ooOol0bWoo00<007ooOol0DGoo00<007ooOol0l7oo000hOol20007
Ool20038Ool2001DOol2003aOol003Qoo`03001oogoo00Qoo`03001oogoo0<=oo`8005Ioo`03001o
ogoo0?1oo`00>7oo00<007ooOol02Goo0P00`Woo00<007ooOol0EWoo00<007ooOol0l7oo000hOol0
0`00Oomoo`0;Ool00`00Oomoo`2mOol2001IOol00`00Oomoo`3`Ool003Qoo`8000eoo`03001oogoo
0;Yoo`8005]oo`800?5oo`00>7oo00<007ooOol03Goo0P00^Goo00<007ooOol0Fgoo00<007ooOol0
l7oo000hOol00`00Oomoo`0?Ool00`00Oomoo`2dOol2001NOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo011oo`800;=oo`03001oogoo05ioo`03001oogoo0?1oo`00>7oo0P004goo00<007ooOol0[Woo
0P00HGoo0P00lGoo000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`0COol2002]Ool0
0`00Oomoo`10Ool30006Ool20004Ool50004Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogoo
Ool00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol05Goo00<007ooOol0
Z7oo0P00@Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00
Oomoo`3`Ool001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000GOol2
002WOol00`00Oomoo`12Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P00
lGoo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol067oo
00<007ooOol0XWoo0P00AGoo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03
001oogoo0?1oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo01Uo
o`800:5oo`03001oogoo04Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomo
o`3`Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0K
Ool00`00Oomoo`2LOol20018Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol0l7oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Io
o`8001eoo`8009]oo`03001oogoo04Qoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<0
07ooOol01Woo0P00lGoo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`0NOol00`00Oomoo`2F
Ool2001<Ool3000=Ool30005Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo01moo`8009Eo
o`03001oogoo06eoo`03001oogoo0?1oo`00>7oo0P008Woo00<007ooOol0T7oo0P00L7oo0P00lGoo
000hOol00`00Oomoo`0ROol2002?Ool00`00Oomoo`1`Ool00`00Oomoo`3`Ool003Qoo`03001oogoo
02Aoo`8008]oo`8007=oo`03001oogoo0?1oo`00>7oo00<007ooOol09Woo0P00R7oo00<007ooOol0
Lgoo00<007ooOol0l7oo000hOol2000YOol00`00Oomoo`23Ool2001fOol2003aOol003Qoo`03001o
ogoo02Uoo`80089oo`03001oogoo07Ioo`03001oogoo0?1oo`00>7oo00<007ooOol0:goo0P00OWoo
0P00NGoo00<007ooOol0l7oo000hOol2000^Ool2001jOol2001kOol2003aOol003Qoo`03001oogoo
02moo`8007Ioo`8007eoo`03001oogoo0?1oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0
<Goo00<007ooOol0LWoo00<007ooOol0I7oo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000N
Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0<Woo0P00L7oo0P00IWoo
00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`007Woo00D007ooOomo
o`00011oo`03001oogoo009oo`8003Eoo`8006aoo`8006Qoo`05001oogooOol0000@Ool00`00Oomo
o`02Ool2003aOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0fOol2001W
Ool3001ZOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0l7oo000NOol01@00Oomo
ogoo000037oo10001Goo00<007ooOol0>7oo0P00Hgoo0P00KGoo00D007ooOomoo`0000aoo`@000Eo
o`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo03Yoo`80
05ioo`<006moo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool2000mOol2001JOol2001bOol01@00Oomoogoo000037oo00<0
07ooOol01Woo0P00lGoo000OOol3000=Ool40005Ool00`00Oomoo`0nOol3001EOol2001eOol3000=
Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo045oo`<0051oo`80091oo`03001oogoo0?1o
o`00>7oo0P00AGoo0`00Bgoo0P00TWoo0P00lGoo000hOol00`00Oomoo`17Ool30015Ool3002DOol0
0`00Oomoo`3`Ool003Qoo`03001oogoo04Yoo`<003moo`<009Moo`03001oogoo0?1oo`00>7oo00<0
07ooOol0CGoo0`00>Goo0`00VWoo00<007ooOol0l7oo000hOol2001AOol3000bOol4002MOol2003a
Ool003Qoo`03001oogoo05=oo`D002Qoo`D00:5oo`03001oogoo0?1oo`00>7oo00<007ooOol0F7oo
1@007goo1000YWoo00<007ooOol0l7oo000hOol2001NOol7000?Ool9002ZOol2003aOol001Moo`<0
00Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo06Aoo`l0099oo`<000Ioo`8000Ioo`03
001oogoo00Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80
0?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05
001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0
000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo
00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00002goo00D0
07ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000;Ool01@00
Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0l7oo000GOol3000<Ool50004Ool40005Ool2
003oOol7Ool3000<Ool50004Ool40005Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qo
o`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`800?moobQoo`800?5oo`00;goo1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo
000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035o
o`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<0
07ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00
Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo
00<007ooOol0mgoo000_Ool3003oOolWOol3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3
000017oo0000000067oo1@00ogoo1Goo0`0000Aoo`00000001Moo`D007Aoo`00UWoo00D007ooOomo
o`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000:Ool01000Oomoo`00
M7oo002FOol01@00Oomoogoo00006goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001Yoo`03001o
ogoo07Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol0
0009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool0
1@00Oomoogoo000077oo00<007ooOol0LWoo002EOol5000LOol00`00Oomoo`3oOol5Ool5000MOol0
0`00Oomoo`1bOol00;Ioo`03001oogoo0?moob=oo`05001oogooOol0001dOol00;Aoo`<00?moobIo
o`<007Eoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomF
Ool00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .27339 L
.08255 .25658 L
.10458 .24056 L
.12507 .22856 L
.14415 .22033 L
.14918 .21868 L
.15465 .21714 L
.15946 .216 L
.16457 .21503 L
.16917 .21436 L
.17178 .21407 L
.17423 .21385 L
.17538 .21377 L
.17647 .2137 L
.17746 .21365 L
.17852 .2136 L
.17967 .21356 L
.18073 .21354 L
.182 .21353 L
.18314 .21353 L
.18435 .21354 L
.18547 .21357 L
.1867 .21361 L
.18802 .21367 L
.19071 .21384 L
.19317 .21405 L
.1979 .21463 L
.20239 .21536 L
.21236 .21765 L
.22321 .22116 L
.24299 .23011 L
.26399 .2429 L
.30174 .27261 L
.34195 .30966 L
.38063 .34528 L
.40028 .36167 L
.42177 .3773 L
.44253 .38948 L
.4614 .39763 L
.47149 .40073 L
.47611 .40185 L
.48101 .40283 L
.4835 .40324 L
.48624 .40362 L
.48876 .40392 L
.49106 .40414 L
.49378 .40433 L
.49527 .4044 L
.49596 .40443 L
Mistroke
.49669 .40446 L
.498 .40449 L
.49921 .40451 L
.49996 .40451 L
.50065 .40451 L
.50196 .40449 L
.50313 .40446 L
.50438 .40442 L
.50556 .40436 L
.50663 .4043 L
.50926 .40411 L
.51175 .40386 L
.5167 .40321 L
.52208 .40224 L
.53169 .39985 L
.54056 .39692 L
.55926 .38855 L
.57988 .37619 L
.62014 .34461 L
.65888 .30888 L
.70007 .27103 L
.72063 .25411 L
.73974 .2404 L
.75939 .22887 L
.77791 .22075 L
.78775 .21762 L
.79293 .21633 L
.7984 .21522 L
.80302 .2145 L
.80546 .2142 L
.80809 .21394 L
.8105 .21375 L
.8127 .21363 L
.81375 .21359 L
.81491 .21356 L
.81599 .21354 L
.817 .21353 L
.81818 .21353 L
.81941 .21354 L
.82047 .21357 L
.82163 .21361 L
.82287 .21366 L
.82421 .21374 L
.82661 .21392 L
.82905 .21415 L
.83134 .21443 L
.83564 .21507 L
.84078 .21606 L
.84552 .21718 L
.85624 .22047 L
Mistroke
.87498 .22858 L
.89561 .24069 L
.93591 .27196 L
.97471 .30761 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .18702 L
.08255 .13407 L
.0932 .1108 L
.10458 .09023 L
.11009 .08202 L
.11531 .07535 L
.12038 .06993 L
.12507 .06587 L
.12951 .06288 L
.13178 .06168 L
.13422 .06064 L
.13549 .0602 L
.13666 .05985 L
.13784 .05956 L
.13895 .05935 L
.14022 .05917 L
.1409 .0591 L
.14161 .05905 L
.1423 .05902 L
.14295 .05902 L
.14415 .05905 L
.14531 .05915 L
.14656 .05932 L
.14773 .05953 L
.14881 .05979 L
.15143 .06061 L
.15392 .06167 L
.15886 .06457 L
.16423 .06889 L
.17383 .0796 L
.1827 .09278 L
.20137 .12989 L
.22197 .18329 L
.26217 .3099 L
.30086 .43193 L
.32051 .48363 L
.3309 .50645 L
.342 .52672 L
.35275 .54191 L
.35784 .54748 L
.36253 .55166 L
.36724 .55494 L
.36972 .55628 L
.37235 .55741 L
.37463 .55815 L
.37573 .55842 L
.37677 .55864 L
.37799 .55883 L
.37911 .55894 L
Mistroke
.38031 .55901 L
.38162 .55901 L
.38227 .55898 L
.38296 .55893 L
.38419 .55879 L
.38551 .55857 L
.38695 .55823 L
.38955 .55741 L
.39197 .55638 L
.39649 .55378 L
.40134 .55003 L
.40698 .54442 L
.41232 .53791 L
.42232 .52269 L
.44227 .48156 L
.4607 .43291 L
.50002 .30895 L
.53782 .18936 L
.55884 .13385 L
.56803 .11355 L
.57808 .09466 L
.58722 .08075 L
.59696 .06956 L
.60236 .06505 L
.60726 .06204 L
.60962 .06095 L
.61086 .06047 L
.61218 .06004 L
.61333 .05973 L
.61459 .05945 L
.61574 .05925 L
.61682 .05913 L
.61808 .05904 L
.61871 .05902 L
.61941 .05902 L
.62065 .05907 L
.62181 .05918 L
.62248 .05927 L
.62318 .05939 L
.62443 .05965 L
.62578 .06 L
.62725 .06048 L
.62973 .0615 L
.63238 .06287 L
.63715 .06611 L
.64214 .07053 L
.64686 .07566 L
.6557 .08768 L
.67568 .12564 L
.69413 .17199 L
Mistroke
.7335 .29387 L
.77136 .41524 L
.79241 .47323 L
.81166 .51534 L
.82118 .53139 L
.8262 .53847 L
.83155 .5449 L
.8367 .54998 L
.84136 .55361 L
.84361 .55504 L
.84604 .55634 L
.84835 .55734 L
.85045 .55804 L
.85159 .55835 L
.85283 .55861 L
.85414 .55882 L
.85538 .55895 L
.85653 .55901 L
.85776 .55901 L
.85881 .55896 L
.85997 .55884 L
.86063 .55875 L
.86132 .55864 L
.86256 .55838 L
.86535 .55755 L
.86777 .55656 L
.87041 .5552 L
.87569 .55157 L
.88133 .5464 L
.89148 .5338 L
.90173 .51699 L
.91284 .49449 L
.933 .44391 L
.97393 .31646 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34079 L
.10458 .37484 L
.14415 .40567 L
.18221 .43378 L
.22272 .46153 L
.26171 .48568 L
.30316 .50814 L
.34309 .52627 L
.3815 .54016 L
.40095 .54579 L
.42237 .55086 L
.44268 .55456 L
.45178 .55586 L
.46172 .55703 L
.4671 .55755 L
.4721 .55796 L
.47727 .55831 L
.48196 .55857 L
.48658 .55877 L
.4887 .55884 L
.49093 .55891 L
.49332 .55896 L
.49438 .55897 L
.49552 .55899 L
.49675 .559 L
.49789 .55901 L
.49859 .55901 L
.49925 .55902 L
.50049 .55902 L
.50163 .55901 L
.50286 .55901 L
.50401 .559 L
.50508 .55898 L
.50754 .55894 L
.51014 .55888 L
.51268 .5588 L
.51504 .55871 L
.5204 .55845 L
.5293 .55785 L
.53882 .55697 L
.54906 .55575 L
.56016 .55411 L
.58032 .55029 L
.62123 .53929 L
.66064 .52473 L
.69852 .5073 L
.73886 .48534 L
.77769 .46127 L
.81897 .43294 L
Mistroke
.85873 .40348 L
.89697 .37361 L
.93767 .3407 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33309 L
.10458 .35753 L
.14415 .37711 L
.18221 .39161 L
.20178 .39709 L
.21267 .39951 L
.22272 .40133 L
.23293 .40277 L
.23832 .40335 L
.24402 .40384 L
.24641 .40401 L
.24897 .40416 L
.25119 .40427 L
.25361 .40437 L
.25507 .40441 L
.25643 .40445 L
.25773 .40447 L
.2584 .40448 L
.25912 .40449 L
.25983 .4045 L
.26048 .4045 L
.26176 .40451 L
.26293 .40451 L
.26416 .4045 L
.26538 .40448 L
.26607 .40447 L
.26671 .40446 L
.26912 .4044 L
.27131 .40432 L
.27364 .40422 L
.27847 .40394 L
.2838 .40351 L
.29326 .40247 L
.30213 .40116 L
.32232 .39702 L
.34082 .39186 L
.38045 .37677 L
.41855 .35789 L
.45912 .33446 L
.49816 .31018 L
.53966 .28432 L
.57964 .26112 L
.61811 .24191 L
.63759 .23376 L
.65902 .22623 L
.67938 .2206 L
.69843 .21678 L
.70884 .2153 L
.71396 .21473 L
Mistroke
.71872 .2143 L
.72301 .214 L
.72758 .21376 L
.7302 .21366 L
.73148 .21362 L
.73266 .21359 L
.73371 .21357 L
.73487 .21355 L
.73603 .21353 L
.73725 .21353 L
.73856 .21353 L
.73977 .21353 L
.7404 .21354 L
.7411 .21354 L
.74251 .21357 L
.74375 .21359 L
.74508 .21363 L
.74748 .21371 L
.74985 .21381 L
.75235 .21395 L
.7568 .21425 L
.76198 .21471 L
.7668 .21523 L
.77773 .21677 L
.78828 .21871 L
.79823 .22094 L
.81683 .22612 L
.85534 .2407 L
.89632 .26099 L
.93577 .28385 L
.97371 .30745 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`0FOol6001YOol5001VOol003Qoo`800?moobQoo`8001Eoo`80
00Ioo`03001oogoo06Aoo`8000Eoo`03001oogoo06=oo`005goo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool04goo00<007ooOol01goo00<007ooOol0HWoo00<007ooOol01Woo00<007ooOol0HWoo000FOol0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo01=oo`03
001oogoo00Qoo`03001oogoo061oo`03001oogoo00Qoo`03001oogoo065oo`003Woo1P000Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000COol00`00Oomoo`0:Ool00`00Oomoo`1NOol0
0`00Oomoo`0:Ool00`00Oomoo`1POol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol04Goo00<007ooOol037oo00<007ooOol0G7oo00<007ooOol02goo00<007ooOol0
H7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo011oo`03001oogoo00eoo`03001o
ogoo05aoo`03001oogoo00aoo`03001oogoo05moo`005Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`1JOol00`00Oomoo`0>Ool0
0`00Oomoo`1NOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo
0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000@Ool0
0`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0?Ool00`00Oomoo`1NOol001Moo`<000aoo`D0
00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@000Eoo`03001oogoo00ioo`03001o
ogoo015oo`03001oogoo05Qoo`03001oogoo011oo`03001oogoo05eoo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol0EWoo00<007ooOol04Woo00<007ooOol0
G7oo000hOol2003oOolXOol2000?Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol0
0`00Oomoo`1LOol003Qoo`03001oogoo0?moobMoo`03001oogoo00eoo`03001oogoo01Aoo`03001o
ogoo05Eoo`03001oogoo01=oo`03001oogoo05]oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
3Goo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol057oo00<007ooOol0Fgoo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomoo`1COol00`00Oomoo`0EOol0
0`00Oomoo`1JOol003Qoo`800?moobQoo`8000aoo`03001oogoo01Moo`03001oogoo059oo`03001o
ogoo01Moo`03001oogoo05Uoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol02goo00<007ooOol0
67oo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol0FGoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`1HOol0
03Qoo`800?moobQoo`8000]oo`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03001o
ogoo05Qoo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo1000
1Goo00<007ooOol02Woo00<007ooOol06Woo00<007ooOol0CWoo00<007ooOol06Woo00<007ooOol0
F7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo01]oo`03001o
ogoo04ioo`03001oogoo01]oo`03001oogoo05Moo`005Woo1P000Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo0?moo`Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`09Ool00`00Oomoo`0LOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`1GOol0
01ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomoogoo000047oo00<0
07ooOol00Woo0P002Woo00<007ooOol077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol0
Egoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000ao
o`@000Eoo`03001oogoo00Qoo`03001oogoo01ioo`03001oogoo04]oo`03001oogoo01eoo`03001o
ogoo05Ioo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0NOol00`00Oomoo`1:Ool0
0`00Oomoo`0NOol00`00Oomoo`1FOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00
Oomoo`3oOol=Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
7Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000OOol3000=Ool40005Ool2003o
Ool?Ool3000=Ool40005Ool20008Ool00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol0
0`00Oomoo`1EOol003Qoo`03001oogoo0?moobMoo`03001oogoo00Moo`03001oogoo021oo`03001o
ogoo04Qoo`03001oogoo021oo`03001oogoo05Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
1goo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol087oo00<007ooOol0EGoo000hOol2003o
OolXOol20007Ool00`00Oomoo`0ROol00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`1DOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo04Ioo`03001o
ogoo029oo`03001oogoo05Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol01Woo00<007ooOol0
8Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol0E7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`06Ool00`00Oomoo`0SOol00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`1COol0
03Qoo`800?moobQoo`8000Ioo`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001o
ogoo05=oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol01Goo00<007ooOol097oo00<007ooOol0
A7oo00<007ooOol097oo00<007ooOol0Dgoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`05Ool0
0`00Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`1BOol003Qoo`8001eoo`d0
08Ioo``006]oo`8000Eoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo
059oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol067oo10003Goo1000OWoo1000
37oo1@00AGoo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol017oo00<007ooOol09Woo00<0
07ooOol0@Woo00<007ooOol09Woo00<007ooOol0DWoo000FOol01@00Oomoogoo00001Goo0P001Goo
00@007ooOol000Qoo`03001oogoo009oo`03001oogoo01Eoo`<001Eoo`8007Uoo`<001Eoo`80049o
o`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol09goo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol0DGoo000>Ool60002Ool0
1@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol04goo0P006Woo00<0
07ooOol0M7oo0P006Woo0P00>7oo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001o
ogoo055oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8001=oo`03
001oogoo01]oo`8007=oo`03001oogoo01aoo`8003ioo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00
Oomoo`1AOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`0AOol0
0`00Oomoo`0NOol3001_Ool00`00Oomoo`0OOol00`00Oomoo`0kOol01@00Oomoogoo00003goo00<0
07ooOol00Woo10001Goo00<007ooOol00goo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0
:Goo00<007ooOol0D7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol03goo0P0097oo0P00Jgoo0P008goo0P00>goo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo
02Yoo`03001oogoo051oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomo
o`06Ool2000?Ool00`00Oomoo`0VOol00`00Oomoo`1VOol2000WOol00`00Oomoo`0hOol01@00Oomo
ogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000=oo`03001oogoo02Yoo`03001o
ogoo03ioo`03001oogoo02Yoo`03001oogoo051oo`005goo0`003Goo0`001Goo10001Goo00<007oo
Ool03Goo00<007ooOol0:7oo00<007ooOol0I7oo00<007ooOol0:7oo00<007ooOol0>7oo0`003Goo
0`001Goo10001Goo00<007ooOol00Woo00<007ooOol0:goo00<007ooOol0?Goo00<007ooOol0:goo
00<007ooOol0Cgoo000hOol00`00Oomoo`0<Ool00`00Oomoo`0ZOol00`00Oomoo`1ROol00`00Oomo
o`0ZOol2001IOol01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0
Cgoo000hOol00`00Oomoo`0:Ool2000COol30006Ool20004Ool50007Ool00`00Oomoo`0>Ool30006
Ool20006Ool3000HOol30006Ool20005Ool3000COol00`00Oomoo`04Ool30006Ool20005Ool3000F
Ool00`00Oomoo`08Ool50019Ool01@00Oomoogoo00007Goo0`001Woo0P0017oo1@0067oo0`001Woo
0P001Woo0`0047oo00<007ooOol01Goo0`001Woo0P001Goo0`0057oo00<007ooOol00Woo0`001Woo
0P001Goo0`008Goo1@0057oo000hOol2000:Ool00`00Oomoo`0BOol01@00Oomoogoo00001Goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00aoo`05001oogooOol00005Ool20007Ool00`00Oomoo`0F
Ool01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00015oo`03001oogoo00Aoo`05001oogoo
Ool00005Ool20004Ool01@00Oomoogoo00005Woo00<007ooOol02Goo00<007ooOol0BGoo0P000Woo
00<007ooOol06Woo00D007ooOomoo`0000Eoo`8000Eoo`800003Ool007oo01Ioo`05001oogooOol0
0005Ool20007Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool01@00Oomoogoo00001Goo0P0017oo00D0
07ooOomoo`0001Aoo`04001oogoo0003Ool00`00Oomoo`03Ool20004Ool01@00Oomoogoo00008Woo
00<007ooOol057oo000hOol00`00Oomoo`08Ool00`00Oomoo`0COol01@00Oomoogoo00003Goo00<0
07ooOol02Goo00<007ooOol02goo00D007ooOomoo`0000]oo`D001Moo`05001oogooOol0000;Ool0
1@00Oomoogoo000047oo00<007ooOol01Goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol0
0`00Oomoo`08Ool00`00Oomoo`19Ool01000Oomoo`007Goo00D007ooOomoo`0000eoo`8001Qoo`05
001oogooOol0000;Ool5000?Ool00`00Oomoo`05Ool01@00Oomoogoo00002goo00D007ooOomoo`00
01Aoo`04001oogoo0003Ool00`00Oomoo`09Ool01@00Oomoogoo00008Woo00<007ooOol057oo000h
Ool00`00Oomoo`07Ool00`00Oomoo`0DOol01@00Oomoogoo00003Woo00<007ooOol02Goo0P002goo
00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomoo`0000io
o`8000Qoo`05001oogooOol0000;Ool01@00Oomoogoo000067oo0P0027oo00<007ooOol0BGoo00@0
07ooOol001eoo`05001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007oo
Ool0011oo`03001oogoo00Eoo`05001oogooOol0000;Ool01@00Oomoogoo000057oo00@007ooOol0
00=oo`03001oogoo00Uoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo00Eo
o`8001Moo`05001oogooOol0000?Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool01@00Oomoogoo0000
37oo00<007oo000067oo00D007ooOomoo`0000]oo`@000ioo`03001oogoo00Qoo`05001oogooOol0
000<Ool3000KOol00`00Oomoo`05Ool00`00Oomoo`19Ool01000Oomoo`007Goo00D007ooOomoo`00
00ioo`8001Moo`05001oogooOol0000<Ool00`00Ool0000@Ool00`00Oomoo`05Ool01@00Oomoogoo
00002goo10005Woo00<007oo00000goo00<007ooOol02Woo0`008goo00<007ooOol057oo000hOol2
0005Ool00`00Oomoo`0GOol01@00Oomoogoo00003goo00<007ooOol02goo00<007ooOol01goo00D0
07ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`0>Ool00`00Oomo
o`09Ool01@00Oomoogoo00002goo00D007ooOomoo`0001]oo`03001oogoo00Aoo`03001oogoo04Uo
o`<001ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo0000
3goo00<007ooOol01Woo00D007ooOomoo`0000]oo`03001oogoo01Moo`03001oo`0000=oo`03001o
ogoo00Uoo`05001oogooOol0000ROol00`00Oomoo`0DOol003Qoo`03001oogoo00=oo`03001oogoo
01Qoo`05001oogooOol0000;Ool01@00Oomoogoo00003Woo00<007ooOol01Woo00D007ooOomoo`00
00eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool01@00Oomoogoo
00002goo00D007ooOomoo`0001aoo`03001oogoo00=oo`03001oogoo04Uoo`03001oo`0001ioo`05
001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8000moo`03001oogoo
00Ioo`05001oogooOol0000<Ool00`00Oomoo`0FOol00`00Ool00003Ool00`00Oomoo`09Ool01@00
Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`02Ool00`00Oomoo`0JOol3000=Ool3
000@Ool00`00Oomoo`06Ool3000?Ool00`00Oomoo`0GOol3000>Ool3000:Ool00`00Oomoo`0<Ool3
000=Ool3000NOol00`00Oomoo`03001;Ool00`00Ool0000OOol3000=Ool4000HOol3000?Ool00`00
Oomoo`0=Ool00`00Oomoo`07Ool3000>Ool3000FOol00`00Ool00002000=Ool3000QOol3000FOol0
03Qoo`80009oo`03001oogoo03moo`03001oogoo04ioo`03001oogoo03moo`03001oogoo04eoo`80
03Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo00@007ooOol004=oo`03
001oogoo04aoo`03001oogoo045oo`03001oogoo04aoo`8003Aoo`03001oogoo03Ioo`03001oogoo
039oo`03001oogoo04aoo`00>7oo00<007oo0000AGoo00<007ooOol0BWoo00<007ooOol0@goo00<0
07ooOol0Bgoo0P00=7oo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol0C7oo000hOol20017
Ool00`00Oomoo`18Ool00`00Oomoo`15Ool00`00Oomoo`1:Ool00`00Oomoo`0dOol00`00Oomoo`0d
Ool00`00Oomoo`0dOol00`00Oomoo`1;Ool0039oonT0041oonT0011oo`00>7oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol01goo0P002Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007oo000027oo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0BGoo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool057oo000hOol00`00Oomoo`1:Ool00`00Oomoo`10Ool00`00Oomoo`2FOol00`00Oomoo`0dOol0
0`00Oomoo`0dOol00`00Oomoo`0eOol00`00Oomoo`0cOol00`00Oomoo`0DOol003Qoo`8004aoo`03
001oogoo03ioo`03001oogoo09Moo`8003Ioo`03001oogoo039oo`03001oogoo03Ioo`03001oogoo
03=oo`03001oogoo01Aoo`00>7oo00<007ooOol0C7oo00<007ooOol0?7oo00<007ooOol0V7oo00<0
07ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol05Goo000h
Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00Oomoo`2IOol00`00Oomoo`0eOol00`00Oomoo`0b
Ool00`00Oomoo`0gOol00`00Oomoo`0aOol00`00Oomoo`0EOol003Qoo`03001oogoo04ioo`03001o
ogoo03Qoo`03001oogoo09Yoo`03001oogoo03Ioo`03001oogoo031oo`03001oogoo03Qoo`03001o
ogoo035oo`03001oogoo01Eoo`00>7oo0P00D7oo00<007ooOol0=Woo00<007ooOol0Vgoo0P00=goo
00<007ooOol0<7oo00<007ooOol0>7oo00<007ooOol0<7oo00<007ooOol05Woo000hOol00`00Oomo
o`1@Ool00`00Oomoo`0cOol2002NOol00`00Oomoo`0fOol00`00Oomoo`0`Ool00`00Oomoo`0iOol0
0`00Oomoo`0_Ool00`00Oomoo`0FOol003Qoo`03001oogoo055oo`03001oogoo035oo`03001oogoo
09ioo`03001oogoo03Moo`03001oogoo02ioo`03001oogoo03Yoo`03001oogoo02moo`03001oogoo
01Ioo`00>7oo00<007ooOol0DWoo00<007ooOol0;goo00<007ooOol0Wgoo00<007ooOol0=goo00<0
07ooOol0;Woo00<007ooOol0>Woo00<007ooOol0;Woo00<007ooOol05goo000hOol2001DOol00`00
Oomoo`0/Ool2002ROol2000hOol00`00Oomoo`0^Ool00`00Oomoo`0kOol00`00Oomoo`0]Ool00`00
Oomoo`0GOol003Qoo`03001oogoo05Aoo`8002]oo`03001oogoo0:9oo`03001oogoo03Qoo`03001o
ogoo02aoo`03001oogoo03aoo`03001oogoo02eoo`03001oogoo01Moo`00>7oo00<007ooOol0EWoo
00<007ooOol09goo00<007ooOol0Xgoo00<007ooOol0>7oo00<007ooOol0;7oo00<007ooOol0?7oo
00<007ooOol0;7oo00<007ooOol067oo000hOol2001HOol00`00Oomoo`0UOol00`00Oomoo`2TOol2
000iOol00`00Oomoo`0/Ool00`00Oomoo`0mOol00`00Oomoo`0[Ool00`00Oomoo`0HOol001Moo`<0
00Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo05Qoo`03001oogoo029oo`8008Ioo`<000Ioo`80
00Aoo`D000Aoo`@000Eoo`03001oogoo03Uoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo
02]oo`03001oogoo01Qoo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00
Oomoo`02Ool00`00Oomoo`1IOol2000POol20027Ool01@00Oomoogoo00001Goo0P001Goo00@007oo
Ool000Qoo`03001oogoo009oo`03001oogoo03Uoo`03001oogoo02Yoo`03001oogoo03ioo`03001o
ogoo02Yoo`03001oogoo01Uoo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo05]oo`<001aoo`03001oogoo08Moo`05001oogooOol0000=Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0oOol00`00Oomoo`0Y
Ool00`00Oomoo`0IOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2
001OOol2000HOol2002:Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00
>goo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol06Goo000FOol01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0H7oo0P0057oo0P00S7oo00D007oo
Oomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo03Yoo`03001oogoo02Qoo`03001oogoo
041oo`03001oogoo02Qoo`03001oogoo01Yoo`005Woo00D007ooOomoo`0000moo`03001oogoo009o
o`03001oogoo00Ioo`03001oogoo069oo`<000moo`8008ioo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`0jOol00`00Oomoo`0XOol00`00Oomoo`11Ool00`00Oomo
o`0WOol00`00Oomoo`0JOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P00IWoo0P002Goo1000T7oo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool2000lOol00`00Oomoo`0WOol00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`0J
Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo06Moo`T009Eoo`<000eoo`<000Eoo`@000Eo
o`03001oogoo03]oo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01]o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0>goo00<007ooOol09Woo00<007ooOol0@goo00<0
07ooOol09Goo00<007ooOol06goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0lOol00`00Oomo
o`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`0KOol003Qoo`800?moobQoo`8003eo
o`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo01aoo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0?7oo00<007ooOol097oo00<007ooOol0AGoo00<007ooOol08goo00<0
07ooOol077oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`0mOol00`00Oomoo`0SOol00`00Oomo
o`15Ool00`00Oomoo`0SOol00`00Oomoo`0LOol003Qoo`800?moobQoo`8003ioo`03001oogoo029o
o`03001oogoo04Ioo`03001oogoo029oo`03001oogoo01eoo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0?Goo00<007ooOol08Woo00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol07Goo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`0nOol00`00Oomoo`0QOol00`00Oomoo`17Ool00`00Oomo
o`0QOol00`00Oomoo`0MOol003Qoo`03001oogoo0?moobMoo`03001oogoo03ioo`03001oogoo021o
o`03001oogoo04Qoo`03001oogoo021oo`03001oogoo01ioo`00>7oo0P00ogoo:7oo0P00?goo00<0
07ooOol087oo00<007ooOol0BGoo00<007ooOol07goo00<007ooOol07Woo000OOol30006Ool20005
Ool40005Ool00`00Oomoo`3oOol>Ool30006Ool20005Ool40005Ool00`00Oomoo`0oOol00`00Oomo
o`0OOol00`00Oomoo`19Ool00`00Oomoo`0NOol00`00Oomoo`0OOol001ioo`05001oogooOol00005
Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol00Woo00<007ooOol0?goo00<007ooOol07Woo00<007ooOol0BWoo00<007ooOol07Woo00<0
07ooOol07goo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`00011oo`03001oogoo009oo`03001oogoo041oo`03001oogoo01eoo`03001oogoo04]o
o`03001oogoo01eoo`03001oogoo01moo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`80
0?moo`ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool20011Ool00`00Oomoo`0MOol00`00Oomo
o`1;Ool00`00Oomoo`0LOol00`00Oomoo`0POol001ioo`05001oogooOol0000<Ool40005Ool00`00
Oomoo`3oOol=Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0@Goo00<007ooOol06goo00<0
07ooOol0C7oo00<007ooOol077oo00<007ooOol087oo000NOol01@00Oomoogoo000037oo00<007oo
Ool01Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo045o
o`03001oogoo01]oo`03001oogoo04eoo`03001oogoo01]oo`03001oogoo021oo`007Woo00D007oo
Oomoo`0000aoo`03001oogoo00Ioo`800?moo`ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2
0012Ool00`00Oomoo`0KOol00`00Oomoo`1=Ool00`00Oomoo`0JOol00`00Oomoo`0QOol001moo`<0
00eoo`@000Eoo`03001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo049oo`03001oogoo01Uo
o`03001oogoo04moo`03001oogoo01Uoo`03001oogoo025oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0@Woo00<007ooOol06Goo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol08Goo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`13Ool00`00Oomoo`0GOol00`00Oomoo`1@Ool00`00Oomo
o`0HOol00`00Oomoo`0ROol003Qoo`800?moobQoo`8004Aoo`03001oogoo01Moo`03001oogoo055o
o`03001oogoo01Moo`03001oogoo029oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0@goo00<0
07ooOol05Woo00<007ooOol0DWoo00<007ooOol05goo00<007ooOol08Woo000hOol00`00Oomoo`3o
OolWOol00`00Oomoo`14Ool00`00Oomoo`0DOol00`00Oomoo`1DOol00`00Oomoo`0EOol00`00Oomo
o`0SOol003Qoo`800?moobQoo`8004Eoo`03001oogoo01Aoo`03001oogoo05Aoo`03001oogoo01Ao
o`03001oogoo02Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0A7oo00<007ooOol04goo00<0
07ooOol0EGoo00<007ooOol057oo00<007ooOol097oo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`15Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol00`00Oomoo`0UOol003Qoo`03
001oogoo0?moobMoo`03001oogoo04Ioo`03001oogoo011oo`03001oogoo05Qoo`03001oogoo015o
o`03001oogoo02Eoo`00>7oo0P00ogoo:7oo0P00B7oo00<007ooOol03goo00<007ooOol0FGoo00<0
07ooOol03goo00<007ooOol09Woo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00
Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`17Ool00`00Oomo
o`0>Ool00`00Oomoo`1KOol00`00Oomoo`0>Ool00`00Oomoo`0VOol001Ioo`05001oogooOol00005
Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo0000
1Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0B7oo00<007ooOol03Goo00<0
07ooOol0Fgoo00<007ooOol03Goo00<007ooOol09goo000FOol01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo04Qoo`03001oogoo00aoo`03001oogoo05eoo`03001oogoo00ao
o`03001oogoo02Moo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80
0?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2001:Ool00`00Oomo
o`0:Ool00`00Oomoo`1OOol00`00Oomoo`0:Ool00`00Oomoo`0XOol001Ioo`05001oogooOol0000>
Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol0
0goo10001Goo00<007ooOol0BWoo00<007ooOol027oo00<007ooOol0H7oo00<007ooOol027oo0P00
:goo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo
1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo04]oo`03001o
ogoo00Ioo`03001oogoo069oo`8000Moo`03001oogoo02]oo`005Woo00D007ooOomoo`0000]oo`05
001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomo
o`0000Aoo`03001oogoo00Ioo`8004eoo`<000=oo`8006Moo`8000=oo`8002ioo`005goo0`0037oo
1@0017oo10001Goo00<007ooOol0ogoo1Woo0`0037oo1@0017oo10001Goo00<007ooOol0CWoo1000
JWoo1000<7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMo
o`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000h
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1o
o`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol002moo`D0
00Aoo`03001oogoo0?mooaioo`D000Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007oo
Ool0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol0
0`00Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007oo
Ool0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03
001oogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00nGoo003oOoooOomFOol00?mo
oomooeIoo`00UGoo0`0000Aoo`00000001Qoo`<00?moo`Moo`<00004Ool00000000IOol3001dOol0
09Ioo`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000ogoo1goo00D007ooOomoo`0000Uo
o`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001aoo`03001oogoo0?moo`Eoo`05001o
ogooOol0000HOol5001dOol009Ioo`05001oogooOol00009Ool6000=Ool00`00Oomoo`3oOol5Ool0
1@00Oomoogoo00002Goo1P002Goo00@007ooOol007Eoo`00UWoo00D007ooOomoo`0001Yoo`800?mo
o`Qoo`05001oogooOol0000IOol00`00Ool0001eOol009Eoo`D001eoo`03001oogoo0?moo`Aoo`D0
01Yoo`03001oo`0007Eoo`00/goo00D007ooOomoo`000?moobIoo`8007Eoo`00]7oo0`00ogoo:7oo
00<007ooOol0Lgoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomF
Ool00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol002moo`D00?moobEoo`D00?Moo`00<Goo00<007ooOol0ogoo9goo00<007oo
Ool0mgoo000VOol60005Ool00`00Oomoo`3oOolLOol60005Ool00`00Oomoo`3gOol0035oo`03001o
ogoo00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol017oo00<007ooOol0
ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolP
Ool00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo
00Aoo`800?5oo`00;goo0`001Woo00<007ooOol0ogoo7Woo0`001Woo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol001Moo`<000Ioo`8000Ioo`03001o
ogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03
001oogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009o
o`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`3`Ool000ioo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`3lOol60002Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo
0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?5oo`005Woo
00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0
000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000?Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`00
00Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<0
07ooOol01Woo0P00lGoo000GOol3000<Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool3000<Ool5
0004Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003o
OolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`800?5oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo1000
1Goo00<007ooOol0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007oo
Ool0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`005Woo
1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`Ioo`H0009oo`05001oogooOol0
000@Ool00`00Oomoo`02Ool2003aOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0l7oo000NOol01@00
Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001o
ogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00
Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P00lGoo000OOol3000=
Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003o
OolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`2MOol<0017Ool003Qoo`800?moobQoo`8009Qoo`H000aoo`L0041oo`005goo0`001Woo
0P0017oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P0017oo1@0017oo10001Goo00<0
07ooOol0Tgoo10006Goo1000?7oo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qo
o`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`00
27oo00<007ooOol00Woo00<007ooOol0Sgoo10008Goo0`00>Goo000>Ool60002Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo0P00oGoo1P000Woo00D007ooOomoo`0000eoo`03
001oogoo00Qoo`03001oogoo009oo`8008eoo`<002Qoo`<003Ioo`005Woo00D007ooOomoo`0000io
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`2:Ool2000^Ool3000cOol001Ioo`05001oogooOol0
000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007oo
Ool00Woo10001Goo00<007ooOol0R7oo0P00<goo0P00<Goo000FOol01@00Oomoogoo00003goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo08Ioo`8003Moo`8002moo`005Woo00D007ooOomoo`0000]o
o`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`8008Eoo`8003]oo`8002eoo`005goo0`003Goo0`001Goo1000
1Goo00<007ooOol0ogoo1Woo0`003Goo0`001Goo10001Goo00<007ooOol0PGoo0`00?goo0P00:goo
000hOol00`00Oomoo`0OOol30006Ool20004Ool5000HOol30006Ool20006Ool3000HOol30006Ool2
0005Ool3000JOol30006Ool20005Ool3000QOol50019Ool00`00Oomoo`0OOol30006Ool20004Ool5
000HOol30006Ool20006Ool3000HOol30005Ool30005Ool3000IOol30006Ool20005Ool3000?Ool2
000@Ool5000DOol003Qoo`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`005goo00D0
07ooOomoo`0000Eoo`8000Moo`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool01@00Oomo
ogoo000067oo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000ROol00`00Oomoo`19Ool2
000OOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool20007
Ool00`00Oomoo`0FOol01@00Oomoogoo00000Woo0P0000=oo`00000017oo00D007ooOomoo`0001Mo
o`05001oogooOol00005Ool20004Ool01@00Oomoogoo000047oo0P0047oo00<007ooOol057oo000h
Ool00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol05goo00D007ooOomoo`0000]oo`D0
01Moo`05001oogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogoo
Ool0000ROol00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol05goo
00D007ooOomoo`0000]oo`D001Moo`04001oogooOol30009Ool01@00Oomoogoo00005goo00D007oo
Oomoo`0000]oo`05001oogooOol0000BOol2000>Ool00`00Oomoo`0DOol003Qoo`03001oogoo01io
o`05001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol001Qoo`05
001oogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogooOol0000R
Ool00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Woo00<007ooOol05Woo00D007oo
Oomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001o
ogooOol0000;Ool01@00Oomoogoo000057oo0P0037oo00<007ooOol057oo000hOol00`00Oomoo`0N
Ool01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05
001oogooOol0000;Ool4000IOol01@00Oomoogoo000037oo0`008goo00<007ooOol0BGoo00<007oo
Ool07Woo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000H
Ool00`00Ool00002000;Ool4000HOol01@00Oomoogoo000037oo0`005goo00<007ooOol02Goo00<0
07ooOol057oo000hOol2000OOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`00
00aoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00Oomoo`0JOol01@00Oomoogoo00002goo
00D007ooOomoo`00029oo`03001oogoo04Uoo`8001moo`05001oogooOol0000?Ool00`00Oomoo`0E
Ool01@00Oomoogoo000037oo00<007oo000067oo0P000Woo00<007ooOol02Goo00<007ooOol06Goo
00D007ooOomoo`0000]oo`05001oogooOol0000GOol20009Ool00`00Oomoo`0DOol003Qoo`03001o
ogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8001Qo
o`05001oogooOol0000<Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`00029o
o`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D0
07ooOomoo`0000eoo`8001Moo`8000=oo`03001oogoo00Yoo`03001oogoo01Qoo`05001oogooOol0
000;Ool01@00Oomoogoo00006Goo0P001goo00<007ooOol057oo000hOol00`00Oomoo`0OOol3000=
Ool3000IOol3000?Ool00`00Oomoo`0GOol3000>Ool3000IOol3000=Ool3000QOol3001;Ool00`00
Oomoo`0OOol3000=Ool3000IOol3000?Ool00`00Oomoo`0COol20002Ool3000>Ool3000HOol3000=
Ool3000LOol00`00Oomoo`02Ool3000FOol003Qoo`03001oogoo0?moobMoo`03001oogoo079oo`03
001oogoo05ioo`8001]oo`00>7oo0P00ogoo:7oo0P00LGoo0P00Hgoo00<007ooOol067oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`1_Ool00`00Oomoo`1TOol2000HOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo06eoo`8006Uoo`03001oogoo01Eoo`00<Wooj@00@7ooj@0047oo000hOol00`00
Ool00008Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00
Ool0001;Ool00`00Ool00008Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`07Ool2000:Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`0DOol003Qoo`04001oogoo000XOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00
Oomoo`0ZOol00`00Oomoo`0VOol01000Oomoo`00Bgoo00<007ooOol00P009goo00<007ooOol0:Goo
00<007ooOol047oo0P005goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol057oo000hOol0
1@00Oomoogoo0000e7oo00<007ooOol0CGoo00<007ooOol00Woo00<007ooOol0HGoo0P00R7oo000h
Ool20003Ool00`00Oomoo`3@Ool00`00Oomoo`1>Ool20004Ool2001POol00`00Oomoo`28Ool003Qo
o`03001oogoo00=oo`03001oogoo0<ioo`03001oogoo04moo`03001oogoo00Eoo`03001oogoo05]o
o`8008]oo`00>7oo00<007ooOol017oo00<007ooOol0c7oo00<007ooOol0D7oo00<007ooOol01Woo
0P00FGoo0P00SGoo000hOol20006Ool00`00Oomoo`3:Ool00`00Oomoo`1AOol20009Ool2001EOol2
002?Ool003Qoo`03001oogoo00Ioo`800<Qoo`8005Aoo`03001oogoo00Yoo`80059oo`03001oogoo
08moo`00>7oo00<007ooOol027oo00<007ooOol0a7oo00<007ooOol0E7oo00<007ooOol037oo00<0
07ooOol0CGoo0P00TWoo000hOol00`00Oomoo`09Ool20032Ool2001GOol00`00Oomoo`0=Ool2001;
Ool2002DOol003Qoo`8000aoo`03001oogoo0;ioo`03001oogoo05Moo`80011oo`8004Qoo`03001o
ogoo09Aoo`00>7oo00<007ooOol037oo00<007ooOol0_7oo00<007ooOol0F7oo00<007ooOol04Goo
0P00A7oo0P00Ugoo000hOol00`00Oomoo`0=Ool2002jOol2001KOol00`00Oomoo`0COol20010Ool2
002IOol003Qoo`03001oogoo00moo`03001oogoo0;Ioo`03001oogoo05]oo`03001oogoo01Eoo`80
03]oo`<009]oo`00>7oo0P004Goo0P00]7oo0P00GWoo0P0067oo0P00=goo0P00WWoo000GOol30006
Ool20004Ool50004Ool40005Ool00`00Oomoo`0BOol00`00Oomoo`2`Ool00`00Oomoo`0mOol30006
Ool20004Ool50004Ool40005Ool00`00Oomoo`0IOol2000cOol2002POol001Ioo`05001oogooOol0
0005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol04goo00<007ooOol0[Woo
00<007ooOol0?Goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`0KOol3000]Ool3002ROol001Ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool2000EOol00`00Oomoo`2[Ool20010Ool01@00Oomoogoo00003Goo00<007ooOol027oo
00<007ooOol00Woo0P007goo0`009goo0`00YGoo000FOol01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol05Goo00<007ooOol0ZGoo00<007ooOol0@7oo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo025oo`80029oo`<00:Qoo`005Woo
00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo01Ioo`03001oogoo0:Moo`03
001oogoo045oo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`0SOol3000M
Ool2002[Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`0GOol00`00Oomoo`2UOol00`00Oomoo`12Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol09Woo1@005Goo0`00[Goo000FOol01@00Oomoogoo00002goo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`8001Uoo`03001oogoo0:9oo`8004Eoo`05001oogooOol0000;
Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00;7oo5@00/7oo000GOol3000=Ool30005Ool4
0005Ool00`00Oomoo`0IOol2002QOol00`00Oomoo`16Ool3000=Ool30005Ool40005Ool00`00Oomo
o`3`Ool003Qoo`03001oogoo01]oo`03001oogoo09eoo`03001oogoo06Qoo`03001oogoo0?1oo`00
>7oo0P007Goo0P00Vgoo0P00Jgoo0P00lGoo000hOol00`00Oomoo`0NOol00`00Oomoo`2GOol00`00
Oomoo`1[Ool00`00Oomoo`3`Ool003Qoo`03001oogoo01moo`8009Ioo`03001oogoo06aoo`03001o
ogoo0?1oo`00>7oo00<007ooOol08Goo00<007ooOol0TWoo00<007ooOol0KGoo00<007ooOol0l7oo
000hOol2000SOol2002@Ool2001`Ool2003aOol003Qoo`03001oogoo02Aoo`03001oogoo08aoo`03
001oogoo071oo`03001oogoo0?1oo`00>7oo00<007ooOol09Goo00<007ooOol0RWoo00<007ooOol0
LGoo00<007ooOol0l7oo000hOol2000WOol20028Ool2001dOol2003aOol003Qoo`03001oogoo02Qo
o`03001oogoo08Aoo`03001oogoo07Aoo`03001oogoo0?1oo`007goo0`001Woo0P001Goo10001Goo
00<007ooOol0:Goo00<007ooOol0PWoo00<007ooOol0G7oo0`001Woo0P001Goo10001Goo00<007oo
Ool0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0:Woo00<0
07ooOol0P7oo00<007ooOol0G7oo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001o
ogoo0?1oo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`8002aoo`8007ioo`8005moo`05
001oogooOol0000@Ool00`00Oomoo`02Ool2003aOol001ioo`05001oogooOol0000@Ool00`00Oomo
o`02Ool00`00Oomoo`0]Ool2001jOol2001QOol01@00Oomoogoo000047oo00<007ooOol00Woo00<0
07ooOol0l7oo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0;goo0P00MWoo0P00Hgoo
00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`03001oogoo035oo`03001oogoo079oo`03001oogoo06=oo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2000c
Ool2001`Ool2001VOol01@00Oomoogoo000037oo00<007ooOol01Woo0P00lGoo000OOol3000=Ool4
0005Ool00`00Oomoo`0dOol2001/Ool2001YOol3000=Ool40005Ool00`00Oomoo`3`Ool003Qoo`03
001oogoo03Ioo`8006Qoo`8008Aoo`03001oogoo0?1oo`00>7oo0P00>Goo0P00I7oo0P00QWoo0P00
lGoo000hOol00`00Oomoo`0jOol2001POol20028Ool00`00Oomoo`3`Ool003Qoo`03001oogoo03ao
o`8005aoo`8008Yoo`03001oogoo0?1oo`00>7oo00<007ooOol0?Woo0P00F7oo0P00S7oo00<007oo
Ool0l7oo000hOol20011Ool2001DOol2002>Ool2003aOol003Qoo`03001oogoo049oo`80051oo`80
091oo`03001oogoo0?1oo`00>7oo00<007ooOol0A7oo00<007ooOol0Bgoo0P00TWoo00<007ooOol0
l7oo000hOol20016Ool20019Ool2002DOol2003aOol001Moo`<000Ioo`8000Ioo`03001oogoo00Ao
o`@000Eoo`03001oogoo04Moo`<004=oo`<007Eoo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eo
o`03001oogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo04Yoo`<003ioo`8007Moo`05001oogooOol00005Ool20006Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`1=Ool3000hOol3001iOol01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo0P00DGoo0`00<Woo0`00O7oo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`800?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001o
ogoo05=oo`D002Qoo`D007moo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomo
o`3`Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`1H
Ool5000OOol40024Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool0l7oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001o
ogoo05eoo`D001Aoo`H008Qoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol0
1Woo00<007ooOol0l7oo000GOol3000<Ool50004Ool40005Ool2001SOolD002?Ool3000<Ool50004
Ool40005Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00
;goo1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001o
ogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3
003oOolWOol3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo1@00
ogoo1Goo0`0000Aoo`00000001Moo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001o
ogoo0?moo`Ioo`05001oogooOol00009Ool6000:Ool01000Oomoo`00M7oo002FOol01@00Oomoogoo
00006goo00<007ooOol0ogoo1Woo00D007ooOomoo`0001Yoo`03001oogoo07Aoo`00UWoo00D007oo
Oomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogooOol00009Ool6000<Ool00`00Oomo
o`1cOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo000077oo00<0
07ooOol0LWoo002EOol5000LOol00`00Oomoo`3oOol5Ool5000MOol00`00Oomoo`1bOol00;Ioo`03
001oogoo0?moob=oo`05001oogooOol0001dOol00;Aoo`<00?moobIoo`<007Eoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32705 L
.08255 .33556 L
.10458 .34367 L
.12507 .34975 L
.14415 .35391 L
.14918 .35475 L
.15465 .35553 L
.15946 .3561 L
.16457 .3566 L
.16917 .35694 L
.17178 .35708 L
.17423 .35719 L
.17538 .35724 L
.17647 .35727 L
.17746 .3573 L
.17852 .35732 L
.17967 .35734 L
.18073 .35735 L
.182 .35736 L
.18314 .35736 L
.18435 .35735 L
.18547 .35734 L
.1867 .35732 L
.18802 .35729 L
.19071 .3572 L
.19317 .35709 L
.1979 .3568 L
.20239 .35643 L
.21236 .35527 L
.22321 .35349 L
.24299 .34896 L
.26399 .34249 L
.30174 .32745 L
.34195 .30869 L
.38063 .29066 L
.40028 .28236 L
.42177 .27445 L
.44253 .26828 L
.4614 .26416 L
.47149 .26259 L
.47611 .26202 L
.48101 .26153 L
.4835 .26132 L
.48624 .26112 L
.48876 .26097 L
.49106 .26087 L
.49378 .26077 L
.49527 .26073 L
.49596 .26071 L
Mistroke
.49669 .2607 L
.498 .26069 L
.49921 .26068 L
.49996 .26068 L
.50065 .26068 L
.50196 .26069 L
.50313 .2607 L
.50438 .26072 L
.50556 .26075 L
.50663 .26078 L
.50926 .26088 L
.51175 .261 L
.5167 .26133 L
.52208 .26183 L
.53169 .26303 L
.54056 .26452 L
.55926 .26875 L
.57988 .27501 L
.62014 .291 L
.65888 .30909 L
.70007 .32825 L
.72063 .33681 L
.73974 .34375 L
.75939 .34959 L
.77791 .3537 L
.78775 .35528 L
.79293 .35594 L
.7984 .3565 L
.80302 .35686 L
.80546 .35702 L
.80809 .35715 L
.8105 .35724 L
.8127 .3573 L
.81375 .35733 L
.81491 .35734 L
.81599 .35735 L
.817 .35736 L
.81818 .35736 L
.81941 .35735 L
.82047 .35734 L
.82163 .35732 L
.82287 .35729 L
.82421 .35725 L
.82661 .35716 L
.82905 .35704 L
.83134 .3569 L
.83564 .35658 L
.84078 .35608 L
.84552 .35551 L
.85624 .35384 L
Mistroke
.87498 .34974 L
.89561 .34361 L
.93591 .32778 L
.97471 .30973 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .26242 L
.08255 .24219 L
.0932 .2333 L
.10458 .22545 L
.11009 .22231 L
.11531 .21977 L
.12038 .21769 L
.12507 .21614 L
.12951 .215 L
.13178 .21454 L
.13422 .21415 L
.13549 .21398 L
.13666 .21384 L
.13784 .21373 L
.13895 .21365 L
.14022 .21358 L
.1409 .21356 L
.14161 .21354 L
.1423 .21353 L
.14295 .21353 L
.14415 .21354 L
.14531 .21358 L
.14656 .21364 L
.14773 .21372 L
.14881 .21382 L
.15143 .21414 L
.15392 .21454 L
.15886 .21565 L
.16423 .2173 L
.17383 .22139 L
.1827 .22642 L
.20137 .2406 L
.22197 .261 L
.26217 .30935 L
.30086 .35597 L
.32051 .37571 L
.3309 .38443 L
.342 .39217 L
.35275 .39797 L
.35784 .4001 L
.36253 .4017 L
.36724 .40295 L
.36972 .40346 L
.37235 .40389 L
.37463 .40418 L
.37573 .40428 L
.37677 .40436 L
.37799 .40444 L
.37911 .40448 L
Mistroke
.38031 .40451 L
.38162 .4045 L
.38227 .40449 L
.38296 .40448 L
.38419 .40442 L
.38551 .40434 L
.38695 .40421 L
.38955 .40389 L
.39197 .4035 L
.39649 .40251 L
.40134 .40108 L
.40698 .39893 L
.41232 .39645 L
.42232 .39063 L
.44227 .37492 L
.4607 .35634 L
.50002 .30899 L
.53782 .26331 L
.55884 .24211 L
.56803 .23435 L
.57808 .22714 L
.58722 .22183 L
.59696 .21755 L
.60236 .21583 L
.60726 .21468 L
.60962 .21426 L
.61086 .21408 L
.61218 .21392 L
.61333 .2138 L
.61459 .21369 L
.61574 .21362 L
.61682 .21357 L
.61808 .21353 L
.61871 .21353 L
.61941 .21353 L
.62065 .21355 L
.62181 .21359 L
.62248 .21362 L
.62318 .21367 L
.62443 .21377 L
.62578 .2139 L
.62725 .21408 L
.62973 .21447 L
.63238 .215 L
.63715 .21624 L
.64214 .21792 L
.64686 .21988 L
.6557 .22447 L
.67568 .23897 L
.69413 .25668 L
Mistroke
.7335 .30323 L
.77136 .34959 L
.79241 .37174 L
.81166 .38782 L
.82118 .39396 L
.8262 .39666 L
.83155 .39912 L
.8367 .40105 L
.84136 .40244 L
.84361 .40299 L
.84604 .40349 L
.84835 .40387 L
.85045 .40414 L
.85159 .40425 L
.85283 .40435 L
.85414 .40443 L
.85538 .40448 L
.85653 .40451 L
.85776 .40451 L
.85881 .40449 L
.85997 .40444 L
.86063 .40441 L
.86132 .40436 L
.86256 .40426 L
.86535 .40395 L
.86777 .40357 L
.87041 .40305 L
.87569 .40166 L
.88133 .39969 L
.89148 .39488 L
.90173 .38845 L
.91284 .37986 L
.933 .36054 L
.97393 .31186 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34401 L
.10458 .38151 L
.14415 .41547 L
.18221 .44642 L
.22272 .47699 L
.26171 .50358 L
.30316 .52832 L
.34309 .54829 L
.3815 .56358 L
.40095 .56979 L
.42237 .57537 L
.44268 .57945 L
.45178 .58088 L
.46172 .58216 L
.4671 .58273 L
.4721 .58319 L
.47727 .58358 L
.48196 .58387 L
.48658 .58408 L
.4887 .58416 L
.49093 .58423 L
.49332 .58429 L
.49438 .58431 L
.49552 .58432 L
.49675 .58434 L
.49789 .58435 L
.49859 .58435 L
.49925 .58435 L
.50049 .58435 L
.50163 .58435 L
.50286 .58434 L
.50401 .58433 L
.50508 .58431 L
.50754 .58427 L
.51014 .5842 L
.51268 .58411 L
.51504 .58401 L
.5204 .58373 L
.5293 .58307 L
.53882 .5821 L
.54906 .58076 L
.56016 .57895 L
.58032 .57475 L
.62123 .56263 L
.66064 .54659 L
.69852 .52739 L
.73886 .50321 L
.77769 .4767 L
.81897 .4455 L
Mistroke
.85873 .41305 L
.89697 .38015 L
.93767 .34391 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35481 L
.10458 .40129 L
.14415 .43855 L
.18221 .46612 L
.20178 .47655 L
.21267 .48115 L
.22272 .48462 L
.23293 .48734 L
.23832 .48846 L
.24402 .48939 L
.24641 .4897 L
.24897 .48999 L
.25119 .4902 L
.25361 .49038 L
.25507 .49047 L
.25643 .49053 L
.25773 .49058 L
.2584 .4906 L
.25912 .49062 L
.25983 .49064 L
.26048 .49064 L
.26176 .49065 L
.26293 .49065 L
.26416 .49063 L
.26538 .4906 L
.26607 .49058 L
.26671 .49056 L
.26912 .49045 L
.27131 .4903 L
.27364 .49011 L
.27847 .48957 L
.2838 .48876 L
.29326 .48678 L
.30213 .48429 L
.32232 .47642 L
.34082 .46659 L
.38045 .43788 L
.41855 .40199 L
.45912 .35742 L
.49816 .31122 L
.53966 .26203 L
.57964 .21791 L
.61811 .18138 L
.63759 .16587 L
.65902 .15154 L
.67938 .14084 L
.69843 .13357 L
.70884 .13076 L
.71396 .12968 L
Mistroke
.71872 .12886 L
.72301 .12828 L
.72758 .12782 L
.7302 .12763 L
.73148 .12755 L
.73266 .1275 L
.73371 .12746 L
.73487 .12742 L
.73603 .1274 L
.73725 .12738 L
.73856 .12738 L
.73977 .12739 L
.7404 .1274 L
.7411 .12742 L
.74251 .12746 L
.74375 .12751 L
.74508 .12757 L
.74748 .12773 L
.74985 .12793 L
.75235 .12818 L
.7568 .12876 L
.76198 .12963 L
.7668 .13063 L
.77773 .13356 L
.78828 .13725 L
.79823 .14149 L
.81683 .15134 L
.85534 .17907 L
.89632 .21767 L
.93577 .26115 L
.97371 .30604 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo0P00
1Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo
10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00
Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Io
o`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`007goo0`001Woo0P001Goo
10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00
Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007ooOomoo`0000Eo
o`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`005Woo1P000Woo00D007ooOomoo`00011oo`03
001oogoo009oo`03001oogoo0?moo`Eoo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003oOol>Ool01@00Oomo
ogoo000047oo00<007ooOol00Woo0P00lGoo000NOol01@00Oomoogoo000037oo10001Goo00<007oo
Ool0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool0
0`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool0
1@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0l7oo000OOol3000=Ool40005Ool2003o
Ool?Ool3000=Ool40005Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQo
o`8001Eoo`T006Ioo`T006Aoo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo
1Woo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol04Woo0P002Goo1000H7oo0P002Goo0`00
HGoo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001o
ogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<0
07ooOol03goo0`003goo00<007ooOol0FWoo0`003Woo0P00Ggoo000>Ool60002Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0o7oo1P000Woo00D007ooOomoo`00
00eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo015oo`8005Qoo`80
01=oo`03001oogoo05aoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`800?moo`Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000=Ool2000F
Ool00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`1KOol001Ioo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo
10001Goo00<007ooOol02goo00<007ooOol05goo00<007ooOol0DWoo00<007ooOol05Woo00<007oo
Ool0FWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Yoo`03
001oogoo01Uoo`03001oogoo051oo`03001oogoo01Qoo`03001oogoo05Uoo`005Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8000]oo`03001oogoo01Yoo`03001oogoo04ioo`03
001oogoo01Yoo`03001oogoo05Qoo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo
0`003Goo0`001Goo10001Goo00<007ooOol02Goo00<007ooOol077oo00<007ooOol0C7oo00<007oo
Ool077oo00<007ooOol0Egoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`08Ool00`00Oomoo`0N
Ool00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`1FOol003Qoo`03001oogoo01moo`<000Io
o`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<001Yoo`<000Ioo`8000Eo
o`<0025oo`D004Uoo`03001oogoo00Moo`03001oogoo01Eoo`<000Ioo`<000=oo`D001Qoo`<000Io
o`8000Ioo`<001Ioo`03001oo`00008000Ioo`8000Eoo`<000ioo`03001oogoo00Qoo`<000Ioo`80
00Eoo`<0025oo`D001Aoo`00>7oo0P007goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000G
Ool01@00Oomoogoo00001Goo0P001goo00<007ooOol060000Woo00<007ooOol00goo0P0017oo00D0
07ooOomoo`0001Qoo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol0
BGoo0P001goo00<007ooOol05Goo00D007ooOomoo`0000Eoo`800003Ool007oo009oo`04001oogoo
000GOol01@00Oomoogoo00001Goo0P001goo00<007ooOol057oo00<007oo00000goo00<007ooOol0
0goo0P0017oo00D007ooOomoo`0000eoo`03001oogoo00Moo`05001oogooOol00005Ool20004Ool0
1@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Goo
00<007ooOol05goo00D007ooOomoo`0000]oo`H001Ioo`03001oo`00008000]oo`05001oogooOol0
000HOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03001oogoo00Io
o`03001oogoo01Eoo`05001oogooOol00008Ool00`00Oomoo`02Ool00`00Oomoo`0GOol01@00Oomo
ogoo00002goo1@005Goo00<007oo00000goo00<007ooOol02Goo00D007ooOomoo`0000ioo`03001o
ogoo00Ioo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo000hOol00`00
Oomoo`0NOol01@00Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`@001Qoo`04
001oogooOol40008Ool01@00Oomoogoo000067oo00D007ooOomoo`0000]oo`05001oogooOol0000R
Ool00`00Oomoo`19Ool00`00Oomoo`05Ool00`00Oomoo`0FOol01@00Oomoogoo00002Goo00<007oo
Ool00Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000EOol01000Oomoo`000goo
00<007ooOol02Goo00D007ooOomoo`0000moo`03001oogoo00Eoo`05001oogooOol0000;Ool01@00
Oomoogoo00008Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003goo00<0
07ooOol05Goo00D007ooOomoo`0000Uoo`800004Ool007oo000HOol01@00Oomoogoo00000goo0P00
1Woo10006Goo00D007ooOomoo`0000aoo`<002=oo`03001oogoo04Uoo`03001oogoo00Aoo`03001o
ogoo01Moo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`0EOol01@00Oomoogoo0000
37oo00<007oo000057oo00D007ooOomoo`0000=oo`03001oogoo00Uoo`@0015oo`03001oogoo00Ao
o`05001oogooOol0000<Ool3000SOol00`00Oomoo`0DOol003Qoo`8001moo`05001oogooOol0000?
Ool00`00Oomoo`0EOol01@00Oomoogoo00001Woo0`000goo00<007oo000067oo00D007ooOomoo`00
00Eoo`8000Aoo`03001oogoo01Yoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007oo
Ool0BGoo0P0017oo00<007ooOol067oo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00
Oomoogoo000037oo00<007oo00004goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo
01=oo`03001oogoo00=oo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol057oo
000hOol00`00Oomoo`0NOol01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0
0004Ool20007Ool2000HOol01@00Oomoogoo00001goo0`000Woo00<007ooOol06Goo00D007ooOomo
o`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`02Ool00`00Oomoo`0IOol0
1@00Oomoogoo00002goo0P000Woo00<007ooOol05Goo00D007ooOomoo`0000eoo`80019oo`03001o
ogoo00=oo`05001oogooOol0000<Ool00`00Oomoo`0COol00`00Oomoo`02Ool01@00Oomoogoo0000
2goo00D007ooOomoo`00029oo`03001oogoo01Aoo`00>7oo00<007ooOol07goo0`003Goo0`006Goo
0`000goo0P002Woo00<007ooOol05goo0`002goo0P0000Aoo`00000001Uoo`<000eoo`<0025oo`<0
04]oo`05001oogooOol0000MOol3000=Ool3000IOol3000?Ool00`00Oomoo`0?Ool00`00Oomoo`05
Ool3000>Ool3000COol00`00Oomoo`02Ool3000=Ool3000QOol3000FOol003Qoo`80051oo`8003Io
o`8009eoo`80009oo`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02eoo`03001oogoo04io
o`00>7oo00<007ooOol0CGoo0P00>Woo0P00Vgoo00@007ooOol0031oo`03001oogoo03Yoo`03001o
ogoo02moo`03001oogoo04eoo`00>7oo00<007ooOol0BWoo0`00?Woo0`00V7oo00<007oo0000<Woo
00<007ooOol0>7oo00<007ooOol0<Goo00<007ooOol0C7oo000hOol00`00Oomoo`18Ool20014Ool2
002FOol2000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`1<Ool0039oonT0041oonT0
011oo`00>7oo00@007oo000000Moo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`04001oogooOol30004Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`03
Ool30002Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool20002Ool00`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool20009Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0DOol003Qoo`04001oogooOol3
000mOol2001BOol2000lOol3001@Ool00`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomoo`0gOol0
0`00Oomoo`0aOol00`00Oomoo`0EOol003Qoo`8000Eoo`8003Qoo`<005Ioo`<003Moo`8005=oo`80
03Moo`03001oogoo031oo`03001oogoo03Uoo`03001oogoo02moo`03001oogoo01Ioo`00>7oo00<0
07ooOol01Woo0P00=7oo0P00G7oo0P00<goo0P00EGoo00<007ooOol0=goo00<007ooOol0;Woo00<0
07ooOol0>goo00<007ooOol0;Goo00<007ooOol05goo000hOol00`00Oomoo`08Ool3000_Ool2001P
Ool2000_Ool2001GOol00`00Oomoo`0hOol00`00Oomoo`0/Ool00`00Oomoo`0lOol00`00Oomoo`0/
Ool00`00Oomoo`0HOol003Qoo`03001oogoo00]oo`8002]oo`8006Aoo`8002Yoo`<005Uoo`03001o
ogoo03Uoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo01Uoo`00>7oo
0P003Woo0`009Woo0P00J7oo0`009Goo0P00G7oo0P00>Woo00<007ooOol0:Woo00<007ooOol0?goo
00<007ooOol0:Goo00<007ooOol06Goo000hOol00`00Oomoo`0@Ool3000POol3001]Ool3000OOol3
001NOol00`00Oomoo`0jOol00`00Oomoo`0XOol00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomo
o`0JOol003Qoo`03001oogoo01=oo`D001Ioo`D007=oo`D001Eoo`D0065oo`03001oogoo03]oo`03
001oogoo02Ioo`03001oogoo04=oo`03001oogoo02Eoo`03001oogoo01]oo`00>7oo00<007ooOol0
67oo0`003goo1000OGoo0`003goo0`00IWoo00<007ooOol0?7oo00<007ooOol097oo00<007ooOol0
AGoo00<007ooOol08goo00<007ooOol077oo000hOol2000LOol?0024Ool?001YOol2000nOol2000S
Ool00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`0MOol003Qoo`03001oogoo0?moobMoo`03
001oogoo03moo`03001oogoo01moo`03001oogoo04Uoo`03001oogoo01moo`03001oogoo01ioo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0@7oo00<007ooOol07Goo00<007ooOol0Bgoo00<007oo
Ool07Goo00<007ooOol07goo000hOol2003oOolXOol20012Ool00`00Oomoo`0KOol00`00Oomoo`1=
Ool00`00Oomoo`0KOol00`00Oomoo`0POol001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001o
ogoo0?moo`Ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo049oo`03001oogoo01Qoo`80
055oo`03001oogoo01Uoo`03001oogoo025oo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001o
ogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00001Goo0P001Goo00@0
07ooOol000Qoo`03001oogoo009oo`03001oogoo04=oo`03001oogoo01Ioo`03001oogoo059oo`03
001oogoo01Ioo`8002Aoo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009o
o`03001oogoo0?moo`Eoo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00
Oomoo`14Ool2000EOol00`00Oomoo`1DOol00`00Oomoo`0DOol00`00Oomoo`0TOol001Ioo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00Woo0P00Agoo00<007ooOol04Goo00<007ooOol0EWoo0`004Woo
00<007ooOol09Goo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo04Moo`8000moo`80
05aoo`03001oogoo00ioo`03001oogoo02Ioo`005Woo00D007ooOomoo`0000moo`03001oogoo009o
o`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00
Oomoo`06Ool00`00Oomoo`19Ool00`00Oomoo`0;Ool00`00Oomoo`1MOol00`00Oomoo`0;Ool2000Y
Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo
00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001;Ool20007Ool4001Q
Ool30007Ool3000[Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo0?moo`Ioo`<000eoo`<0
00Eoo`@000Eoo`03001oogoo04aoo`L006Qoo`L002ioo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`
Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo0P00ogoo:7oo0P00lGoo000OOol30006Ool20005Ool40005Ool00`00Oomoo`3oOol>Ool30006
Ool20005Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol00005Ool20009Ool00`00Oomo
o`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007oo
Ool0l7oo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D007oo
Oomoo`00011oo`03001oogoo009oo`03001oogoo0?1oo`007Woo00D007ooOomoo`00011oo`03001o
ogoo009oo`800?moo`ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2003aOol001ioo`05001o
ogooOol0000<Ool40005Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo10001Goo00<007oo
Ool0l7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0ogoo3Goo00D007oo
Oomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?1oo`007Woo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`800?moo`ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003aOol001moo`<000eo
o`@000Eoo`03001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?mo
obQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000GOol30006Ool20006Ool00`00Oomoo`04Ool4
0005Ool00`00Oomoo`3oOol6Ool30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`3`
Ool001Ioo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomo
o`3oOol5Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007oo
Ool0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?1oo`00
5Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?moo`Ioo`05001oogoo
Ool0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003aOol001Ioo`05001oogooOol0000>Ool0
0`00Oomoo`03Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol00goo
10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
1Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03
001oogoo0?1oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2
003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?5oo`00
5goo0`0037oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`0037oo1@0017oo10001Goo00<007oo
Ool0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol002moo`D000Ao
o`03001oogoo0?mooaioo`D000Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0
ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00
Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0
ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001o
ogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00nGoo003oOoooOomFOol00?mooomo
oeIoo`00UGoo0`0000Aoo`00000001Qoo`<00?moo`Moo`<00004Ool00000000IOol3001dOol009Io
o`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000ogoo1goo00D007ooOomoo`0000Uoo`H0
00aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001aoo`03001oogoo0?moo`Eoo`05001oogoo
Ool0000HOol5001dOol009Ioo`05001oogooOol00009Ool6000=Ool00`00Oomoo`3oOol5Ool01@00
Oomoogoo00002Goo1P002Goo00@007ooOol007Eoo`00UWoo00D007ooOomoo`0001Yoo`800?moo`Qo
o`05001oogooOol0000IOol00`00Ool0001eOol009Eoo`D001eoo`03001oogoo0?moo`Aoo`D001Yo
o`03001oo`0007Eoo`00/goo00D007ooOomoo`000?moobIoo`8007Eoo`00]7oo0`00ogoo:7oo00<0
07ooOol0Lgoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol002moo`D00?moobEoo`D00?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0
mgoo000VOol60005Ool00`00Oomoo`3oOolLOol60005Ool00`00Oomoo`3gOol0035oo`03001oogoo
00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo
87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol0
0`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Ao
o`800?5oo`00;goo0`001Woo00<007ooOol0ogoo7Woo0`001Woo00<007ooOol0l7oo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol001Moo`<000Ioo`8000Ioo`03001oogoo
00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001o
ogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool0
0`00Oomoo`3`Ool000ioo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`3lOol60002Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00
ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`800?5oo`005Woo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000>
Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Ao
o`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo0P00lGoo000GOol3000<Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool3000<Ool50004
Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?mo
obMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolX
Ool2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo09ioo`X004Qoo`00>7oo00<007ooOol0
ogoo9goo00<007ooOol0Vgoo0`002Woo0`00AGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2G
Ool4000@Ool50010Ool003Qoo`800?moobQoo`8009Eoo`<001Uoo`8003ioo`007goo0`001Woo0P00
1Goo10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0TWoo0P007Woo
0P00?7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo
00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo095oo`03001oogoo021oo`03
001oogoo03Uoo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`Ioo`H0
009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool2002@Ool2000TOol2000iOol001ioo`05001o
ogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000047oo00<007oo
Ool00Woo00<007ooOol0SGoo0P00:7oo00<007ooOol0=Woo000NOol01@00Oomoogoo000037oo1000
1Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo08aoo`03001oogoo
02Uoo`03001oogoo03Eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo0?mo
o`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`2;Ool00`00Oomoo`0[Ool2000e
Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo
00<007ooOol01Woo0P00Rgoo00<007ooOol0;Woo00<007ooOol0<Woo000OOol3000=Ool40005Ool0
0`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`29Ool00`00Oomoo`0`Ool00`00Oomoo`0a
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Qoo`03001oogoo039oo`80035oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0QWoo0P00=goo00<007ooOol0;Woo000hOol2003oOolXOol20026
Ool00`00Oomoo`0hOol00`00Oomoo`0]Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Aoo`03
001oogoo03Yoo`03001oogoo02aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Pgoo00<007oo
Ool0?7oo00<007ooOol0:goo000hOol2003oOolXOol20023Ool00`00Oomoo`0nOol00`00Oomoo`0Z
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo085oo`03001oogoo041oo`03001oogoo02Uoo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0P7oo00<007ooOol0@Woo00<007ooOol0:7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`1oOol00`00Oomoo`14Ool00`00Oomoo`0WOol003Qoo`800?mo
obQoo`8007moo`03001oogoo04Ioo`03001oogoo02Ioo`005goo0`001Woo0P0017oo1@0017oo1000
1Goo00<007ooOol0ogoo1Woo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0OGoo00<007oo
Ool0Agoo00<007ooOol09Woo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03
001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo
00<007ooOol00Woo00<007ooOol0O7oo00<007ooOol0BGoo00<007ooOol09Goo000>Ool60002Ool0
1@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P00oGoo1P000Woo00D007ooOomo
o`0000eoo`03001oogoo00Qoo`03001oogoo009oo`8007aoo`03001oogoo04]oo`03001oogoo02Ao
o`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eo
o`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`1jOol00`00Oomo
o`1=Ool00`00Oomoo`0SOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00
Oomoo`3oOol5Ool01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0NGoo00<0
07ooOol0Cgoo00<007ooOol08Woo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo07Qoo`03001oogoo055oo`03001oogoo025oo`005Woo00D007ooOomoo`0000]oo`05
001oogooOol00004Ool00`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomo
o`0000Aoo`03001oogoo00Ioo`8007Qoo`03001oogoo05=oo`03001oogoo021oo`005goo0`003Goo
0`001Goo10001Goo00<007ooOol0ogoo1Woo0`003Goo0`001Goo10001Goo00<007ooOol0MWoo00<0
07ooOol0EGoo00<007ooOol07goo000hOol00`00Oomoo`0OOol30006Ool20004Ool5000HOol30006
Ool20006Ool3000HOol30006Ool20005Ool3000JOol30006Ool20005Ool3000QOol50019Ool00`00
Oomoo`0OOol30006Ool20004Ool5000HOol30006Ool20006Ool3000FOol00`00Ool000020006Ool2
0005Ool3000IOol30006Ool20005Ool3000IOol00`00Oomoo`05Ool5000DOol003Qoo`8001moo`05
001oogooOol00005Ool20005Ool01000Oomoo`005goo00D007ooOomoo`0000Eoo`8000Moo`03001o
ogoo01Ioo`05001oogooOol00005Ool20004Ool01@00Oomoogoo000067oo00D007ooOomoo`0000Eo
o`8000Aoo`05001oogooOol0000ROol00`00Oomoo`19Ool2000OOol01@00Oomoogoo00001Goo0P00
1Goo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00Oomoo`0DOol00`00Ool00003
Ool00`00Oomoo`03Ool20004Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Eoo`8000Aoo`05
001oogooOol0000IOol00`00Oomoo`06Ool00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001o
ogooOol0000=Ool00`00Oomoo`0GOol01@00Oomoogoo00002goo1@005goo00D007ooOomoo`0000]o
o`05001oogooOol0000HOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uo
o`03001oogoo01ioo`05001oogooOol0000=Ool00`00Oomoo`0GOol01@00Oomoogoo00002goo1@00
5Goo00<007oo00000goo00<007ooOol02Goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool0
1@00Oomoogoo00006Goo00<007ooOol01Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00
Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomo
ogoo00002goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<0
07ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0
000;Ool01000Oomoo`005Goo00@007ooOol000=oo`03001oogoo00Uoo`05001oogooOol0000GOol0
1@00Oomoogoo00002goo00D007ooOomoo`0001Yoo`03001oogoo00Eoo`03001oogoo01Aoo`00>7oo
00<007ooOol07Woo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00
Ool0000HOol01@00Oomoogoo00002goo10006Goo00D007ooOomoo`0000aoo`<002=oo`03001oogoo
04Uoo`03001oogoo01ioo`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo
00<007oo000057oo00D007ooOomoo`0000=oo`03001oogoo00Uoo`@001Qoo`05001oogooOol0000<
Ool3000LOol00`00Oomoo`04Ool00`00Oomoo`0DOol003Qoo`8001moo`05001oogooOol0000?Ool0
0`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`0000]oo`03001o
ogoo01Yoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo0P007goo00D0
07ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000COol00`00Oomo
o`02Ool01@00Oomoogoo00002goo00<007ooOol06Goo00D007ooOomoo`0000]oo`05001oogooOol0
000LOol00`00Oomoo`03Ool00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogooOol0000;
Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8001Qoo`05001oogooOol0000<Ool00`00
Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03001oogoo
01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8001=oo`03
001oogoo009oo`05001oogooOol0000<Ool00`00Oomoo`0HOol01@00Oomoogoo00002goo00D007oo
Oomoo`0001eoo`03001oogoo009oo`03001oogoo01Aoo`00>7oo00<007ooOol07goo0`003Goo0`00
6Goo0`003goo00<007ooOol05goo0`003Woo0`006Goo0`003Goo0`008Goo0`00Bgoo00<007ooOol0
7goo0`003Goo0`006Goo0`003goo00<007ooOol047oo00<007ooOol017oo0`003Woo0`0067oo0`00
3Goo0`007goo00<007oo00000P005Woo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1_Ool00`00
Oomoo`1SOol00`00Oomoo`0HOol003Qoo`800?moobQoo`8006moo`03001oogoo06Eoo`03001oogoo
01Moo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0KWoo00<007ooOol0IWoo00<007ooOol05Woo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1]Ool00`00Oomoo`1XOol00`00Oomoo`0EOol0039o
onT0041oonT0011oo`00>7oo00<007oo000027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol01Woo00<007oo0000Bgoo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol057oo000hOol01000Oomoo`00:7oo
00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol09Woo00@007ooOol004]o
o`8002Yoo`03001oogoo02Uoo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo02Uoo`03001o
ogoo02Uoo`03001oogoo01Aoo`00>7oo00D007ooOomoo`000=Aoo`03001oogoo04eoo`03001oo`00
06Yoo`03001oogoo08=oo`00>7oo0P000goo00<007ooOol0d7oo00<007ooOol0CWoo0P0000=oo`00
Ool0Igoo00<007ooOol0Q7oo000hOol00`00Oomoo`03Ool00`00Oomoo`3>Ool00`00Oomoo`1?Ool0
1@00Oomoogoo0000IWoo00<007ooOol0QGoo000hOol00`00Oomoo`04Ool00`00Oomoo`3<Ool00`00
Oomoo`1@Ool00`00Oomoo`02Ool00`00Oomoo`1ROol00`00Oomoo`26Ool003Qoo`8000Ioo`03001o
ogoo0<Yoo`03001oogoo055oo`8000=oo`03001oogoo065oo`03001oogoo08Moo`00>7oo00<007oo
Ool01Woo0P00b7oo0P00E7oo00<007ooOol00goo00<007ooOol0Ggoo00<007ooOol0R7oo000hOol0
0`00Oomoo`08Ool00`00Oomoo`34Ool00`00Oomoo`1DOol00`00Oomoo`04Ool00`00Oomoo`1MOol0
0`00Oomoo`29Ool003Qoo`03001oogoo00Uoo`03001oogoo0<9oo`03001oogoo05Eoo`03001oogoo
00Eoo`03001oogoo05]oo`03001oogoo08Yoo`00>7oo0P002goo00<007ooOol0`7oo00<007ooOol0
EWoo0P001goo00<007ooOol0FGoo00<007ooOol0Rgoo000hOol00`00Oomoo`0;Ool00`00Oomoo`2n
Ool00`00Oomoo`1GOol00`00Oomoo`06Ool00`00Oomoo`1IOol00`00Oomoo`2;Ool003Qoo`03001o
ogoo00aoo`03001oogoo0;aoo`03001oogoo05Qoo`03001oogoo00Moo`03001oogoo05Moo`03001o
ogoo08aoo`00>7oo00<007ooOol03Goo00<007ooOol0^Woo00<007ooOol0FGoo00<007ooOol027oo
00<007ooOol0EGoo00<007ooOol0SGoo000hOol2000?Ool00`00Oomoo`2hOol00`00Oomoo`1JOol2
000:Ool00`00Oomoo`1COol00`00Oomoo`2>Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03
001oogoo00moo`03001oogoo0;Ioo`03001oogoo03Yoo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03
001oogoo00Yoo`03001oogoo055oo`03001oogoo08moo`005Woo00D007ooOomoo`0000Eoo`8000Eo
o`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool2002dOol2000lOol01@00Oomoogoo
00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo04mo
o`03001oogoo091oo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`80
01=oo`03001oogoo0;1oo`03001oogoo03aoo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool2000<Ool00`00Oomoo`1>Ool00`00Oomoo`2AOol001Ioo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`2^Ool00`00Oomoo`0mOol0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0
C7oo00<007ooOol0TWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007oo
Ool057oo00<007ooOol0Zgoo0P00@7oo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03
001oogoo00eoo`03001oogoo04Yoo`03001oogoo09=oo`005Woo00D007ooOomoo`0000moo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo0:Uoo`03001oogoo041oo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`18Ool0
0`00Oomoo`2DOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo
0P005goo00<007ooOol0Ygoo00<007ooOol0@Goo00D007ooOomoo`0000]oo`05001oogooOol00004
Ool00`00Oomoo`06Ool2000@Ool20016Ool2002GOol001Moo`<000eoo`<000Eoo`@000Eoo`03001o
ogoo01Moo`03001oogoo0:Eoo`03001oogoo04=oo`<000eoo`<000Eoo`@000Eoo`03001oogoo015o
o`03001oogoo049oo`03001oogoo09Moo`00>7oo00<007ooOol067oo00<007ooOol0XWoo0P00Igoo
00<007ooOol04Woo00<007ooOol0@7oo00<007ooOol0V7oo000hOol2000JOol2002QOol00`00Oomo
o`1WOol2000DOol00`00Oomoo`0nOol00`00Oomoo`2IOol003Qoo`03001oogoo01]oo`03001oogoo
09eoo`03001oogoo06Qoo`03001oogoo01Aoo`8003eoo`03001oogoo09Yoo`00>7oo00<007ooOol0
77oo00<007ooOol0Vgoo00<007ooOol0JGoo00<007ooOol05Woo00<007ooOol0>Goo00<007ooOol0
Vgoo000hOol00`00Oomoo`0MOol2002JOol00`00Oomoo`1ZOol00`00Oomoo`0GOol00`00Oomoo`0g
Ool00`00Oomoo`2LOol003Qoo`80021oo`03001oogoo09Ioo`03001oogoo06]oo`8001Uoo`03001o
ogoo03Eoo`03001oogoo09eoo`00>7oo00<007ooOol087oo00<007ooOol0U7oo00<007ooOol0K7oo
00<007ooOol06Goo0P00<goo0P00X7oo000hOol00`00Oomoo`0QOol00`00Oomoo`2BOol00`00Oomo
o`1]Ool00`00Oomoo`0KOol00`00Oomoo`0_Ool00`00Oomoo`2POol003Qoo`8002=oo`80091oo`80
071oo`8001eoo`03001oogoo02eoo`03001oogoo0:5oo`00>7oo00<007ooOol097oo00<007ooOol0
S7oo00<007ooOol0L7oo00<007ooOol07Goo00<007ooOol0:Woo0P00Y7oo000OOol30006Ool20005
Ool40005Ool00`00Oomoo`0UOol00`00Oomoo`2:Ool00`00Oomoo`1HOol30006Ool20005Ool40005
Ool00`00Oomoo`0NOol00`00Oomoo`0XOol00`00Oomoo`2TOol001ioo`05001oogooOol00005Ool2
0009Ool00`00Oomoo`02Ool00`00Oomoo`0VOol20028Ool2001JOol01@00Oomoogoo00001Goo0P00
2Goo00<007ooOol00Woo00<007ooOol07goo00<007ooOol09Woo00<007ooOol0YGoo000NOol01@00
Oomoogoo000047oo00<007ooOol00Woo0P00:Goo00<007ooOol0Q7oo00<007ooOol0FWoo00D007oo
Oomoo`00011oo`03001oogoo009oo`80025oo`03001oogoo02Aoo`03001oogoo0:Ioo`007Woo00D0
07ooOomoo`00011oo`03001oogoo009oo`03001oogoo02Uoo`03001oogoo089oo`03001oogoo05]o
o`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0QOol2000ROol2002YOol001ioo`05
001oogooOol0000<Ool40005Ool00`00Oomoo`0ZOol00`00Oomoo`20Ool00`00Oomoo`1LOol01@00
Oomoogoo000037oo10001Goo00<007ooOol08goo0`007Goo0P00Zgoo000NOol01@00Oomoogoo0000
37oo00<007ooOol01Woo00<007ooOol0:goo0P00OWoo0P00Ggoo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`03001oogoo02Ioo`<001Qoo`800:eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo
00Ioo`8002ioo`03001oogoo07Yoo`03001oogoo05moo`05001oogooOol0000<Ool00`00Oomoo`06
Ool2000ZOol2000COol3002_Ool001moo`<000eoo`@000Eoo`03001oogoo02ioo`8007Qoo`8006=o
o`<000eoo`@000Eoo`03001oogoo02]oo`8000eoo`@00;9oo`00>7oo00<007ooOol0<7oo00<007oo
Ool0M7oo00<007ooOol0O7oo00<007ooOol0;Goo3@00]Woo000hOol2000bOol2001bOol2001oOol2
003aOol003Qoo`03001oogoo03=oo`03001oogoo06ioo`03001oogoo07moo`03001oogoo0?1oo`00
>7oo00<007ooOol0=7oo0P00K7oo0P00PWoo00<007ooOol0l7oo000hOol00`00Oomoo`0fOol2001X
Ool20024Ool00`00Oomoo`3`Ool003Qoo`8003Uoo`03001oogoo06Aoo`03001oogoo08Aoo`800?5o
o`00>7oo00<007ooOol0>Goo0P00HWoo0P00Qgoo00<007ooOol0l7oo000hOol00`00Oomoo`0kOol2
001NOol20029Ool00`00Oomoo`3`Ool003Qoo`8003ioo`03001oogoo05Yoo`03001oogoo08Uoo`80
0?5oo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0?Woo0P00F7oo0P00
Jgoo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo
00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0@7oo0P00E7oo0P00K7oo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?1oo`00
5Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo049oo`80051o
o`8006ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool0
01Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20015Ool00`00Oomoo`1;
Ool2001`Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00lGoo000FOol0
1@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0AGoo0P00BGoo0P00LWoo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo04Moo`<004=oo`<007Aoo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0
000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol0BWoo0`00?Woo0P00Mgoo00D0
07ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Moo`<0
00aoo`D000Aoo`@000Eoo`8004ioo`<003Qoo`<007Yoo`<000aoo`D000Aoo`@000Eoo`800?5oo`00
>7oo00<007ooOol0D7oo0P00=7oo0P00WWoo00<007ooOol0l7oo000hOol00`00Oomoo`1BOol2000_
Ool3002POol00`00Oomoo`3`Ool003Qoo`8005Eoo`@002Qoo`<00:=oo`800?5oo`00>7oo00<007oo
Ool0F7oo1@007goo1000YWoo00<007ooOol0l7oo000hOol00`00Oomoo`1MOol5000DOol6002ZOol0
0`00Oomoo`3`Ool003Qoo`03001oogoo069ooa@00;1oo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo
0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03
001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000_Ool50004Ool00`00Oomoo`3oOolNOol50004
Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03
001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007oo
Ool0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001o
ogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003o
OoooOomFOol009Eoo`<00004Ool00000000HOol5003oOol5Ool3000017oo000000005goo1@00M7oo
002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H0
00Yoo`04001oogoo001dOol009Ioo`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomo
ogoo00006Woo00<007ooOol0M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo
1Woo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001]oo`03
001oogoo0?moo`Ioo`05001oogooOol0000LOol00`00Oomoo`1bOol009Eoo`D001aoo`03001oogoo
0?moo`Eoo`D001eoo`03001oogoo079oo`00]Woo00<007ooOol0ogoo8goo00D007ooOomoo`0007Ao
o`00]7oo0`00ogoo9Woo0`00MGoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .37678 L
.08255 .40876 L
.10458 .43923 L
.12507 .46206 L
.14415 .4777 L
.14918 .48085 L
.15465 .48378 L
.15946 .48594 L
.16457 .48779 L
.16917 .48906 L
.17178 .48962 L
.17423 .49004 L
.17538 .4902 L
.17647 .49033 L
.17746 .49042 L
.17852 .49051 L
.17967 .49058 L
.18073 .49062 L
.182 .49065 L
.18314 .49065 L
.18435 .49062 L
.18547 .49058 L
.1867 .4905 L
.18802 .49039 L
.19071 .49006 L
.19317 .48965 L
.1979 .48856 L
.20239 .48716 L
.21236 .4828 L
.22321 .47614 L
.24299 .45911 L
.26399 .43477 L
.30174 .37827 L
.34195 .3078 L
.38063 .24004 L
.40028 .20887 L
.42177 .17914 L
.44253 .15597 L
.4614 .14047 L
.47149 .13456 L
.47611 .13243 L
.48101 .13058 L
.4835 .1298 L
.48624 .12906 L
.48876 .1285 L
.49106 .12809 L
.49378 .12773 L
.49527 .12758 L
.49596 .12753 L
Mistroke
.49669 .12748 L
.498 .12742 L
.49921 .12739 L
.49996 .12738 L
.50065 .12739 L
.50196 .12742 L
.50313 .12747 L
.50438 .12755 L
.50556 .12766 L
.50663 .12777 L
.50926 .12814 L
.51175 .12861 L
.5167 .12986 L
.52208 .1317 L
.53169 .13624 L
.54056 .14182 L
.55926 .15773 L
.57988 .18124 L
.62014 .24132 L
.65888 .30928 L
.70007 .38127 L
.72063 .41346 L
.73974 .43953 L
.75939 .46147 L
.77791 .47691 L
.78775 .48286 L
.79293 .48533 L
.7984 .48743 L
.80302 .4888 L
.80546 .48937 L
.80809 .48987 L
.8105 .49022 L
.8127 .49045 L
.81375 .49053 L
.81491 .49059 L
.81599 .49063 L
.817 .49065 L
.81818 .49065 L
.81941 .49062 L
.82047 .49057 L
.82163 .4905 L
.82287 .49039 L
.82421 .49025 L
.82661 .48991 L
.82905 .48946 L
.83134 .48894 L
.83564 .48772 L
.84078 .48584 L
.84552 .48369 L
.85624 .47744 L
Mistroke
.87498 .46202 L
.89561 .43899 L
.93591 .37951 L
.97471 .31168 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35562 L
.08255 .37584 L
.0932 .38473 L
.10458 .39259 L
.11009 .39572 L
.11531 .39827 L
.12038 .40034 L
.12507 .40189 L
.12951 .40303 L
.13178 .40349 L
.13422 .40389 L
.13549 .40406 L
.13666 .40419 L
.13784 .4043 L
.13895 .40438 L
.14022 .40445 L
.1409 .40448 L
.14161 .4045 L
.1423 .40451 L
.14295 .40451 L
.14415 .40449 L
.14531 .40446 L
.14656 .40439 L
.14773 .40431 L
.14881 .40421 L
.15143 .4039 L
.15392 .40349 L
.15886 .40239 L
.16423 .40074 L
.17383 .39665 L
.1827 .39161 L
.20137 .37744 L
.22197 .35704 L
.26217 .30868 L
.30086 .26207 L
.32051 .24232 L
.3309 .23361 L
.342 .22586 L
.35275 .22006 L
.35784 .21793 L
.36253 .21633 L
.36724 .21508 L
.36972 .21457 L
.37235 .21414 L
.37463 .21386 L
.37573 .21375 L
.37677 .21367 L
.37799 .2136 L
.37911 .21355 L
Mistroke
.38031 .21353 L
.38162 .21353 L
.38227 .21354 L
.38296 .21356 L
.38419 .21361 L
.38551 .2137 L
.38695 .21382 L
.38955 .21414 L
.39197 .21453 L
.39649 .21553 L
.40134 .21696 L
.40698 .2191 L
.41232 .22159 L
.42232 .2274 L
.44227 .24311 L
.4607 .26169 L
.50002 .30904 L
.53782 .35472 L
.55884 .37593 L
.56803 .38368 L
.57808 .39089 L
.58722 .39621 L
.59696 .40048 L
.60236 .4022 L
.60726 .40336 L
.60962 .40377 L
.61086 .40395 L
.61218 .40412 L
.61333 .40424 L
.61459 .40434 L
.61574 .40442 L
.61682 .40447 L
.61808 .4045 L
.61871 .40451 L
.61941 .40451 L
.62065 .40449 L
.62181 .40444 L
.62248 .40441 L
.62318 .40437 L
.62443 .40427 L
.62578 .40413 L
.62725 .40395 L
.62973 .40356 L
.63238 .40304 L
.63715 .4018 L
.64214 .40011 L
.64686 .39815 L
.6557 .39356 L
.67568 .37906 L
.69413 .36136 L
Mistroke
.7335 .3148 L
.77136 .26844 L
.79241 .24629 L
.81166 .23021 L
.82118 .22408 L
.8262 .22137 L
.83155 .21892 L
.8367 .21698 L
.84136 .21559 L
.84361 .21504 L
.84604 .21455 L
.84835 .21417 L
.85045 .2139 L
.85159 .21378 L
.85283 .21368 L
.85414 .2136 L
.85538 .21355 L
.85653 .21353 L
.85776 .21353 L
.85881 .21355 L
.85997 .21359 L
.86063 .21363 L
.86132 .21367 L
.86256 .21377 L
.86535 .21409 L
.86777 .21446 L
.87041 .21498 L
.87569 .21637 L
.88133 .21835 L
.89148 .22316 L
.90173 .22958 L
.91284 .23817 L
.933 .25749 L
.97393 .30617 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34637 L
.10458 .3864 L
.14415 .42264 L
.18221 .45568 L
.22272 .48831 L
.26171 .5167 L
.30316 .5431 L
.34309 .56441 L
.3815 .58074 L
.40095 .58736 L
.42237 .59333 L
.44268 .59767 L
.45178 .5992 L
.46172 .60057 L
.4671 .60118 L
.4721 .60167 L
.47727 .60208 L
.48196 .60239 L
.48658 .60262 L
.4887 .60271 L
.49093 .60278 L
.49332 .60284 L
.49438 .60286 L
.49552 .60288 L
.49675 .60289 L
.49789 .6029 L
.49859 .60291 L
.49925 .60291 L
.50049 .60291 L
.50163 .60291 L
.50286 .6029 L
.50401 .60288 L
.50508 .60287 L
.50754 .60282 L
.51014 .60275 L
.51268 .60265 L
.51504 .60255 L
.5204 .60224 L
.5293 .60154 L
.53882 .6005 L
.54906 .59907 L
.56016 .59714 L
.58032 .59266 L
.62123 .57972 L
.66064 .56261 L
.69852 .54211 L
.73886 .5163 L
.77769 .488 L
.81897 .4547 L
Mistroke
.85873 .42007 L
.89697 .38495 L
.93767 .34626 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .37205 L
.10458 .43602 L
.14415 .4873 L
.18221 .52525 L
.20178 .53961 L
.21267 .54594 L
.22272 .55071 L
.23293 .55446 L
.23832 .556 L
.24402 .55728 L
.24641 .55771 L
.24897 .55811 L
.25119 .55839 L
.25361 .55864 L
.25507 .55876 L
.25643 .55885 L
.25773 .55892 L
.2584 .55895 L
.25912 .55897 L
.25983 .55899 L
.26048 .55901 L
.26176 .55902 L
.26293 .55901 L
.26416 .55899 L
.26538 .55895 L
.26607 .55892 L
.26671 .55889 L
.26912 .55873 L
.27131 .55854 L
.27364 .55827 L
.27847 .55753 L
.2838 .55641 L
.29326 .55369 L
.30213 .55026 L
.32232 .53942 L
.34082 .52589 L
.38045 .48638 L
.41855 .43698 L
.45912 .37564 L
.49816 .31205 L
.53966 .24435 L
.57964 .18362 L
.61811 .13334 L
.63759 .11199 L
.65902 .09227 L
.67938 .07754 L
.69843 .06753 L
.70884 .06366 L
.71396 .06218 L
Mistroke
.71872 .06106 L
.72301 .06025 L
.72758 .05962 L
.7302 .05936 L
.73148 .05926 L
.73266 .05918 L
.73371 .05912 L
.73487 .05907 L
.73603 .05904 L
.73725 .05902 L
.73856 .05902 L
.73977 .05903 L
.7404 .05905 L
.7411 .05907 L
.74251 .05912 L
.74375 .05919 L
.74508 .05928 L
.74748 .0595 L
.74985 .05977 L
.75235 .06012 L
.7568 .06092 L
.76198 .06212 L
.7668 .06349 L
.77773 .06751 L
.78828 .07259 L
.79823 .07843 L
.81683 .09199 L
.85534 .13016 L
.89632 .18329 L
.93577 .24314 L
.97371 .30493 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol0
0`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`800?moobQoo`800?5oo`005goo0`001Woo0P00
1Woo00<007ooOol017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo
10001Goo00<007ooOol0l7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo0?1oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`800?eoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool2003aOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D0
07ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000;Ool01@00
Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool2003aOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Io
o`<000aoo`D000Aoo`@000Eoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool0
03Qoo`800?moobQoo`800?5oo`00>7oo00<007ooOol0Igoo2@00]Woo00<007ooOol0l7oo000hOol0
0`00Oomoo`1TOol30009Ool3002cOol00`00Oomoo`3`Ool003Qoo`8006Aoo`03001oogoo00eoo`80
0;5oo`800?5oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0HGoo0P004Woo00<007ooOol0
UGoo0`001Woo0P001Goo10001Goo00<007ooOol0l7oo000NOol01@00Oomoogoo00001Goo0P002Goo
00<007ooOol00Woo00<007ooOol0H7oo00<007ooOol04goo00<007ooOol0Tgoo00D007ooOomoo`00
00Eoo`8000Uoo`03001oogoo009oo`03001oogoo0?1oo`005Woo1P000Woo00D007ooOomoo`00011o
o`03001oogoo009oo`03001oogoo05moo`03001oogoo01Eoo`03001oogoo08Yoo`H0009oo`05001o
ogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool00`00
Oomoo`02Ool2001OOol00`00Oomoo`0GOol00`00Oomoo`2AOol01@00Oomoogoo000047oo00<007oo
Ool00Woo0P00lGoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0GWoo00<007ooOol0
67oo00<007ooOol0T7oo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo0?1oo`007Woo00D007oo
Oomoo`0000aoo`03001oogoo00Ioo`03001oogoo05eoo`03001oogoo01Yoo`03001oogoo08moo`05
001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool00`00Oomoo`1LOol00`00Oomoo`0LOol00`00Oomoo`2>Ool01@00Oomoogoo0000
37oo00<007ooOol01Woo00<007ooOol0l7oo000OOol3000=Ool40005Ool2001LOol00`00Oomoo`0N
Ool00`00Oomoo`2>Ool3000=Ool40005Ool2003aOol003Qoo`03001oogoo05Yoo`03001oogoo021o
o`03001oogoo0:Ioo`03001oogoo0?1oo`00>7oo00<007ooOol0FGoo00<007ooOol08Woo00<007oo
Ool0YGoo00<007ooOol0l7oo000hOol2001JOol00`00Oomoo`0ROol00`00Oomoo`2UOol2003aOol0
03Qoo`03001oogoo05Qoo`03001oogoo02Aoo`03001oogoo0:Aoo`03001oogoo0?1oo`00>7oo00<0
07ooOol0Egoo00<007ooOol09Woo00<007ooOol0Xgoo00<007ooOol0l7oo000hOol00`00Oomoo`1F
Ool00`00Oomoo`0WOol00`00Oomoo`2SOol00`00Oomoo`3`Ool003Qoo`8005Moo`03001oogoo02Qo
o`03001oogoo0:9oo`800?5oo`00>7oo00<007ooOol0EGoo00<007ooOol0:Woo00<007ooOol0XGoo
00<007ooOol0l7oo000hOol00`00Oomoo`1DOol00`00Oomoo`0[Ool00`00Oomoo`2QOol00`00Oomo
o`3`Ool003Qoo`8005Eoo`03001oogoo02aoo`03001oogoo0:1oo`8004aoo`/006=oo`/002aoo`00
5goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0Dgoo00<007ooOol0;Goo00<007ooOol0
Ogoo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0BGoo0P002goo00<007ooOol0GWoo0P00
2goo0P00:Woo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009o
o`03001oogoo05=oo`03001oogoo02ioo`03001oogoo07eoo`05001oogooOol00005Ool20005Ool0
1000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0B7oo00<007ooOol037oo0P00G7oo0P003goo
0P00:7oo000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<0
07ooOol0DWoo00<007ooOol0<7oo00<007ooOol0M7oo1P000Woo00D007ooOomoo`0000eoo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo04Ioo`80015oo`8005Uoo`03001oogoo015oo`8002Io
o`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80059oo`03001oogoo
035oo`03001oogoo07aoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20015
Ool2000EOol00`00Oomoo`1DOol2000FOol00`00Oomoo`0SOol001Ioo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool40005Ool00`00Oomoo`1AOol00`00Oomoo`0bOol00`00Oomoo`1kOol01@00Oomo
ogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0@goo00<007ooOol05Woo00<007ooOol0
DWoo00<007ooOol05goo00<007ooOol08Woo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol0D7oo00<007ooOol0=7oo00<007ooOol0NWoo00D007ooOomoo`00
00moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo049oo`03001oogoo01Qoo`03001oogoo
051oo`03001oogoo01Qoo`03001oogoo029oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool2001AOol00`00Oomoo`0dOol00`00Oomoo`1jOol01@00Oomoogoo0000
2goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`80049oo`03001oogoo01Yoo`03001oogoo04io
o`03001oogoo01Yoo`03001oogoo025oo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0Cgoo
00<007ooOol0=Woo00<007ooOol0NWoo0`003Goo0`001Goo10001Goo00<007ooOol0@7oo00<007oo
Ool077oo00<007ooOol0C7oo00<007ooOol077oo00<007ooOol087oo000hOol00`00Oomoo`1?Ool0
0`00Oomoo`0fOol00`00Oomoo`2KOol00`00Oomoo`0oOol00`00Oomoo`0NOol00`00Oomoo`1:Ool0
0`00Oomoo`0NOol00`00Oomoo`0OOol003Qoo`03001oogoo01moo`<000Ioo`8000Aoo`D001Qoo`@0
00Eoo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<001Yoo`<000Ioo`8000Eoo`<0025oo`D004Uoo`03
001oogoo01moo`<000Ioo`8000Aoo`D000]oo`03001oogoo00Yoo`<000Ioo`8000Ioo`<0009oo`03
001oogoo01=oo`<000Ioo`8000Eoo`<001Uoo`<000Ioo`8000Eoo`<001Uoo`03001oogoo00Eoo`D0
01Aoo`00>7oo0P007goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol00`00Oomoo`02
0005Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001Qo
o`05001oogooOol00005Ool20004Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo0P007goo00D0
07ooOomoo`0000Eoo`8000Eoo`04001oogoo000:Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo
0P001goo00<007ooOol00Woo00<007ooOol04Goo00D007ooOomoo`0000Eoo`8000Aoo`05001oogoo
Ool0000GOol01@00Oomoogoo000017oo0`0017oo00D007ooOomoo`0001Qoo`03001oogoo00Moo`03
001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000eoo`03001oogoo01Moo`03001o
ogoo008000]oo`D001Moo`05001oogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`00
00]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Goo
00<007ooOol02Woo00<007ooOol02Woo00D007ooOomoo`0000]oo`D000=oo`03001oogoo015oo`05
001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000=oo`03001oogoo00Eoo`05
001oogooOol0000IOol00`00Oomoo`06Ool00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001o
ogooOol0000>Ool00`00Oomoo`0FOol01@00Ool007oo00002goo00@007ooOol001Qoo`05001oogoo
Ool0000;Ool01000Oomoogoo0P005goo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00
Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Woo00<007ooOol027oo00<007ooOol02goo
00D007ooOomoo`0000]oo`04001oogoo0005Ool00`00Oomoo`0@Ool01@00Oomoogoo00002goo00D0
07ooOomoo`0001Moo`05001oogooOol00003Ool00`00Oomoo`05Ool01@00Oomoogoo00006Woo00<0
07ooOol01Goo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003goo00<007oo
Ool05Goo00D007oo001oo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;Ool400000goo001o
o`0FOol01@00Oomoogoo000037oo0`008goo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomo
o`0000moo`03001oogoo00Ioo`03001oogoo00aoo`05001oogooOol0000<Ool00`00Ool00006Ool0
0`00Oomoo`0?Ool01@00Oomoogoo00002goo100067oo00D007ooOomoo`00009oo`03001oogoo00Mo
o`<001aoo`03001oogoo00Aoo`03001oogoo01Aoo`00>7oo0P007goo00D007ooOomoo`0000moo`03
001oogoo01Eoo`80009oo`03001oogoo00Yoo`03001oo`0001Qoo`05001oogooOol0000;Ool00`00
Oomoo`03Ool00`00Oomoo`0DOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo
04Uoo`8001moo`05001oogooOol0000?Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool01@00Oomoogoo
000037oo00<007oo00001goo00<007ooOol03Woo00D007ooOomoo`0000]oo`03001oogoo01Uoo`07
001oogooOol007oo00002Goo00D007ooOomoo`0001aoo`03001oogoo00=oo`03001oogoo01Aoo`00
>7oo00<007ooOol07Woo00D007ooOomoo`0000]oo`05001oogooOol0000GOol20002Ool00`00Oomo
o`0;Ool2000HOol01@00Oomoogoo000037oo00<007ooOol00Woo00<007ooOol057oo00D007ooOomo
o`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo0000
2goo00D007ooOomoo`0000Ioo`03001oogoo00ioo`05001oogooOol0000=Ool20008Ool00`00Oomo
o`0=Ool01@00Oomoogoo000037oo00<007ooOol067oo00@007ooOomoo`8000Yoo`05001oogooOol0
000MOol00`00Oomoo`02Ool00`00Oomoo`0DOol003Qoo`03001oogoo01moo`<000eoo`<001Qoo`@0
00moo`03001oogoo01Moo`<000ioo`<0009oo`03001oogoo01Aoo`<000eoo`<0025oo`<004]oo`03
001oogoo01moo`<000eoo`<000Ioo`03001oogoo011oo`<000moo`03001oogoo00Moo`03001oogoo
00eoo`<000ioo`<001Qoo`@000aoo`<001moo`03001oo`00008001Ioo`00>7oo0P00Bgoo00<007oo
Ool0@7oo00<007ooOol0UWoo0P00>Goo00<007ooOol0;7oo00<007ooOol0>goo00<007ooOol0;Woo
00<007ooOol05goo000hOol00`00Oomoo`19Ool00`00Oomoo`12Ool00`00Oomoo`2EOol00`00Oomo
o`0gOol00`00Oomoo`0^Ool00`00Oomoo`0jOol00`00Oomoo`0_Ool00`00Oomoo`0FOol003Qoo`03
001oogoo04Qoo`03001oogoo04Aoo`03001oogoo09Aoo`03001oogoo03Ioo`03001oogoo031oo`03
001oogoo03Qoo`03001oogoo035oo`03001oogoo01Eoo`00>7oo00<007ooOol0B7oo00<007ooOol0
A7oo00<007ooOol0U7oo00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=Woo00<007ooOol0
<goo00<007ooOol057oo000bOooY0010OooY000@Ool003Qoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Eo
o`04001oogoo000:Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool01@00Oomoogoo00001Woo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo0P00Bgoo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo0P002Woo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol057oo000hOol2
0017Ool00`00Oomoo`18Ool00`00Oomoo`14Ool00`00Oomoo`1;Ool2000dOol00`00Oomoo`0fOol0
0`00Oomoo`0bOol00`00Oomoo`1<Ool003Qoo`8004Ioo`03001oogoo04Uoo`03001oogoo04Aoo`03
001oogoo04]oo`<0039oo`03001oogoo03Qoo`03001oogoo031oo`03001oogoo04eoo`00>7oo00<0
07oo0000AGoo00<007ooOol0BWoo00<007ooOol0@Woo00<007ooOol0C7oo00@007ooOol0031oo`03
001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo00@007ooOol004=oo`03001oogoo
04aoo`03001oogoo041oo`03001oogoo04eoo`05001oogooOol0000^Ool00`00Oomoo`0lOol00`00
Oomoo`0/Ool00`00Oomoo`1?Ool003Qoo`04001oogoo0013Ool00`00Oomoo`1<Ool00`00Oomoo`10
Ool00`00Oomoo`1=Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0Z
Ool00`00Oomoo`1@Ool003Qoo`80009oo`03001oogoo03moo`03001oogoo04ioo`03001oogoo03io
o`03001oogoo04ioo`8000=oo`03001oogoo02Yoo`03001oogoo03moo`03001oogoo02Qoo`03001o
ogoo055oo`00>7oo00D007ooOomoo`00041oo`03001oogoo04moo`03001oogoo03ioo`03001oogoo
04ioo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo045oo`03001oogoo02Moo`03001oogoo
055oo`00>7oo00<007ooOol00Woo00<007ooOol0?Goo00<007ooOol0D7oo00<007ooOol0?7oo00<0
07ooOol0Cgoo00<007ooOol017oo00<007ooOol09Woo00<007ooOol0@goo00<007ooOol09Goo00<0
07ooOol0DWoo000hOol00`00Oomoo`02Ool00`00Oomoo`0lOol00`00Oomoo`1BOol00`00Oomoo`0k
Ool00`00Oomoo`1?Ool00`00Oomoo`05Ool00`00Oomoo`0TOol00`00Oomoo`15Ool00`00Oomoo`0S
Ool00`00Oomoo`1COol003Qoo`8000Aoo`03001oogoo03Yoo`03001oogoo05=oo`03001oogoo03Yo
o`03001oogoo051oo`8000Moo`03001oogoo029oo`03001oogoo04Moo`03001oogoo025oo`03001o
ogoo05Aoo`00>7oo00<007ooOol00goo00<007ooOol0>Woo00<007ooOol0E7oo00<007ooOol0>Goo
00<007ooOol0D7oo00<007ooOol01goo00<007ooOol087oo00<007ooOol0BGoo00<007ooOol07goo
00<007ooOol0EGoo000hOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`00Oomoo`1EOol00`00Oomo
o`0hOol00`00Oomoo`1AOol00`00Oomoo`08Ool00`00Oomoo`0NOol00`00Oomoo`1;Ool00`00Oomo
o`0MOol00`00Oomoo`1FOol003Qoo`8000Ioo`03001oogoo03Moo`03001oogoo05Ioo`03001oogoo
03Ioo`03001oogoo059oo`8000Yoo`03001oogoo01aoo`03001oogoo04eoo`03001oogoo01]oo`03
001oogoo05Moo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol01Goo00<007ooOol0
=Woo00<007ooOol0F7oo00<007ooOol0=Goo00<007ooOol0<Goo0`001Woo0P0017oo1@0017oo1000
1Goo00<007ooOol02Woo0P006goo00<007ooOol0Cgoo00<007ooOol06Goo00<007ooOol0F7oo000F
Ool01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo03Aoo`03001oogoo05Uoo`03001oogoo03Aoo`03001oogoo035oo`05001oogooOol0
0005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol05Woo
0P00Dgoo00<007ooOol05Woo0P00Fgoo000FOol01@00Oomoogoo00003Goo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol0=7oo00<007ooOol0FWoo00<007ooOol0<goo00<0
07ooOol0<Goo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00eo
o`03001oogoo01Aoo`03001oogoo05Aoo`03001oogoo01=oo`8005eoo`005Woo00D007ooOomoo`00
00ioo`03001oogoo00Moo`03001oogoo009oo`8000Qoo`03001oogoo039oo`03001oogoo05]oo`03
001oogoo039oo`03001oogoo039oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool2000?Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0AOol00`00Oomoo`1MOol001Io
o`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`08Ool00`00Oomoo`0`Ool0
0`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomoo`0cOol01@00Oomoogoo00003goo00<007ooOol0
0Woo10001Goo00<007ooOol03goo0P0047oo0P00FWoo0P003goo0P00H7oo000FOol01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0;goo00<007oo
Ool0GGoo00<007ooOol0<7oo00<007ooOol0<goo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo015oo`8000aoo`8005ioo`<000]oo`03001oogoo061oo`005Woo00D0
07ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000:Ool00`00Oomoo`0^Ool0
0`00Oomoo`1OOol00`00Oomoo`0^Ool00`00Oomoo`0dOol01@00Oomoogoo00002goo00D007ooOomo
o`0000Aoo`03001oogoo00Ioo`8001Aoo`8000Moo`<006=oo`8000Moo`8006=oo`005goo0`003Goo
0`001Goo10001Goo00<007ooOol02Woo00<007ooOol0;Goo00<007ooOol0H7oo00<007ooOol0;7oo
00<007ooOol0=Woo0`003Goo0`001Goo10001Goo00<007ooOol05Goo1`00J7oo1`00IGoo000hOol0
0`00Oomoo`0;Ool00`00Oomoo`0[Ool00`00Oomoo`1QOol00`00Oomoo`0/Ool00`00Oomoo`1GOol0
0`00Oomoo`3`Ool003Qoo`03001oogoo00]oo`03001oogoo02Yoo`03001oogoo06=oo`03001oogoo
02Yoo`03001oogoo05Qoo`03001oogoo0?1oo`00>7oo0P003Goo00<007ooOol0:Goo00<007ooOol0
Hgoo00<007ooOol0:Woo00<007ooOol0F7oo0P00lGoo000hOol00`00Oomoo`0=Ool00`00Oomoo`0W
Ool00`00Oomoo`1UOol00`00Oomoo`0XOol00`00Oomoo`1IOol00`00Oomoo`3`Ool003Qoo`03001o
ogoo00ioo`03001oogoo02Ioo`03001oogoo06Ioo`03001oogoo02Ioo`03001oogoo05Yoo`03001o
ogoo0?1oo`00>7oo0P003goo00<007ooOol09Goo00<007ooOol0J7oo00<007ooOol09Goo00<007oo
Ool0FWoo0P00lGoo000hOol00`00Oomoo`0?Ool00`00Oomoo`0SOol00`00Oomoo`1ZOol00`00Oomo
o`0SOol00`00Oomoo`1KOol00`00Oomoo`3`Ool003Qoo`03001oogoo011oo`03001oogoo029oo`03
001oogoo06]oo`03001oogoo025oo`03001oogoo05aoo`03001oogoo0?1oo`00>7oo00<007ooOol0
47oo00<007ooOol08Goo00<007ooOol0K7oo00<007ooOol087oo00<007ooOol0GGoo00<007ooOol0
l7oo000hOol2000BOol00`00Oomoo`0OOol00`00Oomoo`1^Ool00`00Oomoo`0NOol00`00Oomoo`1N
Ool2003aOol001moo`<000Ioo`8000Eoo`@000Eoo`03001oogoo019oo`03001oogoo01eoo`03001o
ogoo071oo`03001oogoo01aoo`03001oogoo04Ioo`<000Ioo`8000Eoo`@000Eoo`03001oogoo0?1o
o`007Woo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo01=oo`03001oogoo
01]oo`03001oogoo079oo`03001oogoo01Yoo`03001oogoo04Ioo`05001oogooOol00005Ool20009
Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`0DOol2000IOol2001fOol2000IOol00`00Oomoo`17Ool01@00Oomoogoo000047oo00<0
07ooOol00Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo0P005goo
00<007ooOol05Goo00<007ooOol0N7oo00<007ooOol05Goo00<007ooOol0B7oo00D007ooOomoo`00
011oo`03001oogoo009oo`800?5oo`007Woo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo01Mo
o`03001oogoo01=oo`03001oogoo07Yoo`03001oogoo01=oo`03001oogoo04Uoo`05001oogooOol0
000<Ool40005Ool00`00Oomoo`3`Ool001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00
Oomoo`0HOol00`00Oomoo`0AOol00`00Oomoo`1lOol00`00Oomoo`0AOol00`00Oomoo`1:Ool01@00
Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0l7oo000NOol01@00Oomoogoo000037oo00<0
07ooOol01Woo0P006Woo00<007ooOol03Woo0P00P7oo0P003goo0P00CGoo00D007ooOomoo`0000ao
o`03001oogoo00Ioo`800?5oo`007goo0`003Goo10001Goo00<007ooOol06Woo0P0037oo0P00Q7oo
00<007ooOol02Woo0P00D7oo0`003Goo10001Goo00<007ooOol0l7oo000hOol00`00Oomoo`0LOol3
0006Ool30027Ool40005Ool3001[Ool00`00Oomoo`3`Ool003Qoo`03001oogoo01moo`H008eoo`L0
06eoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo
000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol001Mo
o`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03
001oogoo00Aoo`@000Eoo`03001oogoo0?1oo`005Woo00D007ooOomoo`0000Eoo`8000Ioo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol00005Ool20006Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0000>Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80
0?5oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05
001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`3`Ool001Ioo`05001oogooOol0
000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo
00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0l7oo000FOol01@00Oomoogoo00002goo00D0
07ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo
000017oo00<007ooOol01Woo0P00lGoo000GOol3000<Ool50004Ool40005Ool00`00Oomoo`3oOol6
Ool3000<Ool50004Ool40005Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo
0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qo
o`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo
000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`3`Ool003Qo
o`800?moobQoo`800?5oo`00;goo1@0017oo00<007ooOol0ogoo7Woo1@0017oo00<007ooOol0l7oo
000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035o
o`03001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0ogoo9goo
00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?mo
obMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3003oOolW
Ool3003iOol00?mooomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo0`00ogoo1goo
0`0000Aoo`00000001Uoo`<007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000Uoo`05001oogooOol0
003oOol7Ool01@00Oomoogoo00002Goo1P0037oo00<007ooOol0Lgoo002FOol01@00Oomoogoo0000
77oo00<007ooOol0ogoo1Goo00D007ooOomoo`0001Qoo`D007Aoo`00UWoo00D007ooOomoo`0000Uo
o`H000eoo`03001oogoo0?moo`Eoo`05001oogooOol00009Ool60009Ool01000Oomoo`00MGoo002F
Ool01@00Oomoogoo00006Woo0P00ogoo27oo00D007ooOomoo`0001Uoo`03001oo`0007Eoo`00UGoo
1@007Goo00<007ooOol0ogoo17oo1@006Woo00<007oo0000MGoo002cOol01@00Oomoogoo0000ogoo
9Woo0P00MGoo002dOol3003oOolXOol00`00Oomoo`1cOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00;goo1@00ogoo9Goo1@00mgoo000a
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eoo`03001oogoo0?mooaaoo`H000Eo
o`03001oogoo0?Moo`00<Goo00<007ooOol017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000a
Ool00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03
001oogoo00Aoo`03001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007oo
Ool017oo0P00ogoo8Goo00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol3
0006Ool00`00Oomoo`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007oo
Ool0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2003aOol003Qoo`03001oogoo0?moobMo
o`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0l7oo000hOol2003oOolXOol2
003aOol003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0l7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2POol6001:Ool003Qoo`800?moobQo
o`8009aoo`D000Ioo`D004Eoo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool0ogoo1Woo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0V7oo0`0047oo0`00
@Woo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007oo
Ool0ogoo1Goo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001o
ogoo09Moo`03001oogoo01Aoo`03001oogoo03moo`003Woo1P000Woo00D007ooOomoo`0000ioo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo0?aoo`H0009oo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`2FOol00`00Oomoo`0FOol00`00Oomoo`0nOol001Io
o`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2003oOol6Ool01@00Oomoogoo
00003Woo00<007ooOol01goo00<007ooOol00Woo0P00UGoo0P006Woo0P00?Woo000FOol01@00Oomo
ogoo00003Woo00<007ooOol00goo10001Goo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03
001oogoo00=oo`@000Eoo`03001oogoo099oo`8001ioo`8003aoo`005Woo00D007ooOomoo`0000mo
o`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`2AOol00`00Oomoo`0POol00`00Oomoo`0iOol001Io
o`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00ogoo1Woo00D007oo
Oomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2002AOol00`00Oomoo`0ROol00`00
Oomoo`0hOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000aoo`D000Aoo`@0
00Eoo`03001oogoo08moo`03001oogoo02=oo`03001oogoo03Qoo`00>7oo00<007ooOol0ogoo9goo
00<007ooOol0SWoo00<007ooOol09Goo00<007ooOol0=goo000hOol00`00Oomoo`3oOolWOol00`00
Oomoo`2=Ool00`00Oomoo`0WOol00`00Oomoo`0fOol003Qoo`800?moobQoo`8008eoo`03001oogoo
02Uoo`03001oogoo03Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Rgoo00<007ooOol0:goo
00<007ooOol0=7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2;Ool00`00Oomoo`0/Ool00`00
Oomoo`0cOol003Qoo`800?moobQoo`8008]oo`03001oogoo02ioo`03001oogoo039oo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0RGoo00<007ooOol0<7oo00<007ooOol0<Goo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`28Ool00`00Oomoo`0bOol00`00Oomoo`0`Ool003Qoo`03001oogoo0?mo
obMoo`03001oogoo08Moo`03001oogoo03=oo`03001oogoo031oo`00>7oo0P00ogoo:7oo0P00R7oo
00<007ooOol0=7oo00<007ooOol0;goo000OOol30006Ool20005Ool40005Ool00`00Oomoo`3oOol>
Ool30006Ool20005Ool40005Ool00`00Oomoo`26Ool00`00Oomoo`0fOol00`00Oomoo`0^Ool001io
o`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo
00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0QGoo00<007ooOol0>7oo00<007ooOol0;Goo
000FOol60002Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00ogoo1Woo1P000Woo00D007oo
Oomoo`00011oo`03001oogoo009oo`8008Eoo`03001oogoo03Yoo`03001oogoo02aoo`007Woo00D0
07ooOomoo`00011oo`03001oogoo009oo`03001oogoo0?moo`eoo`05001oogooOol0000@Ool00`00
Oomoo`02Ool00`00Oomoo`23Ool00`00Oomoo`0lOol00`00Oomoo`0[Ool001ioo`05001oogooOol0
000<Ool40005Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo000037oo10001Goo00<007ooOol0PWoo
00<007ooOol0?Goo00<007ooOol0:goo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<0
07ooOol0ogoo3Goo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo089oo`03001oogoo
03ioo`03001oogoo02Yoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`800?moo`ioo`05
001oogooOol0000<Ool00`00Oomoo`06Ool20022Ool00`00Oomoo`10Ool00`00Oomoo`0YOol001mo
o`<000eoo`@000Eoo`03001oogoo0?moo`ioo`<000eoo`@000Eoo`03001oogoo081oo`03001oogoo
049oo`03001oogoo02Qoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Ogoo00<007ooOol0A7oo
00<007ooOol09goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1nOol00`00Oomoo`16Ool00`00
Oomoo`0VOol003Qoo`800?moobQoo`8007moo`03001oogoo04Ioo`03001oogoo02Ioo`00>7oo00<0
07ooOol0ogoo9goo00<007ooOol0OGoo00<007ooOol0B7oo00<007ooOol09Goo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`1lOol00`00Oomoo`1:Ool00`00Oomoo`0TOol003Qoo`800?moobQoo`80
07aoo`03001oogoo04]oo`03001oogoo02Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Ngoo
00<007ooOol0C7oo00<007ooOol08goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1jOol00`00
Oomoo`1>Ool00`00Oomoo`0ROol003Qoo`03001oogoo0?moobMoo`03001oogoo07Uoo`03001oogoo
04moo`03001oogoo029oo`00>7oo0P00ogoo:7oo0P00NWoo00<007ooOol0D7oo00<007ooOol08Goo
000GOol30006Ool20004Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool30006Ool20004Ool50004
Ool40005Ool00`00Oomoo`1hOol00`00Oomoo`1AOol00`00Oomoo`0QOol001Ioo`05001oogooOol0
0005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomo
o`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`1gOol00`00Oomoo`1C
Ool00`00Oomoo`0POol000ioo`H0009oo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool2003mOol60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo0P00
Mgoo00<007ooOol0EGoo00<007ooOol07goo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol0ogoo1Goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo07Ioo`03001oogoo05Eoo`03001oogoo01moo`005Woo00D007ooOomoo`00
00moo`03001oogoo009oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000?Ool00`00Oomo
o`02Ool40005Ool00`00Oomoo`1eOol00`00Oomoo`1GOol00`00Oomoo`0NOol001Ioo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0M7oo00<007ooOol0FGoo00<007ooOol0
7Goo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Io
o`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00MGoo00<007ooOol0
FGoo00<007ooOol07Goo000GOol3000=Ool30005Ool40005Ool00`00Oomoo`3oOol6Ool3000=Ool3
0005Ool40005Ool00`00Oomoo`1cOol00`00Oomoo`1KOol00`00Oomoo`0LOol003Qoo`03001oogoo
01moo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<001Yoo`<0
00Ioo`8000Eoo`<0025oo`D004Uoo`03001oogoo01moo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`80
00Ioo`<001Aoo`04001oogooOol30006Ool20005Ool3000IOol30006Ool20005Ool3000LOol00`00
Oomoo`02Ool5000DOol003Qoo`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`005goo
00D007ooOomoo`0000Eoo`8000Moo`03001oogoo01Ioo`05001oogooOol00005Ool20004Ool01@00
Oomoogoo000067oo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0000ROol00`00Oomoo`19
Ool2000OOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool2
0007Ool00`00Oomoo`0BOol01@00Oomoogoo00000goo00<007ooOol00goo0P0017oo00D007ooOomo
o`0001Moo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00006goo00<007ooOol017oo00<0
07ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol05goo00D007oo
Oomoo`0000]oo`D001Moo`05001oogooOol0000;Ool01@00Oomoogoo000067oo00D007ooOomoo`00
00]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Goo
00<007ooOol05goo00D007ooOomoo`0000]oo`D0019oo`03001oogoo009oo`05001oogooOol0000;
Ool01@00Oomoogoo00005goo00D007ooOomoo`0000]oo`05001oogooOol0000LOol00`00Oomoo`03
Ool00`00Oomoo`0DOol003Qoo`03001oogoo01ioo`05001oogooOol0000>Ool00`00Oomoo`0FOol0
1@00Oomoogoo00002goo00@007ooOol001Qoo`05001oogooOol0000;Ool01@00Oomoogoo000067oo
00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00Oomoo`19Ool00`00Oomoo`0NOol01@00
Oomoogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000COol00`00Oomo
o`02Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomo
ogoo00007Goo00<007ooOol00Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo
00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`0001Qoo`05001oogooOol0000;
Ool4000IOol01@00Oomoogoo000037oo0`008goo00<007ooOol0BGoo00<007ooOol07Woo00D007oo
Oomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00Ool0000BOol00`00Oomoo`03
Ool01@00Oomoogoo00002goo100067oo00D007ooOomoo`0000aoo`<001ioo`03001oogoo009oo`03
001oogoo01Aoo`00>7oo0P007goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0
000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo00<007ooOol06Woo00D007ooOomoo`0000]o
o`05001oogooOol0000ROol00`00Oomoo`19Ool2000OOol01@00Oomoogoo00003goo00<007ooOol0
5Goo00D007ooOomoo`0000aoo`03001oo`00019oo`03001oogoo00=oo`05001oogooOol0000;Ool0
0`00Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`0001ioo`05001oogooOol0000FOol0
03Qoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`00
00eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007oo
Oomoo`00029oo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo
00005goo00D007ooOomoo`0000eoo`80015oo`03001oogoo00Aoo`05001oogooOol0000<Ool00`00
Oomoo`0HOol01@00Oomoogoo00002goo00D007ooOomoo`0001ioo`05001oogooOol0000FOol003Qo
o`03001oogoo01moo`<000eoo`<001Uoo`<000moo`03001oogoo01Moo`<000ioo`<001Uoo`<000eo
o`<0025oo`<004]oo`03001oogoo01moo`<000eoo`<001Uoo`<000moo`03001oogoo00moo`03001o
ogoo00Eoo`<000ioo`<001Qoo`<000eoo`<0021oo`@001Ioo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0KWoo00<007ooOol0IWoo00<007ooOol05Woo000hOol2003oOolXOol2001_Ool00`00Oomo
o`1VOol00`00Oomoo`0FOol003Qoo`03001oogoo0?moobMoo`03001oogoo06eoo`03001oogoo06Qo
o`03001oogoo01Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0K7oo00<007ooOol0JWoo00<0
07ooOol057oo000bOooY0010OooY000@Ool003Qoo`8000Uoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Moo`8004]oo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo00<007oo0000:Goo
00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol09goo00<007oo0000Bgoo
0P00:Woo00<007ooOol0:Goo00<007ooOol04goo00<007ooOol04goo00<007ooOol0:Goo00<007oo
Ool0:Goo00<007ooOol057oo000hOol01000Oomoo`00eWoo00<007ooOol0C7oo00<007oo0000JWoo
00<007ooOol0Pgoo000hOol20002Ool00`00Oomoo`3BOol00`00Oomoo`1=Ool3001YOol00`00Oomo
o`24Ool003Qoo`03001oogoo009oo`03001oogoo0=1oo`03001oogoo04ioo`04001oogoo001XOol0
0`00Oomoo`24Ool003Qoo`03001oogoo00=oo`03001oogoo0<ioo`03001oogoo04moo`04001oogoo
001WOol00`00Oomoo`25Ool003Qoo`8000Eoo`03001oogoo0<aoo`03001oogoo051oo`80009oo`03
001oogoo06Aoo`03001oogoo08Eoo`00>7oo00<007ooOol01Goo00<007ooOol0bWoo00<007ooOol0
DGoo00<007ooOol00Woo00<007ooOol0HWoo00<007ooOol0QWoo000hOol00`00Oomoo`06Ool20038
Ool2001DOol00`00Oomoo`02Ool00`00Oomoo`1QOol00`00Oomoo`27Ool003Qoo`03001oogoo00Qo
o`03001oogoo0<Aoo`03001oogoo05Aoo`03001oogoo00=oo`03001oogoo061oo`03001oogoo08Mo
o`00>7oo0P002Woo00<007ooOol0`Woo00<007ooOol0EGoo0P0017oo00<007ooOol0Ggoo00<007oo
Ool0R7oo000hOol00`00Oomoo`0:Ool00`00Oomoo`30Ool00`00Oomoo`1FOol00`00Oomoo`04Ool0
0`00Oomoo`1NOol00`00Oomoo`28Ool003Qoo`03001oogoo00]oo`03001oogoo0;ioo`03001oogoo
05Moo`03001oogoo00Eoo`03001oogoo05aoo`03001oogoo08Uoo`00>7oo00<007ooOol037oo00<0
07ooOol0_7oo00<007ooOol0F7oo00<007ooOol01Goo00<007ooOol0Fgoo00<007ooOol0RWoo000h
Ool2000>Ool00`00Oomoo`2jOol00`00Oomoo`1IOol20007Ool00`00Oomoo`1JOol00`00Oomoo`2:
Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00ioo`03001oogoo0;Qoo`03001o
ogoo03Uoo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Ioo`03001oogoo05Uoo`03001o
ogoo08]oo`005Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`0?Ool00`00Oomoo`2fOol00`00Oomoo`0iOol01@00Oomoogoo00001Goo0P001Goo00@0
07ooOol000Qoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo05Qoo`03001oogoo08]oo`00
5Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`80015oo`03001oogoo0;=o
o`8003aoo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool20009Ool00`00Oomo
o`1FOol00`00Oomoo`2<Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`0AOol00`00Oomoo`2aOol00`00Oomoo`0lOol01@00Oomoogoo00003Woo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0EGoo00<007ooOol0SGoo000FOol0
1@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol04Woo00<007ooOol0[goo00<0
07ooOol0?Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00Uoo`03001o
ogoo05=oo`03001oogoo08ioo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo
00Ioo`03001oogoo01=oo`03001oogoo0:eoo`03001oogoo03ioo`05001oogooOol0000?Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`1COol00`00Oomoo`2>Ool001Io
o`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P005Goo00<007ooOol0
Zgoo00<007ooOol0?goo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2
000;Ool00`00Oomoo`1AOol00`00Oomoo`2?Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo
01Eoo`03001oogoo0:Uoo`03001oogoo045oo`<000eoo`<000Eoo`@000Eoo`03001oogoo00]oo`03
001oogoo04moo`03001oogoo091oo`00>7oo00<007ooOol05Woo00<007ooOol0Ygoo00<007ooOol0
Hgoo00<007ooOol02goo00<007ooOol0Cgoo00<007ooOol0T7oo000hOol2000HOol00`00Oomoo`2U
Ool00`00Oomoo`1TOol2000=Ool00`00Oomoo`1=Ool00`00Oomoo`2AOol003Qoo`03001oogoo01Qo
o`03001oogoo0:9oo`8006Moo`03001oogoo00aoo`03001oogoo04aoo`03001oogoo099oo`00>7oo
00<007ooOol06Goo0P00XGoo00<007ooOol0Igoo00<007ooOol03Goo00<007ooOol0BWoo00<007oo
Ool0Tgoo000hOol00`00Oomoo`0KOol00`00Oomoo`2MOol00`00Oomoo`1XOol00`00Oomoo`0>Ool0
0`00Oomoo`19Ool00`00Oomoo`2COol003Qoo`8001eoo`03001oogoo09]oo`03001oogoo06Uoo`80
00moo`03001oogoo04Qoo`03001oogoo09Aoo`00>7oo00<007ooOol07Goo0P00VWoo00<007ooOol0
JWoo00<007ooOol03goo00<007ooOol0AWoo00<007ooOol0UGoo000hOol00`00Oomoo`0OOol00`00
Oomoo`2FOol00`00Oomoo`1[Ool00`00Oomoo`0?Ool00`00Oomoo`16Ool00`00Oomoo`2EOol003Qo
o`80025oo`03001oogoo09Aoo`03001oogoo06aoo`80015oo`03001oogoo04Aoo`03001oogoo09Io
o`00>7oo00<007ooOol08Goo00<007ooOol0TWoo00<007ooOol0KGoo00<007ooOol04Goo00<007oo
Ool0@Woo00<007ooOol0Ugoo000OOol30006Ool20005Ool40005Ool00`00Oomoo`0ROol2002@Ool2
001GOol30006Ool20005Ool40005Ool00`00Oomoo`0BOol00`00Oomoo`10Ool00`00Oomoo`2HOol0
01ioo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomoo`2<
Ool00`00Oomoo`1FOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol04goo
00<007ooOol0?Woo00<007ooOol0VGoo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00
9Woo00<007ooOol0RWoo00<007ooOol0Egoo00D007ooOomoo`00011oo`03001oogoo009oo`8001Eo
o`03001oogoo03aoo`03001oogoo09Yoo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03
001oogoo02Ioo`03001oogoo08Qoo`03001oogoo05Qoo`05001oogooOol0000@Ool00`00Oomoo`02
Ool00`00Oomoo`0DOol00`00Oomoo`0lOol00`00Oomoo`2JOol001ioo`05001oogooOol0000<Ool4
0005Ool00`00Oomoo`0WOol00`00Oomoo`26Ool00`00Oomoo`1IOol01@00Oomoogoo000037oo1000
1Goo00<007ooOol05Goo00<007ooOol0>Woo00<007ooOol0Vgoo000NOol01@00Oomoogoo000037oo
00<007ooOol01Woo00<007ooOol0:7oo00<007ooOol0Q7oo00<007ooOol0FWoo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`03001oogoo01Ioo`03001oogoo03Qoo`03001oogoo09aoo`007Woo00D0
07ooOomoo`0000aoo`03001oogoo00Ioo`8002Yoo`03001oogoo089oo`03001oogoo05]oo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool2000HOol00`00Oomoo`0fOol00`00Oomoo`2MOol001moo`<0
00eoo`@000Eoo`03001oogoo02Yoo`03001oogoo081oo`03001oogoo05eoo`<000eoo`@000Eoo`03
001oogoo01Qoo`03001oogoo03Aoo`03001oogoo09ioo`00>7oo00<007ooOol0:goo0P00OWoo0P00
NGoo00<007ooOol06Goo00<007ooOol0<Woo00<007ooOol0Wgoo000hOol2000^Ool00`00Oomoo`1j
Ool00`00Oomoo`1iOol2000KOol00`00Oomoo`0`Ool00`00Oomoo`2POol003Qoo`03001oogoo02io
o`8007Qoo`8007aoo`03001oogoo01]oo`03001oogoo02ioo`03001oogoo0:5oo`00>7oo00<007oo
Ool0<7oo00<007ooOol0M7oo00<007ooOol0O7oo00<007ooOol077oo00<007ooOol0;7oo00<007oo
Ool0XWoo000hOol00`00Oomoo`0aOol2001bOol2001oOol00`00Oomoo`0MOol00`00Oomoo`0ZOol0
0`00Oomoo`2SOol003Qoo`8003Aoo`03001oogoo06ioo`03001oogoo07moo`8001moo`03001oogoo
02Qoo`03001oogoo0:Aoo`00>7oo00<007ooOol0=7oo0P00K7oo0P00PWoo00<007ooOol07goo00<0
07ooOol09Woo00<007ooOol0YGoo000hOol00`00Oomoo`0fOol2001XOol20024Ool00`00Oomoo`0P
Ool00`00Oomoo`0TOol00`00Oomoo`2VOol003Qoo`8003Uoo`03001oogoo06Aoo`03001oogoo08Ao
o`80029oo`8002=oo`03001oogoo0:Moo`005goo0`001Woo0P001Woo00<007ooOol017oo10001Goo
00<007ooOol0>Goo0P00HWoo0P00IWoo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007oo
Ool08goo00<007ooOol07goo00<007ooOol0Z7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<0
07ooOol027oo00<007ooOol00Woo00<007ooOol0>goo0P00GWoo0P00Igoo00D007ooOomoo`0000Eo
o`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo02Aoo`03001oogoo01eoo`03001o
ogoo0:Uoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo
03eoo`03001oogoo05Yoo`03001oogoo06Moo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`0UOol00`00Oomoo`0KOol00`00Oomoo`2ZOol001Ioo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000oOol2001HOol2001ZOol01@00Oomoogoo0000
3Woo00<007ooOol01goo00<007ooOol00Woo0P009goo0`0067oo0P00[Goo000FOol01@00Oomoogoo
00003Woo00<007ooOol00goo10001Goo00<007ooOol0@7oo0P00EGoo00<007ooOol0JWoo00D007oo
Oomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo02Uoo`8001=oo`<00:moo`005Woo00D0
07ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo049oo`80055oo`8006eo
o`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0[Ool2000?Ool2
002bOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007oo
Ool0A7oo00<007ooOol0C7oo0P00Kgoo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool00`00Oomoo`0]Ool3000:Ool2002dOol001Moo`<000aoo`D000Aoo`@000Eoo`8004Io
o`8004]oo`03001oogoo071oo`<000aoo`D000Aoo`@000Eoo`80035oo`X00;Ioo`00>7oo00<007oo
Ool0Agoo0P00Agoo0P00U7oo00<007ooOol0l7oo000hOol00`00Oomoo`19Ool20012Ool3002FOol0
0`00Oomoo`3`Ool003Qoo`8004aoo`<003eoo`8009Uoo`800?5oo`00>7oo00<007ooOol0CWoo0P00
>7oo0`00Vgoo00<007ooOol0l7oo000hOol00`00Oomoo`1@Ool2000dOol2002NOol00`00Oomoo`3`
Ool003Qoo`03001oogoo059oo`8002moo`<00:1oo`03001oogoo0?1oo`00>7oo0P00EGoo1000:7oo
0`00Xgoo0P00lGoo000hOol00`00Oomoo`1HOol5000OOol4002VOol00`00Oomoo`3`Ool003Qoo`03
001oogoo05eoo`D001Aoo`H00:Yoo`03001oogoo0?1oo`00>7oo0P00Hgoo5000/7oo0P00lGoo000_
Ool50004Ool00`00Oomoo`3oOolNOol50004Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03
001oogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007oo
Ool0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol0
0`00Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007oo
Ool0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002moo`<0
0?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<00004Ool00000000HOol5003o
Ool5Ool3000017oo000000005goo1@00M7oo002FOol01@00Oomoogoo00002Goo1P0037oo00<007oo
Ool0ogoo1Woo00D007ooOomoo`0000Uoo`H000Yoo`04001oogoo001dOol009Ioo`05001oogooOol0
000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo00006Woo00<007ooOol0M7oo002FOol01@00Oomo
ogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo
07=oo`00UWoo00D007ooOomoo`0001]oo`03001oogoo0?moo`Ioo`05001oogooOol0000LOol00`00
Oomoo`1bOol009Eoo`D001aoo`03001oogoo0?moo`Eoo`D001eoo`03001oogoo079oo`00]Woo00<0
07ooOol0ogoo8goo00D007ooOomoo`0007Aoo`00]7oo0`00ogoo9Woo0`00MGoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .41174 L
.08255 .46022 L
.10458 .5064 L
.12507 .54101 L
.14415 .56472 L
.14918 .56949 L
.15465 .57393 L
.15946 .5772 L
.16457 .58001 L
.16917 .58194 L
.17178 .58279 L
.17423 .58342 L
.17538 .58366 L
.17647 .58386 L
.17746 .58401 L
.17852 .58414 L
.17967 .58424 L
.18073 .58431 L
.182 .58435 L
.18314 .58435 L
.18435 .58431 L
.18547 .58424 L
.1867 .58412 L
.18802 .58395 L
.19071 .58345 L
.19317 .58283 L
.1979 .58118 L
.20239 .57906 L
.21236 .57245 L
.22321 .56235 L
.24299 .53655 L
.26399 .49964 L
.30174 .41399 L
.34195 .30717 L
.38063 .20445 L
.40028 .15721 L
.42177 .11214 L
.44253 .07701 L
.4614 .05353 L
.47149 .04457 L
.47611 .04134 L
.48101 .03853 L
.4835 .03734 L
.48624 .03623 L
.48876 .03538 L
.49106 .03476 L
.49378 .0342 L
.49527 .03398 L
.49596 .0339 L
Mistroke
.49669 .03383 L
.498 .03373 L
.49921 .03369 L
.49996 .03368 L
.50065 .03369 L
.50196 .03373 L
.50313 .03381 L
.50438 .03394 L
.50556 .0341 L
.50663 .03427 L
.50926 .03484 L
.51175 .03554 L
.5167 .03743 L
.52208 .04023 L
.53169 .04711 L
.54056 .05557 L
.55926 .07969 L
.57988 .11532 L
.62014 .2064 L
.65888 .30941 L
.70007 .41854 L
.72063 .46734 L
.73974 .50686 L
.75939 .54012 L
.77791 .56353 L
.78775 .57254 L
.79293 .57628 L
.7984 .57947 L
.80302 .58155 L
.80546 .58241 L
.80809 .58317 L
.8105 .5837 L
.8127 .58405 L
.81375 .58417 L
.81491 .58427 L
.81599 .58432 L
.817 .58435 L
.81818 .58435 L
.81941 .5843 L
.82047 .58423 L
.82163 .58412 L
.82287 .58396 L
.82421 .58374 L
.82661 .58322 L
.82905 .58255 L
.83134 .58176 L
.83564 .57991 L
.84078 .57705 L
.84552 .57381 L
.85624 .56433 L
Mistroke
.87498 .54094 L
.89561 .50604 L
.93591 .41587 L
.97471 .31306 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .43101 L
.08255 .48397 L
.0932 .50724 L
.10458 .5278 L
.11009 .53602 L
.11531 .54268 L
.12038 .5481 L
.12507 .55216 L
.12951 .55515 L
.13178 .55635 L
.13422 .55739 L
.13549 .55784 L
.13666 .55818 L
.13784 .55847 L
.13895 .55868 L
.14022 .55887 L
.1409 .55893 L
.14161 .55898 L
.1423 .55901 L
.14295 .55902 L
.14415 .55898 L
.14531 .55889 L
.14656 .55872 L
.14773 .5585 L
.14881 .55825 L
.15143 .55742 L
.15392 .55636 L
.15886 .55347 L
.16423 .54914 L
.17383 .53844 L
.1827 .52525 L
.20137 .48814 L
.22197 .43474 L
.26217 .30814 L
.30086 .1861 L
.32051 .1344 L
.3309 .11159 L
.342 .09132 L
.35275 .07612 L
.35784 .07055 L
.36253 .06637 L
.36724 .0631 L
.36972 .06176 L
.37235 .06063 L
.37463 .05989 L
.37573 .05961 L
.37677 .0594 L
.37799 .05921 L
.37911 .05909 L
Mistroke
.38031 .05903 L
.38162 .05903 L
.38227 .05905 L
.38296 .0591 L
.38419 .05924 L
.38551 .05947 L
.38695 .0598 L
.38955 .06062 L
.39197 .06165 L
.39649 .06425 L
.40134 .068 L
.40698 .07361 L
.41232 .08012 L
.42232 .09535 L
.44227 .13647 L
.4607 .18512 L
.50002 .30909 L
.53782 .42867 L
.55884 .48419 L
.56803 .50449 L
.57808 .52337 L
.58722 .53729 L
.59696 .54848 L
.60236 .55298 L
.60726 .556 L
.60962 .55709 L
.61086 .55756 L
.61218 .55799 L
.61333 .55831 L
.61459 .55859 L
.61574 .55878 L
.61682 .55891 L
.61808 .559 L
.61871 .55901 L
.61941 .55901 L
.62065 .55896 L
.62181 .55885 L
.62248 .55876 L
.62318 .55865 L
.62443 .55839 L
.62578 .55803 L
.62725 .55755 L
.62973 .55654 L
.63238 .55516 L
.63715 .55192 L
.64214 .5475 L
.64686 .54237 L
.6557 .53035 L
.67568 .4924 L
.69413 .44605 L
Mistroke
.7335 .32417 L
.77136 .20279 L
.79241 .1448 L
.81166 .1027 L
.82118 .08664 L
.8262 .07956 L
.83155 .07313 L
.8367 .06806 L
.84136 .06442 L
.84361 .06299 L
.84604 .06169 L
.84835 .0607 L
.85045 .05999 L
.85159 .05969 L
.85283 .05942 L
.85414 .05921 L
.85538 .05908 L
.85653 .05903 L
.85776 .05903 L
.85881 .05908 L
.85997 .05919 L
.86063 .05928 L
.86132 .0594 L
.86256 .05966 L
.86535 .06048 L
.86777 .06147 L
.87041 .06284 L
.87569 .06646 L
.88133 .07164 L
.89148 .08424 L
.90173 .10105 L
.91284 .12354 L
.933 .17412 L
.97393 .30158 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34781 L
.10458 .38938 L
.14415 .42702 L
.18221 .46133 L
.22272 .49521 L
.26171 .5247 L
.30316 .55212 L
.34309 .57425 L
.3815 .59121 L
.40095 .59808 L
.42237 .60428 L
.44268 .60879 L
.45178 .61038 L
.46172 .6118 L
.4671 .61243 L
.4721 .61294 L
.47727 .61337 L
.48196 .61369 L
.48658 .61393 L
.4887 .61402 L
.49093 .61409 L
.49332 .61416 L
.49438 .61418 L
.49552 .6142 L
.49675 .61421 L
.49789 .61422 L
.49859 .61423 L
.49925 .61423 L
.50049 .61423 L
.50163 .61423 L
.50286 .61422 L
.50401 .6142 L
.50508 .61419 L
.50754 .61413 L
.51014 .61406 L
.51268 .61396 L
.51504 .61385 L
.5204 .61354 L
.5293 .6128 L
.53882 .61173 L
.54906 .61024 L
.56016 .60824 L
.58032 .60358 L
.62123 .59015 L
.66064 .57237 L
.69852 .55109 L
.73886 .52429 L
.77769 .49489 L
.81897 .46031 L
Mistroke
.85873 .42434 L
.89697 .38787 L
.93767 .3477 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .38312 L
.10458 .45832 L
.14415 .5186 L
.18221 .56321 L
.20178 .58009 L
.21267 .58754 L
.22272 .59314 L
.23293 .59756 L
.23832 .59936 L
.24402 .60087 L
.24641 .60137 L
.24897 .60184 L
.25119 .60218 L
.25361 .60247 L
.25507 .60261 L
.25643 .60272 L
.25773 .6028 L
.2584 .60283 L
.25912 .60286 L
.25983 .60288 L
.26048 .6029 L
.26176 .60291 L
.26293 .6029 L
.26416 .60288 L
.26538 .60283 L
.26607 .6028 L
.26671 .60276 L
.26912 .60258 L
.27131 .60234 L
.27364 .60203 L
.27847 .60116 L
.2838 .59985 L
.29326 .59665 L
.30213 .59262 L
.32232 .57987 L
.34082 .56397 L
.38045 .51752 L
.41855 .45944 L
.45912 .38733 L
.49816 .31258 L
.53966 .233 L
.57964 .16161 L
.61811 .1025 L
.63759 .0774 L
.65902 .05421 L
.67938 .0369 L
.69843 .02513 L
.70884 .02058 L
.71396 .01884 L
Mistroke
.71872 .01752 L
.72301 .01658 L
.72758 .01583 L
.7302 .01552 L
.73148 .0154 L
.73266 .01531 L
.73371 .01525 L
.73487 .01519 L
.73603 .01515 L
.73725 .01513 L
.73856 .01513 L
.73977 .01514 L
.7404 .01516 L
.7411 .01518 L
.74251 .01525 L
.74375 .01533 L
.74508 .01544 L
.74748 .01569 L
.74985 .01601 L
.75235 .01642 L
.7568 .01736 L
.76198 .01877 L
.7668 .02038 L
.77773 .02511 L
.78828 .03109 L
.79823 .03795 L
.81683 .05389 L
.85534 .09875 L
.89632 .16122 L
.93577 .23157 L
.97371 .30421 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`800?mooaIoo`H000Eoo`03001oogoo00Aoo`800?5oo`00<Goo00<007ooOol0
17oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04Ool0
0`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03001o
ogoo0?moob1oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol017oo0P00ogoo8Goo
00<007ooOol017oo0P00lGoo000_Ool30006Ool00`00Oomoo`3oOolNOol30006Ool00`00Oomoo`3`
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo0P00ogoo:7oo0P00lGoo000hOol0
0`00Oomoo`1YOol6002gOol00`00Oomoo`3`Ool003Qoo`03001oogoo06Moo`8000Ioo`03001oogoo
0;Aoo`03001oogoo0?1oo`00>7oo00<007ooOol0IWoo00<007ooOol01goo0`00/goo00<007ooOol0
l7oo000hOol2001UOol2000=Ool00`00Oomoo`2`Ool2003aOol003Qoo`03001oogoo06=oo`03001o
ogoo00ioo`03001oogoo0:moo`03001oogoo0?1oo`00>7oo00<007ooOol0HWoo00<007ooOol047oo
00<007ooOol0[Woo00<007ooOol0l7oo000hOol00`00Oomoo`1ROol00`00Oomoo`0@Ool00`00Oomo
o`2^Ool00`00Oomoo`1=Ool6001XOol6000_Ool003Qoo`80069oo`03001oogoo019oo`03001oogoo
0:eoo`8004eoo`03001oogoo00Aoo`03001oogoo06Aoo`8000Eoo`03001oogoo02aoo`005goo0`00
1Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0H7oo00<007ooOol057oo00<007ooOol0
Rgoo0`001Woo0P001Woo00<007ooOol017oo10001Goo00<007ooOol0Bgoo00<007ooOol01Woo0P00
Hgoo00<007ooOol01Woo0P00;7oo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo
00<007ooOol00Woo00<007ooOol0Ggoo00<007ooOol05Goo00<007ooOol0RWoo00D007ooOomoo`00
00Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04Yoo`03001oogoo00Uoo`03
001oogoo05moo`03001oogoo00Uoo`03001oogoo02Uoo`003Woo1P000Woo00D007ooOomoo`0000io
o`03001oogoo00Moo`03001oogoo009oo`8005moo`03001oogoo01Moo`03001oogoo085oo`H0009o
o`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2001:Ool00`00Oomoo`0:Ool0
0`00Oomoo`1OOol00`00Oomoo`09Ool00`00Oomoo`0YOol001Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`1NOol00`00Oomoo`0HOol00`00Oomoo`28Ool01@00
Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0BGoo00<007ooOol02goo
00<007ooOol0GGoo00<007ooOol02goo00<007ooOol0:7oo000FOol01@00Oomoogoo00003Woo00<0
07ooOol00goo10001Goo00<007ooOol0GGoo00<007ooOol06Goo00<007ooOol0R7oo00D007ooOomo
o`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo04Qoo`03001oogoo00aoo`03001oogoo05ao
o`03001oogoo00eoo`03001oogoo02Moo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo05aoo`03001oogoo01]oo`03001oogoo08Moo`05001oogooOol0000?
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`17Ool00`00Oomoo`0>Ool00`00Oomoo`1K
Ool00`00Oomoo`0=Ool00`00Oomoo`0WOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P00GGoo00<007ooOol077oo00<007ooOol0QWoo00D007ooOomoo`0000]o
o`05001oogooOol00004Ool00`00Oomoo`06Ool20018Ool00`00Oomoo`0?Ool00`00Oomoo`1IOol0
0`00Oomoo`0?Ool00`00Oomoo`0VOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo05]oo`03
001oogoo01eoo`03001oogoo08Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo04Ioo`03001oogoo
011oo`03001oogoo05Qoo`03001oogoo011oo`03001oogoo02Ioo`00>7oo00<007ooOol0Fgoo00<0
07ooOol07Woo00<007ooOol0Ygoo00<007ooOol0AGoo00<007ooOol04Woo00<007ooOol0EWoo00<0
07ooOol04Woo00<007ooOol09Goo000hOol2001KOol00`00Oomoo`0OOol00`00Oomoo`2WOol20016
Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol00`00Oomoo`0UOol003Qoo`03001o
ogoo05Uoo`03001oogoo025oo`03001oogoo0:Ioo`03001oogoo04Aoo`03001oogoo01Aoo`03001o
ogoo05Aoo`03001oogoo01Aoo`03001oogoo02Aoo`00>7oo00<007ooOol0FGoo00<007ooOol08Woo
00<007ooOol0YGoo00<007ooOol0A7oo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol05Goo
00<007ooOol08goo000hOol00`00Oomoo`1HOol00`00Oomoo`0SOol00`00Oomoo`2UOol00`00Oomo
o`13Ool00`00Oomoo`0FOol00`00Oomoo`1COol00`00Oomoo`0EOol00`00Oomoo`0SOol003Qoo`80
05Uoo`03001oogoo02Aoo`03001oogoo0:Aoo`8004Aoo`03001oogoo01Ioo`03001oogoo059oo`03
001oogoo01Moo`03001oogoo029oo`00>7oo00<007ooOol0Egoo00<007ooOol09Goo00<007ooOol0
Y7oo00<007ooOol0@goo00<007ooOol05goo00<007ooOol0DGoo00<007ooOol05goo00<007ooOol0
8Woo000hOol00`00Oomoo`1GOol00`00Oomoo`0VOol00`00Oomoo`2SOol00`00Oomoo`12Ool00`00
Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`0QOol003Qoo`8005Moo`03001o
ogoo02Moo`03001oogoo0:=oo`8004=oo`03001oogoo01Uoo`03001oogoo04moo`03001oogoo01Uo
o`03001oogoo025oo`007goo0`001Woo0P001Goo10001Goo00<007ooOol0EWoo00<007ooOol09goo
00<007ooOol0RWoo0`001Woo0P001Goo10001Goo00<007ooOol0@Goo00<007ooOol06Woo00<007oo
Ool0Cgoo00<007ooOol06Goo00<007ooOol08Goo000NOol01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol00Woo00<007ooOol0EWoo00<007ooOol0:7oo00<007ooOol0R7oo00D007ooOomoo`0000Eo
o`8000Uoo`03001oogoo009oo`03001oogoo045oo`03001oogoo01]oo`03001oogoo04eoo`03001o
ogoo01]oo`03001oogoo021oo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`03
001oogoo05Eoo`03001oogoo02Uoo`03001oogoo081oo`H0009oo`05001oogooOol0000@Ool00`00
Oomoo`02Ool00`00Oomoo`11Ool00`00Oomoo`0KOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00
Oomoo`0POol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2001FOol00`00Oomoo`0ZOol0
0`00Oomoo`27Ool01@00Oomoogoo000047oo00<007ooOol00Woo0P00@Goo00<007ooOol077oo00<0
07ooOol0C7oo00<007ooOol077oo00<007ooOol087oo000NOol01@00Oomoogoo000037oo10001Goo
00<007ooOol0E7oo00<007ooOol0:goo00<007ooOol0Qgoo00D007ooOomoo`0000aoo`@000Eoo`03
001oogoo041oo`03001oogoo01eoo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo01moo`00
7Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo05Aoo`03001oogoo02aoo`03001o
ogoo08Ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0oOol00`00Oomoo`0NOol0
0`00Oomoo`1;Ool00`00Oomoo`0MOol00`00Oomoo`0OOol001ioo`05001oogooOol0000<Ool00`00
Oomoo`06Ool00`00Oomoo`1COol00`00Oomoo`0]Ool00`00Oomoo`26Ool01@00Oomoogoo000037oo
00<007ooOol01Woo00<007ooOol0?goo00<007ooOol07Woo00<007ooOol0BWoo00<007ooOol07Woo
00<007ooOol07goo000OOol3000=Ool40005Ool2001DOol00`00Oomoo`0]Ool00`00Oomoo`27Ool3
000=Ool40005Ool2000oOol00`00Oomoo`0POol00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomo
o`0NOol003Qoo`03001oogoo05=oo`03001oogoo02ioo`03001oogoo09moo`03001oogoo03ioo`03
001oogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001oogoo01ioo`00>7oo00<007ooOol0
DWoo00<007ooOol0;goo00<007ooOol0Wgoo00<007ooOol0?Woo00<007ooOol087oo00<007ooOol0
B7oo00<007ooOol087oo00<007ooOol07Woo000hOol2001COol00`00Oomoo`0`Ool00`00Oomoo`2N
Ool2000nOol00`00Oomoo`0ROol00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`0MOol003Qo
o`03001oogoo059oo`03001oogoo031oo`03001oogoo09ioo`03001oogoo03eoo`03001oogoo029o
o`03001oogoo04Ioo`03001oogoo029oo`03001oogoo01eoo`00>7oo00<007ooOol0DGoo00<007oo
Ool0<Woo00<007ooOol0WGoo00<007ooOol0?Goo00<007ooOol08Woo00<007ooOol0AWoo00<007oo
Ool08Woo00<007ooOol07Goo000hOol00`00Oomoo`1AOol00`00Oomoo`0bOol00`00Oomoo`2MOol0
0`00Oomoo`0lOol00`00Oomoo`0TOol00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`0LOol0
03Qoo`80059oo`03001oogoo039oo`03001oogoo09eoo`8003eoo`03001oogoo02Aoo`03001oogoo
04Aoo`03001oogoo02Aoo`03001oogoo01aoo`00>7oo00<007ooOol0D7oo00<007ooOol0=7oo00<0
07ooOol0W7oo00<007ooOol0?7oo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<0
07ooOol077oo000hOol00`00Oomoo`1@Ool00`00Oomoo`0dOol00`00Oomoo`2LOol00`00Oomoo`0k
Ool00`00Oomoo`0VOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`0KOol003Qoo`80051o
o`03001oogoo03Ioo`03001oogoo09]oo`8003aoo`03001oogoo02Ioo`03001oogoo049oo`03001o
ogoo02Ioo`03001oogoo01]oo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0Cgoo
00<007ooOol0=Woo00<007ooOol0NWoo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0>goo
00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol06goo000FOol01@00Oomo
ogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo04moo`03001oogoo
03Ioo`03001oogoo07Uoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol0
0Woo00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol0
6Woo000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007oo
Ool0CWoo00<007ooOol0>7oo00<007ooOol0L7oo1P000Woo00D007ooOomoo`0000eoo`03001oogoo
00Qoo`03001oogoo009oo`03001oogoo03Yoo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo
02Qoo`03001oogoo01Yoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009o
o`8004moo`03001oogoo03Qoo`03001oogoo07Qoo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool2000kOol00`00Oomoo`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomo
o`0JOol001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1=Ool00`00
Oomoo`0iOol00`00Oomoo`1hOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007oo
Ool0>Goo00<007ooOol0:Woo00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol06Goo000FOol0
1@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0CGoo00<007ooOol0
>Woo00<007ooOol0Mgoo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo03Uoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo01Uoo`005Woo
00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001>Ool00`00Oomoo`0j
Ool00`00Oomoo`1gOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`80
03Yoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo01Uoo`005goo0`00
3Goo0`001Goo10001Goo00<007ooOol0C7oo00<007ooOol0?7oo00<007ooOol0Mgoo0`003Goo0`00
1Goo10001Goo00<007ooOol0>7oo00<007ooOol0;7oo00<007ooOol0?Goo00<007ooOol0:goo00<0
07ooOol067oo000hOol00`00Oomoo`1<Ool00`00Oomoo`0lOol00`00Oomoo`2HOol00`00Oomoo`0h
Ool00`00Oomoo`0/Ool00`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`0HOol003Qoo`03001o
ogoo01moo`<000Ioo`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<00003
Ool007oo01Moo`<000Ioo`8000Eoo`<0025oo`D004Uoo`03001oogoo01moo`<000Ioo`8000Aoo`D0
00Eoo`03001oogoo011oo`<000Ioo`8000Ioo`<000Qoo`03001oogoo00eoo`<000Ioo`8000Eoo`<0
01Uoo`@000Eoo`8000Eoo`<001moo`03001oo`0000@001Aoo`00>7oo0P007goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo000GOol20002Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`0FOol0
1@00Oomoogoo00001Goo0P0017oo00L007ooOomoo`00Ool0000FOol01@00Oomoogoo00001Goo0P00
17oo00D007ooOomoo`00029oo`03001oogoo04Uoo`8001moo`05001oogooOol00005Ool20005Ool0
1000Oomoo`001Goo00<007ooOol03goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo00Moo`03
001oogoo00aoo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00005goo00D007ooOomoo`00
00Eoo`8000Aoo`05001oogooOol0000OOol01000Oomoo`005Woo000hOol00`00Oomoo`0NOol01@00
Oomoogoo00003Goo00<007ooOol05goo0P000Woo00<007ooOol02Goo1@005goo00D007ooOomoo`00
00]oo`07001oogooOol007oo00005Woo00D007ooOomoo`0000]oo`05001oogooOol0000ROol00`00
Oomoo`19Ool00`00Oomoo`0NOol01@00Oomoogoo00003Goo00<007ooOol017oo00<007ooOol047oo
00D007ooOomoo`0000]oo`D000Uoo`03001oogoo00]oo`05001oogooOol0000;Ool01@00Oomoogoo
00005goo00<007ooOol00P002goo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`03001o
ogoo01ioo`05001oogooOol0000>Ool00`00Oomoo`0FOol01@00Oomoogoo00002goo00@007ooOol0
01Qoo`05001oogooOol0000;Ool01`00Oomoogoo001oo`0001Ioo`05001oogooOol0000;Ool01@00
Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo
00=oo`03001oogoo011oo`05001oogooOol0000;Ool01000Oomoo`002Woo00<007ooOol02goo00D0
07ooOomoo`0000]oo`05001oogooOol0000GOol00`00Oomoo`02000;Ool01@00Oomoogoo00007goo
00@007ooOol001Ioo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000moo`03001oogoo01Eoo`05
001oogooOol0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10000goo00<007ooOol04goo
00D007ooOomoo`0000aoo`<002=oo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000?
Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool01@00Oomoogoo000037oo00<007oo00002Woo00<007oo
Ool02goo00D007ooOomoo`0000]oo`@001Qoo`03001oogoo008000aoo`<0025oo`03001oo`0001Io
o`00>7oo0P007goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00
Ool0000HOol01@00Oomoogoo00002goo00<007ooOol017oo00<007ooOol04goo00D007ooOomoo`00
00]oo`05001oogooOol0000ROol00`00Oomoo`19Ool2000OOol01@00Oomoogoo00003goo00D007oo
Oomoo`0001=oo`05001oogooOol0000<Ool00`00Ool0000;Ool00`00Oomoo`0:Ool01@00Oomoogoo
00002goo00<007ooOol06Goo00D007oo001oo`0000]oo`05001oogooOol0000POol00`00Ool0000F
Ool003Qoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005Woo0P000goo00<0
07ooOol02goo0P0067oo00D007ooOomoo`0000aoo`03001oogoo00Aoo`03001oogoo019oo`05001o
ogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomo
o`0000]oo`05001oogooOol00003Ool00`00Oomoo`0AOol01@00Oomoogoo00003Goo0P002goo00<0
07ooOol02Woo00D007ooOomoo`0000aoo`03001oogoo01Qoo`05001oo`00Ool0000;Ool01@00Oomo
ogoo000087oo00<007oo00005Woo000hOol00`00Oomoo`0OOol3000=Ool3000GOol00`00Ool00002
000?Ool00`00Oomoo`0GOol3000>Ool30003Ool00`00Oomoo`0COol3000=Ool3000QOol3001;Ool0
0`00Oomoo`0OOol3000=Ool30004Ool00`00Oomoo`0BOol3000?Ool00`00Oomoo`09Ool00`00Oomo
o`0;Ool3000>Ool3000HOol3000=Ool3000QOol3000FOol003Qoo`8004Uoo`03001oogoo04=oo`03
001oogoo09Eoo`8003Ioo`03001oogoo039oo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo
01Eoo`00>7oo00<007ooOol0B7oo00<007ooOol0A7oo00<007ooOol0U7oo00<007ooOol0=Goo00<0
07ooOol0<Woo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol05Goo000hOol00`00Oomoo`18
Ool00`00Oomoo`14Ool00`00Oomoo`2DOol00`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomoo`0f
Ool00`00Oomoo`0cOol00`00Oomoo`0DOol003Qoo`03001oogoo04Moo`03001oogoo04Eoo`03001o
ogoo09Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001o
ogoo01Aoo`00<Wooj@00@7ooj@0047oo000hOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`04Ool01@00Oomo
ogoo00002Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00D007ooOomoo`0000Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`8004]oo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo
0P00Agoo00<007ooOol0B7oo00<007ooOol0AGoo00<007ooOol0BWoo00<007ooOol0=7oo00<007oo
Ool0=7oo00<007ooOol0<goo00<007ooOol0C7oo000hOol20017Ool00`00Oomoo`18Ool00`00Oomo
o`14Ool00`00Oomoo`1;Ool2000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`1<Ool0
03Qoo`8004Ioo`03001oogoo04Uoo`03001oogoo04Aoo`03001oogoo04]oo`8003Aoo`03001oogoo
03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo00<007oo0000AGoo00<007ooOol0BWoo00<0
07ooOol0@goo00<007ooOol0Bgoo0P00=7oo00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol0
C7oo000hOol00`00Ool00014Ool00`00Oomoo`1;Ool00`00Oomoo`12Ool00`00Oomoo`1<Ool00`00
Ool0000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`1=Ool003Qoo`<004Aoo`03001o
ogoo04aoo`03001oogoo045oo`03001oogoo04aoo`<0039oo`03001oogoo03Qoo`03001oogoo031o
o`03001oogoo04eoo`00>7oo00@007ooOol004=oo`03001oogoo04aoo`03001oogoo045oo`03001o
ogoo04aoo`03001oo`00039oo`03001oogoo03Qoo`03001oogoo031oo`03001oogoo04eoo`00>7oo
00@007ooOol0049oo`03001oogoo04eoo`03001oogoo041oo`03001oogoo04eoo`04001oogoo000`
Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`1>Ool003Qoo`05001oogooOol00011Ool0
0`00Oomoo`1>Ool00`00Oomoo`0oOol00`00Oomoo`1=Ool01000Oomoo`00<7oo00<007ooOol0>Woo
00<007ooOol0;Woo00<007ooOol0CWoo000hOol20002Ool00`00Oomoo`0nOol00`00Oomoo`1?Ool0
0`00Oomoo`0nOol00`00Oomoo`1>Ool200000goo001oo`0_Ool00`00Oomoo`0jOol00`00Oomoo`0^
Ool00`00Oomoo`1>Ool003Qoo`05001oogooOol00010Ool00`00Oomoo`1@Ool00`00Oomoo`0mOol0
0`00Oomoo`1>Ool01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0
Cgoo000hOol00`00Oomoo`02Ool00`00Oomoo`0mOol00`00Oomoo`1@Ool00`00Oomoo`0mOol00`00
Oomoo`1>Ool01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007ooOol0;7oo00<007ooOol0Cgoo
000hOol20003Ool00`00Oomoo`0lOol00`00Oomoo`1AOol00`00Oomoo`0lOol00`00Oomoo`1?Ool2
0002Ool00`00Oomoo`0/Ool00`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`1?Ool001Moo`<0
00Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo009oo`03001oogoo03aoo`03001oogoo059oo`03
001oogoo03]oo`03001oogoo02ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo009oo`03
001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo051oo`005Woo00D007ooOomo
o`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0j
Ool00`00Oomoo`1COol00`00Oomoo`0kOol00`00Oomoo`0]Ool01@00Oomoogoo00001Goo0P001Goo
00@007ooOol000Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03io
o`03001oogoo02Yoo`03001oogoo051oo`005Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo03Yoo`03001oogoo05Aoo`03001oogoo03Uoo`03
001oogoo02ioo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20005Ool00`00Oomoo`0iOol00`00Oomo
o`1DOol00`00Oomoo`0iOol00`00Oomoo`0^Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo0P0017oo00<007ooOol0:Goo00<007ooOol0?goo00<007ooOol0:7oo00<007ooOol0
DGoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol017oo00<007oo
Ool0>7oo00<007ooOol0EGoo00<007ooOol0>7oo00<007ooOol0;goo00D007ooOomoo`0000moo`03
001oogoo009oo`@000Eoo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo
02Qoo`03001oogoo055oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo00Aoo`03001oogoo03Qoo`03001oogoo05Ioo`03001oogoo03Moo`03001oogoo02mo
o`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomo
o`0XOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`1AOol001Ioo`05001oogooOol0000;
Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P001Woo00<007ooOol0=Woo00<007ooOol0Egoo
00<007ooOol0=goo00<007ooOol0;goo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00
Oomoo`06Ool20005Ool00`00Oomoo`0WOol00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`1A
Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo00Eoo`03001oogoo03Ioo`03001oogoo05Qo
o`03001oogoo03Eoo`03001oogoo035oo`<000eoo`<000Eoo`@000Eoo`03001oogoo00Aoo`03001o
ogoo02Ioo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo059oo`00>7oo00<007ooOol01Goo
00<007ooOol0=Woo00<007ooOol0F7oo00<007ooOol0=Goo00<007ooOol0DWoo00<007ooOol017oo
00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol0DWoo000hOol00`00Oomo
o`06Ool00`00Oomoo`0dOol00`00Oomoo`1IOol00`00Oomoo`0eOol00`00Oomoo`1BOol00`00Oomo
o`05Ool00`00Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`1BOol003Qoo`80
00Moo`03001oogoo03Aoo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo05=oo`8000Ioo`03
001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo05=oo`00>7oo00<007ooOol0
1goo00<007ooOol0<Woo00<007ooOol0Fgoo00<007ooOol0<goo00<007ooOol0Dgoo00<007ooOol0
1Goo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol0Dgoo000hOol00`00
Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`1LOol00`00Oomoo`0aOol00`00Oomoo`1DOol00`00
Oomoo`06Ool00`00Oomoo`0SOol00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`1COol003Qo
o`8000Uoo`03001oogoo035oo`03001oogoo05aoo`03001oogoo035oo`03001oogoo05Aoo`8000Mo
o`03001oogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo05Aoo`00>7oo00<007oo
Ool027oo00<007ooOol0<7oo00<007ooOol0GGoo00<007ooOol0<7oo00<007ooOol0EGoo00<007oo
Ool01Woo00<007ooOol08Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol0E7oo000hOol0
0`00Oomoo`09Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool00`00Oomoo`1EOol0
0`00Oomoo`07Ool00`00Oomoo`0QOol00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`1DOol0
03Qoo`03001oogoo00Uoo`03001oogoo02ioo`03001oogoo05moo`03001oogoo02moo`03001oogoo
05Eoo`03001oogoo00Moo`03001oogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001oogoo
05Eoo`00>7oo0P002Woo00<007ooOol0;Woo00<007ooOol0Ggoo00<007ooOol0;Woo00<007ooOol0
EWoo0P0027oo00<007ooOol087oo00<007ooOol0B7oo00<007ooOol087oo00<007ooOol0EGoo000O
Ool30006Ool20005Ool40005Ool00`00Oomoo`0:Ool00`00Oomoo`0]Ool00`00Oomoo`1POol00`00
Oomoo`0]Ool00`00Oomoo`0mOol30006Ool20005Ool40005Ool00`00Oomoo`08Ool00`00Oomoo`0O
Ool00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`1EOol001ioo`05001oogooOol00005Ool2
0009Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0/Ool00`00Oomoo`1QOol00`00Oomo
o`0/Ool00`00Oomoo`0mOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0
27oo00<007ooOol07Woo00<007ooOol0BWoo00<007ooOol07Woo00<007ooOol0EWoo000NOol01@00
Oomoogoo000047oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol0:goo00<007ooOol0HGoo
00<007ooOol0;7oo00<007ooOol0?Goo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo
00Qoo`03001oogoo01ioo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo05Ioo`007Woo00D0
07ooOomoo`00011oo`03001oogoo009oo`8000aoo`03001oogoo02Yoo`03001oogoo06=oo`03001o
ogoo02Yoo`03001oogoo03ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000:Ool00`00Oomo
o`0LOol00`00Oomoo`1<Ool00`00Oomoo`0MOol00`00Oomoo`1FOol001ioo`05001oogooOol0000<
Ool40005Ool00`00Oomoo`0<Ool00`00Oomoo`0YOol00`00Oomoo`1SOol00`00Oomoo`0ZOol00`00
Oomoo`0nOol01@00Oomoogoo000037oo10001Goo00<007ooOol02Goo00<007ooOol077oo00<007oo
Ool0CGoo00<007ooOol06goo00<007ooOol0Egoo000NOol01@00Oomoogoo000037oo00<007ooOol0
1Woo00<007ooOol037oo00<007ooOol0:Goo00<007ooOol0I7oo00<007ooOol0:7oo00<007ooOol0
?goo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo01]oo`03001o
ogoo04ioo`03001oogoo01]oo`03001oogoo05Moo`007Woo00D007ooOomoo`0000aoo`03001oogoo
00Ioo`8000ioo`03001oogoo02Moo`03001oogoo06Eoo`03001oogoo02Qoo`03001oogoo03moo`05
001oogooOol0000<Ool00`00Oomoo`06Ool2000;Ool00`00Oomoo`0JOol00`00Oomoo`1>Ool00`00
Oomoo`0JOol00`00Oomoo`1HOol001moo`<000eoo`@000Eoo`03001oogoo00eoo`03001oogoo02Mo
o`03001oogoo06Ioo`03001oogoo02Ioo`03001oogoo045oo`<000eoo`@000Eoo`03001oogoo00Yo
o`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo05Qoo`00>7oo00<007oo
Ool03Woo00<007ooOol09Goo00<007ooOol0Igoo00<007ooOol09Woo00<007ooOol0FWoo00<007oo
Ool02Woo00<007ooOol06Goo00<007ooOol0D7oo00<007ooOol06Goo00<007ooOol0F7oo000hOol0
0`00Oomoo`0>Ool00`00Oomoo`0UOol00`00Oomoo`1XOol00`00Oomoo`0UOol00`00Oomoo`1JOol0
0`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`1AOol00`00Oomoo`0GOol00`00Oomoo`1IOol0
03Qoo`8000moo`03001oogoo02Eoo`03001oogoo06Qoo`03001oogoo02Aoo`03001oogoo05]oo`80
00aoo`03001oogoo01Moo`03001oogoo059oo`03001oogoo01Moo`03001oogoo05Uoo`00>7oo00<0
07ooOol03goo00<007ooOol08goo00<007ooOol0JWoo00<007ooOol08goo00<007ooOol0Fgoo00<0
07ooOol037oo00<007ooOol05Woo00<007ooOol0DWoo00<007ooOol05Woo00<007ooOol0FWoo000h
Ool00`00Oomoo`0?Ool00`00Oomoo`0SOol00`00Oomoo`1ZOol00`00Oomoo`0ROol00`00Oomoo`1L
Ool00`00Oomoo`0<Ool00`00Oomoo`0EOol00`00Oomoo`1DOol00`00Oomoo`0EOol00`00Oomoo`1J
Ool003Qoo`80015oo`03001oogoo025oo`03001oogoo06aoo`03001oogoo025oo`03001oogoo05ao
o`8000ioo`03001oogoo01Aoo`03001oogoo05Aoo`03001oogoo01Aoo`03001oogoo05]oo`00>7oo
00<007ooOol047oo00<007ooOol08Goo00<007ooOol0K7oo00<007ooOol087oo00<007ooOol0GGoo
00<007ooOol03Goo00<007ooOol057oo00<007ooOol0EGoo00<007ooOol04Woo00<007ooOol0G7oo
000hOol00`00Oomoo`0AOol00`00Oomoo`0OOol00`00Oomoo`1^Ool00`00Oomoo`0OOol00`00Oomo
o`1MOol00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol00`00Oomo
o`1LOol003Qoo`03001oogoo015oo`03001oogoo01ioo`03001oogoo06moo`03001oogoo01ioo`03
001oogoo05ioo`03001oogoo00ioo`03001oogoo019oo`03001oogoo05Moo`03001oogoo011oo`03
001oogoo05eoo`00>7oo0P004goo00<007ooOol07Goo00<007ooOol0L7oo00<007ooOol077oo00<0
07ooOol0Ggoo0P003goo00<007ooOol04Goo00<007ooOol0F7oo00<007ooOol047oo00<007ooOol0
GGoo000GOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`0BOol00`00Oomoo`0L
Ool00`00Oomoo`1bOol00`00Oomoo`0KOol00`00Oomoo`0nOol30006Ool20006Ool00`00Oomoo`04
Ool40005Ool00`00Oomoo`0?Ool2000AOol00`00Oomoo`1IOol00`00Oomoo`0>Ool00`00Oomoo`1N
Ool001Ioo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomo
o`0COol00`00Oomoo`0KOol00`00Oomoo`1bOol00`00Oomoo`0JOol00`00Oomoo`0nOol01@00Oomo
ogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol0
3Goo00<007ooOol0FWoo00<007ooOol03Woo00<007ooOol0GWoo000FOol01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol04goo00<007ooOol06Woo00<007ooOol0M7oo
00<007ooOol06Goo00<007ooOol0?Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo
009oo`03001oogoo015oo`03001oogoo00]oo`8005ioo`8000eoo`03001oogoo05moo`005Woo00D0
07ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8001Eoo`03001oogoo01Uoo`03001o
ogoo07Aoo`03001oogoo01Qoo`03001oogoo03moo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool2000COol00`00Oomoo`09Ool00`00Oomoo`1POol00`00Oomoo`09Ool00`00Oomo
o`1POol001Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`0EOol00`00
Oomoo`0GOol00`00Oomoo`1fOol00`00Oomoo`0GOol00`00Oomoo`0oOol01@00Oomoogoo00003Woo
00<007ooOol00goo10001Goo00<007ooOol04goo00<007ooOol01goo00<007ooOol0HWoo00<007oo
Ool01goo00<007ooOol0HGoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
1Woo00<007ooOol05Woo00<007ooOol05Goo00<007ooOol0N7oo00<007ooOol05Goo00<007ooOol0
@7oo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01Aoo`03001o
ogoo00Eoo`03001oogoo06Aoo`03001oogoo00Eoo`03001oogoo069oo`005Woo00D007ooOomoo`00
00]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000HOol00`00Oomoo`0COol00`00Oomoo`1j
Ool00`00Oomoo`0COol00`00Oomoo`11Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03
001oogoo00Ioo`8001Ioo`<0009oo`8006Qoo`8000=oo`8006Eoo`005goo0`0037oo1@0017oo1000
1Goo00<007ooOol067oo00<007ooOol04Goo00<007ooOol0O7oo00<007ooOol04Goo00<007ooOol0
@goo0`0037oo1@0017oo10001Goo00<007ooOol05goo1000JWoo1000Igoo000hOol00`00Oomoo`0I
Ool00`00Oomoo`0?Ool00`00Oomoo`1nOol00`00Oomoo`0>Ool2001WOol00`00Oomoo`3`Ool003Qo
o`03001oogoo01Yoo`03001oogoo00eoo`03001oogoo081oo`03001oogoo00aoo`03001oogoo06Mo
o`03001oogoo0?1oo`00>7oo0P0077oo00<007ooOol02Woo0P00Q7oo00<007ooOol02Woo00<007oo
Ool0J7oo0P00lGoo000hOol00`00Oomoo`0LOol20008Ool20027Ool30008Ool00`00Oomoo`1YOol0
0`00Oomoo`3`Ool003Qoo`03001oogoo01ioo`<000=oo`8008aoo`80009oo`@006aoo`03001oogoo
0?1oo`00>7oo0P008Woo0`00T7oo0`00Kgoo0P00lGoo000hOol00`00Oomoo`3oOolWOol00`00Oomo
o`3`Ool003Qoo`03001oogoo0?moobMoo`03001oogoo0?1oo`00>7oo00<007ooOol0ogoo9goo00<0
07ooOol0l7oo000hOol2003oOolXOol2003aOol002moo`D000Aoo`03001oogoo0?mooaioo`D000Ao
o`03001oogoo0?1oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<0
07ooOol0l7oo000aOol00`00Oomoo`04Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03
001oogoo0?moobMoo`03001oogoo0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000a
Ool00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Mo
o`00;goo0`00ogoo9goo0`00nGoo003oOoooOomFOol00?mooomooeIoo`00UGoo0`0000Aoo`000000
01Qoo`<00?moo`Moo`<00004Ool00000000IOol3001dOol009Ioo`05001oogooOol00009Ool60009
Ool01@00Oomoogoo0000ogoo1goo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo
00D007ooOomoo`0001aoo`03001oogoo0?moo`Eoo`05001oogooOol0000HOol5001dOol009Ioo`05
001oogooOol00009Ool6000=Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00002Goo1P002Goo00@0
07ooOol007Eoo`00UWoo00D007ooOomoo`0001Yoo`800?moo`Qoo`05001oogooOol0000IOol00`00
Ool0001eOol009Eoo`D001eoo`03001oogoo0?moo`Aoo`D001Yoo`03001oo`0007Eoo`00/goo00D0
07ooOomoo`000?moobIoo`8007Eoo`00]7oo0`00ogoo:7oo00<007ooOol0Lgoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOooo
OomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol002moo`D00?mo
obEoo`D00?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000VOol60005Ool00`00Oomo
o`3oOolLOol60005Ool00`00Oomoo`3gOol0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo
00Aoo`800?5oo`00<Goo00<007ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007oo
Ool0l7oo000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`3`
Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`800:1oo`P004Uoo`00;goo0`00
1Woo00<007ooOol0ogoo7Woo0`001Woo00<007ooOol0Vgoo100027oo1000AGoo000hOol00`00Oomo
o`3oOolWOol00`00Oomoo`2HOol3000@Ool20013Ool003Qoo`03001oogoo0?moobMoo`03001oogoo
09Moo`03001oogoo01=oo`03001oogoo041oo`00>7oo0P00ogoo:7oo0P00Ugoo00<007ooOol05Goo
0P00@7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2DOol2000JOol2000nOol003Qoo`03001o
ogoo0?moobMoo`03001oogoo09=oo`03001oogoo01aoo`03001oogoo03]oo`00>7oo0P00ogoo:7oo
0P00Tgoo00<007ooOol07Woo00<007ooOol0>Woo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2A
Ool00`00Oomoo`0POol00`00Oomoo`0iOol003Qoo`03001oogoo0?moobMoo`03001oogoo091oo`03
001oogoo029oo`03001oogoo03Qoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0T7oo00<007oo
Ool08Woo00<007ooOol0>7oo000hOol2003oOolXOol2002@Ool00`00Oomoo`0TOol00`00Oomoo`0g
Ool001Moo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`80
00Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo08ioo`03001oogoo02Ioo`03001oogoo03Ioo`00
5Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?mo
o`Eoo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`2=
Ool00`00Oomoo`0XOol00`00Oomoo`0eOol000ioo`H0009oo`05001oogooOol0000>Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`3lOol60002Ool01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol0S7oo00<007ooOol0:Goo00<007ooOol0=Goo000FOol01@00
Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000io
o`03001oogoo00Moo`03001oogoo009oo`8008aoo`03001oogoo02]oo`03001oogoo03Aoo`005Woo
00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0
000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`2;Ool00`00Oomoo`0/Ool00`00Oomoo`0cOol0
01Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool0
1@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0RWoo00<007ooOol0
;Goo00<007ooOol0<goo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo
00Ioo`800?moo`Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00
RWoo00<007ooOol0;goo00<007ooOol0<Woo000GOol3000<Ool50004Ool40005Ool00`00Oomoo`3o
Ool6Ool3000<Ool50004Ool40005Ool00`00Oomoo`28Ool00`00Oomoo`0aOol00`00Oomoo`0aOol0
03Qoo`03001oogoo0?moobMoo`03001oogoo08Moo`03001oogoo03=oo`03001oogoo031oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0Qgoo00<007ooOol0<goo00<007ooOol0<7oo000hOol2003o
OolXOol20027Ool00`00Oomoo`0eOol00`00Oomoo`0_Ool003Qoo`03001oogoo0?moobMoo`03001o
ogoo08Eoo`03001oogoo03Moo`03001oogoo02ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
QGoo00<007ooOol0>7oo00<007ooOol0;Goo000hOol2003oOolXOol20025Ool00`00Oomoo`0iOol0
0`00Oomoo`0]Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08=oo`03001oogoo03]oo`03001o
ogoo02aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Pgoo00<007ooOol0?7oo00<007ooOol0
:goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`22Ool00`00Oomoo`0mOol00`00Oomoo`0[Ool0
03Qoo`800?moobQoo`8008=oo`03001oogoo03ioo`03001oogoo02Yoo`007goo0`001Woo0P001Goo
10001Goo00<007ooOol0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0PGoo00<007ooOol0
@7oo00<007ooOol0:Goo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007oo
Ool0ogoo3Goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo081oo`03001o
ogoo049oo`03001oogoo02Qoo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`80
0?moo`Ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool20021Ool00`00Oomoo`12Ool0
0`00Oomoo`0XOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool0
1@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0Ogoo00<007ooOol0A7oo00<007ooOol0
9goo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000ao
o`@000Eoo`03001oogoo07ioo`03001oogoo04Ioo`03001oogoo02Ioo`007Woo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool0
0`00Oomoo`1nOol00`00Oomoo`16Ool00`00Oomoo`0VOol001ioo`05001oogooOol0000<Ool00`00
Oomoo`06Ool2003oOol>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P00OWoo00<007ooOol0
B7oo00<007ooOol09Goo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool0
0`00Oomoo`1mOol00`00Oomoo`18Ool00`00Oomoo`0UOol003Qoo`03001oogoo0?moobMoo`03001o
ogoo07aoo`03001oogoo04Yoo`03001oogoo02Aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
Ngoo00<007ooOol0C7oo00<007ooOol08goo000hOol2003oOolXOol2001lOol00`00Oomoo`1<Ool0
0`00Oomoo`0SOol003Qoo`03001oogoo0?moobMoo`03001oogoo07Yoo`03001oogoo04ioo`03001o
ogoo029oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0NWoo00<007ooOol0CWoo00<007ooOol0
8Woo000hOol2003oOolXOol2001jOol00`00Oomoo`1@Ool00`00Oomoo`0QOol003Qoo`03001oogoo
0?moobMoo`03001oogoo07Qoo`03001oogoo055oo`03001oogoo025oo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0N7oo00<007ooOol0DWoo00<007ooOol087oo000hOol00`00Oomoo`3oOolWOol0
0`00Oomoo`1gOol00`00Oomoo`1COol00`00Oomoo`0POol003Qoo`800?moobQoo`8007Qoo`03001o
ogoo05Aoo`03001oogoo01moo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo
1Woo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0MWoo00<007ooOol0EWoo00<007ooOol0
7Woo000FOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001o
ogoo0?moo`Eoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<0
07ooOol0MGoo00<007ooOol0Egoo00<007ooOol07Woo000>Ool60002Ool01@00Oomoogoo00003Goo
00<007ooOol027oo00<007ooOol00Woo0P00oGoo1P000Woo00D007ooOomoo`0000eoo`03001oogoo
00Qoo`03001oogoo009oo`8007Ioo`03001oogoo05Qoo`03001oogoo01eoo`005Woo00D007ooOomo
o`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`1dOol00`00Oomoo`1IOol00`00Oomoo`0M
Ool001Ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00
Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0M7oo00<007ooOol0FWoo00<007oo
Ool077oo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
ogoo1Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo07=oo`03
001oogoo05]oo`03001oogoo01aoo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool0
0`00Oomoo`06Ool2003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo
00Ioo`8007Aoo`03001oogoo05aoo`03001oogoo01]oo`005goo0`003Goo0`001Goo10001Goo00<0
07ooOol0ogoo1Woo0`003Goo0`001Goo10001Goo00<007ooOol0LWoo00<007ooOol0GGoo00<007oo
Ool06goo000hOol00`00Oomoo`0OOol30006Ool20004Ool5000HOol30006Ool20006Ool3000HOol3
0006Ool20005Ool3000JOol30006Ool20005Ool3000QOol50019Ool00`00Oomoo`0OOol30006Ool2
0004Ool5000HOol30006Ool20006Ool3000COol00`00Oomoo`02Ool30006Ool20005Ool3000IOol3
0006Ool20005Ool3000MOol01000Oomoogoo1@0057oo000hOol2000OOol01@00Oomoogoo00001Goo
0P001Goo00@007ooOol001Moo`05001oogooOol00005Ool20007Ool00`00Oomoo`0FOol01@00Oomo
ogoo00001Goo0P0017oo00D007ooOomoo`0001Qoo`05001oogooOol00005Ool20004Ool01@00Oomo
ogoo00008Woo00<007ooOol0BGoo0P007goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000G
Ool01@00Oomoogoo00001Goo0P001goo00<007ooOol04Goo00<007ooOol00Woo00D007ooOomoo`00
00Eoo`8000Aoo`05001oogooOol0000GOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00
01aoo`03001oogoo00=oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000eo
o`03001oogoo01Moo`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol0
7Woo00D007ooOomoo`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000BOol00`00Oomo
o`02Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomo
ogoo00007Goo00<007ooOol00Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo
00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo0000
2goo00D007ooOomoo`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0
BGoo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool0
1000Oomoo`004Woo00<007ooOol00goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00
Oomoogoo00002goo00D007ooOomoo`0001ioo`05001oogooOol0000FOol003Qoo`03001oogoo01io
o`05001oogooOol0000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D0
07ooOomoo`0000]oo`@001Uoo`05001oogooOol0000<Ool3000SOol00`00Oomoo`19Ool00`00Oomo
o`0NOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`00019o
o`03001oogoo00=oo`05001oogooOol0000;Ool4000HOol01@00Oomoogoo000037oo0`007goo00D0
07ooOomoo`0001Ioo`00>7oo0P007goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogoo
Ool0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo00<007ooOol06Woo00D007ooOomoo`00
00]oo`05001oogooOol0000ROol00`00Oomoo`19Ool2000OOol01@00Oomoogoo00003goo00<007oo
Ool05Goo00D007ooOomoo`0000aoo`03001oo`00015oo`03001oogoo00Aoo`05001oogooOol0000;
Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`0001moo`04001oogoo000FOol0
03Qoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`00
00eoo`8001Qoo`05001oogooOol0000<Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007oo
Oomoo`00029oo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo
00005goo00D007ooOomoo`0000eoo`80015oo`03001oogoo00Aoo`05001oogooOol0000<Ool00`00
Oomoo`0HOol01@00Oomoogoo00002goo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`03
001oogoo01moo`<000eoo`<001Uoo`<000moo`03001oogoo01Moo`<000ioo`<001Uoo`<000eoo`<0
025oo`<004]oo`03001oogoo01moo`<000eoo`<001Uoo`<000moo`03001oogoo00ioo`03001oogoo
00Ioo`<000ioo`<001Qoo`<000eoo`<0025oo`<001Ioo`00>7oo00<007ooOol0ogoo9goo00<007oo
Ool0KWoo00<007ooOol0IWoo00<007ooOol05Woo000hOol2003oOolXOol2001^Ool00`00Oomoo`1X
Ool00`00Oomoo`0EOol003Qoo`03001oogoo0?moobMoo`03001oogoo06eoo`03001oogoo06Qoo`03
001oogoo01Eoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0K7oo00<007ooOol0JWoo00<007oo
Ool057oo000bOooY0010OooY000@Ool003Qoo`8000Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Moo`8004]oo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo00<007oo0000:Goo00<0
07ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol09goo00<007oo0000Bgoo0P00
:Woo00<007ooOol0:Goo00<007ooOol04goo00<007ooOol04goo00<007ooOol0:Goo00<007ooOol0
:Goo00<007ooOol057oo000hOol01000Oomoo`00eWoo00<007ooOol0C7oo0P00Jgoo00<007ooOol0
Pgoo000hOol20002Ool00`00Oomoo`3BOol00`00Oomoo`1=Ool3001ZOol00`00Oomoo`23Ool003Qo
o`03001oogoo009oo`03001oogoo0=1oo`03001oogoo04ioo`03001oo`0006Uoo`03001oogoo08Ao
o`00>7oo00<007ooOol00goo00<007ooOol0cWoo00<007ooOol0Cgoo00@007ooOol006Qoo`03001o
ogoo08Aoo`00>7oo0P001Goo00<007ooOol0c7oo00<007ooOol0D7oo0P0000=oo`00Ool0IWoo00<0
07ooOol0QGoo000hOol00`00Oomoo`05Ool00`00Oomoo`3:Ool00`00Oomoo`1AOol01@00Oomoogoo
0000IWoo00<007ooOol0QGoo000hOol00`00Oomoo`06Ool00`00Oomoo`38Ool00`00Oomoo`1BOol0
0`00Oomoo`02Ool00`00Oomoo`1ROol00`00Oomoo`26Ool003Qoo`03001oogoo00Moo`03001oogoo
0<Ioo`03001oogoo05=oo`03001oogoo009oo`03001oogoo065oo`03001oogoo08Moo`00>7oo0P00
2Goo00<007ooOol0a7oo00<007ooOol0E7oo0P0017oo00<007ooOol0H7oo00<007ooOol0Qgoo000h
Ool00`00Oomoo`09Ool00`00Oomoo`32Ool00`00Oomoo`1EOol00`00Oomoo`03Ool00`00Oomoo`1O
Ool00`00Oomoo`28Ool003Qoo`03001oogoo00Yoo`03001oogoo0<1oo`03001oogoo05Ioo`03001o
ogoo00Aoo`03001oogoo05ioo`03001oogoo08Qoo`00>7oo00<007ooOol02goo00<007ooOol0_Woo
00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0GGoo00<007ooOol0RGoo000hOol2000=Ool0
0`00Oomoo`2lOol00`00Oomoo`1HOol20006Ool00`00Oomoo`1LOol00`00Oomoo`29Ool001Moo`<0
00Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00eoo`03001oogoo0;Yoo`03001oogoo03Qoo`<0
00Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo00Eoo`03001oogoo05]oo`03001oogoo08Yoo`00
5Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`0>
Ool00`00Oomoo`2hOol00`00Oomoo`0hOol01@00Oomoogoo00001Goo0P001Goo00@007ooOol000Qo
o`03001oogoo009oo`03001oogoo00Ioo`03001oogoo05Yoo`03001oogoo08Yoo`005Woo00D007oo
Oomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`80011oo`03001oogoo0;Ioo`03001oogoo
03Uoo`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`1I
Ool00`00Oomoo`2;Ool001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`0@Ool00`00Oomoo`2cOol2000lOol01@00Oomoogoo00003Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol01goo00<007ooOol0F7oo00<007ooOol0Rgoo000FOol01@00Oomoogoo
00003goo00<007ooOol00Woo10001Goo00<007ooOol04Goo00<007ooOol0/Goo00<007ooOol0?7oo
00D007ooOomoo`0000moo`03001oogoo009oo`@000Eoo`03001oogoo00Moo`03001oogoo05Moo`03
001oogoo08aoo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo019oo`03001oogoo0:moo`03001oogoo03eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`1FOol00`00Oomoo`2<Ool001Ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P0057oo00<007ooOol0[Goo00<007oo
Ool0?Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20009Ool00`00
Oomoo`1EOol00`00Oomoo`2=Ool001Moo`<000eoo`<000Eoo`@000Eoo`03001oogoo01Aoo`03001o
ogoo0:]oo`03001oogoo041oo`<000eoo`<000Eoo`@000Eoo`03001oogoo00Uoo`03001oogoo05=o
o`03001oogoo08ioo`00>7oo00<007ooOol05Goo00<007ooOol0ZGoo00<007ooOol0HWoo00<007oo
Ool02Goo00<007ooOol0Dgoo00<007ooOol0SWoo000hOol2000GOol00`00Oomoo`2WOol00`00Oomo
o`1SOol2000;Ool00`00Oomoo`1AOol00`00Oomoo`2?Ool003Qoo`03001oogoo01Moo`03001oogoo
0:Eoo`03001oogoo06Aoo`03001oogoo00Yoo`03001oogoo055oo`03001oogoo08moo`00>7oo00<0
07ooOol067oo00<007ooOol0XWoo0P00Igoo00<007ooOol02goo00<007ooOol0Cgoo00<007ooOol0
T7oo000hOol00`00Oomoo`0IOol2002QOol00`00Oomoo`1WOol00`00Oomoo`0;Ool00`00Oomoo`1>
Ool00`00Oomoo`2AOol003Qoo`8001aoo`03001oogoo09eoo`03001oogoo06Qoo`8000eoo`03001o
ogoo04eoo`03001oogoo095oo`00>7oo00<007ooOol077oo00<007ooOol0Vgoo00<007ooOol0JGoo
00<007ooOol037oo00<007ooOol0C7oo00<007ooOol0TWoo000hOol00`00Oomoo`0MOol00`00Oomo
o`2IOol00`00Oomoo`1ZOol00`00Oomoo`0=Ool00`00Oomoo`1;Ool00`00Oomoo`2BOol003Qoo`80
01moo`03001oogoo09Moo`03001oogoo06]oo`8000ioo`03001oogoo04Yoo`03001oogoo09=oo`00
>7oo00<007ooOol07goo00<007ooOol0UGoo00<007ooOol0K7oo00<007ooOol03Woo00<007ooOol0
B7oo00<007ooOol0U7oo000OOol30006Ool20005Ool40005Ool00`00Oomoo`0POol00`00Oomoo`2C
Ool00`00Oomoo`1DOol30006Ool20005Ool40005Ool00`00Oomoo`0>Ool00`00Oomoo`18Ool00`00
Oomoo`2DOol001ioo`05001oogooOol00005Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`0QOol0
0`00Oomoo`2@Ool2001FOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0
3goo00<007ooOol0AWoo00<007ooOol0UGoo000NOol01@00Oomoogoo000047oo00<007ooOol00Woo
0P008goo0P00Sgoo00<007ooOol0EWoo00D007ooOomoo`00011oo`03001oogoo009oo`80011oo`03
001oogoo04Ioo`03001oogoo09Eoo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001o
ogoo02Aoo`03001oogoo08]oo`03001oogoo05Moo`05001oogooOol0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`0@Ool00`00Oomoo`14Ool00`00Oomoo`2FOol001ioo`05001oogooOol0000<Ool40005
Ool00`00Oomoo`0UOol00`00Oomoo`29Ool00`00Oomoo`1HOol01@00Oomoogoo000037oo10001Goo
00<007ooOol04Goo00<007ooOol0@Woo00<007ooOol0Ugoo000NOol01@00Oomoogoo000037oo00<0
07ooOol01Woo00<007ooOol09Woo0P00R7oo00<007ooOol0FGoo00D007ooOomoo`0000aoo`03001o
ogoo00Ioo`03001oogoo019oo`03001oogoo045oo`03001oogoo09Moo`007Woo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`8002Uoo`03001oogoo08Aoo`03001oogoo05Yoo`05001oogooOol0000<
Ool00`00Oomoo`06Ool2000COol00`00Oomoo`10Ool00`00Oomoo`2HOol001moo`<000eoo`@000Eo
o`03001oogoo02Uoo`03001oogoo089oo`03001oogoo05aoo`<000eoo`@000Eoo`03001oogoo01=o
o`03001oogoo03ioo`03001oogoo09Uoo`00>7oo00<007ooOol0:Woo00<007ooOol0P7oo00<007oo
Ool0MWoo00<007ooOol057oo00<007ooOol0?Goo00<007ooOol0VGoo000hOol2000/Ool2001nOol2
001iOol2000EOol00`00Oomoo`0lOol00`00Oomoo`2JOol003Qoo`03001oogoo02eoo`03001oogoo
07Yoo`03001oogoo07Uoo`03001oogoo01Eoo`03001oogoo03]oo`03001oogoo09Yoo`00>7oo00<0
07ooOol0;Woo00<007ooOol0N7oo00<007ooOol0NWoo00<007ooOol05Woo00<007ooOol0>Goo00<0
07ooOol0Vgoo000hOol00`00Oomoo`0_Ool2001fOol2001mOol00`00Oomoo`0GOol00`00Oomoo`0g
Ool00`00Oomoo`2LOol003Qoo`80039oo`03001oogoo079oo`03001oogoo07eoo`8001Qoo`03001o
ogoo03Moo`03001oogoo09aoo`00>7oo00<007ooOol0<Woo00<007ooOol0L7oo00<007ooOol0OWoo
00<007ooOol067oo00<007ooOol0=Goo00<007ooOol0WGoo000hOol00`00Oomoo`0cOol00`00Oomo
o`1^Ool00`00Oomoo`1oOol00`00Oomoo`0IOol00`00Oomoo`0cOol00`00Oomoo`2NOol003Qoo`80
03Eoo`8006aoo`80089oo`8001Yoo`03001oogoo03=oo`03001oogoo09ioo`005goo0`001Woo0P00
1Woo00<007ooOol017oo10001Goo00<007ooOol0=Woo00<007ooOol0Igoo0P00Hgoo0`001Woo0P00
1Woo00<007ooOol017oo10001Goo00<007ooOol06Woo00<007ooOol0<Goo00<007ooOol0Wgoo000F
Ool01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0=goo
0P00IWoo00<007ooOol0HWoo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo01]oo`03001oogoo02moo`03001oogoo0:1oo`005Woo00D007ooOomoo`0000io
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo03Uoo`03001oogoo065oo`8006Eoo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0LOol00`00Oomoo`0]Ool0
0`00Oomoo`2QOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2000k
Ool00`00Oomoo`1NOol2001WOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo
0P007Woo00<007ooOol0:goo00<007ooOol0XWoo000FOol01@00Oomoogoo00003Woo00<007ooOol0
0goo10001Goo00<007ooOol0>goo0P00GGoo00<007ooOol0Igoo00D007ooOomoo`0000ioo`03001o
ogoo00=oo`@000Eoo`03001oogoo01eoo`03001oogoo02Yoo`03001oogoo0:=oo`005Woo00D007oo
Oomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo03eoo`03001oogoo05Qoo`80
06Yoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0NOol00`00
Oomoo`0XOol00`00Oomoo`2TOol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<0
07ooOol01Woo00<007ooOol0?Woo0P00Egoo00<007ooOol0JWoo00D007ooOomoo`0000]oo`05001o
ogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`0OOol00`00Oomoo`0VOol00`00Oomoo`2UOol0
01Moo`<000aoo`D000Aoo`@000Eoo`80045oo`8005=oo`8006ioo`<000aoo`D000Aoo`@000Eoo`80
025oo`03001oogoo02Aoo`03001oogoo0:Ioo`00>7oo00<007ooOol0@Woo0P00Cgoo0P00TGoo00<0
07ooOol08Goo0P008goo00<007ooOol0Ygoo000hOol00`00Oomoo`14Ool00`00Oomoo`1;Ool00`00
Oomoo`2AOol00`00Oomoo`0SOol00`00Oomoo`0OOol00`00Oomoo`2XOol003Qoo`8004Ioo`8004Uo
o`8009Aoo`8002Eoo`03001oogoo01eoo`03001oogoo0:Uoo`00>7oo00<007ooOol0Agoo0P00A7oo
0`00UWoo00<007ooOol09Goo00<007ooOol06goo00<007ooOol0ZWoo000hOol00`00Oomoo`19Ool2
0010Ool2002IOol00`00Oomoo`0VOol2000IOol2002]Ool003Qoo`03001oogoo04]oo`<003Yoo`<0
09]oo`03001oogoo02Qoo`03001oogoo01Aoo`800:moo`00>7oo0P00Cgoo0P00=Woo0P00WWoo0P00
:Woo0P004goo00<007ooOol0[goo000hOol00`00Oomoo`1@Ool3000aOol2002POol00`00Oomoo`0[
Ool2000?Ool2002bOol003Qoo`03001oogoo05=oo`<002]oo`<00:9oo`03001oogoo02eoo`03001o
ogoo00Yoo`800;Aoo`00>7oo0P00Egoo0`009Woo0P00YGoo0P00;goo3000]Woo000_Ool50004Ool0
0`00Oomoo`1IOol4000OOol3002NOol50004Ool00`00Oomoo`3`Ool0035oo`03001oogoo00Aoo`03
001oogoo05eoo`L000moo`T00:=oo`03001oogoo00Aoo`03001oogoo0?1oo`00<Goo00<007ooOol0
17oo00<007ooOol0I7oo3`00[7oo00<007ooOol017oo00<007ooOol0l7oo000aOol00`00Oomoo`04
Ool2003oOolQOol00`00Oomoo`04Ool2003aOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Mo
o`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomo
o`3gOol002moo`<00?moobMoo`<00?Uoo`00ogooogooEWoo003oOoooOomFOol009Eoo`<00004Ool0
0000000HOol5003oOol5Ool3000017oo000000005goo1@00M7oo002FOol01@00Oomoogoo00002Goo
1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H000Yoo`04001oogoo001dOol009Io
o`05001oogooOol0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo00006Woo00<007ooOol0M7oo
002FOol01@00Oomoogoo00002Goo1P0037oo00<007ooOol0ogoo1Woo00D007ooOomoo`0000Uoo`H0
00aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001]oo`03001oogoo0?moo`Ioo`05001oogoo
Ool0000LOol00`00Oomoo`1bOol009Eoo`D001aoo`03001oogoo0?moo`Eoo`D001eoo`03001oogoo
079oo`00]Woo00<007ooOol0ogoo8goo00D007ooOomoo`0007Aoo`00]7oo0`00ogoo9Woo0`00MGoo
003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogoo
ogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo0000\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .42431 L
.08255 .47871 L
.10458 .53054 L
.12507 .56939 L
.14415 .596 L
.14918 .60135 L
.15465 .60634 L
.15946 .61001 L
.16457 .61316 L
.16917 .61533 L
.17178 .61628 L
.17423 .61699 L
.17538 .61726 L
.17647 .61748 L
.17746 .61764 L
.17852 .61779 L
.17967 .61791 L
.18073 .61798 L
.182 .61803 L
.18314 .61803 L
.18435 .61798 L
.18547 .6179 L
.1867 .61777 L
.18802 .61758 L
.19071 .61702 L
.19317 .61633 L
.1979 .61447 L
.20239 .61209 L
.21236 .60467 L
.22321 .59334 L
.24299 .56438 L
.26399 .52296 L
.30174 .42683 L
.34195 .30695 L
.38063 .19166 L
.40028 .13864 L
.42177 .08806 L
.44253 .04863 L
.4614 .02227 L
.47149 .01222 L
.47611 .00859 L
.48101 .00544 L
.4835 .00411 L
.48624 .00286 L
.48876 .00191 L
.49106 .00121 L
.49378 .00059 L
.49527 .00034 L
.49596 .00025 L
Mistroke
.49669 .00017 L
.498 6e-05 L
.49921 1e-05 L
.49996 0 L
.50065 1e-05 L
.50196 6e-05 L
.50313 .00015 L
.50438 .00029 L
.50556 .00047 L
.50663 .00066 L
.50926 .0013 L
.51175 .00209 L
.5167 .00421 L
.52208 .00735 L
.53169 .01507 L
.54056 .02456 L
.55926 .05164 L
.57988 .09163 L
.62014 .19384 L
.65888 .30946 L
.70007 .43193 L
.72063 .4867 L
.73974 .53106 L
.75939 .56839 L
.77791 .59466 L
.78775 .60477 L
.79293 .60897 L
.7984 .61255 L
.80302 .61488 L
.80546 .61586 L
.80809 .61671 L
.8105 .6173 L
.8127 .61769 L
.81375 .61783 L
.81491 .61794 L
.81599 .618 L
.817 .61803 L
.81818 .61803 L
.81941 .61798 L
.82047 .6179 L
.82163 .61777 L
.82287 .61759 L
.82421 .61735 L
.82661 .61677 L
.82905 .61601 L
.83134 .61512 L
.83564 .61304 L
.84078 .60984 L
.84552 .6062 L
.85624 .59556 L
Mistroke
.87498 .56932 L
.89561 .53014 L
.93591 .42895 L
.97471 .31355 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .45981 L
.08255 .52527 L
.0932 .55403 L
.10458 .57945 L
.11009 .58961 L
.11531 .59784 L
.12038 .60454 L
.12507 .60956 L
.12951 .61325 L
.13178 .61474 L
.13422 .61603 L
.13549 .61658 L
.13666 .617 L
.13784 .61736 L
.13895 .61762 L
.14022 .61785 L
.1409 .61793 L
.14161 .61799 L
.1423 .61803 L
.14295 .61803 L
.14415 .61799 L
.14531 .61787 L
.14656 .61767 L
.14773 .61739 L
.14881 .61708 L
.15143 .61606 L
.15392 .61475 L
.15886 .61117 L
.16423 .60583 L
.17383 .59259 L
.1827 .5763 L
.20137 .53043 L
.22197 .46442 L
.26217 .30793 L
.30086 .15709 L
.32051 .09318 L
.3309 .06498 L
.342 .03993 L
.35275 .02114 L
.35784 .01426 L
.36253 .00909 L
.36724 .00504 L
.36972 .00339 L
.37235 .00199 L
.37463 .00107 L
.37573 .00073 L
.37677 .00047 L
.37799 .00024 L
.37911 9e-05 L
Mistroke
.38031 1e-05 L
.38162 1e-05 L
.38227 5e-05 L
.38296 .00011 L
.38419 .00028 L
.38551 .00056 L
.38695 .00097 L
.38955 .00199 L
.39197 .00326 L
.39649 .00647 L
.40134 .01111 L
.40698 .01804 L
.41232 .02609 L
.42232 .0449 L
.44227 .09574 L
.4607 .15587 L
.50002 .3091 L
.53782 .45692 L
.55884 .52554 L
.56803 .55063 L
.57808 .57397 L
.58722 .59118 L
.59696 .60501 L
.60236 .61057 L
.60726 .6143 L
.60962 .61565 L
.61086 .61623 L
.61218 .61677 L
.61333 .61715 L
.61459 .6175 L
.61574 .61774 L
.61682 .6179 L
.61808 .61801 L
.61871 .61803 L
.61941 .61803 L
.62065 .61796 L
.62181 .61783 L
.62248 .61772 L
.62318 .61757 L
.62443 .61725 L
.62578 .61682 L
.62725 .61622 L
.62973 .61497 L
.63238 .61327 L
.63715 .60926 L
.64214 .6038 L
.64686 .59746 L
.6557 .5826 L
.67568 .53569 L
.69413 .4784 L
Mistroke
.7335 .32774 L
.77136 .17771 L
.79241 .10603 L
.81166 .05399 L
.82118 .03415 L
.8262 .0254 L
.83155 .01745 L
.8367 .01118 L
.84136 .00668 L
.84361 .00491 L
.84604 .00331 L
.84835 .00208 L
.85045 .0012 L
.85159 .00083 L
.85283 .0005 L
.85414 .00024 L
.85538 8e-05 L
.85653 1e-05 L
.85776 1e-05 L
.85881 7e-05 L
.85997 .00021 L
.86063 .00033 L
.86132 .00047 L
.86256 .00079 L
.86535 .00181 L
.86777 .00303 L
.87041 .00472 L
.87569 .00921 L
.88133 .0156 L
.89148 .03117 L
.90173 .05195 L
.91284 .07976 L
.933 .14228 L
.97393 .29982 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34829 L
.10458 .39038 L
.14415 .42849 L
.18221 .46323 L
.22272 .49753 L
.26171 .52738 L
.30316 .55515 L
.34309 .57755 L
.3815 .59472 L
.40095 .60168 L
.42237 .60796 L
.44268 .61253 L
.45178 .61413 L
.46172 .61557 L
.4671 .61622 L
.4721 .61673 L
.47727 .61717 L
.48196 .61749 L
.48658 .61773 L
.4887 .61782 L
.49093 .6179 L
.49332 .61796 L
.49438 .61798 L
.49552 .618 L
.49675 .61802 L
.49789 .61803 L
.49859 .61803 L
.49925 .61803 L
.50049 .61803 L
.50163 .61803 L
.50286 .61802 L
.50401 .61801 L
.50508 .61799 L
.50754 .61794 L
.51014 .61786 L
.51268 .61776 L
.51504 .61765 L
.5204 .61733 L
.5293 .61659 L
.53882 .6155 L
.54906 .614 L
.56016 .61197 L
.58032 .60725 L
.62123 .59365 L
.66064 .57566 L
.69852 .55411 L
.73886 .52697 L
.77769 .49721 L
.81897 .4622 L
Mistroke
.85873 .42578 L
.89697 .38885 L
.93767 .34818 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .38693 L
.10458 .466 L
.14415 .52938 L
.18221 .57629 L
.20178 .59404 L
.21267 .60187 L
.22272 .60776 L
.23293 .61241 L
.23832 .6143 L
.24402 .61589 L
.24641 .61642 L
.24897 .61691 L
.25119 .61726 L
.25361 .61757 L
.25507 .61772 L
.25643 .61783 L
.25773 .61792 L
.2584 .61795 L
.25912 .61798 L
.25983 .618 L
.26048 .61802 L
.26176 .61803 L
.26293 .61803 L
.26416 .618 L
.26538 .61795 L
.26607 .61792 L
.26671 .61788 L
.26912 .61768 L
.27131 .61744 L
.27364 .61711 L
.27847 .61619 L
.2838 .61482 L
.29326 .61145 L
.30213 .60721 L
.32232 .59381 L
.34082 .57709 L
.38045 .52825 L
.41855 .46718 L
.45912 .39136 L
.49816 .31277 L
.53966 .22909 L
.57964 .15402 L
.61811 .09187 L
.63759 .06548 L
.65902 .0411 L
.67938 .02289 L
.69843 .01052 L
.70884 .00574 L
.71396 .00391 L
Mistroke
.71872 .00252 L
.72301 .00153 L
.72758 .00074 L
.7302 .00042 L
.73148 .00029 L
.73266 .0002 L
.73371 .00013 L
.73487 7e-05 L
.73603 3e-05 L
.73725 0 L
.73856 0 L
.73977 2e-05 L
.7404 4e-05 L
.7411 6e-05 L
.74251 .00013 L
.74375 .00021 L
.74508 .00033 L
.74748 .00059 L
.74985 .00093 L
.75235 .00136 L
.7568 .00235 L
.76198 .00383 L
.7668 .00553 L
.77773 .0105 L
.78828 .01678 L
.79823 .024 L
.81683 .04076 L
.85534 .08793 L
.89632 .15361 L
.93577 .22759 L
.97371 .30396 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{477.312, 295},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0001L1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
;goo1@00ogoo9Goo1@00mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol002Ioo`H000Eo
o`03001oogoo00Aoo`8006Yoo`D00:Ioo`H000Eoo`03001oogoo00Aoo`8004moo`@006Yoo`@0031o
o`00<Goo00<007ooOol017oo00<007ooOol0Igoo0`0017oo0P00[goo00<007ooOol017oo00<007oo
Ool0C7oo0`000goo00<007ooOol0IWoo0P000goo0P00;Woo000aOol00`00Oomoo`04Ool00`00Oomo
o`1VOol00`00Oomoo`07Ool2002]Ool00`00Oomoo`04Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool0
0`00Oomoo`1TOol00`00Oomoo`05Ool00`00Oomoo`0[Ool0035oo`03001oogoo00Aoo`03001oogoo
06Aoo`8000aoo`03001oogoo0:Yoo`03001oogoo00Aoo`03001oogoo04Yoo`03001oogoo00Moo`80
06=oo`03001oogoo00Moo`03001oogoo02Yoo`00<Goo00<007ooOol017oo0P00I7oo00<007ooOol0
3Goo00<007ooOol0ZGoo00<007ooOol017oo0P00Bgoo00<007ooOol02Goo00<007ooOol0Ggoo00<0
07ooOol02Goo00<007ooOol0:Goo000_Ool30006Ool00`00Oomoo`1ROol00`00Oomoo`0?Ool00`00
Oomoo`2VOol30006Ool00`00Oomoo`19Ool00`00Oomoo`0:Ool00`00Oomoo`1OOol00`00Oomoo`09
Ool00`00Oomoo`0YOol003Qoo`03001oogoo069oo`03001oogoo011oo`03001oogoo0:ioo`03001o
ogoo04Uoo`03001oogoo00]oo`03001oogoo05eoo`03001oogoo00]oo`03001oogoo02Qoo`00>7oo
0P00HWoo00<007ooOol04Goo00<007ooOol0[Woo0P00BGoo00<007ooOol037oo00<007ooOol0GGoo
00<007ooOol037oo00<007ooOol09goo000hOol00`00Oomoo`1POol00`00Oomoo`0COol00`00Oomo
o`2]Ool00`00Oomoo`18Ool00`00Oomoo`0=Ool00`00Oomoo`1KOol00`00Oomoo`0=Ool00`00Oomo
o`0WOol003Qoo`03001oogoo061oo`03001oogoo01Aoo`03001oogoo0:aoo`03001oogoo04Moo`03
001oogoo00ioo`03001oogoo05]oo`03001oogoo00ioo`03001oogoo02Ioo`00>7oo00<007ooOol0
Ggoo00<007ooOol05Goo00<007ooOol0[7oo00<007ooOol0Agoo00<007ooOol03Woo00<007ooOol0
FWoo00<007ooOol03goo00<007ooOol09Woo000hOol2001OOol00`00Oomoo`0GOol00`00Oomoo`2[
Ool20017Ool00`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0@Ool00`00Oomoo`0VOol003Qo
o`03001oogoo05ioo`03001oogoo01Qoo`03001oogoo0:Yoo`03001oogoo04Ioo`03001oogoo011o
o`03001oogoo05Qoo`03001oogoo015oo`03001oogoo02Eoo`00>7oo00<007ooOol0GGoo00<007oo
Ool06Goo00<007ooOol0ZWoo00<007ooOol0AGoo00<007ooOol04Woo00<007ooOol0EWoo00<007oo
Ool04Woo00<007ooOol09Goo000hOol00`00Oomoo`1MOol00`00Oomoo`0JOol00`00Oomoo`2YOol0
0`00Oomoo`15Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0COol00`00Oomoo`0TOol0
03Qoo`8005eoo`03001oogoo01]oo`03001oogoo0:Uoo`8004Eoo`03001oogoo01Aoo`03001oogoo
05Aoo`03001oogoo01Aoo`03001oogoo02Aoo`005goo0`001Woo0P001Woo00<007ooOol017oo1000
1Goo00<007ooOol0G7oo00<007ooOol077oo00<007ooOol0Qgoo0`001Woo0P001Woo00<007ooOol0
17oo10001Goo00<007ooOol0A7oo00<007ooOol057oo00<007ooOol0E7oo00<007ooOol05Goo00<0
07ooOol08goo000FOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo
00<007ooOol0Fgoo00<007ooOol07Woo00<007ooOol0QGoo00D007ooOomoo`0000Eoo`8000Ioo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo04Aoo`03001oogoo01Eoo`03001oogoo05=oo`03
001oogoo01Eoo`03001oogoo02=oo`003Woo1P000Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`8005aoo`03001oogoo01ioo`03001oogoo07eoo`H0009oo`05001oogooOol0
000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20014Ool00`00Oomoo`0FOol00`00Oomoo`1BOol0
0`00Oomoo`0FOol00`00Oomoo`0SOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`1JOol00`00Oomoo`0POol00`00Oomoo`24Ool01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol0@goo00<007ooOol05Woo00<007ooOol0DWoo
00<007ooOol05goo00<007ooOol08Woo000FOol01@00Oomoogoo00003Woo00<007ooOol00goo1000
1Goo00<007ooOol0FWoo00<007ooOol087oo00<007ooOol0Q7oo00D007ooOomoo`0000ioo`03001o
ogoo00=oo`@000Eoo`03001oogoo04=oo`03001oogoo01Moo`03001oogoo055oo`03001oogoo01Mo
o`03001oogoo029oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03
001oogoo05Uoo`03001oogoo029oo`03001oogoo08=oo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`12Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool00`00Oomoo`0H
Ool00`00Oomoo`0ROol001Ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol0
1Woo0P00FWoo00<007ooOol08Woo00<007ooOol0Pgoo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool20013Ool00`00Oomoo`0IOol00`00Oomoo`1?Ool00`00Oomoo`0IOol0
0`00Oomoo`0QOol001Moo`<000aoo`D000Aoo`@000Eoo`03001oogoo05Qoo`03001oogoo02Aoo`03
001oogoo08=oo`<000aoo`D000Aoo`@000Eoo`03001oogoo049oo`03001oogoo01Uoo`03001oogoo
04moo`03001oogoo01Uoo`03001oogoo025oo`00>7oo00<007ooOol0F7oo00<007ooOol097oo00<0
07ooOol0Y7oo00<007ooOol0@Goo00<007ooOol06Woo00<007ooOol0CWoo00<007ooOol06Woo00<0
07ooOol08Goo000hOol2001HOol00`00Oomoo`0UOol00`00Oomoo`2TOol20012Ool00`00Oomoo`0K
Ool00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`0POol003Qoo`03001oogoo05Moo`03001o
ogoo02Ioo`03001oogoo0:=oo`03001oogoo045oo`03001oogoo01]oo`03001oogoo04eoo`03001o
ogoo01]oo`03001oogoo021oo`00>7oo00<007ooOol0EWoo00<007ooOol09goo00<007ooOol0Xgoo
00<007ooOol0@7oo00<007ooOol077oo00<007ooOol0CGoo00<007ooOol06goo00<007ooOol087oo
000hOol00`00Oomoo`1FOol00`00Oomoo`0WOol00`00Oomoo`2SOol00`00Oomoo`10Ool00`00Oomo
o`0MOol00`00Oomoo`1;Ool00`00Oomoo`0LOol00`00Oomoo`0POol003Qoo`8005Moo`03001oogoo
02Qoo`03001oogoo0:9oo`80045oo`03001oogoo01eoo`03001oogoo04]oo`03001oogoo01eoo`03
001oogoo01moo`00>7oo00<007ooOol0EGoo00<007ooOol0:Goo00<007ooOol0XWoo00<007ooOol0
?goo00<007ooOol07Woo00<007ooOol0Bgoo00<007ooOol07Goo00<007ooOol07goo000hOol00`00
Oomoo`1EOol00`00Oomoo`0ZOol00`00Oomoo`2QOol00`00Oomoo`0oOol00`00Oomoo`0NOol00`00
Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`0OOol003Qoo`8005Eoo`03001oogoo02]oo`03001o
ogoo0:5oo`80041oo`03001oogoo01moo`03001oogoo04Uoo`03001oogoo01moo`03001oogoo01io
o`007goo0`001Woo0P001Goo10001Goo00<007ooOol0E7oo00<007ooOol0:goo00<007ooOol0R7oo
0`001Woo0P001Goo10001Goo00<007ooOol0?Woo00<007ooOol087oo00<007ooOol0BGoo00<007oo
Ool07goo00<007ooOol07Woo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<0
07ooOol0E7oo00<007ooOol0;7oo00<007ooOol0QWoo00D007ooOomoo`0000Eoo`8000Uoo`03001o
ogoo009oo`03001oogoo03ioo`03001oogoo021oo`03001oogoo04Qoo`03001oogoo021oo`03001o
ogoo01ioo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo05=oo`03
001oogoo02eoo`03001oogoo07ioo`H0009oo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00
Oomoo`0nOol00`00Oomoo`0QOol00`00Oomoo`17Ool00`00Oomoo`0POol00`00Oomoo`0NOol001io
o`05001oogooOol0000@Ool00`00Oomoo`02Ool2001DOol00`00Oomoo`0]Ool00`00Oomoo`26Ool0
1@00Oomoogoo000047oo00<007ooOol00Woo0P00?Woo00<007ooOol08Woo00<007ooOol0Agoo00<0
07ooOol08Goo00<007ooOol07Goo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol0Dgoo
00<007ooOol0;Woo00<007ooOol0QGoo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo03eoo`03
001oogoo029oo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo01eoo`007Woo00D007ooOomo
o`0000aoo`03001oogoo00Ioo`03001oogoo059oo`03001oogoo02moo`03001oogoo08Eoo`05001o
ogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0mOol00`00Oomoo`0ROol00`00Oomoo`16Ool0
0`00Oomoo`0ROol00`00Oomoo`0MOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00
Oomoo`1BOol00`00Oomoo`0`Ool00`00Oomoo`24Ool01@00Oomoogoo000037oo00<007ooOol01Woo
00<007ooOol0?Goo00<007ooOol08goo00<007ooOol0AGoo00<007ooOol08Woo00<007ooOol07Goo
000OOol3000=Ool40005Ool2001COol00`00Oomoo`0`Ool00`00Oomoo`25Ool3000=Ool40005Ool2
000mOol00`00Oomoo`0TOol00`00Oomoo`14Ool00`00Oomoo`0TOol00`00Oomoo`0LOol003Qoo`03
001oogoo055oo`03001oogoo035oo`03001oogoo09ioo`03001oogoo03aoo`03001oogoo02Aoo`03
001oogoo04Aoo`03001oogoo02Aoo`03001oogoo01aoo`00>7oo00<007ooOol0DGoo00<007ooOol0
<Woo00<007ooOol0WGoo00<007ooOol0?7oo00<007ooOol097oo00<007ooOol0A7oo00<007ooOol0
97oo00<007ooOol077oo000hOol2001BOol00`00Oomoo`0bOol00`00Oomoo`2MOol2000mOol00`00
Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`0KOol003Qoo`03001oogoo051o
o`03001oogoo03=oo`03001oogoo09eoo`03001oogoo03]oo`03001oogoo02Ioo`03001oogoo049o
o`03001oogoo02Ioo`03001oogoo01]oo`00>7oo00<007ooOol0D7oo00<007ooOol0=7oo00<007oo
Ool0W7oo00<007ooOol0>goo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol09Woo00<007oo
Ool06goo000hOol00`00Oomoo`1@Ool00`00Oomoo`0dOol00`00Oomoo`2LOol00`00Oomoo`0kOol0
0`00Oomoo`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomoo`0KOol003Qoo`80051oo`03
001oogoo03Ioo`03001oogoo09]oo`8003aoo`03001oogoo02Moo`03001oogoo045oo`03001oogoo
02Moo`03001oogoo01Yoo`00>7oo00<007ooOol0Cgoo00<007ooOol0=Woo00<007ooOol0Vgoo00<0
07ooOol0>Woo00<007ooOol0:7oo00<007ooOol0@7oo00<007ooOol0:7oo00<007ooOol06Woo000h
Ool00`00Oomoo`1?Ool00`00Oomoo`0fOol00`00Oomoo`2KOol00`00Oomoo`0jOol00`00Oomoo`0X
Ool00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`0JOol003Qoo`8004moo`03001oogoo03Qo
o`03001oogoo09Yoo`8003]oo`03001oogoo02Qoo`03001oogoo041oo`03001oogoo02Qoo`03001o
ogoo01Yoo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0CWoo00<007ooOol0>7oo
00<007ooOol0NGoo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0>Woo00<007ooOol0:Goo
00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol06Goo000FOol01@00Oomoogoo00001Goo0P00
1Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo04ioo`03001oogoo03Qoo`03001oogoo
07Qoo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0
>Goo00<007ooOol0:Woo00<007ooOol0?Woo00<007ooOol0:Woo00<007ooOol06Goo000>Ool60002
Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0CGoo00<007oo
Ool0>Woo00<007ooOol0Kgoo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo03Uoo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo
01Uoo`005Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8004ioo`03001o
ogoo03Yoo`03001oogoo07Moo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2
000jOol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0[Ool00`00Oomoo`0HOol001Ioo`05
001oogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`1=Ool00`00Oomoo`0jOol00`00
Oomoo`1gOol01@00Oomoogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol0>7oo00<007oo
Ool0;7oo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol067oo000FOol01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0C7oo00<007ooOol0?7oo00<007ooOol0
MWoo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo03Qoo`03001o
ogoo02aoo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo01Qoo`005Woo00D007ooOomoo`00
00]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2001=Ool00`00Oomoo`0lOol00`00Oomoo`1f
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8003Uoo`03001oogoo
02aoo`03001oogoo03aoo`03001oogoo02aoo`03001oogoo01Qoo`005goo0`003Goo0`001Goo1000
1Goo00<007ooOol0C7oo00<007ooOol0?7oo00<007ooOol0Mgoo0`003Goo0`001Goo10001Goo00<0
07ooOol0>7oo00<007ooOol0;7oo00<007ooOol0?7oo00<007ooOol0;Goo00<007ooOol05goo000h
Ool00`00Oomoo`1;Ool00`00Oomoo`0nOol00`00Oomoo`2GOol00`00Oomoo`0gOol00`00Oomoo`0^
Ool00`00Oomoo`0jOol00`00Oomoo`0^Ool00`00Oomoo`0GOol003Qoo`03001oogoo01moo`<000Io
o`8000Aoo`D001Qoo`<000Ioo`8000Ioo`<001Qoo`<000Ioo`8000Eoo`<0009oo`03001oogoo01Eo
o`<000Ioo`8000Eoo`<0025oo`D004Uoo`03001oogoo01moo`<000Ioo`8000Aoo`D000Aoo`03001o
ogoo015oo`<000Ioo`8000Ioo`<000Uoo`03001oogoo00aoo`<000Ioo`8000Eoo`<001Uoo`<000Io
o`8000Eoo`<0021oo`H001Aoo`00>7oo0P007goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo
000GOol20002Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P00
17oo00L007ooOomoo`00Ool0000FOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00029o
o`03001oogoo04Uoo`8001moo`05001oogooOol00005Ool20005Ool01000Oomoo`0017oo00<007oo
Ool047oo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo00Qoo`03001oogoo00]oo`05001oogoo
Ool00005Ool20004Ool01@00Oomoogoo00005goo00<007ooOol00P001Goo0P0017oo00D007ooOomo
o`0001moo`04001oogoo000FOol003Qoo`03001oogoo01ioo`05001oogooOol0000=Ool00`00Oomo
o`0GOol01@00Oomoogoo00002goo1@005goo00D007ooOomoo`0000]oo`05001oogooOol00002Ool0
0`00Oomoo`0COol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03001oogoo04Uoo`03001o
ogoo01ioo`05001oogooOol0000=Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool01@00Oomoogoo0000
2goo1@002Goo00<007ooOol02goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol00`00Oomo
o`02000;Ool01@00Oomoogoo000087oo00<007oo00005Woo000hOol00`00Oomoo`0NOol01@00Oomo
ogoo00003Woo00<007ooOol05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo
00002goo00D007ooOomoo`00009oo`03001oogoo01=oo`05001oogooOol0000;Ool01@00Oomoogoo
00008Woo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomoo`0000ioo`03001oogoo009oo`03
001oogoo015oo`05001oogooOol0000;Ool01000Oomoo`002goo00<007ooOol02Woo00D007ooOomo
o`0000]oo`05001oogooOol0000GOol01@00Ool007oo00002goo00D007ooOomoo`00021oo`03001o
o`0001Ioo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogoo
Ool0000<Ool00`00Ool0000HOol01@00Oomoogoo00002goo10000goo00<007ooOol04goo00D007oo
Oomoo`0000aoo`<002=oo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000?Ool01@00
Oomoogoo00004goo00D007ooOomoo`0000aoo`03001oo`0000]oo`03001oogoo00Yoo`05001oogoo
Ool0000;Ool4000HOol01@00Ool007oo000037oo0`008Goo00<007oo00005Woo000hOol2000OOol0
1@00Oomoogoo00003goo00<007ooOol057oo0P000goo00<007ooOol02Woo00<007oo000067oo00D0
07ooOomoo`0000]oo`03001oogoo00Eoo`03001oogoo019oo`05001oogooOol0000;Ool01@00Oomo
ogoo00008Woo00<007ooOol0BGoo0P007goo00D007ooOomoo`0000moo`05001oogooOol0000COol0
1@00Oomoogoo000037oo00<007oo00002goo00<007ooOol02Woo00D007ooOomoo`0000]oo`03001o
ogoo01Uoo`05001oo`00Ool0000;Ool01@00Oomoogoo00008Goo0P005Woo000hOol00`00Oomoo`0N
Ool01@00Oomoogoo00002goo00D007ooOomoo`0001Ioo`8000=oo`03001oogoo00]oo`8001Qoo`05
001oogooOol0000<Ool00`00Oomoo`04Ool00`00Oomoo`0BOol01@00Oomoogoo00002goo00D007oo
Oomoo`00029oo`03001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo
00000goo00<007ooOol04Goo00D007ooOomoo`0000eoo`8000]oo`03001oogoo00Yoo`05001oogoo
Ool0000<Ool00`00Oomoo`0HOol01@00Ool007oo00002goo00D007ooOomoo`00025oo`8001Ioo`00
>7oo00<007ooOol07goo0`003Goo0`005goo00<007oo00000P003goo00<007ooOol05goo0`003Woo
0`000goo00<007ooOol04goo0`003Goo0`008Goo0`00Bgoo00<007ooOol07goo0`003Goo0`000goo
00<007ooOol04goo0`003goo00<007ooOol02Woo00<007ooOol02Woo0`003Woo0`0067oo0`003Goo
0`008Goo0`005Woo000hOol20019Ool00`00Oomoo`14Ool00`00Oomoo`2DOol2000fOol00`00Oomo
o`0bOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`0EOol003Qoo`03001oogoo04Qoo`03
001oogoo04Aoo`03001oogoo09Aoo`03001oogoo03Eoo`03001oogoo039oo`03001oogoo03Ioo`03
001oogoo03=oo`03001oogoo01Aoo`00>7oo00<007ooOol0B7oo00<007ooOol0A7oo00<007ooOol0
U7oo00<007ooOol0=Goo00<007ooOol0<Woo00<007ooOol0=Woo00<007ooOol0<goo00<007ooOol0
57oo000hOol00`00Oomoo`17Ool00`00Oomoo`16Ool00`00Oomoo`2COol00`00Oomoo`0dOol00`00
Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0DOol0039oonT0041oonT0011o
o`00>7oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol017oo00D007ooOomoo`0000Yoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`05001oogooOol00006
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool2001;Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0DOol003Qoo`8004Moo`03001oogoo04Qoo`03001o
ogoo04Eoo`03001oogoo04Yoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo03Aoo`03001o
ogoo04]oo`00>7oo0P00Agoo00<007ooOol0B7oo00<007ooOol0A7oo00<007ooOol0Bgoo0P00=7oo
00<007ooOol0=Woo00<007ooOol0<Woo00<007ooOol0C7oo000hOol20016Ool00`00Oomoo`19Ool0
0`00Oomoo`14Ool00`00Oomoo`1;Ool2000dOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomo
o`1<Ool003Qoo`03001oo`0004Eoo`03001oogoo04Yoo`03001oogoo04=oo`03001oogoo04]oo`80
03Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo04aoo`00>7oo00<007oo0000AGoo00<0
07ooOol0BWoo00<007ooOol0@Woo00<007ooOol0C7oo0P00=7oo00<007ooOol0=Woo00<007ooOol0
<Woo00<007ooOol0C7oo000hOol30014Ool00`00Oomoo`1;Ool00`00Oomoo`12Ool00`00Oomoo`1<
Ool3000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00Oomoo`1=Ool003Qoo`04001oogoo0013
Ool00`00Oomoo`1<Ool00`00Oomoo`11Ool00`00Oomoo`1<Ool00`00Ool0000bOol00`00Oomoo`0h
Ool00`00Oomoo`0`Ool00`00Oomoo`1=Ool003Qoo`04001oogoo0013Ool00`00Oomoo`1<Ool00`00
Oomoo`10Ool00`00Oomoo`1=Ool00`00Ool0000bOol00`00Oomoo`0hOol00`00Oomoo`0`Ool00`00
Oomoo`1=Ool003Qoo`04001oogoo0012Ool00`00Oomoo`1=Ool00`00Oomoo`10Ool00`00Oomoo`1=
Ool00`00Ool0000bOol00`00Oomoo`0iOol00`00Oomoo`0_Ool00`00Oomoo`1=Ool003Qoo`80009o
o`03001oogoo03moo`03001oogoo04ioo`03001oogoo03moo`03001oogoo04eoo`800003Ool007oo
02moo`03001oogoo03Yoo`03001oogoo02ioo`03001oogoo04ioo`00>7oo00D007ooOomoo`00045o
o`03001oogoo04ioo`03001oogoo03ioo`03001oogoo04ioo`04001oogoo000`Ool00`00Oomoo`0j
Ool00`00Oomoo`0^Ool00`00Oomoo`1>Ool003Qoo`05001oogooOol00010Ool00`00Oomoo`1?Ool0
0`00Oomoo`0nOol00`00Oomoo`1>Ool01000Oomoo`00<7oo00<007ooOol0>Woo00<007ooOol0;Woo
00<007ooOol0CWoo000hOol20003Ool00`00Oomoo`0mOol00`00Oomoo`1@Ool00`00Oomoo`0mOol0
0`00Oomoo`1>Ool200000goo001oo`0_Ool00`00Oomoo`0kOol00`00Oomoo`0]Ool00`00Oomoo`1>
Ool001Moo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`03001oogoo009oo`03001oogoo03aoo`03001o
ogoo055oo`03001oogoo03aoo`03001oogoo02ioo`<000Ioo`8000Aoo`D000Aoo`@000Eoo`05001o
ogooOol0000^Ool00`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`1?Ool001Ioo`05001oogoo
Ool00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
?7oo00<007ooOol0DWoo00<007ooOol0>goo00<007ooOol0;Goo00D007ooOomoo`0000Eoo`8000Eo
o`04001oogoo0008Ool00`00Oomoo`02Ool01@00Oomoogoo0000;Woo00<007ooOol0?7oo00<007oo
Ool0;7oo00<007ooOol0Cgoo000FOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol0>goo00<007ooOol0DWoo00<007ooOol0>goo00<007ooOol0
;Goo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo009oo`05001oogooOol0000^Ool0
0`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`1?Ool001Ioo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`0jOol00`00Oomoo`1COol00`00Oomoo`0j
Ool00`00Oomoo`0^Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P000goo
00<007ooOol0:goo00<007ooOol0?Goo00<007ooOol0:goo00<007ooOol0Cgoo000FOol01@00Oomo
ogoo00003goo00<007ooOol00Woo10001Goo00<007ooOol00goo00<007ooOol0>Woo00<007ooOol0
E7oo00<007ooOol0>Goo00<007ooOol0;Woo00D007ooOomoo`0000moo`03001oogoo009oo`@000Eo
o`03001oogoo009oo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo051o
o`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo03Uoo`03001oogoo05Aoo`03001oogoo03Uoo`03001oogoo02ioo`05001oogooOol0000?
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`0n
Ool00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo0P001Goo00<007ooOol0>7oo00<007ooOol0EGoo00<007ooOol0>7oo00<0
07ooOol0;goo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool20003Ool0
0`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0ZOol00`00Oomoo`1@Ool001Moo`<000eoo`<0
00Eoo`@000Eoo`03001oogoo00Aoo`03001oogoo03Qoo`03001oogoo05Ioo`03001oogoo03Moo`03
001oogoo031oo`<000eoo`<000Eoo`@000Eoo`03001oogoo00=oo`03001oogoo02Uoo`03001oogoo
03moo`03001oogoo02Qoo`03001oogoo055oo`00>7oo00<007ooOol01Goo00<007ooOol0=goo00<0
07ooOol0EWoo00<007ooOol0=goo00<007ooOol0DGoo00<007ooOol00goo00<007ooOol0:7oo00<0
07ooOol0@7oo00<007ooOol0:7oo00<007ooOol0DGoo000hOol00`00Oomoo`05Ool00`00Oomoo`0f
Ool00`00Oomoo`1GOol00`00Oomoo`0fOol00`00Oomoo`1BOol00`00Oomoo`03Ool00`00Oomoo`0X
Ool00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomoo`1AOol003Qoo`8000Ioo`03001oogoo03Io
o`03001oogoo05Qoo`03001oogoo03Eoo`03001oogoo059oo`8000Aoo`03001oogoo02Qoo`03001o
ogoo041oo`03001oogoo02Qoo`03001oogoo055oo`00>7oo00<007ooOol01Woo00<007ooOol0=Goo
00<007ooOol0F7oo00<007ooOol0=Goo00<007ooOol0DWoo00<007ooOol017oo00<007ooOol09goo
00<007ooOol0@Goo00<007ooOol09Woo00<007ooOol0DWoo000hOol00`00Oomoo`06Ool00`00Oomo
o`0dOol00`00Oomoo`1IOol00`00Oomoo`0dOol00`00Oomoo`1COol00`00Oomoo`04Ool00`00Oomo
o`0VOol00`00Oomoo`12Ool00`00Oomoo`0VOol00`00Oomoo`1BOol003Qoo`8000Moo`03001oogoo
03Aoo`03001oogoo05Yoo`03001oogoo03=oo`03001oogoo05=oo`8000Eoo`03001oogoo02Ioo`03
001oogoo049oo`03001oogoo02Ioo`03001oogoo059oo`00>7oo00<007ooOol01goo00<007ooOol0
<Woo00<007ooOol0Fgoo00<007ooOol0<goo00<007ooOol0Dgoo00<007ooOol017oo00<007ooOol0
9Woo00<007ooOol0@goo00<007ooOol09Goo00<007ooOol0DWoo000hOol00`00Oomoo`07Ool00`00
Oomoo`0bOol00`00Oomoo`1KOol00`00Oomoo`0bOol00`00Oomoo`1DOol00`00Oomoo`05Ool00`00
Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`0TOol00`00Oomoo`1COol003Qoo`03001oogoo00Mo
o`03001oogoo039oo`03001oogoo05aoo`03001oogoo035oo`03001oogoo05Aoo`03001oogoo00Eo
o`03001oogoo02Aoo`03001oogoo04Aoo`03001oogoo02Aoo`03001oogoo05=oo`00>7oo0P002Goo
00<007ooOol0<7oo00<007ooOol0GGoo00<007ooOol0<Goo00<007ooOol0E7oo0P001Woo00<007oo
Ool097oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol0Dgoo000OOol30006Ool20005Ool4
0005Ool00`00Oomoo`08Ool00`00Oomoo`0`Ool00`00Oomoo`1MOol00`00Oomoo`0`Ool00`00Oomo
o`0lOol30006Ool20005Ool40005Ool00`00Oomoo`05Ool00`00Oomoo`0TOol00`00Oomoo`15Ool0
0`00Oomoo`0SOol00`00Oomoo`1COol001ioo`05001oogooOol00005Ool20009Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool00`00Oomoo`0_Ool00`00Oomoo`1NOol00`00Oomoo`0_Ool00`00Oomoo`0k
Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol08goo
00<007ooOol0AGoo00<007ooOol08Woo00<007ooOol0E7oo000NOol01@00Oomoogoo000047oo00<0
07ooOol00Woo00<007ooOol02Goo00<007ooOol0;Woo00<007ooOol0Ggoo00<007ooOol0;Woo00<0
07ooOol0?7oo00D007ooOomoo`00011oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo029o
o`03001oogoo04Ioo`03001oogoo029oo`03001oogoo05Aoo`007Woo00D007ooOomoo`00011oo`03
001oogoo009oo`8000]oo`03001oogoo02eoo`03001oogoo05moo`03001oogoo02ioo`03001oogoo
03aoo`05001oogooOol0000@Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`0ROol00`00Oomoo`16
Ool00`00Oomoo`0ROol00`00Oomoo`1DOol001ioo`05001oogooOol0000<Ool40005Ool00`00Oomo
o`0:Ool00`00Oomoo`0]Ool00`00Oomoo`1POol00`00Oomoo`0]Ool00`00Oomoo`0lOol01@00Oomo
ogoo000037oo10001Goo00<007ooOol01Woo00<007ooOol08Woo00<007ooOol0Agoo00<007ooOol0
8Goo00<007ooOol0E7oo000NOol01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol02Woo
00<007ooOol0;7oo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0?Goo00D007ooOomoo`00
00aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo021oo`03001oogoo04Qoo`03001oogoo
021oo`03001oogoo05Eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`8000aoo`03001o
ogoo02]oo`03001oogoo065oo`03001oogoo02aoo`03001oogoo03eoo`05001oogooOol0000<Ool0
0`00Oomoo`06Ool20008Ool00`00Oomoo`0POol00`00Oomoo`18Ool00`00Oomoo`0POol00`00Oomo
o`1EOol001moo`<000eoo`@000Eoo`03001oogoo00]oo`03001oogoo02Yoo`03001oogoo06=oo`03
001oogoo02Yoo`03001oogoo03moo`<000eoo`@000Eoo`03001oogoo00Moo`03001oogoo021oo`03
001oogoo04Uoo`03001oogoo01moo`03001oogoo05Eoo`00>7oo00<007ooOol037oo00<007ooOol0
:Goo00<007ooOol0Hgoo00<007ooOol0:Woo00<007ooOol0F7oo00<007ooOol01goo00<007ooOol0
7goo00<007ooOol0BWoo00<007ooOol07goo00<007ooOol0EGoo000hOol00`00Oomoo`0<Ool00`00
Oomoo`0YOol00`00Oomoo`1SOol00`00Oomoo`0ZOol00`00Oomoo`1HOol00`00Oomoo`08Ool00`00
Oomoo`0NOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`1FOol003Qoo`8000eoo`03001o
ogoo02Qoo`03001oogoo06Eoo`03001oogoo02Qoo`03001oogoo05Uoo`8000Uoo`03001oogoo01io
o`03001oogoo04]oo`03001oogoo01eoo`03001oogoo05Ioo`00>7oo00<007ooOol03Goo00<007oo
Ool09goo00<007ooOol0IGoo00<007ooOol0:7oo00<007ooOol0FGoo00<007ooOol027oo00<007oo
Ool07Goo00<007ooOol0C7oo00<007ooOol07Goo00<007ooOol0EWoo000hOol00`00Oomoo`0=Ool0
0`00Oomoo`0WOol00`00Oomoo`1VOol00`00Oomoo`0WOol00`00Oomoo`1IOol00`00Oomoo`09Ool0
0`00Oomoo`0LOol00`00Oomoo`1<Ool00`00Oomoo`0LOol00`00Oomoo`1GOol003Qoo`8000moo`03
001oogoo02Eoo`03001oogoo06Moo`03001oogoo02Ioo`03001oogoo05Yoo`8000Yoo`03001oogoo
01aoo`03001oogoo04eoo`03001oogoo01]oo`03001oogoo05Moo`00>7oo00<007ooOol03Woo00<0
07ooOol09Goo00<007ooOol0J7oo00<007ooOol09Goo00<007ooOol0FWoo00<007ooOol02Goo00<0
07ooOol06goo00<007ooOol0CWoo00<007ooOol06goo00<007ooOol0Egoo000hOol00`00Oomoo`0?
Ool00`00Oomoo`0TOol00`00Oomoo`1XOol00`00Oomoo`0TOol00`00Oomoo`1KOol00`00Oomoo`09
Ool00`00Oomoo`0KOol00`00Oomoo`1>Ool00`00Oomoo`0JOol00`00Oomoo`1HOol003Qoo`03001o
ogoo00moo`03001oogoo02=oo`03001oogoo06Yoo`03001oogoo02=oo`03001oogoo05]oo`03001o
ogoo00Yoo`03001oogoo01Yoo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo05Qoo`00>7oo
0P0047oo00<007ooOol08goo00<007ooOol0JWoo00<007ooOol08goo00<007ooOol0Fgoo0P002goo
00<007ooOol06Goo00<007ooOol0D7oo00<007ooOol06Goo00<007ooOol0F7oo000GOol30006Ool2
0006Ool00`00Oomoo`04Ool40005Ool00`00Oomoo`0@Ool00`00Oomoo`0QOol00`00Oomoo`1/Ool0
0`00Oomoo`0QOol00`00Oomoo`0kOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool00`00Oomo
o`0:Ool00`00Oomoo`0IOol00`00Oomoo`1@Ool00`00Oomoo`0HOol00`00Oomoo`1IOol001Ioo`05
001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00
Oomoo`0QOol00`00Oomoo`1/Ool00`00Oomoo`0QOol00`00Oomoo`0jOol01@00Oomoogoo00001Goo
0P001Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol067oo00<007oo
Ool0DGoo00<007ooOol05goo00<007ooOol0FGoo000FOol01@00Oomoogoo00003Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol07goo00<007ooOol0KWoo00<007ooOol0
7goo00<007ooOol0>goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo00]oo`03001oogoo01Moo`03001oogoo059oo`03001oogoo01Moo`03001oogoo05Uoo`005Woo
00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`80019oo`03001oogoo01moo`03
001oogoo06ioo`03001oogoo01moo`03001oogoo03]oo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool2000=Ool00`00Oomoo`0FOol00`00Oomoo`1BOol00`00Oomoo`0FOol00`00
Oomoo`1JOol001Ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`0BOol0
0`00Oomoo`0MOol00`00Oomoo`1`Ool00`00Oomoo`0MOol00`00Oomoo`0lOol01@00Oomoogoo0000
3Woo00<007ooOol00goo10001Goo00<007ooOol037oo00<007ooOol05Woo00<007ooOol0Dgoo00<0
07ooOol05Goo00<007ooOol0FWoo000FOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol04Woo00<007ooOol07Goo00<007ooOol0L7oo00<007ooOol077oo00<007oo
Ool0?Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00aoo`03
001oogoo01Eoo`03001oogoo05Aoo`03001oogoo01Aoo`03001oogoo05]oo`005Woo00D007ooOomo
o`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000COol00`00Oomoo`0LOol00`00Oomo
o`1aOol00`00Oomoo`0LOol00`00Oomoo`0mOol01@00Oomoogoo00002goo00D007ooOomoo`0000Ao
o`03001oogoo00Ioo`8000ioo`03001oogoo01Aoo`03001oogoo05Aoo`03001oogoo01Aoo`03001o
ogoo05]oo`005goo0`0037oo1@0017oo10001Goo00<007ooOol04goo00<007ooOol06goo00<007oo
Ool0LWoo00<007ooOol06Woo00<007ooOol0?goo0`0037oo1@0017oo10001Goo00<007ooOol03Goo
00<007ooOol057oo00<007ooOol0EGoo00<007ooOol04Woo00<007ooOol0G7oo000hOol00`00Oomo
o`0COol00`00Oomoo`0JOol00`00Oomoo`1cOol00`00Oomoo`0JOol00`00Oomoo`1POol00`00Oomo
o`0>Ool00`00Oomoo`0BOol00`00Oomoo`1FOol00`00Oomoo`0BOol00`00Oomoo`1LOol003Qoo`03
001oogoo01Aoo`03001oogoo01Uoo`03001oogoo07Aoo`03001oogoo01Qoo`03001oogoo065oo`03
001oogoo00ioo`03001oogoo019oo`03001oogoo05Ioo`03001oogoo019oo`03001oogoo05aoo`00
>7oo0P005Goo00<007ooOol067oo00<007ooOol0MGoo00<007ooOol067oo00<007ooOol0HGoo0P00
3goo00<007ooOol04Woo00<007ooOol0Egoo00<007ooOol047oo00<007ooOol0GGoo000hOol00`00
Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`1gOol00`00Oomoo`0FOol00`00Oomoo`1ROol00`00
Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`1HOol00`00Oomoo`0@Ool00`00Oomoo`1MOol003Qo
o`03001oogoo01Ioo`03001oogoo01Aoo`03001oogoo07Uoo`03001oogoo01Aoo`03001oogoo06=o
o`03001oogoo00moo`03001oogoo011oo`03001oogoo05Uoo`03001oogoo00ioo`03001oogoo05io
o`00>7oo0P0067oo00<007ooOol04goo00<007ooOol0NWoo00<007ooOol04goo00<007ooOol0Hgoo
0P004Goo00<007ooOol03Woo00<007ooOol0FWoo00<007ooOol03Woo00<007ooOol0GWoo000hOol0
0`00Oomoo`0HOol00`00Oomoo`0AOol00`00Oomoo`1lOol00`00Oomoo`0AOol00`00Oomoo`1TOol0
0`00Oomoo`0AOol00`00Oomoo`0=Ool00`00Oomoo`1KOol00`00Oomoo`0<Ool00`00Oomoo`1OOol0
03Qoo`03001oogoo01Uoo`03001oogoo00moo`03001oogoo07ioo`03001oogoo00moo`03001oogoo
06Eoo`03001oogoo015oo`03001oogoo00aoo`03001oogoo05eoo`03001oogoo00]oo`03001oogoo
05moo`00>7oo00<007ooOol06Goo00<007ooOol03Woo00<007ooOol0P7oo00<007ooOol03Goo00<0
07ooOol0IWoo00<007ooOol04Woo00<007ooOol02Woo00<007ooOol0Ggoo00<007ooOol02Goo00<0
07ooOol0H7oo000hOol2000KOol00`00Oomoo`0;Ool20024Ool00`00Oomoo`0;Ool00`00Oomoo`1W
Ool2000DOol00`00Oomoo`08Ool00`00Oomoo`1QOol00`00Oomoo`07Ool00`00Oomoo`1QOol002mo
o`D000Aoo`03001oogoo01]oo`03001oogoo00Uoo`03001oogoo08Eoo`03001oogoo00Uoo`03001o
ogoo05moo`D000Aoo`03001oogoo01Aoo`03001oogoo00Ioo`03001oogoo069oo`03001oogoo00Io
o`03001oogoo069oo`00<Goo00<007ooOol017oo00<007ooOol077oo0`001goo00<007ooOol0Qgoo
0P001goo0P00I7oo00<007ooOol017oo00<007ooOol05Goo00<007ooOol017oo00<007ooOol0I7oo
00<007ooOol017oo00<007ooOol0Hgoo000aOol00`00Oomoo`04Ool2000POol7002<Ool7001VOol0
0`00Oomoo`04Ool2000GOol6001XOol6001VOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Mo
o`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000aOol00`00Oomoo`3oOolWOol00`00Oomo
o`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo0?Moo`00;goo0`00ogoo9goo0`00nGoo003o
OoooOomFOol00?mooomooeIoo`00UGoo0`0000Aoo`00000001Qoo`<00?moo`Moo`<00004Ool00000
000IOol3001dOol009Ioo`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000ogoo1goo00D0
07ooOomoo`0000Uoo`H000aoo`03001oogoo07=oo`00UWoo00D007ooOomoo`0001aoo`03001oogoo
0?moo`Eoo`05001oogooOol0000HOol5001dOol009Ioo`05001oogooOol00009Ool6000=Ool00`00
Oomoo`3oOol5Ool01@00Oomoogoo00002Goo1P002Goo00@007ooOol007Eoo`00UWoo00D007ooOomo
o`0001Yoo`800?moo`Qoo`05001oogooOol0000IOol00`00Ool0001eOol009Eoo`D001eoo`03001o
ogoo0?moo`Aoo`D001Yoo`03001oo`0007Eoo`00/goo00D007ooOomoo`000?moobIoo`8007Eoo`00
]7oo0`00ogoo:7oo00<007ooOol0Lgoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00
ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol002moo`D00?moobEoo`D00?Moo`00<Goo00<007ooOol0
ogoo9goo00<007ooOol0mgoo000VOol60005Ool00`00Oomoo`3oOolLOol60005Ool00`00Oomoo`3g
Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`8009moo`X004Qoo`00<Goo00<0
07ooOol017oo00<007ooOol0ogoo87oo00<007ooOol017oo00<007ooOol0Vgoo0`002Woo0`00AGoo
000aOol00`00Oomoo`04Ool00`00Oomoo`3oOolPOol00`00Oomoo`04Ool00`00Oomoo`2HOol3000@
Ool20013Ool0035oo`03001oogoo00Aoo`800?moob5oo`03001oogoo00Aoo`8009Qoo`03001oogoo
01=oo`03001oogoo041oo`00;goo0`001Woo00<007ooOol0ogoo7Woo0`001Woo00<007ooOol0UWoo
00<007ooOol05Goo0P00@7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2DOol2000JOol2000n
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo09=oo`03001oogoo01aoo`03001oogoo03]oo`00
>7oo0P00ogoo:7oo0P00Tgoo00<007ooOol07Woo00<007ooOol0>Woo000hOol00`00Oomoo`3oOolW
Ool00`00Oomoo`2AOol00`00Oomoo`0POol00`00Oomoo`0iOol003Qoo`03001oogoo0?moobMoo`03
001oogoo091oo`03001oogoo029oo`03001oogoo03Qoo`00>7oo0P00ogoo:7oo0P00TGoo00<007oo
Ool08Woo00<007ooOol0>7oo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`2?Ool00`00Oomoo`0T
Ool00`00Oomoo`0gOol003Qoo`03001oogoo0?moobMoo`03001oogoo08ioo`03001oogoo02Ioo`03
001oogoo03Ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0SGoo00<007ooOol0:7oo00<007oo
Ool0=Goo000hOol2003oOolXOol2002=Ool00`00Oomoo`0YOol00`00Oomoo`0eOol001Moo`<000Io
o`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo0?moo`Ioo`<000Ioo`8000Ioo`03001oogoo
00Aoo`@000Eoo`03001oogoo08]oo`03001oogoo02]oo`03001oogoo03Aoo`005Woo00D007ooOomo
o`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogoo
Ool00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`2;Ool00`00Oomoo`0/
Ool00`00Oomoo`0cOol000ioo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`3lOol60002Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol0RWoo00<007ooOol0;Goo00<007ooOol0<goo000FOol01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00Woo0P00ogoo1Woo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`8008Yoo`03001oogoo02moo`03001oogoo039oo`005Woo00D007ooOomoo`00
00ioo`03001oogoo00=oo`@000Eoo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomo
o`03Ool40005Ool00`00Oomoo`29Ool00`00Oomoo`0`Ool00`00Oomoo`0aOol001Ioo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0R7oo00<007ooOol0<Woo00<007ooOol0
<7oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`800?moo`Io
o`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00R7oo00<007ooOol0
<goo00<007ooOol0<7oo000GOol3000<Ool50004Ool40005Ool00`00Oomoo`3oOol6Ool3000<Ool5
0004Ool40005Ool00`00Oomoo`27Ool00`00Oomoo`0dOol00`00Oomoo`0_Ool003Qoo`03001oogoo
0?moobMoo`03001oogoo08Ioo`03001oogoo03Ioo`03001oogoo02ioo`00>7oo00<007ooOol0ogoo
9goo00<007ooOol0QGoo00<007ooOol0=goo00<007ooOol0;Woo000hOol2003oOolXOol20026Ool0
0`00Oomoo`0hOol00`00Oomoo`0]Ool003Qoo`03001oogoo0?moobMoo`03001oogoo08Aoo`03001o
ogoo03Yoo`03001oogoo02aoo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0Pgoo00<007ooOol0
>goo00<007ooOol0;7oo000hOol2003oOolXOol20024Ool00`00Oomoo`0lOol00`00Oomoo`0[Ool0
03Qoo`03001oogoo0?moobMoo`03001oogoo089oo`03001oogoo03ioo`03001oogoo02Yoo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0PWoo00<007ooOol0?Woo00<007ooOol0:Woo000hOol00`00
Oomoo`3oOolWOol00`00Oomoo`21Ool00`00Oomoo`10Ool00`00Oomoo`0YOol003Qoo`800?moobQo
o`80085oo`03001oogoo049oo`03001oogoo02Qoo`007goo0`001Woo0P001Goo10001Goo00<007oo
Ool0ogoo3Woo0`001Woo0P001Goo10001Goo00<007ooOol0P7oo00<007ooOol0@Woo00<007ooOol0
:7oo000NOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol0ogoo3Goo00D0
07ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo07moo`03001oogoo04Aoo`03001o
ogoo02Moo`005Woo1P000Woo00D007ooOomoo`00011oo`03001oogoo009oo`800?moo`Ioo`H0009o
o`05001oogooOol0000@Ool00`00Oomoo`02Ool2001oOol00`00Oomoo`16Ool00`00Oomoo`0VOol0
01ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`3oOol=Ool01@00Oomoogoo0000
47oo00<007ooOol00Woo00<007ooOol0OWoo00<007ooOol0AWoo00<007ooOol09Woo000NOol01@00
Oomoogoo000037oo10001Goo00<007ooOol0ogoo3Goo00D007ooOomoo`0000aoo`@000Eoo`03001o
ogoo07eoo`03001oogoo04Qoo`03001oogoo02Eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo
00Ioo`03001oogoo0?moo`eoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`1mOol0
0`00Oomoo`18Ool00`00Oomoo`0UOol001ioo`05001oogooOol0000<Ool00`00Oomoo`06Ool2003o
Ool>Ool01@00Oomoogoo000037oo00<007ooOol01Woo0P00OGoo00<007ooOol0BWoo00<007ooOol0
97oo000OOol3000=Ool40005Ool00`00Oomoo`3oOol>Ool3000=Ool40005Ool00`00Oomoo`1kOol0
0`00Oomoo`1;Ool00`00Oomoo`0TOol003Qoo`03001oogoo0?moobMoo`03001oogoo07]oo`03001o
ogoo04aoo`03001oogoo02=oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0NWoo00<007ooOol0
CGoo00<007ooOol08goo000hOol2003oOolXOol2001kOol00`00Oomoo`1>Ool00`00Oomoo`0ROol0
03Qoo`03001oogoo0?moobMoo`03001oogoo07Uoo`03001oogoo051oo`03001oogoo025oo`00>7oo
00<007ooOol0ogoo9goo00<007ooOol0NGoo00<007ooOol0D7oo00<007ooOol08Goo000hOol2003o
OolXOol2001iOol00`00Oomoo`1BOol00`00Oomoo`0POol003Qoo`03001oogoo0?moobMoo`03001o
ogoo07Qoo`03001oogoo059oo`03001oogoo021oo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0
Mgoo00<007ooOol0E7oo00<007ooOol07goo000hOol00`00Oomoo`3oOolWOol00`00Oomoo`1fOol0
0`00Oomoo`1EOol00`00Oomoo`0OOol003Qoo`800?moobQoo`8007Moo`03001oogoo05Ioo`03001o
ogoo01ioo`005goo0`001Woo0P0017oo1@0017oo10001Goo00<007ooOol0ogoo1Woo0`001Woo0P00
17oo1@0017oo10001Goo00<007ooOol0MGoo00<007ooOol0Egoo00<007ooOol07Woo000FOol01@00
Oomoogoo00001Goo0P001Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo0?moo`Eoo`05
001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol0MGoo00<0
07ooOol0F7oo00<007ooOol07Goo000>Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo
00<007ooOol00Woo0P00oGoo1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo
009oo`8007Eoo`03001oogoo05Uoo`03001oogoo01eoo`005Woo00D007ooOomoo`0000ioo`03001o
ogoo00Moo`03001oogoo009oo`03001oogoo0?moo`Eoo`05001oogooOol0000>Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`1dOol00`00Oomoo`1JOol00`00Oomoo`0LOol001Ioo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`3oOol5Ool01@00Oomoogoo00003goo
00<007ooOol00Woo10001Goo00<007ooOol0Lgoo00<007ooOol0Fgoo00<007ooOol077oo000FOol0
1@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo1Goo00D007oo
Oomoo`0000moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo07=oo`03001oogoo05aoo`03
001oogoo01]oo`005Woo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`06Ool2
003oOol6Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`8007=oo`03
001oogoo05eoo`03001oogoo01]oo`005goo0`003Goo0`001Goo10001Goo00<007ooOol0ogoo1Woo
0`003Goo0`001Goo10001Goo00<007ooOol0LWoo00<007ooOol0GWoo00<007ooOol06Woo000hOol0
0`00Oomoo`0OOol30006Ool20004Ool5000HOol30006Ool20006Ool3000HOol30006Ool20005Ool3
000JOol30006Ool20005Ool3000QOol50019Ool00`00Oomoo`0OOol30006Ool20004Ool5000HOol3
0006Ool20006Ool3000BOol00`00Oomoo`03Ool30006Ool20005Ool3000IOol30006Ool20005Ool3
000MOol01000Oomoogoo1@0057oo000hOol2000OOol01@00Oomoogoo00001Goo0P001Goo00@007oo
Ool001Moo`05001oogooOol00005Ool20007Ool00`00Oomoo`0FOol01@00Oomoogoo00001Goo0P00
17oo00D007ooOomoo`0001Qoo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00008Woo00<0
07ooOol0BGoo0P007goo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000GOol01@00Oomoogoo
00001Goo0P001goo00<007ooOol04Goo00<007ooOol00Woo00D007ooOomoo`0000Eoo`8000Aoo`05
001oogooOol0000GOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0001eoo`03001oogoo
009oo`03001oogoo01Aoo`00>7oo00<007ooOol07Woo00D007ooOomoo`0000eoo`03001oogoo01Mo
o`05001oogooOol0000;Ool5000GOol01@00Oomoogoo00002goo00D007ooOomoo`0001Qoo`05001o
ogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol07Woo00D007ooOomo
o`0000eoo`03001oogoo01Moo`05001oogooOol0000;Ool5000AOol00`00Oomoo`03Ool01@00Oomo
ogoo00002goo00D007ooOomoo`0001Moo`05001oogooOol0000;Ool01@00Oomoogoo00007Goo00<0
07ooOol00Woo00<007ooOol057oo000hOol00`00Oomoo`0NOol01@00Oomoogoo00003Woo00<007oo
Ool05Woo00D007ooOomoo`0000]oo`04001oogoo000HOol01@00Oomoogoo00002goo00D007ooOomo
o`0001Qoo`05001oogooOol0000;Ool01@00Oomoogoo00008Woo00<007ooOol0BGoo00<007ooOol0
7Woo00D007ooOomoo`0000ioo`03001oogoo01Ioo`05001oogooOol0000;Ool01000Oomoo`004Woo
00<007ooOol00goo00D007ooOomoo`0000]oo`05001oogooOol0000GOol01@00Oomoogoo00002goo
00D007ooOomoo`0001ioo`05001oogooOol0000FOol003Qoo`03001oogoo01ioo`05001oogooOol0
000?Ool00`00Oomoo`0EOol01@00Oomoogoo000037oo00<007oo000067oo00D007ooOomoo`0000]o
o`@001Uoo`05001oogooOol0000<Ool3000SOol00`00Oomoo`19Ool00`00Oomoo`0NOol01@00Oomo
ogoo00003goo00<007ooOol05Goo00D007ooOomoo`0000aoo`03001oo`00015oo`03001oogoo00Ao
o`05001oogooOol0000;Ool4000HOol01@00Oomoogoo000037oo0`007goo00D007ooOomoo`0001Io
o`00>7oo0P007goo00D007ooOomoo`0000moo`03001oogoo01Eoo`05001oogooOol0000<Ool00`00
Ool0000HOol01@00Oomoogoo00002goo00<007ooOol06Woo00D007ooOomoo`0000]oo`05001oogoo
Ool0000ROol00`00Oomoo`19Ool2000OOol01@00Oomoogoo00003goo00<007ooOol05Goo00D007oo
Oomoo`0000aoo`03001oo`00015oo`03001oogoo00Aoo`05001oogooOol0000;Ool00`00Oomoo`0I
Ool01@00Oomoogoo00002goo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`03001oogoo
01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007ooOomoo`0000eoo`8001Qoo`05
001oogooOol0000<Ool00`00Oomoo`0IOol01@00Oomoogoo00002goo00D007ooOomoo`00029oo`03
001oogoo04Uoo`03001oogoo01ioo`05001oogooOol0000;Ool01@00Oomoogoo00005goo00D007oo
Oomoo`0000eoo`80015oo`03001oogoo00Aoo`05001oogooOol0000<Ool00`00Oomoo`0HOol01@00
Oomoogoo00002goo00D007ooOomoo`0001moo`04001oogoo000FOol003Qoo`03001oogoo01moo`<0
00eoo`<001Uoo`<000moo`03001oogoo01Moo`<000ioo`<001Uoo`<000eoo`<0025oo`<004]oo`03
001oogoo01moo`<000eoo`<001Uoo`<000moo`03001oogoo00ioo`03001oogoo00Ioo`<000ioo`<0
01Qoo`<000eoo`<0025oo`<001Ioo`00>7oo00<007ooOol0ogoo9goo00<007ooOol0KWoo00<007oo
Ool0IWoo00<007ooOol05Woo000hOol2003oOolXOol2001^Ool00`00Oomoo`1XOol00`00Oomoo`0E
Ool003Qoo`03001oogoo0?moobMoo`03001oogoo06eoo`03001oogoo06Qoo`03001oogoo01Eoo`00
>7oo00<007ooOol0ogoo9goo00<007ooOol0K7oo00<007ooOol0JWoo00<007ooOol057oo000bOooY
0010OooY000@Ool003Qoo`8000Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Moo`8004]oo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo01Aoo`00>7oo00<007oo0000:Goo00<007ooOol0:Goo00<0
07ooOol0:Goo00<007ooOol0:Woo00<007ooOol09goo00<007oo0000Bgoo0P00:Woo00<007ooOol0
:Goo00<007ooOol04goo00<007ooOol04goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0
57oo000hOol01000Oomoo`00eWoo00<007ooOol0C7oo0P00Jgoo00<007ooOol0Pgoo000hOol20002
Ool00`00Oomoo`3BOol00`00Oomoo`1=Ool3001ZOol00`00Oomoo`23Ool003Qoo`03001oogoo009o
o`03001oogoo0=1oo`03001oogoo04ioo`03001oo`0006Uoo`03001oogoo08Aoo`00>7oo00<007oo
Ool00goo00<007ooOol0cWoo00<007ooOol0Cgoo00@007ooOol006Qoo`03001oogoo08Aoo`00>7oo
0P001Goo00<007ooOol0c7oo00<007ooOol0D7oo0P0000=oo`00Ool0IWoo00<007ooOol0QGoo000h
Ool00`00Oomoo`05Ool00`00Oomoo`3:Ool00`00Oomoo`1AOol01@00Oomoogoo0000IWoo00<007oo
Ool0QGoo000hOol00`00Oomoo`06Ool00`00Oomoo`38Ool00`00Oomoo`1BOol01@00Oomoogoo0000
IGoo00<007ooOol0QWoo000hOol00`00Oomoo`07Ool00`00Oomoo`36Ool00`00Oomoo`1COol00`00
Oomoo`02Ool00`00Oomoo`1ROol00`00Oomoo`26Ool003Qoo`8000Uoo`03001oogoo0<Aoo`03001o
ogoo05Aoo`8000=oo`03001oogoo065oo`03001oogoo08Moo`00>7oo00<007ooOol02Goo00<007oo
Ool0`Woo00<007ooOol0EGoo00<007ooOol00goo00<007ooOol0H7oo00<007ooOol0Qgoo000hOol0
0`00Oomoo`0:Ool00`00Oomoo`30Ool00`00Oomoo`1FOol00`00Oomoo`03Ool00`00Oomoo`1OOol0
0`00Oomoo`28Ool003Qoo`03001oogoo00]oo`03001oogoo0;ioo`03001oogoo05Moo`03001oogoo
00Aoo`03001oogoo05ioo`03001oogoo08Qoo`00>7oo0P003Goo00<007ooOol0_7oo00<007ooOol0
F7oo0P001Goo00<007ooOol0GGoo00<007ooOol0RGoo000GOol30006Ool20004Ool50004Ool40005
Ool00`00Oomoo`0=Ool00`00Oomoo`2jOol00`00Oomoo`0hOol30006Ool20004Ool50004Ool40005
Ool00`00Oomoo`05Ool00`00Oomoo`1LOol00`00Oomoo`29Ool001Ioo`05001oogooOol00005Ool2
0005Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol0^7oo00<007oo
Ool0>7oo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`1KOol00`00Oomoo`2:Ool001Ioo`05001oogooOol0000=Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool2000@Ool00`00Oomoo`2fOol00`00Oomoo`0iOol01@00Oomoogoo00003Goo
00<007ooOol027oo00<007ooOol00Woo0P001goo00<007ooOol0FWoo00<007ooOol0RWoo000FOol0
1@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol047oo00<007ooOol0
/goo0P00?7oo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo05Uoo`03001oogoo08]oo`005Woo00D007ooOomoo`0000moo`03001oogoo009oo`@0
00Eoo`03001oogoo015oo`03001oogoo0;5oo`03001oogoo03aoo`05001oogooOol0000?Ool00`00
Oomoo`02Ool40005Ool00`00Oomoo`07Ool00`00Oomoo`1HOol00`00Oomoo`2;Ool001Ioo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`2_Ool0
0`00Oomoo`0mOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
1goo00<007ooOol0Egoo00<007ooOol0S7oo000FOol01@00Oomoogoo00002goo00D007ooOomoo`00
00Aoo`03001oogoo00Ioo`8001Aoo`03001oogoo0:eoo`03001oogoo03ioo`05001oogooOol0000;
Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P002Goo00<007ooOol0EWoo00<007ooOol0S7oo
000GOol3000=Ool30005Ool40005Ool00`00Oomoo`0DOol00`00Oomoo`2[Ool00`00Oomoo`10Ool3
000=Ool30005Ool40005Ool00`00Oomoo`08Ool00`00Oomoo`1EOol00`00Oomoo`2=Ool003Qoo`03
001oogoo01Eoo`03001oogoo0:Uoo`03001oogoo069oo`03001oogoo00Uoo`03001oogoo05=oo`03
001oogoo08ioo`00>7oo0P005goo00<007ooOol0Ygoo00<007ooOol0Hgoo0P002Woo00<007ooOol0
Dgoo00<007ooOol0SWoo000hOol00`00Oomoo`0GOol00`00Oomoo`2UOol00`00Oomoo`1TOol00`00
Oomoo`0:Ool00`00Oomoo`1AOol00`00Oomoo`2?Ool003Qoo`03001oogoo01Qoo`03001oogoo0:=o
o`03001oogoo06Eoo`03001oogoo00Yoo`03001oogoo055oo`03001oogoo08moo`00>7oo00<007oo
Ool06Goo0P00XWoo00<007ooOol0IWoo00<007ooOol02goo00<007ooOol0Cgoo00<007ooOol0T7oo
000hOol2000LOol00`00Oomoo`2NOol00`00Oomoo`1WOol2000<Ool00`00Oomoo`1?Ool00`00Oomo
o`2@Ool003Qoo`03001oogoo01aoo`03001oogoo09aoo`03001oogoo06Qoo`03001oogoo00]oo`03
001oogoo04ioo`03001oogoo095oo`00>7oo00<007ooOol07Goo00<007ooOol0VWoo00<007ooOol0
JGoo00<007ooOol037oo00<007ooOol0CGoo00<007ooOol0TGoo000hOol2000OOol00`00Oomoo`2H
Ool00`00Oomoo`1ZOol2000=Ool00`00Oomoo`1<Ool00`00Oomoo`2BOol003Qoo`03001oogoo01mo
o`03001oogoo09Ioo`03001oogoo06]oo`03001oogoo00eoo`03001oogoo04Yoo`03001oogoo09=o
o`007goo0`001Woo0P001Goo10001Goo00<007ooOol087oo00<007ooOol0U7oo00<007ooOol0Dgoo
0`001Woo0P001Goo10001Goo00<007ooOol03Goo00<007ooOol0BWoo00<007ooOol0Tgoo000NOol0
1@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol0TWoo00<0
07ooOol0Dgoo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo009oo`03001oogoo00ioo`03001o
ogoo04Qoo`03001oogoo09Aoo`007Woo00D007ooOomoo`00011oo`03001oogoo009oo`8002=oo`80
091oo`8005Ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool2000?Ool00`00Oomoo`18Ool00`00
Oomoo`2DOol001ioo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomo
o`2<Ool00`00Oomoo`1FOol01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol03goo00<0
07ooOol0AWoo00<007ooOol0UGoo000NOol01@00Oomoogoo000037oo10001Goo00<007ooOol09Goo
00<007ooOol0RWoo00<007ooOol0Egoo00D007ooOomoo`0000aoo`@000Eoo`03001oogoo00moo`03
001oogoo04Ioo`03001oogoo09Eoo`007Woo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001o
ogoo02Ioo`03001oogoo08Qoo`03001oogoo05Qoo`05001oogooOol0000<Ool00`00Oomoo`06Ool0
0`00Oomoo`0@Ool00`00Oomoo`14Ool00`00Oomoo`2FOol001ioo`05001oogooOol0000<Ool00`00
Oomoo`06Ool2000XOol00`00Oomoo`26Ool00`00Oomoo`1IOol01@00Oomoogoo000037oo00<007oo
Ool01Woo0P004Woo00<007ooOol0@Woo00<007ooOol0Ugoo000OOol3000=Ool40005Ool00`00Oomo
o`0XOol00`00Oomoo`24Ool00`00Oomoo`1KOol3000=Ool40005Ool00`00Oomoo`0BOol00`00Oomo
o`11Ool00`00Oomoo`2GOol003Qoo`03001oogoo02Uoo`03001oogoo089oo`03001oogoo07Eoo`03
001oogoo019oo`03001oogoo041oo`03001oogoo09Qoo`00>7oo0P00:goo00<007ooOol0P7oo00<0
07ooOol0MWoo0P0057oo00<007ooOol0?Woo00<007ooOol0VGoo000hOol00`00Oomoo`0[Ool2001n
Ool2001iOol00`00Oomoo`0DOol00`00Oomoo`0mOol00`00Oomoo`2IOol003Qoo`03001oogoo02eo
o`03001oogoo07Yoo`03001oogoo07Uoo`03001oogoo01Aoo`03001oogoo03aoo`03001oogoo09Yo
o`00>7oo00<007ooOol0;Woo00<007ooOol0N7oo00<007ooOol0NWoo00<007ooOol05Goo00<007oo
Ool0>goo00<007ooOol0VWoo000hOol2000`Ool2001fOol2001mOol2000GOol00`00Oomoo`0iOol0
0`00Oomoo`2KOol003Qoo`03001oogoo035oo`03001oogoo079oo`03001oogoo07eoo`03001oogoo
01Moo`03001oogoo03Moo`03001oogoo09aoo`00>7oo00<007ooOol0<Woo00<007ooOol0L7oo00<0
07ooOol0OWoo00<007ooOol05goo00<007ooOol0=goo00<007ooOol0W7oo000hOol2000dOol00`00
Oomoo`1^Ool00`00Oomoo`1oOol2000IOol00`00Oomoo`0eOol00`00Oomoo`2MOol001Moo`<000Io
o`8000Ioo`03001oogoo00Aoo`@000Eoo`03001oogoo03Aoo`8006aoo`80065oo`<000Ioo`8000Io
o`03001oogoo00Aoo`@000Eoo`03001oogoo01Uoo`03001oogoo03=oo`03001oogoo09ioo`005Woo
00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo03Ioo`80
06Qoo`80069oo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00
Oomoo`0IOol00`00Oomoo`0cOol00`00Oomoo`2NOol001Ioo`05001oogooOol0000>Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`0hOol00`00Oomoo`1TOol00`00Oomoo`1ROol01@00Oomo
ogoo00003Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol06Woo00<007ooOol0<Goo00<0
07ooOol0Wgoo000FOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00Woo0P00>Woo
0P00HWoo0P00IGoo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo009oo`8001aoo`03
001oogoo02moo`03001oogoo0:1oo`005Woo00D007ooOomoo`0000ioo`03001oogoo00=oo`@000Eo
o`03001oogoo03]oo`8005ioo`8006Moo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool0
0`00Oomoo`0LOol00`00Oomoo`0]Ool00`00Oomoo`2QOol001Ioo`05001oogooOol0000?Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0mOol00`00Oomoo`1JOol00`00Oomoo`1WOol01@00
Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol077oo00<007ooOol0;7oo
00<007ooOol0XWoo000FOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Io
o`03001oogoo03ioo`8005Qoo`8006Yoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<0
07ooOol01Woo00<007ooOol07Goo00<007ooOol0:Woo00<007ooOol0Xgoo000GOol3000<Ool50004
Ool40005Ool20011Ool2001EOol00`00Oomoo`1[Ool3000<Ool50004Ool40005Ool2000OOol00`00
Oomoo`0YOol00`00Oomoo`2SOol003Qoo`03001oogoo049oo`80055oo`8008moo`03001oogoo01io
o`03001oogoo02Qoo`03001oogoo0:Aoo`00>7oo00<007ooOol0A7oo00<007ooOol0C7oo0P00TGoo
00<007ooOol07goo00<007ooOol09Woo00<007ooOol0YGoo000hOol20016Ool2001;Ool00`00Oomo
o`2AOol2000QOol00`00Oomoo`0TOol00`00Oomoo`2VOol003Qoo`03001oogoo04Moo`8004Moo`80
09Aoo`03001oogoo025oo`8002=oo`03001oogoo0:Moo`00>7oo00<007ooOol0BGoo0P00@Woo0`00
UWoo00<007ooOol08goo00<007ooOol07goo00<007ooOol0Z7oo000hOol00`00Oomoo`1;Ool3000m
Ool2002IOol00`00Oomoo`0TOol00`00Oomoo`0MOol00`00Oomoo`2YOol003Qoo`8004moo`8003Qo
o`<009]oo`8002Ioo`03001oogoo01]oo`03001oogoo0:Yoo`00>7oo00<007ooOol0D7oo0P00=7oo
0P00WWoo00<007ooOol09Woo0P006Goo0P00[Goo000hOol00`00Oomoo`1BOol2000_Ool3002POol0
0`00Oomoo`0XOol00`00Oomoo`0DOol2002_Ool003Qoo`8005Eoo`8002Yoo`<00:=oo`8002Yoo`80
01=oo`03001oogoo0:moo`00;goo1@0017oo00<007ooOol0EWoo0`008goo1000WGoo1@0017oo00<0
07ooOol0:goo00<007ooOol03Woo0P00/Woo000aOol00`00Oomoo`04Ool00`00Oomoo`1IOol4000K
Ool4002SOol00`00Oomoo`04Ool00`00Oomoo`0/Ool00`00Oomoo`0;Ool2002dOol0035oo`03001o
ogoo00Aoo`03001oogoo05eoo`P000ioo`D00:Moo`03001oogoo00Aoo`03001oogoo02eoo`@000Mo
o`800;Ioo`00<Goo00<007ooOol017oo0P00IWoo3P00[7oo00<007ooOol017oo0P00<Woo1`00^7oo
000aOol00`00Oomoo`3oOolWOol00`00Oomoo`3gOol0035oo`03001oogoo0?moobMoo`03001oogoo
0?Moo`00<Goo00<007ooOol0ogoo9goo00<007ooOol0mgoo000_Ool3003oOolWOol3003iOol00?mo
oomooeIoo`00ogooogooEWoo002EOol3000017oo0000000067oo1@00ogoo1Goo0`0000Aoo`000000
01Moo`D007Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03001oogoo0?moo`Ioo`05001oogoo
Ool00009Ool6000:Ool01000Oomoo`00M7oo002FOol01@00Oomoogoo00006goo00<007ooOol0ogoo
1Woo00D007ooOomoo`0001Yoo`03001oogoo07Aoo`00UWoo00D007ooOomoo`0000Uoo`H000aoo`03
001oogoo0?moo`Ioo`05001oogooOol00009Ool6000<Ool00`00Oomoo`1cOol009Ioo`05001oogoo
Ool0000KOol00`00Oomoo`3oOol6Ool01@00Oomoogoo000077oo00<007ooOol0LWoo002EOol5000L
Ool00`00Oomoo`3oOol5Ool5000MOol00`00Oomoo`1bOol00;Ioo`03001oogoo0?moob=oo`05001o
ogooOol0001dOol00;Aoo`<00?moobIoo`<007Eoo`00ogooogooEWoo003oOoooOomFOol00?mooomo
oeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol0
0?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00\
\>"],
  ImageRangeCache->{{{0, 595.625}, {367.75, 0}} -> {0, 0, 0, 0}, {{14.4375, \
284.312}, {358.938, 192.188}} -> {0, -1, 0, 0}, {{311.25, 581.125}, {358.938, \
192.188}} -> {-1, -1, 0, 0}, {{14.4375, 284.312}, {175.5, 8.75}} -> {0, -3, \
0, 0}, {{311.25, 581.125}, {175.5, 8.75}} -> {-1, -3, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "This figure displays three key features of the normal modes: \n(1) Each \
single-mode oscillation forms a standing wave on the string, with a set of \
stationary nodes. At these nodes the amplitude of the oscillation is zero for \
all time. \n(2) The number of nodes equals ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)]],
  " (excluding the end points). Consequently, modes with large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " exhibit rapid spatial variation. \n(3) One can plainly see (in the \
animation accompanying the electronic version of the text) that the modes \
with higher ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " oscillate more rapidly in time.  For instance, the ",
  Cell[BoxData[
      \(TraditionalForm\`n = 4\)]],
  " standing wave completes four oscillations for every single cycle \
completed by the ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)]],
  " mode. This follows from the expression for the frequencies of the modes, \
Eq. ",
  ButtonBox["(3.1.19)",
    ButtonData:>"(3.1.19)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(3.1.19)",
    ButtonData:>"(3.1.19)",
    ButtonStyle->"Hyperlink"],
  " also shows that as the length of the string is reduced, the mode \
frequencies increase. This simple property of the wave equation has many \
applications. For instance, it is the principle behind the operation of \
stringed musical instruments. In order to increase the frequency of the \
sound, the musician reduces the effective length of the string, by placing \
some object (such as his or her finger) against the string, allowing only \
part of the string to vibrate when plucked. "
}], "Text"],

Cell[TextData[{
  "\tWhen the string is plucked, the lowest, ",
  StyleBox["fundamental",
    FontSlant->"Italic"],
  " frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1\)]],
  " usually predominates in the response, and is primarily responsible for \
the pitch of the sound. However, the higher harmonics are also produced at \
multiples of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1\)]],
  ", and the superposition of these harmonics  are, in part, responsible for  \
the characteristic sound of the instrument. (The manner in which these string \
vibrations couple to sound waves in the surrounding air is also of great \
importance to the sound produced. This coupling is a primary consideration in \
the design of the instrument.)"
}], "Text"],

Cell[TextData[{
  "\tHowever, musicians often play tricks to alter the sound  a string makes. \
For instance, musicians can create a high-frequency sound on an open string \
by placing their finger lightly at the location of the first node of the ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2\)]],
  " harmonic, in the middle of the string. This allows the ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2\)]],
  " mode to vibrate when the string is plucked, but suppresses the \
fundamental mode, creating a sound one octave above than the fundamental \
(i.e. at twice the frequency). "
}], "Text"],

Cell[TextData[{
  "\tAlso, the frequency of the vibration increases as the propagation speed \
",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " increases. Thus, for very thin, high-tension strings such as the high ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " string on a guitar, ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is large and the fundamental frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1\)]],
  " of the string is correspondingly high. Thicker, more massive strings at \
lower tension have  lower fundamental frequencies. By varying the tension in \
the string, a musician can change the frequency and tune his or her \
instrument. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Matching the Initial Conditions", "Subsubsection"],

Cell[TextData[{
  "\tOur final task is to determine the values of ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n\)]],
  " in the general solution. These constants are found by matching the \
general solution to the initial conditions, Eqs. ",
  ButtonBox["(3.1.9)",
    ButtonData:>"(3.1.9)",
    ButtonStyle->"Hyperlink"],
  ". At ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", Eqs. ",
  ButtonBox["(3.1.20)",
    ButtonData:>"(3.1.20)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.1.9)",
    ButtonData:>"(3.1.9)",
    ButtonStyle->"Hyperlink"],
  "  imply"
}], "Text",
  CellTags->"i:13"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          0) = \(\[Sum]\+\(n = 1\)\%\[Infinity] A\_n\ \(sin(
                n\ \[Pi]\ x/L)\) = \(y\_o\)(x)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.21)"],

Cell[TextData[{
  "This is a Fourier sine series, and we can therefore determine the Fourier \
coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " using Eq. ",
  ButtonBox["(2.2.11)",
    ButtonData:>{"Chapter2.nb", "(2.2.11)"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`A\_n = \(2\/L\) \(\[Integral]\_0\%L\(\( y\_o\)(
                x)\)\ sin\ \((n\ \[Pi]\ x/L)\) \[DifferentialD]x\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.22)"],

Cell[TextData[{
  "Similarly, the constants ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n\)]],
  " are determined by the second initial condition, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]y/\[PartialD]t\)\( | \_\(t = 
                0\)\)\) = \(v\_o\)(x)\)]],
  ". Using Eq. ",
  ButtonBox["(3.1.20)",
    ButtonData:>"(3.1.20)",
    ButtonStyle->"Hyperlink"],
  " to evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]y/\[PartialD]t\)\( | \_\(t = 
              0\)\)\)\)]],
  ", we find"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Sum]\+\(n = 1\)\%\[Infinity]\( 
              B\_n\) \[Omega]\_n\ \ \(sin(n\ \[Pi]\ x/L)\) = \(\(\(v\_o\)(
          x)\)\(\ \)\(.\)\)\)]]], "NumberedEquation",
  CellTags->"(3.1.23)"],

Cell[TextData[{
  "This equation is also a Fourier sine series, so ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n\)]],
  " is given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(B\_n\) \[Omega]\_n = \(2\/L\) \
\(\[Integral]\_0\%L\(\( v\_o\)(
                x)\)\ sin\ \((n\ \[Pi]\ x/L)\) \[DifferentialD]x\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.24)"],

Cell[TextData[{
  "Equations ",
  ButtonBox["(3.1.19)",
    ButtonData:>"(3.1.19)",
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["(3.1.20)",
    ButtonData:>"(3.1.20)",
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["(3.1.22)",
    ButtonData:>"(3.1.22)",
    ButtonStyle->"Hyperlink"],
  ", and ",
  ButtonBox["(3.1.24)",
    ButtonData:>"(3.1.24)",
    ButtonStyle->"Hyperlink"],
  " are the solution to the wave equation on a uniform string with fixed \
ends,  for given initial conditions.  We see that the solution matches the \
boundary conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`y(0, t) = \(y(L, t) = 0\)\)]],
  " because each Fourier mode ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ \((n\ \[Pi]\ x/L)\)\)]],
  " satisfies these conditions.  The solution matches the initial conditions \
because the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n\)]],
  " are chosen specifically to do so, via Eqs. ",
  ButtonBox["(3.1.22)",
    ButtonData:>"(3.1.22)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.1.24)",
    ButtonData:>"(3.1.24)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Section",
  CellTags->"c:10"],

Cell[CellGroupData[{

Cell["1. Example 1: Plucked String", "Subsubsection"],

Cell["\<\
\tWe can use our general solution to determine the evolution of any \
given initial condition.  For instance,  consider the initial condition\
\>", \
"Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[{
      FormBox[
        RowBox[{\(\(y\_o\) \((x)\)\), "=", " ", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->16], 
              StyleBox[GridBox[{
                    {\(\(a\ x\)\(,\)\), \(\(\ \)\(\(0 < x < L/2\)\(,\)\)\)},
                    {\(\(a(L - x)\)\(,\)\), \(\(L/2 < x < L\)\(,\)\)}
                    }],
                ShowAutoStyles->True]}],
            (#&)]}], TraditionalForm], "\[IndentingNewLine]", 
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(\(v\_o\)(x)\  = \ 0\),
              "TraditionalForm"], "."}]}], TraditionalForm]}]]
}], "Text"],

Cell[TextData[{
  "This initial condition, plotted in Cell ",
  ButtonBox["3.3",
    ButtonData:>"Cell 3.3",
    ButtonStyle->"Hyperlink"],
  ", is formed by pulling sideways on the center of the string, and then \
letting it go. To find the subsequent motion, all we need do is determine the \
constant ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n\)]],
  " in the general solution. Equation ",
  ButtonBox["(3.1.24)",
    ButtonData:>"(3.1.24)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n = 0\)]],
  ", and Eq. ",
  ButtonBox["(3.1.20)",
    ButtonData:>"(3.1.20)",
    ButtonStyle->"Hyperlink"],
  " implies that "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`A\_n = \(2\/L\ \(\[Integral]\_0\%L\(\( y\_o\)(x)\) 
                sin\ \((n\ \[Pi]\ x/
                      L)\) \[DifferentialD]x\) = \(2\/L\) \
{\[Integral]\_0\%\(L/2\)a\ x\ sin\ \((n\ \[Pi]\ x/
                          L)\) \[DifferentialD]x + \[Integral]\_\(L/2\)\%L\( 
                      a(L - \ x)\)\ sin\ \((n\ \[Pi]\ x/
                          L)\) \[DifferentialD]x}\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "These integrals can be evaluated analytically using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", and the result is as follows:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A[n_]\  = 
      FullSimplify[
        2/L \((\ Integrate[\ a\ x\ Sin[n\ Pi\ x/L], {x, 0, L/2}]\  + 
              Integrate[\ a \((L - \ x)\)\ Sin[n\ Pi\ x/L], {x, L/2, L}])\), 
        n \[Element] Integers]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.2"],

Cell[BoxData[
    \(\(4\ a\ L\ Sin[\(n\ \[Pi]\)\/2]\)\/\(n\^2\ \[Pi]\^2\)\)], "Output"]
}, Open  ]],

Cell["Thus, this perturbation evolves according to", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          t)\  = \ \[Sum]\+\(n = 1\)\%\[Infinity] A\_n\ cos\ \((n\ \[Pi]\ c\ \
t/L)\)\ sin\ \((n\ \[Pi]\ x/L)\)\)]],
  ", "
}], "NumberedEquation",
  CellTags->"(3.1.25)"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " given in Cell ",
  ButtonBox["3.2",
    ButtonData:>"Cell 3.2",
    ButtonStyle->"Hyperlink"],
  ". This sum is a Fourier sine series in space and a cosine series in time. \
The time dependence implies that ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  " is periodic in time with fundamental period ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi]/\[Omega]\_1 = \ 2  L/c\)]],
  ".  By cutting off the sum at some large but finite value ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ", we can observe the evolution of the string via an animation. We do so in \
Cell ",
  ButtonBox["3.3",
    ButtonData:>"Cell 3.3",
    ButtonStyle->"Hyperlink"],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`L = \(c = \(a = 1\)\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(M = 30; \ L = \(c = \(a = 1\)\);\), "\n", 
    \(\(y[x_, t_]\  = \ 
        Sum[A[n]\ Cos[n\ Pi\ c\ t/L]\ Sin[n\ Pi\ x/L], {n, 1, 
            M}];\)\), "\n", 
    \(\(Table[
        Plot[y[x, t], {x, 0, L}, PlotRange \[Rule] {{0, 1}, {\(-1\), 1}}, 
          PlotLabel \[Rule] "\<t = \>" <> ToString[t], 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}], {t, 0, 
          1.9,  .1}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.3"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .32151 L
.08481 .3353 L
.12636 .34802 L
.16632 .36041 L
.20885 .37362 L
.2498 .38611 L
.29331 .39971 L
.33524 .41265 L
.37557 .42493 L
.41848 .43857 L
.4598 .45099 L
.47044 .45484 L
.48055 .45824 L
.48494 .45945 L
.48962 .46047 L
.49232 .4609 L
.49476 .46119 L
.49594 .46129 L
.49722 .46137 L
.49842 .46142 L
.49953 .46144 L
.50071 .46143 L
.50197 .4614 L
.50317 .46135 L
.50425 .46127 L
.50553 .46116 L
.50692 .461 L
.50944 .46063 L
.51208 .46013 L
.51488 .45949 L
.51991 .4581 L
.54183 .45042 L
.58147 .43859 L
.62368 .42515 L
.6643 .4128 L
.7075 .39947 L
.74911 .38645 L
.78912 .37426 L
.83171 .36101 L
.87271 .34831 L
.91628 .33496 L
.95826 .32186 L
.99865 .30944 L
1 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000W
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@ooooooooool04?ooool002Wooooo00?o0000oooo
ooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000002Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool2
o`0002kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo01;ooooo
000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03
o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo02Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooooooo
o`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Dooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000oooo
ooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool002Woooooool0000/
o`0000_ooooo00CogMgMo`000?l@413oc<c<1Oooool002Wooooo00?o0000ooooooooool00ol00009
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Wooooo1?l0000;ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Y
ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1?l00003
ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Oooool002Wooooo00?o0000
ooooooooool01_ooool3o`000?oooooo5?ooool4o`0001;ooooo0_l00002ooooo`;o00001?ooool0
02Wooooo00?o0000ooooooooool02Oooool3o`000?oooooo3_ooool3o`00023ooooo000Yooooo`;o
00003Oooool3o`000?oooooo2?ooool3o`0002?ooooo000Yooooo`03o`000?oooooooooo00oooooo
0ol0003oooooo`;ooooo0ol0000Vooooo`00:Oooool00ol0003oooooooooo`0Booooo`?o0000nooo
ool3o`0002Wooooo000Yooooo`03o`000?oooooooooo01Gooooo1?l0003cooooo`Co0000;?ooool0
02Wooooo00?o0000ooooooooool06Oooool3o`000>gooooo0ol0000`ooooo`00:Oooool2o`0001go
oooo0ol0003Wooooo`?o0000<oooool002Wooooo00?o0000ooooooooool07oooool3o`000>7ooooo
0ol0000fooooo`00:Oooool00ol0003oooooooooo`0Rooooo`?o0000f_ooool4o`0003Wooooo000Y
ooooo`03o`000?oooooooooo02Gooooo0ol0003Dooooo`?o0000?Oooool002Wooooo0_l0000Yoooo
o`?o0000c_ooool3o`00043ooooo000Yooooo`03o`000?oooooooooo02_ooooo0ol00038ooooo`?o
0000@oooool002Wooooo00?o0000ooooooooool0;_ooool3o`000<;ooooo0ol00016ooooo`00:Ooo
ool00ol0003oooooooooo`0aooooo`?o0000_?ooool3o`0004Wooooo000Yooooo`03o`000?oooooo
oooo03Cooooo0ol0002fooooo`?o0000C?ooool002Wooooo0_l0000hooooo`?o0000/?ooool3o`00
04oooooo000Yooooo`03o`000?oooooooooo03[ooooo1?l0002Xooooo`Co0000D_ooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo03kooooo1?l0002Pooooo`Co0000E_ooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`12ooooo`Co0000V?ooool4
o`0005[ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo00?ooooo0ol00016ooooo`Co0000T?ooool4o`0005kooooo0006oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0B_ooool3o`0008[ooooo0ol0001Rooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0COooool3o`0008Cooooo0ol0001Uooooo`001_ooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo053ooooo0ol0001nooooo`?o0000J?ooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo05?ooooo1?l0001gooooo`?o0000Joooool000Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Ko
oooo0_l0001Hooooo`?o0000LOooool3o`0006kooooo000Yooooo`03o`000?oooooooooo05[ooooo
0ol0001[ooooo`?o0000LOooool002Wooooo00?o0000ooooooooool0GOooool3o`0006Gooooo0ol0
001dooooo`00:Oooool00ol0003oooooooooo`1Pooooo`Co0000GOooool4o`0007Oooooo000Yoooo
o`03o`000?oooooooooo06Cooooo0ol0001Gooooo`?o0000Noooool002Wooooo0_l0001Xooooo`?o
0000DOooool3o`0007kooooo000Yooooo`03o`000?oooooooooo06[ooooo0ol0001;ooooo`?o0000
POooool002Wooooo00?o0000ooooooooool0KOooool3o`0004Gooooo0ol00024ooooo`00:Oooool0
0ol0003oooooooooo`1`ooooo`?o0000?oooool3o`0008Oooooo000Yooooo`;o0000M?ooool3o`00
03Wooooo0ol0002:ooooo`00:Oooool00ol0003oooooooooo`1fooooo`?o0000<oooool3o`0008go
oooo000Yooooo`03o`000?oooooooooo07Wooooo0ol0000]ooooo`?o0000T?ooool002Wooooo00?o
0000ooooooooool0O?ooool3o`0002Oooooo0ol0002Cooooo`00:Oooool00ol0003oooooooooo`1o
ooooo`?o00008Oooool3o`0009Kooooo000Yooooo`;o0000Poooool3o`0001_ooooo0ol0002Ioooo
o`00:Oooool00ol0003oooooooooo`25ooooo`Co00005?ooool3o`0009cooooo000>ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo08Wooooo0ol0000>ooooo`?o0000Woooool000kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
08cooooo0ol00006ooooo`Go0000X_ooool000kooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0002?ooooo`Ko0000Yoooool000kooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolm
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:gooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0VOooool002Gooooo0ol000000ol@413oooooooooo`22ooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Ioooo
o`009oooool00ol@413o^[Zjooooo`23ooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooo
oooooooooa0@402Iooooo`009oooool00onHV9So<S8booooo`23ooooo`03o`000?oooooooooo00_o
oooo1_l00009ooooo`05o`000?ooooooooooooooool00000VOooool002Oooooo00?ogMgMo`000?nj
^[X0Poooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000VOooool002Oo
oooo00?oEEEEogMgMom4A4@0POooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooo
oooooooooa0@402Iooooo`009_ooool01OoMgMgo410@oooooolQ8B7ogMgM08;ooooo00?o0000oooo
ooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg09Wooooo000Vooooo`05ofIVI_n7QhOooooo
oiRHV?mEEED0P_ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0VOoo
ool002Gooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`3ooooooccooooo000Uoooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0oooooolkooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .3216 L
.08481 .33515 L
.12636 .34811 L
.16632 .36041 L
.20885 .37348 L
.2498 .38632 L
.29331 .39959 L
.33524 .41253 L
.37557 .42545 L
.38633 .42869 L
.39159 .43 L
.3964 .43098 L
.40147 .43178 L
.40426 .43213 L
.40691 .43239 L
.40978 .43261 L
.41244 .43275 L
.41398 .43282 L
.41537 .43286 L
.41614 .43288 L
.41697 .4329 L
.41775 .43291 L
.41848 .43292 L
.41979 .43293 L
.42098 .43293 L
.42225 .43293 L
.42298 .43292 L
.42365 .43292 L
.42476 .43291 L
.42598 .43289 L
.42846 .43285 L
.43942 .43263 L
.44209 .43259 L
.44491 .43255 L
.44638 .43254 L
.448 .43252 L
.44871 .43252 L
.44946 .43252 L
.45083 .43251 L
.45221 .43251 L
.45299 .43251 L
.45371 .43251 L
.45504 .43251 L
.4557 .43251 L
.45644 .43251 L
.45771 .43251 L
.45907 .43252 L
.46154 .43253 L
.47217 .43261 L
Mistroke
.47509 .43262 L
.47819 .43264 L
.48112 .43265 L
.48377 .43266 L
.4851 .43266 L
.4865 .43266 L
.48769 .43266 L
.489 .43266 L
.49041 .43266 L
.4912 .43266 L
.49192 .43266 L
.49259 .43266 L
.49332 .43266 L
.49465 .43266 L
.49587 .43267 L
.49723 .43267 L
.49791 .43267 L
.49864 .43267 L
.49996 .43267 L
.50121 .43267 L
.50253 .43267 L
.50365 .43267 L
.50488 .43266 L
.50555 .43266 L
.50627 .43266 L
.50755 .43266 L
.50893 .43266 L
.50971 .43266 L
.51045 .43266 L
.51177 .43266 L
.51298 .43266 L
.51437 .43266 L
.51569 .43266 L
.51813 .43265 L
.52039 .43264 L
.52287 .43263 L
.52551 .43262 L
.5361 .43255 L
.539 .43253 L
.54058 .43252 L
.54206 .43252 L
.54332 .43251 L
.54466 .43251 L
.54543 .43251 L
.54616 .43251 L
.54752 .43251 L
.5487 .43251 L
.54999 .43251 L
.55135 .43252 L
.55262 .43253 L
Mistroke
.55488 .43255 L
.55732 .43258 L
.56287 .43267 L
.56794 .43278 L
.57265 .43287 L
.57393 .43289 L
.57531 .43291 L
.5766 .43292 L
.57778 .43293 L
.57898 .43293 L
.58009 .43293 L
.58131 .43292 L
.58259 .4329 L
.58371 .43288 L
.58475 .43286 L
.58713 .43277 L
.58845 .43271 L
.58986 .43263 L
.59239 .43245 L
.59511 .43219 L
.59811 .43184 L
.60348 .431 L
.60851 .42997 L
.61789 .4275 L
.628 .42426 L
.67122 .41066 L
.71284 .39763 L
.75288 .38549 L
.79549 .37217 L
.83651 .35952 L
.8801 .34614 L
.9221 .33302 L
.96251 .32063 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000W
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@ooooooooool04?ooool002Wooooo00?o0000oooo
ooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000002Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool2
o`0002kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo01;ooooo
000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03
o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo02Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooooooo
o`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Dooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000oooo
ooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool002Woooooool0000/
o`0000_ooooo00CogMgMo`000?l@413oc<c<1Oooool002Wooooo00?o0000ooooooooool00ol00009
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo0ol000000ooooooo0000ooooo`0:ooooo`04onk^k_lQ8B7o
410@onk^kPGooooo000Yooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Gooooo0ol00004ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Ooo
ool002Wooooo00?o0000ooooooooool01_ooool3o`000?oooooo5Oooool3o`0001;ooooo0_l00002
ooooo`;o00001?ooool002Wooooo00?o0000ooooooooool02Oooool3o`000?oooooo3oooool3o`00
01oooooo000Yooooo`;o00003Oooool3o`000?oooooo2Oooool3o`0002;ooooo000Yooooo`03o`00
0?oooooooooo00oooooo0ol0003oooooo`?ooooo0ol0000Uooooo`00:Oooool00ol0003ooooooooo
o`0Booooo`?o0000o?ooool3o`0002Sooooo000Yooooo`03o`000?oooooooooo01Gooooo1?l0003d
ooooo`Co0000:oooool002Wooooo00?o0000ooooooooool06Oooool3o`000>gooooo1?l0000_oooo
o`00:Oooool2o`0001gooooo0ol0003Vooooo`Co0000<oooool002Wooooo00?o0000ooooooooool0
7oooool3o`000=oooooo1?l0000gooooo`00:Oooool00ol0003oooooooooo`0Rooooo`?o0000fOoo
ool3o`0003_ooooo000Yooooo`03o`000?oooooooooo02Gooooo0ol0003Cooooo`?o0000?_ooool0
02Wooooo0_l0000Yooooo`?o0000cOooool3o`00047ooooo000Yooooo`03o`000?oooooooooo02_o
oooo0ol00037ooooo`?o0000A?ooool002Wooooo00?o0000ooooooooool0;_ooool3o`000<7ooooo
0ol00017ooooo`00:Oooool00ol0003oooooooooo`0aooooo`?o0000^oooool3o`0004[ooooo000Y
ooooo`03o`000?oooooooooo03Cooooo0ol0002eooooo`?o0000COooool002Wooooo0_l0000hoooo
o`?o0000[_ooool4o`00053ooooo000Yooooo`03o`000?oooooooooo03[ooooo1?l0002Wooooo`?o
0000E?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03kooooo1?l0002Poooo
o`?o0000Eoooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`12
ooooo`Co0000VOooool3o`0005[ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol00016ooooo`Co0000T_ooool3
o`0005gooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0B_ooool3o`0008cooooo0ol0001P
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0COooool3o`0008Kooooo0ol0
001Sooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo0ol00020ooooo`?o0000I_oo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05?ooooo1?l0001iooooo`?o0000
JOooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Kooooo0_l0001Hooooo`?o0000Loooool3o`0006cooooo000Yooooo`03o`00
0?oooooooooo05[ooooo0ol0001]ooooo`?o0000Koooool002Wooooo00?o0000ooooooooool0GOoo
ool3o`0006Oooooo0ol0001booooo`00:Oooool00ol0003oooooooooo`1Pooooo`Co0000Goooool4
o`0007Gooooo000Yooooo`03o`000?oooooooooo06Cooooo0ol0001Iooooo`?o0000NOooool002Wo
oooo0_l0001Xooooo`?o0000Doooool3o`0007cooooo000Yooooo`03o`000?oooooooooo06[ooooo
0ol0001=ooooo`?o0000Ooooool002Wooooo00?o0000ooooooooool0KOooool3o`0004Oooooo0ol0
0022ooooo`00:Oooool00ol0003oooooooooo`1`ooooo`?o0000?_ooool6o`0008Gooooo000Yoooo
o`;o0000M?oooolno`0008_ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolm
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:Gooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`2>ooooo`00
9Oooool3o`000003oa0@4?oooooooooo07[ooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
093ooooo000Wooooo`03oa0@4?nj^[[ooooo07_ooooo00?o0000ooooooooool06_ooool01Ol@413o
oooooooooooooooo410@00kooooo00?o0000ooooooooool0T?ooool002Oooooo00?oV9RHoc8b<_oo
ool0Noooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo0000
00kooooo00?o0000ooooooooool0T?ooool002Oooooo00?ogMgMo`000?nj^[X0Noooool00ol0003o
ooooooooo`0Jooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`2@oooo
o`009oooool00omEEEGoMgMgodA4A01iooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413o
oooooooooooooooo410@00kooooo00?o0000ooooooooool0T?ooool002Kooooo00GogMgMoa0@4?oo
oooo8B4QomgMg@1jooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo093ooooo000Vooooo`05ofIVI_n7QhOooooooiRHV?mEEED0N_ooool0
0ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`00
002Booooo`009Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo0?oooooo??ooool0
02Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`3ooooooc_ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .3215 L
.08481 .33531 L
.12636 .34801 L
.16632 .3604 L
.20885 .37368 L
.2498 .38599 L
.27066 .3929 L
.28166 .39644 L
.28768 .39813 L
.29331 .39946 L
.29831 .40041 L
.30369 .40117 L
.30675 .40149 L
.30965 .40172 L
.31226 .40187 L
.31374 .40193 L
.31511 .40198 L
.31638 .40201 L
.31774 .40203 L
.31903 .40205 L
.32022 .40205 L
.3213 .40205 L
.32247 .40205 L
.32371 .40203 L
.32485 .40202 L
.32748 .40198 L
.32987 .40193 L
.33524 .4018 L
.34029 .40169 L
.34284 .40164 L
.3443 .40162 L
.34565 .40161 L
.34679 .4016 L
.34804 .40159 L
.34929 .40158 L
.35062 .40157 L
.35178 .40157 L
.35303 .40157 L
.35421 .40157 L
.35528 .40158 L
.35664 .40158 L
.35808 .40159 L
.36066 .40161 L
.36649 .40168 L
.37202 .40174 L
.37465 .40176 L
.37708 .40178 L
.37951 .40179 L
.38079 .4018 L
Mistroke
.38216 .4018 L
.38346 .40181 L
.38469 .40181 L
.38579 .40181 L
.38699 .40181 L
.38827 .4018 L
.389 .4018 L
.38968 .4018 L
.39253 .40179 L
.39763 .40176 L
.4021 .40173 L
.40685 .4017 L
.40932 .40169 L
.41064 .40169 L
.41205 .40168 L
.41335 .40168 L
.41453 .40168 L
.41567 .40167 L
.41686 .40167 L
.41818 .40167 L
.41891 .40167 L
.41958 .40167 L
.42089 .40167 L
.42212 .40168 L
.42355 .40168 L
.42488 .40168 L
.42786 .40169 L
.43282 .40171 L
.43827 .40172 L
.44063 .40173 L
.44317 .40174 L
.44556 .40174 L
.44662 .40174 L
.44775 .40175 L
.44903 .40175 L
.45021 .40175 L
.45148 .40175 L
.45221 .40175 L
.45289 .40175 L
.45411 .40175 L
.45524 .40175 L
.45647 .40175 L
.45777 .40175 L
.46853 .40173 L
.47382 .40172 L
.47615 .40172 L
.47871 .40172 L
.481 .40172 L
.48314 .40171 L
.4854 .40171 L
Mistroke
.48668 .40171 L
.48784 .40171 L
.4891 .40171 L
.49027 .40171 L
.49155 .40171 L
.49292 .40171 L
.49422 .40171 L
.49545 .40171 L
.49656 .40171 L
.49775 .40171 L
.49903 .40171 L
.50023 .40171 L
.50155 .40171 L
.50229 .40171 L
.50296 .40171 L
.50431 .40171 L
.50508 .40171 L
.50578 .40171 L
.50708 .40171 L
.50846 .40171 L
.50962 .40171 L
.51088 .40171 L
.51206 .40171 L
.51315 .40171 L
.51435 .40171 L
.51566 .40171 L
.51831 .40171 L
.5198 .40172 L
.5212 .40172 L
.52382 .40172 L
.52971 .40173 L
.53475 .40174 L
.53743 .40174 L
.5403 .40174 L
.54172 .40175 L
.54306 .40175 L
.54427 .40175 L
.54558 .40175 L
.54682 .40175 L
.54815 .40175 L
.54939 .40175 L
.55052 .40175 L
.5512 .40175 L
.55192 .40175 L
.5532 .40174 L
.55609 .40174 L
.55859 .40173 L
.56133 .40173 L
.56611 .40171 L
.57129 .40169 L
Mistroke
.57367 .40168 L
.57497 .40168 L
.57619 .40168 L
.57731 .40168 L
.57834 .40167 L
.57948 .40167 L
.58071 .40167 L
.58208 .40167 L
.58335 .40167 L
.58408 .40167 L
.58474 .40168 L
.58623 .40168 L
.58752 .40168 L
.58892 .40169 L
.59147 .4017 L
.59656 .40172 L
.60125 .40175 L
.60392 .40177 L
.60678 .40178 L
.60817 .40179 L
.60948 .4018 L
.61067 .4018 L
.61194 .4018 L
.61328 .40181 L
.61452 .40181 L
.61585 .40181 L
.61661 .40181 L
.61732 .4018 L
.61805 .4018 L
.61881 .4018 L
.62017 .40179 L
.62163 .40179 L
.62323 .40178 L
.62878 .40173 L
.63402 .40167 L
.63878 .40162 L
.64138 .4016 L
.64265 .40159 L
.64382 .40158 L
.64508 .40158 L
.64643 .40157 L
.64713 .40157 L
.6479 .40157 L
.64863 .40157 L
.64931 .40157 L
.65059 .40158 L
.65176 .40158 L
.6531 .40159 L
.65437 .40161 L
.65723 .40165 L
Mistroke
.65987 .40169 L
.66581 .40182 L
.67076 .40194 L
.67348 .40199 L
.67482 .40202 L
.67605 .40203 L
.67722 .40204 L
.67845 .40205 L
.67969 .40205 L
.68105 .40204 L
.68218 .40203 L
.6834 .40201 L
.68455 .40198 L
.68561 .40195 L
.68687 .40191 L
.68823 .40184 L
.69066 .4017 L
.69356 .40146 L
.69619 .40119 L
.70191 .40037 L
.70731 .39933 L
.71754 .39668 L
.72836 .39323 L
.74775 .38676 L
.78757 .37481 L
.82997 .36151 L
.87077 .34892 L
.91416 .33563 L
.95595 .32256 L
.99615 .31024 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000W
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@ooooooooool04?ooool002Wooooo00?o0000oooo
ooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000002Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool2
o`0002kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo01;ooooo
000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03
o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo02Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooooooo
o`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Dooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000oooo
ooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool002Woooooool0000/
o`0000_ooooo00CogMgMo`000?l@413oc<c<1Oooool002Wooooo00?o0000ooooooooool00ol00009
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo0ol000000ooooooo0000ooooo`0:ooooo`04onk^k_lQ8B7o
410@onk^kPGooooo000Yooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Cooooo1?l00004ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Ooo
ool002Wooooo00?o0000ooooooooool01_ooool3o`000?oooooo4oooool4o`0001?ooooo0_l00002
ooooo`;o00001?ooool002Wooooo00?o0000ooooooooool02Oooool3o`000?oooooo3Oooool3o`00
027ooooo000Yooooo`;o00003Oooool3o`000?oooooo1oooool3o`0002Cooooo000Yooooo`03o`00
0?oooooooooo00oooooo0ol0003oooooo`7ooooo0ol0000Wooooo`00:Oooool00ol0003ooooooooo
o`0Booooo`?o0000n_ooool3o`0002[ooooo000Yooooo`03o`000?oooooooooo01Gooooo1?l0003b
ooooo`Co0000;Oooool002Wooooo00?o0000ooooooooool06Oooool3o`000>cooooo0ol0000aoooo
o`00:Oooool2o`0001gooooo0ol0003Vooooo`?o0000=?ooool002Wooooo00?o0000ooooooooool0
7oooool3o`000>3ooooo0ol0000gooooo`00:Oooool00ol0003oooooooooo`0Rooooo`?o0000f_oo
ool3o`0003[ooooo000Yooooo`03o`000?oooooooooo02Gooooo0ol0003Dooooo`?o0000?Oooool0
02Wooooo0_l0000Yooooo`?o0000c_ooool3o`00043ooooo000Yooooo`03o`000?oooooooooo02_o
oooo0ol00038ooooo`?o0000@oooool002Wooooo00?o0000ooooooooool0;_ooool3o`000<7ooooo
1?l00016ooooo`00:Oooool00ol0003oooooooooo`0aooooo`?o0000^oooool3o`0004[ooooo000Y
ooooo`03o`000?oooooooooo03Cooooo0ol0002eooooo`?o0000COooool002Wooooo0_l0000hoooo
o`?o0000[oooool3o`00053ooooo000Yooooo`03o`000?oooooooooo03[ooooo1?l0002Xooooo`?o
0000Doooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03kooooo1?l0002Qoooo
o`?o0000E_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`12
ooooo`Co0000V_ooool3o`0005Wooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol00016ooooo`Co0000Toooool3
o`0005cooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0B_ooool3o`0008cooooo1?l0001O
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0COooool3o`0008Gooooo1?l0
001Sooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo0_l00021ooooo`;o0000Iooo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05;ooooo1?l0001iooooo`Co0000
JOooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Kooooo0_l0001GooooogWo0000KOooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000O
ooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Gooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol0002Aooooo`009Oooool3o`000003oa0@4?oooooooooo07[ooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0TOooool002Oooooo00?o410@okZj
^_ooool0Noooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP2Booooo`009oooool00onHV9So<S8booooo`1kooooo`03o`000?oooooooooo
00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP2A
ooooo`009oooool00ooMgMgo0000okZj^P1kooooo`03o`000?oooooooooo01[ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo093ooooo000Wooooo`03oeEEEOmgMgOoA4A4
07Wooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`2?ooooo`009_ooool01OoMgMgo410@oooooolQ8B7ogMgM07[ooooo00?o0000
ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@402Aooooo`009_ooool01OmVIVKoQhN7oooooonHV9SoEEEE07[ooooo00?o0000ooooooooool0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Aoooo
o`009Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo0?oooooo??ooool002Gooooo
00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`3ooooooc_ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .32163 L
.08481 .33509 L
.12636 .34815 L
.16632 .36052 L
.17777 .36434 L
.18859 .36746 L
.19331 .36856 L
.19831 .36951 L
.20092 .36991 L
.20379 .37028 L
.20621 .37054 L
.20885 .37076 L
.21027 .37086 L
.21158 .37093 L
.21294 .371 L
.21417 .37105 L
.2153 .37108 L
.21653 .37111 L
.21782 .37113 L
.21904 .37114 L
.22036 .37115 L
.22111 .37115 L
.22181 .37115 L
.22255 .37114 L
.22323 .37114 L
.22474 .37112 L
.22603 .3711 L
.22744 .37108 L
.22999 .37102 L
.23491 .3709 L
.24021 .37079 L
.24264 .37074 L
.24521 .37071 L
.2474 .37069 L
.24864 .37068 L
.2498 .37067 L
.25108 .37067 L
.2523 .37067 L
.25339 .37067 L
.25457 .37067 L
.25586 .37067 L
.25722 .37068 L
.25966 .3707 L
.26529 .37076 L
.27056 .37082 L
.27562 .37087 L
.27708 .37088 L
.27846 .37089 L
.27983 .3709 L
Mistroke
.28106 .3709 L
.28173 .37091 L
.28245 .37091 L
.28321 .37091 L
.28393 .37091 L
.28532 .37091 L
.28659 .37091 L
.28731 .37091 L
.28799 .37091 L
.28952 .3709 L
.29102 .3709 L
.29262 .37089 L
.30333 .37082 L
.30626 .3708 L
.30937 .37078 L
.31203 .37077 L
.31354 .37077 L
.31428 .37077 L
.31496 .37076 L
.3162 .37076 L
.31755 .37076 L
.31887 .37076 L
.31961 .37076 L
.32027 .37076 L
.32148 .37076 L
.32278 .37077 L
.32514 .37077 L
.32791 .37078 L
.33085 .3708 L
.3361 .37082 L
.33854 .37083 L
.3412 .37084 L
.34354 .37085 L
.34604 .37086 L
.34741 .37086 L
.34819 .37086 L
.34893 .37086 L
.35022 .37086 L
.35094 .37086 L
.35161 .37086 L
.35279 .37086 L
.35409 .37086 L
.35544 .37086 L
.35669 .37086 L
.3592 .37085 L
.36157 .37084 L
.36599 .37083 L
.37113 .37081 L
.37594 .3708 L
.37827 .3708 L
Mistroke
.37959 .3708 L
.38079 .3708 L
.3821 .37079 L
.38284 .37079 L
.38353 .37079 L
.38479 .37079 L
.38613 .37079 L
.38686 .37079 L
.38753 .37079 L
.38904 .3708 L
.39038 .3708 L
.39179 .3708 L
.39693 .37081 L
.40213 .37082 L
.40706 .37083 L
.4092 .37083 L
.41148 .37083 L
.41267 .37084 L
.41398 .37084 L
.41517 .37084 L
.41629 .37084 L
.41751 .37084 L
.41879 .37084 L
.41989 .37084 L
.42109 .37084 L
.42238 .37084 L
.42376 .37084 L
.42625 .37083 L
.43693 .37082 L
.43942 .37082 L
.44212 .37082 L
.44467 .37081 L
.44588 .37081 L
.44702 .37081 L
.44813 .37081 L
.44914 .37081 L
.45026 .37081 L
.45147 .37081 L
.45263 .37081 L
.45389 .37081 L
.45508 .37081 L
.45618 .37081 L
.46582 .37082 L
.47108 .37082 L
.47598 .37082 L
.47854 .37082 L
.48129 .37082 L
.48286 .37082 L
.48434 .37082 L
.48567 .37082 L
Mistroke
.48712 .37082 L
.48834 .37082 L
.4897 .37082 L
.49038 .37082 L
.49111 .37082 L
.49243 .37082 L
.49375 .37082 L
.495 .37082 L
.49612 .37082 L
.49735 .37082 L
.49808 .37082 L
.49887 .37082 L
.49962 .37082 L
.50031 .37082 L
.50162 .37082 L
.503 .37082 L
.50372 .37082 L
.50449 .37082 L
.50588 .37082 L
.50672 .37082 L
.50753 .37082 L
.50825 .37082 L
.50903 .37082 L
.51033 .37082 L
.51107 .37082 L
.51177 .37082 L
.51316 .37082 L
.51467 .37082 L
.516 .37082 L
.51739 .37082 L
.51989 .37082 L
.52242 .37082 L
.52513 .37082 L
.53001 .37082 L
.53577 .37081 L
.5383 .37081 L
.54108 .37081 L
.54238 .37081 L
.54378 .37081 L
.5451 .37081 L
.5463 .37081 L
.54766 .37081 L
.54843 .37081 L
.54914 .37081 L
.55044 .37081 L
.55183 .37081 L
.55335 .37081 L
.55498 .37081 L
.55795 .37082 L
.56349 .37082 L
Mistroke
.56885 .37083 L
.57178 .37083 L
.57451 .37083 L
.57684 .37084 L
.57815 .37084 L
.57934 .37084 L
.58065 .37084 L
.58138 .37084 L
.58207 .37084 L
.58332 .37084 L
.58464 .37084 L
.58584 .37084 L
.58715 .37084 L
.58979 .37083 L
.59223 .37083 L
.5945 .37083 L
.60007 .37081 L
.60512 .3708 L
.60741 .3708 L
.60862 .3708 L
.6099 .3708 L
.61102 .3708 L
.61225 .37079 L
.61336 .37079 L
.61441 .37079 L
.61569 .37079 L
.61691 .37079 L
.618 .37079 L
.61919 .3708 L
.62048 .3708 L
.62185 .3708 L
.62432 .3708 L
.63414 .37083 L
.6393 .37085 L
.64189 .37085 L
.64338 .37086 L
.64473 .37086 L
.64602 .37086 L
.64723 .37086 L
.64852 .37086 L
.64924 .37086 L
.64991 .37086 L
.65102 .37086 L
.65225 .37086 L
.65353 .37086 L
.65473 .37085 L
.65704 .37085 L
.65916 .37084 L
.66391 .37082 L
.66888 .3708 L
Mistroke
.67357 .37078 L
.67616 .37077 L
.67762 .37077 L
.67896 .37076 L
.6801 .37076 L
.68134 .37076 L
.68264 .37076 L
.68385 .37076 L
.68456 .37076 L
.68532 .37076 L
.6867 .37077 L
.68805 .37077 L
.6893 .37078 L
.69213 .37079 L
.69514 .37081 L
.70061 .37085 L
.70562 .37088 L
.7081 .37089 L
.71041 .3709 L
.71158 .37091 L
.71282 .37091 L
.7142 .37091 L
.71546 .37091 L
.71682 .37091 L
.71808 .37091 L
.71946 .3709 L
.72092 .3709 L
.72337 .37088 L
.72607 .37086 L
.73591 .37075 L
.73826 .37072 L
.74077 .3707 L
.74198 .37069 L
.74313 .37068 L
.74417 .37067 L
.74526 .37067 L
.74654 .37067 L
.74772 .37067 L
.74898 .37067 L
.75037 .37067 L
.7511 .37067 L
.75176 .37068 L
.75325 .37069 L
.75463 .3707 L
.75594 .37072 L
.76061 .3708 L
.76569 .37092 L
.77122 .37105 L
.77401 .3711 L
.7756 .37113 L
Mistroke
.77631 .37113 L
.77709 .37114 L
.77845 .37115 L
.77974 .37115 L
.781 .37114 L
.78217 .37113 L
.78355 .37111 L
.78481 .37108 L
.78626 .37103 L
.78763 .37097 L
.79015 .37083 L
.79251 .37066 L
.79509 .37041 L
.79787 .37008 L
.80353 .36919 L
.80869 .36812 L
.82808 .36242 L
.86989 .34924 L
.91011 .33669 L
.95291 .32369 L
.99411 .31077 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000W
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@ooooooooool04?ooool002Wooooo00?o0000oooo
ooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000002Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool2
o`0002kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo01;ooooo
000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03
o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo02Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooooooo
o`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Dooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000oooo
ooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool002Woooooool0000/
o`0000_ooooo00CogMgMo`000?l@413oc<c<1Oooool002Wooooo00?o0000ooooooooool00ol00009
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000ooooo`0:ooooo`04onk^k_lQ8B7o
410@onk^kPGooooo000Yooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Kooooo0ol00003ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Ooo
ool002Wooooo00?o0000ooooooooool01_ooool3o`000?oooooo5_ooool3o`00017ooooo0_l00002
ooooo`;o00001?ooool002Wooooo00?o0000ooooooooool02Oooool3o`000?oooooo4?ooool3o`00
01kooooo000Yooooo`;o00003Oooool3o`000?oooooo2Oooool4o`00027ooooo000Yooooo`03o`00
0?oooooooooo00oooooo0ol0003oooooo`?ooooo0ol0000Uooooo`00:Oooool00ol0003ooooooooo
o`0Booooo`?o0000o?ooool3o`0002Sooooo000Yooooo`03o`000?oooooooooo01Gooooo1?l0003e
ooooo`?o0000:oooool002Wooooo00?o0000ooooooooool06Oooool3o`000>kooooo1?l0000^oooo
o`00:Oooool2o`0001gooooo0ol0003Wooooo`Co0000<_ooool002Wooooo00?o0000ooooooooool0
7oooool3o`000>3ooooo1?l0000fooooo`00:Oooool00ol0003oooooooooo`0Rooooo`?o0000fOoo
ool4o`0003[ooooo000Yooooo`03o`000?oooooooooo02Gooooo0ol0003Cooooo`?o0000?_ooool0
02Wooooo0_l0000Yooooo`?o0000cOooool3o`00047ooooo000Yooooo`03o`000?oooooooooo02_o
oooo0ol00037ooooo`?o0000A?ooool002Wooooo00?o0000ooooooooool0;_ooool3o`000<7ooooo
0ol00017ooooo`00:Oooool00ol0003oooooooooo`0aooooo`Co0000^_ooool3o`0004[ooooo000Y
ooooo`03o`000?oooooooooo03Gooooo1?l0002booooo`Co0000COooool002Wooooo0_l0000joooo
ok;o0000DOooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`00
0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oo
oooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Oooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo
000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool0
0ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo
00000?ooooooAoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Go
V9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00GoV9RHoa0@4?l0003o<S8bolc<c02Aooooo`009Oooool3o`000003oa0@4?oooooooooo07[o
oooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S80TOooool002Oooooo00?o410@
okZj^_ooool0Noooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`2?ooooo`009oooool00onHV9So<S8booooo`1kooooo`03o`000?oooooo
oooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@oooo
o`2@ooooo`009oooool00ooMgMgo0000okZj^P1kooooo`03o`000?oooooooooo01[ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj097ooooo000Wooooo`03oeEEEOmgMgOo
A4A407Wooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`2@ooooo`009_ooool01OoMgMgo410@oooooolQ8B7ogMgM07[ooooo00?o
0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo
^[Zjo`00002Aooooo`009_ooool01OmVIVKoQhN7oooooonHV9SoEEEE07[ooooo00?o0000oooooooo
ool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2A
ooooo`009Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo0?oooooo??ooool002Go
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`3ooooooc_ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .32137 L
.06168 .32803 L
.07286 .33184 L
.08481 .33558 L
.0906 .33707 L
.09607 .33822 L
.10099 .33902 L
.10352 .33935 L
.10632 .33964 L
.10893 .33985 L
.11138 .34001 L
.1127 .34007 L
.11396 .34012 L
.11541 .34016 L
.11674 .34019 L
.11789 .34021 L
.11912 .34022 L
.12029 .34023 L
.12134 .34023 L
.12258 .34023 L
.12392 .34021 L
.12519 .3402 L
.12636 .34018 L
.1359 .33998 L
.13841 .33993 L
.14115 .33987 L
.14356 .33984 L
.14613 .33981 L
.14757 .33979 L
.14834 .33979 L
.14917 .33979 L
.14993 .33978 L
.15063 .33978 L
.15199 .33978 L
.15324 .33978 L
.1546 .33978 L
.15529 .33978 L
.15602 .33979 L
.15735 .33979 L
.16017 .33981 L
.16283 .33984 L
.16782 .33989 L
.17309 .33994 L
.17567 .33996 L
.17803 .33998 L
.17922 .33999 L
.18051 .33999 L
.18188 .34 L
.18317 .34 L
Mistroke
.18392 .34 L
.1846 .34 L
.18538 .34 L
.18611 .34 L
.18742 .34 L
.18816 .34 L
.18884 .33999 L
.19116 .33999 L
.19333 .33998 L
.19826 .33995 L
.20343 .33992 L
.20821 .33989 L
.21077 .33988 L
.21208 .33988 L
.21348 .33987 L
.21422 .33987 L
.21489 .33987 L
.21621 .33987 L
.21691 .33987 L
.21767 .33987 L
.21847 .33987 L
.21921 .33987 L
.22057 .33987 L
.22185 .33987 L
.223 .33987 L
.22425 .33988 L
.22962 .33989 L
.23449 .33991 L
.2397 .33993 L
.24223 .33994 L
.24463 .33995 L
.24567 .33995 L
.24678 .33995 L
.24799 .33995 L
.24912 .33995 L
.25029 .33995 L
.25156 .33995 L
.25276 .33995 L
.25385 .33995 L
.25507 .33995 L
.2564 .33995 L
.25908 .33995 L
.26475 .33993 L
.27003 .33992 L
.27291 .33991 L
.27563 .3399 L
.27807 .3399 L
.27944 .3399 L
.28071 .33989 L
.28208 .33989 L
Mistroke
.28336 .33989 L
.28409 .33989 L
.28476 .33989 L
.28553 .33989 L
.28626 .33989 L
.28697 .33989 L
.28772 .33989 L
.28907 .3399 L
.29068 .3399 L
.29214 .3399 L
.30198 .33992 L
.30457 .33992 L
.30735 .33993 L
.30992 .33993 L
.31236 .33994 L
.31373 .33994 L
.31449 .33994 L
.31521 .33994 L
.31646 .33994 L
.3178 .33994 L
.3185 .33994 L
.31926 .33994 L
.32063 .33994 L
.32142 .33994 L
.32226 .33994 L
.32375 .33993 L
.32635 .33993 L
.32876 .33993 L
.33423 .33992 L
.33954 .33991 L
.34233 .33991 L
.34386 .33991 L
.34529 .33991 L
.34654 .33991 L
.34788 .33991 L
.34864 .33991 L
.34936 .33991 L
.35072 .33991 L
.35196 .33991 L
.35312 .33991 L
.35438 .33991 L
.35573 .33991 L
.35827 .33991 L
.36101 .33991 L
.36597 .33992 L
.37045 .33992 L
.37525 .33992 L
.37664 .33993 L
.37796 .33993 L
.37925 .33993 L
Mistroke
.38043 .33993 L
.38156 .33993 L
.38275 .33993 L
.38395 .33993 L
.38527 .33993 L
.386 .33993 L
.38669 .33993 L
.38799 .33993 L
.38872 .33993 L
.3894 .33993 L
.39093 .33993 L
.39624 .33992 L
.40171 .33992 L
.40459 .33992 L
.40764 .33992 L
.4103 .33991 L
.41172 .33991 L
.41323 .33991 L
.41394 .33991 L
.41462 .33991 L
.41589 .33991 L
.41708 .33991 L
.41838 .33991 L
.41971 .33991 L
.42095 .33991 L
.42232 .33991 L
.4238 .33991 L
.42681 .33991 L
.42956 .33992 L
.43451 .33992 L
.43992 .33992 L
.4423 .33992 L
.44484 .33992 L
.44608 .33992 L
.44725 .33992 L
.44829 .33992 L
.44943 .33992 L
.45064 .33992 L
.45196 .33992 L
.45335 .33992 L
.45464 .33992 L
.45585 .33992 L
.45696 .33992 L
.45945 .33992 L
.46994 .33992 L
.4727 .33992 L
.47569 .33992 L
.47827 .33992 L
.4811 .33992 L
.48378 .33992 L
Mistroke
.48523 .33992 L
.48659 .33992 L
.48787 .33992 L
.48903 .33992 L
.49037 .33992 L
.49164 .33992 L
.49279 .33992 L
.49402 .33992 L
.49506 .33992 L
.49622 .33992 L
.49745 .33992 L
.49878 .33992 L
.50004 .33992 L
.50119 .33992 L
.50242 .33992 L
.50353 .33992 L
.50482 .33992 L
.50603 .33992 L
.50716 .33992 L
.50819 .33992 L
.50933 .33992 L
.51054 .33992 L
.51175 .33992 L
.51305 .33992 L
.51428 .33992 L
.5154 .33992 L
.51815 .33992 L
.52075 .33992 L
.52323 .33992 L
.52587 .33992 L
.5306 .33992 L
.5362 .33992 L
.53865 .33992 L
.54133 .33992 L
.54253 .33992 L
.54381 .33992 L
.54501 .33992 L
.54611 .33992 L
.54735 .33992 L
.5487 .33992 L
.54997 .33992 L
.55115 .33992 L
.55241 .33992 L
.55359 .33992 L
.55629 .33992 L
.55892 .33992 L
.56174 .33992 L
.56656 .33992 L
.57169 .33991 L
.57418 .33991 L
Mistroke
.57541 .33991 L
.57653 .33991 L
.57754 .33991 L
.57864 .33991 L
.57975 .33991 L
.58092 .33991 L
.58231 .33991 L
.58357 .33991 L
.58427 .33991 L
.58503 .33991 L
.58641 .33991 L
.5877 .33991 L
.58907 .33991 L
.59154 .33991 L
.59704 .33992 L
.60312 .33992 L
.60567 .33992 L
.60836 .33993 L
.60976 .33993 L
.6113 .33993 L
.61198 .33993 L
.6127 .33993 L
.614 .33993 L
.61532 .33993 L
.61607 .33993 L
.61675 .33993 L
.61802 .33993 L
.61935 .33993 L
.62055 .33993 L
.62167 .33993 L
.62422 .33993 L
.63515 .33991 L
.63776 .33991 L
.64053 .33991 L
.64188 .33991 L
.64315 .33991 L
.64431 .33991 L
.64552 .33991 L
.64664 .33991 L
.64786 .33991 L
.64897 .3399 L
.65 .33991 L
.65122 .33991 L
.65234 .33991 L
.65362 .33991 L
.65484 .33991 L
.65737 .33991 L
.6597 .33991 L
.66499 .33992 L
.66987 .33993 L
Mistroke
.67257 .33993 L
.67513 .33993 L
.6775 .33994 L
.67884 .33994 L
.68009 .33994 L
.68124 .33994 L
.68229 .33994 L
.68349 .33994 L
.68463 .33994 L
.68589 .33994 L
.68726 .33994 L
.6887 .33993 L
.69005 .33993 L
.69503 .33992 L
.70042 .33991 L
.70326 .33991 L
.70628 .3399 L
.70899 .3399 L
.71053 .3399 L
.71123 .3399 L
.71197 .33989 L
.7133 .33989 L
.71451 .33989 L
.71581 .33989 L
.71655 .33989 L
.71724 .33989 L
.71859 .33989 L
.71987 .3399 L
.72102 .3399 L
.72226 .3399 L
.72506 .3399 L
.72763 .33991 L
.73702 .33994 L
.73972 .33994 L
.74229 .33995 L
.74341 .33995 L
.7446 .33995 L
.7459 .33995 L
.74711 .33995 L
.74843 .33995 L
.74917 .33995 L
.74986 .33995 L
.75112 .33995 L
.75244 .33995 L
.75364 .33995 L
.75475 .33995 L
.75728 .33994 L
.76187 .33993 L
.76679 .33991 L
.76958 .3399 L
Mistroke
.77262 .33988 L
.77529 .33988 L
.77675 .33987 L
.77813 .33987 L
.77936 .33987 L
.78068 .33987 L
.7814 .33987 L
.78215 .33987 L
.7835 .33987 L
.78472 .33987 L
.78587 .33987 L
.78712 .33987 L
.78846 .33988 L
.79118 .33989 L
.79406 .3399 L
.79923 .33993 L
.80526 .33997 L
.8082 .33998 L
.80949 .33999 L
.81089 .33999 L
.81219 .34 L
.81339 .34 L
.81453 .34 L
.81576 .34 L
.81643 .34 L
.81717 .34 L
.8185 .33999 L
.81979 .33999 L
.82098 .33999 L
.82355 .33997 L
.82637 .33995 L
.83206 .33989 L
.83759 .33983 L
.84031 .33981 L
.8415 .3398 L
.84282 .33979 L
.84391 .33979 L
.84509 .33978 L
.84634 .33978 L
.84751 .33978 L
.84887 .33978 L
.85017 .33978 L
.85133 .33979 L
.85261 .3398 L
.8541 .33981 L
.8555 .33982 L
.85812 .33986 L
.864 .33998 L
.86905 .34009 L
.87172 .34015 L
Mistroke
.87319 .34017 L
.87459 .3402 L
.87592 .34021 L
.87667 .34022 L
.87736 .34022 L
.87859 .34023 L
.87989 .34023 L
.8811 .34022 L
.88224 .34021 L
.88349 .34019 L
.88484 .34016 L
.88615 .34011 L
.88759 .34006 L
.89049 .33989 L
.89317 .33969 L
.89567 .33944 L
.90058 .33879 L
.90504 .33801 L
.91506 .33562 L
.95704 .32207 L
.99742 .30987 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000W
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@ooooooooool04?ooool002Wooooo00?o0000oooo
ooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000002Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool2
o`0002kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo01;ooooo
000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03
o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo02Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooooooo
o`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Dooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000oooo
ooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool002Woooooool0000/
o`0000_ooooo00CogMgMo`000?l@413oc<c<1Oooool002Wooooo00?o0000ooooooooool00ol00009
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Wooooo1?l0000;ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Y
ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1?l00003
ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Oooool002Wooooo00?o0000
ooooooooool01_ooool3o`000?oooooo5?ooool4o`0001;ooooo0_l00002ooooo`;o00001?ooool0
02Wooooo00?o0000ooooooooool02Oooool3o`000?oooooo3Oooool4o`00023ooooo000Yooooo`;o
00003Oooool3o`000?oooooo1oooool3o`0002Cooooo000Yooooo`03o`000?oooooooooo00oooooo
0ol0003oooooo`7ooooo0ol0000Wooooo`00:Oooool00ol0003oooooooooo`0Booooo`?o0000n_oo
ool3o`0002[ooooo000Yooooo`03o`000?oooooooooo01Gooooo0ol0003dooooo`?o0000;Oooool0
02Wooooo00?o0000ooooooooool06?ooool5o`000>[ooooo1Ol0000`ooooo`00:Oooool2o`0001go
ooook?l0000dooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolm
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:Gooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`2?ooooo`00
9Oooool3o`000003oa0@4?oooooooooo07[ooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
093ooooo000Wooooo`03oa0@4?nj^[[ooooo07_ooooo00?o0000ooooooooool06_ooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol0002Aooooo`009oooool00onHV9So<S8booooo`1kooooo`03
o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000002oooool01?m4
A4CogMgMooooool0002Booooo`009oooool00ooMgMgo0000okZj^P1kooooo`03o`000?oooooooooo
01[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0009;ooooo000W
ooooo`03oeEEEOmgMgOoA4A407Wooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00omgMgOoc<c<o`00002Booooo`009_ooool01OoMgMgo410@oooooolQ
8B7ogMgM07[ooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?ok^k^odA4A?l00000T_ooool002Kooooo00GoIVIVohN7QoooooooV9RHoeEEE@1jooooo`03o`00
0?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo097o
oooo000Uooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool0oooooollooooo`009Ooo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo0?oooooo>oooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00942 .30902 L
.01483 .30902 L
.01975 .30902 L
.02225 .30902 L
.02496 .30902 L
.02644 .30902 L
.02782 .30902 L
.02922 .30902 L
.03053 .30902 L
.03164 .30902 L
.03285 .30902 L
.03418 .30902 L
.0354 .30902 L
.03667 .30902 L
.03805 .30902 L
.03935 .30902 L
.04057 .30902 L
.08481 .30902 L
.0872 .30902 L
.08852 .30902 L
.08977 .30902 L
.09093 .30902 L
.0922 .30902 L
.09334 .30902 L
.09441 .30902 L
.09552 .30902 L
.09675 .30902 L
.09803 .30902 L
.09924 .30902 L
.10179 .30902 L
.10455 .30902 L
.11035 .30902 L
.11566 .30902 L
.12589 .30902 L
.12842 .30902 L
.13113 .30902 L
.13268 .30902 L
.13409 .30902 L
.13543 .30902 L
.13685 .30902 L
.13755 .30902 L
.13833 .30902 L
.13969 .30902 L
.14046 .30902 L
.14129 .30902 L
.14207 .30902 L
.14278 .30902 L
.14415 .30902 L
.14493 .30902 L
Mistroke
.14565 .30902 L
.14838 .30902 L
.15115 .30902 L
.15376 .30902 L
.15864 .30902 L
.16385 .30902 L
.16956 .30902 L
.17488 .30902 L
.17984 .30902 L
.18551 .30902 L
.19068 .30902 L
.1955 .30902 L
.20005 .30902 L
.20486 .30902 L
.21009 .30902 L
.22083 .30902 L
.22608 .30902 L
.23089 .30902 L
.23331 .30902 L
.23595 .30902 L
.23723 .30902 L
.2386 .30902 L
.23936 .30902 L
.24005 .30902 L
.24139 .30902 L
.24212 .30902 L
.24288 .30902 L
.24425 .30902 L
.24502 .30902 L
.24573 .30902 L
.24651 .30902 L
.24735 .30902 L
.24886 .30902 L
.25029 .30902 L
.25297 .30902 L
.25777 .30902 L
.26308 .30902 L
.27384 .30902 L
.29318 .30902 L
.31347 .30902 L
.32392 .30902 L
.32945 .30902 L
.33249 .30902 L
.33536 .30902 L
.33809 .30902 L
.33963 .30902 L
.34037 .30902 L
.34106 .30902 L
.34225 .30902 L
.34357 .30902 L
Mistroke
.34486 .30902 L
.34624 .30902 L
.34754 .30902 L
.34827 .30902 L
.34895 .30902 L
.35153 .30902 L
.35388 .30902 L
.35637 .30902 L
.36236 .30902 L
.36799 .30902 L
.37852 .30902 L
.41902 .30902 L
.42425 .30902 L
.42986 .30902 L
.43258 .30902 L
.43515 .30902 L
.43746 .30902 L
.43876 .30902 L
.43997 .30902 L
.44123 .30902 L
.4424 .30902 L
.44369 .30902 L
.44442 .30902 L
.44509 .30902 L
.44635 .30902 L
.44773 .30902 L
.44918 .30902 L
.45052 .30902 L
.45345 .30902 L
.45612 .30902 L
.46209 .30902 L
.47271 .30902 L
.47852 .30902 L
.48395 .30902 L
.48858 .30902 L
.49118 .30902 L
.49355 .30902 L
.49489 .30902 L
.49614 .30902 L
.4975 .30902 L
.49827 .30902 L
.49896 .30902 L
.50023 .30902 L
.50161 .30902 L
.5029 .30902 L
.5041 .30902 L
.50532 .30902 L
.50644 .30902 L
.50895 .30902 L
.51348 .30902 L
Mistroke
.52376 .30902 L
.53455 .30902 L
.53929 .30902 L
.5418 .30902 L
.54451 .30902 L
.54713 .30902 L
.54954 .30902 L
.5507 .30902 L
.55196 .30902 L
.55315 .30902 L
.55426 .30902 L
.55561 .30902 L
.55688 .30902 L
.55803 .30902 L
.55926 .30902 L
.56061 .30902 L
.5613 .30902 L
.56204 .30902 L
.5646 .30902 L
.56745 .30902 L
.57004 .30902 L
.57588 .30902 L
.58642 .30902 L
.59682 .30902 L
.60645 .30902 L
.62824 .30902 L
.63767 .30902 L
.64262 .30902 L
.64532 .30902 L
.64783 .30902 L
.64929 .30902 L
.65061 .30902 L
.65208 .30902 L
.65289 .30902 L
.65365 .30902 L
.65498 .30902 L
.65621 .30902 L
.65756 .30902 L
.65824 .30902 L
.65899 .30902 L
.66035 .30902 L
.66159 .30902 L
.6644 .30902 L
.66946 .30902 L
.7112 .30902 L
.73226 .30902 L
.74143 .30902 L
.74394 .30902 L
.7466 .30902 L
.74889 .30902 L
Mistroke
.75134 .30902 L
.75272 .30902 L
.75397 .30902 L
.75523 .30902 L
.75642 .30902 L
.75781 .30902 L
.7591 .30902 L
.75977 .30902 L
.7605 .30902 L
.762 .30902 L
.76449 .30902 L
.76717 .30902 L
.77203 .30902 L
.78256 .30902 L
.78812 .30902 L
.79406 .30902 L
.79701 .30902 L
.79979 .30902 L
.80498 .30902 L
.80986 .30902 L
.81513 .30902 L
.82074 .30902 L
.82667 .30902 L
.83174 .30902 L
.8373 .30902 L
.84232 .30902 L
.8478 .30902 L
.8503 .30902 L
.85296 .30902 L
.85406 .30902 L
.85524 .30902 L
.85653 .30902 L
.85775 .30902 L
.85847 .30902 L
.85914 .30902 L
.85988 .30902 L
.86066 .30902 L
.86149 .30902 L
.86227 .30902 L
.86373 .30902 L
.8651 .30902 L
.86637 .30902 L
.86922 .30902 L
.87431 .30902 L
.8797 .30902 L
.88958 .30902 L
.89243 .30902 L
.89514 .30902 L
.8976 .30902 L
.89894 .30902 L
Mistroke
.90022 .30902 L
.90142 .30902 L
.90272 .30902 L
.9039 .30902 L
.90498 .30902 L
.90601 .30902 L
.90713 .30902 L
.90831 .30902 L
.9094 .30902 L
.91071 .30902 L
.91194 .30902 L
.91425 .30902 L
.91692 .30902 L
.91943 .30902 L
.92175 .30902 L
.92306 .30902 L
.92425 .30902 L
.92549 .30902 L
.92685 .30902 L
.92753 .30902 L
.92826 .30902 L
.92957 .30902 L
.9303 .30902 L
.93097 .30902 L
.93248 .30902 L
.93522 .30902 L
.93771 .30902 L
.94034 .30902 L
.95045 .30902 L
.95487 .30902 L
.9572 .30902 L
.95969 .30902 L
.96107 .30902 L
.96233 .30902 L
.96359 .30902 L
.96477 .30902 L
.96598 .30902 L
.96709 .30902 L
.96831 .30902 L
.9696 .30902 L
.97087 .30902 L
.97223 .30902 L
.97468 .30902 L
.97759 .30902 L
.98025 .30902 L
.99013 .30902 L
.99948 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000W
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@ooooooooool04?ooool002Wooooo00?o0000oooo
ooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000002Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool2
o`0002kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo01;ooooo
000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03
o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo02Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooooooo
o`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Dooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000oooo
ooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool002Woooooool0000/
o`0000_ooooo00CogMgMo`000?l@413oc<c<1Oooool002Wooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Cok^k^ob4Q8Ol@413ok^k^1Ooo
ool002Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Oooool002Wooooo00?o0000ooooooooool0oooooolc
ooooo`;o00000_ooool2o`0000Cooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolm
ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
3_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`?o0000oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Q
ooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEE
ofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOoo
ool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM093ooooo000Uooooo`?o000000?o410@oooooooo
ool0N_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0Soooool002Oooooo00?o410@okZj
^_ooool0Noooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`2>ooooo`009oooool00onHV9So<S8booooo`1kooooo`03o`000?oooooooooo
00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`2?
ooooo`009oooool00ooMgMgo0000okZj^P1kooooo`03o`000?oooooooooo01[ooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0T?ooool002Oooooo00?oEEEE
ogMgMom4A4@0NOooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo09;ooooo000Vooooo`05omgMgOl@413oooooob4Q8OoMgMd0N_oo
ool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`2Booooo`009_ooool01OmVIVKoQhN7oooooonHV9SoEEEE07[ooooo00?o0000ooooooooool0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0002Aooooo`009Oooool00oo^k^ko0000
onk^kP02ooooo`03o`000?oMgMgooooo0?oooooo??ooool002Gooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`3ooooooc_ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .29667 L
.06168 .29001 L
.07286 .28619 L
.08481 .28245 L
.0906 .28096 L
.09607 .27981 L
.10099 .27901 L
.10352 .27869 L
.10632 .27839 L
.10893 .27818 L
.11138 .27803 L
.1127 .27796 L
.11396 .27792 L
.11541 .27787 L
.11674 .27784 L
.11789 .27782 L
.11912 .27781 L
.12029 .2778 L
.12134 .2778 L
.12258 .27781 L
.12392 .27782 L
.12519 .27784 L
.12636 .27785 L
.1359 .27806 L
.13841 .27811 L
.14115 .27816 L
.14356 .2782 L
.14613 .27823 L
.14757 .27824 L
.14834 .27824 L
.14917 .27825 L
.14993 .27825 L
.15063 .27825 L
.15199 .27826 L
.15324 .27826 L
.1546 .27825 L
.15529 .27825 L
.15602 .27825 L
.15735 .27824 L
.16017 .27822 L
.16283 .27819 L
.16782 .27814 L
.17309 .27809 L
.17567 .27807 L
.17803 .27805 L
.17922 .27805 L
.18051 .27804 L
.18188 .27804 L
.18317 .27804 L
Mistroke
.18392 .27803 L
.1846 .27803 L
.18538 .27803 L
.18611 .27803 L
.18742 .27804 L
.18816 .27804 L
.18884 .27804 L
.19116 .27805 L
.19333 .27806 L
.19826 .27809 L
.20343 .27812 L
.20821 .27814 L
.21077 .27815 L
.21208 .27816 L
.21348 .27816 L
.21422 .27816 L
.21489 .27817 L
.21621 .27817 L
.21691 .27817 L
.21767 .27817 L
.21847 .27817 L
.21921 .27817 L
.22057 .27817 L
.22185 .27816 L
.223 .27816 L
.22425 .27816 L
.22962 .27814 L
.23449 .27812 L
.2397 .2781 L
.24223 .27809 L
.24463 .27809 L
.24567 .27808 L
.24678 .27808 L
.24799 .27808 L
.24912 .27808 L
.25029 .27808 L
.25156 .27808 L
.25276 .27808 L
.25385 .27808 L
.25507 .27808 L
.2564 .27808 L
.25908 .27809 L
.26475 .2781 L
.27003 .27812 L
.27291 .27813 L
.27563 .27813 L
.27807 .27814 L
.27944 .27814 L
.28071 .27814 L
.28208 .27814 L
Mistroke
.28336 .27814 L
.28409 .27814 L
.28476 .27814 L
.28553 .27814 L
.28626 .27814 L
.28697 .27814 L
.28772 .27814 L
.28907 .27814 L
.29068 .27814 L
.29214 .27813 L
.30198 .27812 L
.30457 .27811 L
.30735 .27811 L
.30992 .2781 L
.31236 .2781 L
.31373 .2781 L
.31449 .2781 L
.31521 .2781 L
.31646 .2781 L
.3178 .2781 L
.3185 .2781 L
.31926 .2781 L
.32063 .2781 L
.32142 .2781 L
.32226 .2781 L
.32375 .2781 L
.32635 .2781 L
.32876 .27811 L
.33423 .27811 L
.33954 .27812 L
.34233 .27812 L
.34386 .27813 L
.34529 .27813 L
.34654 .27813 L
.34788 .27813 L
.34864 .27813 L
.34936 .27813 L
.35072 .27813 L
.35196 .27813 L
.35312 .27813 L
.35438 .27813 L
.35573 .27813 L
.35827 .27813 L
.36101 .27812 L
.36597 .27812 L
.37045 .27811 L
.37525 .27811 L
.37664 .27811 L
.37796 .27811 L
.37925 .27811 L
Mistroke
.38043 .27811 L
.38156 .27811 L
.38275 .27811 L
.38395 .27811 L
.38527 .27811 L
.386 .27811 L
.38669 .27811 L
.38799 .27811 L
.38872 .27811 L
.3894 .27811 L
.39093 .27811 L
.39624 .27811 L
.40171 .27811 L
.40459 .27812 L
.40764 .27812 L
.4103 .27812 L
.41172 .27812 L
.41323 .27812 L
.41394 .27812 L
.41462 .27812 L
.41589 .27812 L
.41708 .27812 L
.41838 .27812 L
.41971 .27812 L
.42095 .27812 L
.42232 .27812 L
.4238 .27812 L
.42681 .27812 L
.42956 .27812 L
.43451 .27812 L
.43992 .27811 L
.4423 .27811 L
.44484 .27811 L
.44608 .27811 L
.44725 .27811 L
.44829 .27811 L
.44943 .27811 L
.45064 .27811 L
.45196 .27811 L
.45335 .27811 L
.45464 .27811 L
.45585 .27811 L
.45696 .27811 L
.45945 .27811 L
.46994 .27811 L
.4727 .27812 L
.47569 .27812 L
.47827 .27812 L
.4811 .27812 L
.48378 .27812 L
Mistroke
.48523 .27812 L
.48659 .27812 L
.48787 .27812 L
.48903 .27812 L
.49037 .27812 L
.49164 .27812 L
.49279 .27812 L
.49402 .27812 L
.49506 .27812 L
.49622 .27812 L
.49745 .27812 L
.49878 .27812 L
.50004 .27812 L
.50119 .27812 L
.50242 .27812 L
.50353 .27812 L
.50482 .27812 L
.50603 .27812 L
.50716 .27812 L
.50819 .27812 L
.50933 .27812 L
.51054 .27812 L
.51175 .27812 L
.51305 .27812 L
.51428 .27812 L
.5154 .27812 L
.51815 .27812 L
.52075 .27812 L
.52323 .27812 L
.52587 .27812 L
.5306 .27811 L
.5362 .27811 L
.53865 .27811 L
.54133 .27811 L
.54253 .27811 L
.54381 .27811 L
.54501 .27811 L
.54611 .27811 L
.54735 .27811 L
.5487 .27811 L
.54997 .27811 L
.55115 .27811 L
.55241 .27811 L
.55359 .27811 L
.55629 .27811 L
.55892 .27811 L
.56174 .27811 L
.56656 .27812 L
.57169 .27812 L
.57418 .27812 L
Mistroke
.57541 .27812 L
.57653 .27812 L
.57754 .27812 L
.57864 .27812 L
.57975 .27812 L
.58092 .27812 L
.58231 .27812 L
.58357 .27812 L
.58427 .27812 L
.58503 .27812 L
.58641 .27812 L
.5877 .27812 L
.58907 .27812 L
.59154 .27812 L
.59704 .27812 L
.60312 .27811 L
.60567 .27811 L
.60836 .27811 L
.60976 .27811 L
.6113 .27811 L
.61198 .27811 L
.6127 .27811 L
.614 .27811 L
.61532 .27811 L
.61607 .27811 L
.61675 .27811 L
.61802 .27811 L
.61935 .27811 L
.62055 .27811 L
.62167 .27811 L
.62422 .27811 L
.63515 .27812 L
.63776 .27812 L
.64053 .27813 L
.64188 .27813 L
.64315 .27813 L
.64431 .27813 L
.64552 .27813 L
.64664 .27813 L
.64786 .27813 L
.64897 .27813 L
.65 .27813 L
.65122 .27813 L
.65234 .27813 L
.65362 .27813 L
.65484 .27813 L
.65737 .27812 L
.6597 .27812 L
.66499 .27811 L
.66987 .27811 L
Mistroke
.67257 .2781 L
.67513 .2781 L
.6775 .2781 L
.67884 .2781 L
.68009 .2781 L
.68124 .2781 L
.68229 .2781 L
.68349 .2781 L
.68463 .2781 L
.68589 .2781 L
.68726 .2781 L
.6887 .2781 L
.69005 .2781 L
.69503 .27811 L
.70042 .27812 L
.70326 .27813 L
.70628 .27813 L
.70899 .27814 L
.71053 .27814 L
.71123 .27814 L
.71197 .27814 L
.7133 .27814 L
.71451 .27814 L
.71581 .27814 L
.71655 .27814 L
.71724 .27814 L
.71859 .27814 L
.71987 .27814 L
.72102 .27814 L
.72226 .27814 L
.72506 .27813 L
.72763 .27812 L
.73702 .2781 L
.73972 .27809 L
.74229 .27809 L
.74341 .27808 L
.7446 .27808 L
.7459 .27808 L
.74711 .27808 L
.74843 .27808 L
.74917 .27808 L
.74986 .27808 L
.75112 .27808 L
.75244 .27808 L
.75364 .27808 L
.75475 .27809 L
.75728 .27809 L
.76187 .27811 L
.76679 .27813 L
.76958 .27814 L
Mistroke
.77262 .27815 L
.77529 .27816 L
.77675 .27816 L
.77813 .27816 L
.77936 .27817 L
.78068 .27817 L
.7814 .27817 L
.78215 .27817 L
.7835 .27817 L
.78472 .27817 L
.78587 .27816 L
.78712 .27816 L
.78846 .27816 L
.79118 .27815 L
.79406 .27813 L
.79923 .2781 L
.80526 .27806 L
.8082 .27805 L
.80949 .27804 L
.81089 .27804 L
.81219 .27804 L
.81339 .27804 L
.81453 .27803 L
.81576 .27803 L
.81643 .27804 L
.81717 .27804 L
.8185 .27804 L
.81979 .27804 L
.82098 .27805 L
.82355 .27806 L
.82637 .27809 L
.83206 .27814 L
.83759 .2782 L
.84031 .27822 L
.8415 .27823 L
.84282 .27824 L
.84391 .27825 L
.84509 .27825 L
.84634 .27826 L
.84751 .27826 L
.84887 .27826 L
.85017 .27825 L
.85133 .27825 L
.85261 .27824 L
.8541 .27822 L
.8555 .27821 L
.85812 .27817 L
.864 .27806 L
.86905 .27794 L
.87172 .27789 L
Mistroke
.87319 .27786 L
.87459 .27784 L
.87592 .27782 L
.87667 .27781 L
.87736 .27781 L
.87859 .2778 L
.87989 .2778 L
.8811 .27781 L
.88224 .27782 L
.88349 .27784 L
.88484 .27788 L
.88615 .27792 L
.88759 .27798 L
.89049 .27814 L
.89317 .27835 L
.89567 .27859 L
.90058 .27924 L
.90504 .28002 L
.91506 .28242 L
.95704 .29596 L
.99742 .30817 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000W
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@ooooooooool04?ooool002Wooooo00?o0000oooo
ooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000002Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool2
o`0001_oooookol0000Nooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo
01Gooooo1Ol0000Cooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0V
ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Wooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02Oooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`05?ooool6o`0001Sooooo00?o
0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool04oooool2o`0001Sooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03
oeEEEOn7QhOooooo02Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41006_ooool3o`0001Gooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000oooo
ooooool04Oooool2o`0001[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41009oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
9oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000Mooooo`?o00004_ooool0
0ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0>ooooo`?o00007?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Wooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Vooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@410Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnYZJWo410@o`000?l@413oZJVY023ooooo0_l0000>ooooo`03oeEEEOmVIVKo000001Cooooo000Y
ooooo`;o00003?ooool3o`000?oooooo2_ooool3o`0002;ooooo000Yooooo`03o`000?oooooooooo
00Oooooo1?l0003ooooooa3ooooo0ol0000Oooooo`00:Oooool00ol0003oooooooooo`03ooooo`Co
0000oooooolGooooo`Co00004Oooool2o`0000;ooooo0_l00004ooooo`00:Oooool00ol0003ooooo
o`000003o`000?oooooo7oooool4o`0000gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4oooo
o`00:Oooooooo`0002co00002oooool01?oMgMgo0000oa0@4?o<c<`5ooooo`00:Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool01?o^k^ko
8B4Qoa0@4?o^k^h5ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`00:Oooool00ol0003o
ooooooooo`3ooooooc?ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`00
3_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Uooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0TOooool002Gooooo0ol0
00000ol@413oooooooooo`1jooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
097ooooo000Wooooo`03oa0@4?nj^[[ooooo07_ooooo00?o0000ooooooooool06_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00002Aooooo`009oooool00onH
V9So<S8booooo`1kooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?oooooooooo
ooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q097ooooo000Wooooo`03omgMgOl0003o
^[Zj07_ooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oeEEEOl0003o410@olc<c02Aooooo`009oooool00omEEEGoMgMgodA4A01iooooo`03oa0@4?l0
003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
Toooool002Kooooo00GogMgMoa0@4?oooooo8B4QomgMg@1jooooo`03o`000?oooooooooo01[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH09?ooooo000Vooooo`05ofIV
I_n7QhOooooooiRHV?mEEED0N_ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@412Aooooo`009Oooool00oo^k^ko0000onk^kP02oooo
o`03o`000?oMgMgooooo0?oooooo??ooool002Gooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`3ooooooc_ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .2964 L
.08481 .28294 L
.12636 .26989 L
.16632 .25751 L
.17777 .2537 L
.18859 .25057 L
.19331 .24947 L
.19831 .24853 L
.20092 .24812 L
.20379 .24775 L
.20621 .24749 L
.20885 .24727 L
.21027 .24718 L
.21158 .2471 L
.21294 .24704 L
.21417 .24699 L
.2153 .24695 L
.21653 .24692 L
.21782 .2469 L
.21904 .24689 L
.22036 .24688 L
.22111 .24688 L
.22181 .24689 L
.22255 .24689 L
.22323 .2469 L
.22474 .24691 L
.22603 .24693 L
.22744 .24696 L
.22999 .24701 L
.23491 .24713 L
.24021 .24725 L
.24264 .24729 L
.24521 .24733 L
.2474 .24735 L
.24864 .24736 L
.2498 .24736 L
.25108 .24737 L
.2523 .24737 L
.25339 .24737 L
.25457 .24736 L
.25586 .24736 L
.25722 .24735 L
.25966 .24733 L
.26529 .24727 L
.27056 .24721 L
.27562 .24716 L
.27708 .24715 L
.27846 .24714 L
.27983 .24713 L
Mistroke
.28106 .24713 L
.28173 .24713 L
.28245 .24713 L
.28321 .24712 L
.28393 .24712 L
.28532 .24712 L
.28659 .24712 L
.28731 .24713 L
.28799 .24713 L
.28952 .24713 L
.29102 .24714 L
.29262 .24714 L
.30333 .24722 L
.30626 .24724 L
.30937 .24725 L
.31203 .24726 L
.31354 .24727 L
.31428 .24727 L
.31496 .24727 L
.3162 .24727 L
.31755 .24727 L
.31887 .24727 L
.31961 .24727 L
.32027 .24727 L
.32148 .24727 L
.32278 .24727 L
.32514 .24726 L
.32791 .24725 L
.33085 .24724 L
.3361 .24721 L
.33854 .2472 L
.3412 .24719 L
.34354 .24718 L
.34604 .24718 L
.34741 .24718 L
.34819 .24718 L
.34893 .24717 L
.35022 .24717 L
.35094 .24717 L
.35161 .24717 L
.35279 .24717 L
.35409 .24718 L
.35544 .24718 L
.35669 .24718 L
.3592 .24718 L
.36157 .24719 L
.36599 .2472 L
.37113 .24722 L
.37594 .24723 L
.37827 .24724 L
Mistroke
.37959 .24724 L
.38079 .24724 L
.3821 .24724 L
.38284 .24724 L
.38353 .24724 L
.38479 .24724 L
.38613 .24724 L
.38686 .24724 L
.38753 .24724 L
.38904 .24724 L
.39038 .24724 L
.39179 .24724 L
.39693 .24723 L
.40213 .24722 L
.40706 .24721 L
.4092 .2472 L
.41148 .2472 L
.41267 .2472 L
.41398 .2472 L
.41517 .2472 L
.41629 .2472 L
.41751 .2472 L
.41879 .2472 L
.41989 .2472 L
.42109 .2472 L
.42238 .2472 L
.42376 .2472 L
.42625 .2472 L
.43693 .24721 L
.43942 .24722 L
.44212 .24722 L
.44467 .24722 L
.44588 .24722 L
.44702 .24722 L
.44813 .24722 L
.44914 .24722 L
.45026 .24722 L
.45147 .24722 L
.45263 .24722 L
.45389 .24722 L
.45508 .24722 L
.45618 .24722 L
.46582 .24722 L
.47108 .24722 L
.47598 .24721 L
.47854 .24721 L
.48129 .24721 L
.48286 .24721 L
.48434 .24721 L
.48567 .24721 L
Mistroke
.48712 .24721 L
.48834 .24721 L
.4897 .24721 L
.49038 .24721 L
.49111 .24721 L
.49243 .24721 L
.49375 .24721 L
.495 .24721 L
.49612 .24721 L
.49735 .24721 L
.49808 .24721 L
.49887 .24721 L
.49962 .24721 L
.50031 .24721 L
.50162 .24721 L
.503 .24721 L
.50372 .24721 L
.50449 .24721 L
.50588 .24721 L
.50672 .24721 L
.50753 .24721 L
.50825 .24721 L
.50903 .24721 L
.51033 .24721 L
.51107 .24721 L
.51177 .24721 L
.51316 .24721 L
.51467 .24721 L
.516 .24721 L
.51739 .24721 L
.51989 .24721 L
.52242 .24721 L
.52513 .24721 L
.53001 .24722 L
.53577 .24722 L
.5383 .24722 L
.54108 .24722 L
.54238 .24722 L
.54378 .24722 L
.5451 .24722 L
.5463 .24722 L
.54766 .24722 L
.54843 .24722 L
.54914 .24722 L
.55044 .24722 L
.55183 .24722 L
.55335 .24722 L
.55498 .24722 L
.55795 .24722 L
.56349 .24721 L
Mistroke
.56885 .24721 L
.57178 .2472 L
.57451 .2472 L
.57684 .2472 L
.57815 .2472 L
.57934 .2472 L
.58065 .2472 L
.58138 .2472 L
.58207 .2472 L
.58332 .2472 L
.58464 .2472 L
.58584 .2472 L
.58715 .2472 L
.58979 .2472 L
.59223 .2472 L
.5945 .24721 L
.60007 .24722 L
.60512 .24723 L
.60741 .24723 L
.60862 .24724 L
.6099 .24724 L
.61102 .24724 L
.61225 .24724 L
.61336 .24724 L
.61441 .24724 L
.61569 .24724 L
.61691 .24724 L
.618 .24724 L
.61919 .24724 L
.62048 .24724 L
.62185 .24724 L
.62432 .24723 L
.63414 .2472 L
.6393 .24719 L
.64189 .24718 L
.64338 .24718 L
.64473 .24718 L
.64602 .24718 L
.64723 .24717 L
.64852 .24717 L
.64924 .24717 L
.64991 .24717 L
.65102 .24717 L
.65225 .24718 L
.65353 .24718 L
.65473 .24718 L
.65704 .24719 L
.65916 .24719 L
.66391 .24721 L
.66888 .24724 L
Mistroke
.67357 .24726 L
.67616 .24726 L
.67762 .24727 L
.67896 .24727 L
.6801 .24727 L
.68134 .24727 L
.68264 .24727 L
.68385 .24727 L
.68456 .24727 L
.68532 .24727 L
.6867 .24727 L
.68805 .24726 L
.6893 .24726 L
.69213 .24724 L
.69514 .24723 L
.70061 .24719 L
.70562 .24715 L
.7081 .24714 L
.71041 .24713 L
.71158 .24713 L
.71282 .24712 L
.7142 .24712 L
.71546 .24712 L
.71682 .24712 L
.71808 .24713 L
.71946 .24713 L
.72092 .24714 L
.72337 .24715 L
.72607 .24718 L
.73591 .24729 L
.73826 .24731 L
.74077 .24734 L
.74198 .24735 L
.74313 .24735 L
.74417 .24736 L
.74526 .24736 L
.74654 .24737 L
.74772 .24737 L
.74898 .24737 L
.75037 .24736 L
.7511 .24736 L
.75176 .24736 L
.75325 .24734 L
.75463 .24733 L
.75594 .24731 L
.76061 .24723 L
.76569 .24712 L
.77122 .24699 L
.77401 .24693 L
.7756 .24691 L
Mistroke
.77631 .2469 L
.77709 .24689 L
.77845 .24688 L
.77974 .24688 L
.781 .24689 L
.78217 .2469 L
.78355 .24693 L
.78481 .24696 L
.78626 .247 L
.78763 .24706 L
.79015 .2472 L
.79251 .24738 L
.79509 .24763 L
.79787 .24795 L
.80353 .24885 L
.80869 .24992 L
.82808 .25561 L
.86989 .26879 L
.91011 .28135 L
.95291 .29434 L
.99411 .30726 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000>?oooongo`0004kooooo000Yooooo`03o`000?oooooooooo03Cooooo0ol0002goooo
o`Co0000B_ooool002Wooooo00?o0000ooooooooool0<?ooool4o`000;kooooo1?l00016ooooo`00
:Oooool00ol0003oooooooooo`0]ooooo`?o0000a_ooool3o`0004?ooooo000Yooooo`03o`000?oo
oooooooo02[ooooo0ol0003<ooooo`?o0000@?ooool002Wooooo0_l0000Xooooo`?o0000d_ooool3
o`0003gooooo000Yooooo`03o`000?oooooooooo02Cooooo0ol00006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00:ooooo`Co00008_ooool4
o`000003oa0@4?oooooooooo013ooooo000Yooooo`03o`000?oooooooooo027ooooo0ol00009oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A00Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
9Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B409oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B403_ooool3o`00027ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool07_ooool3o`0000cooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^02Sooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00009_ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo0000017ooooo0ol0000Nooooo`03o`000?oo
oooooooo01;ooooo000Yooooo`;o00007?ooool3o`0000oooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4
A?oMgMgoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B409oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P0Dooooo`?o00006oooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooooooo
o`0Hooooo`?o00004_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00009oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Wooooo`05o`000?oo
ooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<01Oooooo0ol0000Hooooo`03
o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo01Cooooo1?l0000Eooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Uooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00omgMgOoc<c<o`00000Wooooo`05oa0@4?ooooooooooooooool@41002oooool0
0omEEEGoQhN7ooooo`0Yooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooo
oonj^[[o410@01[ooooo0ol0000Eooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oo
oooooooo017ooooo0ol0000Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000007Oooool3o`0001;ooooo
00?o0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool03_ooool3o`0001cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool09_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo00Coc<c<odA4A?l0003o410@9oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@0Pooooo`?o00003Oooool00omEEEGoIVIVo`00000Dooooo`00
:Oooool2o`0000cooooo0ol0003oooooo`_ooooo1?l0000Pooooo`00:Oooool00ol0003ooooooooo
o`07ooooo`Co0000oooooolBooooo`?o00007Oooool002Wooooo00?o0000ooooooooool00oooool4
o`000?oooooo6Oooool3o`00013ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000oooo
ool000000ol0003oooooob3ooooo0ol0000=ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?oo
ool002Woooooool0000/o`0000_ooooo00CogMgMo`000?l@413oc<c<1Oooool002Wooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Cok^k^
ob4Q8Ol@413ok^k^1Oooool002Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Oooool002Wooooo00?o0000
ooooooooool0oooooolcooooo`;o00000_ooool2o`0000Cooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`03ooooo`?o0000oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00YOooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`2Aooooo`009Oooool3o`000003oa0@
4?oooooooooo07[ooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo097ooooo000Wooooo`03
oa0@4?nj^[[ooooo07_ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool0TOooool002Oooooo00?oV9RHoc8b<_ooool0Noooool00ol0003o
ooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool0T?ooool002Oooooo00?ogMgMo`000?nj^[X0Noooool00ol0003oooooooooo`0Jooooo`05
o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`2@ooooo`009oooool00omEEEGo
MgMgodA4A01iooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@
00kooooo00?oZJVYogMgMoooool0T?ooool002Kooooo00GogMgMoa0@4?oooooo8B4QomgMg@1joooo
o`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooo
oooooooooolb<S80TOooool002Kooooo00GoIVIVohN7QoooooooV9RHoeEEE@1jooooo`03o`000?oo
oooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000TOooool002Gooooo00?o
k^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`3ooooooccooooo000Uooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool0oooooolkooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .29654 L
.08481 .28272 L
.12636 .27003 L
.16632 .25763 L
.20885 .24435 L
.2498 .23205 L
.27066 .22514 L
.28166 .22159 L
.28768 .21991 L
.29331 .21857 L
.29831 .21762 L
.30369 .21686 L
.30675 .21654 L
.30965 .21632 L
.31226 .21617 L
.31374 .2161 L
.31511 .21606 L
.31638 .21603 L
.31774 .216 L
.31903 .21599 L
.32022 .21598 L
.3213 .21598 L
.32247 .21599 L
.32371 .216 L
.32485 .21601 L
.32748 .21606 L
.32987 .21611 L
.33524 .21624 L
.34029 .21634 L
.34284 .21639 L
.3443 .21641 L
.34565 .21643 L
.34679 .21644 L
.34804 .21645 L
.34929 .21646 L
.35062 .21646 L
.35178 .21646 L
.35303 .21646 L
.35421 .21646 L
.35528 .21646 L
.35664 .21645 L
.35808 .21644 L
.36066 .21642 L
.36649 .21636 L
.37202 .2163 L
.37465 .21627 L
.37708 .21625 L
.37951 .21624 L
.38079 .21624 L
Mistroke
.38216 .21623 L
.38346 .21623 L
.38469 .21623 L
.38579 .21623 L
.38699 .21623 L
.38827 .21623 L
.389 .21623 L
.38968 .21623 L
.39253 .21625 L
.39763 .21627 L
.4021 .2163 L
.40685 .21633 L
.40932 .21634 L
.41064 .21635 L
.41205 .21635 L
.41335 .21635 L
.41453 .21636 L
.41567 .21636 L
.41686 .21636 L
.41818 .21636 L
.41891 .21636 L
.41958 .21636 L
.42089 .21636 L
.42212 .21636 L
.42355 .21636 L
.42488 .21635 L
.42786 .21635 L
.43282 .21633 L
.43827 .21631 L
.44063 .2163 L
.44317 .2163 L
.44556 .21629 L
.44662 .21629 L
.44775 .21629 L
.44903 .21629 L
.45021 .21629 L
.45148 .21629 L
.45221 .21629 L
.45289 .21629 L
.45411 .21629 L
.45524 .21629 L
.45647 .21629 L
.45777 .21629 L
.46853 .2163 L
.47382 .21631 L
.47615 .21631 L
.47871 .21632 L
.481 .21632 L
.48314 .21632 L
.4854 .21632 L
Mistroke
.48668 .21632 L
.48784 .21632 L
.4891 .21632 L
.49027 .21632 L
.49155 .21632 L
.49292 .21632 L
.49422 .21632 L
.49545 .21632 L
.49656 .21632 L
.49775 .21632 L
.49903 .21632 L
.50023 .21632 L
.50155 .21632 L
.50229 .21632 L
.50296 .21632 L
.50431 .21632 L
.50508 .21632 L
.50578 .21632 L
.50708 .21632 L
.50846 .21632 L
.50962 .21632 L
.51088 .21632 L
.51206 .21632 L
.51315 .21632 L
.51435 .21632 L
.51566 .21632 L
.51831 .21632 L
.5198 .21632 L
.5212 .21632 L
.52382 .21631 L
.52971 .21631 L
.53475 .2163 L
.53743 .21629 L
.5403 .21629 L
.54172 .21629 L
.54306 .21629 L
.54427 .21629 L
.54558 .21629 L
.54682 .21629 L
.54815 .21629 L
.54939 .21629 L
.55052 .21629 L
.5512 .21629 L
.55192 .21629 L
.5532 .21629 L
.55609 .21629 L
.55859 .2163 L
.56133 .21631 L
.56611 .21632 L
.57129 .21634 L
Mistroke
.57367 .21635 L
.57497 .21635 L
.57619 .21636 L
.57731 .21636 L
.57834 .21636 L
.57948 .21636 L
.58071 .21636 L
.58208 .21636 L
.58335 .21636 L
.58408 .21636 L
.58474 .21636 L
.58623 .21636 L
.58752 .21635 L
.58892 .21635 L
.59147 .21634 L
.59656 .21631 L
.60125 .21628 L
.60392 .21626 L
.60678 .21625 L
.60817 .21624 L
.60948 .21624 L
.61067 .21623 L
.61194 .21623 L
.61328 .21623 L
.61452 .21623 L
.61585 .21623 L
.61661 .21623 L
.61732 .21623 L
.61805 .21623 L
.61881 .21623 L
.62017 .21624 L
.62163 .21625 L
.62323 .21626 L
.62878 .21631 L
.63402 .21636 L
.63878 .21641 L
.64138 .21644 L
.64265 .21645 L
.64382 .21645 L
.64508 .21646 L
.64643 .21646 L
.64713 .21646 L
.6479 .21646 L
.64863 .21646 L
.64931 .21646 L
.65059 .21646 L
.65176 .21645 L
.6531 .21644 L
.65437 .21643 L
.65723 .21639 L
Mistroke
.65987 .21634 L
.66581 .21621 L
.67076 .21609 L
.67348 .21604 L
.67482 .21602 L
.67605 .216 L
.67722 .21599 L
.67845 .21598 L
.67969 .21598 L
.68105 .21599 L
.68218 .216 L
.6834 .21602 L
.68455 .21605 L
.68561 .21608 L
.68687 .21613 L
.68823 .21619 L
.69066 .21634 L
.69356 .21657 L
.69619 .21685 L
.70191 .21766 L
.70731 .21871 L
.71754 .22135 L
.72836 .22481 L
.74775 .23127 L
.78757 .24322 L
.82997 .25652 L
.87077 .26912 L
.91416 .2824 L
.95595 .29548 L
.99615 .3078 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`0005CoooooO?l0
001]ooooo`00:Oooool00ol0003oooooooooo`1?ooooo`Co0000O?ooool6o`0006Oooooo0006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1<ooooo`?o0000Q_ooool3o`0006Cooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0BOooool3o`0008cooooo
0ol0001Qooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol00016ooooo`?o0000T_ooool3o`0005kooooo
0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0@oooool3o`0009Sooooo0ol0001Kooooo`001_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0@?ooool3o`0009kooooo0ol0001Hooooo`00
1_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03gooooo0ol0002Tooooo`?o0000EOooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo1?l0002Zooooo`?o0000D_ooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4
o`0000Kooooo0_l0000gooooo`?o0000/Oooool3o`0004oooooo000Yooooo`03o`000?oooooooooo
03?ooooo0ol0002gooooo`?o0000C?ooool002Wooooo00?o0000ooooooooool0<?ooool3o`000;go
oooo0ol00019ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`?o0000`oooool4o`0004Gooooo
000Yooooo`03o`000?oooooooooo02[ooooo0ol0003:ooooo`?o0000@_ooool002Wooooo0_l0000X
ooooo`?o0000d?ooool3o`0003oooooo000Yooooo`03o`000?oooooooooo02Cooooo0ol00006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c008
ooooo`?o00009Oooool4o`000003oa0@4?oooooooooo013ooooo000Yooooo`03o`000?oooooooooo
027ooooo0ol00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool09Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B409oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402oooool3o`0002Cooooo00?o0000ooooooooool04_oo
ool002Wooooo00?o0000ooooooooool07_ooool3o`0000cooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^02Sooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
9_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Woooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000kooooo1Ol0
000Oooooo`03o`000?oooooooooo01;ooooo000Yooooo`;o00007?ooool3o`0000oooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P0Cooooo`Co00006oooool00ol0003oooooooooo`0Booooo`00:Ooo
ool00ol0003oooooooooo`0Hooooo`?o00004_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool09_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo00009oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<
c00Wooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<01Oo
oooo1?l0000Gooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo01Cooooo
1?l0000Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Uooooo`05
oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool00omEEEGoQhN7ooooo`0Yooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol@413o^[Zjoooooonj^[[o410@01_ooooo0ol0000Dooooo`03o`000?oooooooooo01;ooooo
000Yooooo`03o`000?oooooooooo017ooooo0ol0000Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413o
V9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000
7_ooool3o`00017ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool03_oo
ool3o`0001cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`09oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool09_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@9oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Qooooo`?o00003?ooool00omEEEGo
IVIVo`00000Dooooo`00:Oooool2o`0000cooooo0ol0003oooooo`cooooo0ol0000Pooooo`00:Ooo
ool00ol0003oooooooooo`07ooooo`Co0000oooooolBooooo`?o00007Oooool002Wooooo00?o0000
ooooooooool00oooool4o`000?oooooo6Oooool3o`00013ooooo0_l00002ooooo`;o00001?ooool0
02Wooooo00?o0000ooooool000000ol0003oooooob3ooooo0ol0000=ooooo`06onk^k_lQ8B7oQhN7
okZj^_l0003ogMgM1?ooool002Woooooool0000/o`0000_ooooo00CogMgMo`000?l@413oc<c<1Ooo
ool002Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Wooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool002Wooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Ooo
ool002Wooooo00?o0000ooooooooool0oooooolcooooo`;o00000_ooool2o`0000Cooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`003_ooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@
400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003o
ooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00YOooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
097ooooo000Uooooo`?o000000?o410@ooooooooool0N_ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@2Aooooo`009oooool00ol@413o^[Zjooooo`1kooooo`03o`000?oooooo
oooo01[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000
TOooool002Oooooo00?oV9RHoc8b<_ooool0Noooool00ol0003oooooooooo`0;ooooo`Ko00002Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2Aooooo`00
9oooool00ooMgMgo0000okZj^P1kooooo`03o`000?oooooooooo01[ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0TOooool002Oooooo00?oEEEEogMgMom4
A4@0NOooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@4100TOooool002Kooooo00GogMgMoa0@4?oooooo8B4QomgMg@1j
ooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l00000TOooool002Kooooo00GoIVIVohN7QoooooooV9RHoeEEE@1jooooo`03o`00
0?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0TOooool002Gooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`3oooooocco
oooo000Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0oooooolkooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .29643 L
.08481 .28288 L
.12636 .26992 L
.16632 .25762 L
.20885 .24455 L
.2498 .23171 L
.29331 .21845 L
.33524 .2055 L
.37557 .19258 L
.38633 .18934 L
.39159 .18804 L
.3964 .18705 L
.40147 .18625 L
.40426 .18591 L
.40691 .18565 L
.40978 .18543 L
.41244 .18528 L
.41398 .18522 L
.41537 .18518 L
.41614 .18516 L
.41697 .18514 L
.41775 .18513 L
.41848 .18512 L
.41979 .18511 L
.42098 .1851 L
.42225 .18511 L
.42298 .18511 L
.42365 .18511 L
.42476 .18513 L
.42598 .18514 L
.42846 .18518 L
.43942 .1854 L
.44209 .18545 L
.44491 .18548 L
.44638 .1855 L
.448 .18551 L
.44871 .18551 L
.44946 .18552 L
.45083 .18552 L
.45221 .18553 L
.45299 .18553 L
.45371 .18553 L
.45504 .18553 L
.4557 .18553 L
.45644 .18552 L
.45771 .18552 L
.45907 .18551 L
.46154 .1855 L
.47217 .18543 L
Mistroke
.47509 .18541 L
.47819 .1854 L
.48112 .18538 L
.48377 .18538 L
.4851 .18538 L
.4865 .18537 L
.48769 .18537 L
.489 .18537 L
.49041 .18537 L
.4912 .18537 L
.49192 .18537 L
.49259 .18537 L
.49332 .18537 L
.49465 .18537 L
.49587 .18537 L
.49723 .18537 L
.49791 .18537 L
.49864 .18537 L
.49996 .18537 L
.50121 .18537 L
.50253 .18537 L
.50365 .18537 L
.50488 .18537 L
.50555 .18537 L
.50627 .18537 L
.50755 .18537 L
.50893 .18537 L
.50971 .18537 L
.51045 .18537 L
.51177 .18537 L
.51298 .18537 L
.51437 .18537 L
.51569 .18538 L
.51813 .18538 L
.52039 .18539 L
.52287 .1854 L
.52551 .18541 L
.5361 .18548 L
.539 .1855 L
.54058 .18551 L
.54206 .18552 L
.54332 .18552 L
.54466 .18553 L
.54543 .18553 L
.54616 .18553 L
.54752 .18553 L
.5487 .18553 L
.54999 .18552 L
.55135 .18551 L
.55262 .18551 L
Mistroke
.55488 .18549 L
.55732 .18545 L
.56287 .18536 L
.56794 .18525 L
.57265 .18516 L
.57393 .18514 L
.57531 .18513 L
.5766 .18511 L
.57778 .18511 L
.57898 .1851 L
.58009 .18511 L
.58131 .18511 L
.58259 .18513 L
.58371 .18515 L
.58475 .18518 L
.58713 .18526 L
.58845 .18532 L
.58986 .1854 L
.59239 .18559 L
.59511 .18584 L
.59811 .18619 L
.60348 .18703 L
.60851 .18806 L
.61789 .19054 L
.628 .19377 L
.67122 .20738 L
.71284 .2204 L
.75288 .23254 L
.79549 .24587 L
.83651 .25852 L
.8801 .27189 L
.9221 .28501 L
.96251 .2974 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`1jooooo`;o0000;?ooool3o`00097ooooo000Yooooo`;o0000L_ooool9o`000003ooooool0003o
000002co000000?oooooo`000?l000002Ol00027ooooo`00:Oooool00ol0003oooooooooo`1_oooo
o`;o0000A?ooool3o`0008Cooooo000Yooooo`03o`000?oooooooooo06cooooo0ol00019ooooo`?o
0000POooool002Wooooo00?o0000ooooooooool0JOooool3o`0004oooooo0ol0001nooooo`00:Ooo
ool2o`0006Oooooo0ol0001Eooooo`?o0000Noooool002Wooooo00?o0000ooooooooool0Hoooool3
o`0005_ooooo0ol0001hooooo`00:Oooool00ol0003oooooooooo`1Oooooo`Co0000HOooool4o`00
07Cooooo000Yooooo`03o`000?oooooooooo05[ooooo1Ol0001Yooooo`?o0000LOooool002Wooooo
00?o0000ooooooooool0E_ooool4o`00077ooooo0ol0001^ooooo`00:Oooool2o`0005?ooooo1?l0
001hooooo`?o0000Joooool002Wooooo00?o0000ooooooooool0Coooool3o`0007oooooo0ol0001X
ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0C?ooool3o`0008Gooooo0ol0
001Uooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Wooooo
0ol0002;ooooo`?o0000H_ooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000A_ooool3o`00097ooooo
0ol0001Oooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04?ooooo0ol0002Gooooo`?o0000
G?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo043ooooo0ol0002Mooooo`?o
0000FOooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`?o0000Xoooool3o`0005Ko
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0iooooo`Co0000ZOooool3o`00
05?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`;o0000=oooool3o`000;3ooooo1?l0001?ooooo`00:Oooool00ol0
003oooooooooo`0cooooo`?o0000]oooool4o`0004_ooooo000Yooooo`03o`000?oooooooooo033o
oooo0ol0002nooooo`Co0000Aoooool002Wooooo00?o0000ooooooooool0;Oooool3o`000<Gooooo
1?l00013ooooo`00:Oooool00ol0003oooooooooo`0Zooooo`?o0000c?ooool3o`00043ooooo000Y
ooooo`;o0000:?ooool3o`000=;ooooo0ol0000mooooo`00:Oooool00ol0003oooooooooo`0Toooo
o`?o00001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00009oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool09?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`09oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`02_ooool3o`0002?ooooo1?l000000ol@413oooooooooo`0@ooooo`00:Oooool00ol0
003oooooooooo`0Qooooo`?o00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00gooooo1?l0000Qooooo`03o`000?oo
oooooooo01;ooooo000Yooooo`03o`000?oooooooooo01kooooo0ol0000<ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Xooooo`05oa0@4?ooooooooooooooool@4100
2oooool5o`0002Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000009oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
000Aooooo`?o00007_ooool00ol0003oooooooooo`0Booooo`00:Oooool2o`0001cooooo0ol0000?
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Wooooo`05o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool0000Wooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q02Oooooo00Go0000ooooooooooooooooo`00
000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S805?ooool3o`0001_ooooo00?o0000ooooooooool0
4_ooool002Wooooo00?o0000ooooooooool06?ooool3o`0001;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`09oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c00Gooooo`?o00006?ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooo
ooooo`0Dooooo`Co00005Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool09Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000009oooool01Ol@
413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0:Oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Jooooo`?o00005Oooool00ol0003ooooo
ooooo`0Booooo`00:Oooool00ol0003oooooooooo`0Aooooo`?o00006Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Wooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00oo^k^koA4A4o`00000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV00Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonj^[[o000001gooooo0ol0000Booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oo
oooooooo00kooooo0ol0000Looooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo
02Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT08?ooool3o`0000go
oooo00?oEEEEofIVI_l000005?ooool002Wooooo0_l0000<ooooo`?o0000ooooool;ooooo`?o0000
8Oooool002Wooooo00?o0000ooooooooool01oooool4o`000?oooooo4Oooool3o`0001kooooo000Y
ooooo`03o`000?oooooooooo00?ooooo1?l0003ooooooaSooooo1?l0000@ooooo`;o00000_ooool2
o`0000Cooooo000Yooooo`03o`000?oooooo000000?o0000oooooolPooooo`Co00003?ooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Yoooooooo0000;?l0000;ooooo`04omgMgOl0003o
410@olc<c0Gooooo000Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`09ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Yooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`04ob4Q8OmgMgOo
MgMgoc8b<PGooooo000Yooooo`03o`000?oooooooooo0?oooooo<oooool2o`0000;ooooo0_l00004
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00GoV9RHo`000?l0003oA4A4
okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Co410@o`000?m4
A4Coc<c<T_ooool002Gooooo0ol000000ol@413oooooooooo`1jooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool0
0onHV9So410@omgMg@2Aooooo`009oooool00ol@413o^[Zjooooo`1kooooo`03o`000?oooooooooo
01[ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ohN7QomEEEGooooo093ooooo000Woooo
o`03oiRHV?lb<S;ooooo07_ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05olc<c?lQ8B7o0000oeEEEOl00000TOooool002Oooooo00?ogMgM
o`000?nj^[X0Noooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000002ooo
ool01OlQ8B7oQhN7oooooonHV9So0000097ooooo000Wooooo`03oeEEEOmgMgOoA4A407Wooooo00?o
410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo0000097ooooo000Vooooo`05omgMgOl@413oooooob4Q8OoMgMd0N_ooool00ol0003o
ooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OlQ8B7oV9RHoooooomgMgOo
EEEE097ooooo000Vooooo`05ofIVI_n7QhOooooooiRHV?mEEED0N_ooool00ol0003oooooooooo`0J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo<c<co410@o`000?lb<S;ok^k^097ooooo
000Uooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool0oooooollooooo`009Oooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo0?oooooo>oooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -20 0 ]
[.5 .63053 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .29653 L
.08481 .28274 L
.12636 .27001 L
.16632 .25762 L
.20885 .24441 L
.2498 .23192 L
.29331 .21832 L
.33524 .20538 L
.37557 .19311 L
.41848 .17946 L
.4598 .16704 L
.47044 .1632 L
.48055 .1598 L
.48494 .15858 L
.48962 .15757 L
.49232 .15713 L
.49476 .15685 L
.49594 .15675 L
.49722 .15667 L
.49842 .15662 L
.49953 .1566 L
.50071 .1566 L
.50197 .15663 L
.50317 .15669 L
.50425 .15676 L
.50553 .15688 L
.50692 .15703 L
.50944 .1574 L
.51208 .1579 L
.51488 .15854 L
.51991 .15993 L
.54183 .16761 L
.58147 .17945 L
.62368 .19288 L
.6643 .20524 L
.7075 .21856 L
.74911 .23158 L
.78912 .24377 L
.83171 .25703 L
.87271 .26972 L
.91628 .28307 L
.95826 .29617 L
.99865 .30859 L
1 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo08kooooo2?l0002Voooo
o`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo08_ooooo0ol00008ooooo`Go0000XOooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0R?ooool3
o`00013ooooo0ol0002Nooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`24ooooo`Co00005_ooool3o`0009_ooooo000>oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l00022ooooo`?o00007Oooool3
o`0009Sooooo000Yooooo`03o`000?oooooooooo07kooooo0ol0000Sooooo`?o0000UOooool002Wo
oooo00?o0000ooooooooool0Noooool3o`0002Wooooo0ol0002Booooo`00:Oooool00ol0003ooooo
ooooo`1hooooo`?o0000;oooool3o`0008oooooo000Yooooo`03o`000?oooooooooo07Gooooo0ol0
000eooooo`?o0000S?ooool002Wooooo0_l0001cooooo`?o0000>oooool3o`0008Wooooo000Yoooo
o`03o`000?oooooooooo06oooooo0ol00011ooooo`?o0000Q_ooool002Wooooo00?o0000oooooooo
ool0K?ooool3o`0004Oooooo0ol00023ooooo`00:Oooool00ol0003oooooooooo`1Yooooo`?o0000
COooool5o`0007kooooo000Yooooo`;o0000Ioooool3o`0005Gooooo1?l0001jooooo`00:Oooool0
0ol0003oooooooooo`1Sooooo`?o0000G?ooool4o`0007Kooooo000Yooooo`03o`000?oooooooooo
05oooooo1?l0001Sooooo`?o0000Loooool002Wooooo00?o0000ooooooooool0F_ooool5o`0006[o
oooo0ol0001`ooooo`00:Oooool00ol0003oooooooooo`1Fooooo`Co0000L_ooool3o`0006gooooo
000Yooooo`;o0000Doooool4o`0007Wooooo0ol0001Zooooo`00:Oooool00ol0003oooooooooo`1?
ooooo`?o0000P?ooool3o`0006Oooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`1<ooooo`?o0000Q_ooool3o`0006Cooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0BOooool3o`0008cooooo0ol0001Qooooo`001?l00002ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo
0ol00016ooooo`?o0000T_ooool4o`0005gooooo0006ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
@oooool3o`0009Wooooo0ol0001Jooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0@?ooool3o`0009oooooo0ol0001Gooooo`001_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03go
oooo0ol0002Uooooo`?o0000E?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03Wooooo1?l0002[ooooo`?o0000DOooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000gooooo`?o0000/_ooool3
o`0004kooooo000Yooooo`03o`000?oooooooooo03?ooooo0ol0002hooooo`?o0000Boooool002Wo
oooo00?o0000ooooooooool0<?ooool3o`000;kooooo0ol00018ooooo`00:Oooool00ol0003ooooo
ooooo`0]ooooo`?o0000a?ooool3o`0004Gooooo000Yooooo`03o`000?oooooooooo02[ooooo0ol0
003:ooooo`?o0000@_ooool002Wooooo0_l0000Xooooo`?o0000d?ooool3o`0003oooooo000Yoooo
o`03o`000?oooooooooo02Cooooo0ol00006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c008ooooo`?o00009Oooool4o`000003oa0@4?oooooo
oooo013ooooo000Yooooo`03o`000?oooooooooo027ooooo0ol00009ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Wooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B409oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402ooo
ool4o`0002?ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool07_ooool3
o`0000cooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02Sooooo00Go
410@oooooooooooooooooa0@400;ooooo`Go00009_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`00000Wooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000000oooooo0ol0000Pooooo`03o`000?oooooooooo01;ooooo000Y
ooooo`;o00007?ooool3o`0000oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002Oo
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Booooo`?o0000
7Oooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0Hooooo`?o00004_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool09_ooool01Ol0003ooooo
oooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00009oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Wooooo`05o`000?ooooooooooooooool00000
2oooool01Oo<c<co0000o`000?l0003oc<c<01Gooooo0ol0000Jooooo`03o`000?oooooooooo01;o
oooo000Yooooo`03o`000?oooooooooo01Cooooo1?l0000Eooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`0Uooooo`05oa0@4?ooooooooooooooool@41003?ooool00omg
MgOoc<c<o`00000Wooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Y
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01Sooooo
1?l0000Fooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo017ooooo0ol0
000Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooookZj^_l000007?ooool3o`0001?ooooo00?o0000ooooooooool0
4_ooool002Wooooo00?o0000ooooooooool03_ooool3o`0001cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool09_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@9oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0Oooooo`?o00003_ooool00omEEEGoIVIVo`00000Dooooo`00:Oooool2o`0000cooooo
0ol0003oooooo`[ooooo0ol0000Rooooo`00:Oooool00ol0003oooooooooo`07ooooo`Co0000oooo
ool@ooooo`?o00007oooool002Wooooo00?o0000ooooooooool00oooool4o`000?oooooo5oooool4
o`00017ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000ooooool000000ol0003ooooo
oaoooooo1?l0000=ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool002Woooooool0000/
o`0000_ooooo00CogMgMo`000?l@413oc<c<1Oooool002Wooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Cok^k^ob4Q8Ol@413ok^k^1Ooo
ool002Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Oooool002Wooooo00?o0000ooooooooool0oooooolc
ooooo`;o00000_ooool2o`0000Cooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolm
ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
3_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`?o0000oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Q
ooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEE
ofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00ZOoo
ool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q
U_ooool002Gooooo0ol000000ol@413oooooooooo`1nooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
2Oooool6o`0000cooooo00?o0000ooooooooool01?ooool2ob4Q8IKooooo000Wooooo`03oa0@4?nj
^[[ooooo07oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2Looooo`009oooool0
0onHV9So<S8booooo`1oooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooo
oooo09cooooo000Wooooo`03omgMgOl0003o^[Zj07oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`2Looooo`009oooool00omEEEGoMgMgodA4A01mooooo`03oa0@4?l0003o000000?o
00007?ooool00ol0003oooooooooo`2Looooo`009_ooool01OoMgMgo410@oooooolQ8B7ogMgM07ko
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2Looooo`009_ooool01OmVIVKoQhN7
oooooonHV9SoEEEE07kooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`00002Nooooo`00
9Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo0?oooooo??ooool002Gooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`3ooooooc_ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .29643 L
.08481 .28288 L
.12636 .26992 L
.16632 .25762 L
.20885 .24455 L
.2498 .23171 L
.29331 .21845 L
.33524 .2055 L
.37557 .19258 L
.38633 .18934 L
.39159 .18804 L
.3964 .18705 L
.40147 .18625 L
.40426 .18591 L
.40691 .18565 L
.40978 .18543 L
.41244 .18528 L
.41398 .18522 L
.41537 .18518 L
.41614 .18516 L
.41697 .18514 L
.41775 .18513 L
.41848 .18512 L
.41979 .18511 L
.42098 .1851 L
.42225 .18511 L
.42298 .18511 L
.42365 .18511 L
.42476 .18513 L
.42598 .18514 L
.42846 .18518 L
.43942 .1854 L
.44209 .18545 L
.44491 .18548 L
.44638 .1855 L
.448 .18551 L
.44871 .18551 L
.44946 .18552 L
.45083 .18552 L
.45221 .18553 L
.45299 .18553 L
.45371 .18553 L
.45504 .18553 L
.4557 .18553 L
.45644 .18552 L
.45771 .18552 L
.45907 .18551 L
.46154 .1855 L
.47217 .18543 L
Mistroke
.47509 .18541 L
.47819 .1854 L
.48112 .18538 L
.48377 .18538 L
.4851 .18538 L
.4865 .18537 L
.48769 .18537 L
.489 .18537 L
.49041 .18537 L
.4912 .18537 L
.49192 .18537 L
.49259 .18537 L
.49332 .18537 L
.49465 .18537 L
.49587 .18537 L
.49723 .18537 L
.49791 .18537 L
.49864 .18537 L
.49996 .18537 L
.50121 .18537 L
.50253 .18537 L
.50365 .18537 L
.50488 .18537 L
.50555 .18537 L
.50627 .18537 L
.50755 .18537 L
.50893 .18537 L
.50971 .18537 L
.51045 .18537 L
.51177 .18537 L
.51298 .18537 L
.51437 .18537 L
.51569 .18538 L
.51813 .18538 L
.52039 .18539 L
.52287 .1854 L
.52551 .18541 L
.5361 .18548 L
.539 .1855 L
.54058 .18551 L
.54206 .18552 L
.54332 .18552 L
.54466 .18553 L
.54543 .18553 L
.54616 .18553 L
.54752 .18553 L
.5487 .18553 L
.54999 .18552 L
.55135 .18551 L
.55262 .18551 L
Mistroke
.55488 .18549 L
.55732 .18545 L
.56287 .18536 L
.56794 .18525 L
.57265 .18516 L
.57393 .18514 L
.57531 .18513 L
.5766 .18511 L
.57778 .18511 L
.57898 .1851 L
.58009 .18511 L
.58131 .18511 L
.58259 .18513 L
.58371 .18515 L
.58475 .18518 L
.58713 .18526 L
.58845 .18532 L
.58986 .1854 L
.59239 .18559 L
.59511 .18584 L
.59811 .18619 L
.60348 .18703 L
.60851 .18806 L
.61789 .19054 L
.628 .19377 L
.67122 .20738 L
.71284 .2204 L
.75288 .23254 L
.79549 .24587 L
.83651 .25852 L
.8801 .27189 L
.9221 .28501 L
.96251 .2974 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`1jooooo`;o0000;?ooool3o`00097ooooo000Yooooo`;o0000L_ooool9o`000003ooooool0003o
000002co000000?oooooo`000?l000002Ol00027ooooo`00:Oooool00ol0003oooooooooo`1_oooo
o`;o0000A?ooool3o`0008Cooooo000Yooooo`03o`000?oooooooooo06cooooo0ol00019ooooo`?o
0000POooool002Wooooo00?o0000ooooooooool0JOooool3o`0004oooooo0ol0001nooooo`00:Ooo
ool2o`0006Oooooo0ol0001Eooooo`?o0000Noooool002Wooooo00?o0000ooooooooool0Hoooool3
o`0005_ooooo0ol0001hooooo`00:Oooool00ol0003oooooooooo`1Oooooo`Co0000HOooool4o`00
07Cooooo000Yooooo`03o`000?oooooooooo05[ooooo1Ol0001Yooooo`?o0000LOooool002Wooooo
00?o0000ooooooooool0E_ooool4o`00077ooooo0ol0001^ooooo`00:Oooool2o`0005?ooooo1?l0
001hooooo`?o0000Joooool002Wooooo00?o0000ooooooooool0Coooool3o`0007oooooo0ol0001X
ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0C?ooool3o`0008Gooooo0ol0
001Uooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Wooooo
0ol0002;ooooo`?o0000H_ooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000A_ooool3o`00097ooooo
0ol0001Oooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04?ooooo0ol0002Gooooo`?o0000
G?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo043ooooo0ol0002Mooooo`?o
0000FOooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`?o0000Xoooool3o`0005Ko
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0iooooo`Co0000ZOooool3o`00
05?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`;o0000=oooool3o`000;3ooooo1?l0001?ooooo`00:Oooool00ol0
003oooooooooo`0cooooo`?o0000]oooool4o`0004_ooooo000Yooooo`03o`000?oooooooooo033o
oooo0ol0002nooooo`Co0000Aoooool002Wooooo00?o0000ooooooooool0;Oooool3o`000<Gooooo
1?l00013ooooo`00:Oooool00ol0003oooooooooo`0Zooooo`?o0000c?ooool3o`00043ooooo000Y
ooooo`;o0000:?ooool3o`000=;ooooo0ol0000mooooo`00:Oooool00ol0003oooooooooo`0Toooo
o`?o00001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00009oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool09?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`09oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`02_ooool3o`0002?ooooo1?l000000ol@413oooooooooo`0@ooooo`00:Oooool00ol0
003oooooooooo`0Qooooo`?o00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00gooooo1?l0000Qooooo`03o`000?oo
oooooooo01;ooooo000Yooooo`03o`000?oooooooooo01kooooo0ol0000<ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Xooooo`05oa0@4?ooooooooooooooool@4100
2oooool5o`0002Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000009oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
000Aooooo`?o00007_ooool00ol0003oooooooooo`0Booooo`00:Oooool2o`0001cooooo0ol0000?
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Wooooo`05o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool0000Wooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q02Oooooo00Go0000ooooooooooooooooo`00
000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S805?ooool3o`0001_ooooo00?o0000ooooooooool0
4_ooool002Wooooo00?o0000ooooooooool06?ooool3o`0001;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`09oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c00Gooooo`?o00006?ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooo
ooooo`0Dooooo`Co00005Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool09Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000009oooool01Ol@
413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0:Oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Jooooo`?o00005Oooool00ol0003ooooo
ooooo`0Booooo`00:Oooool00ol0003oooooooooo`0Aooooo`?o00006Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Wooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00oo^k^koA4A4o`00000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV00Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonj^[[o000001gooooo0ol0000Booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oo
oooooooo00kooooo0ol0000Looooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo
02Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT08?ooool3o`0000go
oooo00?oEEEEofIVI_l000005?ooool002Wooooo0_l0000<ooooo`?o0000ooooool;ooooo`?o0000
8Oooool002Wooooo00?o0000ooooooooool01oooool4o`000?oooooo4Oooool3o`0001kooooo000Y
ooooo`03o`000?oooooooooo00?ooooo1?l0003ooooooaSooooo1?l0000@ooooo`;o00000_ooool2
o`0000Cooooo000Yooooo`03o`000?oooooo000000?o0000oooooolPooooo`Co00003?ooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Yoooooooo0000;?l0000;ooooo`04omgMgOl0003o
410@olc<c0Gooooo000Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`09ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Yooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`04ob4Q8OmgMgOo
MgMgoc8b<PGooooo000Yooooo`03o`000?oooooooooo0?oooooo<oooool2o`0000;ooooo0_l00004
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00GoV9RHo`000?l0003oA4A4
okZj^P0Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo1?l000000ol@413ooooo
ooooo`2>ooooo`009Oooool3o`000003oa0@4?oooooooooo07[ooooo00Go410@okZj^_o^k^koMgMg
oa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`2@ooooo`009oooool00ol@413o^[Zjooooo`1kooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`2@ooooo`009oooool00onHV9So<S8booooo`1k
ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0T?ooool002Oooooo00?ogMgMo`000?nj^[X0Noooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0T?ooool002Oooooo00?oEEEEogMgMom4
A4@0NOooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`2@ooooo`009_ooool01OoMgMgo410@oooooolQ8B7ogMgM07[ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo093ooooo000Vooooo`05ofIV
I_n7QhOooooooiRHV?mEEED0N_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000go
oooo00?oEEEEofIVI_l00000T_ooool002Gooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgM
ooooo`3ooooooccooooo000Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
oooooolkooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .29654 L
.08481 .28272 L
.12636 .27003 L
.16632 .25763 L
.20885 .24435 L
.2498 .23205 L
.27066 .22514 L
.28166 .22159 L
.28768 .21991 L
.29331 .21857 L
.29831 .21762 L
.30369 .21686 L
.30675 .21654 L
.30965 .21632 L
.31226 .21617 L
.31374 .2161 L
.31511 .21606 L
.31638 .21603 L
.31774 .216 L
.31903 .21599 L
.32022 .21598 L
.3213 .21598 L
.32247 .21599 L
.32371 .216 L
.32485 .21601 L
.32748 .21606 L
.32987 .21611 L
.33524 .21624 L
.34029 .21634 L
.34284 .21639 L
.3443 .21641 L
.34565 .21643 L
.34679 .21644 L
.34804 .21645 L
.34929 .21646 L
.35062 .21646 L
.35178 .21646 L
.35303 .21646 L
.35421 .21646 L
.35528 .21646 L
.35664 .21645 L
.35808 .21644 L
.36066 .21642 L
.36649 .21636 L
.37202 .2163 L
.37465 .21627 L
.37708 .21625 L
.37951 .21624 L
.38079 .21624 L
Mistroke
.38216 .21623 L
.38346 .21623 L
.38469 .21623 L
.38579 .21623 L
.38699 .21623 L
.38827 .21623 L
.389 .21623 L
.38968 .21623 L
.39253 .21625 L
.39763 .21627 L
.4021 .2163 L
.40685 .21633 L
.40932 .21634 L
.41064 .21635 L
.41205 .21635 L
.41335 .21635 L
.41453 .21636 L
.41567 .21636 L
.41686 .21636 L
.41818 .21636 L
.41891 .21636 L
.41958 .21636 L
.42089 .21636 L
.42212 .21636 L
.42355 .21636 L
.42488 .21635 L
.42786 .21635 L
.43282 .21633 L
.43827 .21631 L
.44063 .2163 L
.44317 .2163 L
.44556 .21629 L
.44662 .21629 L
.44775 .21629 L
.44903 .21629 L
.45021 .21629 L
.45148 .21629 L
.45221 .21629 L
.45289 .21629 L
.45411 .21629 L
.45524 .21629 L
.45647 .21629 L
.45777 .21629 L
.46853 .2163 L
.47382 .21631 L
.47615 .21631 L
.47871 .21632 L
.481 .21632 L
.48314 .21632 L
.4854 .21632 L
Mistroke
.48668 .21632 L
.48784 .21632 L
.4891 .21632 L
.49027 .21632 L
.49155 .21632 L
.49292 .21632 L
.49422 .21632 L
.49545 .21632 L
.49656 .21632 L
.49775 .21632 L
.49903 .21632 L
.50023 .21632 L
.50155 .21632 L
.50229 .21632 L
.50296 .21632 L
.50431 .21632 L
.50508 .21632 L
.50578 .21632 L
.50708 .21632 L
.50846 .21632 L
.50962 .21632 L
.51088 .21632 L
.51206 .21632 L
.51315 .21632 L
.51435 .21632 L
.51566 .21632 L
.51831 .21632 L
.5198 .21632 L
.5212 .21632 L
.52382 .21631 L
.52971 .21631 L
.53475 .2163 L
.53743 .21629 L
.5403 .21629 L
.54172 .21629 L
.54306 .21629 L
.54427 .21629 L
.54558 .21629 L
.54682 .21629 L
.54815 .21629 L
.54939 .21629 L
.55052 .21629 L
.5512 .21629 L
.55192 .21629 L
.5532 .21629 L
.55609 .21629 L
.55859 .2163 L
.56133 .21631 L
.56611 .21632 L
.57129 .21634 L
Mistroke
.57367 .21635 L
.57497 .21635 L
.57619 .21636 L
.57731 .21636 L
.57834 .21636 L
.57948 .21636 L
.58071 .21636 L
.58208 .21636 L
.58335 .21636 L
.58408 .21636 L
.58474 .21636 L
.58623 .21636 L
.58752 .21635 L
.58892 .21635 L
.59147 .21634 L
.59656 .21631 L
.60125 .21628 L
.60392 .21626 L
.60678 .21625 L
.60817 .21624 L
.60948 .21624 L
.61067 .21623 L
.61194 .21623 L
.61328 .21623 L
.61452 .21623 L
.61585 .21623 L
.61661 .21623 L
.61732 .21623 L
.61805 .21623 L
.61881 .21623 L
.62017 .21624 L
.62163 .21625 L
.62323 .21626 L
.62878 .21631 L
.63402 .21636 L
.63878 .21641 L
.64138 .21644 L
.64265 .21645 L
.64382 .21645 L
.64508 .21646 L
.64643 .21646 L
.64713 .21646 L
.6479 .21646 L
.64863 .21646 L
.64931 .21646 L
.65059 .21646 L
.65176 .21645 L
.6531 .21644 L
.65437 .21643 L
.65723 .21639 L
Mistroke
.65987 .21634 L
.66581 .21621 L
.67076 .21609 L
.67348 .21604 L
.67482 .21602 L
.67605 .216 L
.67722 .21599 L
.67845 .21598 L
.67969 .21598 L
.68105 .21599 L
.68218 .216 L
.6834 .21602 L
.68455 .21605 L
.68561 .21608 L
.68687 .21613 L
.68823 .21619 L
.69066 .21634 L
.69356 .21657 L
.69619 .21685 L
.70191 .21766 L
.70731 .21871 L
.71754 .22135 L
.72836 .22481 L
.74775 .23127 L
.78757 .24322 L
.82997 .25652 L
.87077 .26912 L
.91416 .2824 L
.95595 .29548 L
.99615 .3078 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`0005CoooooO?l0
001]ooooo`00:Oooool00ol0003oooooooooo`1?ooooo`Co0000O?ooool6o`0006Oooooo0006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1<ooooo`?o0000Q_ooool3o`0006Cooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0BOooool3o`0008cooooo
0ol0001Qooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol00016ooooo`?o0000T_ooool3o`0005kooooo
0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0@oooool3o`0009Sooooo0ol0001Kooooo`001_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0@?ooool3o`0009kooooo0ol0001Hooooo`00
1_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03gooooo0ol0002Tooooo`?o0000EOooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo1?l0002Zooooo`?o0000D_ooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4
o`0000Kooooo0_l0000gooooo`?o0000/Oooool3o`0004oooooo000Yooooo`03o`000?oooooooooo
03?ooooo0ol0002gooooo`?o0000C?ooool002Wooooo00?o0000ooooooooool0<?ooool3o`000;go
oooo0ol00019ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`?o0000`oooool4o`0004Gooooo
000Yooooo`03o`000?oooooooooo02[ooooo0ol0003:ooooo`?o0000@_ooool002Wooooo0_l0000X
ooooo`?o0000d?ooool3o`0003oooooo000Yooooo`03o`000?oooooooooo02Cooooo0ol00006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c008
ooooo`?o00009Oooool4o`000003oa0@4?oooooooooo013ooooo000Yooooo`03o`000?oooooooooo
027ooooo0ol00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool09Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B409oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402oooool3o`0002Cooooo00?o0000ooooooooool04_oo
ool002Wooooo00?o0000ooooooooool07_ooool3o`0000cooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^02Sooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
9_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Woooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000kooooo1Ol0
000Oooooo`03o`000?oooooooooo01;ooooo000Yooooo`;o00007?ooool3o`0000oooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P0Cooooo`Co00006oooool00ol0003oooooooooo`0Booooo`00:Ooo
ool00ol0003oooooooooo`0Hooooo`?o00004_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool09_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo00009oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<
c00Wooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<01Oo
oooo1?l0000Gooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo01Cooooo
1?l0000Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Uooooo`05
oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool00omEEEGoQhN7ooooo`0Yooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol@413o^[Zjoooooonj^[[o410@01_ooooo0ol0000Dooooo`03o`000?oooooooooo01;ooooo
000Yooooo`03o`000?oooooooooo017ooooo0ol0000Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413o
V9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000
7_ooool3o`00017ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool03_oo
ool3o`0001cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`09oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool09_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@9oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Qooooo`?o00003?ooool00omEEEGo
IVIVo`00000Dooooo`00:Oooool2o`0000cooooo0ol0003oooooo`cooooo0ol0000Pooooo`00:Ooo
ool00ol0003oooooooooo`07ooooo`Co0000oooooolBooooo`?o00007Oooool002Wooooo00?o0000
ooooooooool00oooool4o`000?oooooo6Oooool3o`00013ooooo0_l00002ooooo`;o00001?ooool0
02Wooooo00?o0000ooooool000000ol0003oooooob3ooooo0ol0000=ooooo`06onk^k_lQ8B7oQhN7
okZj^_l0003ogMgM1?ooool002Woooooool0000/o`0000_ooooo00CogMgMo`000?l@413oc<c<1Ooo
ool002Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Wooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool002Wooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Ooo
ool002Wooooo00?o0000ooooooooool0oooooolcooooo`;o00000_ooool2o`0000Cooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`003_ooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@
400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003o
ooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00YOooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`00097ooooo000Uooooo`?o000000?o
410@ooooooooool0N_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0TOooool002Oooooo
00?o410@okZj^_ooool0Noooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h0T_ooool002Oooooo00?oV9RHoc8b<_ooool0Noooool00ol0003ooooooooo
o`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^097ooooo000W
ooooo`03omgMgOl0003o^[Zj07_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=
ooooo`03ogMgMomVIVKooooo093ooooo000Wooooo`03oeEEEOmgMgOoA4A407Wooooo00?o410@o`00
0?l000000ol0000Looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Soooool002Ko
oooo00GogMgMoa0@4?oooooo8B4QomgMg@1jooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@097ooooo000Vooooo`05ofIVI_n7QhOooooo
oiRHV?mEEED0N_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c02Aooooo`009Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgo
oooo0?oooooo??ooool002Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`3o
oooooc_ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .2964 L
.08481 .28294 L
.12636 .26989 L
.16632 .25751 L
.17777 .2537 L
.18859 .25057 L
.19331 .24947 L
.19831 .24853 L
.20092 .24812 L
.20379 .24775 L
.20621 .24749 L
.20885 .24727 L
.21027 .24718 L
.21158 .2471 L
.21294 .24704 L
.21417 .24699 L
.2153 .24695 L
.21653 .24692 L
.21782 .2469 L
.21904 .24689 L
.22036 .24688 L
.22111 .24688 L
.22181 .24689 L
.22255 .24689 L
.22323 .2469 L
.22474 .24691 L
.22603 .24693 L
.22744 .24696 L
.22999 .24701 L
.23491 .24713 L
.24021 .24725 L
.24264 .24729 L
.24521 .24733 L
.2474 .24735 L
.24864 .24736 L
.2498 .24736 L
.25108 .24737 L
.2523 .24737 L
.25339 .24737 L
.25457 .24736 L
.25586 .24736 L
.25722 .24735 L
.25966 .24733 L
.26529 .24727 L
.27056 .24721 L
.27562 .24716 L
.27708 .24715 L
.27846 .24714 L
.27983 .24713 L
Mistroke
.28106 .24713 L
.28173 .24713 L
.28245 .24713 L
.28321 .24712 L
.28393 .24712 L
.28532 .24712 L
.28659 .24712 L
.28731 .24713 L
.28799 .24713 L
.28952 .24713 L
.29102 .24714 L
.29262 .24714 L
.30333 .24722 L
.30626 .24724 L
.30937 .24725 L
.31203 .24726 L
.31354 .24727 L
.31428 .24727 L
.31496 .24727 L
.3162 .24727 L
.31755 .24727 L
.31887 .24727 L
.31961 .24727 L
.32027 .24727 L
.32148 .24727 L
.32278 .24727 L
.32514 .24726 L
.32791 .24725 L
.33085 .24724 L
.3361 .24721 L
.33854 .2472 L
.3412 .24719 L
.34354 .24718 L
.34604 .24718 L
.34741 .24718 L
.34819 .24718 L
.34893 .24717 L
.35022 .24717 L
.35094 .24717 L
.35161 .24717 L
.35279 .24717 L
.35409 .24718 L
.35544 .24718 L
.35669 .24718 L
.3592 .24718 L
.36157 .24719 L
.36599 .2472 L
.37113 .24722 L
.37594 .24723 L
.37827 .24724 L
Mistroke
.37959 .24724 L
.38079 .24724 L
.3821 .24724 L
.38284 .24724 L
.38353 .24724 L
.38479 .24724 L
.38613 .24724 L
.38686 .24724 L
.38753 .24724 L
.38904 .24724 L
.39038 .24724 L
.39179 .24724 L
.39693 .24723 L
.40213 .24722 L
.40706 .24721 L
.4092 .2472 L
.41148 .2472 L
.41267 .2472 L
.41398 .2472 L
.41517 .2472 L
.41629 .2472 L
.41751 .2472 L
.41879 .2472 L
.41989 .2472 L
.42109 .2472 L
.42238 .2472 L
.42376 .2472 L
.42625 .2472 L
.43693 .24721 L
.43942 .24722 L
.44212 .24722 L
.44467 .24722 L
.44588 .24722 L
.44702 .24722 L
.44813 .24722 L
.44914 .24722 L
.45026 .24722 L
.45147 .24722 L
.45263 .24722 L
.45389 .24722 L
.45508 .24722 L
.45618 .24722 L
.46582 .24722 L
.47108 .24722 L
.47598 .24721 L
.47854 .24721 L
.48129 .24721 L
.48286 .24721 L
.48434 .24721 L
.48567 .24721 L
Mistroke
.48712 .24721 L
.48834 .24721 L
.4897 .24721 L
.49038 .24721 L
.49111 .24721 L
.49243 .24721 L
.49375 .24721 L
.495 .24721 L
.49612 .24721 L
.49735 .24721 L
.49808 .24721 L
.49887 .24721 L
.49962 .24721 L
.50031 .24721 L
.50162 .24721 L
.503 .24721 L
.50372 .24721 L
.50449 .24721 L
.50588 .24721 L
.50672 .24721 L
.50753 .24721 L
.50825 .24721 L
.50903 .24721 L
.51033 .24721 L
.51107 .24721 L
.51177 .24721 L
.51316 .24721 L
.51467 .24721 L
.516 .24721 L
.51739 .24721 L
.51989 .24721 L
.52242 .24721 L
.52513 .24721 L
.53001 .24722 L
.53577 .24722 L
.5383 .24722 L
.54108 .24722 L
.54238 .24722 L
.54378 .24722 L
.5451 .24722 L
.5463 .24722 L
.54766 .24722 L
.54843 .24722 L
.54914 .24722 L
.55044 .24722 L
.55183 .24722 L
.55335 .24722 L
.55498 .24722 L
.55795 .24722 L
.56349 .24721 L
Mistroke
.56885 .24721 L
.57178 .2472 L
.57451 .2472 L
.57684 .2472 L
.57815 .2472 L
.57934 .2472 L
.58065 .2472 L
.58138 .2472 L
.58207 .2472 L
.58332 .2472 L
.58464 .2472 L
.58584 .2472 L
.58715 .2472 L
.58979 .2472 L
.59223 .2472 L
.5945 .24721 L
.60007 .24722 L
.60512 .24723 L
.60741 .24723 L
.60862 .24724 L
.6099 .24724 L
.61102 .24724 L
.61225 .24724 L
.61336 .24724 L
.61441 .24724 L
.61569 .24724 L
.61691 .24724 L
.618 .24724 L
.61919 .24724 L
.62048 .24724 L
.62185 .24724 L
.62432 .24723 L
.63414 .2472 L
.6393 .24719 L
.64189 .24718 L
.64338 .24718 L
.64473 .24718 L
.64602 .24718 L
.64723 .24717 L
.64852 .24717 L
.64924 .24717 L
.64991 .24717 L
.65102 .24717 L
.65225 .24718 L
.65353 .24718 L
.65473 .24718 L
.65704 .24719 L
.65916 .24719 L
.66391 .24721 L
.66888 .24724 L
Mistroke
.67357 .24726 L
.67616 .24726 L
.67762 .24727 L
.67896 .24727 L
.6801 .24727 L
.68134 .24727 L
.68264 .24727 L
.68385 .24727 L
.68456 .24727 L
.68532 .24727 L
.6867 .24727 L
.68805 .24726 L
.6893 .24726 L
.69213 .24724 L
.69514 .24723 L
.70061 .24719 L
.70562 .24715 L
.7081 .24714 L
.71041 .24713 L
.71158 .24713 L
.71282 .24712 L
.7142 .24712 L
.71546 .24712 L
.71682 .24712 L
.71808 .24713 L
.71946 .24713 L
.72092 .24714 L
.72337 .24715 L
.72607 .24718 L
.73591 .24729 L
.73826 .24731 L
.74077 .24734 L
.74198 .24735 L
.74313 .24735 L
.74417 .24736 L
.74526 .24736 L
.74654 .24737 L
.74772 .24737 L
.74898 .24737 L
.75037 .24736 L
.7511 .24736 L
.75176 .24736 L
.75325 .24734 L
.75463 .24733 L
.75594 .24731 L
.76061 .24723 L
.76569 .24712 L
.77122 .24699 L
.77401 .24693 L
.7756 .24691 L
Mistroke
.77631 .2469 L
.77709 .24689 L
.77845 .24688 L
.77974 .24688 L
.781 .24689 L
.78217 .2469 L
.78355 .24693 L
.78481 .24696 L
.78626 .247 L
.78763 .24706 L
.79015 .2472 L
.79251 .24738 L
.79509 .24763 L
.79787 .24795 L
.80353 .24885 L
.80869 .24992 L
.82808 .25561 L
.86989 .26879 L
.91011 .28135 L
.95291 .29434 L
.99411 .30726 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000>?oooongo`0004kooooo000Yooooo`03o`000?oooooooooo03Cooooo0ol0002goooo
o`Co0000B_ooool002Wooooo00?o0000ooooooooool0<?ooool4o`000;kooooo1?l00016ooooo`00
:Oooool00ol0003oooooooooo`0]ooooo`?o0000a_ooool3o`0004?ooooo000Yooooo`03o`000?oo
oooooooo02[ooooo0ol0003<ooooo`?o0000@?ooool002Wooooo0_l0000Xooooo`?o0000d_ooool3
o`0003gooooo000Yooooo`03o`000?oooooooooo02Cooooo0ol00006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00:ooooo`Co00008_ooool4
o`000003oa0@4?oooooooooo013ooooo000Yooooo`03o`000?oooooooooo027ooooo0ol00009oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A00Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
9Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B409oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B403_ooool3o`00027ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool07_ooool3o`0000cooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^02Sooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00009_ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo0000017ooooo0ol0000Nooooo`03o`000?oo
oooooooo01;ooooo000Yooooo`;o00007?ooool3o`0000oooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4
A?oMgMgoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B409oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P0Dooooo`?o00006oooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooooooo
o`0Hooooo`?o00004_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00009oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Wooooo`05o`000?oo
ooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<01Oooooo0ol0000Hooooo`03
o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo01Cooooo1?l0000Eooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Uooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00omgMgOoc<c<o`00000Wooooo`05oa0@4?ooooooooooooooool@41002oooool0
0omEEEGoQhN7ooooo`0Yooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooo
oonj^[[o410@01[ooooo0ol0000Eooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oo
oooooooo017ooooo0ol0000Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000007Oooool3o`0001;ooooo
00?o0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool03_ooool3o`0001cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool09_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo00Coc<c<odA4A?l0003o410@9oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@0Pooooo`?o00003Oooool00omEEEGoIVIVo`00000Dooooo`00
:Oooool2o`0000cooooo0ol0003oooooo`_ooooo1?l0000Pooooo`00:Oooool00ol0003ooooooooo
o`07ooooo`Co0000oooooolBooooo`?o00007Oooool002Wooooo00?o0000ooooooooool00oooool4
o`000?oooooo6Oooool3o`00013ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000oooo
ool000000ol0003oooooob3ooooo0ol0000=ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?oo
ool002Woooooool0000/o`0000_ooooo00CogMgMo`000?l@413oc<c<1Oooool002Wooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Cok^k^
ob4Q8Ol@413ok^k^1Oooool002Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Oooool002Wooooo00?o0000
ooooooooool0oooooolcooooo`;o00000_ooool2o`0000Cooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`03ooooo`?o0000oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00YOooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<097ooooo000Uooooo`?o0000
00?o410@ooooooooool0N_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S80TOooool002Oo
oooo00?o410@okZj^_ooool0Noooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0Soooool002Oooooo00?oV9RHoc8b<_ooool0Noooool00ol0003ooooo
ooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOl@413ooooo093ooooo
000Wooooo`03omgMgOl0003o^[Zj07_ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0<ooooo`03oa0@4?l0003o^[Zj097ooooo000Wooooo`03oeEEEOmgMgOoA4A407Wooooo00?o410@
o`000?l000000ol0000Looooo`03o`000?oooooooooo00gooooo00?o^[Zjob4Q8Oooool0T?ooool0
02Kooooo00GogMgMoa0@4?oooooo8B4QomgMg@1jooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool02_ooool01Ol@413oV9RHoooooonj^[[o0000097ooooo000Vooooo`05ofIVI_n7QhOo
oooooiRHV?mEEED0N_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000cooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@2Aooooo`009Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oM
gMgooooo0?oooooo??ooool002Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooooooo
o`3ooooooc_ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .29667 L
.06168 .29001 L
.07286 .28619 L
.08481 .28245 L
.0906 .28096 L
.09607 .27981 L
.10099 .27901 L
.10352 .27869 L
.10632 .27839 L
.10893 .27818 L
.11138 .27803 L
.1127 .27796 L
.11396 .27792 L
.11541 .27787 L
.11674 .27784 L
.11789 .27782 L
.11912 .27781 L
.12029 .2778 L
.12134 .2778 L
.12258 .27781 L
.12392 .27782 L
.12519 .27784 L
.12636 .27785 L
.1359 .27806 L
.13841 .27811 L
.14115 .27816 L
.14356 .2782 L
.14613 .27823 L
.14757 .27824 L
.14834 .27824 L
.14917 .27825 L
.14993 .27825 L
.15063 .27825 L
.15199 .27826 L
.15324 .27826 L
.1546 .27825 L
.15529 .27825 L
.15602 .27825 L
.15735 .27824 L
.16017 .27822 L
.16283 .27819 L
.16782 .27814 L
.17309 .27809 L
.17567 .27807 L
.17803 .27805 L
.17922 .27805 L
.18051 .27804 L
.18188 .27804 L
.18317 .27804 L
Mistroke
.18392 .27803 L
.1846 .27803 L
.18538 .27803 L
.18611 .27803 L
.18742 .27804 L
.18816 .27804 L
.18884 .27804 L
.19116 .27805 L
.19333 .27806 L
.19826 .27809 L
.20343 .27812 L
.20821 .27814 L
.21077 .27815 L
.21208 .27816 L
.21348 .27816 L
.21422 .27816 L
.21489 .27817 L
.21621 .27817 L
.21691 .27817 L
.21767 .27817 L
.21847 .27817 L
.21921 .27817 L
.22057 .27817 L
.22185 .27816 L
.223 .27816 L
.22425 .27816 L
.22962 .27814 L
.23449 .27812 L
.2397 .2781 L
.24223 .27809 L
.24463 .27809 L
.24567 .27808 L
.24678 .27808 L
.24799 .27808 L
.24912 .27808 L
.25029 .27808 L
.25156 .27808 L
.25276 .27808 L
.25385 .27808 L
.25507 .27808 L
.2564 .27808 L
.25908 .27809 L
.26475 .2781 L
.27003 .27812 L
.27291 .27813 L
.27563 .27813 L
.27807 .27814 L
.27944 .27814 L
.28071 .27814 L
.28208 .27814 L
Mistroke
.28336 .27814 L
.28409 .27814 L
.28476 .27814 L
.28553 .27814 L
.28626 .27814 L
.28697 .27814 L
.28772 .27814 L
.28907 .27814 L
.29068 .27814 L
.29214 .27813 L
.30198 .27812 L
.30457 .27811 L
.30735 .27811 L
.30992 .2781 L
.31236 .2781 L
.31373 .2781 L
.31449 .2781 L
.31521 .2781 L
.31646 .2781 L
.3178 .2781 L
.3185 .2781 L
.31926 .2781 L
.32063 .2781 L
.32142 .2781 L
.32226 .2781 L
.32375 .2781 L
.32635 .2781 L
.32876 .27811 L
.33423 .27811 L
.33954 .27812 L
.34233 .27812 L
.34386 .27813 L
.34529 .27813 L
.34654 .27813 L
.34788 .27813 L
.34864 .27813 L
.34936 .27813 L
.35072 .27813 L
.35196 .27813 L
.35312 .27813 L
.35438 .27813 L
.35573 .27813 L
.35827 .27813 L
.36101 .27812 L
.36597 .27812 L
.37045 .27811 L
.37525 .27811 L
.37664 .27811 L
.37796 .27811 L
.37925 .27811 L
Mistroke
.38043 .27811 L
.38156 .27811 L
.38275 .27811 L
.38395 .27811 L
.38527 .27811 L
.386 .27811 L
.38669 .27811 L
.38799 .27811 L
.38872 .27811 L
.3894 .27811 L
.39093 .27811 L
.39624 .27811 L
.40171 .27811 L
.40459 .27812 L
.40764 .27812 L
.4103 .27812 L
.41172 .27812 L
.41323 .27812 L
.41394 .27812 L
.41462 .27812 L
.41589 .27812 L
.41708 .27812 L
.41838 .27812 L
.41971 .27812 L
.42095 .27812 L
.42232 .27812 L
.4238 .27812 L
.42681 .27812 L
.42956 .27812 L
.43451 .27812 L
.43992 .27811 L
.4423 .27811 L
.44484 .27811 L
.44608 .27811 L
.44725 .27811 L
.44829 .27811 L
.44943 .27811 L
.45064 .27811 L
.45196 .27811 L
.45335 .27811 L
.45464 .27811 L
.45585 .27811 L
.45696 .27811 L
.45945 .27811 L
.46994 .27811 L
.4727 .27812 L
.47569 .27812 L
.47827 .27812 L
.4811 .27812 L
.48378 .27812 L
Mistroke
.48523 .27812 L
.48659 .27812 L
.48787 .27812 L
.48903 .27812 L
.49037 .27812 L
.49164 .27812 L
.49279 .27812 L
.49402 .27812 L
.49506 .27812 L
.49622 .27812 L
.49745 .27812 L
.49878 .27812 L
.50004 .27812 L
.50119 .27812 L
.50242 .27812 L
.50353 .27812 L
.50482 .27812 L
.50603 .27812 L
.50716 .27812 L
.50819 .27812 L
.50933 .27812 L
.51054 .27812 L
.51175 .27812 L
.51305 .27812 L
.51428 .27812 L
.5154 .27812 L
.51815 .27812 L
.52075 .27812 L
.52323 .27812 L
.52587 .27812 L
.5306 .27811 L
.5362 .27811 L
.53865 .27811 L
.54133 .27811 L
.54253 .27811 L
.54381 .27811 L
.54501 .27811 L
.54611 .27811 L
.54735 .27811 L
.5487 .27811 L
.54997 .27811 L
.55115 .27811 L
.55241 .27811 L
.55359 .27811 L
.55629 .27811 L
.55892 .27811 L
.56174 .27811 L
.56656 .27812 L
.57169 .27812 L
.57418 .27812 L
Mistroke
.57541 .27812 L
.57653 .27812 L
.57754 .27812 L
.57864 .27812 L
.57975 .27812 L
.58092 .27812 L
.58231 .27812 L
.58357 .27812 L
.58427 .27812 L
.58503 .27812 L
.58641 .27812 L
.5877 .27812 L
.58907 .27812 L
.59154 .27812 L
.59704 .27812 L
.60312 .27811 L
.60567 .27811 L
.60836 .27811 L
.60976 .27811 L
.6113 .27811 L
.61198 .27811 L
.6127 .27811 L
.614 .27811 L
.61532 .27811 L
.61607 .27811 L
.61675 .27811 L
.61802 .27811 L
.61935 .27811 L
.62055 .27811 L
.62167 .27811 L
.62422 .27811 L
.63515 .27812 L
.63776 .27812 L
.64053 .27813 L
.64188 .27813 L
.64315 .27813 L
.64431 .27813 L
.64552 .27813 L
.64664 .27813 L
.64786 .27813 L
.64897 .27813 L
.65 .27813 L
.65122 .27813 L
.65234 .27813 L
.65362 .27813 L
.65484 .27813 L
.65737 .27812 L
.6597 .27812 L
.66499 .27811 L
.66987 .27811 L
Mistroke
.67257 .2781 L
.67513 .2781 L
.6775 .2781 L
.67884 .2781 L
.68009 .2781 L
.68124 .2781 L
.68229 .2781 L
.68349 .2781 L
.68463 .2781 L
.68589 .2781 L
.68726 .2781 L
.6887 .2781 L
.69005 .2781 L
.69503 .27811 L
.70042 .27812 L
.70326 .27813 L
.70628 .27813 L
.70899 .27814 L
.71053 .27814 L
.71123 .27814 L
.71197 .27814 L
.7133 .27814 L
.71451 .27814 L
.71581 .27814 L
.71655 .27814 L
.71724 .27814 L
.71859 .27814 L
.71987 .27814 L
.72102 .27814 L
.72226 .27814 L
.72506 .27813 L
.72763 .27812 L
.73702 .2781 L
.73972 .27809 L
.74229 .27809 L
.74341 .27808 L
.7446 .27808 L
.7459 .27808 L
.74711 .27808 L
.74843 .27808 L
.74917 .27808 L
.74986 .27808 L
.75112 .27808 L
.75244 .27808 L
.75364 .27808 L
.75475 .27809 L
.75728 .27809 L
.76187 .27811 L
.76679 .27813 L
.76958 .27814 L
Mistroke
.77262 .27815 L
.77529 .27816 L
.77675 .27816 L
.77813 .27816 L
.77936 .27817 L
.78068 .27817 L
.7814 .27817 L
.78215 .27817 L
.7835 .27817 L
.78472 .27817 L
.78587 .27816 L
.78712 .27816 L
.78846 .27816 L
.79118 .27815 L
.79406 .27813 L
.79923 .2781 L
.80526 .27806 L
.8082 .27805 L
.80949 .27804 L
.81089 .27804 L
.81219 .27804 L
.81339 .27804 L
.81453 .27803 L
.81576 .27803 L
.81643 .27804 L
.81717 .27804 L
.8185 .27804 L
.81979 .27804 L
.82098 .27805 L
.82355 .27806 L
.82637 .27809 L
.83206 .27814 L
.83759 .2782 L
.84031 .27822 L
.8415 .27823 L
.84282 .27824 L
.84391 .27825 L
.84509 .27825 L
.84634 .27826 L
.84751 .27826 L
.84887 .27826 L
.85017 .27825 L
.85133 .27825 L
.85261 .27824 L
.8541 .27822 L
.8555 .27821 L
.85812 .27817 L
.864 .27806 L
.86905 .27794 L
.87172 .27789 L
Mistroke
.87319 .27786 L
.87459 .27784 L
.87592 .27782 L
.87667 .27781 L
.87736 .27781 L
.87859 .2778 L
.87989 .2778 L
.8811 .27781 L
.88224 .27782 L
.88349 .27784 L
.88484 .27788 L
.88615 .27792 L
.88759 .27798 L
.89049 .27814 L
.89317 .27835 L
.89567 .27859 L
.90058 .27924 L
.90504 .28002 L
.91506 .28242 L
.95704 .29596 L
.99742 .30817 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000W
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@ooooooooool04?ooool002Wooooo00?o0000oooo
ooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000002Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool2
o`0001_oooookol0000Nooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo
01Gooooo1Ol0000Cooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0V
ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Wooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02Oooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`05?ooool6o`0001Sooooo00?o
0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool04oooool2o`0001Sooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03
oeEEEOn7QhOooooo02Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41006_ooool3o`0001Gooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000oooo
ooooool04Oooool2o`0001[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41009oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
9oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000Mooooo`?o00004_ooool0
0ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0>ooooo`?o00007?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Wooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Vooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@410Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnYZJWo410@o`000?l@413oZJVY023ooooo0_l0000>ooooo`03oeEEEOmVIVKo000001Cooooo000Y
ooooo`;o00003?ooool3o`000?oooooo2_ooool3o`0002;ooooo000Yooooo`03o`000?oooooooooo
00Oooooo1?l0003ooooooa3ooooo0ol0000Oooooo`00:Oooool00ol0003oooooooooo`03ooooo`Co
0000oooooolGooooo`Co00004Oooool2o`0000;ooooo0_l00004ooooo`00:Oooool00ol0003ooooo
o`000003o`000?oooooo7oooool4o`0000gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4oooo
o`00:Oooooooo`0002co00002oooool01?oMgMgo0000oa0@4?o<c<`5ooooo`00:Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool01?o^k^ko
8B4Qoa0@4?o^k^h5ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`00:Oooool00ol0003o
ooooooooo`3ooooooc?ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`00
3_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Uooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0Soooool002Gooooo0ol000000ol@
413oooooooooo`1jooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000
ooooooooool01?ooool2ob4Q8@Oooooo00?o0000ooooooooool0T?ooool002Oooooo00?o410@okZj
^_ooool0Noooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo1Ol0002Aoooo
o`009oooool00onHV9So<S8booooo`1kooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03
o`000?oooooooooo00[ooooo00CoA4A4omgMgOoooooo0000T_ooool002Oooooo00?ogMgMo`000?nj
^[X0Noooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00CogMgMoeEEEOoo
oooo0000T_ooool002Oooooo00?oEEEEogMgMom4A4@0NOooool00ol@413o0000o`000003o`0001co
oooo00?o0000ooooooooool02oooool00omgMgOoc<c<o`00002Booooo`009_ooool01OoMgMgo410@
oooooolQ8B7ogMgM07[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;ooooo`03
onk^k_m4A4Co000009;ooooo000Vooooo`05ofIVI_n7QhOooooooiRHV?mEEED0N_ooool00ol0003o
ooooooooo`0Kooooo`03oeEEEOmVIVKo000000kooooo00?oMgMgo`000?ooool0TOooool002Gooooo
00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`3ooooooccooooo000Uooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool0oooooolkooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00488 .30902 L
.00942 .30902 L
.01483 .30902 L
.01975 .30902 L
.02223 .30902 L
.02353 .30902 L
.02492 .30902 L
.02613 .30902 L
.02746 .30902 L
.02867 .30902 L
.02981 .30902 L
.03119 .30902 L
.03251 .30902 L
.0337 .30902 L
.03499 .30902 L
.03788 .30902 L
.04057 .30902 L
.04635 .30902 L
.04919 .30902 L
.0518 .30902 L
.05418 .30902 L
.05537 .30902 L
.05669 .30902 L
.05801 .30902 L
.05875 .30902 L
.05943 .30902 L
.06074 .30902 L
.06198 .30902 L
.06329 .30902 L
.06473 .30902 L
.06766 .30902 L
.07291 .30902 L
.07871 .30902 L
.08187 .30902 L
.08481 .30902 L
.08726 .30902 L
.08863 .30902 L
.08987 .30902 L
.09124 .30902 L
.09201 .30902 L
.09272 .30902 L
.09402 .30902 L
.09541 .30902 L
.09656 .30902 L
.0978 .30902 L
.09897 .30902 L
.10003 .30902 L
.10512 .30902 L
.1105 .30902 L
Mistroke
.11334 .30902 L
.11636 .30902 L
.11785 .30902 L
.11926 .30902 L
.12053 .30902 L
.12189 .30902 L
.12319 .30902 L
.12457 .30902 L
.12574 .30902 L
.12702 .30902 L
.13845 .30902 L
.14407 .30902 L
.14654 .30902 L
.14927 .30902 L
.15044 .30902 L
.1517 .30902 L
.15279 .30902 L
.15398 .30902 L
.15525 .30902 L
.15659 .30902 L
.15782 .30902 L
.15898 .30902 L
.16035 .30902 L
.16165 .30902 L
.16282 .30902 L
.16408 .30902 L
.16691 .30902 L
.16952 .30902 L
.1798 .30902 L
.18482 .30902 L
.18941 .30902 L
.19189 .30902 L
.19424 .30902 L
.19553 .30902 L
.19672 .30902 L
.19803 .30902 L
.19869 .30902 L
.19943 .30902 L
.20012 .30902 L
.20085 .30902 L
.20215 .30902 L
.20288 .30902 L
.20356 .30902 L
.2051 .30902 L
.20645 .30902 L
.20768 .30902 L
.21043 .30902 L
.2202 .30902 L
.22278 .30902 L
.22555 .30902 L
Mistroke
.22689 .30902 L
.22816 .30902 L
.22932 .30902 L
.23055 .30902 L
.23189 .30902 L
.23313 .30902 L
.2339 .30902 L
.23461 .30902 L
.23595 .30902 L
.23668 .30902 L
.23744 .30902 L
.23881 .30902 L
.24029 .30902 L
.2419 .30902 L
.24452 .30902 L
.24732 .30902 L
.25238 .30902 L
.26307 .30902 L
.26871 .30902 L
.2747 .30902 L
.27992 .30902 L
.28289 .30902 L
.28568 .30902 L
.29056 .30902 L
.29583 .30902 L
.30069 .30902 L
.30589 .30902 L
.30887 .30902 L
.31029 .30902 L
.31159 .30902 L
.3129 .30902 L
.31358 .30902 L
.31431 .30902 L
.31554 .30902 L
.31689 .30902 L
.3176 .30902 L
.31837 .30902 L
.3191 .30902 L
.31977 .30902 L
.32105 .30902 L
.32241 .30902 L
.32552 .30902 L
.32834 .30902 L
.33386 .30902 L
.33905 .30902 L
.34437 .30902 L
.34934 .30902 L
.35184 .30902 L
.35324 .30902 L
.35451 .30902 L
Mistroke
.35524 .30902 L
.35591 .30902 L
.35665 .30902 L
.35743 .30902 L
.35874 .30902 L
.35949 .30902 L
.36019 .30902 L
.36138 .30902 L
.36269 .30902 L
.36507 .30902 L
.36739 .30902 L
.36954 .30902 L
.3796 .30902 L
.38493 .30902 L
.38793 .30902 L
.38936 .30902 L
.39069 .30902 L
.39186 .30902 L
.39311 .30902 L
.39382 .30902 L
.3945 .30902 L
.39577 .30902 L
.39711 .30902 L
.39834 .30902 L
.3997 .30902 L
.40114 .30902 L
.40344 .30902 L
.40593 .30902 L
.41042 .30902 L
.42067 .30902 L
.43064 .30902 L
.44129 .30902 L
.45298 .30902 L
.46386 .30902 L
.47506 .30902 L
.48057 .30902 L
.48565 .30902 L
.49026 .30902 L
.49259 .30902 L
.4939 .30902 L
.49515 .30902 L
.49649 .30902 L
.49771 .30902 L
.49903 .30902 L
.49978 .30902 L
.50047 .30902 L
.50173 .30902 L
.50288 .30902 L
.5042 .30902 L
.50545 .30902 L
Mistroke
.50799 .30902 L
.51035 .30902 L
.51572 .30902 L
.52656 .30902 L
.54597 .30902 L
.55697 .30902 L
.56737 .30902 L
.57664 .30902 L
.58192 .30902 L
.58687 .30902 L
.59176 .30902 L
.59427 .30902 L
.59702 .30902 L
.59835 .30902 L
.59977 .30902 L
.60055 .30902 L
.60126 .30902 L
.60198 .30902 L
.60265 .30902 L
.60392 .30902 L
.6053 .30902 L
.60652 .30902 L
.6078 .30902 L
.609 .30902 L
.6101 .30902 L
.61257 .30902 L
.61702 .30902 L
.62715 .30902 L
.63219 .30902 L
.63473 .30902 L
.63619 .30902 L
.63754 .30902 L
.6387 .30902 L
.63992 .30902 L
.64115 .30902 L
.6425 .30902 L
.64366 .30902 L
.64491 .30902 L
.64609 .30902 L
.64716 .30902 L
.64995 .30902 L
.65253 .30902 L
.65836 .30902 L
.66346 .30902 L
.66894 .30902 L
.67166 .30902 L
.67425 .30902 L
.67657 .30902 L
.67788 .30902 L
.6791 .30902 L
Mistroke
.68034 .30902 L
.68152 .30902 L
.68257 .30902 L
.6837 .30902 L
.68495 .30902 L
.68626 .30902 L
.68738 .30902 L
.68861 .30902 L
.69144 .30902 L
.69402 .30902 L
.69981 .30902 L
.70489 .30902 L
.71027 .30902 L
.71522 .30902 L
.71804 .30902 L
.72068 .30902 L
.72532 .30902 L
.73032 .30902 L
.74073 .30902 L
.74624 .30902 L
.75212 .30902 L
.75506 .30902 L
.75783 .30902 L
.76032 .30902 L
.76173 .30902 L
.76302 .30902 L
.76423 .30902 L
.76537 .30902 L
.76661 .30902 L
.76795 .30902 L
.76862 .30902 L
.76935 .30902 L
.77067 .30902 L
.77317 .30902 L
.77609 .30902 L
.77873 .30902 L
.78466 .30902 L
.78985 .30902 L
.79246 .30902 L
.79396 .30902 L
.79532 .30902 L
.79668 .30902 L
.79796 .30902 L
.79931 .30902 L
.80008 .30902 L
.80079 .30902 L
.80196 .30902 L
.80326 .30902 L
.80461 .30902 L
.80588 .30902 L
Mistroke
.80832 .30902 L
.81055 .30902 L
.81558 .30902 L
.82106 .30902 L
.82692 .30902 L
.82976 .30902 L
.83244 .30902 L
.83488 .30902 L
.83621 .30902 L
.83745 .30902 L
.83869 .30902 L
.83983 .30902 L
.84108 .30902 L
.84243 .30902 L
.84356 .30902 L
.84479 .30902 L
.84595 .30902 L
.84702 .30902 L
.84825 .30902 L
.8494 .30902 L
.85204 .30902 L
.85737 .30902 L
.86247 .30902 L
.86783 .30902 L
.87064 .30902 L
.87224 .30902 L
.873 .30902 L
.87372 .30902 L
.87509 .30902 L
.87633 .30902 L
.87767 .30902 L
.87843 .30902 L
.87912 .30902 L
.88941 .30902 L
.89509 .30902 L
.89788 .30902 L
.89924 .30902 L
.90048 .30902 L
.90164 .30902 L
.9029 .30902 L
.90422 .30902 L
.90547 .30902 L
.90685 .30902 L
.90755 .30902 L
.90831 .30902 L
.90966 .30902 L
.91092 .30902 L
.91216 .30902 L
.91333 .30902 L
.91553 .30902 L
Mistroke
.92047 .30902 L
.92971 .30902 L
.93195 .30902 L
.93437 .30902 L
.93576 .30902 L
.93703 .30902 L
.93824 .30902 L
.93952 .30902 L
.94081 .30902 L
.94218 .30902 L
.94348 .30902 L
.94466 .30902 L
.94605 .30902 L
.94755 .30902 L
.95028 .30902 L
.95542 .30902 L
.96023 .30902 L
.9625 .30902 L
.96467 .30902 L
.96586 .30902 L
.96716 .30902 L
.96834 .30902 L
.96943 .30902 L
.97076 .30902 L
.97201 .30902 L
.97313 .30902 L
.97434 .30902 L
.97566 .30902 L
.97706 .30902 L
.97955 .30902 L
.98199 .30902 L
.9846 .30902 L
.98931 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000W
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@ooooooooool04?ooool002Wooooo00?o0000oooo
ooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000002Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool2
o`0002kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo01;ooooo
000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03
o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo02Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooooooo
o`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Dooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000oooo
ooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool002Woooooool0000/
o`0000_ooooo00CogMgMo`000?l@413oc<c<1Oooool002Wooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Cok^k^ob4Q8Ol@413ok^k^1Ooo
ool002Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Oooool002Wooooo00?o0000ooooooooool0oooooolc
ooooo`;o00000_ooool2o`0000Cooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolm
ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
3_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`?o0000oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Q
ooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEE
ofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOoo
ool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM093ooooo000Uooooo`?o000000?o410@ooooooooool0
N_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo08oooooo000Wooooo`03oa0@4?nj^[[ooooo07_ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08kooooo
000Wooooo`03oiRHV?lb<S;ooooo07_ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o
0000ooooooooool03_ooool00omgMgOo<S8booooo`2?ooooo`009oooool00ooMgMgo0000okZj^P1k
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<093ooooo000Wooooo`03oeEEEOmgMgOoA4A407Wooooo00?o410@o`000?l000000ol0000L
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0T_ooool002Kooooo00GogMgMoa0@
4?oooooo8B4QomgMg@1jooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`2Booooo`009_ooool01OmVIVKoQhN7oooooonHV9SoEEEE07[ooooo00?o0000
ooooooooool06oooool00omEEEGoIVIVo`00000=ooooo`Co0000TOooool002Gooooo00?ok^k^o`00
0?o^k^h00_ooool00ol0003ogMgMooooo`3ooooooccooooo000Uooooo`04oa0@4?l0003o0000oooo
o`;o000000?o410@ooooooooool0oooooolkooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .32137 L
.06168 .32803 L
.07286 .33184 L
.08481 .33558 L
.0906 .33707 L
.09607 .33822 L
.10099 .33902 L
.10352 .33935 L
.10632 .33964 L
.10893 .33985 L
.11138 .34001 L
.1127 .34007 L
.11396 .34012 L
.11541 .34016 L
.11674 .34019 L
.11789 .34021 L
.11912 .34022 L
.12029 .34023 L
.12134 .34023 L
.12258 .34023 L
.12392 .34021 L
.12519 .3402 L
.12636 .34018 L
.1359 .33998 L
.13841 .33993 L
.14115 .33987 L
.14356 .33984 L
.14613 .33981 L
.14757 .33979 L
.14834 .33979 L
.14917 .33979 L
.14993 .33978 L
.15063 .33978 L
.15199 .33978 L
.15324 .33978 L
.1546 .33978 L
.15529 .33978 L
.15602 .33979 L
.15735 .33979 L
.16017 .33981 L
.16283 .33984 L
.16782 .33989 L
.17309 .33994 L
.17567 .33996 L
.17803 .33998 L
.17922 .33999 L
.18051 .33999 L
.18188 .34 L
.18317 .34 L
Mistroke
.18392 .34 L
.1846 .34 L
.18538 .34 L
.18611 .34 L
.18742 .34 L
.18816 .34 L
.18884 .33999 L
.19116 .33999 L
.19333 .33998 L
.19826 .33995 L
.20343 .33992 L
.20821 .33989 L
.21077 .33988 L
.21208 .33988 L
.21348 .33987 L
.21422 .33987 L
.21489 .33987 L
.21621 .33987 L
.21691 .33987 L
.21767 .33987 L
.21847 .33987 L
.21921 .33987 L
.22057 .33987 L
.22185 .33987 L
.223 .33987 L
.22425 .33988 L
.22962 .33989 L
.23449 .33991 L
.2397 .33993 L
.24223 .33994 L
.24463 .33995 L
.24567 .33995 L
.24678 .33995 L
.24799 .33995 L
.24912 .33995 L
.25029 .33995 L
.25156 .33995 L
.25276 .33995 L
.25385 .33995 L
.25507 .33995 L
.2564 .33995 L
.25908 .33995 L
.26475 .33993 L
.27003 .33992 L
.27291 .33991 L
.27563 .3399 L
.27807 .3399 L
.27944 .3399 L
.28071 .33989 L
.28208 .33989 L
Mistroke
.28336 .33989 L
.28409 .33989 L
.28476 .33989 L
.28553 .33989 L
.28626 .33989 L
.28697 .33989 L
.28772 .33989 L
.28907 .3399 L
.29068 .3399 L
.29214 .3399 L
.30198 .33992 L
.30457 .33992 L
.30735 .33993 L
.30992 .33993 L
.31236 .33994 L
.31373 .33994 L
.31449 .33994 L
.31521 .33994 L
.31646 .33994 L
.3178 .33994 L
.3185 .33994 L
.31926 .33994 L
.32063 .33994 L
.32142 .33994 L
.32226 .33994 L
.32375 .33993 L
.32635 .33993 L
.32876 .33993 L
.33423 .33992 L
.33954 .33991 L
.34233 .33991 L
.34386 .33991 L
.34529 .33991 L
.34654 .33991 L
.34788 .33991 L
.34864 .33991 L
.34936 .33991 L
.35072 .33991 L
.35196 .33991 L
.35312 .33991 L
.35438 .33991 L
.35573 .33991 L
.35827 .33991 L
.36101 .33991 L
.36597 .33992 L
.37045 .33992 L
.37525 .33992 L
.37664 .33993 L
.37796 .33993 L
.37925 .33993 L
Mistroke
.38043 .33993 L
.38156 .33993 L
.38275 .33993 L
.38395 .33993 L
.38527 .33993 L
.386 .33993 L
.38669 .33993 L
.38799 .33993 L
.38872 .33993 L
.3894 .33993 L
.39093 .33993 L
.39624 .33992 L
.40171 .33992 L
.40459 .33992 L
.40764 .33992 L
.4103 .33991 L
.41172 .33991 L
.41323 .33991 L
.41394 .33991 L
.41462 .33991 L
.41589 .33991 L
.41708 .33991 L
.41838 .33991 L
.41971 .33991 L
.42095 .33991 L
.42232 .33991 L
.4238 .33991 L
.42681 .33991 L
.42956 .33992 L
.43451 .33992 L
.43992 .33992 L
.4423 .33992 L
.44484 .33992 L
.44608 .33992 L
.44725 .33992 L
.44829 .33992 L
.44943 .33992 L
.45064 .33992 L
.45196 .33992 L
.45335 .33992 L
.45464 .33992 L
.45585 .33992 L
.45696 .33992 L
.45945 .33992 L
.46994 .33992 L
.4727 .33992 L
.47569 .33992 L
.47827 .33992 L
.4811 .33992 L
.48378 .33992 L
Mistroke
.48523 .33992 L
.48659 .33992 L
.48787 .33992 L
.48903 .33992 L
.49037 .33992 L
.49164 .33992 L
.49279 .33992 L
.49402 .33992 L
.49506 .33992 L
.49622 .33992 L
.49745 .33992 L
.49878 .33992 L
.50004 .33992 L
.50119 .33992 L
.50242 .33992 L
.50353 .33992 L
.50482 .33992 L
.50603 .33992 L
.50716 .33992 L
.50819 .33992 L
.50933 .33992 L
.51054 .33992 L
.51175 .33992 L
.51305 .33992 L
.51428 .33992 L
.5154 .33992 L
.51815 .33992 L
.52075 .33992 L
.52323 .33992 L
.52587 .33992 L
.5306 .33992 L
.5362 .33992 L
.53865 .33992 L
.54133 .33992 L
.54253 .33992 L
.54381 .33992 L
.54501 .33992 L
.54611 .33992 L
.54735 .33992 L
.5487 .33992 L
.54997 .33992 L
.55115 .33992 L
.55241 .33992 L
.55359 .33992 L
.55629 .33992 L
.55892 .33992 L
.56174 .33992 L
.56656 .33992 L
.57169 .33991 L
.57418 .33991 L
Mistroke
.57541 .33991 L
.57653 .33991 L
.57754 .33991 L
.57864 .33991 L
.57975 .33991 L
.58092 .33991 L
.58231 .33991 L
.58357 .33991 L
.58427 .33991 L
.58503 .33991 L
.58641 .33991 L
.5877 .33991 L
.58907 .33991 L
.59154 .33991 L
.59704 .33992 L
.60312 .33992 L
.60567 .33992 L
.60836 .33993 L
.60976 .33993 L
.6113 .33993 L
.61198 .33993 L
.6127 .33993 L
.614 .33993 L
.61532 .33993 L
.61607 .33993 L
.61675 .33993 L
.61802 .33993 L
.61935 .33993 L
.62055 .33993 L
.62167 .33993 L
.62422 .33993 L
.63515 .33991 L
.63776 .33991 L
.64053 .33991 L
.64188 .33991 L
.64315 .33991 L
.64431 .33991 L
.64552 .33991 L
.64664 .33991 L
.64786 .33991 L
.64897 .3399 L
.65 .33991 L
.65122 .33991 L
.65234 .33991 L
.65362 .33991 L
.65484 .33991 L
.65737 .33991 L
.6597 .33991 L
.66499 .33992 L
.66987 .33993 L
Mistroke
.67257 .33993 L
.67513 .33993 L
.6775 .33994 L
.67884 .33994 L
.68009 .33994 L
.68124 .33994 L
.68229 .33994 L
.68349 .33994 L
.68463 .33994 L
.68589 .33994 L
.68726 .33994 L
.6887 .33993 L
.69005 .33993 L
.69503 .33992 L
.70042 .33991 L
.70326 .33991 L
.70628 .3399 L
.70899 .3399 L
.71053 .3399 L
.71123 .3399 L
.71197 .33989 L
.7133 .33989 L
.71451 .33989 L
.71581 .33989 L
.71655 .33989 L
.71724 .33989 L
.71859 .33989 L
.71987 .3399 L
.72102 .3399 L
.72226 .3399 L
.72506 .3399 L
.72763 .33991 L
.73702 .33994 L
.73972 .33994 L
.74229 .33995 L
.74341 .33995 L
.7446 .33995 L
.7459 .33995 L
.74711 .33995 L
.74843 .33995 L
.74917 .33995 L
.74986 .33995 L
.75112 .33995 L
.75244 .33995 L
.75364 .33995 L
.75475 .33995 L
.75728 .33994 L
.76187 .33993 L
.76679 .33991 L
.76958 .3399 L
Mistroke
.77262 .33988 L
.77529 .33988 L
.77675 .33987 L
.77813 .33987 L
.77936 .33987 L
.78068 .33987 L
.7814 .33987 L
.78215 .33987 L
.7835 .33987 L
.78472 .33987 L
.78587 .33987 L
.78712 .33987 L
.78846 .33988 L
.79118 .33989 L
.79406 .3399 L
.79923 .33993 L
.80526 .33997 L
.8082 .33998 L
.80949 .33999 L
.81089 .33999 L
.81219 .34 L
.81339 .34 L
.81453 .34 L
.81576 .34 L
.81643 .34 L
.81717 .34 L
.8185 .33999 L
.81979 .33999 L
.82098 .33999 L
.82355 .33997 L
.82637 .33995 L
.83206 .33989 L
.83759 .33983 L
.84031 .33981 L
.8415 .3398 L
.84282 .33979 L
.84391 .33979 L
.84509 .33978 L
.84634 .33978 L
.84751 .33978 L
.84887 .33978 L
.85017 .33978 L
.85133 .33979 L
.85261 .3398 L
.8541 .33981 L
.8555 .33982 L
.85812 .33986 L
.864 .33998 L
.86905 .34009 L
.87172 .34015 L
Mistroke
.87319 .34017 L
.87459 .3402 L
.87592 .34021 L
.87667 .34022 L
.87736 .34022 L
.87859 .34023 L
.87989 .34023 L
.8811 .34022 L
.88224 .34021 L
.88349 .34019 L
.88484 .34016 L
.88615 .34011 L
.88759 .34006 L
.89049 .33989 L
.89317 .33969 L
.89567 .33944 L
.90058 .33879 L
.90504 .33801 L
.91506 .33562 L
.95704 .32207 L
.99742 .30987 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000W
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@ooooooooool04?ooool002Wooooo00?o0000oooo
ooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000002Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool2
o`0002kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo01;ooooo
000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03
o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo02Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooooooo
o`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Dooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000oooo
ooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool002Woooooool0000/
o`0000_ooooo00CogMgMo`000?l@413oc<c<1Oooool002Wooooo00?o0000ooooooooool00ol00009
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Wooooo1?l0000;ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Y
ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1?l00003
ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Oooool002Wooooo00?o0000
ooooooooool01_ooool3o`000?oooooo5?ooool4o`0001;ooooo0_l00002ooooo`;o00001?ooool0
02Wooooo00?o0000ooooooooool02Oooool3o`000?oooooo3Oooool4o`00023ooooo000Yooooo`;o
00003Oooool3o`000?oooooo1oooool3o`0002Cooooo000Yooooo`03o`000?oooooooooo00oooooo
0ol0003oooooo`7ooooo0ol0000Wooooo`00:Oooool00ol0003oooooooooo`0Booooo`?o0000n_oo
ool3o`0002[ooooo000Yooooo`03o`000?oooooooooo01Gooooo0ol0003dooooo`?o0000;Oooool0
02Wooooo00?o0000ooooooooool06?ooool5o`000>[ooooo1Ol0000`ooooo`00:Oooool2o`0001go
ooook?l0000dooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolm
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:Gooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c02Aooooo`00
9Oooool3o`000003oa0@4?oooooooooo07[ooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
097ooooo000Wooooo`03oa0@4?nj^[[ooooo07_ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool00000TOooool002Oooooo00?oV9RHoc8b<_oo
ool0Noooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0:ooooo`05
o`000?nHV9SooooooiRHV?lQ8B40TOooool002Oooooo00?ogMgMo`000?nj^[X0Noooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go0000oeEEEOl0003o410@olc<c02Aoooo
o`009oooool00omEEEGoMgMgodA4A01iooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003o
ooooooooo`0:ooooo`03oeEEEOn7QhOooooo09?ooooo000Vooooo`05omgMgOl@413oooooob4Q8OoM
gMd0N_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?ogMgMoa0@4?nH
V9P0Toooool002Kooooo00GoIVIVohN7QoooooooV9RHoeEEE@1jooooo`03o`000?oooooooooo01_o
oooo00?oEEEEofIVI_l000003Oooool01?o<c<coA4A4o`000?l@412Aooooo`009Oooool00oo^k^ko
0000onk^kP02ooooo`03o`000?oMgMgooooo0?oooooo??ooool002Gooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`3ooooooc_ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .32163 L
.08481 .33509 L
.12636 .34815 L
.16632 .36052 L
.17777 .36434 L
.18859 .36746 L
.19331 .36856 L
.19831 .36951 L
.20092 .36991 L
.20379 .37028 L
.20621 .37054 L
.20885 .37076 L
.21027 .37086 L
.21158 .37093 L
.21294 .371 L
.21417 .37105 L
.2153 .37108 L
.21653 .37111 L
.21782 .37113 L
.21904 .37114 L
.22036 .37115 L
.22111 .37115 L
.22181 .37115 L
.22255 .37114 L
.22323 .37114 L
.22474 .37112 L
.22603 .3711 L
.22744 .37108 L
.22999 .37102 L
.23491 .3709 L
.24021 .37079 L
.24264 .37074 L
.24521 .37071 L
.2474 .37069 L
.24864 .37068 L
.2498 .37067 L
.25108 .37067 L
.2523 .37067 L
.25339 .37067 L
.25457 .37067 L
.25586 .37067 L
.25722 .37068 L
.25966 .3707 L
.26529 .37076 L
.27056 .37082 L
.27562 .37087 L
.27708 .37088 L
.27846 .37089 L
.27983 .3709 L
Mistroke
.28106 .3709 L
.28173 .37091 L
.28245 .37091 L
.28321 .37091 L
.28393 .37091 L
.28532 .37091 L
.28659 .37091 L
.28731 .37091 L
.28799 .37091 L
.28952 .3709 L
.29102 .3709 L
.29262 .37089 L
.30333 .37082 L
.30626 .3708 L
.30937 .37078 L
.31203 .37077 L
.31354 .37077 L
.31428 .37077 L
.31496 .37076 L
.3162 .37076 L
.31755 .37076 L
.31887 .37076 L
.31961 .37076 L
.32027 .37076 L
.32148 .37076 L
.32278 .37077 L
.32514 .37077 L
.32791 .37078 L
.33085 .3708 L
.3361 .37082 L
.33854 .37083 L
.3412 .37084 L
.34354 .37085 L
.34604 .37086 L
.34741 .37086 L
.34819 .37086 L
.34893 .37086 L
.35022 .37086 L
.35094 .37086 L
.35161 .37086 L
.35279 .37086 L
.35409 .37086 L
.35544 .37086 L
.35669 .37086 L
.3592 .37085 L
.36157 .37084 L
.36599 .37083 L
.37113 .37081 L
.37594 .3708 L
.37827 .3708 L
Mistroke
.37959 .3708 L
.38079 .3708 L
.3821 .37079 L
.38284 .37079 L
.38353 .37079 L
.38479 .37079 L
.38613 .37079 L
.38686 .37079 L
.38753 .37079 L
.38904 .3708 L
.39038 .3708 L
.39179 .3708 L
.39693 .37081 L
.40213 .37082 L
.40706 .37083 L
.4092 .37083 L
.41148 .37083 L
.41267 .37084 L
.41398 .37084 L
.41517 .37084 L
.41629 .37084 L
.41751 .37084 L
.41879 .37084 L
.41989 .37084 L
.42109 .37084 L
.42238 .37084 L
.42376 .37084 L
.42625 .37083 L
.43693 .37082 L
.43942 .37082 L
.44212 .37082 L
.44467 .37081 L
.44588 .37081 L
.44702 .37081 L
.44813 .37081 L
.44914 .37081 L
.45026 .37081 L
.45147 .37081 L
.45263 .37081 L
.45389 .37081 L
.45508 .37081 L
.45618 .37081 L
.46582 .37082 L
.47108 .37082 L
.47598 .37082 L
.47854 .37082 L
.48129 .37082 L
.48286 .37082 L
.48434 .37082 L
.48567 .37082 L
Mistroke
.48712 .37082 L
.48834 .37082 L
.4897 .37082 L
.49038 .37082 L
.49111 .37082 L
.49243 .37082 L
.49375 .37082 L
.495 .37082 L
.49612 .37082 L
.49735 .37082 L
.49808 .37082 L
.49887 .37082 L
.49962 .37082 L
.50031 .37082 L
.50162 .37082 L
.503 .37082 L
.50372 .37082 L
.50449 .37082 L
.50588 .37082 L
.50672 .37082 L
.50753 .37082 L
.50825 .37082 L
.50903 .37082 L
.51033 .37082 L
.51107 .37082 L
.51177 .37082 L
.51316 .37082 L
.51467 .37082 L
.516 .37082 L
.51739 .37082 L
.51989 .37082 L
.52242 .37082 L
.52513 .37082 L
.53001 .37082 L
.53577 .37081 L
.5383 .37081 L
.54108 .37081 L
.54238 .37081 L
.54378 .37081 L
.5451 .37081 L
.5463 .37081 L
.54766 .37081 L
.54843 .37081 L
.54914 .37081 L
.55044 .37081 L
.55183 .37081 L
.55335 .37081 L
.55498 .37081 L
.55795 .37082 L
.56349 .37082 L
Mistroke
.56885 .37083 L
.57178 .37083 L
.57451 .37083 L
.57684 .37084 L
.57815 .37084 L
.57934 .37084 L
.58065 .37084 L
.58138 .37084 L
.58207 .37084 L
.58332 .37084 L
.58464 .37084 L
.58584 .37084 L
.58715 .37084 L
.58979 .37083 L
.59223 .37083 L
.5945 .37083 L
.60007 .37081 L
.60512 .3708 L
.60741 .3708 L
.60862 .3708 L
.6099 .3708 L
.61102 .3708 L
.61225 .37079 L
.61336 .37079 L
.61441 .37079 L
.61569 .37079 L
.61691 .37079 L
.618 .37079 L
.61919 .3708 L
.62048 .3708 L
.62185 .3708 L
.62432 .3708 L
.63414 .37083 L
.6393 .37085 L
.64189 .37085 L
.64338 .37086 L
.64473 .37086 L
.64602 .37086 L
.64723 .37086 L
.64852 .37086 L
.64924 .37086 L
.64991 .37086 L
.65102 .37086 L
.65225 .37086 L
.65353 .37086 L
.65473 .37085 L
.65704 .37085 L
.65916 .37084 L
.66391 .37082 L
.66888 .3708 L
Mistroke
.67357 .37078 L
.67616 .37077 L
.67762 .37077 L
.67896 .37076 L
.6801 .37076 L
.68134 .37076 L
.68264 .37076 L
.68385 .37076 L
.68456 .37076 L
.68532 .37076 L
.6867 .37077 L
.68805 .37077 L
.6893 .37078 L
.69213 .37079 L
.69514 .37081 L
.70061 .37085 L
.70562 .37088 L
.7081 .37089 L
.71041 .3709 L
.71158 .37091 L
.71282 .37091 L
.7142 .37091 L
.71546 .37091 L
.71682 .37091 L
.71808 .37091 L
.71946 .3709 L
.72092 .3709 L
.72337 .37088 L
.72607 .37086 L
.73591 .37075 L
.73826 .37072 L
.74077 .3707 L
.74198 .37069 L
.74313 .37068 L
.74417 .37067 L
.74526 .37067 L
.74654 .37067 L
.74772 .37067 L
.74898 .37067 L
.75037 .37067 L
.7511 .37067 L
.75176 .37068 L
.75325 .37069 L
.75463 .3707 L
.75594 .37072 L
.76061 .3708 L
.76569 .37092 L
.77122 .37105 L
.77401 .3711 L
.7756 .37113 L
Mistroke
.77631 .37113 L
.77709 .37114 L
.77845 .37115 L
.77974 .37115 L
.781 .37114 L
.78217 .37113 L
.78355 .37111 L
.78481 .37108 L
.78626 .37103 L
.78763 .37097 L
.79015 .37083 L
.79251 .37066 L
.79509 .37041 L
.79787 .37008 L
.80353 .36919 L
.80869 .36812 L
.82808 .36242 L
.86989 .34924 L
.91011 .33669 L
.95291 .32369 L
.99411 .31077 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000W
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@ooooooooool04?ooool002Wooooo00?o0000oooo
ooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000002Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool2
o`0002kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo01;ooooo
000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03
o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo02Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooooooo
o`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Dooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000oooo
ooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool002Woooooool0000/
o`0000_ooooo00CogMgMo`000?l@413oc<c<1Oooool002Wooooo00?o0000ooooooooool00ol00009
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000ooooo`0:ooooo`04onk^k_lQ8B7o
410@onk^kPGooooo000Yooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Kooooo0ol00003ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Ooo
ool002Wooooo00?o0000ooooooooool01_ooool3o`000?oooooo5_ooool3o`00017ooooo0_l00002
ooooo`;o00001?ooool002Wooooo00?o0000ooooooooool02Oooool3o`000?oooooo4?ooool3o`00
01kooooo000Yooooo`;o00003Oooool3o`000?oooooo2Oooool4o`00027ooooo000Yooooo`03o`00
0?oooooooooo00oooooo0ol0003oooooo`?ooooo0ol0000Uooooo`00:Oooool00ol0003ooooooooo
o`0Booooo`?o0000o?ooool3o`0002Sooooo000Yooooo`03o`000?oooooooooo01Gooooo1?l0003e
ooooo`?o0000:oooool002Wooooo00?o0000ooooooooool06Oooool3o`000>kooooo1?l0000^oooo
o`00:Oooool2o`0001gooooo0ol0003Wooooo`Co0000<_ooool002Wooooo00?o0000ooooooooool0
7oooool3o`000>3ooooo1?l0000fooooo`00:Oooool00ol0003oooooooooo`0Rooooo`?o0000fOoo
ool4o`0003[ooooo000Yooooo`03o`000?oooooooooo02Gooooo0ol0003Cooooo`?o0000?_ooool0
02Wooooo0_l0000Yooooo`?o0000cOooool3o`00047ooooo000Yooooo`03o`000?oooooooooo02_o
oooo0ol00037ooooo`?o0000A?ooool002Wooooo00?o0000ooooooooool0;_ooool3o`000<7ooooo
0ol00017ooooo`00:Oooool00ol0003oooooooooo`0aooooo`Co0000^_ooool3o`0004[ooooo000Y
ooooo`03o`000?oooooooooo03Gooooo1?l0002booooo`Co0000COooool002Wooooo0_l0000joooo
ok;o0000DOooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`00
0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oo
oooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Oooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo
000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool0
0ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo
00000?ooooooAoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Go
V9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo
00?o0000onk^k_ooool0TOooool002Gooooo0ol000000ol@413oooooooooo`1jooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool0TOooool002Oooooo00?o410@okZj^_ooool0Noooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool0TOooool002Oooooo00?oV9RH
oc8b<_ooool0Noooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0=
ooooo`03ob4Q8Ooooooooooo093ooooo000Wooooo`03omgMgOl0003o^[Zj07_ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo093ooooo000Wooooo`03
oeEEEOmgMgOoA4A407Wooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00go
oooo00?oZJVYogMgMoooool0T?ooool002Kooooo00GogMgMoa0@4?oooooo8B4QomgMg@1jooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b
097ooooo000Vooooo`05ofIVI_n7QhOooooooiRHV?mEEED0N_ooool00ol0003oooooooooo`0Koooo
o`03oeEEEOmVIVKo000000cooooo1Ol0002Aooooo`009Oooool00oo^k^ko0000onk^kP02ooooo`03
o`000?oMgMgooooo0?oooooo??ooool002Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413o
ooooooooo`3ooooooc_ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .3215 L
.08481 .33531 L
.12636 .34801 L
.16632 .3604 L
.20885 .37368 L
.2498 .38599 L
.27066 .3929 L
.28166 .39644 L
.28768 .39813 L
.29331 .39946 L
.29831 .40041 L
.30369 .40117 L
.30675 .40149 L
.30965 .40172 L
.31226 .40187 L
.31374 .40193 L
.31511 .40198 L
.31638 .40201 L
.31774 .40203 L
.31903 .40205 L
.32022 .40205 L
.3213 .40205 L
.32247 .40205 L
.32371 .40203 L
.32485 .40202 L
.32748 .40198 L
.32987 .40193 L
.33524 .4018 L
.34029 .40169 L
.34284 .40164 L
.3443 .40162 L
.34565 .40161 L
.34679 .4016 L
.34804 .40159 L
.34929 .40158 L
.35062 .40157 L
.35178 .40157 L
.35303 .40157 L
.35421 .40157 L
.35528 .40158 L
.35664 .40158 L
.35808 .40159 L
.36066 .40161 L
.36649 .40168 L
.37202 .40174 L
.37465 .40176 L
.37708 .40178 L
.37951 .40179 L
.38079 .4018 L
Mistroke
.38216 .4018 L
.38346 .40181 L
.38469 .40181 L
.38579 .40181 L
.38699 .40181 L
.38827 .4018 L
.389 .4018 L
.38968 .4018 L
.39253 .40179 L
.39763 .40176 L
.4021 .40173 L
.40685 .4017 L
.40932 .40169 L
.41064 .40169 L
.41205 .40168 L
.41335 .40168 L
.41453 .40168 L
.41567 .40167 L
.41686 .40167 L
.41818 .40167 L
.41891 .40167 L
.41958 .40167 L
.42089 .40167 L
.42212 .40168 L
.42355 .40168 L
.42488 .40168 L
.42786 .40169 L
.43282 .40171 L
.43827 .40172 L
.44063 .40173 L
.44317 .40174 L
.44556 .40174 L
.44662 .40174 L
.44775 .40175 L
.44903 .40175 L
.45021 .40175 L
.45148 .40175 L
.45221 .40175 L
.45289 .40175 L
.45411 .40175 L
.45524 .40175 L
.45647 .40175 L
.45777 .40175 L
.46853 .40173 L
.47382 .40172 L
.47615 .40172 L
.47871 .40172 L
.481 .40172 L
.48314 .40171 L
.4854 .40171 L
Mistroke
.48668 .40171 L
.48784 .40171 L
.4891 .40171 L
.49027 .40171 L
.49155 .40171 L
.49292 .40171 L
.49422 .40171 L
.49545 .40171 L
.49656 .40171 L
.49775 .40171 L
.49903 .40171 L
.50023 .40171 L
.50155 .40171 L
.50229 .40171 L
.50296 .40171 L
.50431 .40171 L
.50508 .40171 L
.50578 .40171 L
.50708 .40171 L
.50846 .40171 L
.50962 .40171 L
.51088 .40171 L
.51206 .40171 L
.51315 .40171 L
.51435 .40171 L
.51566 .40171 L
.51831 .40171 L
.5198 .40172 L
.5212 .40172 L
.52382 .40172 L
.52971 .40173 L
.53475 .40174 L
.53743 .40174 L
.5403 .40174 L
.54172 .40175 L
.54306 .40175 L
.54427 .40175 L
.54558 .40175 L
.54682 .40175 L
.54815 .40175 L
.54939 .40175 L
.55052 .40175 L
.5512 .40175 L
.55192 .40175 L
.5532 .40174 L
.55609 .40174 L
.55859 .40173 L
.56133 .40173 L
.56611 .40171 L
.57129 .40169 L
Mistroke
.57367 .40168 L
.57497 .40168 L
.57619 .40168 L
.57731 .40168 L
.57834 .40167 L
.57948 .40167 L
.58071 .40167 L
.58208 .40167 L
.58335 .40167 L
.58408 .40167 L
.58474 .40168 L
.58623 .40168 L
.58752 .40168 L
.58892 .40169 L
.59147 .4017 L
.59656 .40172 L
.60125 .40175 L
.60392 .40177 L
.60678 .40178 L
.60817 .40179 L
.60948 .4018 L
.61067 .4018 L
.61194 .4018 L
.61328 .40181 L
.61452 .40181 L
.61585 .40181 L
.61661 .40181 L
.61732 .4018 L
.61805 .4018 L
.61881 .4018 L
.62017 .40179 L
.62163 .40179 L
.62323 .40178 L
.62878 .40173 L
.63402 .40167 L
.63878 .40162 L
.64138 .4016 L
.64265 .40159 L
.64382 .40158 L
.64508 .40158 L
.64643 .40157 L
.64713 .40157 L
.6479 .40157 L
.64863 .40157 L
.64931 .40157 L
.65059 .40158 L
.65176 .40158 L
.6531 .40159 L
.65437 .40161 L
.65723 .40165 L
Mistroke
.65987 .40169 L
.66581 .40182 L
.67076 .40194 L
.67348 .40199 L
.67482 .40202 L
.67605 .40203 L
.67722 .40204 L
.67845 .40205 L
.67969 .40205 L
.68105 .40204 L
.68218 .40203 L
.6834 .40201 L
.68455 .40198 L
.68561 .40195 L
.68687 .40191 L
.68823 .40184 L
.69066 .4017 L
.69356 .40146 L
.69619 .40119 L
.70191 .40037 L
.70731 .39933 L
.71754 .39668 L
.72836 .39323 L
.74775 .38676 L
.78757 .37481 L
.82997 .36151 L
.87077 .34892 L
.91416 .33563 L
.95595 .32256 L
.99615 .31024 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000W
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@ooooooooool04?ooool002Wooooo00?o0000oooo
ooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000002Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool2
o`0002kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo01;ooooo
000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03
o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo02Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooooooo
o`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Dooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000oooo
ooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool002Woooooool0000/
o`0000_ooooo00CogMgMo`000?l@413oc<c<1Oooool002Wooooo00?o0000ooooooooool00ol00009
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo0ol000000ooooooo0000ooooo`0:ooooo`04onk^k_lQ8B7o
410@onk^kPGooooo000Yooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Cooooo1?l00004ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Ooo
ool002Wooooo00?o0000ooooooooool01_ooool3o`000?oooooo4oooool4o`0001?ooooo0_l00002
ooooo`;o00001?ooool002Wooooo00?o0000ooooooooool02Oooool3o`000?oooooo3Oooool3o`00
027ooooo000Yooooo`;o00003Oooool3o`000?oooooo1oooool3o`0002Cooooo000Yooooo`03o`00
0?oooooooooo00oooooo0ol0003oooooo`7ooooo0ol0000Wooooo`00:Oooool00ol0003ooooooooo
o`0Booooo`?o0000n_ooool3o`0002[ooooo000Yooooo`03o`000?oooooooooo01Gooooo1?l0003b
ooooo`Co0000;Oooool002Wooooo00?o0000ooooooooool06Oooool3o`000>cooooo0ol0000aoooo
o`00:Oooool2o`0001gooooo0ol0003Vooooo`?o0000=?ooool002Wooooo00?o0000ooooooooool0
7oooool3o`000>3ooooo0ol0000gooooo`00:Oooool00ol0003oooooooooo`0Rooooo`?o0000f_oo
ool3o`0003[ooooo000Yooooo`03o`000?oooooooooo02Gooooo0ol0003Dooooo`?o0000?Oooool0
02Wooooo0_l0000Yooooo`?o0000c_ooool3o`00043ooooo000Yooooo`03o`000?oooooooooo02_o
oooo0ol00038ooooo`?o0000@oooool002Wooooo00?o0000ooooooooool0;_ooool3o`000<7ooooo
1?l00016ooooo`00:Oooool00ol0003oooooooooo`0aooooo`?o0000^oooool3o`0004[ooooo000Y
ooooo`03o`000?oooooooooo03Cooooo0ol0002eooooo`?o0000COooool002Wooooo0_l0000hoooo
o`?o0000[oooool3o`00053ooooo000Yooooo`03o`000?oooooooooo03[ooooo1?l0002Xooooo`?o
0000Doooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03kooooo1?l0002Qoooo
o`?o0000E_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`12
ooooo`Co0000V_ooool3o`0005Wooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol00016ooooo`Co0000Toooool3
o`0005cooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0B_ooool3o`0008cooooo1?l0001O
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0COooool3o`0008Gooooo1?l0
001Sooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo0_l00021ooooo`;o0000Iooo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05;ooooo1?l0001iooooo`Co0000
JOooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Kooooo0_l0001GooooogWo0000KOooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000O
ooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Gooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02Aooooo`009Oooool3o`000003oa0@
4?oooooooooo07[ooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q097ooooo000Wooooo`03
oa0@4?nj^[[ooooo07_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05
o`000?ooooooooooooooool00000TOooool002Oooooo00?oV9RHoc8b<_ooool0Noooool00ol0003o
ooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0:ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S80TOooool002Oooooo00?ogMgMo`000?nj^[X0Noooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00[ooooo00Goc<c<o`000?l0003o0000olc<c02Aooooo`009oooool00omEEEGo
MgMgodA4A01iooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003oooooooooo`0:ooooo`05
oa0@4?nj^[[ooooookZj^_l@4100TOooool002Kooooo00GogMgMoa0@4?oooooo8B4QomgMg@1joooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool01Ol0003o^[Zjoooooonj^[[o
0000097ooooo000Vooooo`05ofIVI_n7QhOooooooiRHV?mEEED0N_ooool00ol0003oooooooooo`0K
ooooo`03oeEEEOmVIVKo000000cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Aooooo`009Oooool0
0oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo0?oooooo??ooool002Gooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`3ooooooc_ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .3216 L
.08481 .33515 L
.12636 .34811 L
.16632 .36041 L
.20885 .37348 L
.2498 .38632 L
.29331 .39959 L
.33524 .41253 L
.37557 .42545 L
.38633 .42869 L
.39159 .43 L
.3964 .43098 L
.40147 .43178 L
.40426 .43213 L
.40691 .43239 L
.40978 .43261 L
.41244 .43275 L
.41398 .43282 L
.41537 .43286 L
.41614 .43288 L
.41697 .4329 L
.41775 .43291 L
.41848 .43292 L
.41979 .43293 L
.42098 .43293 L
.42225 .43293 L
.42298 .43292 L
.42365 .43292 L
.42476 .43291 L
.42598 .43289 L
.42846 .43285 L
.43942 .43263 L
.44209 .43259 L
.44491 .43255 L
.44638 .43254 L
.448 .43252 L
.44871 .43252 L
.44946 .43252 L
.45083 .43251 L
.45221 .43251 L
.45299 .43251 L
.45371 .43251 L
.45504 .43251 L
.4557 .43251 L
.45644 .43251 L
.45771 .43251 L
.45907 .43252 L
.46154 .43253 L
.47217 .43261 L
Mistroke
.47509 .43262 L
.47819 .43264 L
.48112 .43265 L
.48377 .43266 L
.4851 .43266 L
.4865 .43266 L
.48769 .43266 L
.489 .43266 L
.49041 .43266 L
.4912 .43266 L
.49192 .43266 L
.49259 .43266 L
.49332 .43266 L
.49465 .43266 L
.49587 .43267 L
.49723 .43267 L
.49791 .43267 L
.49864 .43267 L
.49996 .43267 L
.50121 .43267 L
.50253 .43267 L
.50365 .43267 L
.50488 .43266 L
.50555 .43266 L
.50627 .43266 L
.50755 .43266 L
.50893 .43266 L
.50971 .43266 L
.51045 .43266 L
.51177 .43266 L
.51298 .43266 L
.51437 .43266 L
.51569 .43266 L
.51813 .43265 L
.52039 .43264 L
.52287 .43263 L
.52551 .43262 L
.5361 .43255 L
.539 .43253 L
.54058 .43252 L
.54206 .43252 L
.54332 .43251 L
.54466 .43251 L
.54543 .43251 L
.54616 .43251 L
.54752 .43251 L
.5487 .43251 L
.54999 .43251 L
.55135 .43252 L
.55262 .43253 L
Mistroke
.55488 .43255 L
.55732 .43258 L
.56287 .43267 L
.56794 .43278 L
.57265 .43287 L
.57393 .43289 L
.57531 .43291 L
.5766 .43292 L
.57778 .43293 L
.57898 .43293 L
.58009 .43293 L
.58131 .43292 L
.58259 .4329 L
.58371 .43288 L
.58475 .43286 L
.58713 .43277 L
.58845 .43271 L
.58986 .43263 L
.59239 .43245 L
.59511 .43219 L
.59811 .43184 L
.60348 .431 L
.60851 .42997 L
.61789 .4275 L
.628 .42426 L
.67122 .41066 L
.71284 .39763 L
.75288 .38549 L
.79549 .37217 L
.83651 .35952 L
.8801 .34614 L
.9221 .33302 L
.96251 .32063 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000W
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@ooooooooool04?ooool002Wooooo00?o0000oooo
ooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000
ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000002Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool2
o`0002kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo01;ooooo
000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03
o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo02Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooooooo
o`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Dooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000oooo
ooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool002Woooooool0000/
o`0000_ooooo00CogMgMo`000?l@413oc<c<1Oooool002Wooooo00?o0000ooooooooool00ol00009
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo0ol000000ooooooo0000ooooo`0:ooooo`04onk^k_lQ8B7o
410@onk^kPGooooo000Yooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Gooooo0ol00004ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Ooo
ool002Wooooo00?o0000ooooooooool01_ooool3o`000?oooooo5Oooool3o`0001;ooooo0_l00002
ooooo`;o00001?ooool002Wooooo00?o0000ooooooooool02Oooool3o`000?oooooo3oooool3o`00
01oooooo000Yooooo`;o00003Oooool3o`000?oooooo2Oooool3o`0002;ooooo000Yooooo`03o`00
0?oooooooooo00oooooo0ol0003oooooo`?ooooo0ol0000Uooooo`00:Oooool00ol0003ooooooooo
o`0Booooo`?o0000o?ooool3o`0002Sooooo000Yooooo`03o`000?oooooooooo01Gooooo1?l0003d
ooooo`Co0000:oooool002Wooooo00?o0000ooooooooool06Oooool3o`000>gooooo1?l0000_oooo
o`00:Oooool2o`0001gooooo0ol0003Vooooo`Co0000<oooool002Wooooo00?o0000ooooooooool0
7oooool3o`000=oooooo1?l0000gooooo`00:Oooool00ol0003oooooooooo`0Rooooo`?o0000fOoo
ool3o`0003_ooooo000Yooooo`03o`000?oooooooooo02Gooooo0ol0003Cooooo`?o0000?_ooool0
02Wooooo0_l0000Yooooo`?o0000cOooool3o`00047ooooo000Yooooo`03o`000?oooooooooo02_o
oooo0ol00037ooooo`?o0000A?ooool002Wooooo00?o0000ooooooooool0;_ooool3o`000<7ooooo
0ol00017ooooo`00:Oooool00ol0003oooooooooo`0aooooo`?o0000^oooool3o`0004[ooooo000Y
ooooo`03o`000?oooooooooo03Cooooo0ol0002eooooo`?o0000COooool002Wooooo0_l0000hoooo
o`?o0000[_ooool4o`00053ooooo000Yooooo`03o`000?oooooooooo03[ooooo1?l0002Wooooo`?o
0000E?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03kooooo1?l0002Poooo
o`?o0000Eoooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`12
ooooo`Co0000VOooool3o`0005[ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol00016ooooo`Co0000T_ooool3
o`0005gooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0B_ooool3o`0008cooooo0ol0001P
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0COooool3o`0008Kooooo0ol0
001Sooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo0ol00020ooooo`?o0000I_oo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05?ooooo1?l0001iooooo`?o0000
JOooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Kooooo0_l0001Hooooo`?o0000Loooool3o`0006cooooo000Yooooo`03o`00
0?oooooooooo05[ooooo0ol0001]ooooo`?o0000Koooool002Wooooo00?o0000ooooooooool0GOoo
ool3o`0006Oooooo0ol0001booooo`00:Oooool00ol0003oooooooooo`1Pooooo`Co0000Goooool4
o`0007Gooooo000Yooooo`03o`000?oooooooooo06Cooooo0ol0001Iooooo`?o0000NOooool002Wo
oooo0_l0001Xooooo`?o0000Doooool3o`0007cooooo000Yooooo`03o`000?oooooooooo06[ooooo
0ol0001=ooooo`?o0000Ooooool002Wooooo00?o0000ooooooooool0KOooool3o`0004Oooooo0ol0
0022ooooo`00:Oooool00ol0003oooooooooo`1`ooooo`?o0000?_ooool6o`0008Gooooo000Yoooo
o`;o0000M?oooolno`0008_ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolm
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:Gooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<T_ooool002Gooooo
0ol000000ol@413oooooooooo`1jooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000co
oooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oV9RHoa0@4?oMgMd0TOooool002Oooooo
00?o410@okZj^_ooool0Noooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00gooooo
00?oQhN7oeEEEOooool0T?ooool002Oooooo00?oV9RHoc8b<_ooool0Noooool00ol0003ooooooooo
o`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0:ooooo`05olc<c?lQ8B7o0000oeEEEOl00000
TOooool002Oooooo00?ogMgMo`000?nj^[X0Noooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00[ooooo00Go8B4QohN7QoooooooV9RHo`00002Aooooo`009oooool00omEEEGoMgMgodA4
A01iooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003oooooooooo`0:ooooo`05o`000?oo
ooooooooooooool00000TOooool002Kooooo00GogMgMoa0@4?oooooo8B4QomgMg@1jooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool02_ooool01OlQ8B7oV9RHoooooomgMgOoEEEE097o
oooo000Vooooo`05ofIVI_n7QhOooooooiRHV?mEEED0N_ooool00ol0003oooooooooo`0Kooooo`03
oeEEEOmVIVKo000000cooooo00Goc<c<oa0@4?l0003o<S8bonk^kP2Aooooo`009Oooool00oo^k^ko
0000onk^kP02ooooo`03o`000?oMgMgooooo0?oooooo??ooool002Gooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`3ooooooc_ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.1113, \
0.00419705, 0.0135819}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "\tThis evolution may seem strange. One might have expected that the entire \
triangle would simply change its amplitude in time, oscillating back and \
forth like the ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)]],
  " normal mode shown in Cell ",
  ButtonBox["3.1",
    ButtonData:>"Cell 3.1",
    ButtonStyle->"Hyperlink"],
  ". Instead,  a flat area in the middle grows with time, and then decreases \
in size until the initial condition is re-formed. This is how an ideal \
undamped string actually behaves, and it is only because it is difficult to \
actually see the rapid evolution of a plucked string that this behavior seems \
unusual to us."
}], "Text"],

Cell[TextData[{
  "\tTo better understand this motion, it is useful to  look at the time \
evolution of the center of the string, superimposed on the evolution of a \
second  point ",
  Cell[BoxData[
      \(TraditionalForm\`at\ x = L/4\)]],
  ", as shown in Cell ",
  ButtonBox["3.4",
    ButtonData:>"Cell 3.4",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\[IndentingNewLine]", 
    \(\(Plot[{y[L/4, t], y[L/2, t]}, {t, 0, 2  c/L}, 
        PlotStyle \[Rule] {{Blue, Thickness[0.01]}, Red}, 
        AxesLabel \[Rule] {"\<t\>", 
            TableForm[{{StyleForm["\<y[L/4,t]\>", FontColor \[Rule] Blue, \ 
                    FontWeight -> "\<Bold\>"], "\<,\>", 
                  StyleForm["\<y[L/2,t]\>", FontColor \[Rule] Red]}}, 
              TableSpacing \[Rule] 0]}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309009 0.596677 [
[.2619 .29651 -9 -9 ]
[.2619 .29651 9 0 ]
[.5 .29651 -3 -9 ]
[.5 .29651 3 0 ]
[.7381 .29651 -9 -9 ]
[.7381 .29651 9 0 ]
[.97619 .29651 -3 -9 ]
[.97619 .29651 3 0 ]
[1.025 .30901 0 -6 ]
[1.025 .30901 10 6 ]
[.01131 .07034 -24 -4.5 ]
[.01131 .07034 0 4.5 ]
[.01131 .18967 -24 -4.5 ]
[.01131 .18967 0 4.5 ]
[.01131 .42834 -18 -4.5 ]
[.01131 .42834 0 4.5 ]
[.01131 .54768 -18 -4.5 ]
[.01131 .54768 0 4.5 ]
[.02381 .64303 -53 0 ]
[.02381 .64303 53 12.3125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30901 m
.2619 .31526 L
s
[(0.5)] .2619 .29651 0 1 Mshowa
.5 .30901 m
.5 .31526 L
s
[(1)] .5 .29651 0 1 Mshowa
.7381 .30901 m
.7381 .31526 L
s
[(1.5)] .7381 .29651 0 1 Mshowa
.97619 .30901 m
.97619 .31526 L
s
[(2)] .97619 .29651 0 1 Mshowa
.125 Mabswid
.07143 .30901 m
.07143 .31276 L
s
.11905 .30901 m
.11905 .31276 L
s
.16667 .30901 m
.16667 .31276 L
s
.21429 .30901 m
.21429 .31276 L
s
.30952 .30901 m
.30952 .31276 L
s
.35714 .30901 m
.35714 .31276 L
s
.40476 .30901 m
.40476 .31276 L
s
.45238 .30901 m
.45238 .31276 L
s
.54762 .30901 m
.54762 .31276 L
s
.59524 .30901 m
.59524 .31276 L
s
.64286 .30901 m
.64286 .31276 L
s
.69048 .30901 m
.69048 .31276 L
s
.78571 .30901 m
.78571 .31276 L
s
.83333 .30901 m
.83333 .31276 L
s
.88095 .30901 m
.88095 .31276 L
s
.92857 .30901 m
.92857 .31276 L
s
.25 Mabswid
0 .30901 m
1 .30901 L
s
gsave
1.025 .30901 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07034 m
.03006 .07034 L
s
[(-0.4)] .01131 .07034 1 0 Mshowa
.02381 .18967 m
.03006 .18967 L
s
[(-0.2)] .01131 .18967 1 0 Mshowa
.02381 .42834 m
.03006 .42834 L
s
[(0.2)] .01131 .42834 1 0 Mshowa
.02381 .54768 m
.03006 .54768 L
s
[(0.4)] .01131 .54768 1 0 Mshowa
.125 Mabswid
.02381 .10017 m
.02756 .10017 L
s
.02381 .13001 m
.02756 .13001 L
s
.02381 .15984 m
.02756 .15984 L
s
.02381 .21951 m
.02756 .21951 L
s
.02381 .24934 m
.02756 .24934 L
s
.02381 .27918 m
.02756 .27918 L
s
.02381 .33884 m
.02756 .33884 L
s
.02381 .36868 m
.02756 .36868 L
s
.02381 .39851 m
.02756 .39851 L
s
.02381 .45818 m
.02756 .45818 L
s
.02381 .48801 m
.02756 .48801 L
s
.02381 .51785 m
.02756 .51785 L
s
.02381 .0405 m
.02756 .0405 L
s
.02381 .01067 m
.02756 .01067 L
s
.02381 .57751 m
.02756 .57751 L
s
.02381 .60735 m
.02756 .60735 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.3125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono-Bold
%%IncludeFont: Math2Mono-Bold
/Math2Mono-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
69.000 12.812 moveto
(@) show
75.000 12.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(L) show
%%IncludeResource: font Math2Mono-Bold
%%IncludeFont: Math2Mono-Bold
/Math2Mono-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
81.000 12.812 moveto
(\\220) show
87.000 12.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(4) show
93.000 12.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(,) show
99.000 12.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono-Bold
%%IncludeFont: Math2Mono-Bold
/Math2Mono-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
105.000 12.812 moveto
(D) show
111.000 12.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
111.000 12.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
111.000 12.812 moveto
(,) show
117.000 12.812 moveto
0.000 0.000 rmoveto
117.000 12.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
117.000 12.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
123.000 12.812 moveto
(@) show
129.000 12.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
135.000 12.812 moveto
(\\220) show
141.000 12.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(2) show
147.000 12.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(,) show
153.000 12.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
159.000 12.812 moveto
(D) show
165.000 12.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
0.000 0.000 0.000 setrgbcolor
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.01 w
.02381 .45799 m
.02499 .458 L
.02605 .45801 L
.02729 .45803 L
.02846 .45807 L
.03279 .45822 L
.03507 .4583 L
.03623 .45833 L
.0375 .45835 L
.03816 .45836 L
.03887 .45837 L
.04016 .45837 L
.04144 .45836 L
.04262 .45834 L
.04384 .45831 L
.04514 .45826 L
.04748 .45818 L
.05021 .45808 L
.05155 .45803 L
.05278 .45801 L
.05397 .45799 L
.05522 .45798 L
.05647 .45798 L
.05718 .45799 L
.05785 .458 L
.05901 .45803 L
.06007 .45806 L
.06244 .45815 L
.06505 .45825 L
.06649 .45831 L
.06783 .45835 L
.06897 .45838 L
.0702 .45839 L
.07086 .4584 L
.07156 .4584 L
.07281 .45839 L
.07352 .45838 L
.07416 .45836 L
.0756 .45832 L
.07819 .45821 L
.08126 .45807 L
.0826 .45802 L
.08332 .45799 L
.08408 .45797 L
.08535 .45794 L
.08654 .45793 L
.08724 .45793 L
.0879 .45793 L
.08914 .45795 L
.0898 .45797 L
Mistroke
.0905 .45799 L
.09177 .45804 L
.09463 .45818 L
.09732 .45833 L
.09864 .45839 L
.09985 .45844 L
.10096 .45847 L
.10212 .45849 L
.1033 .45849 L
.10458 .45847 L
.10939 .45822 L
.11193 .45804 L
.11332 .45794 L
.11462 .45786 L
.11576 .4578 L
.11697 .45776 L
.11763 .45775 L
.11833 .45775 L
.11956 .45776 L
.12069 .4578 L
.12175 .45786 L
.1229 .45795 L
.12413 .45807 L
.12708 .45843 L
.12853 .4586 L
.12987 .45875 L
.13109 .45886 L
.13237 .45893 L
.13366 .45894 L
.1344 .45891 L
.13508 .45887 L
.13637 .4587 L
.1376 .45846 L
.1387 .45815 L
.13989 .45771 L
.14257 .45634 L
.14506 .45457 L
.14968 .45008 L
.15467 .44396 L
.1637 .43188 L
.18429 .40643 L
.2254 .35474 L
.26499 .30514 L
.30307 .2574 L
.34359 .20651 L
.36231 .18323 L
.37216 .17023 L
.37713 .16486 L
.37996 .16253 L
.38261 .1609 L
Mistroke
.38404 .16025 L
.3854 .15978 L
.38662 .15947 L
.38731 .15933 L
.38795 .15924 L
.3887 .15915 L
.38941 .1591 L
.39073 .15908 L
.39147 .15909 L
.39216 .15912 L
.39291 .15917 L
.3937 .15924 L
.39625 .15953 L
.39899 .15987 L
.40032 .16001 L
.40157 .16012 L
.4027 .16019 L
.40393 .16025 L
.40508 .16027 L
.40635 .16027 L
.40699 .16025 L
.40768 .16023 L
.40892 .16018 L
.41009 .16011 L
.41133 .16002 L
.41353 .15986 L
.41597 .15969 L
.41733 .15962 L
.41857 .15957 L
.41927 .15955 L
.42004 .15954 L
.42076 .15953 L
.42142 .15953 L
.42271 .15955 L
.42336 .15956 L
.42407 .15958 L
.42537 .15963 L
.42657 .15969 L
.42929 .15984 L
.43063 .15991 L
.43189 .15997 L
.43312 .16002 L
.43425 .16006 L
.4353 .16008 L
.43641 .16009 L
.43752 .16009 L
.43875 .16007 L
.43994 .16004 L
.44123 .16 L
.44354 .1599 L
Mistroke
.44623 .15978 L
.44765 .15972 L
.44843 .15969 L
.44916 .15967 L
.45047 .15964 L
.45117 .15963 L
.45192 .15962 L
.45261 .15962 L
.45326 .15962 L
.45448 .15964 L
.45567 .15966 L
.45694 .1597 L
.45924 .15978 L
.46171 .15989 L
.46312 .15994 L
.46443 .15998 L
.46569 .16001 L
.46639 .16003 L
.46704 .16003 L
.46771 .16004 L
.46845 .16004 L
.46914 .16004 L
.46979 .16003 L
.47092 .16002 L
.47217 .15999 L
.47471 .1599 L
.47747 .1598 L
.47892 .15974 L
.48045 .1597 L
.4811 .15968 L
.48179 .15967 L
.48255 .15966 L
.48326 .15965 L
.48395 .15965 L
.48461 .15965 L
.48583 .15966 L
.487 .15968 L
.48828 .15971 L
.49087 .15979 L
.49329 .15988 L
.49551 .15996 L
.49615 .15998 L
.49685 .15999 L
.49812 .16001 L
.49883 .16002 L
.49958 .16003 L
.50029 .16003 L
.50093 .16002 L
.50219 .16001 L
.50289 .16 L
Mistroke
.50354 .15998 L
.506 .15991 L
.51071 .15974 L
.51207 .1597 L
.51335 .15967 L
.51451 .15966 L
.51576 .15965 L
.51685 .15965 L
.51805 .15967 L
.51931 .15969 L
.52049 .15973 L
.52486 .15989 L
.52739 .15997 L
.52866 .16001 L
.52938 .16002 L
.53005 .16003 L
.53126 .16004 L
.53235 .16004 L
.53362 .16002 L
.53481 .16 L
.53611 .15996 L
.53749 .15992 L
.53996 .15982 L
.54133 .15976 L
.54282 .15971 L
.5435 .15968 L
.54423 .15966 L
.54553 .15964 L
.54674 .15962 L
.54788 .15962 L
.54913 .15963 L
.54983 .15965 L
.55047 .15966 L
.55152 .15969 L
.55267 .15973 L
.55499 .15983 L
.55753 .15995 L
.55892 .16001 L
.56024 .16005 L
.56147 .16008 L
.56216 .16009 L
.5628 .16009 L
.56393 .16009 L
.56513 .16007 L
.56627 .16004 L
.5673 .16001 L
.56964 .1599 L
.57385 .15967 L
.57499 .15962 L
.57621 .15957 L
Mistroke
.57691 .15955 L
.57754 .15954 L
.57878 .15953 L
.57994 .15954 L
.58119 .15956 L
.58237 .15961 L
.58346 .15966 L
.58816 .15998 L
.5894 .16007 L
.59075 .16016 L
.59202 .16022 L
.5932 .16026 L
.59429 .16027 L
.5955 .16026 L
.59677 .16022 L
.59795 .16015 L
.59904 .16007 L
.60004 .15997 L
.60229 .15972 L
.60461 .15943 L
.60589 .15928 L
.6071 .15917 L
.60778 .15913 L
.60852 .15909 L
.60982 .15908 L
.61114 .15914 L
.61236 .15928 L
.61362 .15952 L
.61481 .15984 L
.61611 .16031 L
.6175 .16096 L
.62035 .16275 L
.62295 .16494 L
.63283 .17667 L
.64198 .18885 L
.66272 .21442 L
.70191 .26369 L
.74355 .31585 L
.78368 .36619 L
.82229 .41456 L
.84188 .43935 L
.84721 .44637 L
.85225 .45212 L
.85504 .45464 L
.8565 .45574 L
.85806 .45672 L
.85937 .45739 L
.86081 .45798 L
.86212 .45839 L
.86335 .45866 L
Mistroke
.86461 .45884 L
.86533 .4589 L
.86599 .45893 L
.8672 .45894 L
.8685 .45889 L
.86977 .45879 L
.87097 .45866 L
.87321 .45839 L
.87569 .45809 L
.87704 .45796 L
.87831 .45786 L
.87897 .45782 L
.87967 .45779 L
.88046 .45776 L
.88118 .45775 L
.88183 .45775 L
.88253 .45775 L
.88382 .45779 L
.88855 .45807 L
.89104 .45825 L
.8924 .45834 L
.89366 .45841 L
.89477 .45845 L
.89596 .45848 L
.89728 .45849 L
.89848 .45848 L
.89957 .45846 L
.90075 .45842 L
.9029 .45832 L
.90746 .45807 L
.90857 .45802 L
.90976 .45798 L
.91106 .45795 L
.91229 .45793 L
.91298 .45793 L
.91373 .45793 L
.91444 .45794 L
.9151 .45795 L
.91635 .45798 L
.91768 .45803 L
.92266 .45825 L
.92398 .4583 L
.92538 .45835 L
.92612 .45837 L
.92692 .45838 L
.92765 .45839 L
.92833 .4584 L
.92902 .4584 L
.92968 .45839 L
.93091 .45838 L
Mistroke
.9316 .45836 L
.93223 .45835 L
.93367 .4583 L
.93848 .45811 L
.9398 .45806 L
.94118 .45802 L
.94236 .458 L
.94366 .45798 L
.94471 .45798 L
.94566 .45798 L
.94676 .458 L
.94779 .45802 L
.94964 .45807 L
.95164 .45814 L
.95521 .45828 L
.95618 .45831 L
.95723 .45833 L
.95822 .45835 L
.95913 .45836 L
.96019 .45837 L
.96134 .45837 L
.96243 .45835 L
.96344 .45834 L
.9646 .45831 L
.96565 .45827 L
.96801 .45819 L
.97004 .45811 L
.9711 .45808 L
.97223 .45805 L
.97321 .45802 L
.97429 .458 L
.97528 .45799 L
.97619 .45799 L
Mfstroke
1 0 0 r
.5 Mabswid
.02381 .60332 m
.06244 .55939 L
.10458 .5061 L
.14415 .45637 L
.18221 .40885 L
.22272 .35825 L
.26171 .30926 L
.30316 .25719 L
.34309 .20735 L
.3815 .15934 L
.42237 .10783 L
.46172 .0582 L
.48147 .03398 L
.49012 .02165 L
.49249 .0189 L
.49379 .01762 L
.49501 .01661 L
.49615 .01585 L
.49739 .01523 L
.49852 .01487 L
.49955 .01472 L
.50074 .01474 L
.50186 .01497 L
.50308 .01544 L
.50439 .01619 L
.50576 .01723 L
.50706 .01843 L
.5095 .02117 L
.51896 .03461 L
.53984 .06011 L
.57817 .10853 L
.61895 .15991 L
.65822 .20894 L
.69597 .2561 L
.73617 .30655 L
.77486 .35519 L
.816 .40666 L
.85562 .45609 L
.89373 .5039 L
.93429 .55531 L
.95438 .57942 L
.96347 .59254 L
.96597 .59593 L
.96861 .59905 L
.97086 .60114 L
.97214 .60205 L
.97334 .60268 L
.97406 .60296 L
.97471 .60315 L
.97547 .60328 L
Mistroke
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00@_ooool00ol0003oooooooooo`3oooooobCooooo
0012ooooo`03o`000?oooooooooo0?oooooo9?ooool004;ooooo00?o0000ooooooooool0oooooolT
ooooo`00@_ooool2o`000?oooooo9Oooool004;ooooo00?o0000ooooooooool0POooool3ool009oo
oooo0012ooooo`03o`000?oooooooooo083ooooo0_oo00000oooooooo`00ool0002Nooooo`00@_oo
ool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Vooo
ool004;ooooo00?o0000ooooooooool0Ooooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo09_ooooo0012ooooo`03o`000?oooooooooo07kooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`2Jooooo`00@_ooool00ol0003oooooooooo`1nooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool0V_ooool004;ooooo00?o0000ooooooooool0OOooool00ooo003ooooo
ooooo`07ooooo`03ool00?oooooooooo09Wooooo0012ooooo`;o0000OOooool00ooo003ooooooooo
o`08ooooo`03ool00?oooooooooo09Wooooo0012ooooo`03o`000?oooooooooo07_ooooo00?oo`00
ooooooooool02_ooool00ooo003oooooooooo`2Hooooo`00@_ooool00ol0003oooooooooo`1joooo
o`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0Uoooool004;ooooo00?o0000oooooooo
ool0NOooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo09Kooooo0012ooooo`03o`00
0?oooooooooo07Sooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`2Eooooo`00@_oo
ool00ol0003oooooooooo`1gooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0U?oo
ool002Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool0Moooool00ooo003oooooooooo`0Cooooo`03ool00?oo
oooooooo09?ooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1fooooo`03ool00?oooooooooo01Cooooo00?o
o`00ooooooooool0Toooool001oooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0000Kooooo00?o0000ooooooooool0MOooool00ooo003oooooooooo`0Fooooo`03ool00?oo
oooooooo09;ooooo000Wooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMoooo
ool00007ooooo`?o0000M?ooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo097ooooo
000Wooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03
o`000?oooooooooo07?ooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`2@ooooo`00
9oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003o
ooooooooo`1cooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool0Soooool002Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooooooo
ool0L_ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo08kooooo000Wooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo077o
oooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`2=ooooo`00@_ooool00ol0003ooooo
ooooo`1`ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool0SOooool004;ooooo00?o
0000ooooooooool0L?ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo08cooooo0012
ooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`2;
ooooo`00@_ooool2o`0006oooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`2:oooo
o`00@_ooool00ol0003oooooooooo`1]ooooo`03ool00?oooooooooo02Oooooo00?oo`00oooooooo
ool0ROooool004;ooooo00?o0000ooooooooool0K?ooool00ooo003oooooooooo`0Yooooo`03ool0
0?oooooooooo08Sooooo0012ooooo`03o`000?oooooooooo06cooooo00?oo`00ooooooooool0:Ooo
ool00ooo003oooooooooo`28ooooo`00@_ooool00ol0003oooooooooo`1[ooooo`03ool00?oooooo
oooo02_ooooo00?oo`00ooooooooool0Qoooool004;ooooo00?o0000ooooooooool0J_ooool00ooo
003oooooooooo`0]ooooo`03ool00?oooooooooo08Kooooo0012ooooo`03o`000?oooooooooo06Wo
oooo00?oo`00ooooooooool0;oooool00ooo003oooooooooo`25ooooo`00@_ooool00ol0003ooooo
ooooo`1Yooooo`03ool00?oooooooooo02oooooo00?oo`00ooooooooool0QOooool004;ooooo00?o
0000ooooooooool0J?ooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo08Cooooo0012
ooooo`;o0000J?ooool00ooo003oooooooooo`0cooooo`03ool00?oooooooooo08?ooooo0012oooo
o`03o`000?oooooooooo06Kooooo00?oo`00ooooooooool0=Oooool00ooo003oooooooooo`22oooo
o`00@_ooool00ol0003oooooooooo`1Vooooo`03ool00?oooooooooo03Gooooo00?oo`00oooooooo
ool0P_ooool004;ooooo00?o0000ooooooooool0IOooool00ooo003oooooooooo`0gooooo`03ool0
0?oooooooooo087ooooo0012ooooo`03o`000?oooooooooo06Cooooo00?oo`00ooooooooool0>Ooo
ool00ooo003oooooooooo`20ooooo`00@_ooool00ol0003oooooooooo`1Tooooo`03ool00?oooooo
oooo03Wooooo00?oo`00ooooooooool0P?ooool004;ooooo00?o0000ooooooooool0Hoooool00ooo
003oooooooooo`0kooooo`03ool00?oooooooooo07oooooo0012ooooo`03o`000?oooooooooo06;o
oooo00?oo`00ooooooooool0?Oooool00ooo003oooooooooo`1nooooo`00@_ooool2o`00067ooooo
00?o003oool00?l00?l0@?l00?l00ooo003oooooooooo`1mooooo`00@_ooool00ol0003ooooooooo
o`1Oooooo`;o003o00?oo`00o`00ool00?l0?ol00?l00ooo003o003oooooo`1mooooo`00@_ooool0
0ol0003oooooooooo`1Nooooo`;o003o00?oo`00ooooooooool0@?ooool00ol00?ooo`00ooooo`1m
ooooo`00@_ooool00ol0003oooooooooo`1Mooooo`;o003o00?oo`00ooooooooool0@Oooool2o`00
o`03ool00?oooooooooo07_ooooo0012ooooo`03o`000?oooooooooo05gooooo00?o003oool00?oo
ool0A?ooool2o`00o`03ool00?oooooooooo07[ooooo0012ooooo`03o`000?oooooooooo05cooooo
00?o003oool00?l00?l0A_ooool2o`00o`03ool00?oooooooooo07Wooooo000Wooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo05_ooooo
00?o003oool00?l00?l0B?ooool00ol00?ooo`00o`00o`1jooooo`009oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`1Kooooo`03ool00?l00?oooooo04Wooooo00?o003oool00?l00?l0NOooool001oooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o
0000F_ooool00ol00?ooo`00o`00o`1;ooooo`03o`00oooo003o003o07Sooooo000Wooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo05Wo
oooo00?o003oool00?l00?l0COooool00ol00?ooo`00ooooo`1gooooo`009oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Hooooo`03
o`00oooo003o003o04kooooo00?o003oool00?l00?l0Moooool002Oooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Eoooool00ol00?oo
o`00o`00o`1@ooooo`03o`00oooo003o003o07Kooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0E_ooool00ol0
0?ooo`00o`00o`1Booooo`03o`00oooo003o003o07Gooooo000Wooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0EOooool0
0ol00?ooo`00o`00o`1Dooooo`03o`00oooo003o003o07Cooooo0012ooooo`03o`000?oooooooooo
05Gooooo00?o003oool00?ooool0EOooool00ol00?ooo`00o`00o`1cooooo`00@_ooool00ol0003o
ooooooooo`1Dooooo`03o`00oooo003o003o05Oooooo00?oo`00o`00ool00?l0L_ooool004;ooooo
00?o0000ooooooooool0Doooool00ol00?ooo`00o`00o`1Iooooo`03ool00?l00?oooooo077ooooo
0012ooooo`;o0000Doooool00ol00?ooo`00o`00o`1Jooooo`03o`00oooo003o003o077ooooo0012
ooooo`03o`000?oooooooooo057ooooo00?o003oool00?l00?l0G?ooool00ol00?ooo`00o`00o`1`
ooooo`00@_ooool00ol0003oooooooooo`1Aooooo`03o`00oooo003ooooo05gooooo00?o003oool0
0?l00?l0Koooool004;ooooo00?o0000ooooooooool0D?ooool00ol00?ooo`00o`00o`1Oooooo`03
o`00oooo003o003o06kooooo0012ooooo`03o`000?oooooooooo04oooooo00?o003oool00?l00?l0
HOooool00ol00?ooo`00ooooo`1]ooooo`00@_ooool00ol0003oooooooooo`1>ooooo`03o`00oooo
003o003o06;ooooo00?o003oool00?l00?l0KOooool004;ooooo00?o0000ooooooooool0C_ooool0
0ol00?ooo`00ooooo`1Sooooo`03o`00oooo003o003o06cooooo0012ooooo`03o`000?oooooooooo
04gooooo00?o003oool00?l00?l0IOooool00ol00?ooo`00o`00o`1[ooooo`00@_ooool2o`0004go
oooo00?o003oool00?l00?l0Ioooool00ol00?ooo`00ooooo`1Zooooo`00@_ooool00ol0003ooooo
ooooo`1;ooooo`03o`00oooo003o003o06Sooooo0_l00?l00ooo003oooooooooo`1Xooooo`00@_oo
ool00ol0003oooooooooo`1:ooooo`03o`00oooo003o003o06[ooooo0_l00?l00ooo003ooooooooo
o`1Wooooo`00@_ooool00ol0003oooooooooo`1:ooooo`03o`00oooo003ooooo06_ooooo00?o003o
ool00?l00?l0J?ooool004;ooooo00?o0000ooooooooool0=?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`07odA4A?l0003o0000oc8b<_l00?ooo`00o`00o`0dooooo`Co0000
00?o410@ooooooooool0<_ooool00ol00?ooo`00o`00o`03o`000003oa0@4?oooooooooo00;ooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0=?ooool5o`0001[ooooo0012ooooo`03o`00
0?oooooooooo03Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00ol00?oo
o`00o`00o`0gooooo`03o`000?oooooooooo03Gooooo00Co003oool00?oooooo00001_ooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool0<oooool01OnHV9So8B4Qonk^k_ooooooA4A401[ooooo0012oooo
o`03o`000?oooooooooo03Cooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00oooo003o
003o03Sooooo00?o0000ooooooooool0=Oooool2o`00o`03ool00?l0003ooooo013ooooo00?o0000
ooooooooool0<oooool00onHV9So8B4Qonk^kP0Kooooo`00@_ooool00ol0003oooooooooo`0doooo
o`05o`000?ooooooooooooooool000003Oooool01?l00?ooo`00o`00oolb<S8hooooo`03o`000?oo
oooooooo03Kooooo0_l00?l00ooo003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Gooooo00?o
V9RHob4Q8Oo^k^h06_ooool004;ooooo0_l0000eooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o003oool00?lb<S;oc<c<03Sooooo00?o0000ooooooooool0=oooool00ol00?ooo`00
o`00o`0<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0=oooool00omgMgOoIVIVooooo`0Iooooo`00
@_ooool00ol0003oooooooooo`0dooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol00?oo
o`00o`00o`0jooooo`03o`000?oooooooooo03Sooooo00?o003oool00?ooool02oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo01Sooooo0012ooooo`03o`000?oooooooooo03Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`00oooo003o003o03_ooooo00?o0000oooooooo
ool0>?ooool2o`00o`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0=_ooool01Ol0003o
^[ZjoooooonHV9So410@01[ooooo0012ooooo`03o`000?oooooooooo03Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0:ooooo`03o`00oooo003o003o00?o0000=oooool00omEEEGoIVIVo`00000hoooo
o`03oeEEEOmVIVKo000000;o003o00?oo`00ooooooooool02?ooool4o`0003Gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00Jooooo`00@_ooool00ol0003oooooooooo`13ooooo`03ool00?l00?oooooo
07Wooooo00?o003oool00?l00?l0HOooool004;ooooo00?o0000ooooooooool0@_ooool00ol00?oo
o`00o`00o`1kooooo`03o`00oooo003ooooo063ooooo0012ooooo`03o`000?oooooooooo047ooooo
00?o003oool00?l00?l0O?ooool2o`00o`03ool00?oooooooooo05Gooooo00GoV9RHo`000?l0003o
A4A4okZj^P04ooooo`00@_ooool00ol0003oooooooooo`10ooooo`03o`00oooo003o003o07kooooo
0_l00?l00ooo003oooooooooo`1Dooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool004;ooooo
00?o0000ooooooooool0?oooool00ol00?ooo`00o`00o`20ooooo`;o003o00?oo`00ooooooooool0
Doooool00ol0003oooooooooo`06ooooo`00>ooooom9o`000003ool00?l00?oo0000083o00000_l0
0?l00ooo003o0000o`000018o`0000_ooooo00?o0000ooooooooool01_ooool004;ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooo003o003o00cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0_l00?l0
0ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`06ooooo`00@_ooool00ol0003oooooooooo`0mooooo`03o`00oooo003o003o
08Cooooo0_l00?l00ooo003oooooooooo`1?ooooo`03oa0@4?l0003o000000?o00001Oooool004;o
oooo00?o0000ooooooooool0??ooool00ol00?ooo`00o`00o`26ooooo`;o003o00?oo`00oooooooo
ool0D?ooool00ol0003oooooooooo`06ooooo`00@_ooool00ol0003oooooooooo`0kooooo`03o`00
oooo003o003o08Oooooo0ol00?l00ooo003oooooooooo`1?ooooo`03o`000?oooooooooo00Kooooo
0012ooooo`03o`000?oooooooooo03[ooooo00?o003oool00?l00?l0ROooool2o`00o`03ool00?oo
oooooooo05Sooooo0012ooooo`03o`000?oooooooooo03Wooooo00?o003oool00?l00?l0Roooool2
o`00o`03ool00?oooooooooo05Oooooo0012ooooo`03o`000?oooooooooo03Wooooo00?oo`00o`00
ooooool0S?ooool2o`00o`03ool00?oooooooooo05Kooooo0012ooooo`;o0000>Oooool00ol00?oo
o`00o`00o`2>ooooo`;o003o00?oo`00ooooooooool0EOooool004;ooooo00?o0000ooooooooool0
=oooool00ol00?ooo`00o`00o`2?ooooo`;o003o00?oo`00ooooooooool0EOooool004;ooooo00?o
0000ooooooooool0=_ooool00ol00?ooo`00o`00o`2Aooooo`;o003o00?oo`00ooooooooool0E?oo
ool004;ooooo00?o0000ooooooooool0=Oooool00ol00?ooo`00o`00o`2Cooooo`;o003o00?oo`00
ooooooooool0Doooool004;ooooo00?o0000ooooooooool0=?ooool00ol00?ooo`00o`00o`2Eoooo
o`;o003o00?oo`00ooooooooool0D_ooool004;ooooo00?o0000ooooooooool0=?ooool00ooo003o
003oooooo`2Eooooo`?o003o00?oo`00ooooooooool0DOooool004;ooooo00?o0000ooooooooool0
<oooool00ol00?ooo`00o`00o`2Gooooo`;o003o00?oo`00ooooooooool0DOooool004;ooooo00?o
0000ooooooooool0<_ooool00ol00?ooo`00o`00o`2Iooooo`;o003o00?oo`00ooooooooool0D?oo
ool004;ooooo0_l0000booooo`03o`00oooo003o003o09_ooooo0_l00?l00ooo003oooooooooo`1?
ooooo`00@_ooool00ol0003oooooooooo`0aooooo`03ool00?l00?oooooo09cooooo0_l00?l00ooo
003oooooooooo`1>ooooo`00@_ooool00ol0003oooooooooo`0`ooooo`03o`00oooo003o003o09go
oooo0ol00?l00ooo003oooooooooo`1=ooooo`00@_ooool00ol0003oooooooooo`0_ooooo`03o`00
oooo003o003o09oooooo0_l00?l00ooo003oooooooooo`1=ooooo`00@_ooool00ol0003ooooooooo
o`0^ooooo`03o`00oooo003o003o0:7ooooo0_l00?l00ooo003oooooooooo`1<ooooo`00@_ooool0
0ol0003oooooooooo`0^ooooo`03ool00?l00?oooooo0:;ooooo0_l00?l00ooo003oooooooooo`1;
ooooo`00@_ooool00ol0003oooooooooo`0]ooooo`03o`00oooo003o003o0:Cooooo0_l00?l00ooo
003oooooooooo`1:ooooo`00@_ooool00ol0003oooooooooo`0/ooooo`03o`00oooo003o003o0:Ko
oooo00?o003oool00?l00?l0Boooool004;ooooo00?o0000ooooooooool0;?ooool00ooo003o003o
ooooo`2Wooooo`03o`00oooo003ooooo04[ooooo0012ooooo`;o0000;?ooool00ol00?ooo`00o`00
o`2Xooooo`;o003o00?oo`00ooooooooool0B?ooool004;ooooo00?o0000ooooooooool0:_ooool0
0ol00?ooo`00o`00o`2Zooooo`;o003o00?oo`00ooooooooool0Aoooool004;ooooo00?o0000oooo
ooooool0:Oooool00ol00?ooo`00o`00o`2/ooooo`;o003o00?oo`00ooooooooool0A_ooool004;o
oooo00?o0000ooooooooool0:Oooool00ooo003o003oooooo`2]ooooo`03o`00oooo003o003o04Oo
oooo0012ooooo`03o`000?oooooooooo02Sooooo00?o003oool00?l00?l0[oooool00ol00?ooo`00
o`00o`16ooooo`00@_ooool00ol0003oooooooooo`0Wooooo`03o`00oooo003o003o0;7ooooo00?o
003oool00?ooool0AOooool002Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool09_ooool00ol00?ooo`00o`00o`2booooo`;o003o00?o
o`00ooooooooool0@oooool002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool09Oooool00ol00?ooo`00
o`00o`2dooooo`;o003o00?oo`00ooooooooool0@_ooool002Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Tooooo`03o`00oooo003o003o0;Kooooo
0_l00?l00ooo003oooooooooo`11ooooo`009oooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Sooooo`03o`00oooo003o003o0;Sooooo
0_l00?l00ooo003oooooooooo`10ooooo`009oooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Rooooo`03o`00oooo003o003o0;[ooooo
00?o003oool00?l00?l0@Oooool002Oooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool08Oooool2o`00o`03ool00?oooooooooo0;[ooooo
00?o003oool00?l00?l0@?ooool002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0Pooooo`;o003o00?oo`00oooooooo
ool0_?ooool00ol00?ooo`00ooooo`0oooooo`009oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo023ooooo00?o003oool0
0?ooool0__ooool2o`00o`03ool00?oooooooooo03gooooo0012ooooo`03o`000?oooooooooo01oo
oooo00?o003oool00?l00?l0`?ooool2o`00o`03ool00?oooooooooo03cooooo0012ooooo`03o`00
0?oooooooooo01kooooo00?o003oool00?l00?l0`_ooool2o`00o`03ool00?oooooooooo03_ooooo
0011oooooaoo003o00Goooooo`00ool00?ooo`00o`00o`34ooooo`;o003o00Coo`00o`00oooooooo
oooo7_l00?lKooooo`00@OoooolRo`00o`03ool00?oooooooooo0<Cooooo00?o003oool00?l00?l0
8?l00?lKooooo`00@_ooool00ol0003oooooooooo`0Iooooo`Co003o00?oo`00ooooooooool0aooo
ool01?oo003o003oo`00ool00?lhooooo`00@_ooool00ol0003oooooooooo`0Looooo`03ool00?oo
oooooooo0<Wooooo00?oo`00ooooooooool0>?ooool004;ooooo00?o0000ooooooooool06oooool0
0ooo003oooooooooo`3;ooooo`03ool00?oooooooooo03Oooooo0012ooooo`03o`000?oooooooooo
01[ooooo00?oo`00ooooooooool0c?ooool00ooo003oooooooooo`0gooooo`00@_ooool00ol0003o
ooooooooo`0Jooooo`03ool00?oooooooooo0<gooooo00?oo`00ooooooooool0=_ooool004;ooooo
00?o0000ooooooooool06Oooool00ooo003oooooooooo`3?ooooo`03ool00?oooooooooo03Gooooo
0012ooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool0dOooool00ooo003ooooooooo
o`0dooooo`00@_ooool2o`0001Sooooo00?oo`00ooooooooool0doooool00ooo003oooooooooo`0c
ooooo`00@_ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0=?ooooo00?oo`00oooo
ooooool0<oooool004;ooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`3Eooooo`03
ool00?oooooooooo03;ooooo0012ooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0
eoooool00ooo003oooooooooo`0aooooo`00@_ooool00ol0003oooooooooo`0Dooooo`03ool00?oo
oooooooo0=Wooooo00?oo`00ooooooooool0<?ooool004;ooooo00?o0000ooooooooool04oooool0
0ooo003oooooooooo`3Jooooo`03ool00?oooooooooo033ooooo0012ooooo`03o`000?oooooooooo
01?ooooo00?oo`00ooooooooool0foooool00ooo003oooooooooo`0_ooooo`00@_ooool00ol0003o
ooooooooo`0Booooo`03ool00?oooooooooo0=gooooo00?oo`00ooooooooool0;_ooool004;ooooo
0_l0000Booooo`03ool00?oooooooooo0=oooooo00?oo`00ooooooooool0;Oooool004;ooooo00?o
0000ooooooooool04?ooool00ooo003oooooooooo`3Qooooo`03ool00?oooooooooo02cooooo0012
ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0hOooool00ooo003oooooooooo`0/
ooooo`00@_ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo0>?ooooo00?oo`00oooo
ooooool0:oooool004;ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`3Uooooo`03
ool00?oooooooooo02[ooooo0012ooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0
ioooool00ooo003oooooooooo`0Yooooo`009oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03ool0
0?oooooooooo0>Sooooo00?oo`00ooooooooool0:?ooool002Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo
00?oo`00ooooooooool0jOooool00ooo003oooooooooo`0Xooooo`009oooool01Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`?o00002oooool00ooo003oooooooooo`3[ooooo`03ool0
0?oooooooooo02Oooooo000Wooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgM
ooooool00007ooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool0k?ooool00ooo003o
ooooooooo`0Vooooo`009oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo00001oooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo0>kooooo00?oo`00oooo
ooooool09Oooool002Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`3`ooooo`03ool00?oooooooooo
02Cooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0lOooool00ooo003oooooooooo`0Toooo
o`009oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0
003oooooooooo`08ooooo`03ool00?oooooooooo0?;ooooo00?oo`00ooooooooool08oooool004;o
oooo00?o0000ooooooooool01oooool00ooo003oooooooooo`3dooooo`03ool00?oooooooooo02;o
oooo0012ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0m_ooool00ooo003ooooo
ooooo`0Qooooo`00@_ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo0?Sooooo00?o
o`00ooooooooool08?ooool004;ooooo0_l00005ooooo`03ool00?oooooooooo0?[ooooo00?oo`00
ooooooooool07oooool004;ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`3koooo
o`03ool00?oooooooooo01oooooo0012ooooo`03o`000?oooooooooo00;ooooo00?oo`00oooooooo
ool0oOooool00ooo003oooooooooo`0Nooooo`00@_ooool01Ol0003oooooooooooooooooo`000?oo
oooo0_ooool00ooo003oooooooooo`0Mooooo`00@_ooool01?l0003ooooooooooooo003oooooo`Co
oooo00?oo`00ooooooooool07?ooool004;ooooo00?o0000oooooooo0000ooooool5ooooo`03ool0
0?oooooooooo01cooooo0012ooooo`03o`000?oo003ooooo0?oooooo1_ooool2ool001cooooo0012
ooooo`03ool00?oooooooooo0?oooooo1oooool2ool001_ooooo0012ooooo`;o0000oooooolUoooo
o`00@_ooool00ol0003oooooooooo`3oooooobCooooo0012ooooo`03o`000?oooooooooo0?oooooo
9?ooool004;ooooo00?o0000ooooooooool0oooooolTooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`000_ooool3o`00o`03oa0@oooooooooooo03kooooo0ooo00000ooo413ooooo
ooooo`3ooooooagooooo0004ooooo`03oa0@oonj^_oooooo00Kooooo0ol00?lJooooo`03o`00oonj
^_oooooo00cooooo0ol00?l4ooooo`03o`000?nj^[[ooooo00Gooooo00?ooa0@oonj^_ooool01_oo
ool2ool001[ooooo00?oo`00oonj^_ooool03?ooool2ool00>[ooooo0004ooooo`03oiRHoolb<_oo
oooo00Kooooo0_l00?l;ooooo`03odA4oonj^_oooooo00gooooo0_lb<_l>ooooo`;o003o1?ooool2
oc8b<PKooooo00?ooiRHoolb<_ooool01_ooool00ooo003oooooooooo`0:ooooo`03oolQ8OoogMgo
oooo00cooooo0_oo<S8>ooooo`03ool00?oooooooooo0>Sooooo0004ooooo`03omgMool00?oo^[[o
00Kooooo0_l00?l2ooooo`03oa0@ool00?oo003o00Co003o0_ooool00omgMooo<S;oooooo`06oooo
o`;o003o00?o413oooooooooool00_ooool00on7Qooo003ookZjo`04ooooo`05oiRHool00?oo003o
odA4oonj^_l01?ooool2o`00o`Cooooo00?oQhN7o`000?nj^[X01Oooool00ooogMgoo`00oonj^P06
ooooo`05ool00?oooooooooooooooooo41001_oo0002ooooo`03oonHV?ooEEGooooo00Cooooo1Ooo
0003ooooo`03oon7Qooo003ookZj00Gooooo00GooiRHool00?oo003oodA4oonj^P03ooooo`03ool0
0?oooooooooo0>Sooooo0004ooooo`03oeEEoomgMoooA4Co00Kooooo0_l00?l4ooooo`05o`00oooo
ooooooooooooool00?l00_ooool00oo^k_oo003oomgMo`07ooooo`03o`00oooooooooooo00?ooooo
00?oc<coo`00ool@4?l01?ooool01Ol@4?oo^[[oonk^oomgMooo413o00Cooooo0_l00?l4ooooo`03
olc<c?l0003o410@00Gooooo00?ooeEEoomgMoooA4@01_ooool00ooo003oooooooooo`03ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oomgMooooo`03ooooo`05oonHV?oo8B7oonk^
ooooooooA4@00oooool00oooc<coo`00ool@4005ooooo`05ool@4?oo^[[oonk^oomgMooo41000ooo
ool00ooo003oooooooooo`3Xooooo`000oooool01OoMgOoo413ooooooolQ8OoogMgo00Gooooo0_l0
0?l4ooooo`05o`00ooooooooooooooooool00?l00oooool2oeEEo`Cooooo1Ol00?l;ooooo`03o`00
oooooooooooo00Kooooo0_l00?l;ooooo`05oooMgOoo413ooooooolQ8OoogMd01Oooool00ooo003o
ooooooooo`03ooooo`05ool00?oooooooooooooooooo00000oooool2oomgM`Gooooo00?ooiRHoolQ
8Oook^h03?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo0>Sooooo0003ooooo`05
ofIVoon7QooooooooiRHoomEEOl01Oooool2o`00o`Cooooo00?o003oooooooooool01Oooool00ooM
gOoo003oomgMo`03ooooo`04odA4oooMgOooooooo`00o`cooooo00?o003oooooooooool01_ooool2
o`00o`_ooooo00GoofIVoon7QooooooooiRHoomEE@05ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool01Oooool00oook^kooa0@ooo^kP05ooooo`03oonHV?oo8B7oonk^00_ooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`3Xooooo`000_ooool00oo^k_oo003oonk^o`02
ooooo`03o`00oooMgOoooooo00?ooooo0_l00?l4ooooo`03o`00oooooooooooo00Kooooo0_mEEOl3
ooooo`04omgMoomEEOooooooo`00o`cooooo00?o003oooooooooool01_ooool2o`00o`[ooooo00?o
onk^ool00?ook^h00_ooool00ooo003oomgMooooo`03ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool01_ooool00oooEEGooiRHooooo`05ooooo`03oomgMoooIVKooooo00[ooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`3Xooooo`000_ooool01?l@4?oo003oo`00oooo
ool2o`00o`03oa0@oooooooooooo00;ooooo0_l00?l4ooooo`03o`00oooooooooooo00Kooooo00?o
gMgoo`00ooo^k_l00oooool00omgMoooc<coo`00o`0:ooooo`03oa0@ool00?oo003o00?o003o1Ooo
ool2o`00o`[ooooo00Cooa0@ool00?oo003ooooo0_oo00000ooo413oooooooooo`02ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool01_ooool00ooogMgooa0@ooooo`06ooooo`03ool0
0?oooooooooo00Oooooo00?ooa0@ool00?oo00000ooo0004ooooo`03ool00?oooooooooo0>Sooooo
000=ooooo`;o003o1?ooool00ol00?ooooooooooo`07ooooo`03oc8boomgMooooooo00;ooooo00?o
k^koodA4ool00?l03?ooool00ol00?ooooooooooo`06ooooo`;o003o5Oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00Oooooo00WooeEEoonHV?ooooooooooool00?oo^[[ooooooonH
V?oo41002oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo0>Sooooo000=ooooo`?o
003o00?ooooooa0@ool00?l00ol00?l7ooooo`03okZjoom4A?oooooo00?ooooo00?oMgOoo`00oooo
ool02oooool00ol00?ooooooooooo`05ooooo`?o003o5Oooool2ool000;ooooo00?ooa0@ool00?oo
00000_oo0007ooooo`09oonj^_ooA4CoooooooooooooV9Sooa0@ool00?oo8B7oolc<00_ooooo00?o
o`00ooooooooool01?ooool2ool00>[ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.497037, -0.595693, \
0.00937789, 0.00748421}}]
}, Open  ]],

Cell[TextData[{
  "The center of the string oscillates back and forth in a triangle wave \
(thin line). The point at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L/4\)]],
  " only starts to move after a certain period of time (thick line), which is \
required by the fact that waves have a finite propagation speed on the \
string. Recall that our initial condition is formed by pulling on the center \
of the string, holding it off axis against the string tension, and then \
releasing the string. Once the center has been released, it takes some time \
for this information to propagate to points far from the center. We will soon \
show that the speed of propagation of this signal is ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ". Thus, the point at ",
  Cell[BoxData[
      \(TraditionalForm\`L/4\)]],
  " does not learn that the point at ",
  Cell[BoxData[
      \(TraditionalForm\`L/2\)]],
  " has been released until time ",
  Cell[BoxData[
      \(TraditionalForm\`t = L/\((4  c)\)\)]],
  " has elapsed. Only after this time does the point at ",
  Cell[BoxData[
      \(TraditionalForm\`L/4\)]],
  " begin to move."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2. Example 2: Travelling Disturbance", "Subsubsection"],

Cell["\<\
 The finite propagation speed of travelling disturbances can be \
easily seen directly by considering a different initial condition, which is \
localized in the middle of the string:\
\>", "Text"],

Cell[TextData[{
  "\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(y\_o\)(
              x) = \[ExponentialE]\^\(\(-50\) \((x/L - 1/2)\)\^2\)\), ",", 
          "\[IndentingNewLine]", 
          RowBox[{
            FormBox[\(\(v\_o\)(x)\  = \ 0\),
              "TraditionalForm"], "."}]}], TraditionalForm]]],
  "\t"
}], "Text"],

Cell[TextData[{
  "The resulting Fourier series solution will still have the form of Eq. ",
  ButtonBox["(3.1.25)",
    ButtonData:>"(3.1.25)",
    ButtonStyle->"Hyperlink"],
  " but the coefficients  ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " will be different. Now,  it is best to simply solve for these \
coefficients numerically:"
}], "Text"],

Cell[BoxData[{
    \(\(L\  = \ 1;\)\ \), "\n", 
    \(A[n_]\  := \(\(2/L\) \((\ 
          NIntegrate[\ \[ExponentialE]\^\(\(-50\) \((x/L - 1/2)\)\^2\)\ Sin[
                n\ Pi\ x/L], {x, 0, L}]\ )\)\(\ \)\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.5"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["3.6",
    ButtonData:>"Cell 3.6",
    ButtonStyle->"Hyperlink"],
  ", we show the string motion resulting from this initial condition. (In \
order to reduce the computation time we have used the fact that only odd \
Fourier modes are present in the solution.) "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(M = 19; c = 1;\), "\n", 
    \(\(y[x_, t_]\  = \ 
        Sum[A[n]\ Cos[n\ Pi\ c\ t/L]\ Sin[n\ Pi\ x/L], {n, 1, M, 
            2}];\)\), "\n", 
    \(\(Table[
        Plot[y[x, t], {x, 0, L}, PlotRange \[Rule] {{0, 1}, {\(-1\), 1}}, 
          PlotLabel \[Rule] "\<t = \>" <> ToString[t], 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}], {t, 0, 
          1.95,  .05}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.6"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00942 .30902 L
.01975 .30902 L
.02496 .30902 L
.03053 .30902 L
.04057 .30903 L
.04628 .30903 L
.05248 .30903 L
.05833 .30904 L
.06373 .30904 L
.07396 .30905 L
.07912 .30906 L
.08481 .30907 L
.09026 .30909 L
.09545 .3091 L
.10519 .30914 L
.11062 .30917 L
.11567 .30921 L
.12117 .30925 L
.12711 .30931 L
.13289 .30938 L
.13821 .30946 L
.14866 .30966 L
.15816 .30991 L
.1682 .31027 L
.17815 .31076 L
.18882 .31146 L
.19889 .31234 L
.20807 .31338 L
.21848 .31489 L
.22811 .31669 L
.23868 .31918 L
.2499 .32256 L
.25974 .32626 L
.27035 .33114 L
.28954 .34276 L
.31059 .36041 L
.33274 .38531 L
.37275 .44654 L
.41534 .52497 L
.43501 .55921 L
.45634 .58994 L
.468 .60261 L
.47312 .60707 L
.47875 .61114 L
.48406 .61413 L
.48903 .61618 L
.49177 .61699 L
.49428 .61753 L
.49566 .61774 L
Mistroke
.49639 .61783 L
.49717 .61791 L
.49792 .61797 L
.49859 .618 L
.49991 .61803 L
.50118 .61801 L
.50236 .61795 L
.50366 .61783 L
.50505 .61764 L
.50651 .61738 L
.50788 .61708 L
.51047 .61635 L
.51511 .61452 L
.52016 .61182 L
.52568 .60801 L
.53153 .60305 L
.54204 .5919 L
.56252 .56317 L
.58173 .53029 L
.62241 .45511 L
.64308 .42005 L
.66566 .38737 L
.68725 .36254 L
.70732 .34505 L
.7184 .33748 L
.72884 .33155 L
.74837 .32316 L
.75861 .31993 L
.76943 .31721 L
.77956 .31522 L
.78882 .31379 L
.79875 .31258 L
.80941 .31159 L
.81929 .31091 L
.82865 .31041 L
.83877 .31001 L
.84953 .3097 L
.85872 .30951 L
.86886 .30936 L
.87402 .3093 L
.87944 .30925 L
.88915 .30918 L
.89456 .30915 L
.8996 .30912 L
.90509 .3091 L
.91104 .30908 L
.91678 .30907 L
.92207 .30906 L
.92704 .30905 L
.9325 .30904 L
Mistroke
.94197 .30903 L
.94715 .30903 L
.95201 .30903 L
.95722 .30903 L
.96292 .30902 L
.96794 .30902 L
.97328 .30902 L
.98337 .30902 L
.99274 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003ooooooona
ooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00oooooona
ooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`009_ooool4o`000003oa0@4?oo
oooooooo0?ooooooQ?ooool002Sooooo00?o0000ooooooooool0oooooon6ooooo`00:?ooool00ol0
003oooooooooo`3oooooohKooooo000Looooo`Oo00001Oooool00ol0003oooooooooo`06ooooo`?o
0000oooooommooooo`00:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
OOooool002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooggooooo000X
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooommooooo`009_ooool00ol0
003oA4A4o`000008ooooo`03o`000?oooooooooo0?ooooooOOooool002Kooooo00?oc<c<oeEEEOl0
00002?ooool2o`000?ooooooO_ooool0037ooooo00?o0000ooooooooool0oooooommooooo`00<Ooo
ool00ol0003oooooooooo`3ooooooggooooo000aooooo`03o`000?oooooooooo0?ooooooOOooool0
037ooooo00?o0000ooooooooool0oooooommooooo`00<Oooool00ol0003oooooooooo`3ooooooggo
oooo000aooooo`;o0000oooooomnooooo`00<Oooool00ol0003oooooooooo`3ooooooggooooo000a
ooooo`03o`000?oooooooooo0?ooooooOOooool0037ooooo00?o0000ooooooooool0oooooommoooo
o`00<Oooool00ol0003oooooooooo`3ooooooggooooo000aooooo`03o`000?oooooooooo0?oooooo
OOooool0037ooooo0_l0003oooooogkooooo000aooooo`03o`000?oooooooooo0?ooooooOOooool0
037ooooo00?o0000ooooooooool0oooooommooooo`00<Oooool00ol0003oooooooooo`3ooooooggo
oooo000aooooo`03o`000?oooooooooo0?ooooooOOooool0037ooooo0_l0003oooooogkooooo000a
ooooo`03o`000?oooooooooo0?ooooooOOooool0037ooooo00?o0000ooooooooool0oooooommoooo
o`002oooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Kooooo00?o8B4QoiRH
V?ooool01?ooool01_nHV9So410@o`000?l0003oA4A4onk^kPKooooo00?o0000ooooooooool0oooo
oommooooo`002_ooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00006ooooo`03oiRH
V?m4A4Cooooo00Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@6ooooo`03o`000?oooooooooo
0?ooooooOOooool000[ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003o
EEEE00Kooooo00?ok^k^o`000?o^k^h02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooOOooool00003ooooool0003o000000Go00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00gooooo00?oEEEEoiRHV?ooool01oooool00oo^k^ko0000ooooo`05oooo
o`?o0000oooooommooooo`002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00go
oooo00?oZJVYodA4A?ooool00oooool01_l@413oV9RHooooooooooooMgMgofIVIPKooooo00?o0000
ooooooooool0oooooommooooo`002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00kooooo00?o0000onk^k_ooool00_ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000
ooooooooool0oooooommooooo`002_ooool01_m4A4CoZJVYooooooooooooZJVYodA4A13ooooo00?o
EEEEoiRHV?ooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?ooooooOOoo
ool000[ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`06oa0@4?oooooooooooooooonY
ZJWoA4A40oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?ooooooOOooool000_o
oooo00Co^[Zjoa0@4?l@413oc<c<3Oooool6o`0000?ooooo1Ol00007ooooo`;o0000oooooomnoooo
o`00<Oooool00ol0003oooooooooo`3ooooooggooooo000aooooo`03o`000?oooooooooo0?oooooo
OOooool0037ooooo00?o0000ooooooooool0oooooommooooo`00<Oooool00ol0003oooooooooo`3o
oooooggooooo000aooooo`03o`000?oooooooooo0?ooooooOOooool0037ooooo0_l0003oooooogko
oooo000aooooo`03o`000?oooooooooo0?ooooooOOooool0037ooooo00?o0000ooooooooool0oooo
oommooooo`00<Oooool00ol0003oooooooooo`3ooooooggooooo000aooooo`03o`000?oooooooooo
0?ooooooOOooool0037ooooo0_l0003oooooogkooooo000aooooo`03o`000?oooooooooo0?oooooo
OOooool0037ooooo00?o0000ooooooooool0oooooommooooo`00<Oooool00ol0003oooooooooo`3o
oooooggooooo000aooooo`03o`000?oooooooooo0?ooooooOOooool0037ooooo00?o0000oooooooo
ool0oooooommooooo`00<Oooool2o`000?ooooooO_ooool0037ooooo00?o0000ooooooooool0oooo
oommooooo`00<Oooool00ol0003oooooooooo`3ooooooggooooo000Dooooo`04okZj^_l@413o0000
ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool01_nHV9So410@o`000?l0003oA4A4onk^kPKooooo
00?o0000ooooooooool0oooooommooooo`004oooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Go
oooo0ol00004ooooo`06oa0@4?n7QhOooooooooooomgMgOoA4A41_ooool00ol0003oooooooooo`3o
oooooggooooo000Cooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEE
E@09ooooo`03o`000?oooooooooo00Cooooo0ol0003ooooooggooooo000:ooooo`Oo00000_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?ok^k^o`000?ooool01Oooool0
0ol0003oooooooooo`3ooooooggooooo000Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02_ooool01_l@413oV9RHooooooooooooMgMgofIVIPKooooo00?o0000ooooooooool0oooo
oommooooo`004oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000
ob4Q8Ol0003o0000ofIVIP07ooooo`03o`000?oooooooooo0?ooooooOOooool001?ooooo00KoA4A4
ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
oooooommooooo`004oooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`3ooooooggooooo000Dooooo`04okZj^_l@413o410@olc<c0go
oooo1Ol00007ooooo`;o0000oooooomnooooo`00<Oooool00ol0003oooooooooo`3ooooooggooooo
000aooooo`03o`000?oooooooooo0?ooooooOOooool0037ooooo00?o0000ooooooooool0oooooomm
ooooo`00<Oooool00ol0003oooooooooo`3ooooooggooooo000aooooo`;o0000oooooomnooooo`00
<Oooool00ol0003oooooooooo`3ooooooggooooo000aooooo`03o`000?oooooooooo0?ooooooOOoo
ool0037ooooo00?o0000ooooooooool0oooooommooooo`00<Oooool00ol0003oooooooooo`3ooooo
oggooooo000aooooo`03o`000?oooooooooo0?ooooooOOooool0037ooooo0_l0003oooooogkooooo
000aooooo`03o`000?oooooooooo0?ooooooOOooool0037ooooo00?o0000ooooooooool0oooooomm
ooooo`00<Oooool00ol0003oooooooooo`3ooooooggooooo000aooooo`03o`000?oooooooooo0?oo
ooooOOooool0037ooooo0_l0003oooooogkooooo000aooooo`03o`000?oooooooooo0?ooooooOOoo
ool0037ooooo00?o0000ooooooooool0oooooommooooo`002oooool01?nj^[[o410@o`000?mgMgL6
ooooo`03oeEEEOl0003oEEEE00Cooooo1_l00003ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^
1_ooool00ol0003oooooooooo`3ooooooggooooo000:ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7o
ZJVY1Oooool3o`0000Cooooo00?oV9RHo`000?o<c<`00_ooool01_l@413ooooooooooooooooo410@
ohN7Q`;ooooo00?oMgMgodA4A?ooool01Oooool00ol0003oooooooooo`3ooooooggooooo000:oooo
o`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@05ooooo`03oiRHV?l0
003oc<c<00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooggooooo0000
0ooooooo0000o`000005o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`03ojVYZOl@413oc<c<00Sooooo00?ok^k^o`000?ooool01Oooool3o`000?ooooooOOooool0
00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03olc<c?l@413oc<c<
00?ooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH6ooooo`03o`000?oooooooooo0?ooooooOOoo
ool000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03ojVYZOlb<S;o
oooo00;ooooo00Go0000ob4Q8Ol0003o0000ofIVIP07ooooo`03o`000?oooooooooo0?ooooooOOoo
ool000[ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@Aooooo`05o`000?ooooooooooooooool0
00002oooool00ol0003oooooooooo`3ooooooggooooo000:ooooo`06olc<c?lb<S;ok^k^onk^k_lb
<S;oc<c<3?ooool01_l0003oQhN7onk^k_ooooooMgMgoc8b<P?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`3ooooooggooooo000;ooooo`04okZj^_l@413o410@olc<c0gooooo00Ko
ZJVYoc8b<_l0003o0000oeEEEOo^k^h3ooooo`Go00001oooool2o`000?ooooooO_ooool0037ooooo
00?o0000ooooooooool0oooooommooooo`00<Oooool00ol0003oooooooooo`3ooooooggooooo000a
ooooo`03o`000?oooooooooo0?ooooooOOooool0037ooooo00?o0000ooooooooool0oooooommoooo
o`00<Oooool00ol0003oooooooooo`3ooooooggooooo000aooooo`;o0000oooooomnooooo`00<Ooo
ool00ol0003oooooooooo`3ooooooggooooo000aooooo`03o`000?oooooooooo03Wooooo00Co^[Zj
oa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`Ko0000<Oooool01?nj^[[o410@o`00
0?mgMgL6ooooo`03oeEEEOl0003oEEEE00Oooooo0_l000000ol@413oooooooooo`0^ooooo`04okZj
^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool01_o^k^koA4A4o`000?l0003oEEEE
onk^kS7ooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06onk^k_m4
A4Co0000o`000?m4A4Cok^k^>Oooool4o`000003oa0@4?oooooooooo01Gooooo000aooooo`03o`00
0?oooooooooo03Sooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool00onH
V9So0000olc<c002ooooo`03oa0@4?oooooooooo02kooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnY
ZJT5ooooo`?o00002?ooool00ol0003oooooooooo`0^ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7o
ZJVY1Oooool3o`0000Cooooo00KoEEEEogMgMoooooooooooogMgMomEEED`ooooo`06olc<c?lb<S;o
k^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko<S8bogMgMoo^k^kok^k^ogMgMolb<S8koooo
o`03o`000?oooooooooo01Oooooo000aooooo`03o`000?oooooooooo03Sooooo00KoA4A4ojVYZOoo
ooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Gooooo00?oV9RHo`000?o<c<`0<_ooool0
1_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED01?ooool6o`0002oooooo
00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Cooooo00?o410@oooo
ooooool00_ooool00ol0003oooooooooo`0^ooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Ooo
ool00omEEEGo0000oeEEE@04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0Gooooo`00<Oooool2o`0003Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0<ooooo`03ojVYZOl@413oc<c<037ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0:ooooo`05ofIVI_nYZJWoooooooooool00000<?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00[ooooo00?o0000onk^k_ooool00_ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_lb<S;oMgMgonk^
k_o^k^koMgMgoc8b<S_ooooo00?o0000ooooooooool05oooool0037ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?oc<c<oa0@4?o<c<`0
<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Gok^k^ob4Q8Oo^k^ko
ooooo`00000`ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_l0003o
EEEEonk^k_ooooooMgMgoeEEEC3ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:
ooooo`03omgMgOl0003o000000;o000000?ogMgMooooooooool0>Oooool00ol0003oooooooooo`0G
ooooo`00<Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03_ooool00onYZJWo<S8booooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02oooool01?nYZJWoIVIVooooool0000`ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02_ooool01_lQ8B7oIVIVo`000?l0003oEEEEonk^kS3ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0:ooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b>oooool00ol0
003oooooooooo`0Gooooo`00<Oooool00ol0003oooooooooo`0hooooo`06odA4A?nYZJWooooooooo
oonYZJWoA4A44Oooool00ol0003oooooooooo`0^ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A4
3_ooool00om4A4Coc<c<o`00000`ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A43?ooool00on7
QhOoIVIVooooo`0cooooo`06odA4A?nYZJWooooooooooonYZJWoA4A43?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool05oooool0037ooooo00?o0000
ooooooooool0>?ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00Ko0000ohN7Qoo^k^ko
ooooogMgMolb<S8`ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3_ooool00ooMgMgoA4A4o`00
000`ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3Oooool00olb<S;oIVIVomgMg@0booooo`06
olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<SWooooo
00?o0000odA4A?l000006Oooool0037ooooo00?o0000ooooooooool0>Oooool01?nj^[[o410@oa0@
4?o<c<`=ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^<Oooool01?nj^[[o410@oa0@4?o<c<`@
ooooo`03ohN7Qol0003ooooo033ooooo00Co^[Zjoa0@4?l@413oc<c<3oooool01?mgMgOo410@o`00
0?lQ8B4aooooo`04okZj^_l@413o410@olc<c0gooooo00Kok^k^odA4A?l0003o0000odA4A?o^k^hi
ooooo`03olc<c?mEEEGo000001Wooooo000aooooo`;o0000oooooomnooooo`00<Oooool00ol0003o
ooooooooo`3ooooooggooooo000aooooo`03o`000?oooooooooo0?ooooooLOooool01ol@413o0000
oa0@4?oooooo410@o`000?l@41001Oooool0037ooooo00?o0000ooooooooool0oooooombooooo`06
oc8b<_n7QhOooooookZj^_l0003ok^k^1Oooool0037ooooo00?o0000ooooooooool0oooooomboooo
o`05onk^k_lQ8B7oc<c<ob4Q8Oo<c<`01_ooool0037oooooool0001Xo`0000kooooo00?o^[Zjo`00
0?n7QhL01oooool0037ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooob;o
000000?oooooo`000?ooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooool000008_l0000Aooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02oooool01Oo^k^ko<S8bolc<c?lb<S;ok^k^00Kooooo000aooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00go
oooo1ol0000<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool7o`00013o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool02oooool01OmEEEGoMgMgoooooon7QhOoEEEE00Kooooo000aooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool00oooool8o`0003[ooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`0gooooo`So00001Oooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo00[ooooo00Oo410@o`000?l@413ooooooa0@4?l0003o410@00Gooooo000aoooo
o`03o`000?oooooooooo05;ooooo0ol0002fooooo`?o0000K_ooool0037ooooo00?o0000oooooooo
ool0EOooool3o`000;;ooooo00?o0000ooooooooool0Koooool0037ooooo0_l0001Iooooo`;o0000
[_ooool2o`0007;ooooo000aooooo`03o`000?oooooooooo05[ooooo0ol0002Xooooo`?o0000M?oo
ool0037ooooo00?o0000ooooooooool0GOooool3o`000:?ooooo0_l0001gooooo`00<Oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo09kooooo0_l0001iooooo`00<Oooool00ol0003o
ooooooooo`1Qooooo`;o0000W?ooool2o`0007_ooooo000aooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool0Uoooool2o`0007gooooo000aooooo`;o0000IOooool00ol0003ooooooooo
o`2Dooooo`;o0000Ooooool0037ooooo00?o0000ooooooooool0IOooool2o`0009?ooooo00?o0000
ooooooooool0Ooooool0037ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`2?oooo
o`03o`000?oooooooooo083ooooo000aooooo`03o`000?oooooooooo06Sooooo00?o0000oooooooo
ool0SOooool00ol0003oooooooooo`21ooooo`00<Oooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo08_ooooo00?o0000ooooooooool0P_ooool0037ooooo0_l0001[ooooo`03o`000?oo
oooooooo08Wooooo00?o0000ooooooooool0Poooool0037ooooo00?o0000ooooooooool0Joooool0
0ol0003oooooooooo`27ooooo`03o`000?oooooooooo08Cooooo000aooooo`03o`000?oooooooooo
06cooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`25ooooo`00<Oooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0Q_ooool0037ooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo08Oooooo
000aooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0P?ooool00ol0003ooooooooo
o`28ooooo`00<Oooool2o`00073ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`29
ooooo`00<Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07cooooo00?o0000oooo
ooooool0R_ooool0037ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo08_ooooo000;ooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mE
EED01?ooool6o`0000?ooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h6ooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`2<ooooo`002_ooool01_o<
c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`03oiRHV?l0003oc<c<00;ooooo00Ko
410@oooooooooooooooooa0@4?n7QhL2ooooo`03ogMgMom4A4Cooooo00Gooooo00?o0000oooooooo
ool0Loooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo08gooooo000:ooooo`06odA4
A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@05ooooo`03oiRHV?l0003oc<c<
00[ooooo00?o0000ooooooooool01?ooool3o`0007Cooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`2>ooooo`002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00co
oooo00?oZJVYoa0@4?o<c<`02?ooool00oo^k^ko0000ooooo`05ooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`2>ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00gooooo00?oc<c<oa0@4?o<c<`00oooool01_l@413oV9RH
ooooooooooooMgMgofIVIPKooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo08oooooo000:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool00onYZJWo<S8booooo`02ooooo`05o`000?lQ8B7o0000o`000?mVIVH01oooool00ol0
003oooooooooo`1fooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0T?ooool000[o
oooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@Aooooo`05o`000?ooooooooooooooool000002ooo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0T?oo
ool000[ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`06o`000?n7QhOok^k^oooooomg
MgOo<S8b0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Oooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`2Aooooo`002oooool01?nj^[[o410@oa0@4?o<c<`=oooo
o`06ojVYZOlb<S;o0000o`000?mEEEGok^k^0oooool5o`0000Oooooo0_l0001iooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0T_ooool0037ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`1/ooooo`03o`000?oooooooooo09;ooooo000aooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`2Cooooo`00<Oooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0U?ooool0037ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo09Cooooo
000aooooo`;o0000O?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo09Gooooo000a
ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`2F
ooooo`00<Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool0U_ooool0037ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`1Rooooo`03
o`000?oooooooooo09Oooooo000aooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`2Gooooo`00<Oooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0V?ooool0037ooooo0_l00020ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool0V?ooool0037ooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1Nooooo`03o`000?oooooooooo09Wooooo000aooooo`03o`000?oooooooooo083o
oooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`2Jooooo`00<Oooool00ol0003ooooo
ooooo`20ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0V_ooool0037ooooo00?o
0000ooooooooool0POooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo09_ooooo000a
ooooo`;o0000Poooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo09_ooooo000aoooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2Loooo
o`00<Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo05Oooooo00?o0000oooooooo
ool0W?ooool001Cooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06
oiRHV?l@413o0000o`000?m4A4Cok^k^1_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooo
oooo05Kooooo00?o0000ooooooooool0WOooool001?ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnY
ZJT5ooooo`?o00001?ooool01_l@413oQhN7ooooooooooooMgMgodA4A0Kooooo00?o0000oooooooo
ool0Q?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo09gooooo000Cooooo`06odA4
A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@09ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
09kooooo000Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00oo^k^ko
0000ooooo`05ooooo`?o0000QOooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo09ko
oooo000Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_l@413oV9RH
ooooooooooooMgMgofIVIPKooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo09oooooo000Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02_ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000ooooooooool0Q_ooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo0:3ooooo000Cooooo`06odA4A?nYZJWooooooooo
oonYZJWoA4A43?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08Oooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`2Pooooo`004oooool01_o<c<co<S8bonk^k_o^k^ko
<S8bolc<c0cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`27ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0XOooool001Cooooo00Co^[Zjoa0@4?l@413oc<c<3Ooo
ool5o`0000Oooooo0_l00029ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0XOoo
ool0037ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo0:;ooooo000aooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`2Rooooo`00<Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0Xoooool0037ooooo00?o0000ooooooooool0R_ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo0:?ooooo000aooooo`03o`000?oooooooooo08[ooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`2Tooooo`00<Oooool2o`0008cooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`2Uooooo`00<Oooool00ol0003oooooooooo`2;oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0YOooool0037ooooo00?o0000oooooooo
ool0S?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0:Kooooo000aooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2Vooooo`00<Ooo
ool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0Yooo
ool0037ooooo0_l0002?ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0Yoooool0
037ooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
0:Sooooo000aooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`2Xooooo`00<Oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0ZOooool0037ooooo00?o0000ooooooooool0T?ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo0:[ooooo000aooooo`03o`000?oooooooooo093ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`2Zooooo`00<Oooool2o`0009;ooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`2[ooooo`00<Oooool00ol0003oooooooooo`2Aooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0Zoooool0037ooooo00?o0000ooooooooool0
T_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo0:cooooo000;ooooo`04okZj^_l@
413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01_ooool00olQ8B7oV9RHooooo`04ooooo`06oiRH
V?l@413o0000o`000?m4A4Cok^k^1_ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0[?ooool000[ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5
ooooo`?o00001_ooool00onHV9SoA4A4ooooo`04ooooo`06oa0@4?n7QhOooooooooooomgMgOoA4A4
1_ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
[Oooool000[ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Ko
oooo00?ok^k^o`000?o^k^h02Oooool00ol0003oooooooooo`04ooooo`?o0000U?ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo0:kooooo000:ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03Oooool00omEEEGoV9RHooooo`07ooooo`03onk^k_l0003ooooo00Gooooo
00?o0000ooooooooool0UOooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0:kooooo
000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00onYZJWoA4A4oooo
o`03ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV1_ooool00ol0003oooooooooo`2Eooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0[oooool000[ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0>ooooo`03o`000?o^k^kooooo00;ooooo00Go0000ob4Q8Ol0003o
0000ofIVIP07ooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`2`ooooo`002_ooool01_m4A4CoZJVYooooooooooooZJVYodA4A13ooooo00?oEEEEoiRH
V?ooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo09Oooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`2`ooooo`002_ooool01_o<c<co<S8bonk^k_o^k^ko<S8b
olc<c0cooooo00Ko410@ooooooooooooooooojVYZOm4A4@3ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo0;7ooooo
000;ooooo`04okZj^_l@413o410@olc<c0gooooo1_l00003ooooo`Go00001oooool2o`0009Wooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2aooooo`00<Oooool00ol0003ooooooooo
o`2Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0/_ooool0037ooooo00?o0000
ooooooooool0VOooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0;?ooooo000aoooo
o`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2coooo
o`00<Oooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0]?ooool0037ooooo0_l0002Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
]Oooool0037ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo0;Gooooo000aooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`2fooooo`00<Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0]oooool0037ooooo00?o0000ooooooooool0W_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo0;Oooooo000aooooo`03o`000?oooooooooo09kooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`2hooooo`00<Oooool2o`000:3ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`2hooooo`00<Oooool00ol0003oooooooooo`2P
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0^Oooool0037ooooo00?o0000oooo
ooooool0XOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0;[ooooo000aooooo`03
o`000?oooooooooo0:;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2kooooo`00
<Oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
_?ooool0037ooooo0_l0002Uooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0_Ooo
ool0037ooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`0Booooo`;o0000`?ooool0
037ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
0<3ooooo000Vooooo`Co000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2Wooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0`Oooool002Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2Xooooo`;o00003?ooool2o`000<Cooooo000Xooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Z_ooool3o`0000Oooooo0_l00036ooooo`00:?ooool0
0ol0003oooooooooo`06ooooo`?o0000[Oooool7o`000<Sooooo000Xooooo`03o`000?oooooooooo
0?ooooooQ_ooool002Sooooo00?o0000ooooooooool0oooooon6ooooo`00:?ooool00ol0003ooooo
ooooo`3oooooohKooooo000Vooooo`03o`000?m4A4Co00000?ooooooR?ooool002Kooooo00?oc<c<
oeEEEOl00000oooooon8ooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00oooo
oonaooooo`00coooool01_o<c<co8B4Qo`000?l0003oEEEEokZj^Qkooooo00Co^[Zjoa0@4?l0003o
MgMg^Oooool002gooooo00Go410@o`000?l0003o0000oa0@402Mooooo`06oa0@4?n7QhOoooooonk^
k_nYZJWo8B4Q3?ooool6o`0000_ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJVhooooo`00;ooo
ool00onHV9So<S8booooo`2Mooooo`03o`000?oooooooooo023ooooo00KoA4A4ojVYZOoooooooooo
ojVYZOlb<S:hooooo`00<?ooool00ol@413ogMgMooooo`2Looooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2fooooo`00<?ooool2oeEEEIgooooo00?o
0000ooooooooool03oooool6o`0000_ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2fooooo`00;oooool01?oMgMgo410@ob4Q8OoMgMfLooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`2fooooo`00;oooool01?mEEEGoMgMgoiRHV?mE
EEFJooooo`03oa0@4?l0003o000000?o000000?o410@ooooooooool07?ooool01_m4A4CoZJVYoooo
ooooooooZJVYodA4A;Sooooo000^ooooo`06onk^k_l@413ok^k^ooooool0003ogMgMVoooool00ol0
003oooooooooo`0Pooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<^?ooool002kooooo00KoMgMg
oeEEEOooooooooooogMgMomVIVJKooooo`03o`000?oooooooooo027ooooo00Co^[Zjoa0@4?l@413o
c<c<^Oooool002kooooo00Oo0000omgMgOooooooooooonk^k_l0003ok^k^09[ooooo00?o410@oooo
ooooool0g_ooool002gooooo00?o410@o`000?l000000_ooool2o`000003oa0@4?oooooooooo0?oo
ooooN_ooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oo
oooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oo
oooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.138349, -1.1117, \
0.00419479, 0.0135746}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00942 .30902 L
.01975 .30903 L
.02496 .30903 L
.03053 .30904 L
.04057 .30905 L
.04628 .30906 L
.05248 .30907 L
.05794 .30909 L
.06373 .30911 L
.06895 .30913 L
.07469 .30915 L
.08481 .30922 L
.09026 .30926 L
.09545 .30931 L
.10519 .30943 L
.11567 .30961 L
.12711 .30988 L
.13794 .31024 L
.14777 .31067 L
.15911 .31134 L
.16979 .31218 L
.18004 .31322 L
.19087 .31464 L
.21027 .31823 L
.22022 .32072 L
.23089 .32398 L
.25014 .33171 L
.27244 .34424 L
.29357 .36024 L
.33381 .40262 L
.37663 .46145 L
.41786 .52029 L
.43854 .54554 L
.4575 .56382 L
.4674 .57105 L
.47782 .57673 L
.48323 .57886 L
.48827 .58032 L
.49117 .58093 L
.49381 .58133 L
.49526 .58149 L
.49603 .58156 L
.49684 .58162 L
.49756 .58166 L
.49834 .5817 L
.49971 .58172 L
.50107 .58171 L
.50233 .58167 L
.50372 .58158 L
Mistroke
.50449 .58152 L
.50519 .58145 L
.50787 .58109 L
.51038 .58062 L
.51507 .57941 L
.52013 .57761 L
.5257 .57505 L
.53157 .57171 L
.54207 .56417 L
.56273 .54412 L
.582 .52047 L
.62291 .46212 L
.66639 .40237 L
.68816 .37757 L
.70828 .35867 L
.72784 .34406 L
.74858 .33232 L
.75845 .32794 L
.76907 .32399 L
.78828 .31856 L
.79835 .31645 L
.80936 .31461 L
.82085 .31312 L
.83153 .31206 L
.84261 .31122 L
.85305 .31063 L
.86243 .31022 L
.87258 .30989 L
.88254 .30964 L
.89349 .30945 L
.899 .30937 L
.90492 .30931 L
.91046 .30925 L
.9156 .30921 L
.92626 .30915 L
.93189 .30912 L
.93787 .3091 L
.94791 .30907 L
.95362 .30906 L
.95899 .30905 L
.9693 .30904 L
.97448 .30903 L
.98016 .30903 L
.99958 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00942 .30906 L
.01975 .30911 L
.03053 .30917 L
.04057 .30925 L
.05176 .30937 L
.06194 .30952 L
.0737 .30977 L
.08481 .31009 L
.09499 .31049 L
.10578 .31106 L
.115 .31168 L
.12514 .31255 L
.13579 .31373 L
.14552 .31509 L
.15689 .31707 L
.16745 .31937 L
.18738 .32517 L
.20914 .33409 L
.23069 .34604 L
.25023 .35969 L
.2923 .39688 L
.33277 .43662 L
.3533 .45493 L
.37583 .4716 L
.38618 .47776 L
.39727 .48326 L
.40767 .48738 L
.41729 .49034 L
.42797 .49278 L
.43361 .49374 L
.43959 .49456 L
.44477 .49511 L
.44963 .49551 L
.45497 .49584 L
.45775 .49597 L
.46072 .49609 L
.46345 .49618 L
.46592 .49624 L
.46844 .49629 L
.47077 .49633 L
.47348 .49637 L
.47642 .4964 L
.47902 .49642 L
.48032 .49642 L
.48176 .49643 L
.48324 .49643 L
.48464 .49644 L
.4859 .49644 L
.48728 .49644 L
Mistroke
.48877 .49644 L
.4896 .49644 L
.49035 .49644 L
.49106 .49644 L
.49182 .49644 L
.49321 .49644 L
.4945 .49645 L
.49524 .49645 L
.49592 .49645 L
.49731 .49645 L
.49808 .49645 L
.49879 .49645 L
.50005 .49645 L
.50142 .49645 L
.50272 .49645 L
.50392 .49645 L
.50516 .49645 L
.50646 .49644 L
.50758 .49644 L
.5088 .49644 L
.51011 .49644 L
.51085 .49644 L
.51152 .49644 L
.51282 .49644 L
.51405 .49644 L
.5152 .49644 L
.51643 .49643 L
.51861 .49643 L
.51983 .49642 L
.52097 .49642 L
.52355 .4964 L
.52636 .49637 L
.52901 .49634 L
.5314 .4963 L
.534 .49624 L
.53682 .49617 L
.53981 .49607 L
.5452 .49583 L
.55032 .49551 L
.55502 .49512 L
.56018 .49458 L
.56562 .49386 L
.57478 .49223 L
.5848 .48976 L
.59557 .4862 L
.60537 .48206 L
.62736 .4695 L
.64748 .45428 L
.66931 .43465 L
.71224 .3925 L
Mistroke
.73359 .37292 L
.75358 .35683 L
.77396 .34319 L
.79332 .33293 L
.8146 .3245 L
.83406 .31902 L
.84413 .31687 L
.85487 .31503 L
.86493 .31364 L
.87418 .31262 L
.88499 .31168 L
.89668 .31091 L
.90698 .31041 L
.91786 .31 L
.92782 .30973 L
.9385 .30952 L
.94857 .30937 L
.95775 .30927 L
.96817 .30918 L
.97781 .30912 L
.99961 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .30951 L
.04057 .31023 L
.0515 .31076 L
.06168 .31141 L
.07286 .31232 L
.08481 .3136 L
.09554 .31508 L
.10718 .31711 L
.11724 .31931 L
.12833 .32226 L
.14916 .32958 L
.17124 .34028 L
.19162 .3531 L
.21354 .36992 L
.25682 .40918 L
.27845 .42878 L
.29852 .44467 L
.30851 .45124 L
.31793 .4564 L
.32314 .45879 L
.32878 .46097 L
.33353 .46248 L
.33862 .46374 L
.34132 .46426 L
.34378 .46465 L
.34626 .46495 L
.3486 .46516 L
.34992 .46524 L
.35059 .46527 L
.35133 .4653 L
.35263 .46533 L
.35385 .46534 L
.35455 .46533 L
.35528 .46532 L
.3566 .46528 L
.35733 .46524 L
.35801 .46521 L
.35956 .4651 L
.36094 .46497 L
.36244 .46481 L
.36516 .46443 L
.37025 .46348 L
.37619 .46195 L
.38167 .46019 L
.40138 .45145 L
.42305 .43911 L
.44518 .42621 L
.4654 .41652 L
.47541 .41305 L
Mistroke
.48107 .41156 L
.48377 .41098 L
.48632 .41051 L
.48874 .41013 L
.49136 .40981 L
.49252 .40969 L
.49374 .40959 L
.49489 .4095 L
.49593 .40944 L
.49715 .40939 L
.49846 .40936 L
.49967 .40934 L
.50082 .40934 L
.50215 .40937 L
.50338 .40941 L
.50473 .40948 L
.50617 .40958 L
.50868 .40981 L
.51132 .41014 L
.51603 .41094 L
.52111 .41209 L
.52666 .41368 L
.53661 .41734 L
.54586 .42155 L
.58691 .44498 L
.60786 .45596 L
.6136 .45841 L
.61967 .46065 L
.62491 .46227 L
.63054 .46365 L
.63332 .46418 L
.63596 .4646 L
.63832 .4649 L
.63955 .46502 L
.6409 .46513 L
.64215 .46522 L
.64333 .46527 L
.64458 .46532 L
.64592 .46534 L
.6471 .46533 L
.64835 .46531 L
.64941 .46527 L
.65057 .46521 L
.65206 .46511 L
.65346 .46498 L
.65608 .46467 L
.6589 .46422 L
.66197 .46361 L
.66749 .46218 L
.67258 .46049 L
Mistroke
.68274 .45607 L
.69225 .45077 L
.71392 .43518 L
.75465 .39842 L
.79796 .36074 L
.81959 .3457 L
.83967 .33459 L
.8591 .32638 L
.87979 .32004 L
.8906 .31756 L
.90229 .31542 L
.91239 .31395 L
.92348 .31267 L
.93431 .3117 L
.94443 .311 L
.95511 .31042 L
.96655 .30995 L
.98373 .30942 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .31113 L
.04057 .31389 L
.06168 .31782 L
.07365 .3208 L
.08481 .32418 L
.10625 .33262 L
.12575 .34286 L
.16768 .37339 L
.20801 .41022 L
.22843 .42862 L
.25092 .446 L
.2612 .45233 L
.26687 .45529 L
.27226 .45771 L
.27725 .4596 L
.28269 .46125 L
.28509 .46185 L
.28764 .46238 L
.28984 .46276 L
.29224 .4631 L
.29356 .46325 L
.29498 .46337 L
.29576 .46343 L
.29647 .46347 L
.29719 .46351 L
.29787 .46354 L
.29914 .46357 L
.30052 .46358 L
.30174 .46356 L
.30304 .46351 L
.30442 .46344 L
.3059 .46332 L
.30859 .46303 L
.31179 .46254 L
.31472 .46195 L
.31965 .46068 L
.32504 .45889 L
.3359 .45409 L
.35649 .44116 L
.37849 .42344 L
.42206 .38562 L
.44391 .3697 L
.4535 .36399 L
.46404 .3588 L
.46893 .35681 L
.47418 .35498 L
.47872 .35366 L
.48366 .35251 L
.48655 .35197 L
Mistroke
.48923 .35156 L
.49179 .35126 L
.4931 .35114 L
.49452 .35103 L
.49591 .35094 L
.4972 .35089 L
.49843 .35085 L
.49972 .35084 L
.50089 .35084 L
.50197 .35086 L
.50316 .3509 L
.50443 .35096 L
.50572 .35104 L
.50714 .35116 L
.51 .35146 L
.51266 .35184 L
.51514 .35227 L
.52075 .35352 L
.52678 .35529 L
.53781 .35963 L
.54792 .36478 L
.56783 .3778 L
.58958 .39533 L
.63222 .43244 L
.65193 .44699 L
.66231 .45315 L
.67327 .45825 L
.67885 .46022 L
.6818 .46109 L
.68497 .46188 L
.68788 .46248 L
.69053 .46291 L
.69181 .46308 L
.6932 .46324 L
.69442 .46335 L
.69573 .46345 L
.69704 .46352 L
.69826 .46356 L
.69897 .46357 L
.69972 .46358 L
.70106 .46357 L
.70173 .46355 L
.70246 .46353 L
.70376 .46346 L
.70456 .46341 L
.70531 .46335 L
.70672 .46322 L
.70926 .4629 L
.71161 .46252 L
.7169 .46136 L
Mistroke
.7218 .45992 L
.72706 .45799 L
.73658 .45354 L
.75824 .43943 L
.80155 .40128 L
.84326 .36438 L
.86431 .34906 L
.88339 .33774 L
.90406 .32822 L
.91553 .32406 L
.92608 .32087 L
.94631 .31616 L
.95695 .31428 L
.96818 .31263 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .31586 L
.04057 .32399 L
.06347 .33501 L
.08481 .34793 L
.12477 .37941 L
.16571 .4173 L
.18658 .43537 L
.19757 .44368 L
.20923 .4512 L
.2196 .45655 L
.22511 .45881 L
.23103 .46077 L
.23381 .46151 L
.23645 .46211 L
.23903 .4626 L
.24142 .46296 L
.24367 .46322 L
.24493 .46333 L
.24607 .46341 L
.24733 .46347 L
.24869 .46351 L
.24997 .46353 L
.25115 .46352 L
.25248 .46348 L
.25374 .46342 L
.25486 .46334 L
.25609 .46324 L
.25884 .46292 L
.26138 .46253 L
.266 .46156 L
.27092 .46018 L
.28123 .45617 L
.29262 .45012 L
.31293 .43578 L
.33483 .41686 L
.37803 .37725 L
.39958 .35983 L
.41963 .34633 L
.43898 .33615 L
.44973 .33174 L
.45965 .32846 L
.4704 .32574 L
.47606 .32464 L
.48206 .32374 L
.48457 .32344 L
.48726 .32317 L
.48959 .32298 L
.49213 .32281 L
.49368 .32274 L
Mistroke
.49511 .32268 L
.49647 .32264 L
.49724 .32262 L
.49793 .32261 L
.49924 .3226 L
.49998 .32259 L
.50065 .3226 L
.5019 .32261 L
.50322 .32263 L
.5045 .32267 L
.5059 .32272 L
.50844 .32285 L
.51091 .32302 L
.5132 .32322 L
.51838 .3238 L
.52388 .32463 L
.53304 .32651 L
.54314 .32931 L
.5635 .33729 L
.58541 .34945 L
.62866 .38314 L
.67032 .42153 L
.69133 .43911 L
.71039 .45187 L
.72101 .45717 L
.72588 .4591 L
.73102 .46077 L
.73365 .46147 L
.73653 .46213 L
.73918 .46262 L
.74159 .46298 L
.74296 .46314 L
.74445 .46329 L
.74526 .46335 L
.74602 .4634 L
.74679 .46345 L
.74751 .46348 L
.74878 .46351 L
.74946 .46352 L
.75019 .46353 L
.75091 .46352 L
.75167 .4635 L
.75304 .46345 L
.75433 .46338 L
.75573 .46327 L
.75828 .463 L
.76075 .46263 L
.76304 .46222 L
.76824 .46098 L
.77374 .45923 L
Mistroke
.78291 .45538 L
.79302 .44987 L
.81341 .43537 L
.83534 .41634 L
.87865 .3764 L
.90028 .35862 L
.92036 .34454 L
.94141 .33243 L
.96048 .32354 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .34381 L
.08481 .38592 L
.12636 .42608 L
.14728 .44311 L
.15641 .44925 L
.16632 .45482 L
.17181 .45735 L
.17688 .45932 L
.18204 .46095 L
.18687 .46211 L
.18932 .46257 L
.19195 .46295 L
.19344 .46313 L
.19487 .46326 L
.19615 .46335 L
.19682 .46339 L
.19754 .46342 L
.19831 .46345 L
.19903 .46346 L
.20038 .46347 L
.20115 .46347 L
.20196 .46345 L
.20265 .46342 L
.20341 .46339 L
.20477 .46331 L
.20622 .46319 L
.20885 .46289 L
.21154 .46247 L
.2144 .4619 L
.21953 .46058 L
.22506 .45873 L
.23115 .45619 L
.25228 .44378 L
.2726 .42773 L
.29449 .40788 L
.33769 .3689 L
.35924 .35251 L
.3793 .34 L
.39864 .33055 L
.41931 .32308 L
.43007 .32014 L
.44172 .31759 L
.45273 .31573 L
.46288 .31442 L
.46779 .31392 L
.47306 .31347 L
.47762 .31315 L
.48259 .31287 L
.4856 .31274 L
Mistroke
.48839 .31264 L
.49107 .31256 L
.49243 .31253 L
.49391 .3125 L
.49537 .31248 L
.49671 .31246 L
.49799 .31246 L
.49934 .31245 L
.50055 .31245 L
.50169 .31245 L
.50293 .31246 L
.50426 .31247 L
.50554 .31249 L
.50696 .31252 L
.50982 .31258 L
.51248 .31266 L
.51497 .31276 L
.52057 .31304 L
.5266 .31344 L
.53764 .31448 L
.54774 .3158 L
.55806 .31755 L
.56765 .31959 L
.57885 .32253 L
.5894 .32592 L
.61092 .33491 L
.63045 .34574 L
.6709 .37617 L
.71392 .41569 L
.73533 .43437 L
.7458 .44241 L
.75535 .44886 L
.76455 .4541 L
.77456 .45859 L
.78006 .46046 L
.78515 .4618 L
.79001 .46272 L
.79247 .46305 L
.79387 .46319 L
.79518 .4633 L
.79641 .46338 L
.79773 .46344 L
.79897 .46347 L
.8001 .46347 L
.80143 .46345 L
.80218 .46343 L
.80287 .4634 L
.80414 .46333 L
.80549 .46323 L
.80816 .46294 L
Mistroke
.81066 .46257 L
.8134 .46206 L
.81635 .46138 L
.82649 .45805 L
.83577 .45375 L
.85572 .4409 L
.87748 .42261 L
.92018 .38098 L
.96129 .34215 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .36878 L
.06168 .39719 L
.08481 .42414 L
.0952 .43434 L
.10632 .44368 L
.11674 .45081 L
.12636 .45588 L
.13157 .45799 L
.13709 .45973 L
.13976 .4604 L
.14263 .46097 L
.14427 .46124 L
.14578 .46144 L
.14721 .4616 L
.14873 .46173 L
.14946 .46178 L
.15014 .46182 L
.15142 .46187 L
.15262 .46189 L
.15391 .46188 L
.1546 .46187 L
.15535 .46184 L
.15613 .46181 L
.15686 .46177 L
.15817 .46167 L
.15957 .46154 L
.16234 .46118 L
.16496 .46072 L
.16988 .45958 L
.1747 .45809 L
.18001 .45605 L
.19078 .45073 L
.21012 .43774 L
.25234 .40049 L
.29296 .36462 L
.31359 .34955 L
.33616 .33633 L
.35771 .32689 L
.37776 .32057 L
.38881 .31794 L
.39924 .31594 L
.41876 .3132 L
.42897 .31219 L
.43977 .31137 L
.449 .31084 L
.45915 .31039 L
.46462 .3102 L
.46982 .31006 L
.47454 .30995 L
Mistroke
.47957 .30986 L
.48243 .30981 L
.48501 .30978 L
.48765 .30975 L
.49006 .30973 L
.4929 .30971 L
.49439 .30971 L
.49515 .3097 L
.49596 .3097 L
.49733 .3097 L
.4986 .30969 L
.49938 .30969 L
.50012 .30969 L
.5015 .30969 L
.50271 .3097 L
.504 .3097 L
.50522 .3097 L
.50634 .30971 L
.50894 .30972 L
.51167 .30975 L
.51682 .3098 L
.52245 .30989 L
.5273 .30999 L
.53248 .31012 L
.54181 .31043 L
.55259 .31092 L
.56426 .31165 L
.57528 .31258 L
.58543 .3137 L
.60517 .31674 L
.61639 .31911 L
.62686 .32183 L
.6482 .32919 L
.66768 .33833 L
.6877 .35041 L
.70948 .36658 L
.75227 .4048 L
.77351 .42421 L
.79347 .44044 L
.81252 .45252 L
.81774 .45507 L
.82324 .45735 L
.82829 .45905 L
.83307 .46031 L
.83559 .46083 L
.83831 .46127 L
.83952 .46143 L
.84079 .46158 L
.84198 .46168 L
.84308 .46176 L
Mistroke
.84434 .46183 L
.84571 .46188 L
.84697 .46189 L
.84817 .46188 L
.84884 .46186 L
.84956 .46183 L
.85085 .46176 L
.85164 .4617 L
.85238 .46164 L
.85377 .46149 L
.85612 .46118 L
.8586 .46074 L
.86304 .4597 L
.86781 .45821 L
.87305 .45614 L
.88378 .45049 L
.89355 .44378 L
.91552 .42379 L
.95738 .37166 L
.99764 .31256 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .34555 L
.04057 .38098 L
.06168 .41078 L
.07365 .42405 L
.08481 .43374 L
.09009 .4374 L
.09583 .44068 L
.10125 .44312 L
.10383 .44406 L
.10625 .44481 L
.1086 .44541 L
.11075 .44587 L
.11314 .44626 L
.11446 .44642 L
.11571 .44655 L
.11692 .44663 L
.1182 .4467 L
.11941 .44672 L
.12051 .44672 L
.12181 .44669 L
.12254 .44666 L
.12321 .44662 L
.12445 .44653 L
.12575 .4464 L
.12842 .44603 L
.13096 .44556 L
.1357 .44438 L
.14081 .44267 L
.14637 .44035 L
.16562 .42906 L
.20844 .39351 L
.24967 .35908 L
.27035 .34506 L
.28931 .33469 L
.30963 .32615 L
.32097 .32244 L
.33152 .31959 L
.35139 .31557 L
.3619 .31402 L
.37313 .31272 L
.38388 .31176 L
.39554 .31098 L
.40655 .31042 L
.4167 .31004 L
.42688 .30976 L
.4364 .30956 L
.44685 .3094 L
.45272 .30933 L
.45808 .30928 L
Mistroke
.4631 .30924 L
.46844 .30921 L
.47306 .30918 L
.47805 .30916 L
.48112 .30915 L
.48394 .30914 L
.48658 .30913 L
.48948 .30913 L
.49208 .30913 L
.49451 .30912 L
.49585 .30912 L
.49708 .30912 L
.49775 .30912 L
.49849 .30912 L
.49982 .30912 L
.50111 .30912 L
.50228 .30912 L
.50357 .30912 L
.50493 .30912 L
.50612 .30912 L
.50722 .30912 L
.50972 .30913 L
.51249 .30913 L
.515 .30914 L
.52063 .30916 L
.52608 .30918 L
.53199 .30921 L
.53753 .30924 L
.5427 .30929 L
.55266 .30939 L
.56361 .30956 L
.57428 .30979 L
.58572 .31012 L
.59638 .31056 L
.608 .31119 L
.61896 .31199 L
.62911 .31296 L
.64869 .31558 L
.65984 .31765 L
.67031 .32005 L
.69148 .32655 L
.7109 .33479 L
.73074 .34574 L
.75247 .36069 L
.79503 .3966 L
.81467 .41374 L
.83599 .43017 L
.84763 .43733 L
.85275 .43993 L
.85838 .44236 L
Mistroke
.86368 .4442 L
.86865 .44548 L
.87138 .446 L
.87389 .44636 L
.87527 .44651 L
.876 .44657 L
.87678 .44662 L
.87753 .44667 L
.87821 .44669 L
.87953 .44672 L
.88079 .44672 L
.88197 .44669 L
.88327 .44662 L
.88465 .44651 L
.88611 .44636 L
.88748 .44617 L
.89006 .44571 L
.89248 .44515 L
.89471 .44453 L
.89975 .44272 L
.90479 .44036 L
.91036 .43711 L
.92162 .42848 L
.93223 .41789 L
.94195 .4062 L
.96385 .37387 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .33547 L
.04057 .36031 L
.05077 .37053 L
.06168 .37966 L
.06795 .38399 L
.07365 .38733 L
.07907 .38996 L
.08481 .39217 L
.08978 .3936 L
.09261 .39423 L
.09526 .39469 L
.09651 .39486 L
.09769 .395 L
.09877 .39511 L
.09991 .3952 L
.10115 .39528 L
.1023 .39533 L
.10367 .39536 L
.10491 .39536 L
.10628 .39533 L
.10697 .39531 L
.10772 .39527 L
.10906 .39519 L
.11031 .39509 L
.11313 .39477 L
.11615 .3943 L
.12169 .39312 L
.12674 .39171 L
.13714 .38789 L
.14677 .38346 L
.16857 .37134 L
.2098 .34682 L
.23048 .33631 L
.24944 .32842 L
.26975 .3219 L
.2811 .31907 L
.29165 .3169 L
.31152 .31385 L
.32203 .31268 L
.33326 .31171 L
.34401 .311 L
.35567 .31042 L
.36668 .31002 L
.37683 .30974 L
.38701 .30953 L
.39653 .30939 L
.40698 .30928 L
.41285 .30923 L
.4182 .30919 L
Mistroke
.42323 .30916 L
.42857 .30913 L
.43818 .3091 L
.44407 .30908 L
.44961 .30907 L
.45454 .30906 L
.45995 .30905 L
.46492 .30905 L
.47023 .30904 L
.47584 .30904 L
.48108 .30903 L
.48358 .30903 L
.4863 .30903 L
.48869 .30903 L
.49124 .30903 L
.49352 .30903 L
.49482 .30903 L
.49604 .30903 L
.49716 .30903 L
.49818 .30903 L
.49931 .30903 L
.50049 .30903 L
.50179 .30903 L
.50252 .30903 L
.5032 .30903 L
.50444 .30903 L
.50576 .30903 L
.50803 .30903 L
.51054 .30903 L
.51321 .30903 L
.51608 .30903 L
.52126 .30904 L
.52644 .30904 L
.53135 .30904 L
.54056 .30905 L
.54536 .30906 L
.55068 .30907 L
.55585 .30908 L
.56143 .3091 L
.5714 .30913 L
.58077 .30918 L
.5908 .30926 L
.60179 .30937 L
.60733 .30944 L
.61325 .30954 L
.62393 .30976 L
.63467 .31006 L
.64632 .31051 L
.65732 .31108 L
.66747 .31177 L
Mistroke
.67763 .31265 L
.68715 .31369 L
.69825 .3152 L
.70881 .31699 L
.73008 .32186 L
.74954 .32804 L
.77035 .33669 L
.78966 .34653 L
.83077 .37095 L
.85176 .38272 L
.8628 .38787 L
.86883 .39022 L
.87445 .39207 L
.8795 .39341 L
.88209 .39397 L
.88491 .39448 L
.88651 .39472 L
.88799 .39491 L
.88938 .39506 L
.89091 .39519 L
.89228 .39527 L
.89356 .39533 L
.89492 .39536 L
.89568 .39536 L
.89638 .39536 L
.89756 .39533 L
.89881 .39528 L
.9 .39521 L
.90107 .39512 L
.90371 .39483 L
.9062 .39445 L
.91117 .39336 L
.91654 .3917 L
.92168 .38962 L
.92649 .38725 L
.93743 .38032 L
.94809 .37158 L
.95953 .36021 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .30902 L
.04057 .30902 L
.05077 .30902 L
.06168 .30902 L
.06795 .30902 L
.07365 .30902 L
.07939 .30902 L
.08219 .30902 L
.08481 .30902 L
.08734 .30902 L
.08965 .30902 L
.09088 .30902 L
.09222 .30902 L
.09296 .30902 L
.09364 .30902 L
.09499 .30902 L
.09567 .30902 L
.0964 .30902 L
.09773 .30902 L
.09902 .30902 L
.10021 .30902 L
.1015 .30902 L
.10292 .30902 L
.10578 .30902 L
.10831 .30902 L
.11061 .30902 L
.11579 .30902 L
.12514 .30902 L
.14518 .30902 L
.16698 .30902 L
.2098 .30902 L
.23107 .30902 L
.25103 .30902 L
.27034 .30902 L
.29067 .30902 L
.30079 .30902 L
.30614 .30902 L
.31186 .30902 L
.31714 .30902 L
.32193 .30902 L
.32674 .30902 L
.33129 .30902 L
.3338 .30902 L
.33615 .30902 L
.3375 .30902 L
.33873 .30902 L
.33941 .30902 L
.34015 .30902 L
.3415 .30902 L
Mistroke
.34223 .30902 L
.34292 .30902 L
.34422 .30902 L
.34494 .30902 L
.34561 .30902 L
.34634 .30902 L
.34711 .30902 L
.34839 .30902 L
.34959 .30902 L
.35231 .30902 L
.3572 .30902 L
.36166 .30902 L
.37168 .30902 L
.38142 .30902 L
.39176 .30902 L
.39715 .30902 L
.40022 .30902 L
.40162 .30902 L
.4031 .30902 L
.40436 .30902 L
.40573 .30902 L
.40698 .30902 L
.40814 .30902 L
.40952 .30902 L
.41077 .30902 L
.41146 .30902 L
.41221 .30902 L
.41357 .30902 L
.41487 .30902 L
.41606 .30902 L
.41873 .30902 L
.42354 .30902 L
.42916 .30902 L
.43448 .30902 L
.45659 .30902 L
.46578 .30902 L
.4757 .30902 L
.48137 .30902 L
.48386 .30902 L
.48658 .30902 L
.48899 .30902 L
.49156 .30902 L
.49298 .30902 L
.49428 .30902 L
.49558 .30902 L
.49681 .30902 L
.498 .30902 L
.49932 .30902 L
.50069 .30902 L
.50198 .30902 L
Mistroke
.50318 .30902 L
.50428 .30902 L
.50555 .30902 L
.50675 .30902 L
.50943 .30902 L
.51191 .30902 L
.51754 .30902 L
.52314 .30902 L
.52822 .30902 L
.53959 .30902 L
.55026 .30902 L
.56152 .30902 L
.57113 .30902 L
.57659 .30902 L
.57924 .30902 L
.58168 .30902 L
.5842 .30902 L
.58553 .30902 L
.58694 .30902 L
.58816 .30902 L
.5893 .30902 L
.59056 .30902 L
.59191 .30902 L
.59304 .30902 L
.59428 .30902 L
.59558 .30902 L
.59678 .30902 L
.59893 .30902 L
.60123 .30902 L
.60688 .30902 L
.61221 .30902 L
.62218 .30902 L
.6324 .30902 L
.63799 .30902 L
.64321 .30902 L
.64766 .30902 L
.65016 .30902 L
.65127 .30902 L
.65244 .30902 L
.65374 .30902 L
.65494 .30902 L
.65567 .30902 L
.65636 .30902 L
.65765 .30902 L
.65889 .30902 L
.66003 .30902 L
.66128 .30902 L
.66259 .30902 L
.66388 .30902 L
.66528 .30902 L
Mistroke
.66782 .30902 L
.6703 .30902 L
.67258 .30902 L
.67777 .30902 L
.68327 .30902 L
.69244 .30902 L
.70254 .30902 L
.72291 .30902 L
.74483 .30902 L
.7881 .30902 L
.82978 .30902 L
.8508 .30902 L
.86987 .30902 L
.87498 .30902 L
.8805 .30902 L
.88528 .30902 L
.89052 .30902 L
.8934 .30902 L
.89609 .30902 L
.89758 .30902 L
.89894 .30902 L
.89969 .30902 L
.9005 .30902 L
.90127 .30902 L
.90198 .30902 L
.90324 .30902 L
.90442 .30902 L
.90571 .30902 L
.90643 .30902 L
.9071 .30902 L
.90836 .30902 L
.90975 .30902 L
.91254 .30902 L
.9152 .30902 L
.91808 .30902 L
.92332 .30902 L
.92842 .30902 L
.93312 .30902 L
.9438 .30902 L
.95511 .30902 L
.99488 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .28257 L
.04057 .25772 L
.05077 .24751 L
.06168 .23837 L
.06795 .23404 L
.07365 .2307 L
.07907 .22808 L
.08481 .22587 L
.08978 .22443 L
.09261 .22381 L
.09526 .22335 L
.09651 .22317 L
.09769 .22303 L
.09877 .22293 L
.09991 .22283 L
.10115 .22275 L
.1023 .22271 L
.10367 .22268 L
.10491 .22267 L
.10628 .2227 L
.10697 .22273 L
.10772 .22276 L
.10906 .22284 L
.11031 .22295 L
.11313 .22326 L
.11615 .22373 L
.12169 .22491 L
.12674 .22632 L
.13714 .23014 L
.14677 .23457 L
.16857 .24669 L
.2098 .27121 L
.23048 .28173 L
.24944 .28962 L
.26975 .29613 L
.2811 .29896 L
.29165 .30113 L
.31152 .30419 L
.32203 .30535 L
.33326 .30632 L
.34401 .30703 L
.35567 .30761 L
.36668 .30802 L
.37683 .30829 L
.38701 .3085 L
.39653 .30864 L
.40698 .30876 L
.41285 .30881 L
.4182 .30884 L
Mistroke
.42323 .30887 L
.42857 .3089 L
.43818 .30894 L
.44407 .30895 L
.44961 .30896 L
.45454 .30897 L
.45995 .30898 L
.46492 .30899 L
.47023 .30899 L
.47584 .309 L
.48108 .309 L
.48358 .309 L
.4863 .309 L
.48869 .309 L
.49124 .309 L
.49352 .309 L
.49482 .309 L
.49604 .309 L
.49716 .309 L
.49818 .309 L
.49931 .309 L
.50049 .309 L
.50179 .309 L
.50252 .309 L
.5032 .309 L
.50444 .309 L
.50576 .309 L
.50803 .309 L
.51054 .309 L
.51321 .309 L
.51608 .309 L
.52126 .309 L
.52644 .309 L
.53135 .30899 L
.54056 .30898 L
.54536 .30897 L
.55068 .30896 L
.55585 .30895 L
.56143 .30894 L
.5714 .3089 L
.58077 .30885 L
.5908 .30878 L
.60179 .30866 L
.60733 .30859 L
.61325 .3085 L
.62393 .30828 L
.63467 .30797 L
.64632 .30753 L
.65732 .30695 L
.66747 .30626 L
Mistroke
.67763 .30538 L
.68715 .30435 L
.69825 .30284 L
.70881 .30105 L
.73008 .29618 L
.74954 .28999 L
.77035 .28134 L
.78966 .2715 L
.83077 .24709 L
.85176 .23531 L
.8628 .23017 L
.86883 .22781 L
.87445 .22596 L
.8795 .22462 L
.88209 .22406 L
.88491 .22355 L
.88651 .22331 L
.88799 .22312 L
.88938 .22298 L
.89091 .22285 L
.89228 .22276 L
.89356 .22271 L
.89492 .22268 L
.89568 .22267 L
.89638 .22268 L
.89756 .2227 L
.89881 .22275 L
.9 .22283 L
.90107 .22291 L
.90371 .2232 L
.9062 .22359 L
.91117 .22467 L
.91654 .22633 L
.92168 .22841 L
.92649 .23078 L
.93743 .23772 L
.94809 .24646 L
.95953 .25783 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .27248 L
.04057 .23705 L
.06168 .20726 L
.07365 .19399 L
.08481 .18429 L
.09009 .18063 L
.09583 .17735 L
.10125 .17491 L
.10383 .17398 L
.10625 .17323 L
.1086 .17262 L
.11075 .17217 L
.11314 .17178 L
.11446 .17161 L
.11571 .17149 L
.11692 .1714 L
.1182 .17134 L
.11941 .17131 L
.12051 .17131 L
.12181 .17134 L
.12254 .17137 L
.12321 .17141 L
.12445 .1715 L
.12575 .17163 L
.12842 .172 L
.13096 .17247 L
.1357 .17366 L
.14081 .17536 L
.14637 .17769 L
.16562 .18898 L
.20844 .22452 L
.24967 .25895 L
.27035 .27297 L
.28931 .28335 L
.30963 .29188 L
.32097 .29559 L
.33152 .29844 L
.35139 .30247 L
.3619 .30401 L
.37313 .30531 L
.38388 .30627 L
.39554 .30706 L
.40655 .30761 L
.4167 .30799 L
.42688 .30828 L
.4364 .30847 L
.44685 .30863 L
.45272 .3087 L
.45808 .30875 L
Mistroke
.4631 .30879 L
.46844 .30883 L
.47306 .30885 L
.47805 .30887 L
.48112 .30888 L
.48394 .30889 L
.48658 .3089 L
.48948 .3089 L
.49208 .30891 L
.49451 .30891 L
.49585 .30891 L
.49708 .30891 L
.49775 .30891 L
.49849 .30891 L
.49982 .30891 L
.50111 .30891 L
.50228 .30891 L
.50357 .30891 L
.50493 .30891 L
.50612 .30891 L
.50722 .30891 L
.50972 .30891 L
.51249 .3089 L
.515 .3089 L
.52063 .30888 L
.52608 .30886 L
.53199 .30883 L
.53753 .30879 L
.5427 .30875 L
.55266 .30864 L
.56361 .30847 L
.57428 .30825 L
.58572 .30791 L
.59638 .30748 L
.608 .30684 L
.61896 .30604 L
.62911 .30508 L
.64869 .30245 L
.65984 .30039 L
.67031 .29798 L
.69148 .29148 L
.7109 .28325 L
.73074 .2723 L
.75247 .25735 L
.79503 .22144 L
.81467 .20429 L
.83599 .18787 L
.84763 .1807 L
.85275 .1781 L
.85838 .17567 L
Mistroke
.86368 .17384 L
.86865 .17255 L
.87138 .17203 L
.87389 .17168 L
.87527 .17153 L
.876 .17147 L
.87678 .17141 L
.87753 .17137 L
.87821 .17134 L
.87953 .17131 L
.88079 .17131 L
.88197 .17134 L
.88327 .17141 L
.88465 .17152 L
.88611 .17168 L
.88748 .17187 L
.89006 .17233 L
.89248 .17288 L
.89471 .17351 L
.89975 .17532 L
.90479 .17767 L
.91036 .18092 L
.92162 .18955 L
.93223 .20015 L
.94195 .21183 L
.96385 .24416 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .24926 L
.06168 .22085 L
.08481 .1939 L
.0952 .18369 L
.10632 .17435 L
.11674 .16723 L
.12636 .16216 L
.13157 .16005 L
.13709 .1583 L
.13976 .15764 L
.14263 .15706 L
.14427 .1568 L
.14578 .15659 L
.14721 .15643 L
.14873 .1563 L
.14946 .15626 L
.15014 .15622 L
.15142 .15617 L
.15262 .15615 L
.15391 .15615 L
.1546 .15617 L
.15535 .15619 L
.15613 .15622 L
.15686 .15627 L
.15817 .15636 L
.15957 .1565 L
.16234 .15686 L
.16496 .15731 L
.16988 .15846 L
.1747 .15994 L
.18001 .16198 L
.19078 .1673 L
.21012 .18029 L
.25234 .21754 L
.29296 .25341 L
.31359 .26848 L
.33616 .2817 L
.35771 .29115 L
.37776 .29747 L
.38881 .30009 L
.39924 .30209 L
.41876 .30483 L
.42897 .30584 L
.43977 .30666 L
.449 .3072 L
.45915 .30764 L
.46462 .30783 L
.46982 .30798 L
.47454 .30809 L
Mistroke
.47957 .30818 L
.48243 .30822 L
.48501 .30825 L
.48765 .30828 L
.49006 .3083 L
.4929 .30832 L
.49439 .30833 L
.49515 .30833 L
.49596 .30833 L
.49733 .30834 L
.4986 .30834 L
.49938 .30834 L
.50012 .30834 L
.5015 .30834 L
.50271 .30834 L
.504 .30833 L
.50522 .30833 L
.50634 .30833 L
.50894 .30831 L
.51167 .30829 L
.51682 .30823 L
.52245 .30814 L
.5273 .30805 L
.53248 .30791 L
.54181 .30761 L
.55259 .30712 L
.56426 .30638 L
.57528 .30545 L
.58543 .30434 L
.60517 .3013 L
.61639 .29892 L
.62686 .2962 L
.6482 .28885 L
.66768 .2797 L
.6877 .26763 L
.70948 .25146 L
.75227 .21323 L
.77351 .19382 L
.79347 .17759 L
.81252 .16551 L
.81774 .16296 L
.82324 .16069 L
.82829 .15898 L
.83307 .15772 L
.83559 .15721 L
.83831 .15676 L
.83952 .1566 L
.84079 .15646 L
.84198 .15635 L
.84308 .15627 L
Mistroke
.84434 .1562 L
.84571 .15616 L
.84697 .15615 L
.84817 .15616 L
.84884 .15618 L
.84956 .1562 L
.85085 .15627 L
.85164 .15633 L
.85238 .1564 L
.85377 .15654 L
.85612 .15686 L
.8586 .15729 L
.86304 .15833 L
.86781 .15982 L
.87305 .1619 L
.88378 .16754 L
.89355 .17425 L
.91552 .19424 L
.95738 .24637 L
.99764 .30547 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .27422 L
.08481 .23211 L
.12636 .19196 L
.14728 .17493 L
.15641 .16878 L
.16632 .16322 L
.17181 .16068 L
.17688 .15871 L
.18204 .15709 L
.18687 .15592 L
.18932 .15547 L
.19195 .15508 L
.19344 .15491 L
.19487 .15478 L
.19615 .15468 L
.19682 .15465 L
.19754 .15461 L
.19831 .15459 L
.19903 .15457 L
.20038 .15456 L
.20115 .15457 L
.20196 .15459 L
.20265 .15461 L
.20341 .15464 L
.20477 .15473 L
.20622 .15485 L
.20885 .15515 L
.21154 .15557 L
.2144 .15613 L
.21953 .15745 L
.22506 .1593 L
.23115 .16184 L
.25228 .17425 L
.2726 .1903 L
.29449 .21015 L
.33769 .24914 L
.35924 .26553 L
.3793 .27803 L
.39864 .28748 L
.41931 .29496 L
.43007 .2979 L
.44172 .30044 L
.45273 .30231 L
.46288 .30361 L
.46779 .30411 L
.47306 .30457 L
.47762 .30489 L
.48259 .30516 L
.4856 .3053 L
Mistroke
.48839 .3054 L
.49107 .30547 L
.49243 .30551 L
.49391 .30553 L
.49537 .30555 L
.49671 .30557 L
.49799 .30558 L
.49934 .30558 L
.50055 .30558 L
.50169 .30558 L
.50293 .30557 L
.50426 .30556 L
.50554 .30554 L
.50696 .30552 L
.50982 .30545 L
.51248 .30537 L
.51497 .30527 L
.52057 .305 L
.5266 .30459 L
.53764 .30355 L
.54774 .30224 L
.55806 .30049 L
.56765 .29845 L
.57885 .29551 L
.5894 .29212 L
.61092 .28312 L
.63045 .2723 L
.6709 .24187 L
.71392 .20235 L
.73533 .18366 L
.7458 .17562 L
.75535 .16918 L
.76455 .16393 L
.77456 .15945 L
.78006 .15757 L
.78515 .15623 L
.79001 .15531 L
.79247 .15498 L
.79387 .15484 L
.79518 .15473 L
.79641 .15465 L
.79773 .1546 L
.79897 .15457 L
.8001 .15456 L
.80143 .15458 L
.80218 .1546 L
.80287 .15463 L
.80414 .1547 L
.80549 .15481 L
.80816 .15509 L
Mistroke
.81066 .15546 L
.8134 .15598 L
.81635 .15666 L
.82649 .15998 L
.83577 .16429 L
.85572 .17714 L
.87748 .19543 L
.92018 .23706 L
.96129 .27588 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .30217 L
.04057 .29405 L
.06347 .28302 L
.08481 .2701 L
.12477 .23862 L
.16571 .20073 L
.18658 .18267 L
.19757 .17436 L
.20923 .16684 L
.2196 .16149 L
.22511 .15922 L
.23103 .15727 L
.23381 .15652 L
.23645 .15592 L
.23903 .15544 L
.24142 .15508 L
.24367 .15482 L
.24493 .15471 L
.24607 .15463 L
.24733 .15456 L
.24869 .15452 L
.24997 .15451 L
.25115 .15452 L
.25248 .15456 L
.25374 .15462 L
.25486 .15469 L
.25609 .15479 L
.25884 .15511 L
.26138 .1555 L
.266 .15647 L
.27092 .15785 L
.28123 .16186 L
.29262 .16792 L
.31293 .18225 L
.33483 .20117 L
.37803 .24078 L
.39958 .25821 L
.41963 .2717 L
.43898 .28188 L
.44973 .28629 L
.45965 .28957 L
.4704 .2923 L
.47606 .29339 L
.48206 .29429 L
.48457 .29459 L
.48726 .29486 L
.48959 .29505 L
.49213 .29522 L
.49368 .2953 L
Mistroke
.49511 .29535 L
.49647 .2954 L
.49724 .29541 L
.49793 .29542 L
.49924 .29544 L
.49998 .29544 L
.50065 .29544 L
.5019 .29543 L
.50322 .2954 L
.5045 .29537 L
.5059 .29532 L
.50844 .29519 L
.51091 .29501 L
.5132 .29482 L
.51838 .29423 L
.52388 .2934 L
.53304 .29152 L
.54314 .28873 L
.5635 .28074 L
.58541 .26858 L
.62866 .23489 L
.67032 .19651 L
.69133 .17893 L
.71039 .16616 L
.72101 .16086 L
.72588 .15894 L
.73102 .15726 L
.73365 .15656 L
.73653 .1559 L
.73918 .15541 L
.74159 .15505 L
.74296 .15489 L
.74445 .15475 L
.74526 .15468 L
.74602 .15463 L
.74679 .15459 L
.74751 .15456 L
.74878 .15452 L
.74946 .15451 L
.75019 .15451 L
.75091 .15451 L
.75167 .15453 L
.75304 .15458 L
.75433 .15465 L
.75573 .15476 L
.75828 .15504 L
.76075 .1554 L
.76304 .15582 L
.76824 .15706 L
.77374 .1588 L
Mistroke
.78291 .16266 L
.79302 .16817 L
.81341 .18266 L
.83534 .20169 L
.87865 .24163 L
.90028 .25941 L
.92036 .27349 L
.94141 .2856 L
.96048 .29449 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .3069 L
.04057 .30415 L
.06168 .30021 L
.07365 .29724 L
.08481 .29386 L
.10625 .28541 L
.12575 .27518 L
.16768 .24464 L
.20801 .20781 L
.22843 .18942 L
.25092 .17203 L
.2612 .1657 L
.26687 .16275 L
.27226 .16033 L
.27725 .15844 L
.28269 .15678 L
.28509 .15619 L
.28764 .15565 L
.28984 .15527 L
.29224 .15494 L
.29356 .15479 L
.29498 .15466 L
.29576 .1546 L
.29647 .15456 L
.29719 .15452 L
.29787 .1545 L
.29914 .15446 L
.30052 .15446 L
.30174 .15448 L
.30304 .15452 L
.30442 .1546 L
.3059 .15471 L
.30859 .15501 L
.31179 .1555 L
.31472 .15608 L
.31965 .15735 L
.32504 .15914 L
.3359 .16395 L
.35649 .17687 L
.37849 .19459 L
.42206 .23242 L
.44391 .24834 L
.4535 .25404 L
.46404 .25923 L
.46893 .26122 L
.47418 .26305 L
.47872 .26437 L
.48366 .26553 L
.48655 .26606 L
Mistroke
.48923 .26647 L
.49179 .26677 L
.4931 .2669 L
.49452 .26701 L
.49591 .26709 L
.4972 .26715 L
.49843 .26718 L
.49972 .2672 L
.50089 .26719 L
.50197 .26717 L
.50316 .26713 L
.50443 .26707 L
.50572 .26699 L
.50714 .26688 L
.51 .26657 L
.51266 .26619 L
.51514 .26576 L
.52075 .26451 L
.52678 .26274 L
.53781 .25841 L
.54792 .25326 L
.56783 .24023 L
.58958 .2227 L
.63222 .1856 L
.65193 .17105 L
.66231 .16489 L
.67327 .15978 L
.67885 .15781 L
.6818 .15694 L
.68497 .15615 L
.68788 .15556 L
.69053 .15512 L
.69181 .15495 L
.6932 .1548 L
.69442 .15468 L
.69573 .15459 L
.69704 .15452 L
.69826 .15448 L
.69897 .15446 L
.69972 .15446 L
.70106 .15447 L
.70173 .15448 L
.70246 .15451 L
.70376 .15457 L
.70456 .15463 L
.70531 .15468 L
.70672 .15482 L
.70926 .15513 L
.71161 .15551 L
.7169 .15667 L
Mistroke
.7218 .15812 L
.72706 .16005 L
.73658 .1645 L
.75824 .17861 L
.80155 .21675 L
.84326 .25365 L
.86431 .26897 L
.88339 .28029 L
.90406 .28981 L
.91553 .29397 L
.92608 .29716 L
.94631 .30187 L
.95695 .30375 L
.96818 .30541 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .30852 L
.04057 .3078 L
.0515 .30727 L
.06168 .30663 L
.07286 .30572 L
.08481 .30444 L
.09554 .30296 L
.10718 .30092 L
.11724 .29873 L
.12833 .29578 L
.14916 .28846 L
.17124 .27775 L
.19162 .26493 L
.21354 .24811 L
.25682 .20885 L
.27845 .18925 L
.29852 .17336 L
.30851 .1668 L
.31793 .16163 L
.32314 .15924 L
.32878 .15706 L
.33353 .15556 L
.33862 .15429 L
.34132 .15377 L
.34378 .15339 L
.34626 .15308 L
.3486 .15288 L
.34992 .1528 L
.35059 .15276 L
.35133 .15274 L
.35263 .15271 L
.35385 .1527 L
.35455 .1527 L
.35528 .15272 L
.3566 .15276 L
.35733 .15279 L
.35801 .15283 L
.35956 .15294 L
.36094 .15306 L
.36244 .15323 L
.36516 .1536 L
.37025 .15456 L
.37619 .15608 L
.38167 .15785 L
.40138 .16659 L
.42305 .17893 L
.44518 .19182 L
.4654 .20151 L
.47541 .20498 L
Mistroke
.48107 .20648 L
.48377 .20706 L
.48632 .20753 L
.48874 .2079 L
.49136 .20823 L
.49252 .20834 L
.49374 .20845 L
.49489 .20853 L
.49593 .20859 L
.49715 .20864 L
.49846 .20868 L
.49967 .20869 L
.50082 .20869 L
.50215 .20866 L
.50338 .20862 L
.50473 .20855 L
.50617 .20846 L
.50868 .20822 L
.51132 .20789 L
.51603 .2071 L
.52111 .20594 L
.52666 .20435 L
.53661 .20069 L
.54586 .19648 L
.58691 .17305 L
.60786 .16207 L
.6136 .15962 L
.61967 .15738 L
.62491 .15576 L
.63054 .15439 L
.63332 .15385 L
.63596 .15343 L
.63832 .15314 L
.63955 .15301 L
.6409 .1529 L
.64215 .15282 L
.64333 .15276 L
.64458 .15272 L
.64592 .1527 L
.6471 .1527 L
.64835 .15273 L
.64941 .15276 L
.65057 .15282 L
.65206 .15293 L
.65346 .15305 L
.65608 .15337 L
.6589 .15381 L
.66197 .15442 L
.66749 .15585 L
.67258 .15755 L
Mistroke
.68274 .16196 L
.69225 .16726 L
.71392 .18285 L
.75465 .21961 L
.79796 .2573 L
.81959 .27234 L
.83967 .28344 L
.8591 .29166 L
.87979 .298 L
.8906 .30047 L
.90229 .30262 L
.91239 .30409 L
.92348 .30536 L
.93431 .30633 L
.94443 .30703 L
.95511 .30761 L
.96655 .30809 L
.98373 .30862 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00942 .30898 L
.01975 .30893 L
.03053 .30886 L
.04057 .30878 L
.05176 .30866 L
.06194 .30851 L
.0737 .30827 L
.08481 .30794 L
.09499 .30754 L
.10578 .30698 L
.115 .30635 L
.12514 .30548 L
.13579 .3043 L
.14552 .30295 L
.15689 .30096 L
.16745 .29866 L
.18738 .29287 L
.20914 .28394 L
.23069 .272 L
.25023 .25834 L
.2923 .22115 L
.33277 .18141 L
.3533 .1631 L
.37583 .14643 L
.38618 .14027 L
.39727 .13477 L
.40767 .13066 L
.41729 .12769 L
.42797 .12525 L
.43361 .12429 L
.43959 .12348 L
.44477 .12293 L
.44963 .12253 L
.45497 .1222 L
.45775 .12206 L
.46072 .12195 L
.46345 .12186 L
.46592 .12179 L
.46844 .12174 L
.47077 .1217 L
.47348 .12166 L
.47642 .12164 L
.47902 .12162 L
.48032 .12161 L
.48176 .12161 L
.48324 .1216 L
.48464 .1216 L
.4859 .12159 L
.48728 .12159 L
Mistroke
.48877 .12159 L
.4896 .12159 L
.49035 .12159 L
.49106 .12159 L
.49182 .12159 L
.49321 .12159 L
.4945 .12159 L
.49524 .12159 L
.49592 .12159 L
.49731 .12159 L
.49808 .12159 L
.49879 .12159 L
.50005 .12159 L
.50142 .12159 L
.50272 .12159 L
.50392 .12159 L
.50516 .12159 L
.50646 .12159 L
.50758 .12159 L
.5088 .12159 L
.51011 .12159 L
.51085 .12159 L
.51152 .12159 L
.51282 .12159 L
.51405 .12159 L
.5152 .1216 L
.51643 .1216 L
.51861 .12161 L
.51983 .12161 L
.52097 .12162 L
.52355 .12164 L
.52636 .12166 L
.52901 .1217 L
.5314 .12174 L
.534 .12179 L
.53682 .12187 L
.53981 .12196 L
.5452 .12221 L
.55032 .12253 L
.55502 .12291 L
.56018 .12345 L
.56562 .12417 L
.57478 .1258 L
.5848 .12827 L
.59557 .13184 L
.60537 .13598 L
.62736 .14853 L
.64748 .16375 L
.66931 .18338 L
.71224 .22554 L
Mistroke
.73359 .24512 L
.75358 .26121 L
.77396 .27485 L
.79332 .28511 L
.8146 .29354 L
.83406 .29902 L
.84413 .30116 L
.85487 .30301 L
.86493 .30439 L
.87418 .30541 L
.88499 .30635 L
.89668 .30712 L
.90698 .30763 L
.91786 .30803 L
.92782 .3083 L
.9385 .30852 L
.94857 .30867 L
.95775 .30877 L
.96817 .30885 L
.97781 .30891 L
.99961 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00942 .30901 L
.01975 .309 L
.02496 .309 L
.03053 .309 L
.04057 .30898 L
.04628 .30897 L
.05248 .30896 L
.05794 .30895 L
.06373 .30893 L
.06895 .30891 L
.07469 .30888 L
.08481 .30882 L
.09026 .30877 L
.09545 .30872 L
.10519 .3086 L
.11567 .30843 L
.12711 .30816 L
.13794 .3078 L
.14777 .30736 L
.15911 .3067 L
.16979 .30586 L
.18004 .30481 L
.19087 .30339 L
.21027 .29981 L
.22022 .29732 L
.23089 .29406 L
.25014 .28633 L
.27244 .2738 L
.29357 .2578 L
.33381 .21542 L
.37663 .15659 L
.41786 .09775 L
.43854 .0725 L
.4575 .05421 L
.4674 .04698 L
.47782 .0413 L
.48323 .03917 L
.48827 .03771 L
.49117 .03711 L
.49381 .0367 L
.49526 .03654 L
.49603 .03647 L
.49684 .03641 L
.49756 .03637 L
.49834 .03634 L
.49971 .03631 L
.50107 .03632 L
.50233 .03637 L
.50372 .03645 L
Mistroke
.50449 .03652 L
.50519 .03659 L
.50787 .03694 L
.51038 .03741 L
.51507 .03862 L
.52013 .04043 L
.5257 .04299 L
.53157 .04633 L
.54207 .05386 L
.56273 .07391 L
.582 .09756 L
.62291 .15591 L
.66639 .21567 L
.68816 .24046 L
.70828 .25937 L
.72784 .27398 L
.74858 .28572 L
.75845 .29009 L
.76907 .29404 L
.78828 .29947 L
.79835 .30159 L
.80936 .30343 L
.82085 .30491 L
.83153 .30597 L
.84261 .30681 L
.85305 .30741 L
.86243 .30781 L
.87258 .30815 L
.88254 .30839 L
.89349 .30859 L
.899 .30866 L
.90492 .30873 L
.91046 .30878 L
.9156 .30882 L
.92626 .30888 L
.93189 .30891 L
.93787 .30893 L
.94791 .30896 L
.95362 .30897 L
.95899 .30898 L
.9693 .30899 L
.97448 .309 L
.98016 .309 L
.99958 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -20 0 ]
[.5 .63053 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00942 .30902 L
.01975 .30901 L
.02496 .30901 L
.03053 .30901 L
.04057 .30901 L
.04628 .30901 L
.05248 .309 L
.05833 .309 L
.06373 .30899 L
.07396 .30898 L
.07912 .30897 L
.08481 .30896 L
.09026 .30895 L
.09545 .30893 L
.10519 .30889 L
.11062 .30886 L
.11567 .30883 L
.12117 .30878 L
.12711 .30872 L
.13289 .30865 L
.13821 .30857 L
.14866 .30837 L
.15816 .30812 L
.1682 .30776 L
.17815 .30728 L
.18882 .30658 L
.19889 .3057 L
.20807 .30466 L
.21848 .30314 L
.22811 .30135 L
.23868 .29885 L
.2499 .29547 L
.25974 .29178 L
.27035 .2869 L
.28954 .27527 L
.31059 .25762 L
.33274 .23272 L
.37275 .17149 L
.41534 .09307 L
.43501 .05882 L
.45634 .02809 L
.468 .01542 L
.47312 .01096 L
.47875 .0069 L
.48406 .0039 L
.48903 .00185 L
.49177 .00104 L
.49428 .00051 L
.49566 .00029 L
Mistroke
.49639 .0002 L
.49717 .00012 L
.49792 7e-05 L
.49859 3e-05 L
.49991 0 L
.50118 2e-05 L
.50236 9e-05 L
.50366 .00021 L
.50505 .00039 L
.50651 .00065 L
.50788 .00096 L
.51047 .00169 L
.51511 .00351 L
.52016 .00622 L
.52568 .01002 L
.53153 .01499 L
.54204 .02613 L
.56252 .05486 L
.58173 .08774 L
.62241 .16293 L
.64308 .19798 L
.66566 .23066 L
.68725 .25549 L
.70732 .27299 L
.7184 .28056 L
.72884 .28648 L
.74837 .29488 L
.75861 .29811 L
.76943 .30082 L
.77956 .30281 L
.78882 .30425 L
.79875 .30545 L
.80941 .30644 L
.81929 .30713 L
.82865 .30762 L
.83877 .30802 L
.84953 .30833 L
.85872 .30852 L
.86886 .30867 L
.87402 .30873 L
.87944 .30879 L
.88915 .30886 L
.89456 .30889 L
.8996 .30891 L
.90509 .30893 L
.91104 .30895 L
.91678 .30896 L
.92207 .30898 L
.92704 .30898 L
.9325 .30899 L
Mistroke
.94197 .309 L
.94715 .309 L
.95201 .30901 L
.95722 .30901 L
.96292 .30901 L
.96794 .30901 L
.97328 .30901 L
.98337 .30901 L
.99274 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00942 .30901 L
.01975 .309 L
.02496 .309 L
.03053 .309 L
.04057 .30898 L
.04628 .30897 L
.05248 .30896 L
.05794 .30895 L
.06373 .30893 L
.06895 .30891 L
.07469 .30888 L
.08481 .30882 L
.09026 .30877 L
.09545 .30872 L
.10519 .3086 L
.11567 .30843 L
.12711 .30816 L
.13794 .3078 L
.14777 .30736 L
.15911 .3067 L
.16979 .30586 L
.18004 .30481 L
.19087 .30339 L
.21027 .29981 L
.22022 .29732 L
.23089 .29406 L
.25014 .28633 L
.27244 .2738 L
.29357 .2578 L
.33381 .21542 L
.37663 .15659 L
.41786 .09775 L
.43854 .0725 L
.4575 .05421 L
.4674 .04698 L
.47782 .0413 L
.48323 .03917 L
.48827 .03771 L
.49117 .03711 L
.49381 .0367 L
.49526 .03654 L
.49603 .03647 L
.49684 .03641 L
.49756 .03637 L
.49834 .03634 L
.49971 .03631 L
.50107 .03632 L
.50233 .03637 L
.50372 .03645 L
Mistroke
.50449 .03652 L
.50519 .03659 L
.50787 .03694 L
.51038 .03741 L
.51507 .03862 L
.52013 .04043 L
.5257 .04299 L
.53157 .04633 L
.54207 .05386 L
.56273 .07391 L
.582 .09756 L
.62291 .15591 L
.66639 .21567 L
.68816 .24046 L
.70828 .25937 L
.72784 .27398 L
.74858 .28572 L
.75845 .29009 L
.76907 .29404 L
.78828 .29947 L
.79835 .30159 L
.80936 .30343 L
.82085 .30491 L
.83153 .30597 L
.84261 .30681 L
.85305 .30741 L
.86243 .30781 L
.87258 .30815 L
.88254 .30839 L
.89349 .30859 L
.899 .30866 L
.90492 .30873 L
.91046 .30878 L
.9156 .30882 L
.92626 .30888 L
.93189 .30891 L
.93787 .30893 L
.94791 .30896 L
.95362 .30897 L
.95899 .30898 L
.9693 .30899 L
.97448 .309 L
.98016 .309 L
.99958 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00942 .30898 L
.01975 .30893 L
.03053 .30886 L
.04057 .30878 L
.05176 .30866 L
.06194 .30851 L
.0737 .30827 L
.08481 .30794 L
.09499 .30754 L
.10578 .30698 L
.115 .30635 L
.12514 .30548 L
.13579 .3043 L
.14552 .30295 L
.15689 .30096 L
.16745 .29866 L
.18738 .29287 L
.20914 .28394 L
.23069 .272 L
.25023 .25834 L
.2923 .22115 L
.33277 .18141 L
.3533 .1631 L
.37583 .14643 L
.38618 .14027 L
.39727 .13477 L
.40767 .13066 L
.41729 .12769 L
.42797 .12525 L
.43361 .12429 L
.43959 .12348 L
.44477 .12293 L
.44963 .12253 L
.45497 .1222 L
.45775 .12206 L
.46072 .12195 L
.46345 .12186 L
.46592 .12179 L
.46844 .12174 L
.47077 .1217 L
.47348 .12166 L
.47642 .12164 L
.47902 .12162 L
.48032 .12161 L
.48176 .12161 L
.48324 .1216 L
.48464 .1216 L
.4859 .12159 L
.48728 .12159 L
Mistroke
.48877 .12159 L
.4896 .12159 L
.49035 .12159 L
.49106 .12159 L
.49182 .12159 L
.49321 .12159 L
.4945 .12159 L
.49524 .12159 L
.49592 .12159 L
.49731 .12159 L
.49808 .12159 L
.49879 .12159 L
.50005 .12159 L
.50142 .12159 L
.50272 .12159 L
.50392 .12159 L
.50516 .12159 L
.50646 .12159 L
.50758 .12159 L
.5088 .12159 L
.51011 .12159 L
.51085 .12159 L
.51152 .12159 L
.51282 .12159 L
.51405 .12159 L
.5152 .1216 L
.51643 .1216 L
.51861 .12161 L
.51983 .12161 L
.52097 .12162 L
.52355 .12164 L
.52636 .12166 L
.52901 .1217 L
.5314 .12174 L
.534 .12179 L
.53682 .12187 L
.53981 .12196 L
.5452 .12221 L
.55032 .12253 L
.55502 .12291 L
.56018 .12345 L
.56562 .12417 L
.57478 .1258 L
.5848 .12827 L
.59557 .13184 L
.60537 .13598 L
.62736 .14853 L
.64748 .16375 L
.66931 .18338 L
.71224 .22554 L
Mistroke
.73359 .24512 L
.75358 .26121 L
.77396 .27485 L
.79332 .28511 L
.8146 .29354 L
.83406 .29902 L
.84413 .30116 L
.85487 .30301 L
.86493 .30439 L
.87418 .30541 L
.88499 .30635 L
.89668 .30712 L
.90698 .30763 L
.91786 .30803 L
.92782 .3083 L
.9385 .30852 L
.94857 .30867 L
.95775 .30877 L
.96817 .30885 L
.97781 .30891 L
.99961 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .30852 L
.04057 .3078 L
.0515 .30727 L
.06168 .30663 L
.07286 .30572 L
.08481 .30444 L
.09554 .30296 L
.10718 .30092 L
.11724 .29873 L
.12833 .29578 L
.14916 .28846 L
.17124 .27775 L
.19162 .26493 L
.21354 .24811 L
.25682 .20885 L
.27845 .18925 L
.29852 .17336 L
.30851 .1668 L
.31793 .16163 L
.32314 .15924 L
.32878 .15706 L
.33353 .15556 L
.33862 .15429 L
.34132 .15377 L
.34378 .15339 L
.34626 .15308 L
.3486 .15288 L
.34992 .1528 L
.35059 .15276 L
.35133 .15274 L
.35263 .15271 L
.35385 .1527 L
.35455 .1527 L
.35528 .15272 L
.3566 .15276 L
.35733 .15279 L
.35801 .15283 L
.35956 .15294 L
.36094 .15306 L
.36244 .15323 L
.36516 .1536 L
.37025 .15456 L
.37619 .15608 L
.38167 .15785 L
.40138 .16659 L
.42305 .17893 L
.44518 .19182 L
.4654 .20151 L
.47541 .20498 L
Mistroke
.48107 .20648 L
.48377 .20706 L
.48632 .20753 L
.48874 .2079 L
.49136 .20823 L
.49252 .20834 L
.49374 .20845 L
.49489 .20853 L
.49593 .20859 L
.49715 .20864 L
.49846 .20868 L
.49967 .20869 L
.50082 .20869 L
.50215 .20866 L
.50338 .20862 L
.50473 .20855 L
.50617 .20846 L
.50868 .20822 L
.51132 .20789 L
.51603 .2071 L
.52111 .20594 L
.52666 .20435 L
.53661 .20069 L
.54586 .19648 L
.58691 .17305 L
.60786 .16207 L
.6136 .15962 L
.61967 .15738 L
.62491 .15576 L
.63054 .15439 L
.63332 .15385 L
.63596 .15343 L
.63832 .15314 L
.63955 .15301 L
.6409 .1529 L
.64215 .15282 L
.64333 .15276 L
.64458 .15272 L
.64592 .1527 L
.6471 .1527 L
.64835 .15273 L
.64941 .15276 L
.65057 .15282 L
.65206 .15293 L
.65346 .15305 L
.65608 .15337 L
.6589 .15381 L
.66197 .15442 L
.66749 .15585 L
.67258 .15755 L
Mistroke
.68274 .16196 L
.69225 .16726 L
.71392 .18285 L
.75465 .21961 L
.79796 .2573 L
.81959 .27234 L
.83967 .28344 L
.8591 .29166 L
.87979 .298 L
.8906 .30047 L
.90229 .30262 L
.91239 .30409 L
.92348 .30536 L
.93431 .30633 L
.94443 .30703 L
.95511 .30761 L
.96655 .30809 L
.98373 .30862 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .3069 L
.04057 .30415 L
.06168 .30021 L
.07365 .29724 L
.08481 .29386 L
.10625 .28541 L
.12575 .27518 L
.16768 .24464 L
.20801 .20781 L
.22843 .18942 L
.25092 .17203 L
.2612 .1657 L
.26687 .16275 L
.27226 .16033 L
.27725 .15844 L
.28269 .15678 L
.28509 .15619 L
.28764 .15565 L
.28984 .15527 L
.29224 .15494 L
.29356 .15479 L
.29498 .15466 L
.29576 .1546 L
.29647 .15456 L
.29719 .15452 L
.29787 .1545 L
.29914 .15446 L
.30052 .15446 L
.30174 .15448 L
.30304 .15452 L
.30442 .1546 L
.3059 .15471 L
.30859 .15501 L
.31179 .1555 L
.31472 .15608 L
.31965 .15735 L
.32504 .15914 L
.3359 .16395 L
.35649 .17687 L
.37849 .19459 L
.42206 .23242 L
.44391 .24834 L
.4535 .25404 L
.46404 .25923 L
.46893 .26122 L
.47418 .26305 L
.47872 .26437 L
.48366 .26553 L
.48655 .26606 L
Mistroke
.48923 .26647 L
.49179 .26677 L
.4931 .2669 L
.49452 .26701 L
.49591 .26709 L
.4972 .26715 L
.49843 .26718 L
.49972 .2672 L
.50089 .26719 L
.50197 .26717 L
.50316 .26713 L
.50443 .26707 L
.50572 .26699 L
.50714 .26688 L
.51 .26657 L
.51266 .26619 L
.51514 .26576 L
.52075 .26451 L
.52678 .26274 L
.53781 .25841 L
.54792 .25326 L
.56783 .24023 L
.58958 .2227 L
.63222 .1856 L
.65193 .17105 L
.66231 .16489 L
.67327 .15978 L
.67885 .15781 L
.6818 .15694 L
.68497 .15615 L
.68788 .15556 L
.69053 .15512 L
.69181 .15495 L
.6932 .1548 L
.69442 .15468 L
.69573 .15459 L
.69704 .15452 L
.69826 .15448 L
.69897 .15446 L
.69972 .15446 L
.70106 .15447 L
.70173 .15448 L
.70246 .15451 L
.70376 .15457 L
.70456 .15463 L
.70531 .15468 L
.70672 .15482 L
.70926 .15513 L
.71161 .15551 L
.7169 .15667 L
Mistroke
.7218 .15812 L
.72706 .16005 L
.73658 .1645 L
.75824 .17861 L
.80155 .21675 L
.84326 .25365 L
.86431 .26897 L
.88339 .28029 L
.90406 .28981 L
.91553 .29397 L
.92608 .29716 L
.94631 .30187 L
.95695 .30375 L
.96818 .30541 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .30217 L
.04057 .29405 L
.06347 .28302 L
.08481 .2701 L
.12477 .23862 L
.16571 .20073 L
.18658 .18267 L
.19757 .17436 L
.20923 .16684 L
.2196 .16149 L
.22511 .15922 L
.23103 .15727 L
.23381 .15652 L
.23645 .15592 L
.23903 .15544 L
.24142 .15508 L
.24367 .15482 L
.24493 .15471 L
.24607 .15463 L
.24733 .15456 L
.24869 .15452 L
.24997 .15451 L
.25115 .15452 L
.25248 .15456 L
.25374 .15462 L
.25486 .15469 L
.25609 .15479 L
.25884 .15511 L
.26138 .1555 L
.266 .15647 L
.27092 .15785 L
.28123 .16186 L
.29262 .16792 L
.31293 .18225 L
.33483 .20117 L
.37803 .24078 L
.39958 .25821 L
.41963 .2717 L
.43898 .28188 L
.44973 .28629 L
.45965 .28957 L
.4704 .2923 L
.47606 .29339 L
.48206 .29429 L
.48457 .29459 L
.48726 .29486 L
.48959 .29505 L
.49213 .29522 L
.49368 .2953 L
Mistroke
.49511 .29535 L
.49647 .2954 L
.49724 .29541 L
.49793 .29542 L
.49924 .29544 L
.49998 .29544 L
.50065 .29544 L
.5019 .29543 L
.50322 .2954 L
.5045 .29537 L
.5059 .29532 L
.50844 .29519 L
.51091 .29501 L
.5132 .29482 L
.51838 .29423 L
.52388 .2934 L
.53304 .29152 L
.54314 .28873 L
.5635 .28074 L
.58541 .26858 L
.62866 .23489 L
.67032 .19651 L
.69133 .17893 L
.71039 .16616 L
.72101 .16086 L
.72588 .15894 L
.73102 .15726 L
.73365 .15656 L
.73653 .1559 L
.73918 .15541 L
.74159 .15505 L
.74296 .15489 L
.74445 .15475 L
.74526 .15468 L
.74602 .15463 L
.74679 .15459 L
.74751 .15456 L
.74878 .15452 L
.74946 .15451 L
.75019 .15451 L
.75091 .15451 L
.75167 .15453 L
.75304 .15458 L
.75433 .15465 L
.75573 .15476 L
.75828 .15504 L
.76075 .1554 L
.76304 .15582 L
.76824 .15706 L
.77374 .1588 L
Mistroke
.78291 .16266 L
.79302 .16817 L
.81341 .18266 L
.83534 .20169 L
.87865 .24163 L
.90028 .25941 L
.92036 .27349 L
.94141 .2856 L
.96048 .29449 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .27422 L
.08481 .23211 L
.12636 .19196 L
.14728 .17493 L
.15641 .16878 L
.16632 .16322 L
.17181 .16068 L
.17688 .15871 L
.18204 .15709 L
.18687 .15592 L
.18932 .15547 L
.19195 .15508 L
.19344 .15491 L
.19487 .15478 L
.19615 .15468 L
.19682 .15465 L
.19754 .15461 L
.19831 .15459 L
.19903 .15457 L
.20038 .15456 L
.20115 .15457 L
.20196 .15459 L
.20265 .15461 L
.20341 .15464 L
.20477 .15473 L
.20622 .15485 L
.20885 .15515 L
.21154 .15557 L
.2144 .15613 L
.21953 .15745 L
.22506 .1593 L
.23115 .16184 L
.25228 .17425 L
.2726 .1903 L
.29449 .21015 L
.33769 .24914 L
.35924 .26553 L
.3793 .27803 L
.39864 .28748 L
.41931 .29496 L
.43007 .2979 L
.44172 .30044 L
.45273 .30231 L
.46288 .30361 L
.46779 .30411 L
.47306 .30457 L
.47762 .30489 L
.48259 .30516 L
.4856 .3053 L
Mistroke
.48839 .3054 L
.49107 .30547 L
.49243 .30551 L
.49391 .30553 L
.49537 .30555 L
.49671 .30557 L
.49799 .30558 L
.49934 .30558 L
.50055 .30558 L
.50169 .30558 L
.50293 .30557 L
.50426 .30556 L
.50554 .30554 L
.50696 .30552 L
.50982 .30545 L
.51248 .30537 L
.51497 .30527 L
.52057 .305 L
.5266 .30459 L
.53764 .30355 L
.54774 .30224 L
.55806 .30049 L
.56765 .29845 L
.57885 .29551 L
.5894 .29212 L
.61092 .28312 L
.63045 .2723 L
.6709 .24187 L
.71392 .20235 L
.73533 .18366 L
.7458 .17562 L
.75535 .16918 L
.76455 .16393 L
.77456 .15945 L
.78006 .15757 L
.78515 .15623 L
.79001 .15531 L
.79247 .15498 L
.79387 .15484 L
.79518 .15473 L
.79641 .15465 L
.79773 .1546 L
.79897 .15457 L
.8001 .15456 L
.80143 .15458 L
.80218 .1546 L
.80287 .15463 L
.80414 .1547 L
.80549 .15481 L
.80816 .15509 L
Mistroke
.81066 .15546 L
.8134 .15598 L
.81635 .15666 L
.82649 .15998 L
.83577 .16429 L
.85572 .17714 L
.87748 .19543 L
.92018 .23706 L
.96129 .27588 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .24926 L
.06168 .22085 L
.08481 .1939 L
.0952 .18369 L
.10632 .17435 L
.11674 .16723 L
.12636 .16216 L
.13157 .16005 L
.13709 .1583 L
.13976 .15764 L
.14263 .15706 L
.14427 .1568 L
.14578 .15659 L
.14721 .15643 L
.14873 .1563 L
.14946 .15626 L
.15014 .15622 L
.15142 .15617 L
.15262 .15615 L
.15391 .15615 L
.1546 .15617 L
.15535 .15619 L
.15613 .15622 L
.15686 .15627 L
.15817 .15636 L
.15957 .1565 L
.16234 .15686 L
.16496 .15731 L
.16988 .15846 L
.1747 .15994 L
.18001 .16198 L
.19078 .1673 L
.21012 .18029 L
.25234 .21754 L
.29296 .25341 L
.31359 .26848 L
.33616 .2817 L
.35771 .29115 L
.37776 .29747 L
.38881 .30009 L
.39924 .30209 L
.41876 .30483 L
.42897 .30584 L
.43977 .30666 L
.449 .3072 L
.45915 .30764 L
.46462 .30783 L
.46982 .30798 L
.47454 .30809 L
Mistroke
.47957 .30818 L
.48243 .30822 L
.48501 .30825 L
.48765 .30828 L
.49006 .3083 L
.4929 .30832 L
.49439 .30833 L
.49515 .30833 L
.49596 .30833 L
.49733 .30834 L
.4986 .30834 L
.49938 .30834 L
.50012 .30834 L
.5015 .30834 L
.50271 .30834 L
.504 .30833 L
.50522 .30833 L
.50634 .30833 L
.50894 .30831 L
.51167 .30829 L
.51682 .30823 L
.52245 .30814 L
.5273 .30805 L
.53248 .30791 L
.54181 .30761 L
.55259 .30712 L
.56426 .30638 L
.57528 .30545 L
.58543 .30434 L
.60517 .3013 L
.61639 .29892 L
.62686 .2962 L
.6482 .28885 L
.66768 .2797 L
.6877 .26763 L
.70948 .25146 L
.75227 .21323 L
.77351 .19382 L
.79347 .17759 L
.81252 .16551 L
.81774 .16296 L
.82324 .16069 L
.82829 .15898 L
.83307 .15772 L
.83559 .15721 L
.83831 .15676 L
.83952 .1566 L
.84079 .15646 L
.84198 .15635 L
.84308 .15627 L
Mistroke
.84434 .1562 L
.84571 .15616 L
.84697 .15615 L
.84817 .15616 L
.84884 .15618 L
.84956 .1562 L
.85085 .15627 L
.85164 .15633 L
.85238 .1564 L
.85377 .15654 L
.85612 .15686 L
.8586 .15729 L
.86304 .15833 L
.86781 .15982 L
.87305 .1619 L
.88378 .16754 L
.89355 .17425 L
.91552 .19424 L
.95738 .24637 L
.99764 .30547 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .27248 L
.04057 .23705 L
.06168 .20726 L
.07365 .19399 L
.08481 .18429 L
.09009 .18063 L
.09583 .17735 L
.10125 .17491 L
.10383 .17398 L
.10625 .17323 L
.1086 .17262 L
.11075 .17217 L
.11314 .17178 L
.11446 .17161 L
.11571 .17149 L
.11692 .1714 L
.1182 .17134 L
.11941 .17131 L
.12051 .17131 L
.12181 .17134 L
.12254 .17137 L
.12321 .17141 L
.12445 .1715 L
.12575 .17163 L
.12842 .172 L
.13096 .17247 L
.1357 .17366 L
.14081 .17536 L
.14637 .17769 L
.16562 .18898 L
.20844 .22452 L
.24967 .25895 L
.27035 .27297 L
.28931 .28335 L
.30963 .29188 L
.32097 .29559 L
.33152 .29844 L
.35139 .30247 L
.3619 .30401 L
.37313 .30531 L
.38388 .30627 L
.39554 .30706 L
.40655 .30761 L
.4167 .30799 L
.42688 .30828 L
.4364 .30847 L
.44685 .30863 L
.45272 .3087 L
.45808 .30875 L
Mistroke
.4631 .30879 L
.46844 .30883 L
.47306 .30885 L
.47805 .30887 L
.48112 .30888 L
.48394 .30889 L
.48658 .3089 L
.48948 .3089 L
.49208 .30891 L
.49451 .30891 L
.49585 .30891 L
.49708 .30891 L
.49775 .30891 L
.49849 .30891 L
.49982 .30891 L
.50111 .30891 L
.50228 .30891 L
.50357 .30891 L
.50493 .30891 L
.50612 .30891 L
.50722 .30891 L
.50972 .30891 L
.51249 .3089 L
.515 .3089 L
.52063 .30888 L
.52608 .30886 L
.53199 .30883 L
.53753 .30879 L
.5427 .30875 L
.55266 .30864 L
.56361 .30847 L
.57428 .30825 L
.58572 .30791 L
.59638 .30748 L
.608 .30684 L
.61896 .30604 L
.62911 .30508 L
.64869 .30245 L
.65984 .30039 L
.67031 .29798 L
.69148 .29148 L
.7109 .28325 L
.73074 .2723 L
.75247 .25735 L
.79503 .22144 L
.81467 .20429 L
.83599 .18787 L
.84763 .1807 L
.85275 .1781 L
.85838 .17567 L
Mistroke
.86368 .17384 L
.86865 .17255 L
.87138 .17203 L
.87389 .17168 L
.87527 .17153 L
.876 .17147 L
.87678 .17141 L
.87753 .17137 L
.87821 .17134 L
.87953 .17131 L
.88079 .17131 L
.88197 .17134 L
.88327 .17141 L
.88465 .17152 L
.88611 .17168 L
.88748 .17187 L
.89006 .17233 L
.89248 .17288 L
.89471 .17351 L
.89975 .17532 L
.90479 .17767 L
.91036 .18092 L
.92162 .18955 L
.93223 .20015 L
.94195 .21183 L
.96385 .24416 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .28257 L
.04057 .25772 L
.05077 .24751 L
.06168 .23837 L
.06795 .23404 L
.07365 .2307 L
.07907 .22808 L
.08481 .22587 L
.08978 .22443 L
.09261 .22381 L
.09526 .22335 L
.09651 .22317 L
.09769 .22303 L
.09877 .22293 L
.09991 .22283 L
.10115 .22275 L
.1023 .22271 L
.10367 .22268 L
.10491 .22267 L
.10628 .2227 L
.10697 .22273 L
.10772 .22276 L
.10906 .22284 L
.11031 .22295 L
.11313 .22326 L
.11615 .22373 L
.12169 .22491 L
.12674 .22632 L
.13714 .23014 L
.14677 .23457 L
.16857 .24669 L
.2098 .27121 L
.23048 .28173 L
.24944 .28962 L
.26975 .29613 L
.2811 .29896 L
.29165 .30113 L
.31152 .30419 L
.32203 .30535 L
.33326 .30632 L
.34401 .30703 L
.35567 .30761 L
.36668 .30802 L
.37683 .30829 L
.38701 .3085 L
.39653 .30864 L
.40698 .30876 L
.41285 .30881 L
.4182 .30884 L
Mistroke
.42323 .30887 L
.42857 .3089 L
.43818 .30894 L
.44407 .30895 L
.44961 .30896 L
.45454 .30897 L
.45995 .30898 L
.46492 .30899 L
.47023 .30899 L
.47584 .309 L
.48108 .309 L
.48358 .309 L
.4863 .309 L
.48869 .309 L
.49124 .309 L
.49352 .309 L
.49482 .309 L
.49604 .309 L
.49716 .309 L
.49818 .309 L
.49931 .309 L
.50049 .309 L
.50179 .309 L
.50252 .309 L
.5032 .309 L
.50444 .309 L
.50576 .309 L
.50803 .309 L
.51054 .309 L
.51321 .309 L
.51608 .309 L
.52126 .309 L
.52644 .309 L
.53135 .30899 L
.54056 .30898 L
.54536 .30897 L
.55068 .30896 L
.55585 .30895 L
.56143 .30894 L
.5714 .3089 L
.58077 .30885 L
.5908 .30878 L
.60179 .30866 L
.60733 .30859 L
.61325 .3085 L
.62393 .30828 L
.63467 .30797 L
.64632 .30753 L
.65732 .30695 L
.66747 .30626 L
Mistroke
.67763 .30538 L
.68715 .30435 L
.69825 .30284 L
.70881 .30105 L
.73008 .29618 L
.74954 .28999 L
.77035 .28134 L
.78966 .2715 L
.83077 .24709 L
.85176 .23531 L
.8628 .23017 L
.86883 .22781 L
.87445 .22596 L
.8795 .22462 L
.88209 .22406 L
.88491 .22355 L
.88651 .22331 L
.88799 .22312 L
.88938 .22298 L
.89091 .22285 L
.89228 .22276 L
.89356 .22271 L
.89492 .22268 L
.89568 .22267 L
.89638 .22268 L
.89756 .2227 L
.89881 .22275 L
.9 .22283 L
.90107 .22291 L
.90371 .2232 L
.9062 .22359 L
.91117 .22467 L
.91654 .22633 L
.92168 .22841 L
.92649 .23078 L
.93743 .23772 L
.94809 .24646 L
.95953 .25783 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .30902 L
.04057 .30902 L
.06168 .30902 L
.06747 .30902 L
.07365 .30902 L
.07945 .30902 L
.08481 .30902 L
.09002 .30902 L
.09268 .30902 L
.09554 .30902 L
.09703 .30902 L
.0984 .30902 L
.09979 .30902 L
.10108 .30902 L
.10257 .30902 L
.10336 .30902 L
.10421 .30902 L
.10501 .30902 L
.10577 .30902 L
.10644 .30902 L
.10718 .30902 L
.1085 .30902 L
.10973 .30902 L
.11109 .30902 L
.11254 .30902 L
.11549 .30902 L
.11819 .30902 L
.1234 .30902 L
.12833 .30902 L
.13846 .30902 L
.14923 .30902 L
.16857 .30902 L
.20821 .30902 L
.25042 .30902 L
.26982 .30902 L
.28082 .30902 L
.29105 .30902 L
.30122 .30902 L
.30691 .30902 L
.31209 .30902 L
.31474 .30902 L
.31756 .30902 L
.31903 .30902 L
.32064 .30902 L
.32213 .30902 L
.32348 .30902 L
.32486 .30902 L
.32616 .30902 L
.32754 .30902 L
Mistroke
.32832 .30902 L
.32904 .30902 L
.33036 .30902 L
.33156 .30902 L
.33294 .30902 L
.33424 .30902 L
.33678 .30902 L
.33915 .30902 L
.34452 .30902 L
.34976 .30902 L
.35537 .30902 L
.36553 .30902 L
.37478 .30902 L
.41667 .30902 L
.43584 .30902 L
.44674 .30902 L
.45697 .30902 L
.46783 .30902 L
.47777 .30902 L
.48295 .30902 L
.4884 .30902 L
.49124 .30902 L
.49387 .30902 L
.49539 .30902 L
.49676 .30902 L
.49752 .30902 L
.49835 .30902 L
.49913 .30902 L
.49985 .30902 L
.50117 .30902 L
.50242 .30902 L
.50354 .30902 L
.50477 .30902 L
.5061 .30902 L
.50751 .30902 L
.51005 .30902 L
.51458 .30902 L
.51959 .30902 L
.52496 .30902 L
.53077 .30902 L
.54127 .30902 L
.58444 .30902 L
.60596 .30902 L
.61646 .30902 L
.62601 .30902 L
.63527 .30902 L
.64533 .30902 L
.65085 .30902 L
.65595 .30902 L
.66082 .30902 L
Mistroke
.66328 .30902 L
.66469 .30902 L
.66599 .30902 L
.66725 .30902 L
.6686 .30902 L
.66937 .30902 L
.6701 .30902 L
.67145 .30902 L
.67275 .30902 L
.67394 .30902 L
.67526 .30902 L
.67664 .30902 L
.67904 .30902 L
.68129 .30902 L
.68638 .30902 L
.69192 .30902 L
.69697 .30902 L
.70831 .30902 L
.72837 .30902 L
.75017 .30902 L
.79301 .30902 L
.81429 .30902 L
.83426 .30902 L
.85335 .30902 L
.86408 .30902 L
.87392 .30902 L
.8789 .30902 L
.88164 .30902 L
.88422 .30902 L
.88663 .30902 L
.8879 .30902 L
.88925 .30902 L
.89038 .30902 L
.89162 .30902 L
.89275 .30902 L
.89381 .30902 L
.89515 .30902 L
.89591 .30902 L
.89662 .30902 L
.89791 .30902 L
.89929 .30902 L
.90064 .30902 L
.90191 .30902 L
.90429 .30902 L
.90711 .30902 L
.9097 .30902 L
.91555 .30902 L
.9205 .30902 L
.92581 .30902 L
.93537 .30902 L
Mistroke
.95708 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .33547 L
.04057 .36031 L
.05077 .37053 L
.06168 .37966 L
.06795 .38399 L
.07365 .38733 L
.07907 .38996 L
.08481 .39217 L
.08978 .3936 L
.09261 .39423 L
.09526 .39469 L
.09651 .39486 L
.09769 .395 L
.09877 .39511 L
.09991 .3952 L
.10115 .39528 L
.1023 .39533 L
.10367 .39536 L
.10491 .39536 L
.10628 .39533 L
.10697 .39531 L
.10772 .39527 L
.10906 .39519 L
.11031 .39509 L
.11313 .39477 L
.11615 .3943 L
.12169 .39312 L
.12674 .39171 L
.13714 .38789 L
.14677 .38346 L
.16857 .37134 L
.2098 .34682 L
.23048 .33631 L
.24944 .32842 L
.26975 .3219 L
.2811 .31907 L
.29165 .3169 L
.31152 .31385 L
.32203 .31268 L
.33326 .31171 L
.34401 .311 L
.35567 .31042 L
.36668 .31002 L
.37683 .30974 L
.38701 .30953 L
.39653 .30939 L
.40698 .30928 L
.41285 .30923 L
.4182 .30919 L
Mistroke
.42323 .30916 L
.42857 .30913 L
.43818 .3091 L
.44407 .30908 L
.44961 .30907 L
.45454 .30906 L
.45995 .30905 L
.46492 .30905 L
.47023 .30904 L
.47584 .30904 L
.48108 .30903 L
.48358 .30903 L
.4863 .30903 L
.48869 .30903 L
.49124 .30903 L
.49352 .30903 L
.49482 .30903 L
.49604 .30903 L
.49716 .30903 L
.49818 .30903 L
.49931 .30903 L
.50049 .30903 L
.50179 .30903 L
.50252 .30903 L
.5032 .30903 L
.50444 .30903 L
.50576 .30903 L
.50803 .30903 L
.51054 .30903 L
.51321 .30903 L
.51608 .30903 L
.52126 .30904 L
.52644 .30904 L
.53135 .30904 L
.54056 .30905 L
.54536 .30906 L
.55068 .30907 L
.55585 .30908 L
.56143 .3091 L
.5714 .30913 L
.58077 .30918 L
.5908 .30926 L
.60179 .30937 L
.60733 .30944 L
.61325 .30954 L
.62393 .30976 L
.63467 .31006 L
.64632 .31051 L
.65732 .31108 L
.66747 .31177 L
Mistroke
.67763 .31265 L
.68715 .31369 L
.69825 .3152 L
.70881 .31699 L
.73008 .32186 L
.74954 .32804 L
.77035 .33669 L
.78966 .34653 L
.83077 .37095 L
.85176 .38272 L
.8628 .38787 L
.86883 .39022 L
.87445 .39207 L
.8795 .39341 L
.88209 .39397 L
.88491 .39448 L
.88651 .39472 L
.88799 .39491 L
.88938 .39506 L
.89091 .39519 L
.89228 .39527 L
.89356 .39533 L
.89492 .39536 L
.89568 .39536 L
.89638 .39536 L
.89756 .39533 L
.89881 .39528 L
.9 .39521 L
.90107 .39512 L
.90371 .39483 L
.9062 .39445 L
.91117 .39336 L
.91654 .3917 L
.92168 .38962 L
.92649 .38725 L
.93743 .38032 L
.94809 .37158 L
.95953 .36021 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .34555 L
.04057 .38098 L
.06168 .41078 L
.07365 .42405 L
.08481 .43374 L
.09009 .4374 L
.09583 .44068 L
.10125 .44312 L
.10383 .44406 L
.10625 .44481 L
.1086 .44541 L
.11075 .44587 L
.11314 .44626 L
.11446 .44642 L
.11571 .44655 L
.11692 .44663 L
.1182 .4467 L
.11941 .44672 L
.12051 .44672 L
.12181 .44669 L
.12254 .44666 L
.12321 .44662 L
.12445 .44653 L
.12575 .4464 L
.12842 .44603 L
.13096 .44556 L
.1357 .44438 L
.14081 .44267 L
.14637 .44035 L
.16562 .42906 L
.20844 .39351 L
.24967 .35908 L
.27035 .34506 L
.28931 .33469 L
.30963 .32615 L
.32097 .32244 L
.33152 .31959 L
.35139 .31557 L
.3619 .31402 L
.37313 .31272 L
.38388 .31176 L
.39554 .31098 L
.40655 .31042 L
.4167 .31004 L
.42688 .30976 L
.4364 .30956 L
.44685 .3094 L
.45272 .30933 L
.45808 .30928 L
Mistroke
.4631 .30924 L
.46844 .30921 L
.47306 .30918 L
.47805 .30916 L
.48112 .30915 L
.48394 .30914 L
.48658 .30913 L
.48948 .30913 L
.49208 .30913 L
.49451 .30912 L
.49585 .30912 L
.49708 .30912 L
.49775 .30912 L
.49849 .30912 L
.49982 .30912 L
.50111 .30912 L
.50228 .30912 L
.50357 .30912 L
.50493 .30912 L
.50612 .30912 L
.50722 .30912 L
.50972 .30913 L
.51249 .30913 L
.515 .30914 L
.52063 .30916 L
.52608 .30918 L
.53199 .30921 L
.53753 .30924 L
.5427 .30929 L
.55266 .30939 L
.56361 .30956 L
.57428 .30979 L
.58572 .31012 L
.59638 .31056 L
.608 .31119 L
.61896 .31199 L
.62911 .31296 L
.64869 .31558 L
.65984 .31765 L
.67031 .32005 L
.69148 .32655 L
.7109 .33479 L
.73074 .34574 L
.75247 .36069 L
.79503 .3966 L
.81467 .41374 L
.83599 .43017 L
.84763 .43733 L
.85275 .43993 L
.85838 .44236 L
Mistroke
.86368 .4442 L
.86865 .44548 L
.87138 .446 L
.87389 .44636 L
.87527 .44651 L
.876 .44657 L
.87678 .44662 L
.87753 .44667 L
.87821 .44669 L
.87953 .44672 L
.88079 .44672 L
.88197 .44669 L
.88327 .44662 L
.88465 .44651 L
.88611 .44636 L
.88748 .44617 L
.89006 .44571 L
.89248 .44515 L
.89471 .44453 L
.89975 .44272 L
.90479 .44036 L
.91036 .43711 L
.92162 .42848 L
.93223 .41789 L
.94195 .4062 L
.96385 .37387 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .36878 L
.06168 .39719 L
.08481 .42414 L
.0952 .43434 L
.10632 .44368 L
.11674 .45081 L
.12636 .45588 L
.13157 .45799 L
.13709 .45973 L
.13976 .4604 L
.14263 .46097 L
.14427 .46124 L
.14578 .46144 L
.14721 .4616 L
.14873 .46173 L
.14946 .46178 L
.15014 .46182 L
.15142 .46187 L
.15262 .46189 L
.15391 .46188 L
.1546 .46187 L
.15535 .46184 L
.15613 .46181 L
.15686 .46177 L
.15817 .46167 L
.15957 .46154 L
.16234 .46118 L
.16496 .46072 L
.16988 .45958 L
.1747 .45809 L
.18001 .45605 L
.19078 .45073 L
.21012 .43774 L
.25234 .40049 L
.29296 .36462 L
.31359 .34955 L
.33616 .33633 L
.35771 .32689 L
.37776 .32057 L
.38881 .31794 L
.39924 .31594 L
.41876 .3132 L
.42897 .31219 L
.43977 .31137 L
.449 .31084 L
.45915 .31039 L
.46462 .3102 L
.46982 .31006 L
.47454 .30995 L
Mistroke
.47957 .30986 L
.48243 .30981 L
.48501 .30978 L
.48765 .30975 L
.49006 .30973 L
.4929 .30971 L
.49439 .30971 L
.49515 .3097 L
.49596 .3097 L
.49733 .3097 L
.4986 .30969 L
.49938 .30969 L
.50012 .30969 L
.5015 .30969 L
.50271 .3097 L
.504 .3097 L
.50522 .3097 L
.50634 .30971 L
.50894 .30972 L
.51167 .30975 L
.51682 .3098 L
.52245 .30989 L
.5273 .30999 L
.53248 .31012 L
.54181 .31043 L
.55259 .31092 L
.56426 .31165 L
.57528 .31258 L
.58543 .3137 L
.60517 .31674 L
.61639 .31911 L
.62686 .32183 L
.6482 .32919 L
.66768 .33833 L
.6877 .35041 L
.70948 .36658 L
.75227 .4048 L
.77351 .42421 L
.79347 .44044 L
.81252 .45252 L
.81774 .45507 L
.82324 .45735 L
.82829 .45905 L
.83307 .46031 L
.83559 .46083 L
.83831 .46127 L
.83952 .46143 L
.84079 .46158 L
.84198 .46168 L
.84308 .46176 L
Mistroke
.84434 .46183 L
.84571 .46188 L
.84697 .46189 L
.84817 .46188 L
.84884 .46186 L
.84956 .46183 L
.85085 .46176 L
.85164 .4617 L
.85238 .46164 L
.85377 .46149 L
.85612 .46118 L
.8586 .46074 L
.86304 .4597 L
.86781 .45821 L
.87305 .45614 L
.88378 .45049 L
.89355 .44378 L
.91552 .42379 L
.95738 .37166 L
.99764 .31256 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .34381 L
.08481 .38592 L
.12636 .42608 L
.14728 .44311 L
.15641 .44925 L
.16632 .45482 L
.17181 .45735 L
.17688 .45932 L
.18204 .46095 L
.18687 .46211 L
.18932 .46257 L
.19195 .46295 L
.19344 .46313 L
.19487 .46326 L
.19615 .46335 L
.19682 .46339 L
.19754 .46342 L
.19831 .46345 L
.19903 .46346 L
.20038 .46347 L
.20115 .46347 L
.20196 .46345 L
.20265 .46342 L
.20341 .46339 L
.20477 .46331 L
.20622 .46319 L
.20885 .46289 L
.21154 .46247 L
.2144 .4619 L
.21953 .46058 L
.22506 .45873 L
.23115 .45619 L
.25228 .44378 L
.2726 .42773 L
.29449 .40788 L
.33769 .3689 L
.35924 .35251 L
.3793 .34 L
.39864 .33055 L
.41931 .32308 L
.43007 .32014 L
.44172 .31759 L
.45273 .31573 L
.46288 .31442 L
.46779 .31392 L
.47306 .31347 L
.47762 .31315 L
.48259 .31287 L
.4856 .31274 L
Mistroke
.48839 .31264 L
.49107 .31256 L
.49243 .31253 L
.49391 .3125 L
.49537 .31248 L
.49671 .31246 L
.49799 .31246 L
.49934 .31245 L
.50055 .31245 L
.50169 .31245 L
.50293 .31246 L
.50426 .31247 L
.50554 .31249 L
.50696 .31252 L
.50982 .31258 L
.51248 .31266 L
.51497 .31276 L
.52057 .31304 L
.5266 .31344 L
.53764 .31448 L
.54774 .3158 L
.55806 .31755 L
.56765 .31959 L
.57885 .32253 L
.5894 .32592 L
.61092 .33491 L
.63045 .34574 L
.6709 .37617 L
.71392 .41569 L
.73533 .43437 L
.7458 .44241 L
.75535 .44886 L
.76455 .4541 L
.77456 .45859 L
.78006 .46046 L
.78515 .4618 L
.79001 .46272 L
.79247 .46305 L
.79387 .46319 L
.79518 .4633 L
.79641 .46338 L
.79773 .46344 L
.79897 .46347 L
.8001 .46347 L
.80143 .46345 L
.80218 .46343 L
.80287 .4634 L
.80414 .46333 L
.80549 .46323 L
.80816 .46294 L
Mistroke
.81066 .46257 L
.8134 .46206 L
.81635 .46138 L
.82649 .45805 L
.83577 .45375 L
.85572 .4409 L
.87748 .42261 L
.92018 .38098 L
.96129 .34215 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .31586 L
.04057 .32399 L
.06347 .33501 L
.08481 .34793 L
.12477 .37941 L
.16571 .4173 L
.18658 .43537 L
.19757 .44368 L
.20923 .4512 L
.2196 .45655 L
.22511 .45881 L
.23103 .46077 L
.23381 .46151 L
.23645 .46211 L
.23903 .4626 L
.24142 .46296 L
.24367 .46322 L
.24493 .46333 L
.24607 .46341 L
.24733 .46347 L
.24869 .46351 L
.24997 .46353 L
.25115 .46352 L
.25248 .46348 L
.25374 .46342 L
.25486 .46334 L
.25609 .46324 L
.25884 .46292 L
.26138 .46253 L
.266 .46156 L
.27092 .46018 L
.28123 .45617 L
.29262 .45012 L
.31293 .43578 L
.33483 .41686 L
.37803 .37725 L
.39958 .35983 L
.41963 .34633 L
.43898 .33615 L
.44973 .33174 L
.45965 .32846 L
.4704 .32574 L
.47606 .32464 L
.48206 .32374 L
.48457 .32344 L
.48726 .32317 L
.48959 .32298 L
.49213 .32281 L
.49368 .32274 L
Mistroke
.49511 .32268 L
.49647 .32264 L
.49724 .32262 L
.49793 .32261 L
.49924 .3226 L
.49998 .32259 L
.50065 .3226 L
.5019 .32261 L
.50322 .32263 L
.5045 .32267 L
.5059 .32272 L
.50844 .32285 L
.51091 .32302 L
.5132 .32322 L
.51838 .3238 L
.52388 .32463 L
.53304 .32651 L
.54314 .32931 L
.5635 .33729 L
.58541 .34945 L
.62866 .38314 L
.67032 .42153 L
.69133 .43911 L
.71039 .45187 L
.72101 .45717 L
.72588 .4591 L
.73102 .46077 L
.73365 .46147 L
.73653 .46213 L
.73918 .46262 L
.74159 .46298 L
.74296 .46314 L
.74445 .46329 L
.74526 .46335 L
.74602 .4634 L
.74679 .46345 L
.74751 .46348 L
.74878 .46351 L
.74946 .46352 L
.75019 .46353 L
.75091 .46352 L
.75167 .4635 L
.75304 .46345 L
.75433 .46338 L
.75573 .46327 L
.75828 .463 L
.76075 .46263 L
.76304 .46222 L
.76824 .46098 L
.77374 .45923 L
Mistroke
.78291 .45538 L
.79302 .44987 L
.81341 .43537 L
.83534 .41634 L
.87865 .3764 L
.90028 .35862 L
.92036 .34454 L
.94141 .33243 L
.96048 .32354 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .31113 L
.04057 .31389 L
.06168 .31782 L
.07365 .3208 L
.08481 .32418 L
.10625 .33262 L
.12575 .34286 L
.16768 .37339 L
.20801 .41022 L
.22843 .42862 L
.25092 .446 L
.2612 .45233 L
.26687 .45529 L
.27226 .45771 L
.27725 .4596 L
.28269 .46125 L
.28509 .46185 L
.28764 .46238 L
.28984 .46276 L
.29224 .4631 L
.29356 .46325 L
.29498 .46337 L
.29576 .46343 L
.29647 .46347 L
.29719 .46351 L
.29787 .46354 L
.29914 .46357 L
.30052 .46358 L
.30174 .46356 L
.30304 .46351 L
.30442 .46344 L
.3059 .46332 L
.30859 .46303 L
.31179 .46254 L
.31472 .46195 L
.31965 .46068 L
.32504 .45889 L
.3359 .45409 L
.35649 .44116 L
.37849 .42344 L
.42206 .38562 L
.44391 .3697 L
.4535 .36399 L
.46404 .3588 L
.46893 .35681 L
.47418 .35498 L
.47872 .35366 L
.48366 .35251 L
.48655 .35197 L
Mistroke
.48923 .35156 L
.49179 .35126 L
.4931 .35114 L
.49452 .35103 L
.49591 .35094 L
.4972 .35089 L
.49843 .35085 L
.49972 .35084 L
.50089 .35084 L
.50197 .35086 L
.50316 .3509 L
.50443 .35096 L
.50572 .35104 L
.50714 .35116 L
.51 .35146 L
.51266 .35184 L
.51514 .35227 L
.52075 .35352 L
.52678 .35529 L
.53781 .35963 L
.54792 .36478 L
.56783 .3778 L
.58958 .39533 L
.63222 .43244 L
.65193 .44699 L
.66231 .45315 L
.67327 .45825 L
.67885 .46022 L
.6818 .46109 L
.68497 .46188 L
.68788 .46248 L
.69053 .46291 L
.69181 .46308 L
.6932 .46324 L
.69442 .46335 L
.69573 .46345 L
.69704 .46352 L
.69826 .46356 L
.69897 .46357 L
.69972 .46358 L
.70106 .46357 L
.70173 .46355 L
.70246 .46353 L
.70376 .46346 L
.70456 .46341 L
.70531 .46335 L
.70672 .46322 L
.70926 .4629 L
.71161 .46252 L
.7169 .46136 L
Mistroke
.7218 .45992 L
.72706 .45799 L
.73658 .45354 L
.75824 .43943 L
.80155 .40128 L
.84326 .36438 L
.86431 .34906 L
.88339 .33774 L
.90406 .32822 L
.91553 .32406 L
.92608 .32087 L
.94631 .31616 L
.95695 .31428 L
.96818 .31263 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.01975 .30951 L
.04057 .31023 L
.0515 .31076 L
.06168 .31141 L
.07286 .31232 L
.08481 .3136 L
.09554 .31508 L
.10718 .31711 L
.11724 .31931 L
.12833 .32226 L
.14916 .32958 L
.17124 .34028 L
.19162 .3531 L
.21354 .36992 L
.25682 .40918 L
.27845 .42878 L
.29852 .44467 L
.30851 .45124 L
.31793 .4564 L
.32314 .45879 L
.32878 .46097 L
.33353 .46248 L
.33862 .46374 L
.34132 .46426 L
.34378 .46465 L
.34626 .46495 L
.3486 .46516 L
.34992 .46524 L
.35059 .46527 L
.35133 .4653 L
.35263 .46533 L
.35385 .46534 L
.35455 .46533 L
.35528 .46532 L
.3566 .46528 L
.35733 .46524 L
.35801 .46521 L
.35956 .4651 L
.36094 .46497 L
.36244 .46481 L
.36516 .46443 L
.37025 .46348 L
.37619 .46195 L
.38167 .46019 L
.40138 .45145 L
.42305 .43911 L
.44518 .42621 L
.4654 .41652 L
.47541 .41305 L
Mistroke
.48107 .41156 L
.48377 .41098 L
.48632 .41051 L
.48874 .41013 L
.49136 .40981 L
.49252 .40969 L
.49374 .40959 L
.49489 .4095 L
.49593 .40944 L
.49715 .40939 L
.49846 .40936 L
.49967 .40934 L
.50082 .40934 L
.50215 .40937 L
.50338 .40941 L
.50473 .40948 L
.50617 .40958 L
.50868 .40981 L
.51132 .41014 L
.51603 .41094 L
.52111 .41209 L
.52666 .41368 L
.53661 .41734 L
.54586 .42155 L
.58691 .44498 L
.60786 .45596 L
.6136 .45841 L
.61967 .46065 L
.62491 .46227 L
.63054 .46365 L
.63332 .46418 L
.63596 .4646 L
.63832 .4649 L
.63955 .46502 L
.6409 .46513 L
.64215 .46522 L
.64333 .46527 L
.64458 .46532 L
.64592 .46534 L
.6471 .46533 L
.64835 .46531 L
.64941 .46527 L
.65057 .46521 L
.65206 .46511 L
.65346 .46498 L
.65608 .46467 L
.6589 .46422 L
.66197 .46361 L
.66749 .46218 L
.67258 .46049 L
Mistroke
.68274 .45607 L
.69225 .45077 L
.71392 .43518 L
.75465 .39842 L
.79796 .36074 L
.81959 .3457 L
.83967 .33459 L
.8591 .32638 L
.87979 .32004 L
.8906 .31756 L
.90229 .31542 L
.91239 .31395 L
.92348 .31267 L
.93431 .3117 L
.94443 .311 L
.95511 .31042 L
.96655 .30995 L
.98373 .30942 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00942 .30906 L
.01975 .30911 L
.03053 .30917 L
.04057 .30925 L
.05176 .30937 L
.06194 .30952 L
.0737 .30977 L
.08481 .31009 L
.09499 .31049 L
.10578 .31106 L
.115 .31168 L
.12514 .31255 L
.13579 .31373 L
.14552 .31509 L
.15689 .31707 L
.16745 .31937 L
.18738 .32517 L
.20914 .33409 L
.23069 .34604 L
.25023 .35969 L
.2923 .39688 L
.33277 .43662 L
.3533 .45493 L
.37583 .4716 L
.38618 .47776 L
.39727 .48326 L
.40767 .48738 L
.41729 .49034 L
.42797 .49278 L
.43361 .49374 L
.43959 .49456 L
.44477 .49511 L
.44963 .49551 L
.45497 .49584 L
.45775 .49597 L
.46072 .49609 L
.46345 .49618 L
.46592 .49624 L
.46844 .49629 L
.47077 .49633 L
.47348 .49637 L
.47642 .4964 L
.47902 .49642 L
.48032 .49642 L
.48176 .49643 L
.48324 .49643 L
.48464 .49644 L
.4859 .49644 L
.48728 .49644 L
Mistroke
.48877 .49644 L
.4896 .49644 L
.49035 .49644 L
.49106 .49644 L
.49182 .49644 L
.49321 .49644 L
.4945 .49645 L
.49524 .49645 L
.49592 .49645 L
.49731 .49645 L
.49808 .49645 L
.49879 .49645 L
.50005 .49645 L
.50142 .49645 L
.50272 .49645 L
.50392 .49645 L
.50516 .49645 L
.50646 .49644 L
.50758 .49644 L
.5088 .49644 L
.51011 .49644 L
.51085 .49644 L
.51152 .49644 L
.51282 .49644 L
.51405 .49644 L
.5152 .49644 L
.51643 .49643 L
.51861 .49643 L
.51983 .49642 L
.52097 .49642 L
.52355 .4964 L
.52636 .49637 L
.52901 .49634 L
.5314 .4963 L
.534 .49624 L
.53682 .49617 L
.53981 .49607 L
.5452 .49583 L
.55032 .49551 L
.55502 .49512 L
.56018 .49458 L
.56562 .49386 L
.57478 .49223 L
.5848 .48976 L
.59557 .4862 L
.60537 .48206 L
.62736 .4695 L
.64748 .45428 L
.66931 .43465 L
.71224 .3925 L
Mistroke
.73359 .37292 L
.75358 .35683 L
.77396 .34319 L
.79332 .33293 L
.8146 .3245 L
.83406 .31902 L
.84413 .31687 L
.85487 .31503 L
.86493 .31364 L
.87418 .31262 L
.88499 .31168 L
.89668 .31091 L
.90698 .31041 L
.91786 .31 L
.92782 .30973 L
.9385 .30952 L
.94857 .30937 L
.95775 .30927 L
.96817 .30918 L
.97781 .30912 L
.99961 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00942 .30902 L
.01975 .30903 L
.02496 .30903 L
.03053 .30904 L
.04057 .30905 L
.04628 .30906 L
.05248 .30907 L
.05794 .30909 L
.06373 .30911 L
.06895 .30913 L
.07469 .30915 L
.08481 .30922 L
.09026 .30926 L
.09545 .30931 L
.10519 .30943 L
.11567 .30961 L
.12711 .30988 L
.13794 .31024 L
.14777 .31067 L
.15911 .31134 L
.16979 .31218 L
.18004 .31322 L
.19087 .31464 L
.21027 .31823 L
.22022 .32072 L
.23089 .32398 L
.25014 .33171 L
.27244 .34424 L
.29357 .36024 L
.33381 .40262 L
.37663 .46145 L
.41786 .52029 L
.43854 .54554 L
.4575 .56382 L
.4674 .57105 L
.47782 .57673 L
.48323 .57886 L
.48827 .58032 L
.49117 .58093 L
.49381 .58133 L
.49526 .58149 L
.49603 .58156 L
.49684 .58162 L
.49756 .58166 L
.49834 .5817 L
.49971 .58172 L
.50107 .58171 L
.50233 .58167 L
.50372 .58158 L
Mistroke
.50449 .58152 L
.50519 .58145 L
.50787 .58109 L
.51038 .58062 L
.51507 .57941 L
.52013 .57761 L
.5257 .57505 L
.53157 .57171 L
.54207 .56417 L
.56273 .54412 L
.582 .52047 L
.62291 .46212 L
.66639 .40237 L
.68816 .37757 L
.70828 .35867 L
.72784 .34406 L
.74858 .33232 L
.75845 .32794 L
.76907 .32399 L
.78828 .31856 L
.79835 .31645 L
.80936 .31461 L
.82085 .31312 L
.83153 .31206 L
.84261 .31122 L
.85305 .31063 L
.86243 .31022 L
.87258 .30989 L
.88254 .30964 L
.89349 .30945 L
.899 .30937 L
.90492 .30931 L
.91046 .30925 L
.9156 .30921 L
.92626 .30915 L
.93189 .30912 L
.93787 .3091 L
.94791 .30907 L
.95362 .30906 L
.95899 .30905 L
.9693 .30904 L
.97448 .30903 L
.98016 .30903 L
.99958 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "\tOne can see that this initial condition breaks into two equal pulses, \
propagating in opposite directions on the string. This is expected from the \
left-right symmetry of the system: there is no reason why propagation of the \
pulse in one direction should be favored over the other direction. Also, the \
pulses do not change their shape until they reach the ends of the string, \
where they reflect and propagate back toward the center again, with opposite \
sign at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)]],
  ". This means that each pulse, having covered a distance ",
  Cell[BoxData[
      \(TraditionalForm\`L = 1\)]],
  " in time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)]],
  ", has traveled with speed ",
  Cell[BoxData[
      \(TraditionalForm\`c = 1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t In fact,  it is easy to see that any function of space and time of the \
form ",
  Cell[BoxData[
      \(TraditionalForm\`f(x - c\ t)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`f(x + c\ t)\)]],
  " satisfies the wave equation for a uniform string, Eq. ",
  ButtonBox["(3.1.10)",
    ButtonData:>"(3.1.10)",
    ButtonStyle->"Hyperlink"],
  ". This is because, for such functions, the chain rule implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f/\[PartialD]t = \(\[PlusMinus]c\) \
\[PartialD]f/\[PartialD]x\)]],
  ". Therefore, ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[
            RowBox[{" ", 
              
              FormBox[\(\[PartialD]\^2 
                      f/\[PartialD]t\^2 = \(c\^2\) \
\[PartialD]f/\[PartialD]x\^2\),
                "TraditionalForm"]}],
            "TraditionalForm"]}], TraditionalForm]]],
  ", so ",
  Cell[BoxData[
      \(TraditionalForm\`f(x \[PlusMinus] c\ t)\)]],
  " satisfies the wave equation for any function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t In Chapter ",
  ButtonBox["5",
    ButtonData:>{"Chapter5.nb", None},
    ButtonStyle->"Hyperlink"],
  " we  will prove that  the general solution to the wave equation for a \
uniform infinite string can be written as a superposition of two such \
functions, traveling in opposite directions:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t) = f(x - c\ t) + g(x + c\ t)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.26)"],

Cell[TextData[{
  "This form of the solution is called  ",
  StyleBox["d'Alembert's solution",
    FontSlant->"Italic"],
  ", after its ",
  ButtonBox["discoverer",
    ButtonData:>{
      URL[ 
      "http://turnbull.dcs.st-and.ac.uk/~history/Mathematicians/D'Alembert.\
html"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:15"],

Cell[TextData[{
  "\t  Disturbances of the form ",
  Cell[BoxData[
      \(TraditionalForm\`f(x \[PlusMinus] c\ t)\)]],
  " travel with speed ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\)\(\ \)\)\)]],
  " without changing shape. For example, if ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " has a maximum at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", then this maximum point moves in time according to ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\[PlusMinus]c\)\ t\)]],
  ". Every other point in the solution moves at the same speed, so the pulse \
does not change shape as it propagates. This is what we observed in Cell ",
  ButtonBox["3.6",
    ButtonData:>"Cell 3.6",
    ButtonStyle->"Hyperlink"],
  ", up to the time that the pulses encountered the string ends."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Static Sources and Inhomogeneous Boundary Conditions ", "Section",
  CellTags->"c:11"],

Cell[CellGroupData[{

Cell["\<\
Dirichlet and von Neumann Boundary Conditions, and Static \
Transverse Forces\
\>", "Subsubsection"],

Cell[TextData[{
  " \tIn the previous wave equation examples, the boundary conditions  ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`y(0, t) = \(y(L, t) = 0\)\)]]]], 
        TraditionalForm]]],
  " were not of the most general type that can be handled using separation of \
variables. The ends of the string need not be fixed at the same height. The \
boundary conditions are then"
}], "Text"],

Cell[TextData[{
  " \t\t ",
  Cell[BoxData[
      \(TraditionalForm\`y(0, t)\  = \ y\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y(L, t)\  = \ y\_2\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Boundary conditions of this sort, where the value of the unknown function \
is specified at the end points, are referred to as ",
  StyleBox[ButtonBox["Dirichlet",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Dirichlet.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "boundary conditions, or boundary conditions of the first kind. We will now \
consider the solution of the wave equation for these Dirichlet boundary \
conditions, ",
  StyleBox["assuming that",
    FontSlant->"Italic"],
  " the boundary conditions are fixed in time; so that ",
  Cell[BoxData[
      \(TraditionalForm\`y\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\_2\)]],
  " are constants. Time-dependent boundary conditions cannot be handled using \
the separation-of-variables method discussed here, and will be left to \
Chapter ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:10"],

Cell[TextData[{
  "\tHowever, other types of ",
  StyleBox["static",
    FontSlant->"Italic"],
  " boundary conditions ",
  StyleBox["can",
    FontSlant->"Italic"],
  "  be treated with separation of variables methods.  For instance, the \
derivative  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]y/\[PartialD]x\)\(,\)\)\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " itself, can be specified at the ends of the string. This type of boundary \
condition is called a ",
  StyleBox["von Neumann",
    FontSlant->"Italic"],
  " boundary condition. Such boundary conditions  do not often occur for \
problems involving waves on a string, because the string tension is usually \
created by fixing the string ends to posts. Therefore, in this section we \
will limit discussion to Dirichlet boundary conditions. On the other hand, \
von Neumann boundary conditions can occur in other physical applications of \
the wave equation (see the exercises), and they also occur in applications \
involving other PDEs (see Sec. ",
  ButtonBox["3.1.3",
    ButtonData:>"c:13",
    ButtonStyle->"Hyperlink"],
  "). "
}], "Text",
  CellTags->"i:11"],

Cell[TextData[{
  "\tAs a second generalization of the wave equation,  we note that for any \
earthbound string the force of gravity acts in the vertical direction, \
causing a horizontal string to sag under its own weight. This effect of \
gravity has been neglected so far, but can be incorporated into the wave \
equation as a source term (provided that the sag is small). To account for \
gravity or any other transverse external force, it is necessary to refer back \
to Fig. ",
  ButtonBox["3.3",
    ButtonData:>"Fig. 3.3",
    ButtonStyle->"Hyperlink"],
  ". An extra force of magnitude ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]F\)]],
  " now acts on the mass element in the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-direction. (For gravity, ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]F = \(-\[DifferentialD]m\)\ \
\(\(g\)\(.\)\)\)]],
  ") This force must be added to the force acting to accelerate the element, \
on the ",
  "right-hand",
  " side of Equation ",
  ButtonBox["(3.1.4)",
    ButtonData:>"(3.1.4)",
    ButtonStyle->"Hyperlink"],
  ", which now reads"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]m\ \(\[PartialD]\^2\/\[PartialD]t\^2\) \
\(y(x, t)\) = \[DifferentialD]x \(\[PartialD]\/\[PartialD]x\) \(\(T\_y\)(x, 
            t)\)\  + \ \(\(\[DifferentialD]F\)\(.\)\(\ \)\)\)]]], \
"NumberedEquation",
  CellTags->"(3.1.27)"],

Cell[TextData[{
  "Dividing through by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]m\)]],
  ", substituting for the string tension via Eq. ",
  ButtonBox["(3.1.6)",
    ButtonData:>"(3.1.6)",
    ButtonStyle->"Hyperlink"],
  ", and using Eq. ",
  ButtonBox["(3.1.2)",
    ButtonData:>"(3.1.2)",
    ButtonStyle->"Hyperlink"],
  ", we obtain an inhomogeneous wave equation with a source term:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]t\^2\) \(y(x, 
            t)\) = \(1\/\(\[Rho](x)\)\) \(\[PartialD]\/\[PartialD]x\) \((\(T(
                  x)\)\ \(\[PartialD]\/\[PartialD]x\) \(y(x, t)\))\) + 
          S(x)\)]],
  ",",
  " "
}], "NumberedEquation",
  CellTags->{"(3.1.28)", "i:17"}],

Cell[TextData[{
  "where the source term ",
  Cell[BoxData[
      \(TraditionalForm\`S(x) = \[DifferentialD]F/\[DifferentialD]m\)]],
  " is the acceleration caused by the external transverse force. We ",
  StyleBox["assume ",
    FontSlant->"Italic"],
  "that this external source is time-independent; time-dependent sources are \
treated in Chapter ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Equilibrium Solution", "Subsubsection"],

Cell[TextData[{
  "As a first step to obtaining the full solution  to this problem, we will \
first consider a time-independent solution of Eq. ",
  ButtonBox["(3.1.28)",
    ButtonData:>"(3.1.28)",
    ButtonStyle->"Hyperlink"],
  ", subject to the boundary conditions  ",
  Cell[BoxData[
      \(TraditionalForm\`y(0, t)\  = \ y\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y(L, t)\  = \ y\_2\)]],
  ". This is the equilibrium solution for the shape of the string, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"y", "=", " ", 
          FormBox[\(\(y\_eq\)(x)\),
            "TraditionalForm"]}], TraditionalForm]]],
  ".  This function satisfies the time-independent wave equation:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(\[Rho](
                x)\)\) \(\[PartialD]\/\[PartialD]x\) \((\(T(
                x)\)\ \(\[PartialD]\/\[PartialD]x\) \(\(y\_eq\)(x, t)\))\) = 
        S(x)\)]],
  ",   ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              SubscriptBox[
                FormBox["y",
                  "TraditionalForm"], "eq"], "(", "0", ")"}], "=", \(y\_1\)}],
           ",", \(\(y\_eq\)(L) = \(\(y\_2\)\(.\)\)\)}], TraditionalForm]]]
}], "NumberedEquation",
  CellTags->"(3.1.29)"],

Cell["\<\
The general solution to this ODE can be obtained by direct \
integration:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(y\_eq\)(
          x)\  = \ \
\(-\(\[Integral]\_0\%x\[DifferentialD]\(\(x\^\[Prime]\)(\(1\/\(\(T(
                          x\^\[Prime])\)\(\ \)\)\) \(\[Integral]\_0\%\(x\^\
\[Prime]\)\(S(x\^\[DoublePrime])\)\ \(\[Rho](
                          x\^\[DoublePrime])\) \[DifferentialD]x\^\
\[DoublePrime]\))\)\)\) + \ C\_1\  + \ 
          C\_2\ \(\[Integral]\_0\%x\[DifferentialD]x\^\[Prime] 
                 1\/\(\(T(x\^\[Prime])\)\(\ \)\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.30)"],

Cell[TextData[{
  "The integration constants ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  " are determined by the boundary conditions:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[\(C\_1 = 
            y\_1, \ \ \ \ \(\(C\_\(\(2\)\(\ \)\)\)\(=\)\(\(y\_2 - 
                  y\_1 + \[Integral]\_0\%L\[DifferentialD]x\^\[Prime] \( 
                          1\/\(\(T(
                            x\^\[Prime])\)\(\ \)\)\) \(\[Integral]\_0\%\(x\^\
\[Prime]\)\(S(x\^\[DoublePrime])\)\ \(\[Rho](
                            x\^\[DoublePrime])\) \[DifferentialD]x\^\
\[DoublePrime]\)\)\/\(\[Integral]\_0\%L\[DifferentialD]x\^\[Prime] 
                     1\/\(\(T(x\^\[Prime])\)\(\ \)\)\)\)\(\ \)\)\),
          "TraditionalForm"], "."}], TraditionalForm]]]], "NumberedEquation",
  CellTags->"(3.1.31)"],

Cell[TextData[{
  "\tFor instance, let us suppose that we are dealing with a gravitational \
force, ",
  Cell[BoxData[
      \(TraditionalForm\`S(x)\  = \ \(-g\)\)]],
  ", that the string is uniform so that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\  = \ \(\[Rho] = constant\)\)]],
  ",  and that  ",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\)]],
  " is also approximately uniform",
  ",",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`T(x) \[TildeEqual] T = constant\)]],
  ". (The latter will be true if the tension in the string is large, so that \
the sag in the string is small). Then Eq.  ",
  ButtonBox["(3.1.30)",
    ButtonData:>"(3.1.30)",
    ButtonStyle->"Hyperlink"],
  "  becomes"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(y\_eq\)(
        x)\  = \ \(-\(\(g\ \[Rho]\)\/\(2  T\)\)\) \(x(
            L - x)\) + \ \(\(y\_2 - y\_1\)\/L\) 
          x\  + \(\(y\_1\)\(.\)\)\)]]], "NumberedEquation",
  CellTags->{"(3.1.32)", "i:5"}],

Cell[TextData[{
  "This parabolic sag in the string is the small-amplitude limit of the \
well-known ",
  StyleBox["catenary ",
    FontSlant->"Italic"],
  "curve for a hanging cable. For the case of zero gravity, the string merely \
 forms a straight line between the end points. Equation ",
  ButtonBox["(3.1.32)",
    ButtonData:>"(3.1.32)",
    ButtonStyle->"Hyperlink"],
  " is valid provided that the maximum displacement of the string due to \
gravity, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(y\_max\)\(|\)\)\  = \ 
        g\ \[Rho]\ L\^2/8\ T\)]],
  ", is small compared to ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ". This requires that the tension satisfy the inequality ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", ">>", " ", 
          RowBox[{
            StyleBox["g",
              FontSlant->"Italic"], " ", "\[Rho]", " ", \(L/8\)}]}], 
        TraditionalForm]]],
  ". For low string tension where this inequality is not satisfied, the sag \
is large and nonlinear terms in the wave equation must be kept.  [A \
discussion of the catenary curve can be found in nearly any book on \
engineering mathematics. See, for instance,  ",
  ButtonBox["Zill and Cullen (2000)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".] "
}], "Text",
  CellTags->"i:19"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Deviation From Equilibrium", "Subsubsection"],

Cell[TextData[{
  "\tHaving dealt with static source terms and inhomogeneous boundary \
conditions, we now allowr time-dependence in the full solution by writing ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  " as a sum of the equilibrium solution, ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\_eq\)(x)\)]],
  ", and a deviation from equilibrium, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(y(x, t)\), " ", "=", " ", 
          RowBox[{\(\(y\_eq\)(x)\), " ", "+", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], "(", \(x, t\), ")"}]}]}], 
        TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.33)"],

Cell[TextData[{
  "A  PDE  for ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["y",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is obtained by substituting Eq. ",
  ButtonBox["(3.1.33)",
    ButtonData:>"(3.1.33)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(3.1.28)",
    ButtonData:>"(3.1.28)",
    ButtonStyle->"Hyperlink"],
  ".  Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\_eq\)(x)\)]],
  " already satisfies Eq. ",
  ButtonBox["(3.1.28)",
    ButtonData:>"(3.1.28)",
    ButtonStyle->"Hyperlink"],
  ",  ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["y",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " satisfies the ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " wave equation with ",
  StyleBox["homogeneous ",
    FontSlant->"Italic"],
  " boundary conditions,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\^2\/\[PartialD]t\^2\), 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], "(", \(x, t\), ")"}]}], "=", 
          RowBox[{\(1\/\(\[Rho](x)\)\), \(\[PartialD]\/\[PartialD]x\), 
            RowBox[{"(", 
              RowBox[{\(T(x)\), " ", \(\[PartialD]\/\[PartialD]x\), 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], "(", \(x, t\), ")"}]}], 
              ")"}]}]}], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->"(3.1.34)"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]], "(", \(0, t\), ")"}], "=", 
          RowBox[{
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], "(", \(L, t\), ")"}], "=", 
            "0"}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.35)"],

Cell[TextData[{
  "Initial conditions for \[CapitalDelta]",
  StyleBox["y",
    FontSlant->"Italic"],
  " are obtained by substituting Eq. ",
  ButtonBox["(3.1.33)",
    ButtonData:>"(3.1.33)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(3.1.9)",
    ButtonData:>"(3.1.9)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]], "(", \(x, 0\), ")"}], 
          "=", \(\(y\_o\)(x) - \(y\_eq\)(x)\)}], TraditionalForm]]],
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[
              RowBox[{"\[PartialD]", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]]}], \(\[PartialD]t\)], \((x, 
              0)\)}], "=", \(\(v\_o\)(x)\)}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.36)"],

Cell[TextData[{
  "For the case of a uniform string, we know how to solve for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  " by using separation of variables and a Fourier series. We will deal with \
a nonuniform string in Chapter ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThis analysis shows that the static applied force and the  inhomogeneous \
boundary conditions have no effect on the string normal modes, which are \
still given by Eqs. ",
  ButtonBox["(3.1.18)",
    ButtonData:>"(3.1.18)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.1.19)",
    ButtonData:>"(3.1.19)",
    ButtonStyle->"Hyperlink"],
  " for a uniform string. This is because of the linearity of the wave \
equation. Linearity allows the application of the superposition principle to \
the solution, so that we can separate the effect of the static force and \
inhomogeneous boundary conditions from the time-dependent response to an \
initial condition."
}], "Text",
  CellTags->"i:16"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Summary", "Section",
  CellTags->"c:12"],

Cell[TextData[{
  " In this subsection we derived the wave equation, and  learned how to \
apply the method of separation of variables to solve the equation,  for the \
case of a ",
  StyleBox["uniform string",
    FontSlant->"Italic"],
  " with a ",
  StyleBox["static source",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`S(x)\)]],
  " and ",
  StyleBox["time-independent Dirichlet",
    FontSlant->"Italic"],
  " boundary conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`y(0, t) = y\_1, \ \ y(L, t) = y\_2\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t  First, we determined the equilibrium shape of the string, ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\_eq\)(x)\)]],
  ", as the time-independent solution to the PDE.  Then, we found that the \
deviation from equilibrium ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  " satisfies the ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " wave equation (i.e. no sources) with ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`y(0, t) = \(y(L, t) = 0\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t  Homogeneity of the equation and the boundary conditions allowed us to \
apply separation of variables to the problem. The solution for ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["y",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " could be written as a Fourier sine series in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " with time-dependent Fourier coefficients. Each Fourier mode was found to \
be  a normal mode of oscillation  - an eigenmode that matched the homogeneous \
boundary conditions and that satisfied an associated eigenvalue problem.   "
}], "Text",
  CellTags->"i:103"],

Cell["\<\
Other linear PDEs with time-independent sources and boundary \
conditions can also be solved using the method of separation of variables. In \
the next section we consider one such PDE: the heat equation. \
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.1.3 Derivation of the Heat Equation", "Subsubtitle",
  CellTags->{"i:108", "c:13"}],

Cell[CellGroupData[{

Cell["Heat Flux", "Section",
  CellTags->{"i:20", "c:14"}],

Cell[TextData[{
  "\tIn a material for which the temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " (measured in kelvins)  is a function of position, the second law of \
thermodynamics requires that heat will flow from hot to cold regions so as to \
equalize the temperature.  The flow of heat energy is described by an ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(energy\ flux\),
          FontSlant->"Italic"], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[CapitalGamma]",
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          
          StyleBox[\((\[CapitalGamma]\_x, \(\[CapitalGamma]\_y\) \
\[CapitalGamma]\_z)\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", with units of ",
  Cell[BoxData[
      \(TraditionalForm\`watts\ per\ square\ meter\)]],
  ". This flux is a vector, with the direction giving the direction of the \
heat flow. In a time \[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  ", the amount of heat energy ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["E",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " flowing through a surface of area ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  ", oriented transverse to the direction of ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[CapitalGamma]",
          FontWeight->"Bold"], TraditionalForm]]],
  ",  is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["E",
                FontSlant->"Italic"]}]], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", "  ", 
          FormBox[
            RowBox[{"A", " ", "\[CapitalGamma]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}],
            "TraditionalForm"]}], TraditionalForm]]],
  "."
}], "Text",
  CellTags->"i:101"],

Cell[TextData[{
  "\tConsider a piece of material in the form of a slab of thickness ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\)\(\ \)\)\)]],
  " and of cross-sectional area ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  ", with a temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\)]],
  " that varies only in the direction across the slab, the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction (see Fig. ",
  ButtonBox["3.4",
    ButtonData:>"Fig. 3.4",
    ButtonStyle->"Hyperlink"],
  ").  It is an experimental fact that this temperature gradient results in a \
heat flux in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction that is proportional to the temperature gradient,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_x = \(\(-\[Kappa]\) \
\(\[PartialD]T\/\[PartialD]x\)\(\ \)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->{"(3.1.37)", "i:113"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\)]],
  ", the constant of proportionality, is the ",
  StyleBox["thermal conductivity",
    FontSlant->"Italic"],
  " of the material. This constant is an intrinsic property of  the material \
in question. For example, pure water at room temperature and atmospheric \
pressure has ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Kappa]", "=", 
          RowBox[{"0.59", " ", 
            RowBox[{
              StyleBox["W",
                FontSlant->"Plain"], "/", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontSlant->"Plain"], " ", 
                  StyleBox["K",
                    FontSlant->"Plain"]}], ")"}]}]}]}], TraditionalForm]]],
  ", but copper conducts heat much more rapidly, having a thermal \
conductivity of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Kappa]", "=", 
          RowBox[{"400", "  ", 
            RowBox[{
              StyleBox["W",
                FontSlant->"Plain"], "/", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontSlant->"Plain"], " ", 
                  StyleBox["K",
                    FontSlant->"Plain"]}], ")"}]}]}]}], TraditionalForm]]],
  ". A temperature gradient of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"1", 
          RowBox[{
            StyleBox["K",
              FontSlant->"Plain"], "/", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "  in water leads to an energy flux of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0.59", " ", 
          RowBox[{
            StyleBox["W",
              FontSlant->"Plain"], "/", 
            SuperscriptBox[
              StyleBox["m",
                FontSlant->"Plain"], "2"]}]}], TraditionalForm]]],
  " in the direction opposite to the temperature gradient, but in copper the \
flux is 400 ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["W",
            FontSlant->"Plain"], "/", 
          SuperscriptBox[
            StyleBox["m",
              FontSlant->"Plain"], "2"]}], TraditionalForm]]],
  " . Since the energy flows down the gradient, it acts to equalize the \
temperature. "
}], "Text",
  CellTags->"i:21"],

Cell["\<\
\tNote that  although thermal conductivity varies from one material \
to the next, it must be nonnegative; otherwise heat energy would flow up the \
temperature gradient from cold to hot regions, in contradiction to the second \
law of thermodynamics.\
\>", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006P0003Gb000`400?l00000o`00003oo`3ooonQ
0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ
0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ
0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ
0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ
0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ
0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ
0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ
0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ
0?ooo`00o`3ooolA0?ooo`040<30`020P800P8200820P1/0000000<0`<300?ooo`3oool0KP3oool0
07X0oooo1@00002F0?ooo`P000002`3oool7000000030820P03oool0oooo06h0oooo001h0?ooo`T0
0000U@3oool6000000l0oooo1@00001`0?ooo`00M`3oool;000009@0oooo1P00000@0?ooo`@00000
L03oool007H0oooo1@0000040?ooo`D00000T`3oool500000140oooo0`00001`0?ooo`00M03oool0
1@20P8000000000000000000P82000L0oooo00D0@41000000000000000000410@02B0?ooo`D00000
00<0P8200?ooo`3oool03`3oool00`20P80000000000001_0?ooo`00M03oool4000000T0oooo1000
002C0?ooo`D000004P3oool00`20P80000000?ooo`1^0?ooo`00L`3oool4000000030820P03oool0
oooo00P0oooo1000002B0?ooo`D000004P3oool00`20P80000000000001^0?ooo`00LP3oool00`20
P800000000000002000000030820P03oool0oooo00P0oooo1@00002A0?ooo`D000004`3oool20000
06h0oooo001b0?ooo`030410@0000000000000800000303oool4000000030820P03oool0oooo08l0
oooo100000000`20P800oooo0?ooo`0@0?ooo`030820P0000000P82006d0oooo001b0?ooo`D00000
303oool500000940oooo100000000`20P800oooo0?ooo`0B0?ooo`030000003oool0oooo06/0oooo
001a0?ooo`D000003P3oool500000900oooo1@0000220?ooo`00L@3oool5000000h0oooo1@00002@
0?ooo`030820P0000000000000800000PP3oool00740oooo1@00000>0?ooo`D00000T03oool00`20
P80000000000000200000880oooo001`0?ooo`H000003P3oool5000000030820P03oool0oooo08d0
oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`1o0?ooo`00L03oool5000000l0oooo
1@0000000`20P800oooo0?ooo`2>0?ooo`D00000P@3oool00700oooo1@00000?0?ooo`030820P000
000000000080000000<0P8200?ooo`3oool0SP3oool500000840oooo001`0?ooo`D000003`3oool0
0`20P800000000000002000000030820P03oool0oooo08h0oooo1P0000200?ooo`00K`3oool60000
00l0oooo00<0P8200000000000000`00002A0?ooo`D00000P03oool006l0oooo1P00000?0?ooo`03
0820P0000000000000<00000T@3oool500000800oooo001_0?ooo`H000003`3oool00`20P8000000
0000000300000980oooo1@00001o0?ooo`00K`3oool6000000l0oooo00<0P8200000000000000`00
002B0?ooo`D00000O`3oool006l0oooo1P00000?0?ooo`030820P0000000000000<00000TP3oool5
000007l0oooo001_0?ooo`H000003`3oool00`20P80000000000000300000980oooo00<0P8200000
000000000`00001n0?ooo`00K`3oool6000000l0oooo00<0P8200000000000000`00002C0?ooo`D0
0000OP3oool006l0oooo1P00000?0?ooo`030820P0000000000000<00000T`3oool5000007h0oooo
001_0?ooo`H000003`3oool00`20P800000000000003000009<0oooo00<0P8200000000000000P00
00000`20P800oooo0?ooo`1k0?ooo`00K`3oool6000000l0oooo00<0P8200000000000000`00002C
0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0N`3oool006l0oooo1P00000?0?oo
o`030820P0000000000000<00000T`3oool00`20P800000000000003000007d0oooo001`0?ooo`D0
00003`3oool00`20P800000000000002000000030820P03oool0oooo0980oooo1@00001m0?ooo`00
L03oool6000000h0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`2B0?ooo`D00000
O@3oool00700oooo1P00000>0?ooo`030410@000000000000080000000<0P8200?ooo`3oool0TP3o
ool00`20P800000000000002000000030820P03oool0oooo07X0oooo001`0?ooo`H000003P3oool5
000000030820P03oool0oooo09<0oooo1@00001l0?ooo`00L@3oool5000000h0oooo1@00002F0?oo
o`D00000O03oool00740oooo1@00000>0?ooo`D00000UP3oool6000007/0oooo001a0?ooo`H00000
3@3oool5000009L0oooo1@00001k0?ooo`00LP3oool5000000`0oooo1@00002H0?ooo`D0000000<0
P8200?ooo`3oool0N03oool00780oooo00<0P8200000000000000P00000<0?ooo`@00000V@3oool6
000007X0oooo001b0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0203oool50000
09T0oooo1P00001j0?ooo`00L`3oool4000000030820P03oool0oooo00P0oooo1000002J0?ooo`H0
000000<0P8200?ooo`3oool0M`3oool007@0oooo100000000`20P800oooo0?ooo`060?ooo`@00000
VP3oool00`20P80000000000000500000080P820M`3oool007D0oooo1@0000060?ooo`050820P000
0000000000000020P800U`3oool@000007@0oooo001f0?ooo`D00000103oool500000?l0oooo7@3o
ool007L0oooo00<0P8200000000000002@00003o0?oooah0oooo001h0?ooo`T00000`03oool20000
05d0oooo001k0?ooo`D0P820`03oool500000080P820F@3oool00?l0oooo@@3oool:000005H0oooo
003o0?oood00oooo3@00001D0?ooo`00o`3ooom00?ooo`l00000DP3oool00?l0oooo@03ooolA0000
00<0P82000<0`<300?ooo`3oool0BP3oool00?l0oooo@03ooolH000004T0oooo003o0?ooocl0oooo
6P0000000`20P800oooo0?ooo`150?ooo`00o`3ooolo0?oooad00000A@3oool00?l0oooo?`3ooolN
000000030820P03oool0oooo0440oooo003o0?ooocl0oooo8@0000020820P0030<30`03oool0oooo
03`0oooo00210?ooon<00000?03oool00840ooooi00000000`20P800oooo0?ooo`0h0?ooo`00P@3o
oooU000003X0oooo00210?ooo`80P8200`00002g0820P0030410@000000000000240000000<0@410
0820P020P800?03oool008<0oooo0`00002h0?ooob400000@@3oool008<0oooo0`00002h0?oooal0
0000@`3oool008<0oooo0`00002h0?oooad00000A@3oool008<0oooo0`00002h0?oooaX0000000<0
P8200?ooo`3oool0A@3oool008<0oooo0`00002h0?ooo`030820P000000000000180000000<0@410
0820P020P800BP3oool008<0oooo0`00002i0?oooa800000C`3oool008<0oooo0`00002i0?oooa00
0000D@3oool008<0oooo0`00002i0?ooo`d00000E03oool008<0oooo0`00002j0?ooo`P000000P20
P8000`30`<00oooo0?ooo`1C0?ooo`00P`3oool3000009h0oooo0`00000I0?ooo`H00000FP3oool0
08<0oooo0`00002N0?ooo`<000006@3oool3000001l0oooo0`0000000`20P800oooo0?ooo`0<0?oo
o`<00000:@3oool008<0oooo0`00002N0?ooo`<00000>`3oool5000000`0oooo00D0P82000000000
000000000820P00X0?ooo`00P`3oool3000009h0oooo0`00000k0?ooo`H0000000<0P8200?ooo`3o
ool0203oool5000000030820P03oool0oooo02D0oooo00230?ooo`<00000WP3oool3000003/0oooo
200000080?ooo`P000009P3oool008<0oooo0`00002N0?ooo`<00000>`3oool3000000030820P03o
ool000000080000000<0P8200?ooo`3oool01@3oool5000000040?ooo`0000000000000002D0oooo
00230?ooo`<00000WP3oool3000003/0oooo0`0000040?ooo`8000001`3oool500000080oooo0P00
000U0?ooo`00P`3oool3000009h0oooo0`0000130?ooo`030000003oool0oooo00@0oooo1P000003
0?ooo`800000903oool008<0oooo0`00002N0?ooo`<00000@`3oool00`10@40000000820P0040?oo
o`D000001@3oool00`000000`<300?ooo`0R0?ooo`00P`3oool3000009h0oooo0`0000140?ooo`<0
00000`3oool5000002X0oooo00230?ooo`<00000WP3oool3000004D0oooo0P0000020?ooo`H00000
:P3oool008<0oooo0`00003V0?ooo`80000000<0P8200?ooo`0000001000000[0?ooo`00P`3oool3
00000>L0oooo00<0P8200410@03oool01@00000[0?ooo`00P`3oool300000>P0oooo1`00000[0?oo
o`00P`3oool300000>P0oooo00<0P8200000000000000`00000/0?ooo`00P`3oool300000>T0oooo
1@00000/0?ooo`00P`3oool300000>T0oooo1@00000/0?ooo`00P`3oool300000>P0oooo00<0P820
0000000000000P0000000`10@400oooo0?ooo`0Z0?ooo`00P`3oool300000>P0oooo00<0P8200000
000000000P0000000`20P800oooo0?ooo`0Z0?ooo`00P`3oool300000>P0oooo1@0000000`20P800
oooo0?ooo`0Z0?ooo`00P`3oool300000>P0oooo1P00000/0?ooo`00P`3oool300000>P0oooo1@00
00000`20P80000000?ooo`0Z0?ooo`00P`3oool300000>L0oooo1P0000000`3oool000000000000Z
0?ooo`00P`3oool300000>L0oooo1@0000020?ooo`<00000:@3oool008<0oooo0`00003W0?ooo`D0
00000`3oool2000000030820P03oool0oooo02H0oooo00230?ooo`<00000iP3oool6000000@0oooo
0P0000030?ooo`<000008P3oool008<0oooo0`00003T0?ooo`030<30`0000000000000@0000000<0
P8200?ooo`3oool00P3oool00`20P80000000000000600000240oooo00230?ooo`<00000h03oool;
000000H0oooo00<0P8200000000000001@00000Q0?ooo`00P`3oool3000009h0oooo0`00000o0?oo
o`X00000203oool700000240oooo00230?ooo`<00000WP3oool300000480oooo1`0000090?ooo`D0
00008P3oool008<0oooo0`00002N0?ooo`<00000AP3oool20820P0`0oooo0P20P80S0?ooo`00P`3o
ool3000009h0oooo0`00001i0?ooo`00P`3oool3000009h0oooo0`00001i0?ooo`00P`3oool30000
09h0oooo0`00001i0?ooo`00P`3oool3000009X0oooo0P20P8000`30`<00oooo00000002000007T0
oooo00230?ooo`<00000V03oool5000000040?ooo`0000000000000007T0oooo00230?ooo`<00000
UP3oool7000000040?ooo`0000000000000007T0oooo00230?ooo`<00000T`3oool00`20P8000000
00000007000000040?ooo`0000000000000007T0oooo00230?ooo`<00000TP3oool9000007l0oooo
00230?ooo`<00000S@3oool20820P0P000000P20P8210?ooo`00P`3oool3000008X0oooo00<0P820
0000000000001`0000260?ooo`00P`3oool3000008T0oooo2@0000280?ooo`00P`3oool3000008H0
oooo2P00002:0?ooo`00P`3oool300000880oooo0P20P807000000<0P820S03oool008<0oooo0`00
00200?ooo`T00000T@3oool008<0oooo0`00001m0?ooo`X00000T`3oool008<0oooo0`00001l0?oo
o`T00000U@3oool008<0oooo0`00001i0?ooo`T00000V03oool008<0oooo0`00001e0?ooo`80P820
1`0000020820P9X0oooo00230?ooo`<00000L`3oool9000009h0oooo00230?ooo`<00000L03oool9
00000:40oooo00230?ooo`<00000KP3oool:00000:80oooo00230?ooo`<00000JP3oool20820P0L0
00000P20P82U0?ooo`00P`3oool3000006L0oooo2@00002Z0?ooo`00P`3oool3000006H0oooo2@00
002[0?ooo`00P`3oool3000006<0oooo2@00000b0?ooo`<00000N@3oool008<0oooo0`00001Q0?oo
o`T00000=03oool3000007T0oooo00230?ooo`<00000G@3oool20820P0L0000000<0P8200?ooo`3o
ool0=@3oool3000007T0oooo00230?ooo`<00000FP3oool9000003/0oooo0`00001i0?ooo`00P`3o
ool3000005P0oooo2@00000m0?ooo`<00000N@3oool008<0oooo0`00001F0?ooo`T00000?`3oool3
000007T0oooo00230?ooo`<00000D@3oool30820P0H000000`20P8110?ooo`<00000N@3oool008<0
oooo0`00001?0?ooo`030820P0000000000000H00000AP3oool3000007T0oooo00230?ooo`<00000
C@3oool9000004P0oooo0`00001i0?ooo`00P`3oool3000004/0oooo2@00001:0?ooo`<00000N@3o
ool008<0oooo0`0000160?ooo`030<30`020P800P82000H000000P20P81=0?ooo`<0P820N@3oool0
08<0oooo0`0000140?ooo`T00000c@3oool008<0oooo0`0000120?ooo`030820P0000000000000H0
0000c`3oool008<0oooo0`0000100?ooo`P00000dP3oool008<0oooo0`00000m0?ooo`030820P000
0000000000H00000e03oool003P0oooo00<0@4100?ooo`3oool0B03oool3000003T0oooo00<0`<30
0820P00000001P0000020820P=H0oooo000h0?ooo`030820P03oool0oooo04P0oooo0`00000g0?oo
o`P00000f`3oool003L0oooo00<000000820P03oool0B@3oool3000003@0oooo00<0P82000000000
00001P0000000`20P800oooo0?ooo`3J0?ooo`00=`3oool00`000000P8200?ooo`190?ooo`<00000
<`3oool800000=l0oooo000f0?ooo`8000009P3oool00`20P800oooo0?ooo`0R0?ooo`<00000;P3o
ool20820P0030410@0000000000000<000000`20P83Q0?ooo`00=@3oool3000002H0oooo0P00000S
0?ooo`<00000;03oool8000000030820P03oool0oooo0><0oooo000e0?ooo`8000009`3oool20000
00030820P03oool0oooo0200oooo0`00000Z0?ooo`P00000j03oool003D0oooo0P00000X0?ooo`80
00008P3oool3000002L0oooo00<0P8200000000000001P00003Z0?ooo`00=03oool3000002T0oooo
0P00000Q0?ooo`<000009P3oool700000>d0oooo000c0?ooo`040<30`000000000000820P2T0oooo
00@0@410000000000000P8207`3oool300000240oooo0P20P80600000080P82000<0`<300?ooo`3o
ool0k03oool003<0oooo00<0P820000000000000:`3oool4000001h0oooo0`00000N0?ooo`030820
P0000000000000H00000l`3oool003<0oooo00<0P820000000000000:`3oool4000000030820P03o
ool0oooo01/0oooo0`00000M0?ooo`L00000mP3oool003<0oooo00<0P820000000000000;03oool4
000001d0oooo0`00000J0?ooo`P0000000<0P8200?ooo`3oool0N@3oool3000007T0oooo000>0?oo
oa40P820503oool3000000/0oooo00D0P82000000000000000000820P00=0?ooo`040410@0000000
00000820P0`0oooo1000000L0?ooo`<000005P3oool20820P0H000000P20P81n0?ooo`<00000N@3o
ool00140oooo2P00000H0?ooo`<000002`3oool00`20P800000000000003000000/0oooo1@000000
0`20P800oooo0?ooo`0:0?ooo`@000006`3oool3000001@0oooo200000220?ooo`<00000N@3oool0
01<0oooo1`00000I0?ooo`<000002`3oool00`20P800000000000004000000X0oooo1P00000<0?oo
o`D000006P3oool300000140oooo200000000`20P800oooo0?ooo`220?ooo`<00000N@3oool001@0
oooo1@00000I0?ooo`@000002`3oool00`20P800000000000005000000P0oooo2000000<0?ooo`@0
00006P3oool300000100oooo1`0000270?ooo`<00000N@3oool001@0oooo1@00000I0?ooo`@00000
2`3oool01@20P8000000000000000000oooo00@000001`3oool5000000040?ooo`20P80000000000
00/0oooo100000000`20P800oooo0?ooo`0G0?ooo`<000003@3oool8000008T0oooo0`00001i0?oo
o`00503oool00`20P800000000000002000000030820P03oool0oooo01H0oooo1000000;0?ooo`03
0<30`020P800P82000@0oooo00<0P82000000020P8001@3oool00`20P80000000000000300000080
oooo00<0P82000000020P8002P3oool00`20P800000000000002000001T0oooo0`0000080?ooo`<0
P8201@0000000`10@400P8200820P02;0?ooo`<00000N@3oool001D0oooo1@00000H0?ooo`@00000
4`3oool2000000D0oooo1@0000050?ooo`030000003oool0oooo00P0oooo00<0P820000000000000
0`00000H0?ooo`<000001`3oool700000900oooo0`00001i0?ooo`005@3oool5000001P0oooo1@00
000C0?ooo`800000103oool5000000D0oooo0P00000:0?ooo`D00000603oool3000000@0oooo2000
002B0?ooo`<00000N@3oool001D0oooo1@00000H0?ooo`D000004`3oool00`20P800000000000003
0?ooo`D000004@3oool6000001L0oooo0`0000020?ooo`P00000U03oool3000007T0oooo000F0?oo
o`D000005`3oool5000001@0oooo0P0000000`20P800oooo00000004000000030820P03oool0oooo
0100oooo1@0000000`20P800oooo0?ooo`0D0?ooo`P000000P20P8000`30`<00oooo0?ooo`2D0?oo
o`<0P820N@3oool001H0oooo1@00000G0?ooo`D000005@3oool2000000030?ooo`000000000000<0
00004`3oool6000001H0oooo1P00003o0?oooaP0oooo000F0?ooo`H000005P3oool5000001H0oooo
00<000000820P00000001000000D0?ooo`H000005@3oool400000?l0oooo6P3oool001L0oooo1@00
000F0?ooo`H000005@3oool7000001@0oooo1P00000E0?ooo`<00000o`3ooolK0?ooo`005`3oool5
000001H0oooo00<0P8200000000000000`00000F0?ooo`030410@000000000000080000000<0P820
0?ooo`3oool04P3oool00`20P800000000000003000001D0oooo0`00003o0?oooa/0oooo000H0?oo
o`D000005P3oool5000001H0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0C0?oo
o`D0000000<0P8200?ooo`3oool04P3oool300000?l0oooo6`3oool001P0oooo1@00000F0?ooo`D0
000000<0P8200?ooo`3oool04`3oool5000000030820P03oool0oooo01<0oooo1@0000000`20P800
oooo0?ooo`0B0?ooo`<00000o`3ooolK0?ooo`00603oool5000001H0oooo1@0000000`20P800oooo
0?ooo`0C0?ooo`D000005P3oool5000000030820P03oool0oooo0180oooo0`00003o0?oooa/0oooo
000H0?ooo`D0000000<0P8200?ooo`3oool04`3oool5000000030820P03oool0oooo01<0oooo1@00
000F0?ooo`030820P000000000000080000000<0P8200?ooo`3oool04P3oool300000?l0oooo6`3o
ool001P0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0C0?ooo`030820P0000000
00000080000000<0@4100?ooo`3oool04P3oool6000000030<30`03oool0oooo01<0oooo00<0P820
0000000000000P0000000`10@400oooo0?ooo`0B0?ooo`<00000o`3ooolK0?ooo`00603oool00`20
P800000000000002000000030820P03oool0oooo01<0oooo00<0P8200000000000000`00000D0?oo
o`D0000000<0oooo0000003oool0503oool00`20P800000000000003000001@0oooo0`00003o0?oo
oa/0oooo000I0?ooo`D000005@3oool00`20P800000000000003000001@0oooo1@0000000`3oool0
00000?ooo`0E0?ooo`D00000503oool300000?l0oooo6`3oool001T0oooo1@00000F0?ooo`H00000
4P3oool6000000030?ooo`20P800000001D0oooo1@00000D0?ooo`<00000o`3ooolK0?ooo`006@3o
ool5000000030820P03oool0oooo01<0oooo00<0P8200000000000000`00000B0?ooo`D000000P3o
ool01030`<00000000000020P80C0?ooo`D00000503oool300000?l0oooo6`3oool001X0oooo1@00
000F0?ooo`H00000403oool6000000@0oooo0P0000000`20P800oooo0?ooo`03000000d0oooo1@00
000D0?ooo`<00000o`3ooolK0?ooo`006P3oool5000001L0oooo1@00000?0?ooo`030820P0000000
000000@00000103oool9000000`0oooo1@00000D0?ooo`<00000o`3ooolK0?ooo`006P3oool50000
01L0oooo1P00000>0?ooo`H000001P3oool8000000d0oooo1000000D0?ooo`<00000o`3ooolK0?oo
o`006`3oool5000001L0oooo1@0000090?ooo`030820P0000000000000P000001`3oool7000000d0
oooo1000000D0?ooo`<00000o`3ooolK0?ooo`006`3oool5000001L0oooo00<0P820000000000000
0P0000000`30`<00oooo0?ooo`060?ooo`030<30`020P800P82000L00000203oool00`30`<000000
00000003000000030820P03oool0oooo00/0oooo1000000D0?ooo`<00000WP3oool3000007T0oooo
000K0?ooo`H000005`3oool4000000030820P03oool0oooo00d0oooo0P0000000`20P800oooo0?oo
o`090?ooo`80000000<0P8200?ooo`3oool0303oool4000001@0oooo0`00002N0?ooo`<00000N@3o
ool001`0oooo1@00000G0?ooo`030820P0000000000000800000;P3oool3000000030820P03oool0
oooo0180oooo0`00002N0?ooo`<00000N@3oool001`0oooo1@00000H0?ooo`@00000;P3oool30000
00030820P03oool0oooo00X0oooo00<0P8200000000000003`00002G0?ooo`<00000N@3oool001`0
oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`0F0?ooo`@0000000<0P8200?ooo`3o
ool0:P3oool3000000030820P03oool0oooo00H0oooo00<0`<300820P00000005@0000030820P980
oooo0`00001i0?ooo`003`3oool00`20P800oooo0?ooo`0;0?ooo`@0000000<0P8200?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`@00000;03oool3000000T0oooo6`00002B0?ooo`<00000
N@3oool000l0oooo00<0P8200?ooo`3oool02`3oool4000000030820P03oool0oooo00/0oooo00<0
P8200?ooo`3oool02P3oool4000002/0oooo0`0000090?ooo`030820P0000000000001L00000T`3o
ool3000007T0oooo000?0?ooo`030820P03oool0oooo00/0oooo1@00000=0?ooo`030820P03oool0
oooo00X0oooo00@0P8200000000000000000:`3oool3000000T0oooo00<0P8200000000000005`00
002C0?ooo`<00000N@3oool000l0oooo00<0P8200000003oool02`3oool00`20P800000000000002
000000d0oooo00<0P8200?ooo`3oool02`3oool4000002X0oooo0P00000:0?ooo`030820P0000000
000001L00000T`3oool3000007T0oooo000@0?ooo`0300000020P800oooo00X0oooo00<0P8200000
000000000P0000000`20P800oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00@0P8200000
00000000@410:03oool3000000/0oooo6000002D0?ooo`<0P820N@3oool00100oooo0P00000<0?oo
o`D00000303oool00`000000oooo0?ooo`0>0?ooo`800000:03oool2000000`0oooo5`00003o0?oo
oa80oooo000@0?ooo`<000002`3oool5000000`0oooo0P00000@0?ooo`8000009`3oool2000000d0
oooo5P00003o0?oooa80oooo000A0?ooo`<0000000<0P8200?ooo`3oool01`3oool5000000/0oooo
0`00000@0?ooo`030820P0000000000002D0oooo00<0P8200000000000003@3ooolF00000?l0oooo
4P3oool00140oooo100000030820P0030<30`03oool0oooo00<0oooo00<0P8200000000000000`00
00080?ooo`80P8200`00000A0?ooo`040820P000000000000<30`2<0oooo00<0P8200000003oool0
3@3oool00`20P80000000000000B00000?l0oooo4`3oool00180oooo8000000B0?ooo`8000008`3o
ool00`000000oooo0?ooo`0>0?oooa@00000o`3ooolC0?ooo`004P3ooolP000001<0oooo00<0P820
0000003oool08@3oool00`000000oooo0?ooo`0>0?oooa<0000000<0P8200?ooo`3oool0o`3ooolA
0?ooo`00AP3oool300000200oooo00<0P8200?ooo`3oool03`3ooolB000000030820P03oool0oooo
0?l0oooo4@3oool004L0oooo00<0P82000000020P8007P3oool00`000000`<300?ooo`0@0?oooa80
000000<0`<300?ooo`3oool0o`3ooolA0?ooo`00N`3oool00`20P80000000000000?00000?l0oooo
503oool007/0oooo00<0P8200000000000003P00003o0?oooaD0oooo001k0?ooo`030820P0000000
000000h00000o`3ooolE0?ooo`00O03oool@00000?l0oooo5@3oool007`0oooo3`0000000`20P800
oooo0?ooo`3o0?oooa<0oooo001m0?ooo`h00000o`3ooolF0?ooo`00O@3oool>00000?l0oooo5P3o
ool007h0oooo3@00003o0?oooaH0oooo001n0?ooo``00000VP3oool30820P7T0oooo001o0?ooo`/0
0000VP3oool3000007T0oooo001o0?ooo`X0000000<0P8200?ooo`3oool0V03oool3000007T0oooo
001o0?ooo`X0000000<0P8200?ooo`3oool0V03oool3000007T0oooo00200?ooo`T00000V`3oool3
000007T0oooo00200?ooo`T00000V`3oool3000007T0oooo00200?ooo`030820P0000000000000D0
0000W03oool3000007T0oooo00200?ooo`030820P0000000000000D00000W03oool3000007T0oooo
00200?ooo`030820P0000000000000D00000W03oool3000007T0oooo00210?ooo`H00000W@3oool3
000007T0oooo00210?ooo`H00000W@3oool3000007T0oooo00220?ooo`@00000o`3ooolK0?ooo`00
PP3oool400000?l0oooo6`3oool00880oooo1000003o0?oooa/0oooo00230?ooo`800000o`3ooolL
0?ooo`00P`3oool00`000000P8200?ooo`3o0?oooa/0oooo00240?ooo`030820P03oool0oooo0?l0
oooo6P3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0
ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0
ooooX@3oool00?l0oooo9@3oool30820P7T0oooo003o0?ooobD0oooo0`00001i0?ooo`00o`3ooolU
0?ooo`<00000N@3oool00?l0oooo9@3oool3000007T0oooo003o0?ooobD0oooo0`00001i0?ooo`00
o`3ooolU0?ooo`<00000N@3oool00?l0oooo9@3oool3000007T0oooo003o0?ooobD0oooo0`00001i
0?ooo`00o`3ooolU0?ooo`<00000N@3oool00?l0oooo9@3oool3000007T0oooo003o0?ooobD0oooo
0`00001i0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00
o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00
o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00
Q@3oool400000?l0oooo603oool008D0oooo1000003o0?oooaP0oooo00250?ooo`@00000o`3ooolH
0?ooo`00Q@3oool4000009/0oooo0`00001i0?ooo`00Q@3oool4000009/0oooo0`00001i0?ooo`00
Q@3oool4000009/0oooo0`00001i0?ooo`00Q@3oool4000009/0oooo0`00001i0?ooo`00Q@3oool4
000009/0oooo0`00001i0?ooo`00Q@3oool4000009/0oooo0`00001i0?ooo`00Q@3oool4000009/0
oooo0`00001i0?ooo`00Q@3oool40820P9/0oooo0`00001i0?ooo`00o`3ooolU0?ooo`<00000N@3o
ool00?l0oooo9@3oool3000007T0oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo
003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo
003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo
003o0?oooj40oooo003o0?oooj40oooo00250?ooo`@00000o`3ooolH0?ooo`00Q@3oool400000?l0
oooo603oool008D0oooo1000002K0?ooo`<00000N@3oool008D0oooo1000002K0?ooo`<00000N@3o
ool008D0oooo1000002K0?ooo`<00000N@3oool008D0oooo1000002K0?ooo`<00000N@3oool008D0
oooo1000002K0?ooo`<00000N@3oool008D0oooo1000002K0?ooo`<00000N@3oool008D0oooo1000
002K0?ooo`<00000N@3oool008D0oooo1020P82K0?ooo`<00000N@3oool00?l0oooo9@3oool30000
07T0oooo003o0?ooobD0oooo0`00001i0?ooo`00o`3ooolU0?ooo`<00000N@3oool00?l0ooooX@3o
ool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3o
ool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3o
ool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool008D0oooo1000003o0?oooaP0oooo
00250?ooo`@00000o`3ooolH0?ooo`00Q@3oool4000009/0oooo0`00001i0?ooo`00Q@3oool40000
09/0oooo0`00001i0?ooo`00Q@3oool4000009/0oooo0`00001i0?ooo`00Q@3oool4000009/0oooo
0`00001i0?ooo`00Q@3oool4000009/0oooo0`00001i0?ooo`00Q@3oool4000009/0oooo0`00001i
0?ooo`00Q@3oool4000009/0oooo0`00001i0?ooo`00Q@3oool40820P9/0oooo0`00001i0?ooo`00
o`3ooolU0?ooo`<00000N@3oool00?l0oooo9@3oool3000007T0oooo003o0?ooobD0oooo0`00001i
0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00o`3oool80?oooal0[7Yj00<0^Jj^0?ooo`3oool0
M`3oool00>L0oooo?`2/NWX00`1cG5`0oooo0?ooo`1g0?ooo`00Z03ooolO0=Jm_El0[7Yj0P1cG5`2
0;V^[WH0oooo00280?oooih0[7Yj1@1cG5ae0?ooo`00R03ooonN0:ajNPD0LeaL00<0^Jj^0?ooo`3o
ool0LP3oool008P0ooooWP2/NWX607=LG7@0oooo00280?oooih0[7Yj1`1cG5ac0?ooo`00R03ooonN
0:ajNPP0LeaL00<0^Jj^0?ooo`3oool0K`3oool008P0ooooWP2/NWX:07=LG700oooo00280?oooih0
[7Yj2`1cG5a_0?ooo`00R03ooonN0:ajNP`0LeaLKP3oool008P0ooooWP2/NWX=07=LG0030;V^[P3o
ool0oooo06X0oooo00280?oooih0[7Yj3P1cG5`00`2i[Zh0oooo0?ooo`1Y0?ooo`00R03ooonN0:aj
NPl0LeaLJ`3oool008P0ooooWP2/NWX@07=LG6X0oooo00280?oooih0[7Yj4P1cG5aX0?ooo`00R03o
oonN0:ajNQ80LeaL00<0UXF50?ooo`3oool0I@3oool008P0ooooWP2/NWXD07=LG6H0oooo00280?oo
oih0[7Yj5@1cG5aU0?ooo`00R03ooonN0:ajNQH0LeaLI03oool008P0ooooWP2/NWXG07=LG0030;V^
[P3oool0oooo0600oooo00280?oooih0[7Yj6@1cG5aQ0?ooo`00R03ooonN0:ajNQX0LeaLH03oool0
08P0ooooWP2/NWXK07=LG5l0oooo00280?oooih0[7Yj6`1cG5`00`2i[Zh0oooo0?ooo`1L0?ooo`00
R03ooonN0:ajNQ`0LeaL00<0^Jj^0?ooo`3oool0F`3oool008P0ooooWP2/NWXO07=LG5/0oooo0028
0?oooih0[7Yj801cG5aJ0?ooo`00R03ooonN0:ajNR00LeaL00<0^Jj^0?ooo`3oool0E`3oool008P0
ooooWP2/NWXQ07=LG0030;V^[P3oool0oooo05H0oooo00280?oooih0[7Yj8`1cG5aG0?ooo`00R03o
oonN0:ajNR@0LeaLEP3oool008P0ooooWP2/NWXU07=LG5D0oooo00280?oooih0[7Yj9P1cG5`00`2i
[Zh0oooo0?ooo`1A0?ooo`00R03ooonN0:ajNRP0LeaLDP3oool008P0ooooWP2/NWXY07=LG540oooo
00280?oooih0[7Yj:@1cG5`00`2i[Zh0oooo0?ooo`1>0?ooo`00R03ooonN0:ajNRX0LeaLD03oool0
08P0ooooWP2/NWX[07=LG080^Jj^C@3oool008P0ooooWP2/NWX]07=LG0030;V^[P3oool0oooo04X0
oooo00280?oooih0[7Yj;P1cG5a<0?ooo`00R03ooonN0:ajNRl0LeaLB`3oool008P0ooooWP2/NWX`
07=LG0030;V^[P3oool0oooo04L0oooo00280?oooih0[7Yj<P1cG5a80?ooo`00R03ooonN0:ajNS<0
LeaLA`3oool008P0ooooWP2/NWXd07=LG4H0oooo00280?oooih0[7Yj=@1cG5a50?ooo`00R03ooonN
0:ajNSH0LeaL00<0g=OG0?ooo`3oool0@@3oool008P0ooooWP2/NWXg07=LG4<0oooo00280?oooih0
[7Yj>01cG5a20?ooo`00R03ooonN0:ajNSX0LeaL@03oool008P0ooooWP2/NWXk07=LG0030=cGe`3o
ool0oooo03`0oooo00280?oooih0[7Yj?01cG5`n0?ooo`00R03ooonN0:ajNSd0LeaL?@3oool008P0
ooooWP2/NWXn07=LG3`0oooo00280?oooih0[7Yj?`1cG5`k0?ooo`00R03ooonN0:ajNT00LeaL00<0
^Jj^0?ooo`3oool0=`3oool008P0ooooWP2/NWY207=LG3P0oooo00280?oooih0[7Yj@`1cG5`g0?oo
o`00R03ooonN0:ajNT@0LeaL=P3oool008P0ooooWP2/NWY407=LG00309J5Q@3oool0oooo03<0oooo
00280?oooih0[7YjAP1cG5`d0?ooo`00R03ooonN0:ajNTP0LeaL<P3oool008P0ooooWP2/NWY807=L
G0030;V^[P3oool0oooo02l0oooo00280?oooih0[7YjB@1cG5`a0?ooo`00R03ooonN0:ajNTX0LeaL
00<0^Jj^0?ooo`3oool0;@3oool008P0ooooWP2/NWY<07=LG2h0oooo00280?oooih0[7YjC@1cG5`]
0?ooo`00R03ooonN0:ajNTh0LeaL;03oool008P0ooooWP2/NWY?07=LG0030;V^[P3oool0oooo02P0
oooo00280?oooih0[7YjD@1cG5`Y0?ooo`00R03ooonN0:ajNU40LeaL00<0^Jj^0?ooo`3oool09P3o
ool008P0ooooWP2/NWYB07=LG2P0oooo00280?oooih0[7YjD`1cG5`20;V^[RD0oooo00280?oooih0
[7YjEP1cG5`T0?ooo`00R03ooonN0:ajNUH0LeaL00<0^Jj^0?ooo`3oool08@3oool008P0ooooWP2/
NWYG07=LG2<0oooo00280?oooih0[7YjF01cG5`R0?ooo`00R03ooonN0:ajNUT0LeaL00<0^Jj^0?oo
o`3oool07P3oool008P0ooooWP2/NWYK07=LG1l0oooo00280?oooih0[7YjG01cG5`N0?ooo`00R03o
oonN0:ajNUd0LeaL7@3oool008P0ooooWP2/NWYN07=LG0030;V^[P3oool0oooo01T0oooo00280?oo
oih0[7YjG`1cG5`00`2i[Zh0oooo0?ooo`0H0?ooo`00R03ooonN0:ajNV00LeaL6P3oool008P0oooo
WP2/NWYQ07=LG1T0oooo00280?oooih0[7YjH`1cG5`G0?ooo`00R03ooonN0:ajNV<0LeaL00<0UXF5
0?ooo`3oool0503oool008P0ooooWP2/NWYU07=LG1D0oooo00280?oooih0[7YjIP1cG5`D0?ooo`00
R03ooonN0:ajNVL0LeaL4`3oool008P0ooooWP2/NWYX07=LG0030;V^[P3oool0oooo00l0oooo0028
0?oooih0[7YjJP1cG5`@0?ooo`00R03ooonN0:ajNV/0LeaL3`3oool008P0ooooWP2/NWY/07=LG0h0
oooo00280?oooih0[7YjK01cG5`>0?ooo`00R03ooonN0:ajNV`0LeaL3P3oool008P0ooooWP2/NWY/
07=LG0h0oooo00280?oooih0[7YjK01cG5`>0?ooo`00R03ooonN0:ajNV`0LeaL3P3oool008P0oooo
WP2/NWY/07=LG0h0oooo00280?oooih0[7YjK01cG5`>0?ooo`00R03ooonN0:ajNV`0LeaL3P3oool0
08P0ooooWP2/NWY/07=LG0h0oooo00280?oooih0[7YjK01cG5`>0?ooo`00R03ooonN0:ajNV`0LeaL
3P3oool008P0ooooWP2/NWY/07=LG0h0oooo00280?oooih0[7YjK01cG5`>0?ooo`00R03ooonN0:aj
NV`0LeaL3P3oool008P0ooooWP2/NWY/07=LG0h0oooo00280?oooih0[7YjK01cG5`>0?ooo`00R03o
oonN0:ajNV`0LeaL3P3oool008P0ooooWP2/NWY/07=LG0h0oooo00280?oooih0[7YjK01cG5`>0?oo
o`00R03ooonN0:ajNV`0LeaL3P3oool008P0ooooWP2/NWY/07=LG0h0oooo00280?oooih0[7YjK01c
G5`>0?ooo`00R03ooonN0:ajNV`0LeaL3P3oool008P0ooooK`2/NWX00`1F?Cd0[7Yj0:ajNP0/0:aj
NV`0LeaL3P3oool008P0ooooK`2/NWX00`000000[7Yj0:ajNP0/0:ajNV`0LeaL3P3oool008P0oooo
K`2/NWX2000002d0[7YjK01cG5`>0?ooo`00R03ooom_0:ajNP800000;@2/NWY/07=LG0h0oooo0028
0?ooofl0[7Yj0P0000000`21G5`0[7Yj0:ajNP0Z0:ajNV`0LeaL3P3oool008P0ooooK`2/NWX20000
000305Hm?@2/NWX0[7Yj02X0[7YjK01cG5`>0?ooo`00R03ooom_0:ajNP<00000;02/NWY/07=LG0h0
oooo00280?ooofl0[7Yj0`00000/0:ajNV`0LeaL3P3oool008P0ooooK`2/NWX3000002`0[7YjK01c
G5`>0?ooo`00R03ooom_0:ajNP@00000:`2/NWY/07=LG0h0oooo00280?ooofl0[7Yj1@00000Z0:aj
NV`0LeaL3P3oool008P0ooooK`2/NWX5000002X0[7YjK01cG5`>0?ooo`00R03ooom_0:ajNPD00000
:P2/NWY/07=LG0h0oooo00280?ooofl0[7Yj1P00000Y0:ajNV`0LeaL3P3oool008P0ooooK`2/NWX6
000002T0[7YjK01cG5`>0?ooo`00R03ooom_0:ajNPL00000:02/NWY/07=LG0h0oooo00280?ooofl0
[7Yj1`00000X0:ajNV`0LeaL3P3oool008P0ooooK`2/NWX70000000305Hm?@2/NWX0[7Yj02D0[7Yj
K01cG5`>0?ooo`00R03ooom_0:ajNP<0000000D0oooo000000000000000005Hm?@0W0:ajNV`0LeaL
3P3oool008P0ooooK`2/NWX3000000030?ooo`0000000000008000009`2/NWY/07=LG0h0oooo0028
0?ooofl0[7Yj0`0000000`3oool0000000000002000002L0[7YjK01cG5`>0?ooo`00R03ooom_0:aj
NP<000000P3oool4000002H0[7YjK01cG5`>0?ooo`00R03ooom_0:ajNP<000000P3oool01020P800
000000000000000V0:ajNV`0LeaL3P3oool008P0ooooK`2/NWX3000000<0oooo1000000U0:ajNV`0
LeaL3P3oool008P0ooooK`2/NWX3000000<0oooo1000000U0:ajNV`0LeaL3P3oool008P0ooooK`2/
NWX3000000@0oooo1000000T0:ajNV`0LeaL3P3oool008P0ooooK`2/NWX3000000@0oooo00@0@410
0000000000000000902/NWY/07=LG0h0oooo00280?ooofl0[7Yj0`0000040?ooo`050820P0000000
00000000001F?Cd08`2/NWY/07=LG0h0oooo00280?ooofl0[7Yj0`0000040?ooo`050820P0000000
00000000001F?Cd08`2/NWY/07=LG0h0oooo00280?ooofl0[7Yj0`0000050?ooo`<0000000<0ESdm
0:ajNP2/NWX08@2/NWY/07=LG0h0oooo00280?ooofl0[7Yj0`0000050?ooo`@000008`2/NWY/07=L
G0h0oooo00280?ooofl0[7Yj0`0000060?ooo`<0000000<0ESdm0:ajNP2/NWX0802/NWY/07=LG0h0
oooo00280?ooofl0[7Yj0`0000060?ooo`@000008P2/NWY/07=LG0h0oooo00280?ooofl0[7Yj0`00
00070?ooo`<000008P2/NWY/07=LG0h0oooo00280?ooofl0[7Yj0`0000070?ooo`@000008@2/NWY/
07=LG0h0oooo00280?ooofl0[7Yj0`0000070?ooo`050820P000000000000000001F?Cd0802/NWY/
07=LG0h0oooo00280?ooofl0[7Yj0`0000080?ooo`@00000802/NWY/07=LG0h0oooo00280?ooofl0
[7Yj0`0000080?ooo`040820P0000000000000000200[7YjK01cG5`>0?ooo`00R03ooom_0:ajNP<0
0000203oool00`20P800000000000002000001l0[7YjK01cG5`>0?ooo`00R03ooom_0:ajNP<00000
203oool00`20P800000000000002000001l0[7YjK01cG5`>0?ooo`00R03ooom_0:ajNP<000002@3o
ool400000003085LG02/NWX0[7Yj01`0[7YjK01cG5`>0?ooo`00R03ooom_0:ajNP<000002P3oool3
0000000305Hm?@2/NWX0[7Yj01`0[7YjK01cG5`>0?ooo`00R03ooom_0:ajNP<000002P3oool40000
01h0[7YjK01cG5`>0?ooo`00R03ooom_0:ajNP<000002P3oool4000001h0[7YjK01cG5`>0?ooo`00
R03ooom_0:ajNP<000002`3oool30000000305Hm?@2/NWX0[7Yj01/0[7YjK01cG5`>0?ooo`00R03o
oom_0:ajNP<00000303oool3000001d0[7YjK01cG5`>0?ooo`00R03ooom_0:ajNP<00000303oool4
000001`0[7YjK01cG5`>0?ooo`00R03ooom_0:ajNP<00000303oool4000001`0[7YjK01cG5`>0?oo
o`00R03ooom_0:ajNP<000003@3oool30000000305Hm?@2/NWX0[7Yj01T0[7YjK01cG5`>0?ooo`00
R03ooom_0:ajNP<000003@3oool01020P800000000000000000K0:ajNV`0LeaL3P3oool008P0oooo
302/NWYV000000d0oooo00D0P820000000000000000005Hm?@0J0:ajNV`0LeaL3P3oool008P0oooo
302/NWYV000000d0oooo00D0P820000000000000000005Hm?@0J0:ajNV`0LeaL3P3oool008P0oooo
302/NWYV000000h0oooo0`0000000`1F?Cd0[7Yj0:ajNP0H0:ajNV`0LeaL3P3oool008P0oooo302/
NWX3000006<0P8203P3oool4000001X0[7YjK01cG5`>0?ooo`00R03oool<0:ajNP<00000LP3oool3
000001X0[7YjK01cG5`>0?ooo`00R03oool<0:ajNP<00000LP3oool4000001T0[7YjK01cG5`>0?oo
o`00R03oool<0:ajNP<00000L`3oool3000001T0[7YjK01cG5`>0?ooo`00R03oool<0:ajNP<00000
L`3oool4000001P0[7YjK01cG5`>0?ooo`00R03oool<0:ajNP<00000M03oool3000001P0[7YjK01c
G5`>0?ooo`00R03oool<0:ajNP<00000M03oool4000001L0[7YjK01cG5`>0?ooo`00R03oool<0:aj
NP<00000M03oool01020P800000000000000000G0:ajNV`0LeaL3P3oool008P0oooo302/NWX30000
07@0oooo00<0P8200000000000000P00000F0:ajNV`0LeaL3P3oool008P0oooo302/NWX3000007@0
oooo00<0`<300000000000000P00000F0:ajNV`0LeaL3P3oool008P0oooo302/NWX3000007D0oooo
100000000`1F?Cd0[7Yj0:ajNP0C0:ajNV`0LeaL3P3oool008P0oooo302/NWX3000007H0oooo0`00
00000`1F?Cd0[7Yj0:ajNP0C0:ajNV`0LeaL3P3oool008P0oooo302/NWX3000007H0oooo0`000000
0`1F?Cd0[7Yj0:ajNP0C0:ajNV`0LeaL3P3oool008P0oooo302/NWX3000007H0oooo00@0P8200000
0000000000005@2/NWY/07=LG0h0oooo00280?ooo``0[7Yj0`00001g0?ooo`@00000502/NWY/07=L
G0h0oooo00280?ooo``0[7Yj0`00001h0?ooo`<00000502/NWY/07=LG0h0oooo00280?ooo``0[7Yj
0`00001h0?ooo`<00000502/NWY/07=LG0h0oooo00280?ooo``0[7Yj0`00001h0?ooo`@000004`2/
NWY/07=LG0h0oooo00280?ooo``0[7Yj0`00001i0?ooo`<0000000<0ESdm0:ajNP2/NWX0402/NWY/
07=LG0030;V^[P3oool0oooo00/0oooo00280?ooo``0[7Yj0`00001i0?ooo`@000004P2/NWY/07=L
G0030;V^[P3oool0oooo00/0oooo00280?ooo``0[7Yj0`00001i0?ooo`040820P000000000000000
0180[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00R03oool<0:ajNP<00000N@3oool01@20P800
0000000000000000ESdm0140[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00R03oool<0:ajNP<0
0000NP3oool30000000305Hm?@2/NWX0[7Yj00l0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00
R03oool<0:ajNP<00000NP3oool400000140[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00R03o
ool<0:ajNP<00000N`3oool300000140[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00R03oool<
0:ajNP<00000N`3oool400000100[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00R03oool<0:aj
NP<00000O03oool300000100[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00R03oool<0:ajNP<0
0000O03oool4000000l0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00R03oool<0:ajNP<00000
O@3oool3000000l0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00R03oool<0:ajNP<00000O@3o
ool4000000h0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00R03oool<0:ajNP<00000O@3oool0
1020P800000000000000000>0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008P0oooo302/NWX3
000007d0oooo00D0P820000000000000000005Hm?@0=0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3o
ool008P0oooo302/NWX3000007h0oooo1000000=0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool0
08P0oooo302/NWX3000007h0oooo100000000`1F?Cd0[7Yj0:ajNP0:0:ajNV`0LeaL00<0^Jj^0?oo
o`3oool02`3oool008P0oooo302/NWX3000007h0oooo100000000`1F?Cd0[7Yj0:ajNP0:0:ajNV`0
LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo3@2/NWX3000007l0oooo0`0000000`0[7al0[7Yj
0:ajNP0:0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo3@2/NWX300000800oooo0`00
000<0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo3@2/NWX300000800oooo0`00000<
0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo3@2/NWX300000800oooo1000000;0:aj
NV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo3@2/NWX300000840oooo0`00000;0:ajNV`0
LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo3@2/NWX300000840oooo00@0P820000000000000
00002P2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?ooo`d0[7Yj0`0000220?ooo`<00000
2P2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?ooo`d0[7Yj0`0000210?ooo`@000002P2/
NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?ooo`d0[7Yj0`0000210?ooo`<000002`2/NWY/
07=LG0030;V^[P3oool0oooo00/0oooo00270?ooo`d0[7Yj0`0000200?ooo`<0000000<0ESdm0:aj
NP2/NWX02@2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?ooo`d0[7Yj0`0000200?ooo`<0
0000302/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?ooo`d0[7Yj0`00001o0?ooo`@00000
302/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?ooo`d0[7Yj0`00001o0?ooo`<0000000<0
ESdm0:ajNP2/NWX02P2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?ooo`d0[7Yj0`00001o
0?ooo`<0000000<0ESdm0:ajNP2/NWX02P2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?oo
o`d0[7Yj0`00001n0?ooo`@0000000<0PEaL0:ajNP2/NWX02P2/NWY/07=LG0030;V^[P3oool0oooo
00/0oooo00270?ooo`d0[7Yj0`00001m0?ooo`030820P00000000000008000003@2/NWY/07=LG003
0;V^[P3oool0oooo00/0oooo00270?ooo`d0[7Yj0`00001m0?ooo`040820P00000000000000000h0
[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNP<00000O@3oool01020P8000000
00000000000>0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo3@2/NWX3000007d0oooo
0`0000000`1F?Cd0[7Yj0:ajNP0<0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo3@2/
NWX3000007`0oooo1000000?0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo3@2/NWX3
000007`0oooo0`00000@0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo3@2/NWX30000
07`0oooo0`00000@0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo3@2/NWX3000007/0
oooo1000000@0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo3@2/NWX3000007X0oooo
00@0P82000000000000000004@2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?ooo`d0[7Yj
0`00001j0?ooo`<0000000<0ESdm0:ajNP2/NWX03`2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo
00270?ooo`d0[7Yj0`00001j0?ooo`<0000000<0ESdm0:ajNP2/NWX03`2/NWY/07=LG0030;V^[P3o
ool0oooo00/0oooo00270?ooo`d0[7Yj0`00001i0?ooo`050820P000000000000000001F?Cd04@2/
NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?ooo`d0[7Yj0`00001i0?ooo`040820P0000000
000000000180[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNP<00000N@3oool4
00000180[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNP<00000N@3oool30000
01<0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNP<00000N03oool4000001<0
[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNP<00000N03oool3000001@0[7Yj
K01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNP<00000M`3oool4000001@0[7YjK01c
G5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNP<00000M`3oool3000001D0[7YjK01cG5`0
0`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNP<00000MP3oool4000001D0[7YjK01cG5`00`2i
[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNP<00000MP3oool30000000305Hm?@2/NWX0[7Yj01<0
[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNP<00000M@3oool01@20P8000000
000000000000ESdm01D0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNP<00000
M@3oool4000001H0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNP<00000M@3o
ool4000001H0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNP<00000M03oool0
0`20P800000000000002000001H0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:aj
NP<00000M03oool01010@400000000000000000G0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool0
08L0oooo3@2/NWX3000007@0oooo0`00000H0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0
oooo3@2/NWX3000007@0oooo0`00000H0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo
3@2/NWX3000007<0oooo1000000H0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo3@2/
NWX3000007<0oooo0`00000I0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo3@2/NWX3
00000780oooo0`0000000`1F?Cd0[7Yj0:ajNP0G0:ajNR80LeaL2000000203X^;PX0LeaL0`0j;Rh:
000000<0>Rh^9P1cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNP<00000LP3oool30000
01X0[7Yj8`1cG5`60000000303X^;P1cG5`0LeaL00l0LeaL1`00000Z07=LG0030;V^[P3oool0oooo
00/0oooo00270?ooo`d0[7Yj0`00001a0?ooo`@000006P2/NWXT07=LG00303X^;P00000000000080
00004P1cG5`00`0j;Rh0000000000003000002/0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo
3@2/NWX300000740oooo0`0000000`1F?Cd0[7Yj0:ajNP0H0:ajNRD0LeaL1000000B07=LG00303X^
;P000000000000<00000:`1cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNVH000003@3o
ool01@30`<000000000000000000ESdm01X0[7Yj9P1cG5`0100j;Rh000000000001GADDA07=LG003
05M5A@000000000000<00000:`1cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNVH00000
3@3oool01020P800000000000000000K0:ajNRL0LeaL0P0000000`0j;Rh0LeaL07=LG00@07=LG0D0
0000:`1cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool=0:ajNVH000003@3oool4000001/0[7Yj
:01cG5`200000180LeaL1@00000[07=LG0030;V^[P3oool0oooo00/0oooo00270?ooog00[7Yj0`00
000=0?ooo`<00000702/NWXY07=LG0030000001cG5`0LeaL0100LeaL1@00000[07=LG0030;V^[P3o
ool0oooo00/0oooo00270?ooog00[7Yj0`00000=0?ooo`<00000702/NWXY07=LG00303X^;P000000
LeaL0100LeaL1@00000[07=LG0030;V^[P3oool0oooo00/0oooo00270?ooog00[7Yj0`00000<0?oo
o`<0000000<0ESdm0:ajNP2/NWX06P2/NWXZ07=LG0800000401cG5`5000002/0LeaL00<0^Jj^0?oo
o`3oool02`3oool008L0ooooL02/NWX3000000/0oooo1000000M0:ajNR/0LeaL0P00000?07=LG0D0
0000:`1cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooom`0:ajNP<000002`3oool3000001h0[7Yj
;01cG5`00`000000>Rh^07=LG00=07=LG0D00000:`1cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3o
oom`0:ajNP<000002`3oool3000001h0[7Yj;@1cG5`00`000000LeaL07=LG00<07=LG0H00000:P1c
G5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooom`0:ajNP<000002P3oool30000000302/O7`2/NWX0
[7Yj01`0[7Yj;@1cG5`00`0M5aL0>Rh^03X^;P0=03X^;PD00000:P1cG5`00`2i[Zh0oooo0?ooo`0;
0?ooo`00Q`3ooom`0:ajNP<000002@3oool40000000305Hm?@2/NWX0[7Yj01`0[7Yj;P1cG5`D0000
02X0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0ooooL02/NWX3000000T0oooo1000000O0:ajNRl0
LeaL0P00000<07=LG0D00000:P1cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooom`0:ajNP<00000
2@3oool4000001l0[7Yj;`1cG5`2000000`0LeaL1@00000Z07=LG0030;V^[P3oool0oooo00/0oooo
00270?ooog00[7Yj0`0000080?ooo`050820P000000000000000001F?Cd07`2/NWX`07=LG00303X^
;P000000EdE500X0LeaL1@00000Z07=LG0030;V^[P3oool0oooo00/0oooo00270?ooog00[7Yj0`00
00080?ooo`040820P0000000000000000200[7Yj<P1cG5`00`000000LeaL07=LG00807=LG0D00000
:P1cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooom`0:ajNP<00000203oool400000200[7Yj<P1c
G5`00`000000LeaL07=LG00807=LG0D00000:P1cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooom`
0:ajNP<00000203oool300000240[7Yj<P1cG5`00`0j;Rh0000007=LG00807=LG0D00000:P1cG5`0
0`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooom`0:ajNP<000001`3oool400000240[7Yj<`1cG5`20000
00T0LeaL1@00000Y07=LG0030;V^[P3oool0oooo00/0oooo00270?ooog00[7Yj0`0000070?ooo`<0
00008P2/NWXd07=LG0800000201cG5`5000002T0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo
L02/NWX3000000H0oooo1000000R0:ajNSD0LeaL00<0000003X^;P1cG5`01P1cG5`5000002T0LeaL
00<0^Jj^0?ooo`3oool02`3oool008L0ooooL02/NWX3000000H0oooo0`00000S0:ajNSH0LeaL00<0
000007=LG01cG5`01@1cG5`5000002T0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0ooooL02/NWX3
000000D0oooo1000000S0:ajNSH0LeaL0P00000607=LG0D00000:@1cG5`00`2i[Zh0oooo0?ooo`0;
0?ooo`00Q`3ooom`0:ajNP<000001@3oool30000000305Hm?@2/NWX0[7Yj0240[7Yj=P1cG5`00`1G
ADD0000003X^;P0507=LG0D00000:@1cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooom`0:ajNP<0
0000103oool01@20P8000000000000000000ESdm02<0[7Yj>01cG5`2000000@0LeaL1@00000Y07=L
G0030;V^[P3oool0oooo00/0oooo00270?ooog00[7Yj0`0000040?ooo`040820P000000000000000
02@0[7Yj>01cG5`3000000<0LeaL1@00000Y07=LG0030;V^[P3oool0oooo00/0oooo00270?ooog00
[7Yj0`0000040?ooo`040820P00000000000000002@0[7Yj>@1cG5`2000000<0LeaL1@00000Y07=L
G0030;V^[P3oool0oooo00/0oooo00270?ooog00[7Yj0`0000040?ooo`@00000902/NWXj07=LG003
0000000j;Rh0LeaL0080LeaL1@00000X07=LG0030;V^[P3oool0oooo00/0oooo00270?ooog00[7Yj
0`0000030?ooo`040820P00000000000000002D0[7Yj>`1cG5`010000000>Rh^07=LG01cG5`50000
02P0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0ooooL02/NWX3000000<0oooo0`00000V0:ajNS/0
LeaL00@0>Rh^0000001cG5`0LeaL1@00000X07=LG0030;V^[P3oool0oooo00/0oooo00270?ooog00
[7Yj0`0000030?ooo`<000009P2/NWXl07=LG080000000<0LeaL0000000000000`00000X07=LG003
0;V^[P3oool0oooo00/0oooo00270?ooog00[7Yj0`0000020?ooo`@000009P2/NWXm07=LG0L00000
:01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooom`0:ajNP<0000000<0oooo0820P00000000P00
000W0:ajNSd0LeaL00<0>Rh^0000000000001000000X07=LG0030;V^[P3oool0oooo00/0oooo0027
0?ooog00[7Yj0`0000001@3oool00000000000000000ESdm02L0[7Yj?`1cG5`5000002P0LeaL00<0
^Jj^0?ooo`3oool02`3oool008L0ooooL02/NWX3000000050?ooo`00000000000000001F?Cd09`2/
NWXo07=LG00303X^;P000000000000800000:01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooom`
0:ajNPL0000000<0ESdm0:ajNP2/NWX09@2/NWXo07=LG00303X^;P000000000000800000:01cG5`0
0`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooom`0:ajNPL00000:02/NWY007=LG0@0000000<0>Rh^07=L
G01cG5`09@1cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooom`0:ajNPH0000000<0ESdm0:ajNP2/
NWX09P2/NWY107=LG00403X^;P000000000003X^;RL0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0
ooooBP2/NWX3000000l0[7Yj0P00000B0:ajNPH00000:@2/NWY207=LG080000000<0>Rh^07=LG01c
G5`09@1cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooom:0:ajNP@0000000<0ESdm0:ajNP2/NWX0
2P2/NWX400000140[7Yj1P00000Y0:ajNT<0LeaL00<0000003X^;P1cG5`09P1cG5`00`2i[Zh0oooo
0?ooo`0;0?ooo`00Q`3ooom:0:ajNPD000002`2/NWX600000100[7Yj1@00000Z0:ajNV`0LeaL00<0
^Jj^0?ooo`3oool02`3oool008L0ooooBP2/NWX60000000305Hm?@2/NWX0[7Yj00H0[7Yj00<0ESdm
000000000000100000000`0[7al0[7Yj0:ajNP0=0:ajNPD00000:P2/NWY/07=LG0030;V^[P3oool0
oooo00/0oooo00270?ooodX0[7Yj0`0000000`2/NWX0ESdm00000002000000L0[7Yj1@0000020:aj
NP8000003P2/NWX4000002/0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooom:0:ajNP80
0000102/NWX3000000H0[7Yj1@0000020:ajNP0305Hm?@000000[7Yj00d0[7Yj1000000[0:ajNV`0
LeaL00<0^Jj^0?ooo`3oool02`3oool008L0ooooD@2/NWX2000000D0[7Yj1P0000030:ajNP800000
3@2/NWX3000002`0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooomA0:ajNP0305Hm?@00
0000:alO00@0[7Yj1@0000050:ajNP030000001F?Cd0[7Yj00/0[7Yj0`00000/0:ajNV`0LeaL00<0
^Jj^0?ooo`3oool02`3oool008L0ooooD`2/NWX2000000<0[7Yj1@00000C0:ajNP80000000<0ESdm
0:ajNP2/NWX0:P2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?oooe<0[7Yj00D0ESdm0000
002/NWX0[7Yj05Hm?@05000001<0[7Yj0P0000000`1F?Cd0[7Yj0:ajNP0Z0:ajNV`0LeaL00<0^Jj^
0?ooo`3oool02`3oool008L0ooooD`2/NWX01@1F?Cd000000000002/NWX0ESdm00@0000000<0ESdm
0:ajNP2/NWX04@2/NWX20000000305Hm?@2/NWX0[7Yj02X0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;
0?ooo`00Q`3ooomD0:ajNP80000000<0[7Yj05Hm?@0000000`0000000`1F?Cd0[7Yj0:ajNP0A0:aj
NP800000;@2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?oooeD0[7Yj0P0000000`0[7al0
0000000000020000000305Hm?@2/NWX0[7Yj0140[7Yj0P00000]0:ajNV`0LeaL00<0^Jj^0?ooo`3o
ool02`3oool008L0ooooEP2/NWX6000001@0[7Yj00<000000:ajNP2/NWX0;02/NWY/07=LG0030;V^
[P3oool0oooo00/0oooo00270?oooeL0[7Yj1@00000D0:ajNP030000002/NWX0[7Yj02`0[7YjK01c
G5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooomG0:ajNPD00000@`2/NWY/07=LG0030;V^[P3oool0
oooo00/0oooo00270?oooeH0[7Yj1@0000000`1F?Cd0[7Yj0:ajNP110:ajNV`0LeaL00<0^Jj^0?oo
o`3oool02`3oool008L0ooooEP2/NWX5000004@0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00
Q`3ooomE0:ajNPH00000A02/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?oooeD0[7Yj1`00
00130:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo9@2/NWXC0000000305Hm?@2/NWX0
[7Yj01X0[7Yj1@0000000`2/NWX0000005Hm?@120:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool0
08L0oooo9@2/NWX405Hm?@`000000`1F?Cd00`21G5`0[7Yj0:ajNP0I0:ajNP0305Hm?@0000000000
00<0000000<0[7Yj05Hm?@0[7al0@P2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?ooobX0
[7Yj00<0ESdm0000000000001P0000000`1F?Cd0[7Yj0:ajNP0N0:ajNPD000000`2/NWX200000440
[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool[0:ajNPP0000000<0ESdm0:ajNP2/NWX0
7P2/NWX5000000<0[7Yj00<0ESdm000000000000@02/NWY/07=LG0030;V^[P3oool0oooo00/0oooo
00270?ooob`0[7Yj1`0000000`1F?Cd0[7Yj0:ajNP0M0:ajNP0305Hm?@000000000000<00000102/
NWX300000080[7Yj0`0000000`1F?Cd0[7Yj0:ajNP0g0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3o
ool008L0oooo;02/NWX70000000305Hm?@2/NWX0[7Yj01`0[7Yj00<0ESdm0000000000000`000000
0`1F?Cd0[7Yj0:ajNP020:ajNP0305Hm?@000000000000H00000>@2/NWY/07=LG0030;V^[P3oool0
oooo00/0oooo00270?ooobd0[7Yj1P0000000`1F?Cd0[7Yj0:ajNP0H0:ajNPX000001`2/NWX70000
03T0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool]0:ajNPH0000000<0ESdm0:ajNP2/
NWX0602/NWX90000000305Hm?@2/NWX0[7Yj00H0[7Yj1P00000i0:ajNV`0LeaL00<0^Jj^0?ooo`3o
ool02`3oool008L0oooo;@2/NWX60000000305Hm?@2/NWX0[7Yj01X0[7Yj1`0000000`1F?Cd0[7Yj
0:ajNP060:ajNP0305Hm?@00000000000080000000<0ESdm0:ajNP2/NWX0=`2/NWY/07=LG0030;V^
[P3oool0oooo00/0oooo00270?ooobd0[7Yj1P0000000`1F?Cd0[7Yj0:ajNP0N0:ajNP<000002`2/
NWX3000003X0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool]0:ajNP0305Hm?@000000
000000<0000000<0:alO0:ajNP2/NWX0J@2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?oo
obh0[7Yj1P00001[0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo;P2/NWX6000006/0
[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool^0:ajNPH00000J`2/NWY/07=LG0030;V^
[P3oool0oooo00/0oooo00270?ooobh0[7Yj00<0ESdm0000000000000`0000000`1F?Cd0[7Yj0:aj
NP1X0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo;`2/NWX6000006X0[7YjK01cG5`0
0`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool_0:ajNPH00000JP2/NWY/07=LG0030;V^[P3oool0oooo
00/0oooo00270?ooobl0[7Yj1P00001Z0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo
;`2/NWX00`0[7al00000000000030000000305Hm?@2/NWX0[7Yj06L0[7YjK01cG5`00`2i[Zh0oooo
0?ooo`0;0?ooo`00Q`3oool_0:ajNP0305Hm?@000000000000@00000J@2/NWY/07=LG0030;V^[P3o
ool0oooo00/0oooo00270?ooobl0[7Yj00<0ESdm0000000000001000001Y0:ajNV`0LeaL00<0^Jj^
0?ooo`3oool02`3oool008L0oooo;`2/NWX00`1F?Cd0000000000004000006T0[7YjK01cG5`00`2i
[Zh0oooo0?ooo`0;0?ooo`00Q`3oool_0:ajNP0305Hm?@000000000000@00000J@2/NWY/07=LG003
0;V^[P3oool0oooo00/0oooo00270?oooc00[7Yj1`00001X0:ajNV`0LeaL00<0^Jj^0?ooo`3oool0
2`3oool008L0oooo<02/NWX7000006P0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool`
0:ajNPL00000J02/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?oooc00[7Yj1`00001X0:aj
NV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo<@2/NWX7000006L0[7YjK01cG5`00`2i[Zh0
oooo0?ooo`0;0?ooo`00Q`3ooola0:ajNPL00000I`2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo
00270?oooc40[7Yj1`00001W0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0oooo<@2/NWX7
000006L0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooolb0:ajNPH0000000<0ESdm0:aj
NP2/NWX04`2/NWX00`000000[7Yj0:ajNP1>0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0
oooo<P2/NWX60000000305Hm?@2/NWX0[7Yj01<0[7Yj00<000000:ajNP2/NWX0CP2/NWY/07=LG003
0;V^[P3oool0oooo00/0oooo00270?oooc80[7Yj1P0000000`1F?Cd0[7Yj0:ajNP0B0:ajNP800000
D02/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?oooc80[7Yj1P0000000`1F?Cd0[7Yj0:aj
NP0B0:ajNP800000D02/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?oooc<0[7Yj1P00000D
0:ajNP800000D02/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?oooc<0[7Yj1P00000B0:aj
NP0405Hm?@000000000000000500[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooolc0:aj
NPL000004@2/NWX400000500[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooolc0:ajNPL0
0000402/NWX500000500[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooolb0:ajNPT00000
3@2/NWX700000500[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3oool`0:ajNQl00000D02/
NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?ooobd0[7Yj8`00001?0:ajNV`0LeaL00<0^Jj^
0?ooo`3oool02`3oool008L0ooooW`2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?oooil0
[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooonO0:ajNV`0LeaL00<0^Jj^0?ooo`3oool0
2`3oool008L0ooooW`2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?oooil0[7YjK01cG5`0
0`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooonO0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0
ooooW`2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?oooil0[7YjK01cG5`00`2i[Zh0oooo
0?ooo`0;0?ooo`00Q`3ooonO0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0ooooW`2/NWY/
07=LG0030;V^[P3oool0oooo00/0oooo00270?oooil0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?oo
o`00Q`3ooonO0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0ooooW`2/NWY/07=LG0030;V^
[P3oool0oooo00/0oooo00270?oooil0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooonO
0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3oool008L0ooooW`2/NWY/07=LG0030;V^[P3oool0oooo
00/0oooo00270?oooil0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooonO0:ajNV`0LeaL
00<0^Jj^0?ooo`3oool02`3oool008L0ooooW`2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo0027
0?oooil0[7YjK01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooonO0:ajNV`0LeaL00<0^Jj^0?oo
o`3oool02`3oool008L0ooooW`2/NWY/07=LG0030;V^[P3oool0oooo00/0oooo00270?oooil0[7Yj
K01cG5`00`2i[Zh0oooo0?ooo`0;0?ooo`00Q`3ooonO0:ajNV`0LeaL00<0^Jj^0?ooo`3oool02`3o
ool008L0ooooW`2/NWY]07=LG0d0oooo00270?oooil0[7YjK@1cG5`=0?ooo`00Q`3ooonO0:ajNVd0
LeaL3@3oool008L0ooooW`2/NWY]07=LG0d0oooo00270?oooil0[7YjK@1cG5`=0?ooo`00Q`3ooonO
0:ajNVd0LeaL3@3oool008L0ooooW`2/NWY]07=LG0d0oooo00270?oooil0[7YjK@1cG5`=0?ooo`00
Q`3ooonO0:ajNVd0LeaL3@3oool008L0ooooW`2/NWY]07=LG0d0oooo00270?oooil0[7YjK@1cG5`=
0?ooo`00Q`3ooonO0:ajNVd0LeaL3@3oool008L0ooooW`2/NWY]07=LG0d0oooo00270?oooil0[7Yj
K@1cG5`=0?ooo`00Q`3ooonO0:ajNVd0LeaL3@3oool008L0ooooW`2/NWY]07=LG0d0oooo00270?oo
oil0[7YjK@1cG5`=0?ooo`00Q`3ooonO0:ajNVd0LeaL3@3oool008L0ooooW`2/NWY]07=LG0d0oooo
00270?oooil0[7YjK@1cG5`=0?ooo`00Q`3ooonO0:ajNVd0LeaL3@3oool008L0ooooW`2/NWY]07=L
G0d0oooo00270?oooil0[7YjK@1cG5`=0?ooo`00Q`3ooonO0:ajNVd0LeaL3@3oool008L0ooooW`2/
NWY]07=LG0d0oooo00270?ooogL0[7Yj00<0TVa/07QNGP1hGUh09P1hGUi/07=LG0d0oooo00270?oo
odl0[7YjDP1hGUi[07=LG0d0oooo00270?ooobP0[7YjN`1hGUiY07=LG0d0oooo00270?ooo`80_:n_
XP1hGUh00`1fGEd0LeaL07=LG01U07=LG0d0oooo00290?ooo`030;b_[`1hGUh0N5iN0:40N5iNIP1c
G5`=0?ooo`00R`3ooonT07QNGV@0LeaL3@3oool008d0ooooX`1hGUiS07=LG0d0oooo002>0?ooo`03
0;b_[`1hGUh0N5iN0:00N5iN0P1fGEeP07=LG0d0oooo002A0?oooj<0N5iNG`1cG5`=0?ooo`00TP3o
ool00`2l[jl0N5iN07QNGP2P07QNGUh0LeaL3@3oool009@0ooooXP1hGUiM07=LG0d0oooo002E0?oo
oj<0N5iNF`1cG5`=0?ooo`00UP3oool00`3NemL0_:n_07QNGP2P07QNGP0307IMG@1cG5`0LeaL05L0
LeaL3@3oool009X0ooooXP1hGUiG07=LG0d0oooo002K0?oooj80N5iNEP1cG5`=0?ooo`00W03ooonR
07QNGUD0LeaL3@3oool009h0oooo00<0_:n_09Z7Q`1hGUh0W`1hGUh00`1fGEd0LeaL07=LG01@07=L
G0d0oooo002P0?oooj80N5iND@1cG5`=0?ooo`00XP3ooonQ07QNGU00LeaL3@3oool00:@0ooooX@1h
GUi>07=LG0d0oooo002U0?oooj40N5iNC@1cG5`=0?ooo`00YP3oool20;b_[il0N5iN0P1fGEe:07=L
G0d0oooo002Y0?oooj40N5iNB@1cG5`=0?ooo`00ZP3ooonQ07QNGTP0LeaL3@3oool00:`0ooooX01h
GUi707=LG0d0oooo002]0?ooo`030=kGe`2l[jl0N5iN09h0N5iN00<0MUeM07=LG01cG5`0@P1cG5`=
0?ooo`00/03ooonP07QNGT<0LeaL3@3oool00;40oooo00<0_:n_07QNGP1hGUh0WP1hGUi107=LG0d0
oooo002c0?oooj00N5iN@01cG5`=0?ooo`00]@3oool00`2l[jl0N5iN07QNGP2L07QNGP0307IMG@1c
G5`0LeaL03`0LeaL3@3oool00;L0ooooX01hGUhl07=LG0d0oooo002i0?oooil0N5iN>`1cG5`=0?oo
o`00^P3oool00`2l[jl0N5iN07QNGP2L07QNGSX0LeaL3@3oool00;/0ooooX01hGUhh07=LG0d0oooo
002m0?ooo`80_:n_W@1hGUh00`1fGEd0LeaL07=LG00d07=LG0d0oooo00300?oooih0N5iN=@1cG5`=
0?ooo`00`@3ooonO07QNGS<0LeaL3@3oool00<<0ooooWP1hGUh00`1fGEd0LeaL07=LG00_07=LG0d0
oooo00340?ooo`030;b_[`1hGUh0N5iN09/0N5iN0P1fGEd_07=LG0d0oooo00370?oooih0N5iN;P1c
G5`=0?ooo`00b03oool00`2l[jl0N5iN07QNGP2K07QNGRd0LeaL3@3oool00<X0ooooW@1hGUh/07=L
G0d0oooo003;0?oooih0N5iN:P1cG5`=0?ooo`00c03oool00`3NemL0_:n_07QNGP2K07QNGP0307MN
GP1cG5`0LeaL02H0LeaL3@3oool00=00ooooW@1hGUhV07=LG0d0oooo003A0?oooid0N5iN9@1cG5`=
0?ooo`00dP3ooonM07QNGR@0LeaL3@3oool00=@0oooo00<0_:n_09Z7Q`1hGUh0V@1hGUh207IMGB40
LeaL3@3oool00=H0ooooW@1hGUh00`1fGEd0LeaL07=LG00M07=LG0d0oooo003H0?oooi`0N5iN7`1c
G5`=0?ooo`00fP3ooonL07QNGQd0LeaL3@3oool00=/0ooooW01hGUhL07=LG0d0oooo003L0?ooo`80
_:n_VP1hGUh00`1fGEd0LeaL07=LG00H07=LG0d0oooo003O0?oooi`0N5iN601cG5`=0?ooo`00h@3o
oonK07QNGP0307IMG@1cG5`0LeaL01@0LeaL3@3oool00>80ooooV`1hGUhF07=LG0d0oooo003S0?oo
o`030=kGe`2l[jl0N5iN09T0N5iN00<0MUeM07=LG01cG5`04@1cG5`=0?ooo`00iP3ooonK07QNGQ80
LeaL3@3oool00>L0oooo00<0_:n_07QNGP1hGUh0V@1hGUh@07=LG0d0oooo003Y0?oooi/0N5iN3`1c
G5`=0?ooo`00j`3oool00`2l[jl0N5iN07QNGP2G07QNGP0307MNGP1cG5`0LeaL00/0LeaL3@3oool0
0>d0ooooV`1hGUh;07=LG0d0oooo003_0?oooiX0N5iN2P1cG5`=0?ooo`00l03oool00`2l[jl0N5iN
07QNGP2G07QNGPT0LeaL3@3oool00?40ooooV`1hGUh707=LG0d0oooo003c0?ooo`80_:n_V01hGUh0
0`1fGEd0MEeM07=LG00307=LG0d0oooo003f0?oooiT0N5iN101cG5`=0?ooo`00m`3ooonJ07QNGP80
LeaL3@3oool00?T0ooooV@1hGUh00`1cG5`0oooo0?ooo`0;0?ooo`00nP3oool20;b_[fH0N5iN<@2l
[jl=0?ooo`00o@3ooolc07QNGW00oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo
003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo
003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo
003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo
003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{90.5625, 188.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 3.4 Heat flux ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_x\)]],
  "in a slab of material of area ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and thickness ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ", caused by a temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\)]],
  " that varies in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction."
}], "Caption",
  CellTags->"Fig. 3.4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Energy conservation", "Section",
  CellTags->"c:15"],

Cell[TextData[{
  "\tWhen ",
  Cell[BoxData[
      \(TraditionalForm\`T = T(x)\)]],
  ", Eq. ",
  ButtonBox["(3.1.37)",
    ButtonData:>"(3.1.37)",
    ButtonStyle->"Hyperlink"],
  " implies that the energy flux ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(\[CapitalGamma]\_x\),
            "TraditionalForm"]}], TraditionalForm]]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " direction is generally also a function of position. This, in turn, \
implies that the energy content of the material changes with time as energy \
builds up in some locations and is lost to other locations. We will now \
examine this process in detail. "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.05858 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00132829 0.0252042 0.00132829 [
[ 0 0 0 0 ]
[ 1 1.05858 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.05858 L
0 1.05858 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .0252 translate
.95238 1.00817 scale
2151 string
717 759 8 [717 0 0 759 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010101000000000000000000FFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000010101000000000000010101000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000010101000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000010101
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000010101000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000010101000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010101000000000000000000000000FEFEFEFFFFFF000000000000000000000000000000
000000000000000000010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFF000000000000000000000000FFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFF000000000000010101000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF010101000000000000000000000000000000FEFEFEFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFF010101000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
010101000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FEFEFEFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFF000000010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000010101000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000010101000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFEFEFEFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF000000000000000000010101000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFE000000000000000000FFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF010101000000FFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF010101000000FFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF010101000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
010101000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF000000000000000000000000010101000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
010101000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000010101000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
010101000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000010101000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000010101000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
010101000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF010101
000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000010101000000FFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101000000
000000000000000000FFFFFF010101000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000010101
000000000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
010101000000000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFEFEFEFFFFFF000000000000000000FFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFF000000010101000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFF000000000000010101000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000010101000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000010101000000000000000000000000010101000000FFFFFFFFFFFFFEFEFE
FEFEFEFFFFFF000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000010101000000FEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000010101000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000010101000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000FEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FEFEFEFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000010101000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000010101000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000010101000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFEFEFE
FFFFFFFFFFFF000000000000000000010101000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000010101FFFFFF
FFFFFF000000000000000000000000000000000000000000000000010101FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFF000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000010101
000000000000000000010101000000000000000000000000000000FFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000010101000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000010101000000000000010101FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF010101000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D8D8D8D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D8D8D8000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7
D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D6D6D6
D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000
000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000
000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000
000000000000000000000000000000010101000000000000000000000000000000D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000
000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D6D7000000000000000100000000000000
000000000000000000000000000000000000000100000100000000000000000000000000
000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6
D7D7D5D7D7D5D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D6D7D8D6D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D6D7D8D6D7D7D7D7D7D7D7
D7D7D7D7D7D7D6D8D7D6D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7
D8D8D8D7D7D7D7D7D7D7D7D7D7D7D5D7D7D7D6D8D7D6D7D9D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7000000000000000000010002010002000000000000000000010101000000000000
000000000000000000000000000000000000000000D7D7D7D6D8D7D6D8D7D8D8D8D7D7D7
D7D7D5D6D6D4D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000010000000000000000000100000000030000
070000070000030000000000000000000000000100000100000000000000000000000000
000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D5D7D7D5D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D6D7D8D6D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D6D7D8D6D7D7D7D7D7D7D7
D7D7D7D7D7D7D6D8D7D6D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D5D8D8D8D6D8D7D6D7D9D7D7D7000000000000000000
000000000000000000010101010002010002000000000000000000010101000000000000
000000000000000000000000000000000000000000000000D6D8D7D6D8D7D7D7D7D7D7D7
D7D7D5D7D7D5D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000000000000000070000
150000150000070000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D7D7D5D7D7D5D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D5D7D7D5D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D5D7D7D5D7D7D7D7D7D7D8D6D7D8D6D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D6D8D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D9D7D7D9D6D8D7D7D7D7D7D7D7D8D6D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D9D7D7D9D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000010000010000
010000000000010103000002000000000000000000010101000000000000000000000000
000000000000000000000000000000000000000000000000000000D7D7D5D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D70000000000000000000000000100000400000800000F00001B0000
A77155A673581600000B0000070000030000010000000000000000000000000000000000
000000000000010101000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D5D7D7D5D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D5D7D7D5D7D7D7D7D7D7D8D6D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D6D8D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D9D7D7D9D6D8D7D7D7D7D7D7D7D8D6D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D9D7D7D9D7D7D7D7D7D7000000000000000000000000000000000000010000010000
0100000000000000020000020000000100000300000700000D00000F0000120000140000
1400001100000D0000070000030000000000000000000000000000000000D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D70000000000000000000000000400000B0000190000AF7051BB6C45
BF6B3FBD6B43B06F4F2300001500000A0000030000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000D7D7D7D7D7D7
D7D7D7D7D7D7D6D8D7D7D7D7D7D7D5D8D7D5D8D6D7D8D6D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D5D7D7D5D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D6D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D8D7D5D8D7D5D7D7D5D7D7D5
D7D7D7D7D7D7000000000000000000000000010101000000010101000000000000000000
0000020000020000000000000000000300000A0000150000240000AD7051B66D4AB86D46
B86D46B16F4D240000150000070000000000000000000000000000000000D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7000000000000000000000000000000090000190000AC7153C0693ECB6534
CB6632C86836C0693EB66D4AA771571900000B0000030000010000000000000000010000
040000060000080000080000060000040000010000010100000000000000000000000000
D7D7D7D7D7D7D6D8D7D7D7D7D7D7D5D8D7D5D8D6D7D8D6D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D5D7D7D5D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D6D8D7D6D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D7D5D8D7D5D7D7D5D7D7D5
000000000000000000000000000000000000000000010000040000060000080000070000
030000000002000000000000000000070000150000A3745AB46E4AC0693EC76737CC6635
CC6733C46839B66E48A872561B00000E0000040000010101000000000000000000D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D8D8D8D7D7D7D6D8D7D6D8D7
D6D6D6D7D7D70000000000000000000000000000000F0000AF7051C16A3DC86836CC6733
CC6635CB6735C86836C5693ABF6B3FB06E4C1900000A0000030000000000000100030000
0B00001200001900001900001200000B0000040000000000000000000100000000000000
000100000100000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D7D7D7D7D7D7D8D6D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D6D8D7D7D7D5D7D7D5D7D7D7000000000000000000
0000000000000000000000000000020000020001000300000B0000120000190000160000
0700000000000000000000000000000D0000240000B66D4AC0693EC86838CB6735CC6733
CC6733C96835C5693AC16A3FBA6B42AA71540E0000000000000000000000010000010000
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D6D8D7
D7D7D7D7D7D70000000000000000000300000700001B0000BB6C45CC6733CC6733CC6733
CB6534CC6635CB6632CC6733CC6733C16A3DAA7153190000080000000000000000030000
0B0000624535723F24793E207240291E00001400000D0000070000030000010000000000
000100000100000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D6D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D6D8D7D7D7D7000000000000000000000000000000
0000000000000000000300000700000B00001100001600001D0000704029763E256C422C
0B0000000000000000010000040000140000B06F4FC2693FC86637CB6534CC6733CC6733
CB6632CB6632CE6633CE6633CC6733BC6A421D00000B0000030000000000010000010000
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7
D6D8D7000100000100000100000000070000160000A87258C0693ECC6635CC6733CB6632
CC6733CC6733CC6733CC6733CE6633C96736C16A3DAD70510F0000000000000000010000
040000150000803C198E35098C370E853A137C3D1C2500001500000A0000030000010101
000000000000000000000000000000000000000002000002000000000000000000D7D7D7
D7D7D7D7D7D7D8D6D7D8D6D7D8D7D5D8D7D5D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D8D6D7D8D6D7D7D7D5D7D7D5D9D7D8D7D7D7D7D7D7D7D7D7D7D7D9D7D7D9D7D7D7D7D7D7
D7D7D7D6D6D6D7D7D7D7D7D7000100000100000000000000000000000000000000000000
0000000000000000000700001600002400007D3B1987391289370F883912843A17723E26
0D00000000000000000400000B00001D0000B76C45C96738CA6634CC6733CB6632CB6632
CB6534CC6635CB6534CC6635CC6635C4693CB36F4C2000000A0000000100010100000000
000000D6D6D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D70001000001000000000300000F0000260000B76D4AC5683CCC6635CB6632CC6733
CC6733CC6733CC6733CC6733CE6633CE6633CC6733BB6C431B0000070000030000000000
010101120000833A179634039733019434028D3609823A14743E241C00001400000D0000
0B0000080000060000040000010000000000000002000002000000000000000000000000
000000D7D7D7D8D6D7D8D6D7D9D8D6D8D7D5D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D8D6D7D8D6D7D7D7D5D7D7D5D8D6D7D9D7D8D7D7D7D7D7D7D7D7D9D7D7D9D7D7D7D7D7D7
D6D6D60000000000000000000001000001000000020000020000000300000700000B0000
0D00000F00001200001B0000763E23833914913506993400993302943507873913270000
0D0000000000000000060000120000A5735ABF6A41CC6635CC6733CC6733CC6733CC6733
CB6534CC6635CC6635CB6534CC6635C96738C16A3DAF704F120000030000020100000000
000002D7D7D9D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D50000000000000300000A00001C0000B66D4AC7683ACB6736CE6633CC6733CC6733
CC6733CC6733CC6733CC6733CC6733CC6733CE6633C16A3FA87256150000070000000000
0000000F00007C3D1E8D36099535039834029535039135068C380C843A137C3D1E270000
2000001900001200000B0000030000000100000000000000000000000000000002000002
000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D7D5D8D7D5D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000000000000000000000000000000002000002000000080000160000200000
270000793C1D833A178839108E370C9135069635029733009933029136097F3B18200000
0B00000000000001000900001A0000AC7153C16A3DCB6632CC6635CB6534CE6535CE6535
CE6633CE6633CC6635CC6635CE6633CC6635C96736B86D461D00000B0000040000000000
000002D7D7D9D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7
D8D7D5010000000000070000150000A87258C16A3FCE6633CD6532CE6633CC6733CB6632
CC6733CC6733CC6733CC6733CC6733CC6733CE6633C4693CAF70511C0000080000000002
0101010D00002800008739129435079934009833009934009933029535058E370A863811
803C19793E207240271D00001600001100000F00000E00000C0000070000010000000002
000000010101000000000000000000D7D7D7D7D7D7D7D7D7D8D7D5D8D7D5D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000
0000000000000000000100000400000700000B00000F00001200001C0000763E23803C19
8739138D36099535039833009934009934009834009834009933028F360A7D3C1C1D0000
0A00000000000001000B0000240000B76D48C5693ACC6733CC6635CC6635CE6535CE6535
CE6633CE6633CB6534CC6635CE6633CE6633CC6733BF6B3FA47259120000060000000000
010103000002D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D6D8D7
D7D7D70000000000020B0000240000B66E48C5693ACC6733CB6534CC6635CB6534CC6635
CC6733CC6733CC6733CC6733CC6635CC6635CC6733C26A3CB06F511D00000A0000000000
0000000B00002100007F3A199136099933029B3300993400983201973301953302943505
9136098E370A8C370E89370F873913833A177C3D1E290000220000160000070000000000
000002000000000000000000000000000002000000010000000000D7D7D7D7D7D7D7D7D7
D8D8D8D7D7D7D7D7D7000000010000010000000000000000000100000100000000000000
0000000000000101000400000B00001500002400007A3D20833A178839108D360B913609
94350795350598340299340099340099340098340298340299340091360A7C3B1B1D0000
0A0000010101000000120000B06E4CC5693AC96835CB6632CC6635CC6635CC6733CC6733
CC6733CC6733CC6733CC6733CC6733CC6733CB6632C16A3DAC7153190000080000000000
000000000000D6D8D7D7D9D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D6D8D7
0000000000000000020F0000AC6F50C16A3DC76735CB6632CC6635CC6635CB6534CC6635
CC6733CC6733CC6733CC6733CC6635CC6635CC6733C2693DB06F4F1D00000B0000010000
0000000A00001D00007C3B1D8E35099832019B33009A32009933029832019B33009B3300
9934009934009933029933029933029634058F360A8839127F3B18743E221B0000110000
0B0000070000030000000000000000000002000000010000000000000000000000000000
0000000000000000000000000000000000000000000000000000000100000700000B0000
0D00000F0000120000160000200000753F23833A178E370C953503993400993400993400
99330299330299340099340099340098330097330199330298330091360A7D3C1C1D0000
0A0000000000000000140000B76C45CC6733CC6733CC6733CC6635CB6534CC6733CB6632
CC6733CC6733CC6733CC6733CB6632CC6733CC6733C1693BB06F511D00000A0000000000
010101000000D6D8D7D6D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
000100000100000000120000B56C49C86838CB6735CC6733CC6635CB6534CC6733CC6733
CC6733CC6733CE6633CE6633CC6733CC6733CB6735C2693DAF6E4E1D00000A0000000000
0000020A00001D00007C3B1D8E35099833009934009934009B33009B3300983300993400
9934009833009A32009B33009933029834029634039435059136098C380C8839107E3C1A
240000160000070000000000000000000000000000000000000000000000000000000000
010000010000010000000000000002000002000002000000010000080000160000200000
2700007A3D1E833A178739128A38108C380C9236079434029933029B3300993400993400
9833009833009933029933029934009934009934009934009933028E35097D3C1C1D0000
080000000100000000140000B86D46CC6635CB6632CB6632CB6632CC6733CC6635CB6534
CC6733CC6733CC6635CC6635CC6733CC6733CC6733C26A3CAF6E501D00000A0000000000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
000100000100000000140000BA6C48CB6534CC6733CC6733CC6635CC6635CC6733CC6733
CC6733CC6733CE6633CE6633CC6733CC6733CC6635C16A3DAC7153190000080000000000
0000020D00002500008339149135069934009934009934009B33009B3300993400993400
9833009934009B3300993400993302993302983300993400993400993400993400913609
803B1A6F412A120000070000030000000000000000000000000000000000010101000000
0100000100000100000300000700000800000800000B00001200001D0000753F23803B1A
8739128E370A9535039833009933029933029833009934009B33009B3300983300993400
9833009934009832019933029934009934009934009934009933028F360A7C3B1B1D0000
080000000100000000110000B06E4CC5693AC96736CC6733CB6632CB6632CC6635CC6635
CB6632CC6733CC6635CB6534CC6733CC6733CB6632C1693BAF6E501D00000A0000000000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
000002000002010000140000B96B47CF6636CC6635CC6635CB6632CC6733CC6733CB6632
CB6534CB6534CC6635CC6635CE6633CC6733CC6733BE6B3FA5735A120000060000000000
0000001100007F3A199236079834039832019B33009A3200993400993400993400993400
9B33009A32009934009934009933029834029933029934009934009934009A3200933406
8739137C3C206F412A624537070000000000000100000002000000000000000000000000
0000000000000000000700001500001C00001D0000240000803B1A8839128C380C913609
943507953503983402993400993400993400993400993400993400993400993400993400
9934009934009934009934009934009934009933029933029834008E38097B3C1B1D0000
0A00000000000000020B0000240000B66E48C5693ACE6633CB6632CC6733CC6733CB6632
CC6635CC6635CB6632CB6632CB6632CB6632CD6532C4693CB06F511D00000B0000010000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFE000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000
000002000002010000140000B66D4AC96738CA6635CC6635CC6733CB6632CC6733CC6733
CB6534CC6635CC6635CC6635CD6532CD6532CC6733BD6B431F00000B0000040000000000
0000001400008739139A32009933029933029A32009A3200993400983300983300993400
9A32009A32009934009934009834029834029933029834029535039236078E370C873913
7C3D1E270000220000160000070000000000000100000100000000010000030000070000
0D00000F00001200001C0000743E247B3C1D7D3C1C843A15923509993302993302993302
993400993400993400993400993400993400993400993400993400993400993400993400
993400993400993400993400993400993400993302993302983400913607833B15230000
0D0000000000000002080000190000AC7153C2693DCE6633CC6733CC6733CC6733CB6632
CC6635CC6635CC6733CC6733CC6733CC6733CE6633C4693CB06F511D00000C0000010000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000
0000000000000000000F0000AE6F50C16A3FC86838CC6635CC6733CC6733CC6635CC6635
CC6733CC6733CC6733CC6733CC6733CC6733CB6632BA6C45160000040000020100000000
000000140000853A139933029933029832019832019933029934009934009B33009B3300
9833009833009833009934009833009934009833009434028E370A823A14753D221D0000
1400000F00000B00000800000400000101010000000000000000000300000A0000150000
2400007B3C1D813B178739128C370E8D34089035089435079834029B3300993302993302
993400993400993302993302993400993400993400993400993400993400993400993400
9934009934009934009934009934009934009934009934009934009635029135067E3C1A
110000000000010000070000120000A47259BF6B3FCC6733CC6635CC6635CC6733CC6733
CC6733CC6733CC6733CC6733CB6632CC6733CC6733C26A3CAF70511C00000A0000000000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7
0000000000000000000B0000240000B66E48C5683CCC6635CC6733CC6733CC6635CC6635
CC6733CC6733CC6733CC6733CC6733C96835C5693AB06E4C110000000000000000030000
0800001C00008839129933029933029933029832019833009934009934009A32009B3300
9934009635029135068E36088F37098C380C883910833A177A3D1E2400001600000B0000
0400000000000100000100000000000300000700000B00000E00001400001C0000753F23
8339148E35099535059733019733019933029934009B33009B33009B3300993302993302
993400993400993302993302993400993400993400993400993400993400993400993400
993400993400993400993400993400993400993400993400993400993400983300883912
1B00000700000300000400000B00001D0000B86D46C86836CB6735CC6635CC6733CC6733
CC6733CC6733CB6632CC6733CC6733CC6733CC6733BF6B3FA87258150000080000000000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D6D7D9D6D7D9D7D7D7D7D7D7
000000000000000100070000150000A87256BF6B3FCB6632CB6632CB6632CE6633CE6633
CC6635CB6534CC6635CC6635CB6632C46839B66C472400000E0000000000000000070000
160000753F238D360B993400993400993400973300973300993400993400993400993302
9A3200913506833B157C3D1C7B3C1B743E221B00001200000F00000B0000080000050000
0100000000000000000000000100000800001600002200002900007C3B1B853A138C380C
913506963403993302993400993302993302993400993400993400993400993400993400
9934009934009B32029B3202993302993302993302993302993400993400993400993400
9934009934009934009934009934009934009934009934009934009934009B32028E370C
753F25150000080000030000040000140000AF704FC0693CC76735CB6632CC6733CC6733
CC6733CC6733CC6733CB6632CE6633CE6633CB6534BA6B441B0000070000030000000000
010101000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7
0000000000000001000300000B00001B0000B06E4CC0693CC86836CC6733CE6633CE6633
CC6635CB6534CC6635C96736C46839B86D46A673581600000700000000000000000D0000
240000843A159135069934009934009833009834009534019135068E370A8B380E8A3810
883912803C192400001C00001C0000150000070000000000000100000000040000070000
0800000D00001100001400001400001C0000763E237F3B188839128E3509953304983201
9934009934009A32009B3300983201983201983300993400993400993400993400993400
9934009934009B32029B3202993302993302993302993302993400993400993400993400
9934009934009934009934009934009934009934009934009833009833009B3202923509
843A172600001200000400000100000B0000200000B16F4DBF6B3FC86836CA6634CC6733
CC6733CC6733CC6733CA6634C86635C46839BF6B3FAD70510F0000000000000000000000
000000D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D70000000001000000000400000D00001B0000AB6F53C16A3DCC6733CB6534CB6534
CC6733CC6733CB6534C5683CB56C49A5735A140000070000030000000000000000110000
7E3C1A913506963502983300993400983300983300923607833B15763D1F7040291D0000
1600001100000D00000A00000A00000700000300000000000000000300000B0000120000
1900002400007D3B19843912853A138839108E370C903508943505963403973301983300
9B33009A32009934009934009832019832019834029933029934009B3300993400993400
9933029933029933029933029934009934009934009934009934009934009B33009B3300
9933029933029933029933029934009934009934009934009933029933029B3300983403
9235098239161C00000B00000400000400000B00001B0000B06E4CC16A3DC86836CB6632
CC6635CC6635CB6534C76737C16A3DB56D47A77157190000080000010000000000000000
000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFE000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D8D7D5D8D7D5D7D7D7D7D7D7
D7D7D70000000000000000000000000400000B0000190000AE6F50BA6B42C16A3FC16A3F
BF6A41BD6B43BA6C46B06E4C2400001500000700000000000000000400000B00001D0000
8A38109634039236078C380C873811843912853A137E3C1A2500001900001100000A0000
0300000000000000000400000700000B00000D00000F00001200001600001F0000713F26
793E20843A159236079934009833009934009934009934009B3300993400993400993400
9934009934009833009833009933029933029834029832019B33009B3300993400993400
9933029933029933029933029934009934009934009934009934009934009B33009B3300
9933029933029933029933029934009934009934009934009933029832019B33009B3300
9832018C380C753D221600000800000000000000000A0000200000AF704FB86D46BF6A41
C0693EBF6A41BA6B44B56C49AD70512300001500000B0000040000010000000000000000
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D8D7D5D8D7D50100000000000000000100000400000800000F00001B0000A97156AC7054
A472591F00001600001100000D00000700000300000000000000000B0000200000803B1A
903509923509823916753F251900001200001400001200000D0000080000060000030000
0100000000000000000700001600002000002800007C3D1E833A178739138A38108B380C
8E370C9236079634039934009933029933029B32029B3202993400993400993302983402
9834009934009934009B33009934009934009934009934009B33009B3300993400993400
9934009934009934009934009B33009B3300993400993400993400993400993400993400
9B33009A3200993400993400993302993302993302993302993400993400993400993400
993302913408843A152400000D00000000000001000300000B00001400001D0000A5735A
AC7054A872581B00001200000F00000B0000070000040000030000010000000000000000
D7D7D7D7D7D7D8D6D7D8D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D8D7D5D8D7D50100000100000000000000000000000000000000000700001600001B0000
1200000B00000400000000000000000000000000000100000400000E00006D402B7A3D20
833A197E3C1A2400001500000700000000000000000100000000000300000700000A0000
0A00000D00001100001B0000763E23803C198739138E370A963405993400993400983400
9933029933029934009934009933029933029B32029B3202993400993400983402983402
9834009934009934009B33009934009934009934009934009B33009B3300993400993400
9934009934009934009934009B33009B3300993400993400993400993400993400993400
9B33009B3300993400993400993302993302983201983201993400993400993400993400
9933029634058F360A7C3D1E0F00000000000001000001000000000400000B0000120000
190000160000070000010101000000000000000000000000010000010000000000D7D7D7
D7D7D7D6D6D6D8D6D7D8D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D6D8D7
D7D7D7D7D7D7D7D7D70000000000000000000000000000000001000100000800000A0000
0700000400000100000000000000000000000000000400000B00005A483E0E00000F0000
1200001100000D00000700000300000000000000000000000000000700001500001C0000
1D00002400007D3B198839108E370C903508943507953503983402993400993400993302
9933029933029934009934009934009934009B33009B3300993400993400993400993400
993400993400993302993302993400993400993400993400993302993302993400993400
9B33009B3300993302993302993400993400993400993400993400993400993400993400
9933029933029933029933029934009934009934009833009B33009A3200983300993400
993302983402963403833A17120000000000000000000000010000010000040000060000
080000080000030000000000000000000000000000000000000000000000D7D7D7D6D6D6
D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000010101000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D6D8D7
D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000100000000010101010000
0000000000000000000000000000000000000000000400000B00000B0000040000000000
0000000000000000000100000400000700000D00000F00001200001B0000753F257C3D1E
7C3B1D843A15923607993400993400993400993302993400993400993400993302993302
9933029933029934009934009934009934009B33009B3300993400993400993400993400
9B33009B3300993302993302993400993400993400993400993302993302993400993400
9B33009B3300993302993302993400993400993400993400993400993400993400993400
9933029933029933029832019934009833009934009833009B3300983300953302943505
9136098E370C8C370E7C3D1E0F0000000000010101000000010000010000000000000000
000000000000000000000000000000000000000000000000000000D7D7D5D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D8D8D8D7D9D6D6D8D5
D7D7D7D7D7D7D7D7D9D7D7D9D7D7D7D7D7D7000000000000000000000000000000000000
000000010100000000000000010101000000000000010000040000040000010000000000
0000000000000100000400000B00001600002500007A3D1E833A178839128B370B8E370A
8E3509923607963403993302993400983300993400993400993400993400993302993302
9B32029B3202993400993400993302993302993302993302993400993400993400993400
9934009934009934009934009934009934009B33009B33009B33009B3300993302993302
9B32029B3202993400993400993400993400993400993400993302993302993400993400
9B33009B33009934009934009833009934009832019933029934009634038E370A863811
7F3A19783C20724027190000080000000000000000000000000000000000000000000000
000000000000000002000100000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D6D8D5D6D8D5
D7D7D7D8D8D8D7D7D9D7D7D9D7D7D7D7D7D7D7D7D7D7D7D7000000010101000000000000
000000000000000000000000000000000000000000000000010000020100000000030000
0700000C00000E00001500001E0000753F25843A178E370A953503993400993400993400
993400993400983201993302983300993400993400993400993400993400993302993302
9B32029B3202993400993400993302993302993302993302993400993400993400993400
9934009934009934009934009934009934009B33009B33009B33009B3300993302993302
9B32029B3202993400993400993400993400993400993400993302993400993400993400
9934009933029533029435059136098E370A8C370E8A3810873912803A167A3D1E270000
2000001900001200000B0000040000000000000000000000010101000000000000010101
000000000000000002000002000000000000D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
010101000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D5D7D7D5D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D9D6D6D8D6D8D7D6D8D7D7D7D7D7D7D7
D7D7D7000000000000000000000000000000000100000100000000000000000000070000
1500002100002900007D3C1C8739138E370C923509943404983402993400993400993400
9934009934009834029832019833009A32009A32009A3200993302993302993400993400
9B33009B33009934009934009B33009B33009933029933029B33009B33009B33009B3300
9934009934009834029834029933029933029B33009B33009B33009B3300993400993400
9934009934009B33009B33009934009934009834009834009934009934009B3300993400
9934009434028F360A873811803C19793E207240271D00001600001100000F00000D0000
0B0000080000060000040000010000000000000000000000000002000002000000000000
000000000000000000D7D7D7D7D7D7D7D7D7D7D7D5D7D7D5D7D7D7D7D7D7D7D7D7D7D7D7
D8D6D7D8D6D7D7D7D9D7D7D9D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D5D7D7D5D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D9D7D7D9D6D8D7D6D8D7D7D7D7D7D7D7
D7D7D7D6D6D60000000000000101010000000001000100000700000D00001100001B0000
743E24803B1A8739138F360A9634039B33009832019933029934009934009A32009B3300
9833009934009733019832019934009B33009B33009B3300993302993302993400993400
9B33009B33009934009934009B33009B33009933029933029B33009B33009B33009B3300
9934009934009834029834029933029933029B33009B33009B33009B3300993400993400
9934009934009B33009B33009934009934009834009635029236078F37099136098E370A
883912813B177B3C1D2900002100001900001200000B0000030000000100000000000000
000000000000000000000000000000000000000000000000000002000002000000000000
D7D7D7D7D7D7D8D6D7D8D6D7D7D7D7D8D8D8D7D7D5D7D7D5D7D7D7D7D7D7D6D6D6D7D7D7
D8D6D7D8D6D7D7D7D9D7D7D9D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
010101000000000000010101000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D8D6D70100000100000201000000000000000001000600001600002400007E3C1A883912
8C370E903509943507963405983402993400993400993400993302993400993400993400
9934009934009934009934009933029933029B33009B3300993400993400993400993400
9933029933029933029933029A32009B3300993400993400983300983300993400993400
993400993400993400993400993302993302983300983300983300983300983300983300
993400993400993400993400993400993400993400923607843A157D3C1C7C3D1C743E22
1B00001200000F00000E00000B0000080000060000040000010000000000010000010000
000000000000000000000000000000000000000000000000000000000000000000000000
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D8D6D70100000100000000000000000000000300000F0000724029843A17913408993302
993302993302993302993302993400993400993400993400993302993302993400993400
9934009934009934009934009933029933029B33009B3300993400993400993400993400
9933029933029933029933029A32009B3300993400993400983300993400983300993400
9934009934009934009934009933029A3403993400993400993400993400993400963502
9236078E36088F360A8C380C883910853A138439127E3C1A2400001D00001D0000150000
0700000000000000020000020000020000020000000100000400000600000A00000B0000
0E00000F00001200001400001400000F0000080000040000010000000000000000000000
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFF000000000000000000000000FFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D90000000000000000000000020300000B00001D0000833A17923509963403993400
993400983300993302993302993400993400993400993400993400993400993302993302
9B33009B33009B33009B33009934009934009934009934009B3300993400993302983402
993400993400993400993400983300993400993400993400993400993400993302983201
9B32029B32029933029832019933029933029B33009A3200993400983300983400903506
843A157D3C1C7D3C1E753F231B00001400001200001100000D00000A00000A0000070000
0300000101010000000000000100000100000101010400000B0000120000190000200000
2900007C3D1E833A17843912853A137C3D1E1900000B0000040000000000000000000000
D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D9010103000000000000000002070000150000753F238C380C983201993400993400
983300983300993302993302993400993400993400993400993400993400993302993302
9B33009B33009B33009B3300993400993400993400993400993400993400993302993302
993400993400993400993400993400993400993400993400983300993400983201993302
9B32029A31019933029634039235098F360A91360A8E370C883910853A13853A137E3C1A
2400001D00001D0000160000070000000000000100000000000000010000000000000000
0000000300000800000A00000B00000D00001100001600001F0000724029793E20803C19
8839128E35099533029934009833008C380C753F23160000070000000000000000000000
000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D70000000000000000000000000B0000240000833A17923607993400993400993400
993400993400993400993400993400993400993400993400993302993302993400993400
9B33009B3300993400993400993400993400993302993302993302993302993400993400
9934009934009934009934009934009934009A35019833009934009833009B33009B3300
9833009934009A32009236078339167D3C1E7C3D1E753F231B0000140000140000120000
0B00000800000A0000070000030000000000000000000000000000000000010000010000
0000000700001600001D00001D00002400007E3C1A8638118A38108C370E8F360A913506
953505963502983402993400983201923509833B152400000D0000000000000000000000
000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF000000000000010101
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
0000000000000000000200010300001400007C3D1E8E370C9634039833009A3501993400
993400993400993400993400993400993400993400993400993302993302993400993400
9B33009B33009934009934009934009934009933029933029933029933029934009B3300
9934009934009934009934009934009833009934009834029434029435059235098E3509
8B370B8A38108738117F3A192500001D00001C0000150000070000000000000000000000
0000020000000000000300000700000A00000A00000B0000110000140000140000140000
1400001B0000753D247D3C1E7D3C1E8339169236079934009933029933029A32009B3300
9B33009A32009934009934009832019434048E370C7A3D1E0F0000000000000000000000
000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF000000010101000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
0200010100000000020300000A00001C00008438149634059833009B3300983300993400
9934009934009833009833009934009934009B32029B3202993302993302993400993400
9B33009B33009933029933029934009934009B3300993400993400993400993302993302
9934009934009834029933029934009B33009933029434048E370A8638117F3B18793E20
7240271F00001800001100000D00000B00000B0000070000030000000000010000010000
0100000000000000000700001600001D00001C00002300007E3C1A843912853A13853A13
853A138839128E370C8F360A8F360A923509963403993400993302993302993400983300
983300993400993400983300993400973301953505833A17120000000000000000000000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFF000000010101000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
0100000100000000020600001200007040298B380E9833009B33009B3300983300993400
9833009833009934009934009934009934009B32029B3202993302993302993400993400
9B33009B33009933029933029934009934009B33009B3300993400993400993302983402
9535039236078F37098E370C8C370E8A3810883813833A17793C1D280000210000190000
1300000B0000040000000000000000000000000002000002000000010000040000080000
0D00001100001200001B0000753D227D3C1C7C3D1C833B15923607993400993400993400
993302993302993400983300993302993302983300993400993302993302993400993400
993400993400993400983300983300993400993302853A13140000000000000000000000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
000000000000000000080000190000793E208E370A993400983300993400993400993400
9933029832019833009934009933029832019B33009A32009B33009B3300983300983300
9833009934009833009934009933029933029B33009B33009A3200993400983300953503
8D36098739127E3C1A773E217240291F00001800001200000F00000D00000B0000080000
0600000400000100000000000000000000000000000000000000000300000B0000150000
2400007C3D1E833A178839128E370C8F37098F3709923607963502993400993400993400
9934009833009B33009A3200983300993400983400973300993400983300983300993400
9933029933029B33009A32009934009934009B3300863812140000010101010000010000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
0000000000000000000A00001D00007D3C1C8E3509993400993400983300993400983300
9933029933029934009833009933029933029B33009B33009B33009B3300993400983300
9833009934009934009733019535059435079235098F360A8C370E89370F873912813B17
793C1D2700002000001900001200000B0000050000000000000000000100000000000000
0000000000000000000000000000000101010000000000000000000300000A0000624537
734025813B198B3810913609943507953503983402993400993400993400993400993400
993400993400993400993400993400993400983300983300983300993400993400993400
9832019933029A32009B33009934009934009A3200863812140000000000010000010000
000000000000D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
0000000000000000000A00001C00007B3C1B8E3509993302993400993400983201993302
9833009934009934009934009A32009B33009933029832019B33009B3300983201993302
9B33009B33009933029535058E370C873912803C19783D1F7240291D0000180000120000
0F00000D00000A0000090000060000040000010000000000000002000002010000010000
0000000000000000000000000000000000000001000001000000000100000300000B0000
1600006D4029763D20803B1A8739128E370A953503993400993400993400993400993400
9B3300983300993302983201983300993400983300993400993400993400993400983300
993400983300993400993400993400993400993302853A13140000000000000000000000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000010101000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D6D6D60000000000000700001500007340258A3810953505983402993400993302993302
9934009934009833009833009B33009B33009832019834029533029435079035088E370C
8D380F8A38108638128239167A3D1E2700002000001900001100000A0000040000010000
000000000100000000000000000000000000000000000000000002000002010000010000
010101000000000000000000000000000000000100000100000000000000000000040000
0B00001200001900002000002700007A3D1E833A17853A13853A1386381189370F8E370C
9435079634039733019834029833009934009B33009B3300983300983300993400993400
9934009934009934009934009934009434028D360B7C3D1E0F0000000000000000000000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000010101000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
010101000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D70000000000000300000700001600007D3C1C8E370A9535039934009B33009A3200
9933029832019833009833009833009934009933029535058E370A863811803B1A783C20
7240291D00001600001200001000000D00000B0000080000060000030000010000010000
000002000002000000000000000000000000000000000000000000000000010101000000
000000000000000000000000000000000000010101000000000002000100000000010000
0400000600000800000B00000D00000F00001200001400001400001600001F0000753D24
843A158F360A9535059834029934009A3200993302993302983201983201983300993400
9833009934009934009934009832018D360B783C20190000080000000000000000000000
000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D70000000000000000000000000B0000240000803A168E370A963403993302993302
9634059435079136098E370A8B380E8A3810863812833A177A3D1E270000200000190000
1200000A0000040000000000000000000100000002000002000100000100000000010000
000002000002000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000100000100000000000000
0000000000000000000000000000000000000000000000000000000400000B0000160000
2400007C3D1E813B178439128739138839128A38108B360D8E370C913609943505953503
9834029834029535039435079136098239181C00000C0000040000000000000000000000
000000D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7000100000100000000070000150000704029813B178E370A963405963405
8E370C873912803C19793E207040291D00001800001200000F00000D00000B0000080000
060000040000010000000000000000000000000000000000000100000100000000000000
000000000000D7D7D7D6D6D6D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000002000002
000000000000010000010000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D8D6D7010000
000002000000000000010101000000000000000000000000000000010000040000070000
0D00000F00001200001400001400001800001F0000724029793E20803C198739128E370A
9535039535038E370A8739127F3A196F3F280F0000030000010000000000000000000000
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D70001000001000000000300000A00001500002400007A3D1E833A17833A17
7C3D1E2700002200001900001200000A0000040000000000010101000002010101000000
000000000000010000010000000000000000000000000000000100000100D7D7D5D7D7D5
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000010101010103000002
000000000000010000010000000000000000000000000000000000000000010000D7D7D7
D7D7D9D6D6D8D7D7D7000000000000000000000000000000000000000000000000000000
0000020000020100000100000000000400000B00001200001900002000002700007A3E1C
833A17833A177A3D1E270000200000150000070000000100000000000000010101D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D8D8D80000000000000100000400000700000D00000F0000120000120000
1100000E00000B0000080000060000040000010000000000000000010101000000000000
010000010000000000000000000000000000000000D7D7D7D6D8D7D5D7D6D7D7D5D7D7D5
D7D5D6D7D5D6010000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000100000100000000000000000000000000
000000000100D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7000000000000000000000100000000
0000000100000000000000000000000100000500000600000800000B00000D00000F0000
1200001200000F00000D00000B0000070000030000000000000000000000000000D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000010101000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000000000000000000000
010000010000000000000000000000000000000000000000000000000000000000000000
010000010000000000000000D7D7D7D7D7D7D8D8D8D7D7D7D6D8D7D6D8D7D7D7D5000000
010000010000010000010000000000000000000000000000000000010100060100070100
070100070100070100070100070100070200070100060100040100030000010000000000
000100000100000000000000000000D7D7D7D7D7D7D7D7D7D7D7D5D7D7D5000201000000
010000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D6D6D6D7D7D7D7D7D9D7D7D9D7D7D7000000000100000100000000000000000000000000
000000000000000000000000000002000002000000000000000000000000000000000000
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7000000000000000000000000000000
000000000000000000000000000000000000000000000000000000060100110200160300
1603001603001603001603001603001603001603001402000E0200080100030000000000
000000000000000000000002000000000000000000000000D7D7D7D8D8D8D7D7D7D7D7D7
010000010000000000000000000000000000000000000000000000000000010000010000
000000000000000000000000000000000000000000000000010000D8D6D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D9D7D7D9D7D7D7D7D7D7D6D8D7000100000000000000000000000000
010101000000000000000000000002000002000000000000000000D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7000000000000000000000000000000000000000000000000000000010101
0000000100000300000401000701000A01000D02000E0200100300140300E3C95BE8C94A
EAC84AEAC84AEAC84AE8C94AE8C94AE8C94AE8C94AE6C953E1C8641803001202000E0200
0B0200080200060100030000010000000000000000000000000000000000000000000000
D8D7D5D8D7D5000000000000000000000000000000000000000000010101010000000000
000000000000000000000000000000000000010101D7D7D7D7D5D6D8D6D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFEFEFEFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFF010101000000000000000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D6D8D7D7D7D7000000000000000000
000000000000000000000000010000D8D6D7000000000000000000000000000000000000
000100000201000000000000000000000000000000000000000000000000000002000002
0000000300000801000E02001403001C0400EBC943EEC930F1CA31F2CA2AF5CB1DF8CB18
F9CA18F9CA18F9CA18F8CB18F8CB18F8CB1AF8CB1AF6CB1CF5CB21F4CA28F1CA2FECC939
E6C84C1B04000F0300080100030000010000000000000000000002000002000000000000
000000000000000000000000000000D7D7D7D7D7D9000000000000000000000000000000
000000000100000100000100000000000000D7D7D7D7D7D7D7D7D5D7D7D5D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000010101000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D6D8D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D6D6D6D7D7D7000000010000000000000000000000000000000000000000000000
0001000001000000000000000000000000000101010100000300000601000A01000E0200
0E0200110300160300E0C866E7C853EFC936F9CC11FFCC00FFCC00FFCC00FFCC00FFCC00
FFCB00FFCB00FFCB00FFCB00FFCC01FFCC01FFCC01FFCC01FFCC00FFCC00FFCD02FCCC0A
F6CB1CEECA36E3C95B1603000F02000A0000030000000000000002000002000000000000
000000000000000000000000000000000000000002000000000000D7D7D5D7D7D7D7D7D7
D6D8D7000100000100000100D7D7D7D8D8D8D7D7D7D7D7D7D8D8D6D8D8D6D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D6D8D7D7D9D8D7D7D7D7D7D7D7D9D8D6D8D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7000000000000000000000000000000000000000100000000000000000000000000
0000000000000000000000000100000100000000020300000801001102001C0400E8C84D
EEC93AF1CA2DF4CA28F5CB21F6CB1CF9CC11FDCC05FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FDCD01FDCC05
FDCD0BF9CB13F5CB1FF1CA31EAC84A190300080100000000000100000100000000000000
000000000000000100000100000000000000000100000100000000000000000000000000
000000D6D6D6D7D7D9D7D7D9D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D6D8D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000
000000000000000000000000000000010101000100000100010101000000000000000000
0000000000000000000100000400000700000A01000E0200160300E3C95BEFC938F8CA1C
FCCC0AFFCC00FFCB00FFCB00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FFCC01FFCC01FECB00FFCC00FDCD01FDCD01
FFCC01FFCC01FFCD00FCCC08F8CA1CEDC9411803000B0200060100010100000100000000
000000000000000100000100030000030000010200000100000000000000000000000000
000000000000000002000002D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D6D8D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D5D7D7D5D7D7D7D7D7D7D7D7D7D7D7D7D7D7D9D7D7D9D5D7D6000100000002000002
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000300000801001102001C0400E8C94AF1CA31F6CB1DFBCB13FDCB0A
FFCB05FFCC01FFCD00FFCC00FFCC01FFCC01FDCD01FDCD01FFCC00FFCC00FDCD00FDCD00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCD00FFCC00FFCC00FFCC01FFCC01
FFCC00FFCC00FFCC00FFCC03FECC09F9CB15F4CA28E7CA4C120300070200030000000000
000000000000000000030000080100090200030000000000010000000000000000000100
000000000000000000000000000000000000D7D7D7D7D7D7D7D7D9D7D7D9D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D6D4D7D7D5D7D7D7D7D7D7D7D7D7D8D6D7D7D7D9010103000000000201000002000000
000000010000030100030100040000030000010000000000000000000000000000000000
0000000300000801000E0200160300E4C85BF0CA39F6CB1CFCCC08FFCC00FFCB01FFCA00
FFCC01FFCC01FFCC00FFCC00FFCC01FFCC01FFCC01FDCD01FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC01FFCC01
FFCC00FFCC00FFCC00FFCC00FFCB00FFCB00FFCC00F6CB1AE6C953140300080200030000
010000000000000000030000080100CFC69B0E02000D02000A0100070100040100010100
010000000000000000000000000000000000000000000000D7D7D9D6D6D8D7D7D7D7D7D7
D8D8D8D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000000000000000FFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D6D6D6D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7000000010000000000000000000000000000000000
0000000402000801000A02000B0200090200030000000000000000000000000000000000
000000080100180400E9CA4BF1CA31F6CA1FF9CB13FCCC0AFCCB02FFCC00FFCC01FECB00
FFCD02FFCC01FECB00FFCC00FFCB01FFCC01FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC01FFCC01FECB00FFCC01FFCC00FFCC00FFCB00FFCB00FFCC01FFCC01FFCC01FFCC01
FFCC00FFCC00FFCC00FFCC00FFCC01FECB00FFCA00FDCB08F6CB1CEAC944140300080100
0300000000000000000100000300000E0200E6C953EAC8431C04001403000E0200080100
030000010000000002000002000000000000000000000000010000010000D8D8D8D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D70000000000000100000100000000000100000601000A0100
0E0300110200140300D6C782D1C796080100030000000000000000010000030100060100
0A0100140300EAC944F6CB1CFCCC0AFFCC01FFCC01FFCD02FFCC00FFCC00FFCC01FFCB01
FFCA03FFCA06FFC706FFC706FFC608FFC608FFC708FFC706FFC708FFC706FFC706FFC805
FFCA03FFCC01FFCC01FFCC01FFCC00FFCC00FFCB00FFCB00FFCC01FFCC01FFCC01FFCC01
FFCC00FFCC00FFCC00FFCC00FFCC01FFCC00FFCB00FFCB00FFCC01F5CB1FE2C75C110200
0601000000000101010000000000000D0200EBC944F4CB25EDC93DE7C853E0C866160300
1202000E01000A0100060100010000000000000000000000010000010000000000000000
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101000000000000000000FEFEFEFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D70000000000000000000000000000000000000601001102001C0400
EBC943EECA36EACA43E0C8640B0200030000010000000000000000030000080100110200
1C0400EBC943F5CB1FFCCC0AFDCC05FFCC01FFCC00FFCB00FFCC01FFCC01FFCC00FFCA03
FFC608FFC20DFFBD12FFBC16FFBC16FFBC16FFBC16FFBC16FFBC18FFBC16FFBC16FFC011
FFC706FFCC02FFCC00FFCD00FFCB00FFCB00FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC01FFCC01F8CA12EECA381C0400
0A01000000000000000000000001000802001C0400EDC93DF4CB25F6CB1CF5CB21F2CB28
F1CA2DEACA431C0400110200060100000000000100000000010000020001000000000100
000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D70000000000000000000000000100000300000701000D0100140300E3C85DEECA38
F9CB13F9CD16ECCB401804000801000000000000000100000300000A0100150200E3C85D
EFC938F6CB1CFCCC0AFECB00FFCC01FFCD02FFCC00FFCA04FFC60AFFC30DFFC20DFFC012
FFBC18DF7C00E67700E97600E97600E77600E97500E77600E97500E77600E77600E27A00
FFBF13FFC508FFCA03FFCC00FFCC00FECB00FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC01FFCC01FECB00FCCC0AF6CB1CEAC946
110300060100010000000000000000040200110200E3C95BF5CB1DFFCC00FFCC00FFCC00
FDCD00F8CC11EECA36E3C95B1403000D0200080200060100030000010000000000000100
000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
000000010101000000000000000000030000080100140200E8C84DF2CA2CF5CB1FF9CB13
FDCC06F2CB26160300080100030000000000000000030000080100150200EAC944F5CB1F
F9CB13FCCC0AFDCC03FFCC00FFCC00FFCC00FFCC01FFC507FFB91AE97600ED7300F17000
F36F00F46E00F76C00F96C00F86B00F76B00F86B00F76B00F86B00F76B00F76B00F36F00
E97500FFBA1AFFC508FFCD00FFCC00FFCC00FFCC01FFCB01FFCC00FFCC00FFCB01FFCB00
FFCB00FFCB00FFCC00FFCC01FFCC00FFCC00FFCC01FECB00FFCB00FFCC03FCCC0AF1CA27
E1C95F0F0300060100000000000000010100060100140300F2CA2CFFCC01FFCB00FFCC00
FCCC00FCCD05F9CC11F5CB1DF0CA2BEAC9441C0400110200070000010000000000000000
000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000
0000000201000300000601000A01000F0200160300E7C853F6CB1CFFCC01FFCC01FCCC0A
F7CC1DE7CA4C0D0100000000000000000000000000070100140200E6C953F6CB1DFDCD01
FFCC01FFCC01FFCC00FFCB01FFC903FFC706FFC30DFFBB18EC7400F76C00FC6800FF6600
FF6801FE6700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FE6700FB6900
F66B00EA7500FFBD15FFC508FFCA03FFCC00FFCC01FFCC01FFCC00FFCC00FFCB01FFCB00
FFCB00FFCB00FFCC01FFCC01FFCC00FFCC00FFCC01FFCD02FFCB00FFCB00FFCC01F9CB13
EECA381B04000A01000100000000000000000000000E0200F1CA31FFCC01FFCB00FFCC00
FFCC00FCCC00FFCC00FFCC00FDCD01F9CB13EFC936E3C85F1202000A0000030000000000
000000010101000000000000000000D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D9D7D7D9
D8D6D7D8D6D7D7D7D7D7D7D7D7D7D5D7D7D5D7D7D7D7D7D7D8D7D5D9D8D6000000000000
0000000300000801001102001D0500EAC84AF1CA31F8CA1CFCCC0AFFCC01FFCC00F6CB1C
E7CA541203000701000000020000000000000000000D0100E8C84DF6CB1CFCCC0AFFCC01
FFCC00FFCC00FFCB01FFCA04FFC508FFBE15E77600F36E00F86A00FC6800FE6700FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FE6700
FC6800F66E00EC7400FFB91AFFC608FFCC01FFCC00FFCC00FFCC01FDCD01FFCC00FFCC00
FFCC00FFCC00FFCB01FFCB01FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC01FDCC06
F9CB13EBC9440E01000100000100000100000000020E0200F1CA31FFCC00FFCC01FFCC01
FFCD00FFCC00FFCC00FFCC00FFCC00FDCC06F9CB13F4CA28EAC948190300080100000000
000100000000000000000000000000000100D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D9D7D7D9
D8D6D7D8D6D7D7D7D7D7D7D7D7D7D5D7D7D5D7D7D7D7D7D7D8D7D5D7D7D5000000000100
0300000A0100150200E4C85BF0CA37F8CA1CFDCB08FFCB00FFCC01FFCB01FFCA03F5C92A
180300080100030000000000000000030000080100160300F2CB28FFCC00FFCC01FFCC01
FFCC00FFCB01FFC706FFC30DFFBD17E67700F76B00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FC6800F76C00EA7500FFBF13FFC806FFCB01FFCC00FDCD01FDCD01FFCC00FFCC00
FFCC00FFCC00FFCB01FFCB01FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC01FFCC01
FFCC01F2CA2C1502000700000300000100000000020F0000F4C63FFFC70FFFC808FFC902
FFCB01FFCC00FFCC00FFCD00FFCC00FFCC00FFCC01FCCC0AF8CA1DEDC9411904000B0200
060100030000010000000000000000000100D7D7D7D7D7D7D8D8D8D6D6D6D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D8D6D7D8D6D7D7D7D7D7D7D7D7D7D7000000000000010100
080100150200EBC944F6CA1FF9CB13FCCC08FFCC03FFCC00FECB00FFCA03FFC608F9C436
140100030000010000010000000000080100180400EBC941F8CC15FFCC00FECB00FECB00
FFCC01FFC806FFC011E07B00EE7400F76C00FC6800FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6701FE6700FC6800F36F00E37B00FFC011FFC806FFCC01FFCC00FFCC00FDCD01FDCD01
FFCC00FFCC00FFCC00FFCC00FFCC01FFCC01FFCC01FFCC01FFCB01FFCB01FFCC00FFCC00
FFCC01F6CC20E4C85D110200060100000000010000120000350000FFBD2FFFC218FFC608
FFCA03FFCC01FFCC01FFCC01FFCB01FFCB01FFCC00FFCC03FCCA09F9CB16F4CA28E8C94C
140300080100030000000000000000000000000000D7D7D7D7D7D5D8D8D6D7D7D5D7D7D5
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D8D6D7D8D6D7D7D7D7D7D7D7000000000000000000060100
110200E3C85DF6CA1FFFCC01FFCC00FFCC00FFCC00FFCA03FFC608FFC211FFBE1DC38110
150000010101010000030000060100110300EAC946F6CB1CFCCC08FFCC00FFCC00FFCB01
FFCA03FFC30DFFB81DED7300FA6A00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600F86A00EC7200FFB81CFFC50AFFCC01FFCC00FFCC00FDCD01FDCD01
FFCC00FFCC00FFCC00FFCC00FFCC01FFCC01FFCC01FFCC01FFCB01FFCB01FFCC00FFCC00
FFCC01F9CB13EECA381C04000A0100000000010000160000C8792CDE7701DE7B00FFBC16
FFC10FFFC60AFFCA03FFCC01FFCB01FFCB01FFCC00FFCC00FFCB01FFCB01FFCC00F6CB1C
E7C853140300070100000000000000000000000000000000D7D7D5D7D7D5D7D7D5D7D7D5
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D70000000000000101010000000A0100
1D0500EFCB39F9CB13FFCC00FDCD01FCCC00FFCC00FFC608FFBA1AE37700DF7603C8792C
150000000000000000060100110200E3C85FF2CB28FCCC0AFDCC03FFCC00FECB00FFCA03
FFC608FFBD16ED7300F86A00FC6800FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6501FE6400FF6501FE6700F86A00EA7500FFC30DFECB00FFCC00FFCC00FFCC00FFCC00
FFCC01FFCC01FFCC01FFCC01FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FFCC00FFCC00
FDCD01FCCC06F9CB13EBC9430D02000000000000001B0000DA7326F46C00F46F00F07000
E97500FFB91AFFC608FFCC00FECB00FFCC00FECB00FFCC00FFCD00FFCC00FFCC00FDCD09
F5CA1BE8C94C0D0100000000000000000000000000000000000100D6D8D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000010101000000000000000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000010000060100120200
EAC946F6CB1CFCCC08FFCC00FCCC00FFCB03FFC608FFBD15EA7400EE7002E0701C3E0000
1500000000000000000A01001C0400EECA38F9CB13FFCD02FFCC00FFCC00FFCD02FFC905
FFC20DE07B00F46E00FE6700FF6600FF6600FF6600FF6701FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6501FF6602FF6403FF6602FF6600F07100FFC10FFFCC01FFCC00FFCC00FFCC00FFCC00
FFCC01FFCC01FFCC01FFCC01FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FFCC00FFCC00
FFCC01FDCD01FFCC00F1CA310F01000000000101011D0000E36F22FF6600FE6700FC6800
F76B00EC7400FFBB15FFC40CFFC706FFCA03FFCB01FFCC00FFCC00FFCC00FFCC00FFCD00
FFCC00F2CB28160300080100030100000000000000000000000100D6D8D7D8D8D8D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000010101000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D8D7D5D8D7D5D8D6D7D8D6D7D7D7D7D8D8D8000000000000000100050200110200E3C85F
F2CB28FCCC08FDCC03FFCC01FFCC01FFC608FFBC19EA7500F56D00F06B0CD8732B320000
1100000000000000000D0200EBC943FBCB13FDCC06FFCC01FFCC01FFCC01FFCC00FFC706
FFBE13E67700F76C00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6602FF6501FF6501F17000FFC00EFFCC01FFCC00FFCC00FFCC00FFCC00
FFCC01FFCC01FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FFCC00FFCC00FFCB01FFCC01
FFCC00FFCC00FFCB01F1CA310F01000100020000001D0000E26E21FF6600FF6600FE6700
FC6800F86A00F36F00E67700FFBE13FFC608FFCA03FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC01F8CB16EBC941180400080100010101000002000002000000000000D7D7D7D8D8D8
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFE010101000000
000000010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D8D7D5D8D7D5D8D6D7D8D6D7D6D6D6D7D7D70000000000000000000802001B0400EECA38
F9CB13FFCC00FFCC01FFCC01FFCC01FFC30DE77600F86D00FC6800EE6C16C7763F220000
0B00000000000000000F0200F1CA31FFCA00FECB00FFCC01FECB00FECB00FFCC00FFC508
FFB81CEE7200FB6B00FF6600FF6701FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6501FF6501FF6602F17000FFC10FFFCC01FFCC00FFCC00FFCC00FFCC00
FFCC01FFCC01FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FFCC00FFCC00FFCB01FFCB01
FFCC00FFCC00FFCB01F1CA310F01000100020000001D0000E26E21FF6600FF6600FF6600
FF6501FF6501FE6700F56D00E57800FFBE13FFC706FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC01FCCC0AF6CB1CE8C94A0F0200030000010000000000000000000000D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D8D7D5D8D7D5D8D6D7D8D6D7
D7D7D7D7D7D7D7D7D9D7D7D9D7D7D7D7D7D70000000000000000000D0200EAC944F9CD14
FDCC06FFCC00FFCC00FFCC00FFCC01FFC20FED7200FC6800FE6700E56E1E2900000B0000
0400000000000001000E0200F1CA31FFCB00FFCC01FFCC01FFCC00FFCC00FFCC01FFC30D
EA7400FA6A00FE6700FF6600FE6700FD6600FF6801FE6700FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6801FE6700FE6700FE6700FE6700F17100FFC10EFECE00FFCC01FFCC01FFCC01FFCC01
FDCD00FFCC00FFCC01FFCB01FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FECB00FFCC00FFCC00F1CA310F01000000000000001D0000E26E21FF6500FF6600FF6600
FF6600FF6600FF6600FC6800F86D00E77600FFC30CFFCB00FFCC00FFCC00FFCC00FFCC00
FFCC00FDCC03FBCB09EFCA31160300080100030000000000000000000000D8D6D7D8D6D7
D8D6D7D8D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000010101FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D8D7D5D8D7D5D8D6D7D8D6D7
D7D7D7D7D7D7D7D7D9D7D7D9D7D7D7000000000000010100070000150200F0CA2BFDCD01
FFCC00FFCC00FFCC00FFCB01FFC806FFBD15F47000FF6501FF6600E26E211D0000000000
000000010100040100140300F2CA2CFFCB00FFCC01FFCC01FFCC00FFCC00FFCC01FFC10F
F07000FF6600FF6600FF6600FE6700FE6700FE6700FE6700FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FE6700FE6700FE6700FC6700FB6800ED7300FFC30DFDCD00FFCC01FFCC01FFCC01FFCC01
FDCD00FFCC00FFCC01FFCB01FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00EFCA310F02000000000000001D0000E26E21FF6500FF6600FF6600
FF6600FF6600FF6600FF6600FF6600F36F00FFBC16FFC508FFCA03FFCC00FFCB00FFCC00
FECB00FFCC00FFCC01F5CA23E0C7630E0200040100000000000000000000010000D8D6D7
D8D6D7D8D6D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF000000
010101000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D8D6D7D8D6D7D7D7D7000000000000060100110200E3C95BF5CB1DFFCC00
FFCC00FFCC00FECB00FFC805FFC011E37A00F46C00FF6600FF6600E26E211D0000000000
010000060100110200E3C95BF6CA1FFFCC01FFCC01FFCC01FFCC00FFCC00FFCC00FFC10F
F07000FF6501FF6600FF6600FF6501FF6501FF6600FF6701FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6501FC6800F76B00E77600FFC30DFFCC01FFCC00FFCC00FFCC01FFCC01
FFCC00FFCC00FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FFCB00FFCB00FFCB00FFCB00
FFCC01FFCC01FFCC00EFCA310F02000000000000001D0000E26E21FF6600FF6501FF6501
FE6700FE6700FE6601FE6601FE6700F96C00EC7400FFBA1AFFC608FECB00FFCD02FFCC01
FFCC00FFCB00FFCB00F8CA1CE7C853140200070000000000000000000000000000D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000010101FEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D8D6D7D8D6D7D7D7D7000000000000070100160300E8CA48F8CB18FFCC00
FFCC00FFCC00FECB00FFC706FFBC16E77600F76B00FF6600FF6600E26E211D0000000000
010000080100160300E8C94AF8CB1AFFCC01FFCC01FFCC01FFCC00FFCC00FFCC00FFC10F
F17100FF6501FF6600FF6600FF6501FF6602FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FB6900F17000FFB61FFFC40CFFCC01FFCC00FFCC00FFCC01FFCC01
FFCC00FFCC00FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FFCB00FFCB00FFCB00FFCB00
FFCC01FFCC01FECB00EFCA310F01000000000000001D0000E26E21FF6600FF6501FF6501
FE6700FE6700FE6601FE6601FE6700FC6800F76B00E77600FFC30DFFCC01FFCC01FFCC01
FECB00FFCB00FFCB00FBCB11EECA381C04000A0100000002000000000000000000D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010101010101000000000000000000000000
000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D6D8D7
D7D7D7D7D7D7D7D7D9D7D7D9D7D7D7000000000000070100160300E8CA48F8CB18FFCB00
FFCC00FFCC00FFCB00FFC706FFBC16E77600F76B00FE6700FF6501E26E231D0000000100
000000070100160300E8C94AF8CB1AFFCB01FFCC01FFCC01FFCC00FFCC00FFCC00FFC10F
F07000FE6700FE6700FE6700FF6501FF6501FE6700FE6700FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6701F86B00EC7400FFBA1AFFC60AFFCC01FFCC00FFCC00FFCC00FFCC00
FFCC01FFCC01FFCC00FFCC00FFCC00FFCC00FFCB01FFCB01FFCC01FFCC01FFCC00FFCC00
FFCB00FFCB00FFCC01EFCA310F01000000020000001D0000E26E23FF6501FE6700FE6700
FF6600FF6600FF6600FF6600FF6600FF6600FC6800ED7200FFC20DFFCC00FFCC00FFCC00
FFCC01FFCC01FFCC00FDCC05F9CB13EBC9430D0200010101000000000000000000D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFEFEFE000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D5D7D7D5
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D70000000000000000000000000E0200
EEC93AFCCC08FFCC03FFCB00FFCC01FFCC01FFCC01FFCC01FFCC01FFCA03FFC608FFC51D
EEC8431A0400080100030000080100160300F0C832FCCC0AFDCC03FFCC00FFCB00FFCB00
FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FFCC01FFCA03FFC709FFBD15EA7500F76C00
FC6800FF6600FF6600FF6600FF6501F46E00FFBB18FFC608FFCA03FFCC00FFCC00FFCC00
FFCC00FFCC00FDCD00FFCC00FFCC01FFCB01FFCC01FFCC01FFCC00FFCC00FFCC01FFCC01
FFCC00FFCC00FFCC00FDCC03FCCC08F4CA26E3C85F1102000601000100000400000D0100
1E0400EECA36F9CB13FFCB00FFCA03FFBF11F17000FF6600FF6600FD6900F76B00EA7400
FFBD15FFC608FFCA03FFCC01FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC01FCCC06
F9CB13EAC9440D0200000000000000000000000000D7D7D5D7D7D7D7D7D7D7D7D7D7D7D7
D8D6D7D8D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000010101000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D70000000000000000000000000D0100
E8C84DF6CB1CFCCC0AFFCC01FFCC01FFCC01FFCC00FFCC00FFCC00FFCB01FFCA03FDC913
F2C92F1F04000A02000100000300000E0200E8C94CF6CB1CFBCC0AFCCC00FFCC00FFCD00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCB01FFCB01FFCA01FFC407FFBE15E57800
F56D00FE6700FF6600FF6600FF6600F17000FFBE10FFCA03FFCB01FFCC00FFCB01FFCB01
FFCC00FFCC00FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FFCC01FFCC01FFCC01FFCC01
FFCB00FFCB00FFCC00FCCC08F6CB1CEAC946120200060100010000030000080100160200
EEC93AF9CC11FDCC06FFCA01FFC608FFBC16F36F00FF6600FF6600F76C00E57800FFBE15
FFC50AFFCA03FFCB01FFCC00FFCC01FFCC01FFCC00FFCC00FFCD00FFCC00FDCD00F8CC13
EDCA381B04000A0100000000000000000000000000D8D6D7D7D7D9D7D7D9D7D7D7D7D7D7
D7D7D9D7D7D9D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8000000000000000000080100
190300EAC840F9CB15FFCB00FFCD00FFCC00FFCC00FFCC00FFCC01FFCC01FFCC01FDCC03
FCCC0AEEC93A0F0300000000000000070200180400EBCA3FF8CC15FFCD00FFCC00FFCC00
FFCC01FFCC01FFCC01FFCB01FFCC01FFCC01FFCC01FFCC01FFCC01FFCB01FFCA03FFC50A
FFBD15E67700F76B00FF6501FE6700F17100FFC10FFECB00FFCC01FFCC01FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FFCB00FFCA00FFCC01FFCC01
FFCC01FFCC01FFCC01F6CA1FE4C85D1102000601000000000000000802001C0400EECA36
F9CB13FFCC01FFCC01FFC706FFBE13E37A00EE7100EE7100E37A00FFBD15FFC50AFFCA03
FFCB01FFCC01FFCC01FFCC01FFCC00FFCC00FFCD02FFCC01FFCC00FFCC00FFCC01F2CA2C
150200060100030000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6000000000000000000070100
140200E6C953F6CB1CFECB00FFCC00FFCC00FFCC00FFCC00FFCC01FFCC01FFCC01FFCC01
FFCC00F1CA2D120200030000000100040200110200E3C95BF4CA1CFFCC00FFCB00FFCC00
FFCC01FFCC01FFCB01FFCB01FFCC01FFCC01FFCC01FFCC01FFCC01FFCC01FFCC01FFCA03
FFC709FFBD15EA7400F76B00FB6800F07000FFBF13FFCA03FFCB01FFCC01FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FFCB00FFCB00FFCC01FFCC01
FDCD01FBCC0AF6CB1CEBC9441502000801000301000000000000000B0200E7C94DF6CB1C
FCCC0AFFCC01FFCC01FFC708FFBC16E37A00E57900FFB81CFFC011FFC608FFCA03FFCC01
FFCC01FFCC01FFCC01FFCC01FFCC00FFCC00FFCC01FFCC01FFCC00FDCC06FBCB13EBC944
0E0100000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D5D7D7D5D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000040100
0E0200E0C864F4CB21FFCC00FFCC00FECB00FFCB00FFCB00FFCC01FFCC01FFCC00FFCC00
FFCC00F2CB28160300080100030000010100060100150200F1CB2CFDCD01FFCC01FFCC01
FFCC00FFCC00FFCB00FFCB00FFCC00FFCC00FFCB00FFCC00FFCC00FDCD00FDCD00FFCC01
FFCA03FFC50AFFBE15E57800F76C00F36F00FFBC16FFC608FFCA03FFCD00FFCB01FFCA00
FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FFCC01FFCC01FFCC01FFCC01FFCC00FFCC00
FFCC00F6CB1CE8C9541502000A01000300000001000001000000000E0200EDCA3AFCCC08
FDCC03FFCC00FFCC01FFC708DB8000DE7E00FFC10FFFC508FFC805FFCB03FFCB01FFCC01
FECB00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC01FFCC01FFCB00FBCB13EFC9381C0400
080200000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000010101000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000030000
080100150400EFCA31FCCC08FECD04FFCC00FFCB00FFCB00FFCC01FFCC01FFCC00FFCC00
FFCC00F5CB21DFC7650E02000401000000000200010E0100EAC944F8CC13FDCC06FFCC01
FFCC00FFCC00FFCB00FFCB00FFCC00FFCC00FFCB00FFCC00FFCC00FDCD00FDCD00FDCD00
FFCC01FFCA03FFC608FFBE15EA7400ED7300DE7D00FFC30EFFC905FFCC00FFCB01FFCB01
FFCC00FFCC00FFCC01FFCC01FFCC00FFCC00FFCC01FFCC01FFCC01FFCC01FFCC00FDCC03
FCCC08EFCA311603000801000300000000000001000001000000000E0200F1CA31FFCC00
FFCC00FFCC00FFCC01FFC806FFC011FFBF11FFC704FFCD00FFCC00FDCD00FFCC01FFCC01
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC01FFCC01FFCB00F6CB1DE4C85B110200
060100000000000000000000000000D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7
000000000000010000030000080100160300F4CA28FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC01FFCC01FFCC01FDCC06F9CB13EBC9430E0100010000010101010000060100110300
EAC946F6CB1CFCCC0AFFCC01FFCC01FFCC01FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCB00FFCB00FFCC00FFCC00FDCD00FDCD00FFCC00FFCD00FFCC00FFCC00FECB00FFCC01
FFCD00FFCC00FFCB00FFCC00FFCC01FDCD01FFCC00F6CB1CE6C953120300070100010101
000000000000000000000000D7D7D7D7D7D7D8D6D7010000000000010000040000120200
F1CA2DFFCC00FFCC01FFCD02FFCC01FECB00FFCC01FFCC01FFCC01FFCC01FFCC01FFCC01
FFCC00FFCC00FFCC00FFCC00FFCC00F9CB13EECA381B0400080200000100000000000000
000002000000D7D7D7D7D7D5D7D7D7D6D6D6D7D7D7D7D7D7D7D7D9D7D7D9D7D7D7D7D7D7
D6D7D9D6D7D9D7D7D9D7D7D9D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000010101000000FEFEFEFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D8D7D7D9D8000000000000
0000000100000300000A0100150200E6C752F6CB1CFFCC00FFCB00FCCB05F9CB13EBC944
0D0200000000000002010103000002000002000000000000000002060100120300E6C953
F6CB1CFFCC00FFCC00FFCC00FFCB00FFCB00FFCC01FFCC01FFCC01FFCC01FFCC00FFCC00
FFCC00F4CA20E1C8640F0300060000010000000000000000D7D7D5D7D7D5D7D7D7D7D7D7
D6D8D7D6D8D7D7D7D7D7D7D5D7D7D7D8D8D8D7D7D7D7D7D70101010000000000000A0200
1D0500EECA36F2CA2AEFC936E4C85B1502000A0100030000000100000000000000000000
000000000000D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D8D7D5D8D7D5D8D6D7D8D6D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7000000000000000000000100010100080200140300E7C853F8CA1CF0C930
0F0100010101010000000000000002D7D7D9D7D7D7000000000000000000000000010000
0300000D01001C0400EECA36F9CC11FFCC00FFCC00FFCB00FFCC01FDCD01FFCC00FFCC00
FFCC00F2CB28160300080100030000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7
D8D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000030000
080100080100040100010101000000000000000000000000000000D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7000000000000010101000000000000000100000100
000000000000000000000000000000D8D8D8D7D7D7D7D7D7D7D7D7D6D6D6D8D8D8000000
000000000000000000030000080100140300EAC944F6CB1CFCCC0AFFCC01FFCC01FFCC01
FFCC00FBCB0FF1CA2D1D05000B0200000002000000000000000000D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000000000000000000000
000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D9D7D7D9D8D6D7D7D5D6
D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D9D7D7D9010000010000000000000000
000000000000000000080100180400DCC871080100000000000002000002000002000002
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D5D8D8D6D7D7D7D7D7D7D8D6D7D8D6D7
D7D7D7D6D6D6D7D7D9D7D7D9D8D6D7D8D6D7D7D7D7D7D7D7D7D7D7D6D6D6D8D6D7D8D6D7
D7D7D7D7D7D7D8D6D7D8D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000
000000000000000000030000080100080100030000000000000000010101010000010000
D7D7D9D7D7D9D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D5D7D7D5D7D7D7D7D7D7D8D6D7D8D6D7
D7D7D7D7D7D7D7D7D9D7D7D9D8D6D7D8D6D7D7D7D7D7D7D7D7D7D7D7D7D7D8D6D7D8D6D7
D7D7D7D7D7D7D8D6D7D8D6D7D7D7D7D7D7D7D8D8D8D6D6D6D7D7D7D6D6D6000000000000
000000000000000000000000000000000000000000000000000000000000010000010000
000002D7D7D9D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000
000000000000000000000000010101010101000000000000000000000000000000000000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000010101000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7000000000000000000010101000000000000000000000000000000000000
000000000000000000D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFE
000000000000010101000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7000000000000000000000000000000000000000000000000000000
000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D8D8D8D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000000000000000000000
000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000010101FFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7000000000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D8D8D8D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D8D8D8000000000000000000000000000000000000000000D7D7D7D6D6D6D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000000000000000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7000000000000000000000000000000000000D8D8D8D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7000000000000D7D7D7D6D6D6D7D7D7D7D7D7000000000000
000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7
D7D7D7000000000000010101000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8
D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D6D6D6
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000000000000000000000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000D7D7D7D7D7D7D7D7D7
D6D6D6D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000000000000000000000
000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8000000000000000000000000010101D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000010101000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000000000000000D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D8D8D8D7D7D7D8D8D8D7D7D7000000000000000000000000000000D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000010101FFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000
000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000
000000000000D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8000000000000D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000
000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7000000000000000000000000000000000000
000000000000D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6
D7D7D7D8D8D8000000000000000000000000000000000000000000000000000000010101
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7000000000000000000000000000000000000000000000000000000000000D7D7D7
D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010101010101000000000000000000000000
000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
010101000000000000FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
000000000000000000000000000000000000000000000000000000000000D8D8D8D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000
000000000000000000000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7000000000000
000000000000000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000
000000000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8000000000000000000000000
000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000
000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D8D8D8000000000000000000000000000000000000
000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFE000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000000000000000
000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000010101
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000000000000000000000
000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFF000000000000000000010101000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7000000000000000000000000000000000000000000000000000000
000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101000000000000010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6
D7D7D7D7D7D7000000000000000000000000000000000000000000000000000000000000
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6
D7D7D7D7D7D7000000000000000000000000000000000000000000000000000000D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7000000000000000000000000000000000000000000000000D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8
D7D7D7000000000000000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7010101D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000000000000000000000FFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7000000000000000000000000010101000000000000D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7000000000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000010101FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7000000000000000000000000000000000000D6D6D6D7D7D7D7D7D7D7D7D7D8D8D8
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
010101000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF010101000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7000000000000000000000000000000000000D8D8D8D6D6D6D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6000000000000010101D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7000000010101000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000D7D7D7D8D8D8D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D8D8D8
D7D7D7D7D7D7000000000000000000000000000000D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D8D8D8D7D7D7D7D7D7D7D7D7000000000000000000000000D7D7D7D6D6D6D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7
D7D7D7D7D7D7000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D6D6D6D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8
D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000D7D7D7D6D6D6D7D7D7D6D6D6
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6
D7D7D7D7D7D7D7D7D7000000000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D8D8D8
D7D7D7D7D7D7000000000000000000010101000000000000000000D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000010101000000010101000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7000000000000000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
000000000000000000000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000000000000000
000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000
000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7000000000000D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7000000000000D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
000000000000000000000000000000000000000000000000000000D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D8D8D8D7D7D7000000D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000000000000000FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D6D6D6D7D7D7
D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFEFEFE000000000000010101000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFEFEFEFEFEFE000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFF000000000000010101000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFEFEFE000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFF000000010101000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000010101000000000000FFFFFF000000000000000000000000
010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000010101000000000000FFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
010101FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000000000000000000000
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFF010101000000010101000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000010101000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFEFEFE000000000000000000000000000000000000000000000000000000000000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FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
010101000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000010101000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFE000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000010101000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFE000000000000FFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000010101010101000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101000000000000000000000000FFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000010101000000000000
000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF000000000000000000000000000000010101000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101000000000000000000000000010101
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFF000000000000000000000000000000010101000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000010101000000000000FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFF000000000000000000010101000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000010101000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000010101000000000000000000000000000000FFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000010101000000000000010101000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000010101000000000000000000FFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFE010101000000000000000000000000000000FFFFFF000000000000FFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE010101000000
000000000000000000000000FFFFFF000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010101000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFF000000000000000000010101000000000000FFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000010101010101FFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000010101010101FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000010101000000000000000000000000000000FFFFFFFFFFFF000000
010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFF000000000000000000000000000000010101FFFFFFFFFFFFFFFFFF010101
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
010101000000000000000000000000010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101000000000000000000000000
010101FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000010101000000000000000000
000000010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE010101000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000010101000000000000010101000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF010101000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
010101000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
010101000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000010101000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
010101000000000000000000000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101000000000000000000
000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF010101000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFEFEFEFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7
D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D7D7D7D7D7D7D7D7D7D7D7D7000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{146, 154.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003K0000ib000`400?l00000o`00003ofoooool0
0=_ooooo003Kooooo`00foooool00=_ooooo003Kooooo`001Oooooo?0?ooo`Oooooo0005oooooll0
oooo1oooool000Goooooc`3oool7ooooo`001Oooooo?0?ooo`Oooooo0005oooooll0oooo1oooool0
00Gooooo>03oool00`2o_kl0kno_0?ooo`030?ooo`030=CDe03_knl0oooo02@0oooo00<0_kno0>o_
k`3oool00`3oool00`3De=@0kno_0?ooo`0N0?ooo`030>[ZjP3?cll0oooo00@0oooo00<0clo?0?oo
o`3oool0>@3oool7ooooo`001Ooooolh0?ooo`030000000E5AD0hn?S0080oooo00<0eMGE00000010
@4009@3oool00`0000005ADE0>?Sh`020?ooo`030=GEe@000000@4100180oooo00<0ZZZZ00000000
00002P0000000`1aLG40000005EEE@030?ooo`03075aL@000000ZZZZ03X0oooo1oooool000Gooooo
>03oool02@10@400X:2P05EEE@3Ogml0oooo071`L0000000P82006YZJP0T0?ooo`090410@02OWil0
EEEE0=oOg`3oool0L71`00000020P800JVYZ00T0oooo00<0`<300?ooo`3oool01P3oool00`10@400
P8200;no_`060;no_`0=0410@000000000000;no_`1`L700UIFE0820P03oool0kno_0000000`<300
P8200;no_`0i0?ooo`Oooooo0005ooooocX0oooo00P0hn?S05EEE@3oool0@4100000003oool0a/K6
0>[ZjRD0oooo00P0hn?S05EEE@3oool0@4100000003oool0a/K60>?Sh`P0oooo00<0P8200?ooo`3o
ool01P3oool00`3EeMD071`L0?ooo`060?ooo`0301`L70000000@41000<0oooo00L0P8200:ZZZP2o
_kl000000820P03oool0_kno03T0oooo1oooool000Gooooo>`3oool0102EUID0a/K60000000i>CTY
0?ooo`0409FEU@36a/H0000003Ti>@/0oooo00<0P8200?ooo`3oool01`3oool00`1EEED0UIFE0?oo
o`050?ooo`80000000<0EEEE0?ooo`3oool00P3oool0100i>CT0P8200000002ZZZXk0?ooo`Oooooo
0005oooooc`0oooo00<0EEEE00000020P800:P3oool00`1EEED000000820P00;0?ooo`030820P03o
ool0oooo00L0oooo00<0j^[Z030`<03Zj^X0103oool0102o_kl000000000002@T9040?ooo`040=GE
e@0P820000000=oOgc/0oooo1oooool000Gooooo?03oool00`1aLG4000000<K6aP0Z0?ooo`03075a
L@000000a/K600/0oooo00<0P8200?ooo`3oool0203oool00`2EUID0LG5a0?ooo`030?ooo`040820
P000000000000;no_`D0oooo00<05ADE01`L703oool0>`3oool7ooooo`001Oooooll0?ooo`0301DE
5@0@4100_kno02X0oooo00<05ADE010@402o_kl02`3oool00`20P800oooo0?ooo`080?ooo`030>o_
k`0[:b/0_kno00<0oooo00@0H61P000000000000kno_103oool0102o_kl000000410@03_knlk0?oo
o`Oooooo0005oooooc/0oooo00D0eMGE0000001EEED0EEEE0>[ZjP0X0?ooo`050=GEe@000000EEEE
05EEE@3Zj^X0103oool00`2ZZZX0EEEE05EEE@0305EEE@0302/[:`1EEED0EEEE00<0EEEE1P3oool0
0`36a/H0@4100?ooo`020?ooo`030410@000000071`L00D0oooo00@0LG5a0000002ZZZX0P820>`3o
ool7ooooo`001Ooooolk0?ooo`07061PH0000000T92@0>[ZjP10@400Jf][051@D00V0?ooo`08061P
H0000000T92@0>[ZjP10@400Jf][0410@03Ogml70?ooo`030820P03oool0oooo00X0oooo00@0H61P
09FEU@3oool0oooo0P0000000`1ZJVX0oooo0?ooo`020?ooo`080<o?c`0E5AD0410@0?ooo`20P800
JVYZ051@D02EUIDh0?ooo`Oooooo0005ooooocT0oooo00T0ZZZZ01`L7000000000000>[ZjP3oool0
_kno0000000E5AD0903oool01`2ZZZX071`L000000000000j^[Z0?ooo`2o_kl00P0000000`3EeMD0
oooo0?ooo`050?ooo`030820P03oool0oooo00X0oooo00@0j^[Z0000003Zj^X0a/K60P0000001@2Z
ZZX0oooo0?ooo`3oool0EEEE0080000000H0JVYZ0?ooo`3oool0EEEE0000001aLG4h0?ooo`Oooooo
0005oooooc/0oooo00<0kno_0=CDe03oool00P3oool00`3Zj^X0gmoO0?ooo`0U0?ooo`030>o_k`3D
e=@0oooo0080oooo00<0j^[Z0=CDe03oool01`3oool00`20P800oooo0?ooo`0;0?ooo`0309FEU@1P
H600UIFE0080000000<0j^[Z0?ooo`3oool00`3oool00`3De=@0kno_0?ooo`020?ooo`030<o?c`3o
ool0oooo03L0oooo1oooool000GoooooM`3oool00`20P800oooo0?ooo`0<0?ooo`0402/[:`0L71`0
000001`L74D0oooo1oooool000GoooooM`3oool00`20P800oooo0?ooo`0<0?ooo`040;no_`000000
000006YZJTD0oooo1oooool000GoooooQ`3oool00`1EEED000000:ZZZP150?ooo`Oooooo0005oooo
ohL0oooo00<0hn?S0000003Rh^80A@3oool7ooooo`001Ooooon80?ooo`030:n_[`3oool0oooo04@0
oooo1oooool000Goooooc`3oool7ooooo`001Oooooo?0?ooo`Oooooo0005oooooll0oooo1oooool0
00Goooooc`3oool7ooooo`001Ooooolo0?ooobT0ZZZZ00<0eMGE0?ooo`3oool0I03oool7ooooo`00
1Ooooolo0?ooo`030000000f=SH0=SHf02D0=SHf00<04Q8B0820P03oool0I@3oool7ooooo`001Ooo
oolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo
0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?oo
o`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`03
0000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000
003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003G
emL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0
emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG
02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0
emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG
00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0
B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q8
0820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820
P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03o
ool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0
I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3o
ool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7
ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7oooo
o`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`00
1Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooo
oolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo
0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?oo
o`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`03
0000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000
003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003G
emL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0
emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG
02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0
emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG
00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0
B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q8
0820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820
P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03o
ool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0
I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3o
ool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7
ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7oooo
o`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`00
1Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooo
oolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo
0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?oo
o`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`03
0000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000
003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003G
emL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0
emOG02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG
02D0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0
emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG
00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0
B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q8
0820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820
P03oool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03o
ool0I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0
I@3oool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3o
ool7ooooo`001Ooooolo0?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03oool0I@3oool7
ooooo`001Ooooolo0?ooo`0;0000003GemL0emOG0=OGe`2RXJ40=SHf008000000000=SHf055AD@2Q
XJ40203GemL01P3HemL0emOG0=OGe`3HemL0emOG0=OHe`@0emOG00P0aLG509BDU01/K6`0DE5A02@T
90000000=SHf0<G6a@<0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`080000
003GemL0emOG0:NWY`0100006P`906`m:@0H2@L30000000402@T902WYjL0emOG0=OGeP<0emOG01<0
emOF0=OGe`3GemL0emOG0=OHe`3GemL0emOH0=OGe`3GemH0_ko005YJFP0000000@0100000@080000
@R@I038H4003000061PH00<0emOG00<0B4Q80820P03oool0I@3oool7ooooo`001Ooooolo0?ooo`0A
0000003GemL0emSG03Hf=P0@1`H0/f4i0<aV=02iHcP0=A`C00<0000l6Pd0:@l700@0000Y:BT0K6a[
08N6Q`35aLD01@3GemL0403GemP0emOG0<[:bP2?T8l0A4A30000000?1080<a<802@@2@020000OD<Z
0<YW=@39IcH0RDT]00D0001/K6`20=OGe`0304Q8B020P800oooo06D0oooo1oooool000Gooooo?`3o
ool050000000emOG0=OGe`010000J3HR0<aW=@3<Ic<0cFLc0:eN>@070040EAl909@e1@1_;0d0=Q@:
00X000040040000106a/K03GemL0f=OF0P3GemL02`2c/k@0B4Q80000000400407`X505@O2@26<PP0
US@402/?1P0<0000`VXn0080cFHd00<0bfLe05Pa8P0U92D00P3GemL00`18B4P0P8200?ooo`1U0?oo
o`Oooooo0005oooooc40oooo00<0SXj>0?ooo`3oool02`3oool08P000000emOG0;>d/`050000]V4g
0<aV=@3<Ic<0cFLd0;mZ@00:0000=a@909Ld0`2I<`40USD3098e201_:``0:0d500<000000000<30`
04Q8B00000400@0000h0000e50L0Kb`>09@e1@2H=080VC@109Hd100Y3`L0@b@H0<]W=03<IS@20<aW
<`0608A8;`020000emSG0=OGe`18B4P0P8209`3oool00`2ZZZX0j^[Z0?ooo`0l0?ooo`Oooooo0005
oooooc40oooo00<0EEEE0=oOg`3oool02`3oool030000000emOG08N7Q`070000aVPk0<aW<`3<IS@0
cFHd0:AI=@050000Fb0809Tc0@80VC@001P0VC@109He0`1g;`d09a0;0000000200005`P303lH2@1Q
8PP0T3H:09Pd0P2I=000VS@009Td002I=040USD3038B1`0I2@L0a6Tk0<aW<`3<Ic@0c6Lc08E8;`03
00020=OGe`0304Q8B020P800oooo02H0oooo00<0ZZZZ0:2PX03oool0?03oool7ooooo`001Ooooola
0?ooo`0305EEE@20P800oooo00/0oooo01X000000=OGe`2QXZ800P0008I7:`3<Ic@0c6Hd0<UX=`1K
<B002000084a2`2H<`40UCD308Pb201P9Pd0:Pl600P000060000:0h705LO2@2A=@P0VC<109Xd002I
=040VS<109Tc0@@0VC@000P0IR@900H00027Ab/0bfLc0<aW<`3:IcD0Ec4Q01<B4P80emOG00<0B4Q8
0820P03oool09P3oool00`2ZZZX0@4100?ooo`0l0?ooo`Oooooo0005oooooc40oooo00<0EEEE020P
803oool02`3oool0:P000000emOG0=OGe`0T92@04@L507@n9P26Ab`0CBTK00@000106P/0NRh:04`L
1P0X3`P02P00020:1@146@L0I2D:08/b1`2G=0@0V3@109Td002I<`40VS<109Td002I=040VC@009Xd
002J<`40VC@109Tc0@2F=0@0=Q<801471@1d?bL0QDL/04/Y6`050000K6a/0=SGe`3GemL0B4Q80820
P2L0oooo00<0ZZZZ0000003EeMD0?03oool7ooooo`001Ooooola0?ooo`0305EEE@000000a/K600/0
oooo01H000000=OGe`3Gf=L0_ko002@T900100000`000000000400003@H500D0000D1@<0@QX:06hZ
302E=@@0V3@109Tc0P2I=040VS<109Td002J=000VC@00P2J=0403@2J<`40VC@009Td0@2J<`40VC@0
09Tc0@2?=PX0DB0<0000000100000P000000001PH6000`3GemL00`18B4P0P8200?ooo`0V0?ooo`03
0:ZZZP000000LG5a03`0oooo1oooool000Gooooo<@3oool00`1EEED0000005EEE@0;0?ooo`030000
003GemL0emOG0080emOH00X0XJ:Q07imO@0000000`0002T?1P1K8@T0Rc8809Td0@2I=000VC<10`2J
=0403P2J<`80VS<009Td002I<`80VS<009Td0@2J=000V3@1090g2@1`:@L0CAd:02T>1@0A10801000
0P000000201/K6`0[jn_0=OGe`3HemL0emOH0=OGe`18B4P0P8209`3oool0102ZZZX0000001DE5@3_
knlk0?ooo`Oooooo0005oooooc40oooo00@0EEEE02/[:`000000j^[Z2P3oool00`000000emOG0=OG
e`030=OGe`0:092?T0010000@A/<09Hd102I<`80VC@009Td0@2J<`00VC@109Xd0080VC@10140VC@0
09Pc002J<`40Uc@309De1@22<@T0Eb8<038C1`0=00000P0000D00@0G1`D0@aT:06DT1`0X3`L00000
0;no_`050=OGe`0304Q8B020P800oooo02H0oooo00@0ZZZZ02/[:`000000ZZZZ>`3oool7ooooo`00
1Ooooola0?ooo`0405EEE@1`L7005ADE0:2PX0X0oooo00<000000=OGe`3GemL00`3GemL00`1JFUX0
3P@308Hb2P0209Td000H09Xd0@2I<`40VS@009Td002J=040VC@109He0`2D=@H0OBd805lS200e4`L0
5`P400H0000?1080:Pl604`L1P1I80L0NR`:09Dd1@2H=080VC@106PV20000000K6a/1@3GemL00`18
B4P0P8200?ooo`0V0?ooo`040:ZZZP10@400@410061PH3/0oooo1oooool000Gooooo<@3oool0101E
EED0P820075aL@10@40:0?ooo`030000003GemL0emOG00<0emOG01D0B4Q802P?1`2E=@<0VC<109Td
002J<`40VS<009Tc0@2D=@H0Pc<<068U2@0f50X02P0000@00@02000000000040000T3`X0Q3XF09@e
1@2I=0000P2I<`001P2I=000VC@109Xc001c:0D00@0004Q8B0D0emOG00<0B4Q80820P03oool09P3o
ool0102ZZZX0@4100<K6aP00000k0?ooo`Oooooo0005oooooc40oooo00D0EEEE0820P03Zj^X00000
0>[ZjP090?ooo`030000003GemL0emOG00<0emOG00`0XJ6Q00`40P1g;`h0V3@3090f2@1j;0P0FR09
03TF2@0L2PD01`410040000Y:BT205YJFP0?03Hf=P0T92@0=SHf01@B4P0:000090l6034B1P1U9@P0
M2P508hg2`2F=@<0TcH6040I2P000000Shn?00D0emOG00<0B4Q80820P03oool09P3oool01@2ZZZX0
@4100?ooo`0P8200UIFE03X0oooo1oooool000Gooooo<@3oool01@1EEED0P8200?ooo`10@400LG5a
00T0oooo00<000000=OGe`3GemL0103GemL03@0f=SH02P00030D2@0?00001000000000010000<30`
07enO@2WYjH0FUYJ000000010@000P02000030020@00<30`05YJFP1gMgL092@T00000@0200002`00
02T?1P0J1`<00`00061PH0H0emOG00<0B4Q80820P03oool09P3oool01@2ZZZX0@4100?ooo`1ZJVX0
71`L03X0oooo1oooool000Gooooo<@3oool01@1EEED0P8200?ooo`2EUID071`L00T0oooo00<00000
0=OGe`3GemL0103GemL05P35aLH0Gf1P0000000000004Q8C030`<01/K6`0B4Q8018B4P0000401@40
03`^3@1aFaL0Z8LQ0:N88@2BMb00Dd@D00H100000000B4Q8030`;`0T92@30000000305YJF@3GemL0
emOG00D0emOG00<0B4Q80820P03oool09P3oool01P2ZZZX0@4100?ooo`2o_kl000000=GEeCT0oooo
1oooool000Gooooo<@3oool01P1EEED0P8200?ooo`3Ogml000000;no_`P0oooo00<000000=OGe`3G
emL01@3GemL00`3GemP0QhN702@T90030000000500<00013=100ZXPF0=bb5@3mc0P00`3oc000303o
c040oL`50=^b5`1GA1400P41000000020@004Q8B03Hf=P1JFUX0b/[:0=OHe`H0emOG00<0B4Q80820
P03oool09P3oool01P2ZZZX0@4100?ooo`3oool05ADE0820P3T0oooo1oooool000Gooooo<@3oool0
1P1EEED0P8200?ooo`3oool0EEEE06YZJPP0oooo00<000000=OGe`3GemL00`3GemL02`3GemH0XJ6Q
01PH60030@007aL>01DA3@0000006Q860<6N803lc0/0ol`10080olX300<0olX20?o<0@3oc0000P3o
c0402P3oc000o//407iV6@010000?C<J079K700J4PT00P01018B4P1hMgP60=OGe`0304Q8B020P800
oooo02H0oooo00H0ZZZZ0410@03oool0oooo08j>SP0[:b/i0?ooo`Oooooo0005oooooc40oooo00H0
EEEE0820P03oool0oooo0;no_`0P82080?ooo`030000003GemL0emOG00<0emOG00`0K6a/010>3P11
<a00_ITG08mg8`030000@c<?0=^b5P3ob`80o;L70?^H1@3gPPD20?N11P030?VU1`3ob`40ol`10080
ol`000/0ol`10>bo400^8`d010400<nZ7@3kc0d0ZXTD048d3`02000092@T0:n_[`040=OGe`0304Q8
B020P800oooo02H0oooo00L0ZZZZ0410@03oool0oooo0>[ZjP000000eMGE03P0oooo1oooool000Go
oooo<@3oool00`1EEED0P8200?ooo`020?ooo`0302/[:`2ZZZX0oooo00H0oooo00<000000=OGe`3G
emP00P3GemL02`1hN7L01@400:R8803lb`/0e:PC00D0000J4PH0nL/D0?o:0`3fX0P0nVT000@0ofH0
0100nfT00?RY2@3oc040o/`00?o<0@3oc000ol`10<:N7@030000UVhC0?o:103oc000nl/@079K5P05
0@0092@T103GemL00`18B4P0P8200?ooo`0V0?ooo`030:ZZZP10@400oooo0080oooo0P1EEEDh0?oo
o`Oooooo0005oooooc40oooo00<0EEEE0820P03oool00P3oool00`20P800@4100?ooo`060?ooo`0?
0000003GemL0emOG0=OGe`2RXJ400`40099g8@3mb`D0nk0809YC30030000_9TJ0?o<0@3iZ`P0o6P0
00D0ofH000@0ofH10?Qb0`3obP@0ol`00P3oc0402`3oc000o<`9038V2`2SBP`0n8850?bi1P3ob`40
o/`30:N86P030@00B4Q800<0emOG00<0B4Q80820P03oool09P3oool00`2ZZZX0@4100?ooo`020?oo
o`030:2PX0000000j^[Z03L0oooo1oooool000Gooooo3P3oool00`3EeMD0ZZZZ0:ZZZP0P0:ZZZP03
03Ti>@20P800oooo0080oooo00<0eMGE00000036a/H01P3oool040000000emOG0=SGe`3GemL0FUYJ
03d^303kc0/0olT50?Q/001E9@`01P400?c;303oc000nXP50?iV003oI`040?mV00030?mW003iJP00
olX40080ol`10`3oc0002P10<`d0ZTH;0?mV003jJP00o;T60?o<003mc0H0E4@F00000036a<D20=OG
e`0304Q8B020P800oooo00<0oooo00<0a/K60:ZZZP2ZZZX0802ZZZX00`1aLG40@4100?ooo`020?oo
o`030>[ZjP000000LG5a03L0oooo1oooool000Gooooo3P3oool00`20P8005ADE0410@00Q0410@003
0:2PX03oool0oooo0080oooo00<0@41005EEE@3oool01@3oool040000000emOG0=OHe`3HemP0:RTX
0:J88P3oc000nK870?aX001070T0ET@J0?g<203oc000nX440?mU0@3oI`050?mV00030?J21P3obP<0
ol`100<0ol`100H0o/`3040c3P2[A``0ofL10?mV0@3iQ`D20?o<0@0309mo5@000000XJ6Q0080emOG
00<0B4Q80820P03oool00`3oool00`1EEED000000410@00Q0410@003071`L03oool0oooo0080oooo
00<0JVYZ01DE5@3_knl0=P3oool7ooooo`001Oooool>0?ooo`030820P01EEED0oooo02H0oooo00<0
ZZZZ0000003Zj^X01@3oool040000000emOG0=OGf03GemH00P000:N8803oc000nK470?aX000o70P0
Ed@I0?g<1`3oc000nIP80?mV003oIP440?mV00030?]Y003hZ@P0ol/200<0ol`000@0ol`10?G;7P0A
0@00e60G0P3oIP002P3kO`@0ol`00?o<002oV@`000000:6QXP3GemP0emOG04Q8B020P8040?ooo`03
05EEE@000000oooo02H0oooo00<0hn?S0000002ZZZX0=P3oool7ooooo`001Oooool>0?ooo`030820
P01EEED0oooo02L0oooo00<071`L0:ZZZP3oool0103oool03`000000emOG0=OGe`3GemH00P000:N8
803oc000n[X70?]Y001F9@d0Ed@I0?g<1`3ob`00nJX50?iW00020?mV00060?mW003oIP00ofH00?R9
1P3nb`80old1103oc0402`32WQ`0=A<70?QX203oI`00ofH00?RB1P3oc000ol/00;nI3P000000aLG5
0080emOG00<0B4Q80820P03oool00`3oool00`1EEED000000?ooo`0W0?ooo`0303Ti>@1ZJVX0oooo
03D0oooo1oooool000Gooooo3P3oool00`20P800EEEE0?ooo`0W0?ooo`030820P01@D500oooo00@0
oooo01H000000=OGe`3GemL0emOG00400@2BMb00ol`00?o:0`3fRPL0OcPA05I46P3mc0L0ol`00?o9
1@3gN`<0ofH10?iW003oIP00ofH10?Md0P3n`PL0o/d10`3oc040203nc@00k;l@02lS3@2??Q40ofH0
0?mV0@3lJ@00nkP60P3oc0000`2?LaP092@T0=OGf0020=OGe`0304Q8B020P800oooo00<0oooo00<0
EEEE0000003oool09`3oool00`2ZZZX0410@0?ooo`0e0?ooo`Oooooo0005ooooo`h0oooo00<0P820
05EEE@3oool0:03oool00`000000oooo0?ooo`030?ooo`0@0000003GemL0emOG0=OGe`0g=SH0?Bh<
0?_<2`3oc040oK`80:=K4@060@00o<`<0?o<0@3oc000n[890?]Y0080ofH000<0nfT00?Zb2P3oc000
0P3oc0420?o<000A0?k<0P20IQD00`000;iG303oIP00oVL00?J:1`3obP<0ol/10?g<1P10<`l0B4Q8
0=OGe`3GemH0emOG04Q8B020P800103oool00`1EEED000000?ooo`0X0?ooo`0301DE5@2ZZZX0oooo
03@0oooo1oooool000Gooooo3P3oool00`20P800EEEE0?ooo`0X0?ooo`03051@D020P800oooo00<0
oooo01D000000=OGe`3GemL0emOG07UjN@050@00cjXK0?o<0@3ob`40eIXI00P2003K/QP0ol`00?o<
0@3ob`80n9<70?iW003oI`00m8<50?o:0`3oc0400`3oc000203oc040i[/D01@=1P1FA1@0mjH@0?mV
0@3hMP<0oL860P3oc000103AZQP01@4008n?S`3GemP20=OGe`0304Q8B020P800oooo00<0oooo00<0
EEEE0000003oool0:03oool00`1PH600:b/[0?ooo`0d0?ooo`Oooooo0005ooooo`h0oooo00<0P820
05EEE@3oool0:03oool00`2ZZZX071`L0?ooo`030?ooo`0=0000003GemL0emOG0=OGe`2c/k<00000
08ia603oc0<0ol`00?_:4P0T5`T0K5DB0?g<0`020?o<00060?o9103eR`H0oVL00?^W1`3ob`40ol`0
0`3oc0403P3lc0X0Ed@G01XA203O]AD0nJX60?YZ003k/0P0ol`10?o<003lc0H0LU/J0000003GemL0
emOH0P3GemL00`18B4P0P8200?ooo`030?ooo`0305EEE@000000oooo02P0oooo00<0_kno0000003E
eMD0=03oool7ooooo`001Oooool>0?ooo`030820P01EEED0oooo02P0oooo00<0kno_01DE5@2o_kl0
0`3oool00`000000emOG0=OGe`020=OGe`0802@T9013<aD0o<`90?o<003oc080JUDG02<K2P3jc103
0?o<0@050?o:1@3hSPH0mj870?o<0P3oc0000P3oc040203oc080WWlI00<1001_FA40o/`30?FX203k
^@P0ol`20P3oc0400`3@ZA`01@4003Hf=P040=OGe`0304Q8B020P800oooo00<0oooo00<0EEEE0000
003oool0:@3oool00`0E5AD0P8200?ooo`0c0?ooo`Oooooo0005ooooo`h0oooo00<0P82005EEE@3o
ool0:@3oool00`1aLG40JVYZ0?ooo`020?ooo`030000003GemL0emOG0080emOG00P0Shn?00@0003A
ZAT0ol`00?o;0@33WQl0104008ea6P@0ol`000d0olT40>nT2@3ob`80ol`00?k<003oc040gKDJ01TB
1P000000JeD@0?k<0`3ob`40ol`10080ol`000@0oL`803h^30000040OWin0P3GemL0103He]L0emOG
04Q8B020P8040?ooo`0305EEE@000000oooo02T0oooo00<0SXj>02/[:`3oool0<`3oool7ooooo`00
1Oooool>0?ooo`030820P01EEED0oooo02T0oooo00<0eMGE020P803oool00P3oool00`000000emOG
0=OGe`030=OGe`08018B4`1C@0h0oL`70?o<0@3lc0T0@S<?01/B1P3Y_aL30?o<000;0?o<0@3obP80
ol/10?o=0@3oc040jklC01/B1@0>3Ph0B4Q802<J303kc0`00`3oc0401@3oc000_ITE00<1000B4Q<0
bL[:00<0emOH00<0emOG04Q8B020P800103oool00`1EEED000000?ooo`0Y0?ooo`030>[ZjP000000
eMGE03<0oooo1oooool000Gooooo3P3oool00`20P800EEEE0?ooo`0Z0?ooo`050410@02ZZZX0oooo
0?ooo`0000001@3GemL02`1gMgL00`000<6N8P3oc040ol`00:Z85@020000K5DD0?k<0@3oc040ol`0
0080ol`10P3oc000203nc0@0JeHB0000001mOWh0_kno00<00033WQh0ol`00P3oc040103nc0D0E4@D
0000002WYjL20=OGe`050=OGf03Ff=P0emOG04Q8B020P800103oool00`1EEED000000?ooo`0Z0?oo
o`80EEEE<`3oool7ooooo`001Oooool>0?ooo`030820P01EEED0oooo02X0oooo00D0X:2P0410@03o
ool0oooo000000050=OGe`0;0=OGf00K6a/06a860>^o503nc@00o<`;04@c3P0C3@D0d:XF0?o<0@3o
c0000`3oc0403P3oc000i[XF01@>1P0f=SH0emOG0=OHe`0Z:BP0OVHJ0?o<003oc040oL/807mV6003
0@00FUYJ1P3GemL00`18B4P0P8200?ooo`030?ooo`0305EEE@000000oooo02X0oooo00<0X:2P0000
003_knl0<P3oool7ooooo`001Oooool>0?ooo`030820P01EEED0oooo02X0oooo00D0j^[Z0000003E
eMD0oooo000000060=OGe`0;092?S`000000JeDG0?k<1P3oc000g;@L00H1000R60T0nL/A0?k<0@3o
b`000P3oc0003@3oc040SG8K0040002o_kl0emOH0=OGeP0f=SH0ED@@0?o<0@3oc080Z8PJ0080000f
=SH01`3GemL00`18B4P0P8200?ooo`030?ooo`0305EEE@000000oooo02X0oooo00<0j^[Z0000002E
UID0<P3oool7ooooo`001Oooool>0?ooo`030820P01EEED0oooo02/0oooo00@0EEEE09FEU@3oool0
00001P3GemL02P3HemL0B4Q800@10032WQX0ol`10?[;4P0/8Ph00@00081W5P3mc0@20?o<00040?o<
0@3nc080E4@B03Hf=`80emOG00P0emOH03Lf=P2<LA`0o/`30=bd7P0J4@H000000:6QX@L0emOG00<0
B4Q80820P03oool00`3oool00`1EEED000000?ooo`0[0?ooo`80EEEE<P3oool7ooooo`001Oooool>
0?ooo`030820P01EEED0oooo02/0oooo00@0_kno0410@03oool000001`3GemL02P35aLD0:2TY01XB
1`3<YAD0n/`@02@J2000004010400;^I703nc0<20?o<0@0>0>Zo5`090@00K6a[0=OGe`3Gf=L0aLG5
0081002hV2/0T7<H00D1000K6a/0XJ6Q0=OGe`3HemL60=OGe`0304Q8B020P800oooo00<0oooo00<0
EEEE0000003oool0:`3oool00`2o_kl0410@0>[ZjP0a0?ooo`Oooooo0005ooooo`h0oooo00<0P820
05EEE@3oool0;03oool00`0E5AD0hn?S000000060=OGe`0@0=OGf03GemL0aLG501PH600I4PL0gKDK
040c3017B4P04Q8B00H0002nVAL0ol/00?o<0@31V@/00P0006]/K080emOG00P0H61P0080001DA1l0
0P0001PH6035aLD0emOF0=OGf0L0emOG00<0B4Q80820P03oool00`3oool00`1EEED000000?ooo`0/
0?ooo`0301DE5@2ZZZX0oooo0300oooo1oooool000Gooooo3P3oool00`20P800EEEE0?ooo`0[0?oo
o`040;no_`10@400oooo000000T0emOG0100/k>c00h>3P0H4@L040d604Q8B02_[jl04Q8B038W3@3U
^aD0ol`20?S;6@0:0@00DE5A0=OGe`3:b/X04Q8B0P0000000`1ADE40aLG50=OGe`090=OGe`0304Q8
B020P800oooo00<0oooo00<0EEEE0000003oool0:`3oool00`2o_kl0410@0>[ZjP0a0?ooo`Oooooo
0005ooooo`h0oooo00<0P82005EEE@3oool0:`3oool0101EEED0UIFE0?ooo`00000:0=OGe`0A0:6Q
XP000000000001PH603GemP0_kno018B4P0R5`P0`IhP0?c<1`1EA1@0=SHf0=OGe`1/K6`00000018B
4P2?Shl0303GemL00`18B4P0P8200?ooo`030?ooo`0305EEE@000000oooo02/0oooo0P1EEEDb0?oo
o`Oooooo0005ooooo`h0oooo00<0P82005EEE@3oool0:P3oool01@3Ogml000000=oOg`3oool00000
00X0emOG0100f=OG0:6QXP0Y:2T000010=OGe`3GemH0[jn_018B4P050@00WGlI0;ZH9P030@00aLG5
00h>3P1JFUX0_;bl3@3GemL00`18B4P0P8200?ooo`030?ooo`0305EEE@000000oooo02X0oooo00<0
gmoO0000002PX:00<P3oool7ooooo`001Oooool>0?ooo`030820P01EEED0oooo02X0oooo00D0UIFE
05EEE@3oool0oooo0000000?0=OGe`090=SFe`3GemL0_ko001PH60020000E4@O00810@1PH600aLG5
00l0emOG00<0B4Q80820P03oool00`3oool00`1EEED000000?ooo`0Z0?ooo`0309FEU@000000oooo
0380oooo1oooool000Gooooo3P3oool00`20P800EEEE0?ooo`0Z0?ooo`05030`<02o_kl0oooo0?oo
o`0000004P3GemL00`35aLD0=SHf00000002000000030:6QX@3GemL0emOG00d0emOG00<0B4Q80820
P03oool00`3oool00`1EEED000000?ooo`0Z0?ooo`030410@01ZJVX0oooo0380oooo1oooool000Go
oooo3P3oool00`20P800EEEE0?ooo`0Y0?ooo`030<K6aP0[:b/0oooo0080oooo00<000000=OGe`3G
emL04P3GemL0101OGel000000000000T92@?0=OGe`0304Q8B020P800oooo00<0oooo00<0EEEE0000
003oool0:@3oool00`3Shn<000000>?Sh`0c0?ooo`Oooooo0005ooooo`h0oooo00<0P82005EEE@3o
ool0:@3oool00`1aLG40JVYZ0?ooo`020?ooo`030000003GemL0emOG01<0emOG00@0OWin00000000
0000MgMg3P3GemL00`18B4P0P8200?ooo`030?ooo`0305EEE@000000oooo02T0oooo00<0SXj>02/[
:`3oool0<`3oool7ooooo`001Oooool>0?ooo`030820P01EEED0oooo02P0oooo00<0kno_01DE5@2o
_kl00`3oool00`000000emOG0=OGe`0;0=OGe`040<G5a@3GemL0emOG0=OGe`80XJ6Q00L0[jn_0=OG
e`3GemL0/k>c02TY:@0B4Q80_;bl00d0emOG00<0B4Q80820P03oool00`3oool00`1EEED000000?oo
o`0Y0?ooo`0301DE5@20P800oooo03<0oooo1oooool000Gooooo3P3oool00`20P800EEEE0?ooo`0X
0?ooo`030:ZZZP0L71`0oooo00<0oooo00<000000=OGe`3GemL02`3GemL01018B4P0Shn?04Q8B00f
=SH208n?S`0306a/K00`<300Shn?0080emOG00<0Shn?0<G5a@3GemL0303GemL00`18B4P0P8200?oo
o`030?ooo`0305EEE@000000oooo02P0oooo00<0_kno0000003EeMD0=03oool7ooooo`001Oooool>
0?ooo`030820P01EEED0oooo02P0oooo00<0D51@0820P03oool00`3oool00`000000emOG0=OGe`0;
0=OGe`0305YJFP000000Shn?00@0emOG00<0a/K602TY:@1/K6`0403GemL00`18B4P0P8200?ooo`03
0?ooo`0305EEE@000000oooo02P0oooo00<0H61P02/[:`3oool0=03oool7ooooo`001Oooool>0?oo
o`030820P01EEED0oooo02P0oooo00<000000?ooo`3oool00`3oool00`000000emOG0=OGe`0;0=OG
e`0308n?S`18B4P0emOG00D0emOG00<0T92@0000002c/k<03`3GemL00`18B4P0P8200?ooo`030?oo
o`0305EEE@000000oooo02P0oooo00<05ADE0:ZZZP3oool0=03oool7ooooo`001Oooool>0?ooo`03
0820P01EEED0oooo02L0oooo00<0P820051@D03oool0103oool00`000000emOG0=OGe`0;0=OGe`03
0<G5a@1/K6`0emOG00D0emOG00<0XJ6Q0000001iNGT03`3GemL00`18B4P0P8200?ooo`030?ooo`03
05EEE@000000oooo02L0oooo00<0ZZZZ010@403oool0=@3oool7ooooo`001Oooool>0?ooo`030820
P01EEED0oooo02L0oooo00<071`L0:ZZZP3oool0103oool00`000000emOG0=OGe`0<0=OGe`0307em
O@3GemL0emOG00@0emOG00<0K6a/0000001/K6`03`3GemL00`18B4P0P8200?ooo`030?ooo`0305EE
E@000000oooo02L0oooo00<0>CTi06YZJP3oool0=@3oool7ooooo`001Oooool>0?ooo`030820P01E
EED0oooo02H0oooo00<0UIFE0000003_knl01@3oool00`000000emOG0=OGe`0<0=OGe`030<[:bP3G
emL0emOG00<0emOG00@0XJ6Q00h>3P000000XJ6Q3`3GemL00`18B4P0P8200?ooo`030?ooo`0305EE
E@000000oooo02H0oooo00<0eMGE0000002_[jl0=P3oool7ooooo`001Oooool>0?ooo`030820P00L
71`0EEEE0240EEEE00<0ZZZZ0?ooo`3oool00P3oool00`0i>CT0LG5a0?ooo`050?ooo`030000003G
emL0emOG0140emOG00@0XZ:R000000000000B4Q8403GemL00`18B4P0P8200?ooo`030?ooo`0305EE
E@000000EEEE0240EEEE00<0P8200?ooo`3oool00P3oool00`1EEED071`L0?ooo`0f0?ooo`Oooooo
0005ooooo`h0oooo00<0`<300820P020P8008020P8000`0[:b/0P8200?ooo`020?ooo`030<o?c`00
0000eMGE00H0oooo00<000000=OGe`3GemL0403GemL0102QXJ403Ph>0000001ADE4A0=OGe`0304Q8
B020P800oooo00<0oooo00<0ZZZZ0820P020P8008020P8000`1EEED0@4100?ooo`020?ooo`030=oO
g`000000P82003L0oooo1oooool000Gooooo<@3oool00`1EEED0P8200?ooo`020?ooo`0306YZJP1E
EED0oooo00H0oooo00<000000=OGe`3GemL03`3GemL0102?Shl0000000000018B4PB0=OGe`0304Q8
B020P800oooo02H0oooo00<0ZZZZ0410@03oool00P3oool00`2EUID000000?ooo`0g0?ooo`Oooooo
0005oooooc40oooo00<0EEEE0820P03oool00P3oool00`0[:b/0ZZZZ0?ooo`060?ooo`030000003G
emL0emOG00h0emOG00@0XJ6Q000000000000=SHf4`3GemL00`18B4P0P8200?ooo`0V0?ooo`030:ZZ
ZP10@400oooo0080oooo0P1EEEDh0?ooo`Oooooo0005oooooc40oooo00H0EEEE0820P03oool0oooo
0;no_`0P82080?ooo`030000003GemL0emOG00h0emOG00@0:2PX0000000f=SH0b/[:103GemL00`2c
/k<0emOG0=OGe`0<0=OGe`0304Q8B020P800oooo02H0oooo00L0ZZZZ0410@03oool0oooo0>[ZjP00
0000eMGE03P0oooo1oooool000Gooooo<@3oool01P1EEED0P8200?ooo`3oool0EEEE06YZJPP0oooo
00<000000=OGe`3GemL03P3GemL00`00000061PH0=OGe`050=OGe`0304Q8B03GemL0emOG00`0emOG
00<0B4Q80820P03oool09P3oool01P2ZZZX0@4100?ooo`3oool0SXj>02/[:cT0oooo1oooool000Go
oooo<@3oool01P1EEED0P8200?ooo`3Ogml000000;no_`P0oooo00<000000=OGe`3GemL03P3GemL0
0`0K6a/0B4Q80=OGe`040=OGe`030<[:bP0B4Q80emOG00d0emOG00<0B4Q80820P03oool09P3oool0
1P2ZZZX0@4100?ooo`3oool05ADE0820P3T0oooo1oooool000Gooooo<@3oool01@1EEED0P8200?oo
o`2EUID071`L00T0oooo00<000000=OGe`3GemL03P3GemL00`1/K6`000000;no_`040=OGe`0306a/
K0000000aLG500d0emOG00<0B4Q80820P03oool09P3oool01P2ZZZX0@4100?ooo`2o_kl000000=GE
eCT0oooo1oooool000Gooooo<@3oool01@1EEED0P8200?ooo`0`<300P82000T0oooo00<000000=OG
e`3GemL03`3GemL02@1/K6`092@T08N7Q`2QXJ40U9BD06a/K01ADE40FUYJ09BDU00=0=OGe`0304Q8
B020P800oooo02H0oooo00D0ZZZZ0410@03oool0H61P02/[:`0j0?ooo`Oooooo0005oooooc40oooo
00@0EEEE0820P03Shn<000002P3oool00`000000emOG0=OGe`0A0=OGe`030:6QX@2?Shl0XJ6Q00<0
emOG00<0aLG50=OGe`3GemL02`3GemL00`18B4P0P8200?ooo`0V0?ooo`050:ZZZP10@400oooo01DE
5@2ZZZX0>P3oool7ooooo`001Ooooola0?ooo`0405EEE@20P800JVYZ051@D0X0oooo00<000000=OG
e`3GemL09@3GemL00`18B4P0P8200?ooo`0V0?ooo`040:ZZZP10@400ZZZZ010@43/0oooo1oooool0
00Gooooo<@3oool0101EEED0JVYZ0000002ZZZX:0?ooo`030000003GemL0emOG02D0emOG00<0B4Q8
0820P03oool09P3oool0102ZZZX0@41003Ti>@1ZJVXk0?ooo`Oooooo0005oooooc40oooo00@0EEEE
02/[:`000000j^[Z2P3oool00`000000emOG0=OGe`0U0=OGe`0304Q8B020P800oooo02H0oooo00@0
ZZZZ02/[:`000000ZZZZ>`3oool7ooooo`001Ooooola0?ooo`0305EEE@000000EEEE00/0oooo00<0
00000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`0V0?ooo`040:ZZZP0000005ADE0>o_kc/0oooo
1oooool000Gooooo<@3oool00`1EEED000000<K6aP0;0?ooo`030000003GemL0emOG02D0emOG00<0
B4Q80820P03oool09P3oool00`2ZZZX00000075aL@0l0?ooo`Oooooo0005ooooo`d0oooo00<0EEEE
020P802o_kl00`3oool00`10@400<30`0>[ZjP0K0?ooo`0305EEE@0P8200oooo00/0oooo00<00000
0=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`0=0?ooo`030;no_`000000L71`00<0oooo00<0eMGE
010@4020P800403oool00`2ZZZX000000=CDe00l0?ooo`Oooooo0005ooooo`d0oooo00T0EEEE06YZ
JP0i>CT0_kno0?ooo`2o_kl0000005EEE@0i>CT06`3oool00`1EEED0P8200?ooo`0;0?ooo`030000
003GemL0emOG02D0emOG00<0B4Q80820P03oool03@3oool0102o_kl071`L0820P01EEED20?ooo`04
05EEE@000000SXj>09FEU@l0oooo00<0ZZZZ0410@03oool0?03oool7ooooo`001Oooool@0?ooo`07
061PH03Zj^X0P8200000002_[jl0j^[Z0;no_`040?ooo`030820P03oool0oooo01<0oooo00<0EEEE
0=oOg`3oool02`3oool00`000000emOG0=OGe`0U0=OGe`0304Q8B020P800oooo0100oooo00L0UIFE
0:2PX03oool00000030`<03oool0[jn_00@0oooo00<0j^[Z0;2`/03oool0203oool00`2ZZZX0X:2P
0?ooo`0l0?ooo`Oooooo0005oooooa00oooo00D0eMGE075aL@10@40000000>[ZjP050?ooo`030=GE
e@2>SXh0oooo01@0oooo00D0SXj>0?ooo`3oool0oooo0>?Sh`090?ooo`030000003GemL0emOG02D0
emOG00<0B4Q80820P03oool04@3oool0101ZJVX0ZZZZ0000001ZJVX60?ooo`03075aL@3Zj^X0oooo
00P0oooo00<0ZZZZ0>[ZjP3oool0=03oool00`3Zj^X0oooo0?ooo`050?ooo`Oooooo0005oooooa40
oooo00<0UIFE010@400[:b/01P3oool00`1`L700j^[Z0?ooo`0<0?ooo`030=GEe@2@T900oooo00T0
oooo00<0UIFE0:2PX03oool01`3oool00`000000emOG0=OGe`0U0=OGe`0304Q8B020P800oooo0140
oooo00@0gmoO02/[:`000000X:2P1@3oool00`3_knl0@4100?ooo`0d0?ooo`030:ZZZP2`/;00oooo
00T0oooo00<0P8200;no_`3oool01@3oool7ooooo`001OoooolA0?ooo`030<K6aP000000LG5a00H0
oooo00<0@4100?ooo`3oool03@3oool00`3EeMD0LG5a0?ooo`090?ooo`030410@02ZZZX0oooo00H0
oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`0B0?ooo`0301`L70000000eMGE00D0
oooo00<0UIFE08j>SP3oool0=@3oool00`2EUID0a/K60?ooo`080?ooo`030>[ZjP0L71`0_kno00D0
oooo1oooool000Gooooo00<0j^[Z0;no_`2o_kl0102o_kl00`3Ogml0oooo0?ooo`070?ooo`0306YZ
JP000000P82000D0oooo00<0eMGE0410@03oool00`3oool00`2PX:00ZZZZ0?ooo`030?ooo`030:n_
[`2o_kl0oooo0080oooo00<0clo?0000003Ogml00`3oool00`3?cll0P8200=oOg`030?ooo`030<o?
c`000000UIFE00H0oooo00<000000=OGe`3GemL09@3GemL01018B4P0P8200?ooo`3_knl60;no_`03
0<o?c`3oool0oooo00L0oooo00@0clo?0000000E5AD0clo?1@3oool00`1PH600ZZZZ0?ooo`020?oo
o`030:ZZZP2EUID0kno_00<0oooo00<0clo?09FEU@3oool04P3oool=0;no_`030820P03De=@0oooo
00<0oooo00<0UIFE0<o?c`3oool00P3oool00`2@T900:b/[0?ooo`030?ooo`030;no_`2@T900j^[Z
00<0oooo00<0_kno010@403EeMD0103oool7ooooo`001Oooool00`3Shn<0ZZZZ03Ti>@0200000003
01DE5@2>SXh0eMGE00T0oooo00@071`L01DE5@2>SXh0_kno103oool00`2>SXh0@4100?ooo`030?oo
o`030410@0000000P8200080oooo00@0hn?S000000000000_kno0P3oool00`10@40000000;no_`03
0?ooo`040410@0000000JVYZ0>?Sh`<0oooo00<0LG5a0000003EeMD01@3oool00`000000emOG0=OG
e`0U0=OGe`0604Q8B020P800oooo0>[ZjP2ZZZX0EEEE0`0000000`1aLG40_kno0?ooo`080?ooo`04
09FEU@000000LG5a06YZJPD0oooo00<0:b/[0:ZZZP3oool00P3oool00`1EEED000000410@0030?oo
o`0302/[:`000000P8200180oooo00<0JVYZ0000000000002@000000100i>CT000000000002ZZZX2
0?ooo`040:ZZZP0000005ADE0>?Sh`80oooo0P0000040?ooo`040000000E5AD0LG5a0>[ZjP<0oooo
00<0EEEE01dM7@3oool00`3oool7ooooo`001Oooool30?ooo`0302/[:`000000@41000X0oooo00/0
_kno00000010@400oooo0410@02ZZZX0EEEE0>?Sh`3oool0EEEE0410@0040?ooo`0907moO`3Shn<0
JVYZ0<K6aP3oool0SXj>0000002ZZZX0JVYZ0080oooo00<0P82001`L703Zj^X00`3oool01010@400
00000=GEe@1EEED30?ooo`030>?Sh`000000EEEE00D0oooo00<000000=OGe`3GemL09@3GemL00`18
B4P0P8200?ooo`030?ooo`0303Ti>@000000000000/0oooo00L0@4100000002ZZZX0ZZZZ05EEE@20
P800LG5a0080oooo00<000000:ZZZP3oool00P3oool02P2=SHd0ZZZZ0:ZZZP1aLG40oooo0>?Sh`00
0000EEEE0820P03Shn<80?ooo`0308j>SP3oool0oooo00H0oooo00<0eMGE01`L703Shn<01`3oool2
0000000:05EEE@1ZJVX0hn?S05EEE@3EeMD0oooo06YZJP000000ZZZZ05EEE@80oooo00<0@41005EE
E@3oool00`3oool0100000005ADE0?ooo`20P8030?ooo`030:ZZZP000000UIFE00<0oooo1oooool0
00Gooooo0`3oool00`1`L70000000410@0080?ooo`0=0=oOg`1[Jf/0410@0000002PX:00oooo0<o?
c`0E5AD000000;no_`3oool0EEEE010@40060?ooo`080>o_k`1EEED0gmoO0410@0000000oooo0=oO
g`3Zj^X70?ooo`05092@T0000000T92@0>[ZjP3_knl00`3oool00`1EEED000000=GEe@040?ooo`03
0000003GemL0emOG02D0emOG00<0B4Q80820P03oool00`3oool00`2EUID00000000000090?ooo`04
0:2PX00[:b/0000002/[:`80oooo00<0P8200000000E5AD00P3oool00`000000JVYZ0?ooo`050?oo
o`070820P02`/;00UIFE0000002ZZZX0oooo0;no_`080?ooo`0305EEE@3oool0oooo00L0oooo00<0
P82005EEE@3oool01@3oool0103?cll000000000002ZZZX20?ooo`080>[ZjP1PH600oooo030`<000
0000oooo0=GEe@3_knl70?ooo`0406YZJP000000_kno0=oOg`<0oooo00<0kno_01DE5@0P82000`3o
ool7ooooo`001Oooool30?ooo`0309FEU@000000:b/[00/0oooo00<0ZZZZ0?ooo`3oool00P3oool0
1@2o_kl0oooo0?ooo`1EEED0000000L0oooo00@0hn?S0820P0000000@4102P3oool00`2o_kl00000
0410@0050?ooo`030<K6aP000000>CTi00@0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P820
0?ooo`030?ooo`040<K6aP00000000000>?Sh`X0oooo00<0eMGE0>?Sh`3oool00P3oool01P3EeMD0
hn?S0?ooo`3oool0000005EEE@L0oooo00<0JVYZ05EEE@0000002`3oool00`1EEED0oooo0?ooo`08
0?ooo`0303Ti>@2ZZZX0oooo00@0oooo00@0ZZZZ000000000000hn?S0`3oool0102o_kl0SXj>0000
001EEED:0?ooo`030:ZZZP000000EEEE00D0oooo00<0LG5a0000002>SXh00P3oool7ooooo`001Ooo
ool30?ooo`030;no_`000000000001<0oooo00<0P8200000002ZZZX01`3oool00`2@T9000000071`
L00;0?ooo`0301DE5@000000oooo00D0oooo00<0820P0000003_knl00`3oool00`000000emOG0=OG
e`0U0=OGe`0304Q8B020P800oooo00@0oooo0P0000000`2ZZZX0oooo0?ooo`0A0?ooo`03020P8000
0000oooo00H0oooo00<0clo?0000000`<3002`3oool00`1EEED0oooo0?ooo`080?ooo`030=GEe@10
@400oooo00@0oooo00<0L71`0000000P82001@3oool00`1ZJVX0000009FEU@0;0?ooo`03010@4000
0000oooo00@0oooo00<0eMGE00000010@4000P3oool7ooooo`001Oooool40?ooo`80000000<0ZZZZ
0?ooo`3oool0403oool00`2ZZZX0000005EEE@070?ooo`030820P0000000ZZZZ00/0oooo00<0LG5a
0000002ZZZX01@3oool00`1EEED000000;no_`030?ooo`030000003GemL0emOG02D0emOG00<0B4Q8
0820P03oool0103oool00`1EEED0000005EEE@0C0?ooo`030410@0000000_kno00H0oooo00<0_kno
0000001ZJVX02`3oool00`1EEED0oooo0?ooo`090?ooo`0306YZJP2>SXh0oooo00<0oooo00<0@410
00000010@4001@3oool00`1EEED000000>?Sh`0;0?ooo`0305EEE@000000_kno00D0oooo00@05ADE
0000003oool0oooo1oooool000Gooooo103oool00`0[:b/000000820P00C0?ooo`030000000E5AD0
oooo00H0oooo00<0@4100000002@T9002`3oool00`2o_kl0000005EEE@050?ooo`03092@T0000000
T92@00<0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`040?ooo`030820P0000000
:b/[01<0oooo00<0P8200000002@T9001P3oool00`20P8000000051@D0050?ooo`030>o_k`2o_kl0
_kno00<0_kno00<0@4100;no_`2o_kl00`2o_kl00`3Zj^X0oooo0?ooo`030?ooo`030>o_k`0E5AD0
gmoO00<0oooo00<0410@00000020P8001@3oool00`000000820P09FEU@0;0?ooo`03092@T0000000
P82000D0oooo00@0D51@0000003?cll0oooo1oooool000Gooooo103oool00`1EEED0000005EEE@0C
0?ooo`0305EEE@000000ZZZZ00H0oooo00@0000003Ti>@2EUID0ZZZZ2`3oool00`0E5AD000000?oo
o`040?ooo`030;no_`000000P82000<0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?oo
o`040?ooo`030:ZZZP000000000001<0oooo00<0eMGE00000010@4001P3oool01010@40000000;no
_`1EEED40?ooo`030>[ZjP2ZZZX0ZZZZ00<0ZZZZ00<0>CTi0:ZZZP2ZZZX00`2ZZZX00`3Shn<0oooo
0?ooo`040?ooo`050:ZZZP1EEED0oooo0?ooo`3Shn<00P0000000`2ZZZX0oooo0?ooo`020?ooo`05
0;no_`000000JVYZ075aL@2o_kl02P3oool00`3EeMD000000410@0050?ooo`040820P0000000_kno
0?ooo`Oooooo0005ooooo`@0oooo00<0ZZZZ0000000000004`3oool00`2o_kl0000002/[:`030?oo
o`0:0>[ZjP2o_kl0@41000000020P800oooo0410@00`<30000000;no_`P0oooo00<0H61P0000002o
_kl0103oool00`3Ogml000000820P0030?ooo`030000003GemL0emOG02D0emOG00<0B4Q80820P03o
ool01@3oool2000000030;no_`3oool0oooo0140oooo00<0EEEE0000003EeMD00`3oool02@2o_kl0
P8200000000[:b/0oooo09FEU@0`<3000000092@T0070?ooo`0305EEE@3oool0oooo00/0oooo00@0
@4100:ZZZP3oool0ZZZZ0P000000303Ogml0oooo0?ooo`3EeMD0_kno030`<0000000X:2P0?ooo`10
@400:b/[010@40T0oooo00<0:b/[0000003oool0103oool0102PX:0000000;no_`3oool7ooooo`00
1Oooool40?ooo`040>?Sh`00000000000=GEeA<0oooo00<0>CTi0000003EeMD00P3oool0103Shn<0
P82005EEE@0E5AD30?ooo`0305EEE@0L71`0hn?S00H0oooo00H0j^[Z05EEE@000000000002/[:`1E
EED40?ooo`0300000020P800oooo0080oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?oo
o`050?ooo`0302/[:`000000UIFE01<0oooo00<0hn?S0000001aLG400`3oool0102EUID0EEEE01DE
5@36a/H20?ooo`0309FEU@000000_kno00L0oooo00<0EEEE0?ooo`3oool02`3oool0103EeMD071`L
0>[ZjP1EEED2000000<0oooo00@0a/K6075aL@10@40071`L0P3oool00`3Zj^X0>CTi0410@0070?oo
o`060>?Sh`10@40000000000000i>CT0P8200`3oool0102o_kl000000;no_`3oool7ooooo`001Ooo
ool50?ooo`80000000<0`<300?ooo`3oool04@3oool00`3Shn<071`L06YZJP0D0?ooo`030=GEe@0L
71`0@41000D0oooo00<000000;no_`3oool00P3oool00`000000emOG0=OGe`0U0=OGe`0304Q8B020
P800oooo00D0oooo00<0@41000000020P800503oool00`20P80000000>[ZjP0B0?ooo`0305EEE@3o
ool0oooo00`0oooo00D0EEEE09FEU@0i>CT0000005EEE@0E0?ooo`030<K6aP0E5AD0EEEE00@0oooo
00@0_kno0000003oool0oooo1oooool000Gooooo1@3oool00`10@40000000820P0060?ooo`030>o_
k`1EEED0oooo00/0oooo00<0_kno010@403EeMD0503oool00`3Zj^X0<30`0?ooo`040?ooo`030000
003_knl0oooo0080oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`050?ooo`030820
P0000000@41000L0oooo00<0L71`0?ooo`3oool02P3oool00`3_knl0@410061PH00B0?ooo`0305EE
E@3oool0oooo00`0oooo00D0j^[Z020P8000000000000820P00F0?ooo`030=3@d00E5AD0oooo00<0
oooo00@0_kno0410@03oool0oooo1oooool000Gooooo1@3oool00`1ZJVX0000005EEE@060?ooo`03
0:ZZZP1EEED0oooo00`0oooo00<0_kno01`L703Zj^X0503oool00`2o_kl0a/K60?ooo`020?ooo`03
0=GEe@1EEED0oooo00<0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`050?ooo`03
0:ZZZP0000005ADE00H0oooo00<0hn?S0410@03oool03@3oool00`10@400ZZZZ0?ooo`0@0?ooo`03
05EEE@3oool0oooo00d0oooo00@0UIFE000000000000a/K65`3oool00`2ZZZX0eMGE0?ooo`020?oo
o`0409FEU@2ZZZX0oooo0?ooo`Oooooo0005ooooo`D0oooo00@0L71`0000000@4100j^[Z103oool0
0`2ZZZX0820P05EEE@0>0?ooo`030;no_`1`L700oooo01P0oooo00<0X:2P0;no_`3oool00`3oool0
0`000000emOG0=OGe`0U0=OGe`0304Q8B020P800oooo00D0oooo00@0[jn_000000000000ZZZZ103o
ool00`2o_kl0:b/[0410@00>0?ooo`030>o_k`1EEED0_kno0200oooo00<0kno_02/[:`0000007@3o
ool0101`L700oooo0?ooo`3oool7ooooo`001Oooool30?ooo`030:ZZZP0i>CT0000000T0000000<0
71`L0?ooo`3oool03@3oool00`2o_kl0LG5a0?ooo`0G0?ooo`030820P03oool0oooo00<0oooo00<0
00000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`030?ooo`030<K6aP1EEED0000000T0000000<0
5ADE0?ooo`3oool03P3oool00`1aLG40_kno0?ooo`0O0?ooo`030<K6aP10@400oooo01`0oooo00@0
P8200?ooo`3oool0oooo1oooool000Gooooo803oool00`3Zj^X0X:2P0?ooo`0F0?ooo`030<30`03o
ool0oooo00<0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`0Q0?ooo`030:2PX03Z
j^X0oooo01l0oooo00<0gmoO0?ooo`3oool06P3oool00`3EeMD0gmoO0?ooo`020?ooo`Oooooo0005
ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005oooo
ocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0
oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo
00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<0
00000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<00000
0=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OG
e`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3G
emL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL0
9@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3G
emL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL0
0`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18
B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0
P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P820
0?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?oo
o`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U
0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?oo
o`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oo
oooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo
0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005
ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005oooo
ocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0
oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo
00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<0
00000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<00000
0=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OG
e`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3G
emL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL0
9@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3G
emL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL0
0`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18
B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0
P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P820
0?ooo`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?oo
o`1U0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U
0?ooo`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?oo
o`Oooooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oo
oooo0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo
0005ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005
ooooocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005oooo
ocl0oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0
oooo00<000000=OGe`3GemL09@3GemL00`18B4P0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo
00<000000:6QX@2QXJ409@2QXJ400`0f=SH0P8200?ooo`1U0?ooo`Oooooo0005ooooocl0oooo:@00
00000`20P800oooo0?ooo`1T0?ooo`Oooooo003Kooooo`00foooool00=_ooooo003Kooooo`00fooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 218}, {230.625, 0}} -> {-18.1661, -18.9789, 5.18346, \
5.18346}}],

Cell[TextData[{
  "Fig. 3.5: Energy change of an element of material of width ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " due to a source ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " and due to heat flux ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_x\)]],
  "."
}], "Caption",
  CellTags->"Fig. 3.5"],

Cell[TextData[{
  "\tConsider the volume element ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["V",
                FontSlant->"Italic"]}]], " ", "=", " ", 
          RowBox[{"A", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " shown in Fig. ",
  ButtonBox["3.5",
    ButtonData:>"Fig. 3.5",
    ButtonStyle->"Hyperlink"],
  ". This element, located at position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ",  has a time-varying thermal energy content ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[
            RowBox[{\(\[Epsilon](x, t)\), " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["V",
                    FontSlant->"Italic"]}]]}],
            "TraditionalForm"]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " is the ",
  StyleBox["energy density",
    FontSlant->"Italic"],
  " of the material (energy per unit volume). The heat flux leaving this \
element from the right side has magnitude ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[CapitalGamma]\_x\), "(", 
          RowBox[{
            RowBox[{"x", "+", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}], ",", "t"}], ")"}], 
        TraditionalForm]]],
  ", but the flux entering the element on the left side has magnitude ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalGamma]\_x\)(x, t)\)]],
  ". The difference in these fluxes results in energy gained or lost to the \
element, at a rate ",
  Cell[BoxData[
      FormBox[
        RowBox[{"A", " ", "[", 
          RowBox[{\(\(\[CapitalGamma]\_x\)(x, t)\), " ", "-", " ", 
            RowBox[{\(\[CapitalGamma]\_x\), "(", 
              RowBox[{
                RowBox[{"x", "+", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]]}], ",", "t"}], ")"}]}], " ", 
          "]"}], TraditionalForm]]],
  ".  In addition, extra sources of heat such as chemical or nuclear \
reactions can be occurring within the slab, adding or removing heat energy \
from the volume element at the rate \[CapitalDelta]",
  StyleBox["V",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`S(x, t)\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["S",
            "TraditionalForm"], "(", \(x, t\), ")"}], TraditionalForm]]],
  " represents a given source of heat energy per unit volume, with units of \
watts per cubic meter (i.e. it is the ",
  StyleBox["power density",
    FontSlant->"Italic"],
  " of the source). In a time ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\)]],
  ", the total energy change of the element,",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[
            RowBox[{"\[DifferentialD]", 
              RowBox[{"(", 
                RowBox[{"\[Epsilon]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["V",
                        FontSlant->"Italic"]}]]}], ")"}]}],
            "TraditionalForm"]}], TraditionalForm]]],
  ", is the sum of these two terms multiplied by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\)]],
  ":"
}], "Text",
  CellTags->"i:22"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[DifferentialD]", 
            RowBox[{"(", 
              RowBox[{"\[Epsilon]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["V",
                      FontSlant->"Italic"]}]]}], ")"}]}], " ", "=", " ", 
          RowBox[{
            RowBox[{\(\[DifferentialD]t\), " ", "A", " ", 
              RowBox[{"(", 
                RowBox[{\(\(\[CapitalGamma]\_x\)(x, t)\), " ", "-", " ", 
                  RowBox[{\(\[CapitalGamma]\_x\), "(", 
                    RowBox[{
                      RowBox[{"x", "+", 
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["x",
                              FontSlant->"Italic"]}]]}], ",", "t"}], ")"}]}], 
                " ", ")"}]}], "+", 
            RowBox[{\(\[DifferentialD]t\), "  ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["V",
                    FontSlant->"Italic"]}]], 
              RowBox[{
                FormBox[\(S(x, t)\),
                  "TraditionalForm"], " ", "."}]}]}]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "Taylor expansion of the heat flux implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[DifferentialD]t\), " ", "A", " ", 
            RowBox[{"(", 
              RowBox[{\(\(\[CapitalGamma]\_x\)(x, t)\), " ", "-", " ", 
                RowBox[{\(\[CapitalGamma]\_x\), "(", 
                  RowBox[{
                    RowBox[{"x", "+", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]]}], ",", "t"}], ")"}]}], 
              " ", ")"}]}], " ", "=", " ", 
          RowBox[{
            RowBox[{\(-\[DifferentialD]t\), " ", "A", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], 
              " ", \(\[PartialD]\[CapitalGamma]\_x/\[PartialD]x\)}], " ", "=",
             
            RowBox[{\(-\[DifferentialD]t\), " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["V",
                    FontSlant->"Italic"]}]], 
              " ", \(\[PartialD]\[CapitalGamma]\_x/\(\(\[PartialD]x\)\(\ \)\)\
\)}]}]}], TraditionalForm]]],
  ". Dividing by the differentials, we obtain the ",
  StyleBox["continuity equation",
    FontSlant->"Italic"],
  " for the energy density,"
}], "Text",
  CellTags->"i:102"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Epsilon]\/\[PartialD]t = \(-\(\
\[PartialD]\[CapitalGamma]\_x\/\[PartialD]x\)\) + S(x, t)\)]],
  "."
}], "NumberedEquation",
  CellTags->{"(3.1.38)", "i:23"}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The Heat and Diffusion Equations. Dirichlet, von Neumann, and Mixed \
Boundary Conditions.\
\>", "Section",
  CellTags->"c:16"],

Cell[TextData[{
  "When combined with Eq. ",
  ButtonBox["(3.1.37)",
    ButtonData:>"(3.1.37)",
    ButtonStyle->"Hyperlink"],
  ", Eq. ",
  ButtonBox["(3.1.38)",
    ButtonData:>"(3.1.38)",
    ButtonStyle->"Hyperlink"],
  " yields  the following  partial differential equation:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Epsilon]\/\[PartialD]t = \
\(\[PartialD]\/\[PartialD]x\) \((\[Kappa]\ \[PartialD]T\/\[PartialD]x)\) + 
          S(x, t)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.39)"],

Cell["\<\
This equation can be used to obtain a temperature evolution \
equation,  because we can connect the energy density to the temperature via \
the laws of thermodynamics.  A change in the thermal energy density of the \
material causes a change  in the temperature according to the relation\
\>", \
"Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\[Epsilon]\  = \ 
        C\ \[DifferentialD]T\)]],
  ","
}], "NumberedEquation",
  CellTags->"(3.1.40)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " is the ",
  StyleBox["specific heat",
    FontSlant->"Italic"],
  " of the material. This constant, with units of ",
  Cell[BoxData[
      \(TraditionalForm\`joules\ per\ cubic\ meter\ per\ kelvin\)]],
  ", is another intrinsic property of the material.  Like the thermal \
conductivity, the specific heat must be nonnegative. For water at room \
temperature and at constant atmospheric pressure, the specific heat is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"C", "=", 
          RowBox[{\(4.2\ \[Cross]10\^6\), 
            RowBox[{
              StyleBox["J",
                FontSlant->"Plain"], "/", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox["m",
                      FontSlant->"Plain"], "3"], 
                  StyleBox["K",
                    FontSlant->"Plain"]}], ")"}], " "}]}]}], 
        TraditionalForm]]],
  ", meaning that ",
  Cell[BoxData[
      \(TraditionalForm\`4.2\ MJ\)]],
  " of heat energy must be added to a cubic meter of water in order to raise \
its temperature by 1 K. [A typical hot tub contains a few cubic meters of \
water, so one can see that tens of megajoules of energy are required to heat \
it by several degrees. Fortunately, 1 MJ of energy costs only a few pennies \
(as of 2002).] The specific heat of copper is not very different from that of \
water, ",
  Cell[BoxData[
      \(TraditionalForm\`C = 
        3.5\ \[Cross]10\^6 \(\( Joules/\((\(m\^3\) K)\)\)\(\ \)\)\)]],
  ". "
}], "Text",
  CellTags->"i:24"],

Cell[TextData[{
  "\tWhen we combine Eqs. ",
  ButtonBox["(3.1.39)",
    ButtonData:>"(3.1.39)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.1.40)",
    ButtonData:>"(3.1.40)",
    ButtonStyle->"Hyperlink"],
  "",
  ",",
  " we arrive at the following partial differential equation for the \
temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(C(
            x)\)\ \ \[PartialD]T\/\[PartialD]t = \
\(\[PartialD]\/\[PartialD]x\) \((\(\[Kappa](
                  x)\) \[PartialD]T\/\[PartialD]x)\) + S(x, t)\)]],
  "."
}], "NumberedEquation",
  CellTags->{"(3.1.41)", "i:25"}],

Cell[TextData[{
  "Equation ",
  ButtonBox["(3.1.41)",
    ButtonData:>"(3.1.41)",
    ButtonStyle->"Hyperlink"],
  " is the heat equation in one spatial dimension. In writing it we have \
allowed for spatial variation in the material properties ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " . This can occur in layered materials, for example. The equation \
simplifies when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " are independent of position:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]T\/\[PartialD]t = \[Chi] \[PartialD]\^2 T\
\/\[PartialD]x\^2 + \(S(x, t)\)\/C\)]],
  ","
}], "NumberedEquation",
  CellTags->"(3.1.42)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  " is the ",
  StyleBox["thermal diffusivity",
    FontSlant->"Italic"],
  " of the material, defined as"
}], "Text",
  CellTags->"i:26"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] = \[Kappa]/C\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.43)"],

Cell[TextData[{
  "The thermal diffusivity has units of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["m",
              FontSlant->"Plain"], "2"], "/", 
          StyleBox["s",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ". For water, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", "=", 
          RowBox[{\(1.4\[Cross]10\^\(-7\)\), 
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "2"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", and for copper, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", "=", 
          RowBox[{\(1.1\[Cross]10\^\(-4\)\), 
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "2"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". Equation ",
  ButtonBox["(3.1.42)",
    ButtonData:>"(3.1.42)",
    ButtonStyle->"Hyperlink"],
  " is sometimes referred to as the ",
  StyleBox["diffusion equation",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"i:114"],

Cell["\<\
\tThe heat equation is a first-order PDE in time and so requires a \
single initial condition, specifying the initial temperature in the slab as a \
function of position:\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`T(x, 
        0)\  = \ \(\(\(T\_o\)(x)\)\(.\)\)\)]]], "NumberedEquation",
  CellTags->"(3.1.44)"],

Cell[TextData[{
  "The equation is second-order in space, and so requires two boundary \
conditions to specify the solution. The boundary conditions one employs \
depend on the circumstances. For example, in some experiments one might fix \
the temperature of the slab faces to be given functions of time, by putting \
the faces in good thermal contact with heat reservoirs at given temperatures \
",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_1\)(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_2\)(t)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[{
      \(TraditionalForm\`T(0, t)\  = \ \(T\_1\)(t)\), "\[IndentingNewLine]", 
      \(TraditionalForm\`T(L, t)\  = \ \(\(\(T\_2\)(t)\)\(.\)\)\)}]],
  ","
}], "NumberedEquation",
  CellTags->"(3.1.45)"],

Cell["\<\
These Dirichlet boundary conditions are of the same type as those \
encountered previously for the wave equation.\
\>", "Text",
  CellTags->"i:27"],

Cell[TextData[{
  "\t On the other hand, one might also insulate the faces of the slab, so \
that no heat flux can enter of leave the faces: ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalGamma]\_x\)(
          0) = \(\(\[CapitalGamma]\_x\)(L) = 0\)\)]],
  ". More generally, one might specify the heat flux entering or leaving the \
faces to be some function of time. Then according to Eq. ",
  ButtonBox["(3.1.37)",
    ButtonData:>"(3.1.37)",
    ButtonStyle->"Hyperlink"],
  ", the temperature gradient at the faces is specified:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\[PartialD]T\/\[PartialD]x\) \((0, 
          t)\)\  = \ \(-\(\(\(\[CapitalGamma]\_\(x\ 1\)\)(
              t)\)\/\[Kappa]\)\), \[IndentingNewLine]\(\[PartialD]T\/\
\[PartialD]x\) \((L, 
          t)\)\  = \ \(-\(\(\(\[CapitalGamma]\_\(x\ 2\)\)(
              t)\)\/\[Kappa]\)\), \)]]], "NumberedEquation",
  CellTags->"(3.1.46)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalGamma]\_\(x\ 1\)\)(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalGamma]\_\(x\ 2\)\)(t)\)]],
  " are given functions of time, equaling zero if the faces are insulated. \
Boundary conditions where the gradient of the unknown function is specified \
are called von Neumann boundary conditions, or boundary conditions of the \
second kind."
}], "Text",
  CellTags->"i:28"],

Cell[TextData[{
  "\tThere can also be circumstances where the flux of heat lost or gained \
from the slab faces is proportional to the temperature of the faces: for \
example, the hotter the face, the faster the heat loss.  This leads to ",
  StyleBox["mixed",
    FontSlant->"Italic"],
  " boundary conditions at the faces:"
}], "Text",
  CellTags->"i:29"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] \(\[PartialD]T\/\[PartialD]x\) \((0, t)\) = 
        a\ [T(0, t) - \ \(T\_1\)(
              t)]\ , \[IndentingNewLine]\[Kappa]\ \
\(\[PartialD]T\/\[PartialD]x\) \((L, 
            t)\) = \(-\(\(b[T(L, t) - \ \(T\_2\)(t)]\)\(.\)\)\)\)]]
}], "NumberedEquation",
  CellTags->"(3.1.47)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "  are given (nonnegative) constants. The functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_1\)(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_2\)(t)\)]],
  " are the temperatures of the exterior surroundings: only if the face is \
hotter than the surroundings is there a flux of heat out of the face. If ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " are very large, representing good thermal contact with the surroundings, \
then the temperature of the faces is pinned to that of the surroundings and \
the boundary conditions are of Dirichlet form, Eq. ",
  ButtonBox["(3.1.45)",
    ButtonData:>"(3.1.45)",
    ButtonStyle->"Hyperlink"],
  ". On the other hand, if ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " are very small, then the faces are insulating and obey homogeneous ",
  "von Neumann",
  " conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]T/\[PartialD]x = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFinally, there can be situations where one face has a different type of \
boundary condition than the other; for instance, one side of a slab might be \
insulated, while on the other side the temperature might be fixed. These \
possibilites are summarized in Table ",
  ButtonBox["3.1",
    ButtonData:>"Table 3.1",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "Table 3.1. Possible Boundary Conditions for the Heat ",
  Cell[BoxData[
      \(TraditionalForm\`Equation\^a\)]],
  " \n\n\n",
  Cell[BoxData[GridBox[{
          {
            StyleBox["Dirichlet",
              FontFamily->"Times"], 
            RowBox[{Cell[TextData[Cell[BoxData[
                  FormBox[
                    StyleBox[
                      RowBox[{\(T(0, t)\), "=", 
                        FormBox[\(\(T\_1\)(t)\),
                          "TraditionalForm"]}],
                      FontFamily->"Times"], TraditionalForm]]]]], Cell[
              ""]}]},
          {
            StyleBox[\(von\ Neumann\),
              FontFamily->"Times"], 
            RowBox[{Cell[TextData[Cell[BoxData[
                  FormBox[Cell[""], TraditionalForm]]]]], Cell[TextData[Cell[
              BoxData[
                  FormBox[
                    
                    StyleBox[\(\[Kappa] \(\[PartialD]T\/\[PartialD]x\) \((0, 
                            t)\)\  = \ \(-\(\(\[CapitalGamma]\_\(x\ 1\)\)(
                            t)\)\)\),
                      FontFamily->"Times"], TraditionalForm]]]]]}]},
          {
            StyleBox["mixed",
              FontFamily->"Times"], Cell[TextData[Cell[BoxData[
                FormBox[
                  
                  StyleBox[\(\[Kappa] \(\[PartialD]T\/\[PartialD]x\) \((0, 
                          t)\) = a\ [T(0, t) - \ \(T\_1\)(t)]\),
                    FontFamily->"Times"], TraditionalForm]]]]]}
          }]]]
}], "2ColumnBox",
  TextAlignment->Center,
  TextJustification->0,
  CellTags->"Table 3.1"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\^a\)\)\)]],
  StyleBox["At one end,  ",
    FontSize->10],
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)],
    FontSize->10],
  StyleBox[".",
    FontSize->10]
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.1.4 Solution of the Heat Equation Using Separation of Variables\
\
\>", "Subsubtitle",
  CellTags->"c:17"],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  CellTags->"c:18"],

Cell[TextData[{
  "\tThe heat equation for a uniform medium, Eq. ",
  ButtonBox["(3.1.41)",
    ButtonData:>"(3.1.41)",
    ButtonStyle->"Hyperlink"],
  ", can often be solved using the method of separation of variables. For \
this method to work, we require that an equilibrium solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_eq\)(x)\)]],
  " for the temperature exist. A necessary (but not sufficient) requirement \
for equilibrium is time-independent boundary conditions and a \
time-independent source function. "
}], "Text"],

Cell[TextData[{
  "\tIf  an equilibrium solution can be found, then this solution can be \
subtracted out, and the deviation from equilibrium, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  ", can then be analyzed using separation of variables, just as for the wave \
equation. However, if an equilibrium solution does not exist, then other more \
general solution methods  must be applied. Such methods will be discussed in \
Sec. ",
  ButtonBox["4.2",
    ButtonData:>{"Chapter4.nb", "c:14"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell["\<\
\t One might have expected that time-independent boundary \
conditions and a time-independent source would necessarily imply that an \
equilibrium solution for the temperature exists. However, this is not always \
the case, as we will now show.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Static Boundary Conditions and a Static Source", "Section",
  CellTags->"c:19"],

Cell[CellGroupData[{

Cell["The Equilibrium Solution", "Subsubsection"],

Cell[TextData[{
  "We  consider time-independent boundary conditions,  of either the \
Dirichlet, the ",
  "von Neumann",
  ", or the mixed form,  and a static source function, ",
  Cell[BoxData[
      \(TraditionalForm\`S = S(x)\)]],
  ". We will look for an equilibrium solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_eq\)(x)\)]],
  " that satisfies these boundary conditions, as well as the time-independent \
heat equation,  "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`0 = \(\[PartialD]\/\[PartialD]x\) \((\(\[Kappa](
                  x)\) \[PartialD]T\_eq\/\[PartialD]x)\) + S(x, t)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.48)"],

Cell["\<\
This equation has a general solution that can be found by direct \
integration:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(T\_eq\)(
          x)\  = \ \
\(-\(\[Integral]\_0\%x\[DifferentialD]\(\(x\^\[Prime]\)(\(1\/\(\(\[Kappa](
                          x\^\[Prime])\)\(\ \)\)\) \(\[Integral]\_0\%\(x\^\
\[Prime]\)\(S(
                          x\^\[DoublePrime])\)\ \[DifferentialD]x\^\
\[DoublePrime]\))\)\)\) + \ C\_1\  + \ 
          C\_2\ \(\[Integral]\_0\%x\[DifferentialD]x\^\[Prime] 
                 1\/\(\(\[Kappa](x\^\[Prime])\)\(\ \)\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.49)"],

Cell[TextData[{
  "The constants ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  " are chosen to match the boundary conditions. For example, for Dirichlet \
boundary conditions at each end, ",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t) = T\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T(L, t) = T\_2\)]],
  ",  the solution mirrors the equilibrium solution to the wave equation:"
}], "Text",
  CellTags->"i:30"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`C\_1 = T\_1\)]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2 = \(T\_2 - T\_\(\(1\)\(\ \)\) + \
\[Integral]\_0\%L\[DifferentialD]x\^\[Prime] \( \
1\/\(\(\[Kappa](x\^\[Prime])\)\(\ \)\)\) \
\(\[Integral]\_0\%\(x\^\[Prime]\)\(S(x\^\[DoublePrime])\)\ \
\[DifferentialD]x\^\[DoublePrime]\)\)\/\(\[Integral]\_0\%L\[DifferentialD]x\^\
\[Prime]  1\/\(\(\[Kappa](x\^\[Prime])\)\(\ \)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Similarly, one can also find a unique equilibrium solution for  mixed \
boundary conditions at each end [Eq. ",
  ButtonBox["(3.1.47)",
    ButtonData:>"(3.1.47)",
    ButtonStyle->"Hyperlink"],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`T\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T\_2\)]],
  " constants], although we will not write the solution here. In fact, one \
can always find a unique equilibrium solution for every possible combination \
of static boundary conditions at each end, ",
  StyleBox["except one",
    FontSlant->"Italic"],
  ": von Neumann conditions at each end. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Constraint Condition on the Existence of an Equilibrium for von \
Neumann Boundary Conditions\
\>", "Subsubsection",
  CellTags->"i:31"],

Cell[TextData[{
  "\tIf we specify von Neumann boundary conditions, then according to Eq. ",
  ButtonBox["(3.1.49)",
    ButtonData:>"(3.1.49)",
    ButtonStyle->"Hyperlink"],
  " the derivative of the equilibrium temperature at each end must satisfy \
the following two equations:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Kappa](
            0)\) \(\[PartialD]T\_eq\/\[PartialD]x\) \((0, 
            t)\) = \(\(-\[CapitalGamma]\_\(x\ 1\)\) = \ C\_2\)\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Kappa](
            L)\) \(\[PartialD]T\_eq\/\[PartialD]x\) \((L, 
            t)\) = \ \(\(-\[CapitalGamma]\_\(x\ 2\)\) = \ 
          C\_2 - \[Integral]\_0\%L\( S(
                  x\^\[DoublePrime])\)\ \
\[DifferentialD]x\^\[DoublePrime]\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.50)"],

Cell[TextData[{
  "However, these are two equations in only one unknown, ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  ". [The constant ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  " disappeared when the derivative of Eq. ",
  ButtonBox["(3.1.49)",
    ButtonData:>"(3.1.49)",
    ButtonStyle->"Hyperlink"],
  " was taken] Therefore, a solution cannot necessarily be found to these \
equations.  This should not be completely surprising. After all, Eq. ",
  ButtonBox["(3.1.48)",
    ButtonData:>"(3.1.48)",
    ButtonStyle->"Hyperlink"],
  " is being solved as a boundary-value problem, and we know that a solution \
to boundary-value problems need not exist. "
}], "Text"],

Cell[TextData[{
  "\tSubtracting Eqs. ",
  ButtonBox["(3.1.50)",
    ButtonData:>"(3.1.50)",
    ButtonStyle->"Hyperlink"],
  " from one another implies that the equations have a solution for ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  " only if the external heat fluxes ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_\(x\ 1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_\(x\ 2\)\)]],
  "are related to the heat source ",
  Cell[BoxData[
      \(TraditionalForm\`S(x)\)]],
  " through"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_\(x\ 1\) - \[CapitalGamma]\_\(x\ \
2\) + \[Integral]\_0\%L\( S(
                x\^\[DoublePrime])\)\ \[DifferentialD]x\^\[DoublePrime] = 
        0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.51)"],

Cell[TextData[{
  "If this equation is not satisfied, there is no equilibrium solution. The \
equation follows from the requirement that, in equilibrium, the overall \
energy content of the material must not change with time.  In a slab with \
cross-sectional area ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  ", the total energy content is  ",
  Cell[BoxData[
      \(TraditionalForm\`E = 
        A \(\[Integral]\_0\%L \[Epsilon] \[DifferentialD]x\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " is the energy density. Setting the time derivative of this expression \
equal to zero yields"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]E\/\[DifferentialD]t = \(0 = \(A \(\
\[Integral]\_0\%L\ \(\[PartialD]\[Epsilon]\/\[PartialD]t\) \((x, 
                    t)\) \[DifferentialD]x\) = 
            A \(\[Integral]\_0\%L\ \((\(-\(\[PartialD]\[CapitalGamma]\_x\/\
\[PartialD]x\)\) + S(x, t))\) \[DifferentialD]x\)\)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where the second equality follows from energy conservation, Eq. ",
  ButtonBox["(3.1.38)",
    ButtonData:>"(3.1.38)",
    ButtonStyle->"Hyperlink"],
  ".   Performing the integral over the heat flux using the fundamental \
theorem of calculus then leads to Eq. ",
  ButtonBox["(3.1.51)",
    ButtonData:>"(3.1.51)",
    ButtonStyle->"Hyperlink"],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(3.1.51)",
    ButtonData:>"(3.1.51)",
    ButtonStyle->"Hyperlink"],
  " is easy to understand intuitively: Take the case of an insulated slab, \
with ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_\(x\ 1\) = \(\[CapitalGamma]\_\(x\ \
2\) = 0\)\)]],
  " . Then for a temperature equilibrium to exist, there can be no net heat \
energy injected into the slab by the source:",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%L\( S(
              x\^\[DoublePrime])\)\ \[DifferentialD]x\^\[DoublePrime] = 
        0\)]],
  "; otherwise the temperature must rise or fall as the overall energy \
content in the slab varies with time. Similarly, if ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_\(x\ 1\) - \[CapitalGamma]\_\(x\ \
2\) < 0\)]],
  ", then we are removing heat through the faces of the slab; and in \
equilibrium this energy must be replaced by the heat source ",
  Cell[BoxData[
      \(TraditionalForm\`S(x)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tFor Dirichlet or mixed boundary conditions, where the external heat \
fluxes ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_\(x\ 1\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_\(x\ 2\)\)]],
  " are not directly specified, the fluxes through the slab faces are free to \
vary until the equilibrium condition of Eq. ",
  ButtonBox["(3.1.51)",
    ButtonData:>"(3.1.51)",
    ButtonStyle->"Hyperlink"],
  " is achieved. However, for von Neumann boundary conditions these fluxes \
are specified directly, and if they do not satisfy Eq. ",
  ButtonBox["(3.1.51)",
    ButtonData:>"(3.1.51)",
    ButtonStyle->"Hyperlink"],
  ", the energy content of the slab will increase with time [if the ",
  "left-hand",
  " side of Eq. ",
  ButtonBox["(3.1.51)",
    ButtonData:>"(3.1.51)",
    ButtonStyle->"Hyperlink"],
  " is greater than zero] or decrease with time [if it is less than zero], \
and no equilibrium will exist.  Conditions such as this cannot be treated \
using separation of variables. A solution to this problem can be found in \
Chapter ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  ".\t"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Separation of Variables for the Deviation from Equilibrium", \
"Subsubsection"],

Cell[TextData[{
  "\tLet's assume that the static boundary conditions and the source are such \
that Eq, ",
  ButtonBox["(3.1.51)",
    ButtonData:>"(3.1.51)",
    ButtonStyle->"Hyperlink"],
  " is satisfied, so that an equilibrium solution to the heat equation \
exists.  We can then determine the evolution of ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " from a general initial condition, ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = \(T\_o\)(x)\)]],
  ", by following the prescription laid out for the wave equation."
}], "Text"],

Cell[TextData[{
  "\tWe first subtract out the equilibrium, and follow the deviation from \
equilibrium, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  ", where"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T(x, t)\), " ", "=", " ", 
          RowBox[{\(\(T\_eq\)(x)\), " ", "+", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["T",
                    FontSlant->"Italic"]}]], "(", \(x, t\), ")"}]}]}], 
        TraditionalForm]]],
  ". "
}], "NumberedEquation",
  CellTags->"(3.1.52)"],

Cell[TextData[{
  "Substitution of this expression into the heat equation ",
  ButtonBox["(3.1.41)",
    ButtonData:>"(3.1.41)",
    ButtonStyle->"Hyperlink"],
  " and application of Eq. ",
  ButtonBox["(3.1.48)",
    ButtonData:>"(3.1.48)",
    ButtonStyle->"Hyperlink"],
  " implies that  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  " satisfies the homogeneous heat equation"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(C(x)\), "  ", 
          FractionBox[
            RowBox[{"\[PartialD]", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["T",
                    FontSlant->"Italic"]}]]}], \(\[PartialD]t\)]}], "=", 
        RowBox[{\(\[PartialD]\/\[PartialD]x\), 
          RowBox[{"(", 
            RowBox[{\(\[Kappa](x)\), 
              FractionBox[
                RowBox[{"\[PartialD]", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["T",
                        FontSlant->"Italic"]}]]}], \(\[PartialD]x\)]}], 
            ")"}]}]}], TraditionalForm]]]], "NumberedEquation",
  CellTags->"(3.1.53)"],

Cell[TextData[{
  "with ",
  StyleBox["homogeneous  boundary conditions,",
    FontSlant->"Italic"],
  " and  initial condition"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["T",
                  FontSlant->"Italic"]}]], "(", \(x, 0\), ")"}], " ", "=", 
          " ", \(\(T\_o\)(x) - \(T\_eq\)(x)\)}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.54)"],

Cell[TextData[{
  "The boundary conditions are of the same type as the original equation, but \
are homogeneous.  Recall that homogeneous boundary conditions are such that a \
trivial solution ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "=", "0"}], TraditionalForm]]],
  " exists. For instance, if the original equation had von Neumann conditions \
at one end and Dirichlet conditions at the other, ",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t) = T\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]T/\[PartialD]x\)\( | \_\(x = 
                L\)\)\) = \(-\[CapitalGamma]\_\(x\ 2\)\)/\[Kappa]\)]],
  "; then ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["T",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " would satisfy homogeneous conditions of the same type, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["T",
                    FontSlant->"Italic"]}]], "(", \(0, t\), ")"}], "=", "0"}],
           ",", 
          FormBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{"\[PartialD]", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["T",
                          FontSlant->"Italic"]}]]}], 
                  "/", \(\[PartialD]x\)}], \( | \_\(x = L\)\)}], "=", "0"}],
            "TraditionalForm"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "The boundary conditions for the temperature deviation ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["T",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " are of the same type as the original boundary conditions for ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", but are homogeneous. (This was the point of subtracting out the \
equilibrium solution.)  Separation of variables only works if we can write \
down a PDE for ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["T",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " that is accompanied by homogeneous boundary conditions. "
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "\tThe solution of Eq. ",
  ButtonBox["(3.1.53)",
    ButtonData:>"(3.1.53)",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["T",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " can again be obtained using the method of separation of variables. Here \
for simplicity we will only consider the case where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " are constants, so that Eq. ",
  ButtonBox["(3.1.53)",
    ButtonData:>"(3.1.53)",
    ButtonStyle->"Hyperlink"],
  " becomes the diffusion equation,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["T",
                  FontSlant->"Italic"]}]]}], \(\[PartialD]t\)], "=", 
        RowBox[{"\[Chi]", 
          FractionBox[
            RowBox[{\(\[PartialD]\^2\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["T",
                    FontSlant->"Italic"]}]]}], \(\[PartialD]x\^2\)]}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(3.1.55)"],

Cell[TextData[{
  "\tWe look for a solution of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["T",
                  FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], "=", 
          " ", \(\(f(t)\)\ \(\[Psi](x)\)\)}], TraditionalForm]]],
  ". Substituting this expression into Eq. ",
  ButtonBox["(3.1.55)",
    ButtonData:>"(3.1.55)",
    ButtonStyle->"Hyperlink"],
  " and dividing by ",
  Cell[BoxData[
      \(TraditionalForm\`\(f(t)\)\ \(\[Psi](x)\)\)]],
  " yields"
}], "Text",
  CellTags->"i:43"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(f(
                t)\)\) \[PartialD]f\/\[PartialD]t = \(\[Chi]\/\(\[Psi](
                x)\)\) \[PartialD]\^2 \[Psi]\/\[PartialD]x\^2\)]],
  ","
}], "NumberedEquation",
  CellTags->"(3.1.56)"],

Cell[TextData[{
  "which can be separated into two ODEs. The ",
  "left-hand",
  " side is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", and the right-hand side is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". Therefore, Eq. ",
  ButtonBox["(3.1.56)",
    ButtonData:>"(3.1.56)",
    ButtonStyle->"Hyperlink"],
  " can only be satisfied if each side equals a constant, \[Lambda]:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(f(
                t)\)\) \[PartialD]f\/\[PartialD]t = \[Lambda]\)]],
  ","
}], "NumberedEquation",
  CellTags->"(3.1.57)"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Chi]\/\(\[Psi](
                x)\)\) \[PartialD]\^2 \[Psi]\/\[PartialD]x\^2 = \
\[Lambda]\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.58)"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Eigenvalue Problem", "Subsubsection",
  CellTags->"i:32"],

Cell[TextData[{
  "The separation constant ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " and the functions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x)\)]],
  " are determined by the homogeneous boundary conditions. Let us assume \
Dirichlet boundary conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](0) = \(\[Psi](L) = 0\)\)]],
  ". With these boundary conditions, Eq. ",
  ButtonBox["(3.1.58)",
    ButtonData:>"(3.1.58)",
    ButtonStyle->"Hyperlink"],
  " may be recognized as an eigenvalue problem; in fact, it is the identical \
eigenvalue problem encountered previously for the wave equation! The solution \
for the eigenmodes is, as before, "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Psi](x)\  = \ 
      D\ \(sin(n\ \[Pi]\ x/L)\)\)]]], "NumberedEquation",
  CellTags->"(3.1.59)"],

Cell["and", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = \(\[Lambda]\_n = \(-\[Chi]\)\ \((n\ \
\[Pi]/L)\)\^2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... \)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.60)"],

Cell[TextData[{
  " In addition, the solution of Eq. ",
  ButtonBox["(3.1.57)",
    ButtonData:>"(3.1.57)",
    ButtonStyle->"Hyperlink"],
  ","
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \ A\ \[ExponentialE]\^\(\[Lambda]\ t\)\)]],
  ","
}], "Text"],

Cell["\<\
provides the time-dependent amplitude for each eigenmode. By \
forming a linear superposition of these solutions, we obtain the general \
solution to the heat equation for the temperature perturbation away from \
equilibrium:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["T",
                  FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], " ", "=", 
          " ", \(\[Sum]\+\(n = 1\)\%\[Infinity] A\_n\ \[ExponentialE]\^\(\(\
\[Lambda]\_n\) t\)\ sin\ \((n\ \[Pi]\ x/L)\)\)}], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->{"(3.1.61)", "i:33"}],

Cell[TextData[{
  "As in the wave equation solution, we have absorbed the constant ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " into the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  ". These coefficients are found by matching the initial condition, Eq. ",
  ButtonBox["(3.1.54)",
    ButtonData:>"(3.1.54)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["T",
                  FontSlant->"Italic"]}]], "(", \(x, 0\), ")"}], 
          "=", \(\[Sum]\+\(n = 1\)\%\[Infinity] A\_n\ sin\ \((n\ \[Pi]\ x/
                      L)\) = \(T\_o\)(x) - \(T\_eq\)(x)\)}], 
        TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "This is a Fourier sine series, so the ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  "'s are determined as"
}], "Text",
  CellTags->"i:34"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`A\_n = \(2\/L\) \(\[Integral]\_0\%L\([\(T\_o\)(
                  x) - \(T\_eq\)(x)]\) \(sin(
              n\ \[Pi]\ x/L)\) \[DifferentialD]x\)\)]]], "NumberedEquation",
  CellTags->"(3.1.62)"],

Cell[TextData[{
  "Equations ",
  ButtonBox["(3.1.61)",
    ButtonData:>"(3.1.61)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.1.62)",
    ButtonData:>"(3.1.62)",
    ButtonStyle->"Hyperlink"],
  " are the solution for the deviation from equilibrium for the case of \
Dirichlet boundary conditions in a uniform slab. The solution is again made \
up of a sum of eigenmodes with the same spatial form as those for the wave \
equation, shown in Cell ",
  ButtonBox["3.1",
    ButtonData:>"Cell 3.1",
    ButtonStyle->"Hyperlink"],
  ". But now the amplitudes of the modes decay with time with rate ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[Lambda]\_n\)\(|\)\)\)]],
  ", rather than oscillating as in the wave equation. The result is that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "\[Rule]", "0", " "}], 
        TraditionalForm]]],
  ". Thus, the full solution for ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", Eq. ",
  ButtonBox["(3.1.48)",
    ButtonData:>"(3.1.48)",
    ButtonStyle->"Hyperlink"],
  ", approaches the equilibrium solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_eq\)(x)\)]],
  " in the long time limit. The time evolution of several of these eigenmodes \
is displayed in Cell ",
  ButtonBox["3.7",
    ButtonData:>"Cell 3.7",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:35"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(L = 1; \[Chi] = 1;\), "\n", 
    \(\(\[Lambda][n_]\  = \ \(-\[Chi]\) \((n\ Pi\ /L)\)^2\ ;\)\), "\n", 
    \(\(p[n_, t_]\  := \ 
        Plot[Exp[\[Lambda][n] t]\ Sin[n\ Pi\ x], {x, 0, L}, 
          DisplayFunction \[Rule] Identity, PlotRange \[Rule] {\(-1\), 1}, 
          PlotLabel \[Rule] "\<n = \>" <> ToString[n]];\)\), "\n", 
    \(\(Table[
        Show[GraphicsArray[Table[{{p[1, t], p[2, t]}, {p[3, t], p[4, t]}}]], 
          DisplayFunction \[Rule] $DisplayFunction], {t, 0, 
          0.25,  .0125}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.7"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .42431 L
.08255 .47871 L
.10458 .53054 L
.12507 .56939 L
.14415 .596 L
.14918 .60135 L
.15465 .60634 L
.15946 .61001 L
.16457 .61316 L
.16917 .61533 L
.17178 .61628 L
.17423 .61699 L
.17538 .61726 L
.17647 .61748 L
.17746 .61764 L
.17852 .61779 L
.17967 .61791 L
.18073 .61798 L
.182 .61803 L
.18314 .61803 L
.18435 .61798 L
.18547 .6179 L
.1867 .61777 L
.18802 .61758 L
.19071 .61702 L
.19317 .61633 L
.1979 .61447 L
.20239 .61209 L
.21236 .60467 L
.22321 .59334 L
.24299 .56438 L
.26399 .52296 L
.30174 .42683 L
.34195 .30695 L
.38063 .19166 L
.40028 .13864 L
.42177 .08806 L
.44253 .04863 L
.4614 .02227 L
.47149 .01222 L
.47611 .00859 L
.48101 .00544 L
.4835 .00411 L
.48624 .00286 L
.48876 .00191 L
.49106 .00121 L
.49378 .00059 L
.49527 .00034 L
.49596 .00025 L
Mistroke
.49669 .00017 L
.498 6e-05 L
.49921 1e-05 L
.49996 0 L
.50065 1e-05 L
.50196 6e-05 L
.50313 .00015 L
.50438 .00029 L
.50556 .00047 L
.50663 .00066 L
.50926 .0013 L
.51175 .00209 L
.5167 .00421 L
.52208 .00735 L
.53169 .01507 L
.54056 .02456 L
.55926 .05164 L
.57988 .09163 L
.62014 .19384 L
.65888 .30946 L
.70007 .43193 L
.72063 .4867 L
.73974 .53106 L
.75939 .56839 L
.77791 .59466 L
.78775 .60477 L
.79293 .60897 L
.7984 .61255 L
.80302 .61488 L
.80546 .61586 L
.80809 .61671 L
.8105 .6173 L
.8127 .61769 L
.81375 .61783 L
.81491 .61794 L
.81599 .618 L
.817 .61803 L
.81818 .61803 L
.81941 .61798 L
.82047 .6179 L
.82163 .61777 L
.82287 .61759 L
.82421 .61735 L
.82661 .61677 L
.82905 .61601 L
.83134 .61512 L
.83564 .61304 L
.84078 .60984 L
.84552 .6062 L
.85624 .59556 L
Mistroke
.87498 .56932 L
.89561 .53014 L
.93591 .42895 L
.97471 .31355 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .45981 L
.08255 .52527 L
.0932 .55403 L
.10458 .57945 L
.11009 .58961 L
.11531 .59784 L
.12038 .60454 L
.12507 .60956 L
.12951 .61325 L
.13178 .61474 L
.13422 .61603 L
.13549 .61658 L
.13666 .617 L
.13784 .61736 L
.13895 .61762 L
.14022 .61785 L
.1409 .61793 L
.14161 .61799 L
.1423 .61803 L
.14295 .61803 L
.14415 .61799 L
.14531 .61787 L
.14656 .61767 L
.14773 .61739 L
.14881 .61708 L
.15143 .61606 L
.15392 .61475 L
.15886 .61117 L
.16423 .60583 L
.17383 .59259 L
.1827 .5763 L
.20137 .53043 L
.22197 .46442 L
.26217 .30793 L
.30086 .15709 L
.32051 .09318 L
.3309 .06498 L
.342 .03993 L
.35275 .02114 L
.35784 .01426 L
.36253 .00909 L
.36724 .00504 L
.36972 .00339 L
.37235 .00199 L
.37463 .00107 L
.37573 .00073 L
.37677 .00047 L
.37799 .00024 L
.37911 9e-05 L
Mistroke
.38031 1e-05 L
.38162 1e-05 L
.38227 5e-05 L
.38296 .00011 L
.38419 .00028 L
.38551 .00056 L
.38695 .00097 L
.38955 .00199 L
.39197 .00326 L
.39649 .00647 L
.40134 .01111 L
.40698 .01804 L
.41232 .02609 L
.42232 .0449 L
.44227 .09574 L
.4607 .15587 L
.50002 .3091 L
.53782 .45692 L
.55884 .52554 L
.56803 .55063 L
.57808 .57397 L
.58722 .59118 L
.59696 .60501 L
.60236 .61057 L
.60726 .6143 L
.60962 .61565 L
.61086 .61623 L
.61218 .61677 L
.61333 .61715 L
.61459 .6175 L
.61574 .61774 L
.61682 .6179 L
.61808 .61801 L
.61871 .61803 L
.61941 .61803 L
.62065 .61796 L
.62181 .61783 L
.62248 .61772 L
.62318 .61757 L
.62443 .61725 L
.62578 .61682 L
.62725 .61622 L
.62973 .61497 L
.63238 .61327 L
.63715 .60926 L
.64214 .6038 L
.64686 .59746 L
.6557 .5826 L
.67568 .53569 L
.69413 .4784 L
Mistroke
.7335 .32774 L
.77136 .17771 L
.79241 .10603 L
.81166 .05399 L
.82118 .03415 L
.8262 .0254 L
.83155 .01745 L
.8367 .01118 L
.84136 .00668 L
.84361 .00491 L
.84604 .00331 L
.84835 .00208 L
.85045 .0012 L
.85159 .00083 L
.85283 .0005 L
.85414 .00024 L
.85538 8e-05 L
.85653 1e-05 L
.85776 1e-05 L
.85881 7e-05 L
.85997 .00021 L
.86063 .00033 L
.86132 .00047 L
.86256 .00079 L
.86535 .00181 L
.86777 .00303 L
.87041 .00472 L
.87569 .00921 L
.88133 .0156 L
.89148 .03117 L
.90173 .05195 L
.91284 .07976 L
.933 .14228 L
.97393 .29982 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34829 L
.10458 .39038 L
.14415 .42849 L
.18221 .46323 L
.22272 .49753 L
.26171 .52738 L
.30316 .55515 L
.34309 .57755 L
.3815 .59472 L
.40095 .60168 L
.42237 .60796 L
.44268 .61253 L
.45178 .61413 L
.46172 .61557 L
.4671 .61622 L
.4721 .61673 L
.47727 .61717 L
.48196 .61749 L
.48658 .61773 L
.4887 .61782 L
.49093 .6179 L
.49332 .61796 L
.49438 .61798 L
.49552 .618 L
.49675 .61802 L
.49789 .61803 L
.49859 .61803 L
.49925 .61803 L
.50049 .61803 L
.50163 .61803 L
.50286 .61802 L
.50401 .61801 L
.50508 .61799 L
.50754 .61794 L
.51014 .61786 L
.51268 .61776 L
.51504 .61765 L
.5204 .61733 L
.5293 .61659 L
.53882 .6155 L
.54906 .614 L
.56016 .61197 L
.58032 .60725 L
.62123 .59365 L
.66064 .57566 L
.69852 .55411 L
.73886 .52697 L
.77769 .49721 L
.81897 .4622 L
Mistroke
.85873 .42578 L
.89697 .38885 L
.93767 .34818 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .38693 L
.10458 .466 L
.14415 .52938 L
.18221 .57629 L
.20178 .59404 L
.21267 .60187 L
.22272 .60776 L
.23293 .61241 L
.23832 .6143 L
.24402 .61589 L
.24641 .61642 L
.24897 .61691 L
.25119 .61726 L
.25361 .61757 L
.25507 .61772 L
.25643 .61783 L
.25773 .61792 L
.2584 .61795 L
.25912 .61798 L
.25983 .618 L
.26048 .61802 L
.26176 .61803 L
.26293 .61803 L
.26416 .618 L
.26538 .61795 L
.26607 .61792 L
.26671 .61788 L
.26912 .61768 L
.27131 .61744 L
.27364 .61711 L
.27847 .61619 L
.2838 .61482 L
.29326 .61145 L
.30213 .60721 L
.32232 .59381 L
.34082 .57709 L
.38045 .52825 L
.41855 .46718 L
.45912 .39136 L
.49816 .31277 L
.53966 .22909 L
.57964 .15402 L
.61811 .09187 L
.63759 .06548 L
.65902 .0411 L
.67938 .02289 L
.69843 .01052 L
.70884 .00574 L
.71396 .00391 L
Mistroke
.71872 .00252 L
.72301 .00153 L
.72758 .00074 L
.7302 .00042 L
.73148 .00029 L
.73266 .0002 L
.73371 .00013 L
.73487 7e-05 L
.73603 3e-05 L
.73725 0 L
.73856 0 L
.73977 2e-05 L
.7404 4e-05 L
.7411 6e-05 L
.74251 .00013 L
.74375 .00021 L
.74508 .00033 L
.74748 .00059 L
.74985 .00093 L
.75235 .00136 L
.7568 .00235 L
.76198 .00383 L
.7668 .00553 L
.77773 .0105 L
.78828 .01678 L
.79823 .024 L
.81683 .04076 L
.85534 .08793 L
.89632 .15361 L
.93577 .22759 L
.97371 .30396 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<Z0001mB000`400?l00000o`00003ooooooooo
oooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00
oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]
ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooooooooooo
ooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooo
ooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo
003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oooooooooooooooooo
obgooooo000looooo`Co000000?o410@ooooooooool0oooooon=ooooo`Co000000?o410@oooooooo
ool0oooooomEooooo`00?_ooool00ol0003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool0
oooooomGooooo`00?_ooool00ol0003oooooooooo`06ooooo`?o0000Toooool5o`000>oooooo00?o
0000ooooooooool01_ooool3o`0006kooooo1Ol0002Dooooo`Co0000@_ooool003;ooooo1ol00005
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0T?ooool3o`0000Gooooo1?l0003O
ooooo`Oo00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06cooooo0_l00004
ooooo`?o0000T?ooool2o`0000Cooooo0_l00010ooooo`00?_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo08oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Xoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo08_ooooo0_l00008ooooo`03o`000?oooooooooo03gooooo000nooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0SOooool2o`0000kooooo00?o0000oooooooo
ool0ioooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0??ooool003kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2<ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0i_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo06Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`29ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0>oooool003cooooo00?o0000odA4A?l000002?oo
ool2o`0008cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3Sooooo`03o`000?m4
A4Co000000Sooooo0_l0001Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Qooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo000looooo`03olc<c?mEEEGo
000000Sooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo0>;ooooo00?oc<c<oeEEEOl000002?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo03[ooooo0017ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`3/ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>Oooool004Oo
oooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0>_o
oooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo087o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0hooooo`00Aoooool00ol0003ooooo
ooooo`28ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0joooool00ol0003ooooo
ooooo`1Vooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0POooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo03Sooooo0017ooooo`;o0000R?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo0>[ooooo0_l0001Vooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Oooooo0017
ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3Y
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=oooool004Oooooo00?o0000oooo
ooooool0Q_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0>Wooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07kooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0fooooo`00Aoooool00ol0003oooooooooo`25ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0j?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo03Kooooo0017ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`3Wooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
=Oooool004Oooooo0_l00025ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0iooo
ool2o`0006?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0=?ooool004Oooooo00?o0000ooooooooool0Poooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0>Kooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0dooooo`00Aoooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0iOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
03?ooooo0017ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`3Uooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<oooool004Oooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0>Cooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0booooo`00Aoooool2o`0008;ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`3Tooooo`;o0000H_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0booooo`00Aoooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0hoooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0Moooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03;ooooo000Qoooo
o`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01_ooool00olQ8B7oV9RHooooo`04
ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1_ooool00ol0003oooooooooo`20ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0_?ooool01?nj^[[o410@o`000?mgMgL6ooooo`03
oeEEEOl0003oEEEE00Kooooo00?o8B4QoiRHV?ooool01?ooool01_nHV9So410@o`000?l0003oA4A4
onk^kPKooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo07Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0aooooo`008?ooool01_o<
c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00006ooooo`03oiRHV?m4A4Cooooo00Cooooo00Ko
410@ohN7QoooooooooooogMgMom4A4@6ooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`2kooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3
o`0000Kooooo00?oV9RHodA4A?ooool01?ooool01_l@413oQhN7ooooooooooooMgMgodA4A0Kooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Gooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0aooooo`008?ooool01_m4A4CoZJVYoooo
ooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED01_ooool00oo^k^ko0000onk^kP09ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo0;[ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003o
EEEE00Kooooo00?ok^k^o`000?o^k^h02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1eooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0<Oooool001Oooooo1ol00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03Oooool00omEEEGoV9RHooooo`07ooooo`03onk^k_l0003ooooo
00Gooooo0ol0001nooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0/Oooool7o`00
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03oeEEEOnHV9Sooooo
00Oooooo00?ok^k^o`000?ooool01Oooool3o`0005kooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1cooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0<?ooool0023o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03ojVYZOm4A4Cooooo00?o
oooo00Ko410@oiRHV?ooooooooooogMgMomVIVH6ooooo`03o`000?oooooooooo07gooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03Oooool00onYZJWoA4A4ooooo`03ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV
1_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo033ooooo000Pooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003ok^k^ooooo`02ooooo`05o`000?lQ
8B7o0000o`000?mVIVH01oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0^?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo
00?o0000onk^k_ooool00_ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0`ooooo`008?ooool01_m4A4CoZJVYooooooooooooZJVYodA4
A13ooooo00?oEEEEoiRHV?ooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
07cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2hooooo`06odA4A?nYZJWooooo
oooooonYZJWoA4A44?ooool00omEEEGoV9RHooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0_ooooo`008?ooool01_o<c<co<S8bonk^k_o^
k^ko<S8bolc<c0cooooo00Ko410@ooooooooooooooooojVYZOm4A4@3ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
0;Oooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`06oa0@4?oooooooooooooooonYZJWo
A4A40oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0;oooool0027ooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool6o`0000?ooooo1Ol00007ooooo`;o
0000O?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0;Sooooo00Co^[Zjoa0@4?l@
413oc<c<3Oooool6o`0000?ooooo1Ol00007ooooo`;o0000GOooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0_oooo
o`00Aoooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0gOooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02kooooo0017ooooo`03o`00
0?oooooooooo07_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`3Mooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0;_ooool004Oooooo00?o0000ooooooooool0N_oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0=gooooo00?o0000ooooooooool0Fooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0^ooooo`00Aoooool00ol0003oooooooooo`1jooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0g?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02gooooo0017ooooo`;o0000N_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
0=cooooo0_l0001Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02gooooo0017ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`3Kooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0;Oooool004Oooooo00?o0000ooooooooool0N?ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo0=_ooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0/ooooo`00Aoooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0foooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0Joooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02cooooo0017
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3J
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1[
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0;?ooool004Oooooo0_l0001hoooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0f_ooool2o`0005[ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0:oooool004Oooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo0=Wooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo06Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0[ooooo`00
Aoooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
fOooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
JOooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02_ooooo0017ooooo`03o`000?oo
oooooooo07Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`3Iooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0:_ooool004Oooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo0=Sooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0Zooooo`00Aoooool2o`0007Kooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`3Hooooo`;o0000FOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Zooooo`00Aoooool00ol0003o
ooooooooo`1eooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0eoooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo02Wooooo000Zooooo`04okZj^_l@413o0000ogMgM`Ko
oooo00?oEEEEo`000?mEEED01?ooool01_nHV9So410@o`000?l0003oA4A4onk^kPKooooo00?o0000
ooooooooool0M?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0;[ooooo00Co^[Zj
oa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06oiRHV?l@413o0000o`000?m4A4Co
k^k^1_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02Wooooo000Yooooo`06olc<
c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7QoooooooooooogMgMom4
A4@6ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`2iooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7Qooo
ooooooooogMgMom4A4@6ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0:Oooool0
02Wooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0^?ooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mE
EED02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0:?ooool0023ooooo1ol00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3_ooool00oo^k^ko0000ooooo`05ooooo`?o0000Loooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo0:oooooo1ol00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3_ooool00oo^k^ko0000ooooo`05ooooo`?o0000E_ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Xooooo`00:Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko410@oiRHV?oooooooooo
ogMgMomVIVH6ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`2hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_l@413o
V9RHooooooooooooMgMgofIVIPKooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0X
ooooo`00:Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q
8Ol0003o0000ofIVIP07ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`2gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool0
1Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Xooooo`00:Oooool01_m4A4CoZJVYooooooooooooZJVYodA4A0cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
]oooool01_m4A4CoZJVYooooooooooooZJVYodA4A0cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1Eooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0HOooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo02Oooooo000Yooooo`06olc<c?lb<S;ok^k^onk^
k_lb<S;oc<c<3?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`2fooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<
3?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
9oooool002[ooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool5o`0000Oooooo0_l0001cooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool0]oooool01?nj^[[o410@oa0@4?o<c<`=ooooo`Go
00001oooool2o`0005Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool09oooool004Oooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0=Cooooo00?o0000ooooooooool0
EOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0Wooooo`00Aoooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool0doooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo02Kooooo0017ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`3Cooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09_ooool0
04Oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
0=;ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Vooooo`00Aoooool2o`00077o
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`3Booooo`;o0000EOooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Uooooo`00Aoooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool0d_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Gooooo
0017ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`3Aooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09Oooool004Oooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0=7ooooo00?o0000
ooooooooool0Doooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0Uooooo`00Aoooool2o`0006oooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`3Aooooo`;o0000E?ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Toooo
o`00Aoooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool0d?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Cooooo0017ooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`3@ooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool09?ooool004Oooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo0=3ooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0Tooooo`00Aoooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0coooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo02?ooooo0017ooooo`;o0000K_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
0<oooooo0_l0001Booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo0017ooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`3?ooooo`03o`000?oooooooooo057o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool08oooool004Oooooo00?o0000ooooooooool0K?ooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo0<kooooo00?o0000ooooooooool0DOooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0Sooooo`008Oooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo
1_l00003ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1_ooool00ol0003oooooooooo`1/oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool0Z?ooool01?nj^[[o410@o`000?mgMgL6
ooooo`03oeEEEOl0003oEEEE00Cooooo1_l00003ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^
1_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02;ooooo000Pooooo`06olc<c?lb
<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00?oV9RHo`000?o<c<`00_ooool01_l@413o
oooooooooooooooo410@ohN7Q`;ooooo00?oMgMgodA4A?ooool01Oooool00ol0003oooooooooo`1[
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0Yoooool01_o<c<co<S8bonk^k_o^
k^ko8B4QojVYZ@Gooooo0ol00004ooooo`03oiRHV?l0003oc<c<00;ooooo00Ko410@oooooooooooo
oooooa0@4?n7QhL2ooooo`03ogMgMom4A4Cooooo00Gooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Rooooo`008?ooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEE
o`000?mEEED01Oooool00onHV9So0000olc<c00:ooooo`03o`000?oooooooooo00Cooooo0ol0001[
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Y_ooool01_m4A4CoZJVYoooooooo
ooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED01Oooool00onHV9So0000olc<c00:ooooo`03o`00
0?oooooooooo00Cooooo0ol0001@ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02;ooooo000Gooooo`Oo00000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?oZJVYoa0@4?o<c<`02?oo
ool00oo^k^ko0000ooooo`05ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`2Mooooo`Oo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00cooooo00?oZJVYoa0@4?o<c<`02?ooool00oo^k^ko0000ooooo`05ooooo`03o`000?oo
oooooooo053ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1Fooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool08_ooool0023ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0=ooooo`03olc<c?l@413oc<c<00?ooooo00Ko410@oiRHV?ooooooooooogMg
MomVIVH6ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`2Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00oo<c<co410@
olc<c003ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV1_ooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo027ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool00onYZJWo<S8booooo`02ooooo`05o`000?lQ8B7o0000o`000?mVIVH01oooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0YOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?oZJVYoc8b<_ooool00_ooool01Ol0
003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Q
ooooo`008?ooool01_m4A4CoZJVYooooooooooooZJVYodA4A17ooooo00Go0000oooooooooooooooo
o`00000;ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`2Uooooo`06odA4A?nYZJWooooooooooonYZJWoA4A44Oooool01Ol0003ooooooooooooooooo
000000_ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Qooooo`008?ooool01_o<
c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00Ko0000ohN7Qoo^k^koooooogMgMolb<S83ooooo`03
o`000?oooooooooo00Wooooo0_l0001Zooooo`03o`000?oooooooooo05Gooooo00?o0000oooooooo
ool0YOooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00Ko0000ohN7Qoo^k^koooooogMg
Molb<S83ooooo`03o`000?oooooooooo00Wooooo0_l0001@ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo027ooooo
000Qooooo`04okZj^_l@413o410@olc<c0gooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h3oooo
o`Go00001oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool0YOooool01?nj^[[o410@oa0@4?o<c<`=ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^
0oooool5o`0000Oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo05?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Pooooo`00Aooo
ool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0booo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Dooo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo023ooooo0017ooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool08?ooool004Oooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0Pooooo`00Aoooool2o`0006Wooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`3:ooooo`;o0000Coooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo057o
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Oooooo`00Aoooool00ol0003ooooo
ooooo`0^ooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool6o`0002;o
oooo00So0000oooooooooooooooookZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01ooo
ool2o`000003oa0@4?oooooooooo02Cooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000
oeEEE@04ooooo`06onk^k_m4A4Co0000o`000?mEEEGok^k^1?ooool00ol0003oooooooooo`0Ooooo
o`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool01_o^k^koA4A4o`000?l0
003oA4A4onk^kRoooooo1?l000000ol@413oooooooooo`1Nooooo`03o`000?oooooooooo02oooooo
00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`Ko00002?ooool00ol0003o
ooooooooo`0Kooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01oooool2o`00
0003oa0@4?oooooooooo00gooooo00?o0000ooooooooool05?ooool01?nj^[[o410@o`000?mgMgL6
ooooo`03oeEEEOl0003oEEEE00Cooooo00Kok^k^odA4A?l0003o0000oeEEEOo^k^hVooooo`04o`00
0?l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool01_o^k^koA4A4o`000?l0003oA4A4
onk^kRkooooo1Ol000000ol@413oooooooooo`0Jooooo`00Aoooool00ol0003oooooooooo`0]oooo
o`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00?oV9RHo`000?o<c<`00_oo
ool00ol@413oooooooooo`0Pooooo`05o`000?ooooooooooolc<c?lb<S800_o^k^h00olQ8B7oZJVY
ooooo`04ooooo`?o00002?ooool00ol0003oooooooooo`0Tooooo`06olc<c?lb<S;ok^k^onk^k_lQ
8B7oZJVY1Oooool3o`0000Cooooo00KoEEEEogMgMoooooooooooogMgMomEEED5ooooo`03o`000?oo
oooooooo01gooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool01_lb<S;o
MgMgonk^k_o^k^koMgMgoc8b<S7ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0^
ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00?oV9RHo`000?o<c<`0
0_ooool00ol@413oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo00Koc<c<oc8b<_o^k^ko
k^k^ob4Q8OnYZJT5ooooo`?o00002?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01?ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool01_mEEEGoMgMgoooo
ooooooooMgMgoeEEEBGooooo00Koc<c<o`000?o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool0
1_lb<S;oMgMgonk^k_o^k^koMgMgoc8b<Rkooooo00Co0000oooooooooooo00007_ooool004Oooooo
00?o0000ooooooooool0;Oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`00
0?mEEED01Oooool00onHV9So0000olc<c00Tooooo`05o`000?ooooooooooodA4A?nYZJT00_ooool0
0onYZJWo<S8booooo`04ooooo`03oeEEEOl0003oEEEE00Cooooo1_l0000Uooooo`06odA4A?nYZJWo
oooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@04ooooo`03oa0@4?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`06odA4A?nYZJWooooooooooonY
ZJWo<S8b1Oooool00omEEEGo0000oeEEE@04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo00KoA4A4ojVY
ZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Gooooo00?oV9RHo`000?o<c<`02Ooo
ool00ol0003oooooooooo`0Kooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo
0000oeEEE@04ooooo`Ko00004?ooool00ol0003oooooooooo`0Booooo`06odA4A?nYZJWooooooooo
oonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@04ooooo`03oa0@4?oooooooooo00;ooooo00?o0000
ooooooooool08oooool01_m4A4Co0000ooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02gooooo00?o0000ooooool00000
7_ooool004Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00cooooo00?oZJVYoa0@4?o<c<`08_ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool02_ooool01OmVIVKoZJVYoooooooooooo000002Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02_ooool01_lb<S;oMgMgonk^k_o^k^koMgMgoc8b<S7ooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool0
0onYZJWo410@olc<c008ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0:ooooo`05ofIVI_nYZJWoooooooooool000004Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003ok^k^oooo
o`02ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0:ooooo`06oc8b<_mgMgOok^k^onk^k_mgMgOo<S8b;oooool00ol0003oooooo`00000Nooooo`00
Aoooool2o`0002kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03olc<
c?l@413oc<c<027ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00[o
oooo00Gok^k^ob4Q8Oo^k^koooooo`00000Vooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02_ooool01_l0003oEEEEonk^k_ooooooMgMgoeEEE@Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?ogMgMo`000?l000000_l0
00000ooMgMgoooooooooo`0_ooooo`03o`000?oooooooooo063ooooo0_l0000_ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03Oooool00oo<c<co410@olc<c007ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05onk^k_lQ
8B7ok^k^ooooool000004Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02_ooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEBGooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0:ooooo`03omgMgOl0003o000000;o000000?ogMgMoooo
ooooool0;Oooool00ol0003oooooo`00000Nooooo`00Aoooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00onYZJWo<S8booooo`0Pooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`04ojVYZOmVIVKooooo
o`0002Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`06ob4Q8OmVIVKo
0000o`000?mEEEGok^k^1_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02_ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<S7ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03_ooool00onYZJWo<S8booooo`05ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0;ooooo`04ojVYZOmVIVKoooooo`00017ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko8B4Q
ofIVI_l0003o0000oeEEEOo^k^hUooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2_ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<Roooooo00?o0000ooooool000007_ooool004Oo
oooo00?o0000ooooooooool0;Oooool01_m4A4CoZJVYooooooooooooZJVYodA4A17ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`02ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A4
3_ooool00om4A4Coc<c<o`00000Vooooo`06odA4A?nYZJWooooooooooonYZJWoA4A43?ooool00on7
QhOoIVIVooooo`09ooooo`03o`000?oooooooooo01cooooo00KoA4A4ojVYZOooooooooooojVYZOm4
A4@<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo02kooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@Aooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool01_m4A4CoZJVYooooooooooooZJVY
odA4A0kooooo00?oA4A4olc<c?l000004_ooool00ol0003oooooooooo`0Aooooo`06odA4A?nYZJWo
oooooooooonYZJWoA4A43?ooool00on7QhOoIVIVooooo`0Xooooo`06o`000?nYZJWooooooooooonY
ZJWoA4A43?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo0_l0000Noooo
o`00Aoooool00ol0003oooooooooo`0]ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool0
1_l0003oQhN7onk^k_ooooooMgMgoc8b<R3ooooo00?o0000ooooooooool00_ooool01_o<c<co<S8b
onk^k_o^k^ko<S8bolc<c0kooooo00?ogMgModA4A?l000009_ooool01_o<c<co<S8bonk^k_o^k^ko
<S8bolc<c0gooooo00?o<S8bofIVI_oMgMd02Oooool00ol0003oooooooooo`0Kooooo`06olc<c?lb
<S;ok^k^onk^k_lb<S;oc<c<3?ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<Roooooo00?o0000
odA4A?l00000H_ooool00ol0003oooooooooo`0^ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<
3?ooool01_l0003oQhN7onk^k_ooooooMgMgoc8b<PKooooo00?o0000ooooooooool07?ooool01_o<
c<co<S8bonk^k_o^k^ko<S8bolc<c0kooooo00?ogMgModA4A?l000004_ooool00ol0003ooooooooo
o`0Aooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3Oooool00olb<S;oIVIVomgMg@0Vooooo`03
o`000?o<c<co<S8b00;ok^k^00?o<S8bolc<c?ooool02oooool01_lb<S;oIVIVonk^k_o^k^koIVIV
oc8b<Roooooo0ol0000Nooooo`00Aoooool00ol0003oooooooooo`0^ooooo`04okZj^_l@413o410@
olc<c0gooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^hPooooo`03o`000?oooooooooo00?ooooo
00Co^[Zjoa0@4?l@413oc<c<4?ooool00on7QhOo0000ooooo`0Vooooo`04okZj^_l@413o410@olc<
c0oooooo00CoMgMgoa0@4?l0003o8B4Q1oooool00ol0003oooooooooo`0Looooo`04okZj^_l@413o
410@olc<c0gooooo00Kok^k^odA4A?l0003o0000odA4A?o^k^h_ooooo`03olc<c?mEEEGo000006;o
oooo00?o0000ooooooooool0;oooool01?nj^[[o410@oa0@4?o<c<`=ooooo`06ojVYZOlb<S;o0000
o`000?mEEEGok^k^1_ooool00ol0003oooooooooo`0Mooooo`04okZj^_l@413o410@olc<c13ooooo
00?oQhN7o`000?ooool04Oooool00ol0003oooooooooo`0Booooo`04okZj^_l@413o410@olc<c0oo
oooo00CoMgMgoa0@4?l0003o8B4Q9?ooool00ol0003ooooookZj^P02oa0@4003olc<c?oooooooooo
00_ooooo00Kok^k^odA4A?l0003o0000odA4A?o^k^h_ooooo`03olc<c?l0003o000001kooooo0017
ooooo`;o0000IOooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo0<Oooooo0_l0001<
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo01gooooo0017ooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04Oooooo00?o0000oooo
ooooool07?ooool004Oooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo0<Kooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Looooo`00
Aoooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0
a_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01cooooo0017ooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`35ooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool07?ooool003ooooooool00012o`0005?oooooool00012
o`0001Kooooo0017ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07?ooool004Oo
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool2o`00067ooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo01cooooo0017ooooo`;o0000Hoooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0H?ooool2o`0004[ooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo06Sooooo
0017ooooo`;o0000H_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool0H?ooool2o`0004[ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo06Sooooo0017ooooo`;o0000H_ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool2o`0004[ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo06Wooooo0017oooo
o`03o`000?oooooo0000067ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo067ooooo0_l0001:ooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`1Yooooo`00Aoooool00ol0003oooooo`00001Pooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooo000004Sooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo06Wooooo0017ooooo`03o`000?oooooo0000063ooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo06;ooooo00?o0000ooooool00000
B?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
JOooool004Oooooo00Co0000oooooooooooo0000Goooool00ol0003oooooooooo`1Xooooo`03o`00
0?oooooooooo05gooooo00?o0000ooooooooool0H_ooool00ol0003oooooo`000018ooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1Zooooo`00Aooo
ool2o`000003ooooool0003ooooo05gooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo06;ooooo0_l000000ooooooo0000ooooo`16ooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1Zooooo`00Aoooool0
1?l0003oooooooooool0001Nooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0G?oo
ool00ol0003oooooooooo`1Sooooo`04o`000?ooooooooooo`0004Kooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo06[ooooo0017ooooo`05o`000?oo
ooooooooooooool00000GOooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool0Hoooool01?l0003oooooooooool00016ooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1Zooooo`00Aoooool01Ol0003ooooo
oooooooooooo000005cooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo06?ooooo00Co0000oooooooooooo0000A_ooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0Joooool004Oooooo00Go0000oooooooo
ooooooooo`00001Looooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0F_ooool00ol0
003oooooooooo`1Tooooo`05o`000?ooooooooooooooool00000A?ooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0Joooool004Oooooo0_l00003oooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo06Cooooo0_l00002ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo06_ooooo0017ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool0I?ooool01Ol0003ooooooooooooooooo0000
04Cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
06cooooo0017ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0IOooool01Ol0003o
oooooooooooooooo000004Cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo06cooooo0017ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo05Oooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0D_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo06cooooo0017ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo05Oooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo06cooooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1Fooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1Vooooo`;o00000ooo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`1]ooooo`00Aoooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo06Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo05?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1]ooooo`008Oooool01?nj
^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo1_l00003ooooo`06oiRHV?l@413o
0000o`000?m4A4Cok^k^1_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Cooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo043ooooo
00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`Ko00000oooool01_nHV9So
410@o`000?l0003oA4A4onk^kPKooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1]
ooooo`008?ooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`03oiRHV?l0
003oc<c<00;ooooo00Ko410@oooooooooooooooooa0@4?n7QhL2ooooo`03ogMgMom4A4Cooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`10ooooo`06olc<c?lb<S;ok^k^onk^
k_lQ8B7oZJVY1Oooool3o`0000Cooooo00?oV9RHo`000?o<c<`00_ooool01_l@413ooooooooooooo
oooo410@ohN7Q`;ooooo00?oMgMgodA4A?ooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo06gooooo000Pooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo
0000oeEEE@05ooooo`03oiRHV?l0003oc<c<00[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo043ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85
ooooo`03oeEEEOl0003oEEEE00Gooooo00?oV9RHo`000?o<c<`02_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0K_ooool0023ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0<ooooo`03ojVYZOl@413oc<c<00Sooooo00?ok^k^o`00
0?ooool01Oooool3o`0000Gooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1coooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00cooooo00?oZJVYoa0@4?o<c<`02?ooool00oo^k^ko0000ooooo`05oooo
o`?o00001?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo05Gooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`1^ooooo`008?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00gooooo00?oc<c<oa0@4?o<c<`00oooool01_l@413oV9RHooooooooooooMgMg
ofIVIPKooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03Oooool00oo<c<co410@olc<c003ooooo`06oa0@4?nHV9So
oooooooooomgMgOoIVIV1_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo06kooooo
000Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00onYZJWo<S8boooo
o`02ooooo`05o`000?lQ8B7o0000o`000?mVIVH01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03ojVY
ZOlb<S;ooooo00;ooooo00Go0000ob4Q8Ol0003o0000ofIVIP07ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0Koooool0023ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@Aoooo
o`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo047ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@Aooooo`05o`000?ooooooooooooooool0
00002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo06oooooo000Pooooo`06olc<
c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool01_l0003oQhN7onk^k_ooooooMgMgoc8b<P?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool0MOooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04;ooooo00Ko
c<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`06o`000?n7QhOok^k^oooooomgMgOo<S8b0oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0Koooool0
027ooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kP?ooooo
1Ol00007ooooo`;o00002?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool0Coooool00ol0003oooooooooo`13ooooo`04okZj^_l@413o410@olc<c0go
oooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h3ooooo`Go00001oooool2o`0000Kooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0Koooool004Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0L?ooool004Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo07Oooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0L?ooool004Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0L?ooool004Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0L?oo
ool004Oooooo0_l00009ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0NOooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo06_ooooo0_l00007ooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo077ooooo0017ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo077ooooo0017ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo077o
oooo0017ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0K?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo07;ooooo0017ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool0K?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo07;ooooo0017
ooooo`;o00002oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo07gooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`1/ooooo`;o00002Oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1b
ooooo`00Aoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0OOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`1booooo`00Aoooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1cooooo`00
Aoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`1cooooo`00Aoooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1cooooo`00Aoooool2
o`0000gooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool0K_ooool2o`0000[ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0Loooool0
04Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
087ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0M?ooool002[ooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omE
EEGo0000oeEEE@04ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo05;ooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000
oeEEE@04ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo07Cooooo000Yooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3
o`0000Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@6ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool0DOooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004oooo
o`06oa0@4?n7QhOooooooooooomgMgOoA4A41_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo07Cooooo000Yooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000
oeEEE@09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`1Booooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@09oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1eoooo
o`00:Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?ok^k^o`000?oo
ool01Oooool3o`0000gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`24ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00kooooo00?ok^k^o`000?ooool01Oooool3o`0000[ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0MOooool002Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`06oa0@
4?nHV9SooooooooooomgMgOoIVIV1_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`06oa0@4?nHV9Sooooo
oooooomgMgOoIVIV1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo07Gooooo000Y
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?l0
003oIVIV00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo08Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1Cooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`1eooooo`00:Oooool01_m4A4CoZJVYoooo
ooooooooZJVYodA4A0cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo05?ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1fooooo`00:Oooool01_o<
c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0R?ooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo05Cooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1fooooo`00
:_ooool01?nj^[[o410@oa0@4?o<c<`=ooooo`Go00001oooool2o`00013ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool0EOooool01?nj^[[o410@oa0@4?o<c<`=ooooo`Go00001oooool2o`0000gooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0M_ooool004Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo08Wooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0M_ooool004Oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
Moooool004Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo08_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Xooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0Moooool004Oooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`1dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Moooool0
04Oooooo0_l0000Booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0S?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo07Cooooo0_l0000>ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
07Sooooo0017ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`2>ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0MOooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo07Sooooo0017ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0MOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo07Sooooo
0017ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`2>ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0M_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo07Wooooo0017ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0M_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0K?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Wooooo0017oooo
o`;o00005Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo093ooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`1fooooo`;o00004?ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1ioooo
o`00Aoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0T_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo07Oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1jooooo`00Aoooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo07Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1jooooo`00Aooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0Tooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1jooooo`00Aoooool2o`0001Oooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`2Dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0N?ooool2
o`00017ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0Noooool004Oooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Noooool004Oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0Noooool0027ooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo
0000oeEEE@06ooooo`03ob4Q8OnHV9Sooooo00Cooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h6
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2F
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Doooool01?nj^[[o410@o`000?mg
MgL6ooooo`03oeEEEOl0003oEEEE00Kooooo00?o8B4QoiRHV?ooool01?ooool01_nHV9So410@o`00
0?l0003oA4A4onk^kPKooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1looooo`00
8?ooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00006ooooo`03oiRHV?m4A4Cooooo
00Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@6ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0Doooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00006ooooo`03
oiRHV?m4A4Cooooo00Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@6ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0O?ooool0023ooooo00KoA4A4ojVYZOooooooooooojVYZOlb
<S85ooooo`03oeEEEOl0003oEEEE00Kooooo00?ok^k^o`000?o^k^h02Oooool00ol0003ooooooooo
o`04ooooo`?o00006?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09Sooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`1Cooooo`06odA4A?nYZJWooooooooooonYZJWo
<S8b1Oooool00omEEEGo0000oeEEE@06ooooo`03onk^k_l0003ok^k^00Wooooo00?o0000oooooooo
ool01?ooool3o`00017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0O?ooool0023ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`03oeEEEOnHV9Sooooo00Oooooo00?ok^k^o`000?ooool0
1Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
V_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`03oeEEEOnHV9Sooooo00Oooooo00?ok^k^o`000?ooool0
1Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07gooooo000Pooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03Oooool00onYZJWoA4A4ooooo`03ooooo`06oa0@4?nH
V9SooooooooooomgMgOoIVIV1_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03ojVYZOm4A4Cooooo00?o
oooo00Ko410@oiRHV?ooooooooooogMgMomVIVH6ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0OOooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>oooo
o`03o`000?o^k^kooooo00;ooooo00Go0000ob4Q8Ol0003o0000ofIVIP07ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2Looooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00kooooo00?o0000onk^k_ooool00_ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07Cooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`1mooooo`008?ooool01_m4A4CoZJVYoooooooo
ooooZJVYodA4A13ooooo00?oEEEEoiRHV?ooool00_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2Mooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0E_ooool01_m4A4CoZJVYooooooooooooZJVYodA4
A13ooooo00?oEEEEoiRHV?ooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0O_ooool0023ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<
ooooo`06oa0@4?oooooooooooooooonYZJWoA4A40oooool00ol0003oooooooooo`09ooooo`;o0000
6oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`1Fooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool01_l@
413oooooooooooooooooZJVYodA4A0?ooooo00?o0000ooooooooool02Oooool2o`0001Cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0O_ooool0027ooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool6o`0000?ooooo1Ol0
0007ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`2Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0F?ooool01?nj^[[o410@oa0@
4?o<c<`=ooooo`Ko00000oooool5o`0000Oooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`1oooooo`00Aoooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0X?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`1oooooo`00Aoooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1o
ooooo`00Aoooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0X_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`20ooooo`00Aoooool2o`0001kooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0P?ooool2o`0001Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0P?ooool004Oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
POooool004Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo0:Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`21ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1looooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0POooool004Oooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0POooool0
04Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
0:Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0P_ooool004Oooooo0_l0000Qooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo08?o
oooo0_l0000Iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0P?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo08;ooooo0017ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08?ooooo
0017ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`2]ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0QOooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo08Cooooo0017ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`2_ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0Q_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08Cooooo0017oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo08Gooooo0017ooooo`;o00009_ooool2o`0001?ooooo00?o0000oooooooo
ool0/oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08Sooooo0_l0000Looooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo08Kooooo0017ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
3_ooool2o`000;Oooooo0_l0000Aooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0
7?ooool2o`0000cooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo08Oooooo0017ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`2iooooo`;o00003_ooool00ol0003oooooooooo`2:ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`29ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0R?ooool003cooooo1?l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo02Sooooo0_l0000;ooooo`;o0000__ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo083ooooo1?l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01oooool2o`0008gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`29ooooo`00?_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02[ooooo0_l00008ooooo`03o`000?oooooooooo0;oooooo0_l00007ooooo`?o0000QOooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo0_l00006ooooo`03o`000?oooooooooo
08kooooo0_l00005ooooo`;o0000S?ooool003kooooo00?o0000ooooooooool01_ooool3o`0002co
oooo2?l00034ooooo`So0000Qoooool00ol0003oooooooooo`06ooooo`?o00008Oooool6o`0009;o
oooo1ol0002=ooooo`00?_ooool00ol0003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool0
oooooomGooooo`00?_ooool00ol0003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool0oooo
oomGooooo`00?_ooool00ol0003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool0oooooomG
ooooo`00?_ooool00ol0003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool0oooooomGoooo
o`00??ooool00ol0003oA4A4o`00003ooooooi7ooooo00?o0000odA4A?l00000oooooomIooooo`00
??ooool00oo<c<coEEEEo`00003ooooooi7ooooo00?oc<c<oeEEEOl00000oooooomIooooo`00oooo
oooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]oooo
o`00b_ooool00ol@413o0000o`000002ooooo`;o000000?o410@ooooooooool06_ooool01_nYZJWo
8B4Qo`000?l0003oEEEEonk^k_ooooooJ_ooool00ol@413o0000o`000002ooooo`;o000000?o410@
ooooooooool07Oooool2o`000003oa0@4?oooooooooo0:7ooooo003;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02_ooool6o`0000_ooooo00Ko410@ojVYZOooooooooooogMgMolb
<S;oooooof_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`Ko00003ooo
ool00ol0003oooooooooo`2Rooooo`00boooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0oooooomYooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06oooool6o`000:?ooooo003;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool07oooool00omgMgOo8B4Qooooo`3oooooof[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Kooooo`05ofIVI_nYZJWoooooooooool00000Y?ooool00<_ooooo00?o0000onk^
k_ooool00_ooool00ol0003oooooooooo`0:ooooo`Ko00003Oooool01?lQ8B7o0000o`000?nj^[[o
ooooof_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`0:ooooo`Ko00002oooool0
1Oo^k^ko8B4Qonk^k_oooooo00000:Cooooo003;ooooo`06o`000?m4A4CogMgMoooooomgMgOo410@
8?ooool00oo^k^koMgMgoc8b<P3oooooof_ooooo00Ko0000odA4A?oMgMgoooooogMgMol@410Noooo
o`04ojVYZOmVIVKoooooo`000:Cooooo003:ooooo`07oa0@4?l0003oMgMgoa0@4?l0003o8B4Qolc<
c00Rooooo`03o`000?oooooooooo0?ooooooJ?ooool01ol@413o0000ogMgMol@413o0000ob4Q8Oo<
c<`07oooool00om4A4Coc<c<o`00002Tooooo`00k_ooool01_lQ8B7oQhN7ooooooooooooIVIVoc8b
<_ooooooT?ooool00ooMgMgoA4A4o`00002Tooooo`00k_ooool01_nj^[[oA4A4o`000?l0003oA4A4
onk^k_ooooooTOooool00on7QhOo0000ooooo`2Sooooo`00oooooooooooooooooooo;Oooool00?oo
ooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Ooo
ool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooo
oooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00oooooooo
oooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00
oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]
ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooooooooooo
ooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooo
ooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo
003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oooooooooooooooooo
obgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oooooooooo
ooooooooobgooooo003oooooooooooooooooool]ooooo`00??ooool4o`000003oa0@4?oooooooooo
0?ooooooSOooool4o`000003oa0@4?oooooooooo0?ooooooEOooool003kooooo00?o0000oooooooo
ool0oooooonAooooo`03o`000?oooooooooo0?ooooooEoooool003kooooo00?o0000ooooooooool0
oooooonAooooo`03o`000?oooooooooo0?ooooooEoooool003;ooooo1ol00005ooooo`03o`000?oo
oooooooo00Kooooo0ol0003oooooogcooooo1ol00005ooooo`03o`000?oooooooooo00Kooooo0ol0
003Kooooo`oo0000Hoooool003kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3o
ooooohSooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Hooooo`?o00003oooool3
o`00063ooooo000nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooon8oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0e_ooool2o`0001Gooooo0_l0001Noooo
o`00?_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooR?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0=Cooooo0_l0000Iooooo`;o0000G?ooool003cooooo
00?o0000odA4A?l000002?ooool00ol0003oooooooooo`3oooooohKooooo00?o0000odA4A?l00000
2?ooool00ol0003oooooooooo`3Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
FOooool003cooooo00?oc<c<oeEEEOl000002?ooool2o`000?ooooooQoooool00oo<c<coEEEEo`00
0008ooooo`;o0000d_ooool2o`0001oooooo0_l0001Iooooo`00Aoooool00ol0003oooooooooo`3o
oooooi7ooooo00?o0000ooooooooool0d?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo05Kooooo0017ooooo`03o`000?oooooooooo0?ooooooTOooool00ol0003oooooooooo`3?oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0EOooool004Oooooo00?o0000oooooooo
ool0oooooonAooooo`03o`000?oooooooooo0<kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1Dooooo`00Aoooool2o`000?ooooooT_ooool2o`000<kooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`1Cooooo`00Aoooool00ol0003oooooooooo`3ooooooi7ooooo00?o
0000ooooooooool0c?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05;ooooo0017
ooooo`03o`000?oooooooooo0?ooooooTOooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0DOooool004Oooooo00?o0000ooooooooool0oooooonAoooo
o`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1@oooo
o`00Aoooool00ol0003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool0bOooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo04oooooo0017ooooo`;o0000oooooonBooooo`;o0000
b_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04oooooo0017ooooo`03o`000?oo
oooooooo0?ooooooTOooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0C_ooool004Oooooo00?o0000ooooooooool0oooooonAooooo`03o`000?oooooo
oooo0<Oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1=ooooo`00Aoooool00ol0
003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo04cooooo0017ooooo`03o`000?oooooooooo0?ooooooTOooool00ol0003o
ooooooooo`35ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Boooool004Oooooo
0_l0003ooooooi;ooooo0_l00035ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
B_ooool004Oooooo00?o0000ooooooooool0oooooonAooooo`03o`000?oooooooooo0<?ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`19ooooo`00Aoooool00ol0003oooooooooo`3o
oooooi7ooooo00?o0000ooooooooool0`_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo04Sooooo000Qooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01_ooool0
0olQ8B7oV9RHooooo`04ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1_ooool00ol0003ooooo
ooooo`3oooooof_ooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@06ooooo`03
ob4Q8OnHV9Sooooo00Cooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h6ooooo`03o`000?oooooo
oooo0<;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`18ooooo`008?ooool01_o<
c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00006ooooo`03oiRHV?m4A4Cooooo00Cooooo00Ko
410@ohN7QoooooooooooogMgMom4A4@6ooooo`03o`000?oooooooooo0?ooooooJ_ooool01_o<c<co
<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00006ooooo`03oiRHV?m4A4Cooooo00Cooooo00Ko410@
ohN7QoooooooooooogMgMom4A4@6ooooo`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`17ooooo`008?ooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGo
oooo00?oEEEEo`000?mEEED01_ooool00oo^k^ko0000onk^kP09ooooo`03o`000?oooooooooo00Co
oooo0ol0003oooooof[ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003o
EEEE00Kooooo00?ok^k^o`000?o^k^h02Oooool00ol0003oooooooooo`04ooooo`?o0000`?ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo04Kooooo000Gooooo`Oo00000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?oEEEEoiRHV?ooool01oooool00oo^
k^ko0000ooooo`05ooooo`03o`000?oooooooooo0?ooooooHOooool7o`0000;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0=ooooo`03oeEEEOnHV9Sooooo00Oooooo00?ok^k^o`00
0?ooool01Oooool00ol0003oooooooooo`2oooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool0AOooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03
ojVYZOm4A4Cooooo00?ooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH6ooooo`03o`000?oooooo
oooo0?ooooooJ_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?oZJVY
odA4A?ooool00oooool01_l@413oV9RHooooooooooooMgMgofIVIPKooooo00?o0000ooooooooool0
_oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Cooooo000Pooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003ok^k^ooooo`02ooooo`05o`000?lQ
8B7o0000o`000?mVIVH01oooool00ol0003oooooooooo`3oooooof[ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0>ooooo`03o`000?o^k^kooooo00;ooooo00Go0000ob4Q8Ol0003o
0000ofIVIP07ooooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`13ooooo`008?ooool01_m4A4CoZJVYooooooooooooZJVYodA4A13ooooo00?oEEEEoiRH
V?ooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?ooooooJ_ooool01_m4
A4CoZJVYooooooooooooZJVYodA4A13ooooo00?oEEEEoiRHV?ooool00_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`12ooooo`008?ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00Ko410@oooooooooooo
ooooojVYZOm4A4@3ooooo`03o`000?oooooooooo00Wooooo0_l0003oooooof_ooooo00Koc<c<oc8b
<_o^k^kok^k^oc8b<_o<c<`<ooooo`06oa0@4?oooooooooooooooonYZJWoA4A40oooool00ol0003o
ooooooooo`09ooooo`;o0000_Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;o
oooo000Qooooo`04okZj^_l@413o410@olc<c0gooooo1_l00003ooooo`Go00001oooool00ol0003o
ooooooooo`3oooooof_ooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool6o`0000?ooooo1Ol00007oooo
o`03o`000?oooooooooo0;cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`11oooo
o`00Aoooool00ol0003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool0^oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo043ooooo0017ooooo`03o`000?oooooooooo0?oooooo
TOooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
@?ooool004Oooooo00?o0000ooooooooool0oooooonAooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`0oooooo`00Aoooool2o`000?ooooooT_ooool2
o`000;[ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0oooooo`00Aoooool00ol0
003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo03kooooo0017ooooo`03o`000?oooooooooo0?ooooooTOooool00ol0003o
ooooooooo`2hooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0?Oooool004Oooooo
00?o0000ooooooooool0oooooonAooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`0mooooo`00Aoooool00ol0003oooooooooo`3ooooooi7ooooo00?o
0000ooooooooool0]_ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo03cooooo0017
ooooo`;o0000oooooonBooooo`;o0000]oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo03_ooooo0017ooooo`03o`000?oooooooooo0?ooooooTOooool00ol0003oooooooooo`2eoooo
o`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0>oooool004Oooooo00?o0000oooooooo
ool0oooooonAooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`0jooooo`00Aoooool00ol0003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool0
]?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo03[ooooo0017ooooo`03o`000?oo
oooooooo0?ooooooTOooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool0>Oooool004Oooooo0_l0003ooooooi;ooooo0_l0002dooooo`03o`000?oooooo
oooo05cooooo00?o0000ooooooooool0>?ooool004Oooooo00?o0000ooooooooool0oooooonAoooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0hoooo
o`00Aoooool00ol0003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo03Oooooo000Zooooo`04okZj^_l@413o0000ogMgM`Ko
oooo00?oEEEEo`000?mEEED01?ooool01_nHV9So410@o`000?l0003oA4A4onk^kPKooooo00?o0000
ooooooooool0oooooomdooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?oo
ool01_nHV9So410@o`000?l0003oA4A4onk^kPKooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo03Oooooo000Yooooo`06olc<c?lb<S;ok^k^onk^k_lQ
8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@6ooooo`03o`000?oo
oooooooo0?ooooooLoooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`06
oa0@4?n7QhOooooooooooomgMgOoA4A41_ooool00ol0003oooooooooo`2`ooooo`03o`000?oooooo
oooo067ooooo00?o0000ooooooooool0=_ooool002Wooooo00KoA4A4ojVYZOooooooooooojVYZOlb
<S85ooooo`03oeEEEOl0003oEEEE00Wooooo00?o0000ooooooooool01?ooool3o`000?ooooooLooo
ool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED02Oooool00ol0003o
ooooooooo`04ooooo`?o0000[oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo03Go
oooo000Pooooo`Oo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo
00?ok^k^o`000?ooool01Oooool00ol0003oooooooooo`3oooooof[ooooo1ol00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00oo^k^ko0000ooooo`05ooooo`03o`00
0?oooooooooo0:oooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0eooooo`00:Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko410@oiRHV?oooooooooo
ogMgMomVIVH6ooooo`03o`000?oooooooooo0?ooooooLoooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00[ooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH6ooooo`03o`000?oooooo
oooo0:kooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0dooooo`00:Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o0000ofIVIP07
ooooo`03o`000?oooooooooo0?ooooooLoooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00Go0000ob4Q8Ol0003o0000ofIVIP07ooooo`03o`000?oooooooooo0:kooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`0dooooo`00:Oooool01_m4A4CoZJVYoooooooo
ooooZJVYodA4A0cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3oooooog?ooooo
00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0[Oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo03?ooooo000Yooooo`06
olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool00ol0003oooooooooo`09ooooo`;o0000oooooomd
ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool00ol0003oooooooooo`09ooooo`;o0000
[_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo03?ooooo000Zooooo`04okZj^_l@
413o410@olc<c0gooooo1Ol00007ooooo`03o`000?oooooooooo0?ooooooM?ooool01?nj^[[o410@
oa0@4?o<c<`=ooooo`Go00001oooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo06Wo
oooo00?o0000ooooooooool0<_ooool004Oooooo00?o0000ooooooooool0oooooonAooooo`03o`00
0?oooooooooo0:cooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0booooo`00Aooo
ool00ol0003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool0Zoooool00ol0003ooooooooo
o`1[ooooo`03o`000?oooooooooo037ooooo0017ooooo`03o`000?oooooooooo0?ooooooTOooool0
0ol0003oooooooooo`2[ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0<Oooool0
04Oooooo0_l0003ooooooi;ooooo0_l0002[ooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool0<?ooool004Oooooo00?o0000ooooooooool0oooooonAooooo`03o`000?oooooooooo0:[o
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0`ooooo`00Aoooool00ol0003ooooo
ooooo`3ooooooi7ooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo02oooooo0017ooooo`03o`000?oooooooooo0?ooooooTOooool00ol0003ooooooooo
o`2Yooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0;_ooool004Oooooo00?o0000
ooooooooool0oooooonAooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0^ooooo`00Aoooool2o`000?ooooooT_ooool2o`000:Wooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`0]ooooo`00Aoooool00ol0003oooooooooo`3ooooooi7o
oooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo02go
oooo0017ooooo`03o`000?oooooooooo0?ooooooTOooool00ol0003oooooooooo`2Wooooo`03o`00
0?oooooooooo07Cooooo00?o0000ooooooooool0;?ooool004Oooooo00?o0000ooooooooool0oooo
oonAooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0MOooool00ol0003ooooooooo
o`0/ooooo`00Aoooool00ol0003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool0Y_ooool0
0ol0003oooooooooo`1fooooo`03o`000?oooooooooo02_ooooo0017ooooo`;o0000oooooonBoooo
o`;o0000Y_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo02_ooooo0017ooooo`03
o`000?oooooooooo0?ooooooTOooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo07So
oooo00?o0000ooooooooool0:_ooool0027ooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo
0000oeEEE@04ooooo`Ko00000oooool01_nHV9So410@o`000?l0003oA4A4onk^kPKooooo00?o0000
ooooooooool0oooooom[ooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?oo
ool6o`0000?ooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h6ooooo`03o`000?oooooooooo0:Co
oooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0Zooooo`008?ooool01_o<c<co<S8b
onk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`03oiRHV?l0003oc<c<00;ooooo00Ko410@oooo
oooooooooooooa0@4?n7QhL2ooooo`03ogMgMom4A4Cooooo00Gooooo00?o0000ooooooooool0oooo
oomZooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00?oV9RHo`000?o<
c<`00_ooool01_l@413ooooooooooooooooo410@ohN7Q`;ooooo00?oMgMgodA4A?ooool01Oooool0
0ol0003oooooooooo`2Tooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0:Oooool0
023ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Gooooo00?o
V9RHo`000?o<c<`02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooJ_oo
ool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED01Oooool00onHV9So
0000olc<c00:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Xoooool00ol0003o
ooooooooo`1kooooo`03o`000?oooooooooo02Wooooo000Gooooo`Oo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oZJVYoa0@4?o<c<`02?ooool00oo^k^ko0000
ooooo`05ooooo`?o0000oooooomQooooo`Oo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?oZJVYoa0@4?o<c<`02?ooool00oo^k^ko0000ooooo`05ooooo`?o0000
Xoooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Sooooo000Pooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03Oooool00oo<c<co410@olc<c003ooooo`06oa0@4?nH
V9SooooooooooomgMgOoIVIV1_ooool00ol0003oooooooooo`3oooooof[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0=ooooo`03olc<c?l@413oc<c<00?ooooo00Ko410@oiRHV?oo
ooooooooogMgMomVIVH6ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0OOooool0
0ol0003oooooooooo`0Xooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00kooooo00?oZJVYoc8b<_ooool00_ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000
ooooooooool0oooooomZooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool0
0onYZJWo<S8booooo`02ooooo`05o`000?lQ8B7o0000o`000?mVIVH01oooool00ol0003ooooooooo
o`2Rooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool09oooool0023ooooo00KoA4A4
ojVYZOooooooooooojVYZOm4A4@Aooooo`05o`000?ooooooooooooooool000002oooool00ol0003o
ooooooooo`3oooooof[ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@Aooooo`05o`000?oooooo
ooooooooool000002oooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool09oooool0023ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`06o`00
0?n7QhOok^k^oooooomgMgOo<S8b0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
0?ooooooJ_ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00Ko0000ohN7Qoo^k^kooooo
ogMgMolb<S83ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0XOooool00ol0003o
ooooooooo`20ooooo`03o`000?oooooooooo02Kooooo000Qooooo`04okZj^_l@413o410@olc<c0go
oooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h3ooooo`Go00001oooool2o`000?ooooooK?ooool0
1?nj^[[o410@oa0@4?o<c<`=ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^0oooool5o`0000Oo
oooo0_l0002Qooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool09_ooool004Oooooo
00?o0000ooooooooool0oooooonAooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`0Uooooo`00Aoooool00ol0003oooooooooo`3ooooooi7ooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo02Gooooo0017
ooooo`03o`000?oooooooooo0?ooooooTOooool00ol0003oooooooooo`2Oooooo`03o`000?oooooo
oooo08Cooooo00?o0000ooooooooool09?ooool004Oooooo00?o0000ooooooooool0oooooonAoooo
o`03o`000?oooooooooo09kooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Toooo
o`00Aoooool2o`000?ooooooT_ooool2o`0009oooooo00?o0000ooooooooool0Q_ooool00ol0003o
ooooooooo`0Sooooo`00Aoooool00ol0003oooooooooo`0^ooooo`04okZj^_l@413o0000ogMgM`Ko
oooo00?oEEEEo`000?mEEED01?ooool6o`0002Kooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omE
EEGo0000oeEEE@07ooooo`;o000000?o410@ooooooooool09?ooool01?nj^[[o410@o`000?mgMgL6
ooooo`03oeEEEOl0003oEEEE00Cooooo00Kok^k^odA4A?l0003o0000oeEEEOo^k^hVooooo`04okZj
^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool01_o^k^koA4A4o`000?l0003oA4A4
onk^kRoooooo1?l000000ol@413oooooooooo`1Nooooo`03o`000?oooooooooo02oooooo00Co^[Zj
oa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`Ko00009_ooool01?nj^[[o410@o`00
0?mgMgL6ooooo`03oeEEEOl0003oEEEE00Oooooo0_l000000ol@413oooooooooo`0Hooooo`03o`00
0?oooooooooo00Wooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06
onk^k_m4A4Co0000o`000?mEEEGok^k^9_ooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0
003oEEEE00Cooooo00Kok^k^odA4A?l0003o0000odA4A?o^k^h[ooooo`04o`000?oooooooooooooo
o`Co000000?o410@ooooooooool06_ooool004Oooooo00?o0000ooooooooool0;Oooool01_o<c<co
<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`03oiRHV?l0003oc<c<00;ooooo00?o410@
ooooooooool08oooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00008ooooo`03o`00
0?oooooooooo02Cooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool01_mE
EEGoMgMgooooooooooooMgMgoeEEEBGooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o
00001?ooool01_lb<S;oMgMgonk^k_o^k^koMgMgoc8b<S7ooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`0^ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo
00?oV9RHo`000?o<c<`00_ooool00ol@413oooooooooo`0Sooooo`06olc<c?lb<S;ok^k^onk^k_lQ
8B7oZJVY1Oooool3o`0000Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08oooo
o`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00KoEEEEogMgMooooooooooo
ogMgMomEEEDUooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko<S8b
ogMgMoo^k^kok^k^ogMgMolb<S8[ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7?ooool004Oooooo00?o0000ooooooooool0;Oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGo
oooo00?oEEEEo`000?mEEED01Oooool00onHV9So0000olc<c00Wooooo`06odA4A?nYZJWooooooooo
oonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@04ooooo`Ko00009Oooool01_m4A4CoZJVYoooooooo
ooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED01?ooool00ol@413oooooooooo`02ooooo`03o`00
0?oooooooooo02?ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0;_ooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?o
EEEEo`000?mEEED01Oooool00onHV9So0000olc<c00Wooooo`06odA4A?nYZJWooooooooooonYZJWo
<S8b1Oooool00omEEEGo0000oeEEE@04ooooo`Ko00006Oooool00ol0003oooooooooo`09ooooo`06
odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@04ooooo`03oa0@4?oooooo
oooo00;ooooo00?o0000ooooooooool08oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo
00?oEEEEo`000?mEEED01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`00Aoooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00onYZJWo410@olc<
c00Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01OmVIVKoZJVYoooo
oooooooo000002Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?o^k^kooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00[ooooo00Ko<S8bogMgMoo^k^kok^k^ogMgMolb<S8aooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00cooooo00?oZJVYoa0@4?o<c<`09_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00[ooooo00GoIVIVojVYZOooooooooooo`00000Iooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?o^k^kooooo00;ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko<S8b
ogMgMoo^k^kok^k^ogMgMolb<S8/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7?ooool004Oooooo0_l0000^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Ooo
ool00oo<c<co410@olc<c00Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool01Oo^k^ko8B4Qonk^k_oooooo000002Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0:ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE9Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00[ooooo00?ogMgMo`000?l000000_l000000ooMgMgoooooooooo`0_oooo
o`03o`000?oooooooooo063ooooo0_l0000_ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool00oo<c<co410@olc<c00Uooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02_ooool01Oo^k^ko8B4Qonk^k_oooooo000001Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko0000oeEEEOo^k^koooooogMg
MomEEEDUooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ooMgMgo0000
o`000002o`000003omgMgOoooooooooo02_ooooo00Go0000ooooooooooooooooo`00000Nooooo`00
Aoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3_ooool00onYZJWo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2oooool01?nYZJWoIVIVooooool0000Vooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02_ooool01_lQ8B7oIVIVo`000?l0003oEEEEonk^kRGooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0:ooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b<Oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0>ooooo`03ojVYZOlb<S;ooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0;ooooo`04ojVYZOmVIVKoooooo`0001Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko8B4QofIVI_l0003o0000oeEEEOo^k^hU
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_lb<S;oIVIVonk^k_o^
k^koIVIVoc8b<Rgooooo00Go0000ooooooooooooooooo`00000Nooooo`00Aoooool00ol0003ooooo
ooooo`0]ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A44Oooool00ol0003oooooooooo`0Soooo
o`06odA4A?nYZJWooooooooooonYZJWoA4A43_ooool00om4A4Coc<c<o`00000Vooooo`06odA4A?nY
ZJWooooooooooonYZJWoA4A43?ooool00on7QhOoIVIVooooo`0Xooooo`06odA4A?nYZJWooooooooo
oonYZJWoA4A43?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`0^ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A4
4Oooool00ol0003oooooooooo`0Sooooo`06odA4A?nYZJWooooooooooonYZJWoA4A43_ooool00om4
A4Coc<c<o`00000Hooooo`03o`000?oooooooooo00_ooooo00KoA4A4ojVYZOooooooooooojVYZOm4
A4@<ooooo`03ohN7QomVIVKooooo02Sooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool01?l0003oooooooooool0000Noooo
o`00Aoooool00ol0003oooooooooo`0]ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool0
1_l0003oQhN7onk^k_ooooooMgMgoc8b<RGooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`>oooo
o`03omgMgOm4A4Co000002Kooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`=ooooo`03oc8b<_mV
IVKogMgM02Oooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`06oc8b<_mVIVKok^k^onk^
k_mVIVKo<S8b;oooool00ol0003oA4A4o`00001Rooooo`03o`000?oooooooooo02kooooo00Koc<c<
oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`06o`000?n7QhOok^k^oooooomgMgOo<S8b9Oooool01_o<
c<co<S8bonk^k_o^k^ko<S8bolc<c0kooooo00?ogMgModA4A?l000005oooool00ol0003ooooooooo
o`0<ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3Oooool00olb<S;oIVIVomgMg@0Wooooo`06
olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<Rkooooo
0_l000000om4A4Co0000ooooo`0Mooooo`00Aoooool00ol0003oooooooooo`0^ooooo`04okZj^_l@
413o410@olc<c0gooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^hVooooo`04okZj^_l@413o410@
olc<c13ooooo00?oQhN7o`000?ooool09_ooool01?nj^[[o410@oa0@4?o<c<`?ooooo`04ogMgMol@
413o0000ob4Q8BKooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool01_o^k^koA4A4o`000?l0003oA4A4
onk^kRoooooo00?oc<c<oeEEEOl00000H_ooool00ol0003oooooooooo`0_ooooo`04okZj^_l@413o
410@olc<c0gooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^hVooooo`04okZj^_l@413o410@olc<
c13ooooo00?oQhN7o`000?ooool05_ooool00ol0003oooooooooo`0=ooooo`04okZj^_l@413o410@
olc<c0oooooo00CoMgMgoa0@4?l0003o8B4Q9_ooool01?nj^[[o410@oa0@4?o<c<`=ooooo`06onk^
k_m4A4Co0000o`000?m4A4Cok^k^;oooool00ol0003oEEEEo`00000Nooooo`00Aoooool2o`000?oo
ooooT_ooool2o`0009Wooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0Nooooo`00
Aoooool00ol0003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool0V?ooool00ol0003ooooo
ooooo`2Booooo`03o`000?oooooooooo01gooooo0017ooooo`03o`000?oooooooooo0?ooooooTOoo
ool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool07Ooo
ool004Oooooo00?o0000ooooooooool0oooooonAooooo`03o`000?oooooooooo09Oooooo00?o0000
ooooooooool0U?ooool00ol0003oooooooooo`0Looooo`00Aoooool00ol0003oooooooooo`3ooooo
oi7ooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo
01cooooo000ooooooooo0000@_l0001Coooooooo0000@_l0000Fooooo`00Aoooool2o`0000gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02_ooool00ol0003oooooo`00001Qooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo
0_l0000>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01cooooo0017ooooo`03o`000?oooooo000003[ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0=oooool01?l0003oooooooooool0001Qooooo`;o0000>oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool07?ooool004Oooooo00Co
0000oooooooooooo0000oooooolZooooo`03o`000?oooooooooo06?ooooo0_l0002Eooooo`03o`00
0?oooooooooo0;Kooooo0017ooooo`05o`000?ooooooooooooooool00000oooooolXooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooool00000U?ooool00ol0003oooooooooo`2fooooo`00Aooo
ool2o`0000?ooooo00?o0000ooooooooool0oooooolTooooo`03o`000?oooooooooo06Gooooo0ol0
002Cooooo`03o`000?oooooooooo0;Oooooo0017ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0oooooolRooooo`03o`000?oooooooooo06Kooooo00Co0000oooooooooooo0000T_oo
ool00ol0003oooooooooo`2gooooo`00Aoooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?oooooo8?ooool00ol0003oooooooooo`1Wooooo`04o`000?ooooooooooo`00097ooooo00?o
0000ooooooooool0^?ooool004Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooooakooooo00?o0000ooooooooool0J?ooool01Ol0003ooooooooooooooooo0000093ooooo00?o
0000ooooooooool0^?ooool004Oooooo0_l00007ooooo`03o`000?oooooooooo0?oooooo7?ooool0
0ol0003oooooooooo`1Yooooo`;o00000_ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooo
oooo0;Wooooo0017ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolJoooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2<oooo
o`03o`000?oooooooooo0;Wooooo0017ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0oooooolHooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2;ooooo`03o`000?oooooooooo0;[ooooo0017ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0oooooolFooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo0;[ooooo0017ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0oooooolDooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo0;_ooooo0017
ooooo`;o00003?ooool00ol0003oooooooooo`3ooooooa;ooooo00?o0000ooooooooool0K_ooool2
o`0000Gooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`2kooooo`00Aoooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`2koooo
o`00Aoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?oooooo3_ooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Q_ooool00ol0003o
ooooooooo`2looooo`00Aoooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo
3?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
QOooool00ol0003oooooooooo`2looooo`00Aoooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0?oooooo2_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0Q?ooool00ol0003oooooooooo`2mooooo`00Aoooool2o`00017ooooo00?o0000
ooooooooool0ooooool8ooooo`03o`000?oooooooooo07?ooooo0_l00008ooooo`03o`000?oooooo
oooo08?ooooo00?o0000ooooooooool0_Oooool004Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`3oooooo`Kooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0__ooool004Oooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`3oooooo`Cooooo00?o0000ooooooooool0MOooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0__ooool0027ooooo
00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`Ko00000oooool01_nHV9So
410@o`000?l0003oA4A4onk^kPKooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3o
ooooo`;ooooo00?o0000ooooooooool0D?ooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0
003oEEEE00Cooooo1_l00003ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0_oooool0023ooooo
00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool00onHV9So0000olc<c002oooo
o`06oa0@4?ooooooooooooooool@413oQhN70_ooool00omgMgOoA4A4ooooo`05ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0ooooool00ol0003oooooooooo`1@ooooo`06olc<c?lb
<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00?oV9RHo`000?o<c<`00_ooool01_l@413o
oooooooooooooooo410@ohN7Q`;ooooo00?oMgMgodA4A?ooool01Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0_oooool0023ooooo00KoA4A4ojVY
ZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Gooooo00?oV9RHo`000?o<c<`02_oo
ool00ol0003oooooooooo`04ooooo`?o00005Oooool00ol0003oooooooooo`3mooooo`03o`000?oo
oooooooo057ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Go
oooo00?oV9RHo`000?o<c<`02_ooool00ol0003oooooooooo`04ooooo`?o00002Oooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo0<3ooooo000Pooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03?ooool00onYZJWo410@olc<c008ooooo`03onk^k_l0003ooooo00Gooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`3kooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03ojVYZOl@413oc<c<00Sooooo
00?ok^k^o`000?ooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07gooooo
00?o0000ooooooooool0`?ooool0023ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0=ooooo`03olc<c?l@413oc<c<00?ooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH6ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0nOooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00oo<c<co410@olc<c003ooooo`06
oa0@4?nHV9SooooooooooomgMgOoIVIV1_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo07cooooo00?o0000ooooooooool0`Oooool0023ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0>ooooo`03ojVYZOlb<S;ooooo00;ooooo00Go0000ob4Q8Ol0003o0000ofIVIP07
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0moooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00onYZJWo<S8booooo`02
ooooo`05o`000?lQ8B7o0000o`000?mVIVH01oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo07_ooooo00?o0000ooooooooool0`Oooool0023ooooo00KoA4A4ojVYZOooooooooooojVY
ZOm4A4@Aooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo0?Gooooo00?o0000ooooooooool0EOooool01_m4A4CoZJVYooooooooooooZJVY
odA4A17ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0N_ooool00ol0003oooooooooo`32ooooo`008?ooool01_o<c<co<S8bonk^k_o^
k^ko<S8bolc<c0cooooo00Ko0000ohN7Qoo^k^koooooogMgMolb<S83ooooo`03o`000?oooooooooo
00Wooooo0_l0000Kooooo`03o`000?oooooooooo0??ooooo00?o0000ooooooooool0E_ooool01_o<
c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00Ko0000ohN7Qoo^k^koooooogMgMolb<S83ooooo`03
o`000?oooooooooo00Wooooo0_l0000=ooooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool0`_ooool0027ooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool01_nYZJWo<S8bo`000?l0003oEEEE
onk^kP?ooooo1Ol00007ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0lOooool0
0ol0003oooooooooo`1Hooooo`04okZj^_l@413o410@olc<c0gooooo00KoZJVYoc8b<_l0003o0000
oeEEEOo^k^h3ooooo`Go00001oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07So
oooo00?o0000ooooooooool0`oooool004Oooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`3_ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1gooooo`03o`000?oooooooooo0<?ooooo0017ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0kOooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`34ooooo`00Aoooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo0>_ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0aOooool004Oooooo0_l0000Poooo
o`03o`000?oooooooooo0>Wooooo00?o0000ooooooooool0P_ooool2o`0000oooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`35ooooo`00Aoooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo0>Oooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo07;ooooo00?o0000ooooooooool0a_ooool004Oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`3Uooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo0<Kooooo0017ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0h_ooool2o`0008Oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo0<Oooooo0017ooooo`03o`000?oooooo
oooo02?ooooo0_l0003Qooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo0<Oooooo0017ooooo`;o00009_ooool00ol0
003oooooooooo`3Mooooo`03o`000?oooooooooo08Sooooo0_l0000Booooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool0b?ooool004Oooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`3Kooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo0<Sooooo0017ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0fOooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`39ooooo`00Aoooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo0=Oooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0bOooool004Oooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`3Eooooo`03o`000?oooooooooo08cooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo0<[ooooo0017oooo
o`;o0000:oooool00ol0003oooooooooo`3Cooooo`03o`000?oooooooooo08gooooo0_l0000Eoooo
o`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0b_ooool004Oooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`3Aooooo`03o`000?oooooooooo08kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo0<_ooooo0017ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0coooool00ol0003oooooooooo`2?ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`3<ooooo`00:_oo
ool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo00KoV9RHoa0@4?l0003o
0000odA4A?o^k^h6ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0cOooool00ol0
003oooooooooo`1cooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool0
1_nHV9So410@o`000?l0003oA4A4onk^kPKooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`1Vooooo`03o`000?oooooooooo0<cooooo000Yooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7o
ZJVY1Oooool3o`0000Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@6ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`1cooooo`06olc<c?lb<S;o
k^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@6oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`3=oooo
o`00:Oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED02Oooool0
0ol0003oooooooooo`04ooooo`?o0000;oooool2o`000<Wooooo0_l0001fooooo`06odA4A?nYZJWo
oooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@09ooooo`03o`000?oooooooooo00Cooooo
0ol0000Fooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0cOooool002Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03onk^k_l0003ooooo00Gooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`35ooooo`03o`000?oooooooooo07Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03onk^k_l0003ooooo00Gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo0<kooooo000Y
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_l@413oV9RHoooooooo
ooooMgMgofIVIPKooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`33ooooo`03o`00
0?oooooooooo07Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`06oa0@
4?nHV9SooooooooooomgMgOoIVIV1_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0c_ooool002Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0:ooooo`05o`000?lQ8B7o0000o`000?mVIVH01oooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o0000ofIVIP07ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`3?ooooo`00:Oooool01_m4
A4CoZJVYooooooooooooZJVYodA4A0cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo0;oooooo00?o0000ooooooooool0NOooool01_m4A4CoZJVYoooo
ooooooooZJVYodA4A0cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool0d?ooool002Wooooo00Koc<c<oc8b<_o^k^ko
k^k^oc8b<_o<c<`<ooooo`03o`000?oooooooooo00Wooooo0_l0000fooooo`;o0000_Oooool2o`00
07cooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`03o`000?oooooooooo00Wooooo0_l0
000Jooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0d?ooool002[ooooo00Co^[Zj
oa0@4?l@413oc<c<3Oooool5o`0000Oooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`2iooooo`03o`000?oooooooooo07gooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool5o`0000Oooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo0=7ooooo
0017ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0]oooool00ol0003ooooooooo
o`2Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`3Aooooo`00Aoooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo0;Gooooo00?o0000
ooooooooool0W?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool0d_ooool004Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2coooo
o`03o`000?oooooooooo09gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo0=?ooooo0017ooooo`;o0000??ooool00ol0003oooooooooo`2aooooo`03
o`000?oooooooooo09kooooo0_l0000Nooooo`03o`000?oooooooooo05Oooooo00?o0000oooooooo
ool0doooool004Oooooo00?o0000ooooooooool0??ooool2o`000:oooooo0_l0002Qooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`3Dooooo`00Aooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool0XOoo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0e?oo
ool004Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo0:;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo0=Gooooo0017ooooo`03o`000?oooooooooo043ooooo0_l0002Wooooo`;o0000YOooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0e_ooool004Oo
oooo0_l00013ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0YOooool2o`00027o
oooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`3Fooooo`00Aoooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool0Y_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0eoooool004Oooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`2Nooooo`;o0000ZOooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0eoooool004Oooooo00?o0000
ooooooooool0AOooool2o`0009gooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0f?ooool004Oooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo0:[ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo0=Wooooo0017ooooo`;o
0000BOooool00ol0003oooooooooo`2Fooooo`;o0000[Oooool2o`0002Cooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`3Iooooo`00Aoooool00ol0003oooooooooo`19ooooo`;o0000
UOooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`3Jooooo`008Oooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEE
EOl0003oEEEE00Kooooo00?o8B4QoiRHV?ooool01?ooool01_nHV9So410@o`000?l0003oA4A4onk^
kPKooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`2@ooooo`;o0000R_ooool01?nj
^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Kooooo00?o8B4QoiRHV?ooool01?ooool0
1_nHV9So410@o`000?l0003oA4A4onk^kPKooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo0=[ooooo000Pooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7o
ZJVY1Oooool3o`0000Kooooo00?oV9RHodA4A?ooool01?ooool01_l@413oQhN7ooooooooooooMgMg
odA4A0Kooooo00?o0000ooooooooool0C?ooool2o`0008oooooo00?o0000ooooooooool0ROooool0
1_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00006ooooo`03oiRHV?m4A4Cooooo00Cooooo
00Ko410@ohN7QoooooooooooogMgMom4A4@6ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`3Kooooo`008?ooool01_m4A4CoZJVYooooooooooooZJVY
oc8b<PGooooo00?oEEEEo`000?mEEED01_ooool00oo^k^ko0000onk^kP09ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0C_ooool2o`0008_ooooo0_l0002<ooooo`06odA4A?nYZJWo
oooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@06ooooo`03onk^k_l0003ok^k^00Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0g?ooool0023ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0=ooooo`03oeEEEOnHV9Sooooo00Oooooo00?ok^k^o`000?ooool01Oooool3o`00053ooooo00?o
0000ooooooooool0Qoooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03Oooool00omEEEGoV9RHooooo`07ooooo`03onk^k_l0003ooooo00Gooooo0ol0
000Wooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0gOooool0023ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03ojVYZOm4A4Cooooo00?ooooo00Ko410@
oiRHV?ooooooooooogMgMomVIVH6ooooo`03o`000?oooooooooo057ooooo0_l00026ooooo`03o`00
0?oooooooooo08gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03ojVY
ZOm4A4Cooooo00?ooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH6ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`3Nooooo`008?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000onk^k_ooool00_ooool01Ol0003o
8B4Qo`000?l0003oIVIV00Oooooo00?o0000ooooooooool0Doooool2o`0008;ooooo0_l0002@oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003ok^k^ooooo`02oooo
o`05o`000?lQ8B7o0000o`000?mVIVH01oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool0goooool0023ooooo00KoA4A4ojVYZOooooooooooojVYZOm4
A4@@ooooo`03oeEEEOnHV9Sooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Eooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0T?ooool01_m4A4CoZJVYoooo
ooooooooZJVYodA4A13ooooo00?oEEEEoiRHV?ooool00_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`3Pooooo`00
8?ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00Ko410@ooooooooooooooooojVYZOm4
A4@3ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E_ooool2o`0007cooooo0_l0
002Cooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool01_l@413oooooooooooooooooZJVY
odA4A0?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool0hOooool0027ooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool6
o`0000?ooooo1Ol00007ooooo`;o0000FOooool00ol0003oooooooooo`1gooooo`;o0000U_ooool0
1?nj^[[o410@oa0@4?o<c<`=ooooo`Ko00000oooool5o`0000Oooooo0_l0000/ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0hOooool004Oooooo00?o0000ooooooooool0FOooool2
o`0007Kooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0h_ooool004Oooooo00?o0000ooooooooool0Foooool2o`00
07;ooooo0_l0002oooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`3Sooooo`00Aoooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo06go
oooo0_l00031ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`3Tooooo`00Aoooool00ol0003oooooooooo`1Nooooo`;o0000K?ooool00ol0003ooooo
ooooo`31ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`3Uooooo`00Aoooool2o`00067ooooo0_l0001Xooooo`;o0000a?ooool2o`00033ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`3Vooooo`00Aoooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo06?ooooo0_l00036ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`3Wooooo`00Aoooool00ol0003oooooooooo`1Soooo
o`;o0000HOooool2o`000<Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo0>Sooooo0017ooooo`03o`000?oooooooooo06Gooooo0ol0001Looooo`;o
0000b_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool0jOooool004Oooooo00?o0000ooooooooool0J?ooool2o`0005Oooooo0ol0003<ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3Zooooo`00Aooo
ool2o`0006_ooooo0_l0001Cooooo`;o0000coooool2o`0003Gooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`3[ooooo`00Aoooool00ol0003oooooooooo`1/ooooo`?o0000C_ooool2
o`000=7ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo0>cooooo0017ooooo`03o`000?oooooooooo06oooooo0ol00018ooooo`?o0000doooool00ol0
003oooooooooo`0fooooo`;o00009?ooool2o`000>oooooo0017ooooo`03o`000?oooooooooo07;o
oooo0ol00012ooooo`?o0000e_ooool00ol0003oooooooooo`0hooooo`;o00008?ooool2o`000?7o
oooo0017ooooo`03o`000?oooooooooo07Gooooo0ol0000looooo`?o0000fOooool00ol0003ooooo
ooooo`0jooooo`;o00007Oooool00ol0003oooooooooo`3aooooo`00Aoooool2o`0007Wooooo0ol0
000fooooo`?o0000g?ooool2o`0003gooooo00?o0000ooooooooool06?ooool2o`000?Cooooo0017
ooooo`03o`000?oooooooooo07_ooooo1?l0000^ooooo`Co0000goooool00ol0003oooooooooo`0m
ooooo`;o00005oooool00ol0003oooooooooo`3dooooo`00??ooool4o`000003oa0@4?oooooooooo
00Cooooo00?o0000ooooooooool0Ooooool3o`0002Sooooo0ol0003Hooooo`Co000000?o410@oooo
ooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0mOooool003kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`22ooooo`Oo
00006oooool6o`000=gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`10ooooo`Co
00003oooool2o`000?Sooooo000nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
ROooool8o`0000Wooooo2_l0003Sooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
A?ooool4o`0000Gooooo1_l0003jooooo`00?_ooool00ol0003oooooooooo`06ooooo`?o0000TOoo
ool9o`000>gooooo00?o0000ooooooooool01_ooool3o`0004Oooooo1_l0003oooooo`7ooooo000n
ooooo`03o`000?oooooooooo0?ooooooTOooool00ol0003oooooooooo`3ooooooeOooooo000noooo
o`03o`000?oooooooooo0?ooooooTOooool00ol0003oooooooooo`3ooooooeOooooo000nooooo`03
o`000?oooooooooo0?ooooooTOooool00ol0003oooooooooo`3ooooooeOooooo000looooo`03o`00
0?m4A4Co00000?ooooooTOooool00ol0003oA4A4o`00003ooooooeWooooo000looooo`03olc<c?mE
EEGo00000?ooooooTOooool00oo<c<coEEEEo`00003ooooooeWooooo003oooooooooooooooooool]
ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003:ooooo`03oa0@
4?l0003o000000;ooooo0_l000000ol@413oooooooooo`0Kooooo`Co000000?o410@ooooooooool0
oooooomXooooo`03oa0@4?l0003o000000;ooooo0_l000000ol@413oooooooooo`0Jooooo`Ko0000
Xoooool00<_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`Ko00003_oo
ool00ol0003oooooooooo`3oooooof_ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0:ooooo`Ko00002oooool00onHV9So0000olc<c002ooooo`03oa0@4?oooooooooo0:7ooooo003;
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`3o
ooooof_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03oiRHV?l0003o
c<c<0:Gooooo003;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`3oooooof_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Moooo
o`03ojVYZOl@413oc<c<0:Cooooo003;ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooooooo
ool02_ooool6o`0000kooooo00?o0000ooooooooool0oooooom[ooooo`03o`000?o^k^kooooo00;o
oooo00?o0000ooooooooool02_ooool6o`0000kooooo00?oc<c<oa0@4?o<c<`0Xoooool00<_ooooo
00Ko0000odA4A?oMgMgoooooogMgMol@410Pooooo`03o`000?oooooooooo0?ooooooJoooool01_l0
003oA4A4omgMgOooooooMgMgoa0@427ooooo00?oZJVYoc8b<_ooool0X_ooool00<[ooooo00Oo410@
o`000?mgMgOo410@o`000?lQ8B7oc<c<023ooooo00?o0000ooooooooool0oooooomZooooo`07oa0@
4?l0003oMgMgoa0@4?l0003o8B4Qolc<c00Rooooo`03o`000?oooooooooo0:7ooooo003_ooooo`03
o`000?m4A4Co00000?ooooooT?ooool01_l0003oQhN7onk^k_ooooooMgMgoc8b<Z?ooooo003_oooo
o`03olc<c?mEEEGo00000?ooooooT?ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kZ?ooooo003o
ooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgo
oooo003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oooooooooooooo
ooooobgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oooooo
ooooooooooooobgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool0
0?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooooooo
;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00\
\>"],
  ImageRangeCache->{{{0, 809.75}, {500.062, 0}} -> {-0.0508237, -0.0309082, \
0.00389315, 0.00389315}, {{19.5625, 386.5}, {488.125, 261.312}} -> \
{-0.233021, -1.18872, 0.00491479, 0.0151472}, {{423.188, 790.125}, {488.125, \
261.312}} -> {-1.55551, -1.18872, 0.00491479, 0.0151472}, {{19.5625, 386.5}, \
{238.688, 11.875}} -> {-0.233021, -3.70758, 0.00491479, 0.0151472}, \
{{423.188, 790.125}, {238.688, 11.875}} -> {-1.55551, -3.70758, 0.00491479, \
0.0151472}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .347 L
.08255 .36492 L
.10458 .382 L
.12507 .3948 L
.14415 .40356 L
.14918 .40533 L
.15465 .40697 L
.15946 .40818 L
.16457 .40922 L
.16917 .40993 L
.17178 .41025 L
.17423 .41048 L
.17538 .41057 L
.17647 .41064 L
.17746 .41069 L
.17852 .41074 L
.17967 .41078 L
.18073 .41081 L
.182 .41082 L
.18314 .41082 L
.18435 .41081 L
.18547 .41078 L
.1867 .41074 L
.18802 .41067 L
.19071 .41049 L
.19317 .41026 L
.1979 .40965 L
.20239 .40886 L
.21236 .40642 L
.22321 .40269 L
.24299 .39315 L
.26399 .3795 L
.30174 .34783 L
.34195 .30833 L
.38063 .27035 L
.40028 .25289 L
.42177 .23622 L
.44253 .22323 L
.4614 .21455 L
.47149 .21124 L
.47611 .21004 L
.48101 .209 L
.4835 .20857 L
.48624 .20815 L
.48876 .20784 L
.49106 .20761 L
.49378 .2074 L
.49527 .20732 L
.49596 .20729 L
Mistroke
.49669 .20727 L
.498 .20723 L
.49921 .20721 L
.49996 .20721 L
.50065 .20721 L
.50196 .20723 L
.50313 .20726 L
.50438 .20731 L
.50556 .20737 L
.50663 .20743 L
.50926 .20764 L
.51175 .2079 L
.5167 .2086 L
.52208 .20963 L
.53169 .21218 L
.54056 .2153 L
.55926 .22422 L
.57988 .2374 L
.62014 .27107 L
.65888 .30916 L
.70007 .34951 L
.72063 .36756 L
.73974 .38217 L
.75939 .39447 L
.77791 .40312 L
.78775 .40645 L
.79293 .40784 L
.7984 .40902 L
.80302 .40978 L
.80546 .41011 L
.80809 .41038 L
.8105 .41058 L
.8127 .41071 L
.81375 .41075 L
.81491 .41079 L
.81599 .41081 L
.817 .41082 L
.81818 .41082 L
.81941 .4108 L
.82047 .41078 L
.82163 .41074 L
.82287 .41068 L
.82421 .4106 L
.82661 .41041 L
.82905 .41015 L
.83134 .40986 L
.83564 .40918 L
.84078 .40812 L
.84552 .40692 L
.85624 .40342 L
Mistroke
.87498 .39477 L
.89561 .38187 L
.93591 .34853 L
.97471 .31051 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32996 L
.08255 .33906 L
.0932 .34305 L
.10458 .34658 L
.11009 .34799 L
.11531 .34914 L
.12038 .35007 L
.12507 .35077 L
.12951 .35128 L
.13178 .35148 L
.13422 .35166 L
.13549 .35174 L
.13666 .3518 L
.13784 .35185 L
.13895 .35189 L
.14022 .35192 L
.1409 .35193 L
.14161 .35194 L
.1423 .35194 L
.14295 .35194 L
.14415 .35194 L
.14531 .35192 L
.14656 .35189 L
.14773 .35185 L
.14881 .35181 L
.15143 .35167 L
.15392 .35149 L
.15886 .35099 L
.16423 .35025 L
.17383 .34841 L
.1827 .34615 L
.20137 .33977 L
.22197 .3306 L
.26217 .30887 L
.30086 .28791 L
.32051 .27904 L
.3309 .27512 L
.342 .27164 L
.35275 .26903 L
.35784 .26807 L
.36253 .26735 L
.36724 .26679 L
.36972 .26656 L
.37235 .26637 L
.37463 .26624 L
.37573 .26619 L
.37677 .26616 L
.37799 .26612 L
.37911 .2661 L
Mistroke
.38031 .26609 L
.38162 .26609 L
.38227 .2661 L
.38296 .26611 L
.38419 .26613 L
.38551 .26617 L
.38695 .26623 L
.38955 .26637 L
.39197 .26654 L
.39649 .26699 L
.40134 .26763 L
.40698 .2686 L
.41232 .26972 L
.42232 .27233 L
.44227 .27939 L
.4607 .28774 L
.50002 .30903 L
.53782 .32956 L
.55884 .33909 L
.56803 .34258 L
.57808 .34582 L
.58722 .34821 L
.59696 .35013 L
.60236 .35091 L
.60726 .35142 L
.60962 .35161 L
.61086 .35169 L
.61218 .35177 L
.61333 .35182 L
.61459 .35187 L
.61574 .3519 L
.61682 .35192 L
.61808 .35194 L
.61871 .35194 L
.61941 .35194 L
.62065 .35193 L
.62181 .35191 L
.62248 .3519 L
.62318 .35188 L
.62443 .35183 L
.62578 .35177 L
.62725 .35169 L
.62973 .35152 L
.63238 .35128 L
.63715 .35072 L
.64214 .34997 L
.64686 .34908 L
.6557 .34702 L
.67568 .3405 L
.69413 .33255 L
Mistroke
.7335 .31162 L
.77136 .29078 L
.79241 .28082 L
.81166 .27359 L
.82118 .27083 L
.8262 .26962 L
.83155 .26851 L
.8367 .26764 L
.84136 .26702 L
.84361 .26677 L
.84604 .26655 L
.84835 .26638 L
.85045 .26626 L
.85159 .26621 L
.85283 .26616 L
.85414 .26612 L
.85538 .2661 L
.85653 .26609 L
.85776 .26609 L
.85881 .2661 L
.85997 .26612 L
.86063 .26614 L
.86132 .26616 L
.86256 .2662 L
.86535 .26634 L
.86777 .26651 L
.87041 .26675 L
.87569 .26737 L
.88133 .26826 L
.89148 .27042 L
.90173 .27331 L
.91284 .27717 L
.933 .28585 L
.97393 .30774 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34373 L
.10458 .38094 L
.14415 .41462 L
.18221 .44533 L
.22272 .47565 L
.26171 .50204 L
.30316 .52658 L
.34309 .54639 L
.3815 .56156 L
.40095 .56772 L
.42237 .57326 L
.44268 .5773 L
.45178 .57872 L
.46172 .57999 L
.4671 .58056 L
.4721 .58101 L
.47727 .5814 L
.48196 .58169 L
.48658 .5819 L
.4887 .58198 L
.49093 .58205 L
.49332 .5821 L
.49438 .58212 L
.49552 .58214 L
.49675 .58215 L
.49789 .58216 L
.49859 .58217 L
.49925 .58217 L
.50049 .58217 L
.50163 .58216 L
.50286 .58216 L
.50401 .58214 L
.50508 .58213 L
.50754 .58208 L
.51014 .58202 L
.51268 .58193 L
.51504 .58183 L
.5204 .58155 L
.5293 .58089 L
.53882 .57993 L
.54906 .5786 L
.56016 .57681 L
.58032 .57264 L
.62123 .56062 L
.66064 .54471 L
.69852 .52566 L
.73886 .50167 L
.77769 .47536 L
.81897 .44442 L
Mistroke
.85873 .41223 L
.89697 .37959 L
.93767 .34363 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35658 L
.10458 .40485 L
.14415 .44355 L
.18221 .47219 L
.20178 .48302 L
.21267 .4878 L
.22272 .4914 L
.23293 .49424 L
.23832 .49539 L
.24402 .49636 L
.24641 .49669 L
.24897 .49698 L
.25119 .4972 L
.25361 .49739 L
.25507 .49748 L
.25643 .49755 L
.25773 .4976 L
.2584 .49762 L
.25912 .49764 L
.25983 .49765 L
.26048 .49766 L
.26176 .49767 L
.26293 .49767 L
.26416 .49765 L
.26538 .49762 L
.26607 .4976 L
.26671 .49758 L
.26912 .49746 L
.27131 .49731 L
.27364 .49711 L
.27847 .49655 L
.2838 .49571 L
.29326 .49365 L
.30213 .49107 L
.32232 .48288 L
.34082 .47267 L
.38045 .44286 L
.41855 .40558 L
.45912 .35929 L
.49816 .31131 L
.53966 .26022 L
.57964 .21439 L
.61811 .17645 L
.63759 .16034 L
.65902 .14545 L
.67938 .13434 L
.69843 .12679 L
.70884 .12387 L
.71396 .12275 L
Mistroke
.71872 .1219 L
.72301 .1213 L
.72758 .12082 L
.7302 .12062 L
.73148 .12054 L
.73266 .12048 L
.73371 .12044 L
.73487 .12041 L
.73603 .12038 L
.73725 .12037 L
.73856 .12036 L
.73977 .12037 L
.7404 .12038 L
.7411 .1204 L
.74251 .12044 L
.74375 .12049 L
.74508 .12056 L
.74748 .12072 L
.74985 .12093 L
.75235 .1212 L
.7568 .1218 L
.76198 .1227 L
.7668 .12374 L
.77773 .12678 L
.78828 .13061 L
.79823 .13501 L
.81683 .14524 L
.85534 .17404 L
.89632 .21414 L
.93577 .2593 L
.97371 .30593 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32153 L
.08255 .32744 L
.10458 .33306 L
.12507 .33728 L
.14415 .34017 L
.14918 .34075 L
.15465 .34129 L
.15946 .34169 L
.16457 .34203 L
.16917 .34226 L
.17178 .34237 L
.17423 .34244 L
.17538 .34247 L
.17647 .3425 L
.17746 .34251 L
.17852 .34253 L
.17967 .34254 L
.18073 .34255 L
.182 .34256 L
.18314 .34256 L
.18435 .34255 L
.18547 .34254 L
.1867 .34253 L
.18802 .34251 L
.19071 .34245 L
.19317 .34237 L
.1979 .34217 L
.20239 .34191 L
.21236 .34111 L
.22321 .33988 L
.24299 .33673 L
.26399 .33224 L
.30174 .3218 L
.34195 .30879 L
.38063 .29628 L
.40028 .29052 L
.42177 .28503 L
.44253 .28076 L
.4614 .27789 L
.47149 .2768 L
.47611 .27641 L
.48101 .27607 L
.4835 .27592 L
.48624 .27579 L
.48876 .27568 L
.49106 .27561 L
.49378 .27554 L
.49527 .27551 L
.49596 .2755 L
Mistroke
.49669 .2755 L
.498 .27548 L
.49921 .27548 L
.49996 .27548 L
.50065 .27548 L
.50196 .27548 L
.50313 .27549 L
.50438 .27551 L
.50556 .27553 L
.50663 .27555 L
.50926 .27562 L
.51175 .2757 L
.5167 .27593 L
.52208 .27627 L
.53169 .27711 L
.54056 .27814 L
.55926 .28108 L
.57988 .28542 L
.62014 .29652 L
.65888 .30907 L
.70007 .32236 L
.72063 .3283 L
.73974 .33312 L
.75939 .33717 L
.77791 .34002 L
.78775 .34112 L
.79293 .34157 L
.7984 .34196 L
.80302 .34221 L
.80546 .34232 L
.80809 .34241 L
.8105 .34248 L
.8127 .34252 L
.81375 .34253 L
.81491 .34255 L
.81599 .34255 L
.817 .34256 L
.81818 .34256 L
.81941 .34255 L
.82047 .34254 L
.82163 .34253 L
.82287 .34251 L
.82421 .34248 L
.82661 .34242 L
.82905 .34234 L
.83134 .34224 L
.83564 .34202 L
.84078 .34167 L
.84552 .34127 L
.85624 .34012 L
Mistroke
.87498 .33727 L
.89561 .33302 L
.93591 .32203 L
.97471 .30951 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31193 L
.08255 .31319 L
.0932 .31374 L
.10458 .31424 L
.11009 .31443 L
.11531 .31459 L
.12038 .31472 L
.12507 .31482 L
.12951 .31489 L
.13178 .31492 L
.13422 .31494 L
.13549 .31495 L
.13666 .31496 L
.13784 .31497 L
.13895 .31497 L
.14022 .31498 L
.1409 .31498 L
.14161 .31498 L
.1423 .31498 L
.14295 .31498 L
.14415 .31498 L
.14531 .31498 L
.14656 .31497 L
.14773 .31497 L
.14881 .31496 L
.15143 .31494 L
.15392 .31492 L
.15886 .31485 L
.16423 .31474 L
.17383 .31449 L
.1827 .31417 L
.20137 .31329 L
.22197 .31202 L
.26217 .309 L
.30086 .30609 L
.32051 .30485 L
.3309 .30431 L
.342 .30382 L
.35275 .30346 L
.35784 .30333 L
.36253 .30323 L
.36724 .30315 L
.36972 .30312 L
.37235 .30309 L
.37463 .30307 L
.37573 .30307 L
.37677 .30306 L
.37799 .30306 L
.37911 .30306 L
Mistroke
.38031 .30305 L
.38162 .30305 L
.38227 .30306 L
.38296 .30306 L
.38419 .30306 L
.38551 .30306 L
.38695 .30307 L
.38955 .30309 L
.39197 .30312 L
.39649 .30318 L
.40134 .30327 L
.40698 .3034 L
.41232 .30356 L
.42232 .30392 L
.44227 .3049 L
.4607 .30606 L
.50002 .30902 L
.53782 .31187 L
.55884 .3132 L
.56803 .31368 L
.57808 .31413 L
.58722 .31446 L
.59696 .31473 L
.60236 .31484 L
.60726 .31491 L
.60962 .31493 L
.61086 .31495 L
.61218 .31496 L
.61333 .31496 L
.61459 .31497 L
.61574 .31497 L
.61682 .31498 L
.61808 .31498 L
.61871 .31498 L
.61941 .31498 L
.62065 .31498 L
.62181 .31498 L
.62248 .31497 L
.62318 .31497 L
.62443 .31496 L
.62578 .31496 L
.62725 .31494 L
.62973 .31492 L
.63238 .31489 L
.63715 .31481 L
.64214 .31471 L
.64686 .31458 L
.6557 .3143 L
.67568 .31339 L
.69413 .31229 L
Mistroke
.7335 .30938 L
.77136 .30648 L
.79241 .3051 L
.81166 .3041 L
.82118 .30371 L
.8262 .30354 L
.83155 .30339 L
.8367 .30327 L
.84136 .30318 L
.84361 .30315 L
.84604 .30312 L
.84835 .30309 L
.85045 .30308 L
.85159 .30307 L
.85283 .30306 L
.85414 .30306 L
.85538 .30306 L
.85653 .30305 L
.85776 .30305 L
.85881 .30306 L
.85997 .30306 L
.86063 .30306 L
.86132 .30306 L
.86256 .30307 L
.86535 .30309 L
.86777 .30311 L
.87041 .30315 L
.87569 .30323 L
.88133 .30336 L
.89148 .30366 L
.90173 .30406 L
.91284 .30459 L
.933 .3058 L
.97393 .30884 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33971 L
.10458 .37259 L
.14415 .40237 L
.18221 .42951 L
.22272 .45631 L
.26171 .47964 L
.30316 .50133 L
.34309 .51884 L
.3815 .53225 L
.40095 .53769 L
.42237 .54259 L
.44268 .54616 L
.45178 .54742 L
.46172 .54854 L
.4671 .54904 L
.4721 .54944 L
.47727 .54979 L
.48196 .55004 L
.48658 .55023 L
.4887 .5503 L
.49093 .55036 L
.49332 .55041 L
.49438 .55042 L
.49552 .55044 L
.49675 .55045 L
.49789 .55046 L
.49859 .55046 L
.49925 .55046 L
.50049 .55047 L
.50163 .55046 L
.50286 .55045 L
.50401 .55044 L
.50508 .55043 L
.50754 .55039 L
.51014 .55033 L
.51268 .55025 L
.51504 .55017 L
.5204 .54992 L
.5293 .54934 L
.53882 .54849 L
.54906 .54731 L
.56016 .54573 L
.58032 .54204 L
.62123 .53141 L
.66064 .51735 L
.69852 .50052 L
.73886 .47931 L
.77769 .45606 L
.81897 .4287 L
Mistroke
.85873 .40025 L
.89697 .3714 L
.93767 .33962 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33806 L
.10458 .36753 L
.14415 .39115 L
.18221 .40863 L
.20178 .41525 L
.21267 .41817 L
.22272 .42036 L
.23293 .42209 L
.23832 .4228 L
.24402 .42339 L
.24641 .42359 L
.24897 .42377 L
.25119 .4239 L
.25361 .42402 L
.25507 .42407 L
.25643 .42411 L
.25773 .42415 L
.2584 .42416 L
.25912 .42417 L
.25983 .42418 L
.26048 .42418 L
.26176 .42419 L
.26293 .42419 L
.26416 .42418 L
.26538 .42416 L
.26607 .42415 L
.26671 .42413 L
.26912 .42406 L
.27131 .42397 L
.27364 .42385 L
.27847 .4235 L
.2838 .42299 L
.29326 .42174 L
.30213 .42016 L
.32232 .41516 L
.34082 .40893 L
.38045 .39073 L
.41855 .36797 L
.45912 .33971 L
.49816 .31041 L
.53966 .27923 L
.57964 .25125 L
.61811 .22808 L
.63759 .21825 L
.65902 .20916 L
.67938 .20238 L
.69843 .19777 L
.70884 .19598 L
.71396 .1953 L
Mistroke
.71872 .19478 L
.72301 .19441 L
.72758 .19412 L
.7302 .194 L
.73148 .19395 L
.73266 .19392 L
.73371 .19389 L
.73487 .19387 L
.73603 .19385 L
.73725 .19385 L
.73856 .19384 L
.73977 .19385 L
.7404 .19386 L
.7411 .19387 L
.74251 .19389 L
.74375 .19392 L
.74508 .19397 L
.74748 .19406 L
.74985 .19419 L
.75235 .19435 L
.7568 .19472 L
.76198 .19527 L
.7668 .1959 L
.77773 .19776 L
.78828 .2001 L
.79823 .20279 L
.81683 .20903 L
.85534 .22662 L
.89632 .2511 L
.93577 .27867 L
.97371 .30713 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31314 L
.08255 .31508 L
.10458 .31694 L
.12507 .31833 L
.14415 .31928 L
.14918 .31947 L
.15465 .31965 L
.15946 .31978 L
.16457 .31989 L
.16917 .31997 L
.17178 .32 L
.17423 .32003 L
.17538 .32004 L
.17647 .32005 L
.17746 .32005 L
.17852 .32006 L
.17967 .32006 L
.18073 .32006 L
.182 .32007 L
.18314 .32007 L
.18435 .32006 L
.18547 .32006 L
.1867 .32006 L
.18802 .32005 L
.19071 .32003 L
.19317 .32001 L
.1979 .31994 L
.20239 .31985 L
.21236 .31959 L
.22321 .31918 L
.24299 .31815 L
.26399 .31667 L
.30174 .31323 L
.34195 .30894 L
.38063 .30482 L
.40028 .30292 L
.42177 .30112 L
.44253 .29971 L
.4614 .29876 L
.47149 .2984 L
.47611 .29827 L
.48101 .29816 L
.4835 .29811 L
.48624 .29807 L
.48876 .29804 L
.49106 .29801 L
.49378 .29799 L
.49527 .29798 L
.49596 .29798 L
Mistroke
.49669 .29797 L
.498 .29797 L
.49921 .29797 L
.49996 .29797 L
.50065 .29797 L
.50196 .29797 L
.50313 .29797 L
.50438 .29798 L
.50556 .29798 L
.50663 .29799 L
.50926 .29801 L
.51175 .29804 L
.5167 .29812 L
.52208 .29823 L
.53169 .29851 L
.54056 .29885 L
.55926 .29981 L
.57988 .30124 L
.62014 .3049 L
.65888 .30903 L
.70007 .31341 L
.72063 .31537 L
.73974 .31696 L
.75939 .31829 L
.77791 .31923 L
.78775 .31959 L
.79293 .31974 L
.7984 .31987 L
.80302 .31995 L
.80546 .31999 L
.80809 .32002 L
.8105 .32004 L
.8127 .32005 L
.81375 .32006 L
.81491 .32006 L
.81599 .32007 L
.817 .32007 L
.81818 .32007 L
.81941 .32006 L
.82047 .32006 L
.82163 .32006 L
.82287 .32005 L
.82421 .32004 L
.82661 .32002 L
.82905 .31999 L
.83134 .31996 L
.83564 .31989 L
.84078 .31977 L
.84552 .31964 L
.85624 .31926 L
Mistroke
.87498 .31832 L
.89561 .31692 L
.93591 .31331 L
.97471 .30918 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30942 L
.08255 .3096 L
.0932 .30967 L
.10458 .30974 L
.11009 .30977 L
.11531 .30979 L
.12038 .30981 L
.12507 .30982 L
.12951 .30983 L
.13178 .30984 L
.13422 .30984 L
.13549 .30984 L
.13666 .30984 L
.13784 .30984 L
.13895 .30984 L
.14022 .30984 L
.1409 .30985 L
.14161 .30985 L
.1423 .30985 L
.14295 .30985 L
.14415 .30985 L
.14531 .30984 L
.14656 .30984 L
.14773 .30984 L
.14881 .30984 L
.15143 .30984 L
.15392 .30984 L
.15886 .30983 L
.16423 .30981 L
.17383 .30978 L
.1827 .30973 L
.20137 .30961 L
.22197 .30943 L
.26217 .30901 L
.30086 .30861 L
.32051 .30844 L
.3309 .30836 L
.342 .3083 L
.35275 .30825 L
.35784 .30823 L
.36253 .30821 L
.36724 .3082 L
.36972 .3082 L
.37235 .30819 L
.37463 .30819 L
.37573 .30819 L
.37677 .30819 L
.37799 .30819 L
.37911 .30819 L
Mistroke
.38031 .30819 L
.38162 .30819 L
.38227 .30819 L
.38296 .30819 L
.38419 .30819 L
.38551 .30819 L
.38695 .30819 L
.38955 .30819 L
.39197 .3082 L
.39649 .30821 L
.40134 .30822 L
.40698 .30824 L
.41232 .30826 L
.42232 .30831 L
.44227 .30845 L
.4607 .30861 L
.50002 .30902 L
.53782 .30941 L
.55884 .3096 L
.56803 .30966 L
.57808 .30973 L
.58722 .30977 L
.59696 .30981 L
.60236 .30983 L
.60726 .30984 L
.60962 .30984 L
.61086 .30984 L
.61218 .30984 L
.61333 .30984 L
.61459 .30984 L
.61574 .30984 L
.61682 .30984 L
.61808 .30985 L
.61871 .30985 L
.61941 .30985 L
.62065 .30985 L
.62181 .30984 L
.62248 .30984 L
.62318 .30984 L
.62443 .30984 L
.62578 .30984 L
.62725 .30984 L
.62973 .30984 L
.63238 .30983 L
.63715 .30982 L
.64214 .30981 L
.64686 .30979 L
.6557 .30975 L
.67568 .30962 L
.69413 .30947 L
Mistroke
.7335 .30907 L
.77136 .30867 L
.79241 .30847 L
.81166 .30833 L
.82118 .30828 L
.8262 .30826 L
.83155 .30824 L
.8367 .30822 L
.84136 .30821 L
.84361 .3082 L
.84604 .3082 L
.84835 .30819 L
.85045 .30819 L
.85159 .30819 L
.85283 .30819 L
.85414 .30819 L
.85538 .30819 L
.85653 .30819 L
.85776 .30819 L
.85881 .30819 L
.85997 .30819 L
.86063 .30819 L
.86132 .30819 L
.86256 .30819 L
.86535 .30819 L
.86777 .3082 L
.87041 .3082 L
.87569 .30821 L
.88133 .30823 L
.89148 .30827 L
.90173 .30833 L
.91284 .3084 L
.933 .30857 L
.97393 .30899 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33614 L
.10458 .36521 L
.14415 .39153 L
.18221 .41553 L
.22272 .43922 L
.26171 .45983 L
.30316 .47901 L
.34309 .49448 L
.3815 .50634 L
.40095 .51115 L
.42237 .51548 L
.44268 .51864 L
.45178 .51975 L
.46172 .52074 L
.4671 .52119 L
.4721 .52154 L
.47727 .52184 L
.48196 .52206 L
.48658 .52223 L
.4887 .52229 L
.49093 .52235 L
.49332 .52239 L
.49438 .52241 L
.49552 .52242 L
.49675 .52243 L
.49789 .52244 L
.49859 .52244 L
.49925 .52244 L
.50049 .52244 L
.50163 .52244 L
.50286 .52243 L
.50401 .52242 L
.50508 .52241 L
.50754 .52238 L
.51014 .52232 L
.51268 .52226 L
.51504 .52218 L
.5204 .52196 L
.5293 .52145 L
.53882 .52069 L
.54906 .51965 L
.56016 .51825 L
.58032 .515 L
.62123 .5056 L
.66064 .49317 L
.69852 .47829 L
.73886 .45955 L
.77769 .43899 L
.81897 .41481 L
Mistroke
.85873 .38966 L
.89697 .36416 L
.93767 .33606 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32675 L
.10458 .34474 L
.14415 .35916 L
.18221 .36983 L
.20178 .37387 L
.21267 .37565 L
.22272 .37699 L
.23293 .37805 L
.23832 .37848 L
.24402 .37884 L
.24641 .37896 L
.24897 .37907 L
.25119 .37915 L
.25361 .37922 L
.25507 .37926 L
.25643 .37928 L
.25773 .3793 L
.2584 .37931 L
.25912 .37932 L
.25983 .37932 L
.26048 .37933 L
.26176 .37933 L
.26293 .37933 L
.26416 .37932 L
.26538 .37931 L
.26607 .3793 L
.26671 .37929 L
.26912 .37925 L
.27131 .37919 L
.27364 .37912 L
.27847 .37891 L
.2838 .3786 L
.29326 .37783 L
.30213 .37687 L
.32232 .37382 L
.34082 .37001 L
.38045 .3589 L
.41855 .34501 L
.45912 .32775 L
.49816 .30987 L
.53966 .29083 L
.57964 .27375 L
.61811 .25961 L
.63759 .2536 L
.65902 .24806 L
.67938 .24391 L
.69843 .2411 L
.70884 .24001 L
.71396 .23959 L
Mistroke
.71872 .23928 L
.72301 .23905 L
.72758 .23887 L
.7302 .2388 L
.73148 .23877 L
.73266 .23875 L
.73371 .23873 L
.73487 .23872 L
.73603 .23871 L
.73725 .23871 L
.73856 .2387 L
.73977 .23871 L
.7404 .23871 L
.7411 .23872 L
.74251 .23873 L
.74375 .23875 L
.74508 .23878 L
.74748 .23884 L
.74985 .23892 L
.75235 .23901 L
.7568 .23924 L
.76198 .23958 L
.7668 .23996 L
.77773 .24109 L
.78828 .24252 L
.79823 .24416 L
.81683 .24798 L
.85534 .25871 L
.89632 .27366 L
.93577 .29049 L
.97371 .30787 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31038 L
.08255 .31102 L
.10458 .31163 L
.12507 .31208 L
.14415 .3124 L
.14918 .31246 L
.15465 .31252 L
.15946 .31256 L
.16457 .3126 L
.16917 .31263 L
.17178 .31264 L
.17423 .31265 L
.17538 .31265 L
.17647 .31265 L
.17746 .31265 L
.17852 .31265 L
.17967 .31266 L
.18073 .31266 L
.182 .31266 L
.18314 .31266 L
.18435 .31266 L
.18547 .31266 L
.1867 .31265 L
.18802 .31265 L
.19071 .31265 L
.19317 .31264 L
.1979 .31262 L
.20239 .31259 L
.21236 .3125 L
.22321 .31237 L
.24299 .31203 L
.26399 .31154 L
.30174 .3104 L
.34195 .30899 L
.38063 .30763 L
.40028 .30701 L
.42177 .30641 L
.44253 .30595 L
.4614 .30564 L
.47149 .30552 L
.47611 .30548 L
.48101 .30544 L
.4835 .30543 L
.48624 .30541 L
.48876 .3054 L
.49106 .30539 L
.49378 .30538 L
.49527 .30538 L
.49596 .30538 L
Mistroke
.49669 .30538 L
.498 .30538 L
.49921 .30538 L
.49996 .30538 L
.50065 .30538 L
.50196 .30538 L
.50313 .30538 L
.50438 .30538 L
.50556 .30538 L
.50663 .30538 L
.50926 .30539 L
.51175 .3054 L
.5167 .30543 L
.52208 .30546 L
.53169 .30555 L
.54056 .30567 L
.55926 .30598 L
.57988 .30646 L
.62014 .30766 L
.65888 .30902 L
.70007 .31046 L
.72063 .31111 L
.73974 .31163 L
.75939 .31207 L
.77791 .31238 L
.78775 .3125 L
.79293 .31255 L
.7984 .31259 L
.80302 .31262 L
.80546 .31263 L
.80809 .31264 L
.8105 .31265 L
.8127 .31265 L
.81375 .31265 L
.81491 .31266 L
.81599 .31266 L
.817 .31266 L
.81818 .31266 L
.81941 .31266 L
.82047 .31266 L
.82163 .31265 L
.82287 .31265 L
.82421 .31265 L
.82661 .31264 L
.82905 .31263 L
.83134 .31262 L
.83564 .3126 L
.84078 .31256 L
.84552 .31252 L
.85624 .31239 L
Mistroke
.87498 .31208 L
.89561 .31162 L
.93591 .31043 L
.97471 .30907 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30907 L
.08255 .3091 L
.0932 .30911 L
.10458 .30912 L
.11009 .30912 L
.11531 .30912 L
.12038 .30913 L
.12507 .30913 L
.12951 .30913 L
.13178 .30913 L
.13422 .30913 L
.13549 .30913 L
.13666 .30913 L
.13784 .30913 L
.13895 .30913 L
.14022 .30913 L
.1409 .30913 L
.14161 .30913 L
.1423 .30913 L
.14295 .30913 L
.14415 .30913 L
.14531 .30913 L
.14656 .30913 L
.14773 .30913 L
.14881 .30913 L
.15143 .30913 L
.15392 .30913 L
.15886 .30913 L
.16423 .30913 L
.17383 .30912 L
.1827 .30912 L
.20137 .3091 L
.22197 .30907 L
.26217 .30902 L
.30086 .30896 L
.32051 .30894 L
.3309 .30893 L
.342 .30892 L
.35275 .30891 L
.35784 .30891 L
.36253 .30891 L
.36724 .3089 L
.36972 .3089 L
.37235 .3089 L
.37463 .3089 L
.37573 .3089 L
.37677 .3089 L
.37799 .3089 L
.37911 .3089 L
Mistroke
.38031 .3089 L
.38162 .3089 L
.38227 .3089 L
.38296 .3089 L
.38419 .3089 L
.38551 .3089 L
.38695 .3089 L
.38955 .3089 L
.39197 .3089 L
.39649 .3089 L
.40134 .30891 L
.40698 .30891 L
.41232 .30891 L
.42232 .30892 L
.44227 .30894 L
.4607 .30896 L
.50002 .30902 L
.53782 .30907 L
.55884 .3091 L
.56803 .30911 L
.57808 .30912 L
.58722 .30912 L
.59696 .30913 L
.60236 .30913 L
.60726 .30913 L
.60962 .30913 L
.61086 .30913 L
.61218 .30913 L
.61333 .30913 L
.61459 .30913 L
.61574 .30913 L
.61682 .30913 L
.61808 .30913 L
.61871 .30913 L
.61941 .30913 L
.62065 .30913 L
.62181 .30913 L
.62248 .30913 L
.62318 .30913 L
.62443 .30913 L
.62578 .30913 L
.62725 .30913 L
.62973 .30913 L
.63238 .30913 L
.63715 .30913 L
.64214 .30913 L
.64686 .30912 L
.6557 .30912 L
.67568 .3091 L
.69413 .30908 L
Mistroke
.7335 .30902 L
.77136 .30897 L
.79241 .30894 L
.81166 .30892 L
.82118 .30891 L
.8262 .30891 L
.83155 .30891 L
.8367 .30891 L
.84136 .3089 L
.84361 .3089 L
.84604 .3089 L
.84835 .3089 L
.85045 .3089 L
.85159 .3089 L
.85283 .3089 L
.85414 .3089 L
.85538 .3089 L
.85653 .3089 L
.85776 .3089 L
.85881 .3089 L
.85997 .3089 L
.86063 .3089 L
.86132 .3089 L
.86256 .3089 L
.86535 .3089 L
.86777 .3089 L
.87041 .3089 L
.87569 .30891 L
.88133 .30891 L
.89148 .30891 L
.90173 .30892 L
.91284 .30893 L
.933 .30895 L
.97393 .30901 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33299 L
.10458 .35869 L
.14415 .38196 L
.18221 .40317 L
.22272 .42411 L
.26171 .44233 L
.30316 .45928 L
.34309 .47296 L
.3815 .48344 L
.40095 .48769 L
.42237 .49152 L
.44268 .49431 L
.45178 .49529 L
.46172 .49617 L
.4671 .49656 L
.4721 .49687 L
.47727 .49714 L
.48196 .49734 L
.48658 .49749 L
.4887 .49754 L
.49093 .49759 L
.49332 .49763 L
.49438 .49764 L
.49552 .49765 L
.49675 .49766 L
.49789 .49767 L
.49859 .49767 L
.49925 .49767 L
.50049 .49767 L
.50163 .49767 L
.50286 .49766 L
.50401 .49765 L
.50508 .49764 L
.50754 .49761 L
.51014 .49757 L
.51268 .49751 L
.51504 .49744 L
.5204 .49724 L
.5293 .49679 L
.53882 .49613 L
.54906 .49521 L
.56016 .49397 L
.58032 .49109 L
.62123 .48279 L
.66064 .4718 L
.69852 .45864 L
.73886 .44208 L
.77769 .42391 L
.81897 .40253 L
Mistroke
.85873 .3803 L
.89697 .35776 L
.93767 .33292 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31984 L
.10458 .33082 L
.14415 .33963 L
.18221 .34614 L
.20178 .34861 L
.21267 .3497 L
.22272 .35052 L
.23293 .35116 L
.23832 .35142 L
.24402 .35164 L
.24641 .35172 L
.24897 .35179 L
.25119 .35184 L
.25361 .35188 L
.25507 .3519 L
.25643 .35191 L
.25773 .35193 L
.2584 .35193 L
.25912 .35194 L
.25983 .35194 L
.26048 .35194 L
.26176 .35194 L
.26293 .35194 L
.26416 .35194 L
.26538 .35193 L
.26607 .35193 L
.26671 .35192 L
.26912 .35189 L
.27131 .35186 L
.27364 .35181 L
.27847 .35169 L
.2838 .3515 L
.29326 .35103 L
.30213 .35044 L
.32232 .34858 L
.34082 .34626 L
.38045 .33947 L
.41855 .33099 L
.45912 .32046 L
.49816 .30954 L
.53966 .29791 L
.57964 .28749 L
.61811 .27885 L
.63759 .27519 L
.65902 .2718 L
.67938 .26927 L
.69843 .26755 L
.70884 .26689 L
.71396 .26663 L
Mistroke
.71872 .26644 L
.72301 .2663 L
.72758 .26619 L
.7302 .26615 L
.73148 .26613 L
.73266 .26612 L
.73371 .26611 L
.73487 .2661 L
.73603 .2661 L
.73725 .26609 L
.73856 .26609 L
.73977 .26609 L
.7404 .2661 L
.7411 .2661 L
.74251 .26611 L
.74375 .26612 L
.74508 .26614 L
.74748 .26617 L
.74985 .26622 L
.75235 .26628 L
.7568 .26642 L
.76198 .26662 L
.7668 .26686 L
.77773 .26755 L
.78828 .26842 L
.79823 .26942 L
.81683 .27175 L
.85534 .27831 L
.89632 .28743 L
.93577 .29771 L
.97371 .30831 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30946 L
.08255 .30968 L
.10458 .30988 L
.12507 .31003 L
.14415 .31013 L
.14918 .31015 L
.15465 .31017 L
.15946 .31019 L
.16457 .3102 L
.16917 .31021 L
.17178 .31021 L
.17423 .31021 L
.17538 .31021 L
.17647 .31021 L
.17746 .31021 L
.17852 .31022 L
.17967 .31022 L
.18073 .31022 L
.182 .31022 L
.18314 .31022 L
.18435 .31022 L
.18547 .31022 L
.1867 .31022 L
.18802 .31021 L
.19071 .31021 L
.19317 .31021 L
.1979 .3102 L
.20239 .31019 L
.21236 .31016 L
.22321 .31012 L
.24299 .31001 L
.26399 .30985 L
.30174 .30947 L
.34195 .30901 L
.38063 .30856 L
.40028 .30836 L
.42177 .30816 L
.44253 .30801 L
.4614 .3079 L
.47149 .30787 L
.47611 .30785 L
.48101 .30784 L
.4835 .30783 L
.48624 .30783 L
.48876 .30783 L
.49106 .30782 L
.49378 .30782 L
.49527 .30782 L
.49596 .30782 L
Mistroke
.49669 .30782 L
.498 .30782 L
.49921 .30782 L
.49996 .30782 L
.50065 .30782 L
.50196 .30782 L
.50313 .30782 L
.50438 .30782 L
.50556 .30782 L
.50663 .30782 L
.50926 .30782 L
.51175 .30783 L
.5167 .30783 L
.52208 .30785 L
.53169 .30788 L
.54056 .30791 L
.55926 .30802 L
.57988 .30817 L
.62014 .30857 L
.65888 .30902 L
.70007 .30949 L
.72063 .30971 L
.73974 .30988 L
.75939 .31002 L
.77791 .31013 L
.78775 .31016 L
.79293 .31018 L
.7984 .3102 L
.80302 .3102 L
.80546 .31021 L
.80809 .31021 L
.8105 .31021 L
.8127 .31021 L
.81375 .31022 L
.81491 .31022 L
.81599 .31022 L
.817 .31022 L
.81818 .31022 L
.81941 .31022 L
.82047 .31022 L
.82163 .31022 L
.82287 .31021 L
.82421 .31021 L
.82661 .31021 L
.82905 .31021 L
.83134 .31021 L
.83564 .3102 L
.84078 .31018 L
.84552 .31017 L
.85624 .31013 L
Mistroke
.87498 .31003 L
.89561 .30988 L
.93591 .30948 L
.97471 .30903 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30903 L
.0932 .30903 L
.10458 .30903 L
.11009 .30903 L
.11531 .30903 L
.12038 .30903 L
.12507 .30903 L
.12951 .30903 L
.13178 .30903 L
.13422 .30903 L
.13549 .30903 L
.13666 .30903 L
.13784 .30903 L
.13895 .30903 L
.14022 .30903 L
.1409 .30903 L
.14161 .30903 L
.1423 .30903 L
.14295 .30903 L
.14415 .30903 L
.14531 .30903 L
.14656 .30903 L
.14773 .30903 L
.14881 .30903 L
.15143 .30903 L
.15392 .30903 L
.15886 .30903 L
.16423 .30903 L
.17383 .30903 L
.1827 .30903 L
.20137 .30903 L
.22197 .30903 L
.26217 .30902 L
.30086 .30901 L
.32051 .30901 L
.3309 .309 L
.342 .309 L
.35275 .309 L
.35784 .309 L
.36253 .309 L
.36724 .309 L
.36972 .309 L
.37235 .309 L
.37463 .309 L
.37573 .309 L
.37677 .309 L
.37799 .309 L
.37911 .309 L
Mistroke
.38031 .309 L
.38162 .309 L
.38227 .309 L
.38296 .309 L
.38419 .309 L
.38551 .309 L
.38695 .309 L
.38955 .309 L
.39197 .309 L
.39649 .309 L
.40134 .309 L
.40698 .309 L
.41232 .309 L
.42232 .309 L
.44227 .30901 L
.4607 .30901 L
.50002 .30902 L
.53782 .30902 L
.55884 .30903 L
.56803 .30903 L
.57808 .30903 L
.58722 .30903 L
.59696 .30903 L
.60236 .30903 L
.60726 .30903 L
.60962 .30903 L
.61086 .30903 L
.61218 .30903 L
.61333 .30903 L
.61459 .30903 L
.61574 .30903 L
.61682 .30903 L
.61808 .30903 L
.61871 .30903 L
.61941 .30903 L
.62065 .30903 L
.62181 .30903 L
.62248 .30903 L
.62318 .30903 L
.62443 .30903 L
.62578 .30903 L
.62725 .30903 L
.62973 .30903 L
.63238 .30903 L
.63715 .30903 L
.64214 .30903 L
.64686 .30903 L
.6557 .30903 L
.67568 .30903 L
.69413 .30903 L
Mistroke
.7335 .30902 L
.77136 .30901 L
.79241 .30901 L
.81166 .309 L
.82118 .309 L
.8262 .309 L
.83155 .309 L
.8367 .309 L
.84136 .309 L
.84361 .309 L
.84604 .309 L
.84835 .309 L
.85045 .309 L
.85159 .309 L
.85283 .309 L
.85414 .309 L
.85538 .309 L
.85653 .309 L
.85776 .309 L
.85881 .309 L
.85997 .309 L
.86063 .309 L
.86132 .309 L
.86256 .309 L
.86535 .309 L
.86777 .309 L
.87041 .309 L
.87569 .309 L
.88133 .309 L
.89148 .309 L
.90173 .309 L
.91284 .30901 L
.933 .30901 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33021 L
.10458 .35292 L
.14415 .37349 L
.18221 .39224 L
.22272 .41075 L
.26171 .42686 L
.30316 .44184 L
.34309 .45393 L
.3815 .4632 L
.40095 .46695 L
.42237 .47034 L
.44268 .4728 L
.45178 .47367 L
.46172 .47445 L
.4671 .47479 L
.4721 .47507 L
.47727 .47531 L
.48196 .47548 L
.48658 .47561 L
.4887 .47566 L
.49093 .4757 L
.49332 .47573 L
.49438 .47575 L
.49552 .47576 L
.49675 .47577 L
.49789 .47577 L
.49859 .47577 L
.49925 .47577 L
.50049 .47578 L
.50163 .47577 L
.50286 .47577 L
.50401 .47576 L
.50508 .47575 L
.50754 .47572 L
.51014 .47568 L
.51268 .47563 L
.51504 .47557 L
.5204 .4754 L
.5293 .475 L
.53882 .47441 L
.54906 .4736 L
.56016 .4725 L
.58032 .46996 L
.62123 .46262 L
.66064 .45291 L
.69852 .44128 L
.73886 .42663 L
.77769 .41057 L
.81897 .39168 L
Mistroke
.85873 .37203 L
.89697 .3521 L
.93767 .33015 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31562 L
.10458 .32233 L
.14415 .32771 L
.18221 .33168 L
.20178 .33319 L
.21267 .33385 L
.22272 .33435 L
.23293 .33475 L
.23832 .33491 L
.24402 .33504 L
.24641 .33509 L
.24897 .33513 L
.25119 .33516 L
.25361 .33518 L
.25507 .3352 L
.25643 .33521 L
.25773 .33521 L
.2584 .33522 L
.25912 .33522 L
.25983 .33522 L
.26048 .33522 L
.26176 .33522 L
.26293 .33522 L
.26416 .33522 L
.26538 .33522 L
.26607 .33521 L
.26671 .33521 L
.26912 .33519 L
.27131 .33517 L
.27364 .33514 L
.27847 .33507 L
.2838 .33495 L
.29326 .33466 L
.30213 .33431 L
.32232 .33317 L
.34082 .33175 L
.38045 .32761 L
.41855 .32243 L
.45912 .316 L
.49816 .30934 L
.53966 .30224 L
.57964 .29587 L
.61811 .2906 L
.63759 .28836 L
.65902 .2863 L
.67938 .28475 L
.69843 .2837 L
.70884 .2833 L
.71396 .28314 L
Mistroke
.71872 .28302 L
.72301 .28294 L
.72758 .28287 L
.7302 .28285 L
.73148 .28284 L
.73266 .28283 L
.73371 .28282 L
.73487 .28282 L
.73603 .28281 L
.73725 .28281 L
.73856 .28281 L
.73977 .28281 L
.7404 .28281 L
.7411 .28282 L
.74251 .28282 L
.74375 .28283 L
.74508 .28284 L
.74748 .28286 L
.74985 .28289 L
.75235 .28293 L
.7568 .28301 L
.76198 .28314 L
.7668 .28328 L
.77773 .2837 L
.78828 .28423 L
.79823 .28485 L
.81683 .28627 L
.85534 .29027 L
.89632 .29584 L
.93577 .30211 L
.97371 .30859 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30916 L
.08255 .30923 L
.10458 .3093 L
.12507 .30935 L
.14415 .30938 L
.14918 .30939 L
.15465 .3094 L
.15946 .3094 L
.16457 .30941 L
.16917 .30941 L
.17178 .30941 L
.17423 .30941 L
.17538 .30941 L
.17647 .30941 L
.17746 .30941 L
.17852 .30941 L
.17967 .30941 L
.18073 .30941 L
.182 .30941 L
.18314 .30941 L
.18435 .30941 L
.18547 .30941 L
.1867 .30941 L
.18802 .30941 L
.19071 .30941 L
.19317 .30941 L
.1979 .30941 L
.20239 .3094 L
.21236 .3094 L
.22321 .30938 L
.24299 .30934 L
.26399 .30929 L
.30174 .30917 L
.34195 .30901 L
.38063 .30887 L
.40028 .3088 L
.42177 .30873 L
.44253 .30868 L
.4614 .30865 L
.47149 .30864 L
.47611 .30863 L
.48101 .30863 L
.4835 .30863 L
.48624 .30863 L
.48876 .30862 L
.49106 .30862 L
.49378 .30862 L
.49527 .30862 L
.49596 .30862 L
Mistroke
.49669 .30862 L
.498 .30862 L
.49921 .30862 L
.49996 .30862 L
.50065 .30862 L
.50196 .30862 L
.50313 .30862 L
.50438 .30862 L
.50556 .30862 L
.50663 .30862 L
.50926 .30862 L
.51175 .30862 L
.5167 .30863 L
.52208 .30863 L
.53169 .30864 L
.54056 .30865 L
.55926 .30869 L
.57988 .30874 L
.62014 .30887 L
.65888 .30902 L
.70007 .30917 L
.72063 .30924 L
.73974 .3093 L
.75939 .30935 L
.77791 .30938 L
.78775 .3094 L
.79293 .3094 L
.7984 .30941 L
.80302 .30941 L
.80546 .30941 L
.80809 .30941 L
.8105 .30941 L
.8127 .30941 L
.81375 .30941 L
.81491 .30941 L
.81599 .30941 L
.817 .30941 L
.81818 .30941 L
.81941 .30941 L
.82047 .30941 L
.82163 .30941 L
.82287 .30941 L
.82421 .30941 L
.82661 .30941 L
.82905 .30941 L
.83134 .30941 L
.83564 .30941 L
.84078 .3094 L
.84552 .3094 L
.85624 .30938 L
Mistroke
.87498 .30935 L
.89561 .3093 L
.93591 .30917 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30901 L
.35784 .30901 L
.36253 .30901 L
.36724 .30901 L
.36972 .30901 L
.37235 .30901 L
.37463 .30901 L
.37573 .30901 L
.37677 .30901 L
.37799 .30901 L
.37911 .30901 L
Mistroke
.38031 .30901 L
.38162 .30901 L
.38227 .30901 L
.38296 .30901 L
.38419 .30901 L
.38551 .30901 L
.38695 .30901 L
.38955 .30901 L
.39197 .30901 L
.39649 .30901 L
.40134 .30901 L
.40698 .30901 L
.41232 .30901 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30901 L
.83155 .30901 L
.8367 .30901 L
.84136 .30901 L
.84361 .30901 L
.84604 .30901 L
.84835 .30901 L
.85045 .30901 L
.85159 .30901 L
.85283 .30901 L
.85414 .30901 L
.85538 .30901 L
.85653 .30901 L
.85776 .30901 L
.85881 .30901 L
.85997 .30901 L
.86063 .30901 L
.86132 .30901 L
.86256 .30901 L
.86535 .30901 L
.86777 .30901 L
.87041 .30901 L
.87569 .30901 L
.88133 .30901 L
.89148 .30901 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32775 L
.10458 .34783 L
.14415 .36601 L
.18221 .38258 L
.22272 .39894 L
.26171 .41318 L
.30316 .42642 L
.34309 .43711 L
.3815 .4453 L
.40095 .44862 L
.42237 .45161 L
.44268 .45379 L
.45178 .45456 L
.46172 .45525 L
.4671 .45555 L
.4721 .4558 L
.47727 .45601 L
.48196 .45616 L
.48658 .45628 L
.4887 .45632 L
.49093 .45635 L
.49332 .45639 L
.49438 .4564 L
.49552 .4564 L
.49675 .45641 L
.49789 .45642 L
.49859 .45642 L
.49925 .45642 L
.50049 .45642 L
.50163 .45642 L
.50286 .45641 L
.50401 .45641 L
.50508 .4564 L
.50754 .45638 L
.51014 .45634 L
.51268 .45629 L
.51504 .45624 L
.5204 .45609 L
.5293 .45573 L
.53882 .45521 L
.54906 .45449 L
.56016 .45353 L
.58032 .45128 L
.62123 .44479 L
.66064 .43621 L
.69852 .42593 L
.73886 .41298 L
.77769 .39879 L
.81897 .38208 L
Mistroke
.85873 .36471 L
.89697 .3471 L
.93767 .3277 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31305 L
.10458 .31714 L
.14415 .32043 L
.18221 .32285 L
.20178 .32377 L
.21267 .32418 L
.22272 .32448 L
.23293 .32472 L
.23832 .32482 L
.24402 .3249 L
.24641 .32493 L
.24897 .32496 L
.25119 .32498 L
.25361 .32499 L
.25507 .325 L
.25643 .32501 L
.25773 .32501 L
.2584 .32501 L
.25912 .32501 L
.25983 .32501 L
.26048 .32502 L
.26176 .32502 L
.26293 .32502 L
.26416 .32501 L
.26538 .32501 L
.26607 .32501 L
.26671 .32501 L
.26912 .325 L
.27131 .32499 L
.27364 .32497 L
.27847 .32492 L
.2838 .32485 L
.29326 .32467 L
.30213 .32446 L
.32232 .32376 L
.34082 .3229 L
.38045 .32037 L
.41855 .31721 L
.45912 .31328 L
.49816 .30921 L
.53966 .30488 L
.57964 .30099 L
.61811 .29777 L
.63759 .29641 L
.65902 .29515 L
.67938 .2942 L
.69843 .29356 L
.70884 .29332 L
.71396 .29322 L
Mistroke
.71872 .29315 L
.72301 .2931 L
.72758 .29306 L
.7302 .29304 L
.73148 .29303 L
.73266 .29303 L
.73371 .29302 L
.73487 .29302 L
.73603 .29302 L
.73725 .29302 L
.73856 .29302 L
.73977 .29302 L
.7404 .29302 L
.7411 .29302 L
.74251 .29302 L
.74375 .29303 L
.74508 .29304 L
.74748 .29305 L
.74985 .29307 L
.75235 .29309 L
.7568 .29314 L
.76198 .29322 L
.7668 .2933 L
.77773 .29356 L
.78828 .29389 L
.79823 .29426 L
.81683 .29513 L
.85534 .29757 L
.89632 .30097 L
.93577 .3048 L
.97371 .30876 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30907 L
.08255 .30909 L
.10458 .30911 L
.12507 .30913 L
.14415 .30914 L
.14918 .30914 L
.15465 .30914 L
.15946 .30914 L
.16457 .30915 L
.16917 .30915 L
.17178 .30915 L
.17423 .30915 L
.17538 .30915 L
.17647 .30915 L
.17746 .30915 L
.17852 .30915 L
.17967 .30915 L
.18073 .30915 L
.182 .30915 L
.18314 .30915 L
.18435 .30915 L
.18547 .30915 L
.1867 .30915 L
.18802 .30915 L
.19071 .30915 L
.19317 .30915 L
.1979 .30915 L
.20239 .30914 L
.21236 .30914 L
.22321 .30914 L
.24299 .30912 L
.26399 .30911 L
.30174 .30907 L
.34195 .30902 L
.38063 .30897 L
.40028 .30895 L
.42177 .30892 L
.44253 .30891 L
.4614 .3089 L
.47149 .30889 L
.47611 .30889 L
.48101 .30889 L
.4835 .30889 L
.48624 .30889 L
.48876 .30889 L
.49106 .30889 L
.49378 .30889 L
.49527 .30889 L
.49596 .30889 L
Mistroke
.49669 .30889 L
.498 .30889 L
.49921 .30889 L
.49996 .30889 L
.50065 .30889 L
.50196 .30889 L
.50313 .30889 L
.50438 .30889 L
.50556 .30889 L
.50663 .30889 L
.50926 .30889 L
.51175 .30889 L
.5167 .30889 L
.52208 .30889 L
.53169 .30889 L
.54056 .3089 L
.55926 .30891 L
.57988 .30893 L
.62014 .30897 L
.65888 .30902 L
.70007 .30907 L
.72063 .30909 L
.73974 .30911 L
.75939 .30913 L
.77791 .30914 L
.78775 .30914 L
.79293 .30914 L
.7984 .30914 L
.80302 .30915 L
.80546 .30915 L
.80809 .30915 L
.8105 .30915 L
.8127 .30915 L
.81375 .30915 L
.81491 .30915 L
.81599 .30915 L
.817 .30915 L
.81818 .30915 L
.81941 .30915 L
.82047 .30915 L
.82163 .30915 L
.82287 .30915 L
.82421 .30915 L
.82661 .30915 L
.82905 .30915 L
.83134 .30915 L
.83564 .30915 L
.84078 .30914 L
.84552 .30914 L
.85624 .30914 L
Mistroke
.87498 .30913 L
.89561 .30911 L
.93591 .30907 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30902 L
.35784 .30902 L
.36253 .30902 L
.36724 .30902 L
.36972 .30902 L
.37235 .30902 L
.37463 .30902 L
.37573 .30902 L
.37677 .30902 L
.37799 .30902 L
.37911 .30902 L
Mistroke
.38031 .30902 L
.38162 .30902 L
.38227 .30902 L
.38296 .30902 L
.38419 .30902 L
.38551 .30902 L
.38695 .30902 L
.38955 .30902 L
.39197 .30902 L
.39649 .30902 L
.40134 .30902 L
.40698 .30902 L
.41232 .30902 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30902 L
.83155 .30902 L
.8367 .30902 L
.84136 .30902 L
.84361 .30902 L
.84604 .30902 L
.84835 .30902 L
.85045 .30902 L
.85159 .30902 L
.85283 .30902 L
.85414 .30902 L
.85538 .30902 L
.85653 .30902 L
.85776 .30902 L
.85881 .30902 L
.85997 .30902 L
.86063 .30902 L
.86132 .30902 L
.86256 .30902 L
.86535 .30902 L
.86777 .30902 L
.87041 .30902 L
.87569 .30902 L
.88133 .30902 L
.89148 .30902 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32558 L
.10458 .34332 L
.14415 .35939 L
.18221 .37404 L
.22272 .3885 L
.26171 .40109 L
.30316 .4128 L
.34309 .42224 L
.3815 .42948 L
.40095 .43242 L
.42237 .43506 L
.44268 .43699 L
.45178 .43767 L
.46172 .43828 L
.4671 .43855 L
.4721 .43876 L
.47727 .43895 L
.48196 .43908 L
.48658 .43918 L
.4887 .43922 L
.49093 .43925 L
.49332 .43928 L
.49438 .43929 L
.49552 .4393 L
.49675 .43931 L
.49789 .43931 L
.49859 .43931 L
.49925 .43931 L
.50049 .43931 L
.50163 .43931 L
.50286 .43931 L
.50401 .4393 L
.50508 .43929 L
.50754 .43927 L
.51014 .43924 L
.51268 .4392 L
.51504 .43915 L
.5204 .43902 L
.5293 .4387 L
.53882 .43825 L
.54906 .43761 L
.56016 .43676 L
.58032 .43477 L
.62123 .42903 L
.66064 .42144 L
.69852 .41236 L
.73886 .40092 L
.77769 .38837 L
.81897 .3736 L
Mistroke
.85873 .35825 L
.89697 .34268 L
.93767 .32553 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31148 L
.10458 .31398 L
.14415 .31598 L
.18221 .31746 L
.20178 .31803 L
.21267 .31827 L
.22272 .31846 L
.23293 .31861 L
.23832 .31867 L
.24402 .31872 L
.24641 .31873 L
.24897 .31875 L
.25119 .31876 L
.25361 .31877 L
.25507 .31877 L
.25643 .31878 L
.25773 .31878 L
.2584 .31878 L
.25912 .31878 L
.25983 .31878 L
.26048 .31878 L
.26176 .31878 L
.26293 .31878 L
.26416 .31878 L
.26538 .31878 L
.26607 .31878 L
.26671 .31878 L
.26912 .31877 L
.27131 .31877 L
.27364 .31875 L
.27847 .31873 L
.2838 .31868 L
.29326 .31858 L
.30213 .31844 L
.32232 .31802 L
.34082 .31749 L
.38045 .31595 L
.41855 .31402 L
.45912 .31162 L
.49816 .30914 L
.53966 .30649 L
.57964 .30412 L
.61811 .30215 L
.63759 .30132 L
.65902 .30055 L
.67938 .29997 L
.69843 .29958 L
.70884 .29943 L
.71396 .29937 L
Mistroke
.71872 .29933 L
.72301 .2993 L
.72758 .29927 L
.7302 .29926 L
.73148 .29926 L
.73266 .29926 L
.73371 .29925 L
.73487 .29925 L
.73603 .29925 L
.73725 .29925 L
.73856 .29925 L
.73977 .29925 L
.7404 .29925 L
.7411 .29925 L
.74251 .29925 L
.74375 .29926 L
.74508 .29926 L
.74748 .29927 L
.74985 .29928 L
.75235 .29929 L
.7568 .29932 L
.76198 .29937 L
.7668 .29942 L
.77773 .29958 L
.78828 .29978 L
.79823 .30001 L
.81683 .30054 L
.85534 .30203 L
.89632 .3041 L
.93577 .30644 L
.97371 .30886 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30903 L
.08255 .30904 L
.10458 .30905 L
.12507 .30905 L
.14415 .30906 L
.14918 .30906 L
.15465 .30906 L
.15946 .30906 L
.16457 .30906 L
.16917 .30906 L
.17178 .30906 L
.17423 .30906 L
.17538 .30906 L
.17647 .30906 L
.17746 .30906 L
.17852 .30906 L
.17967 .30906 L
.18073 .30906 L
.182 .30906 L
.18314 .30906 L
.18435 .30906 L
.18547 .30906 L
.1867 .30906 L
.18802 .30906 L
.19071 .30906 L
.19317 .30906 L
.1979 .30906 L
.20239 .30906 L
.21236 .30906 L
.22321 .30906 L
.24299 .30905 L
.26399 .30905 L
.30174 .30903 L
.34195 .30902 L
.38063 .309 L
.40028 .30899 L
.42177 .30899 L
.44253 .30898 L
.4614 .30898 L
.47149 .30898 L
.47611 .30898 L
.48101 .30897 L
.4835 .30897 L
.48624 .30897 L
.48876 .30897 L
.49106 .30897 L
.49378 .30897 L
.49527 .30897 L
.49596 .30897 L
Mistroke
.49669 .30897 L
.498 .30897 L
.49921 .30897 L
.49996 .30897 L
.50065 .30897 L
.50196 .30897 L
.50313 .30897 L
.50438 .30897 L
.50556 .30897 L
.50663 .30897 L
.50926 .30897 L
.51175 .30897 L
.5167 .30897 L
.52208 .30898 L
.53169 .30898 L
.54056 .30898 L
.55926 .30898 L
.57988 .30899 L
.62014 .309 L
.65888 .30902 L
.70007 .30903 L
.72063 .30904 L
.73974 .30905 L
.75939 .30905 L
.77791 .30906 L
.78775 .30906 L
.79293 .30906 L
.7984 .30906 L
.80302 .30906 L
.80546 .30906 L
.80809 .30906 L
.8105 .30906 L
.8127 .30906 L
.81375 .30906 L
.81491 .30906 L
.81599 .30906 L
.817 .30906 L
.81818 .30906 L
.81941 .30906 L
.82047 .30906 L
.82163 .30906 L
.82287 .30906 L
.82421 .30906 L
.82661 .30906 L
.82905 .30906 L
.83134 .30906 L
.83564 .30906 L
.84078 .30906 L
.84552 .30906 L
.85624 .30906 L
Mistroke
.87498 .30905 L
.89561 .30905 L
.93591 .30903 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30902 L
.35784 .30902 L
.36253 .30902 L
.36724 .30902 L
.36972 .30902 L
.37235 .30902 L
.37463 .30902 L
.37573 .30902 L
.37677 .30902 L
.37799 .30902 L
.37911 .30902 L
Mistroke
.38031 .30902 L
.38162 .30902 L
.38227 .30902 L
.38296 .30902 L
.38419 .30902 L
.38551 .30902 L
.38695 .30902 L
.38955 .30902 L
.39197 .30902 L
.39649 .30902 L
.40134 .30902 L
.40698 .30902 L
.41232 .30902 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30902 L
.83155 .30902 L
.8367 .30902 L
.84136 .30902 L
.84361 .30902 L
.84604 .30902 L
.84835 .30902 L
.85045 .30902 L
.85159 .30902 L
.85283 .30902 L
.85414 .30902 L
.85538 .30902 L
.85653 .30902 L
.85776 .30902 L
.85881 .30902 L
.85997 .30902 L
.86063 .30902 L
.86132 .30902 L
.86256 .30902 L
.86535 .30902 L
.86777 .30902 L
.87041 .30902 L
.87569 .30902 L
.88133 .30902 L
.89148 .30902 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32366 L
.10458 .33934 L
.14415 .35355 L
.18221 .36649 L
.22272 .37928 L
.26171 .3904 L
.30316 .40075 L
.34309 .4091 L
.3815 .4155 L
.40095 .4181 L
.42237 .42043 L
.44268 .42214 L
.45178 .42274 L
.46172 .42327 L
.4671 .42351 L
.4721 .4237 L
.47727 .42387 L
.48196 .42399 L
.48658 .42408 L
.4887 .42411 L
.49093 .42414 L
.49332 .42416 L
.49438 .42417 L
.49552 .42418 L
.49675 .42418 L
.49789 .42419 L
.49859 .42419 L
.49925 .42419 L
.50049 .42419 L
.50163 .42419 L
.50286 .42418 L
.50401 .42418 L
.50508 .42417 L
.50754 .42415 L
.51014 .42413 L
.51268 .42409 L
.51504 .42405 L
.5204 .42393 L
.5293 .42365 L
.53882 .42325 L
.54906 .42269 L
.56016 .42193 L
.58032 .42017 L
.62123 .4151 L
.66064 .4084 L
.69852 .40036 L
.73886 .39025 L
.77769 .37916 L
.81897 .36611 L
Mistroke
.85873 .35254 L
.89697 .33877 L
.93767 .32361 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31052 L
.10458 .31205 L
.14415 .31327 L
.18221 .31417 L
.20178 .31452 L
.21267 .31467 L
.22272 .31478 L
.23293 .31487 L
.23832 .31491 L
.24402 .31494 L
.24641 .31495 L
.24897 .31496 L
.25119 .31496 L
.25361 .31497 L
.25507 .31497 L
.25643 .31498 L
.25773 .31498 L
.2584 .31498 L
.25912 .31498 L
.25983 .31498 L
.26048 .31498 L
.26176 .31498 L
.26293 .31498 L
.26416 .31498 L
.26538 .31498 L
.26607 .31498 L
.26671 .31498 L
.26912 .31497 L
.27131 .31497 L
.27364 .31496 L
.27847 .31494 L
.2838 .31492 L
.29326 .31485 L
.30213 .31477 L
.32232 .31451 L
.34082 .31419 L
.38045 .31325 L
.41855 .31207 L
.45912 .31061 L
.49816 .30909 L
.53966 .30747 L
.57964 .30603 L
.61811 .30483 L
.63759 .30432 L
.65902 .30385 L
.67938 .3035 L
.69843 .30326 L
.70884 .30316 L
.71396 .30313 L
Mistroke
.71872 .3031 L
.72301 .30308 L
.72758 .30307 L
.7302 .30306 L
.73148 .30306 L
.73266 .30306 L
.73371 .30306 L
.73487 .30306 L
.73603 .30305 L
.73725 .30305 L
.73856 .30305 L
.73977 .30305 L
.7404 .30305 L
.7411 .30306 L
.74251 .30306 L
.74375 .30306 L
.74508 .30306 L
.74748 .30307 L
.74985 .30307 L
.75235 .30308 L
.7568 .3031 L
.76198 .30313 L
.7668 .30316 L
.77773 .30326 L
.78828 .30338 L
.79823 .30352 L
.81683 .30384 L
.85534 .30475 L
.89632 .30602 L
.93577 .30745 L
.97371 .30892 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30903 L
.12507 .30903 L
.14415 .30903 L
.14918 .30903 L
.15465 .30903 L
.15946 .30903 L
.16457 .30903 L
.16917 .30903 L
.17178 .30903 L
.17423 .30903 L
.17538 .30903 L
.17647 .30903 L
.17746 .30903 L
.17852 .30903 L
.17967 .30903 L
.18073 .30903 L
.182 .30903 L
.18314 .30903 L
.18435 .30903 L
.18547 .30903 L
.1867 .30903 L
.18802 .30903 L
.19071 .30903 L
.19317 .30903 L
.1979 .30903 L
.20239 .30903 L
.21236 .30903 L
.22321 .30903 L
.24299 .30903 L
.26399 .30903 L
.30174 .30902 L
.34195 .30902 L
.38063 .30901 L
.40028 .30901 L
.42177 .30901 L
.44253 .30901 L
.4614 .309 L
.47149 .309 L
.47611 .309 L
.48101 .309 L
.4835 .309 L
.48624 .309 L
.48876 .309 L
.49106 .309 L
.49378 .309 L
.49527 .309 L
.49596 .309 L
Mistroke
.49669 .309 L
.498 .309 L
.49921 .309 L
.49996 .309 L
.50065 .309 L
.50196 .309 L
.50313 .309 L
.50438 .309 L
.50556 .309 L
.50663 .309 L
.50926 .309 L
.51175 .309 L
.5167 .309 L
.52208 .309 L
.53169 .309 L
.54056 .309 L
.55926 .30901 L
.57988 .30901 L
.62014 .30901 L
.65888 .30902 L
.70007 .30902 L
.72063 .30903 L
.73974 .30903 L
.75939 .30903 L
.77791 .30903 L
.78775 .30903 L
.79293 .30903 L
.7984 .30903 L
.80302 .30903 L
.80546 .30903 L
.80809 .30903 L
.8105 .30903 L
.8127 .30903 L
.81375 .30903 L
.81491 .30903 L
.81599 .30903 L
.817 .30903 L
.81818 .30903 L
.81941 .30903 L
.82047 .30903 L
.82163 .30903 L
.82287 .30903 L
.82421 .30903 L
.82661 .30903 L
.82905 .30903 L
.83134 .30903 L
.83564 .30903 L
.84078 .30903 L
.84552 .30903 L
.85624 .30903 L
Mistroke
.87498 .30903 L
.89561 .30903 L
.93591 .30902 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30902 L
.35784 .30902 L
.36253 .30902 L
.36724 .30902 L
.36972 .30902 L
.37235 .30902 L
.37463 .30902 L
.37573 .30902 L
.37677 .30902 L
.37799 .30902 L
.37911 .30902 L
Mistroke
.38031 .30902 L
.38162 .30902 L
.38227 .30902 L
.38296 .30902 L
.38419 .30902 L
.38551 .30902 L
.38695 .30902 L
.38955 .30902 L
.39197 .30902 L
.39649 .30902 L
.40134 .30902 L
.40698 .30902 L
.41232 .30902 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30902 L
.83155 .30902 L
.8367 .30902 L
.84136 .30902 L
.84361 .30902 L
.84604 .30902 L
.84835 .30902 L
.85045 .30902 L
.85159 .30902 L
.85283 .30902 L
.85414 .30902 L
.85538 .30902 L
.85653 .30902 L
.85776 .30902 L
.85881 .30902 L
.85997 .30902 L
.86063 .30902 L
.86132 .30902 L
.86256 .30902 L
.86535 .30902 L
.86777 .30902 L
.87041 .30902 L
.87569 .30902 L
.88133 .30902 L
.89148 .30902 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32196 L
.10458 .33582 L
.14415 .34838 L
.18221 .35982 L
.22272 .37112 L
.26171 .38096 L
.30316 .3901 L
.34309 .39749 L
.3815 .40314 L
.40095 .40544 L
.42237 .4075 L
.44268 .40901 L
.45178 .40954 L
.46172 .41001 L
.4671 .41022 L
.4721 .41039 L
.47727 .41054 L
.48196 .41064 L
.48658 .41072 L
.4887 .41075 L
.49093 .41078 L
.49332 .4108 L
.49438 .41081 L
.49552 .41081 L
.49675 .41082 L
.49789 .41082 L
.49859 .41082 L
.49925 .41082 L
.50049 .41082 L
.50163 .41082 L
.50286 .41082 L
.50401 .41081 L
.50508 .41081 L
.50754 .41079 L
.51014 .41077 L
.51268 .41073 L
.51504 .4107 L
.5204 .41059 L
.5293 .41035 L
.53882 .40999 L
.54906 .40949 L
.56016 .40882 L
.58032 .40727 L
.62123 .40279 L
.66064 .39686 L
.69852 .38976 L
.73886 .38082 L
.77769 .37102 L
.81897 .35948 L
Mistroke
.85873 .34748 L
.89697 .33532 L
.93767 .32192 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30993 L
.10458 .31087 L
.14415 .31161 L
.18221 .31217 L
.20178 .31237 L
.21267 .31247 L
.22272 .31254 L
.23293 .31259 L
.23832 .31261 L
.24402 .31263 L
.24641 .31264 L
.24897 .31264 L
.25119 .31265 L
.25361 .31265 L
.25507 .31265 L
.25643 .31265 L
.25773 .31266 L
.2584 .31266 L
.25912 .31266 L
.25983 .31266 L
.26048 .31266 L
.26176 .31266 L
.26293 .31266 L
.26416 .31266 L
.26538 .31266 L
.26607 .31266 L
.26671 .31266 L
.26912 .31265 L
.27131 .31265 L
.27364 .31265 L
.27847 .31264 L
.2838 .31262 L
.29326 .31258 L
.30213 .31253 L
.32232 .31237 L
.34082 .31217 L
.38045 .3116 L
.41855 .31088 L
.45912 .30999 L
.49816 .30906 L
.53966 .30808 L
.57964 .30719 L
.61811 .30646 L
.63759 .30615 L
.65902 .30586 L
.67938 .30565 L
.69843 .3055 L
.70884 .30544 L
.71396 .30542 L
Mistroke
.71872 .30541 L
.72301 .30539 L
.72758 .30539 L
.7302 .30538 L
.73148 .30538 L
.73266 .30538 L
.73371 .30538 L
.73487 .30538 L
.73603 .30538 L
.73725 .30538 L
.73856 .30538 L
.73977 .30538 L
.7404 .30538 L
.7411 .30538 L
.74251 .30538 L
.74375 .30538 L
.74508 .30538 L
.74748 .30538 L
.74985 .30539 L
.75235 .30539 L
.7568 .3054 L
.76198 .30542 L
.7668 .30544 L
.77773 .3055 L
.78828 .30557 L
.79823 .30566 L
.81683 .30586 L
.85534 .30641 L
.89632 .30719 L
.93577 .30806 L
.97371 .30896 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.14918 .30902 L
.15465 .30902 L
.15946 .30902 L
.16457 .30902 L
.16917 .30902 L
.17178 .30902 L
.17423 .30902 L
.17538 .30902 L
.17647 .30902 L
.17746 .30902 L
.17852 .30902 L
.17967 .30902 L
.18073 .30902 L
.182 .30902 L
.18314 .30902 L
.18435 .30902 L
.18547 .30902 L
.1867 .30902 L
.18802 .30902 L
.19071 .30902 L
.19317 .30902 L
.1979 .30902 L
.20239 .30902 L
.21236 .30902 L
.22321 .30902 L
.24299 .30902 L
.26399 .30902 L
.30174 .30902 L
.34195 .30902 L
.38063 .30902 L
.40028 .30901 L
.42177 .30901 L
.44253 .30901 L
.4614 .30901 L
.47149 .30901 L
.47611 .30901 L
.48101 .30901 L
.4835 .30901 L
.48624 .30901 L
.48876 .30901 L
.49106 .30901 L
.49378 .30901 L
.49527 .30901 L
.49596 .30901 L
Mistroke
.49669 .30901 L
.498 .30901 L
.49921 .30901 L
.49996 .30901 L
.50065 .30901 L
.50196 .30901 L
.50313 .30901 L
.50438 .30901 L
.50556 .30901 L
.50663 .30901 L
.50926 .30901 L
.51175 .30901 L
.5167 .30901 L
.52208 .30901 L
.53169 .30901 L
.54056 .30901 L
.55926 .30901 L
.57988 .30901 L
.62014 .30902 L
.65888 .30902 L
.70007 .30902 L
.72063 .30902 L
.73974 .30902 L
.75939 .30902 L
.77791 .30902 L
.78775 .30902 L
.79293 .30902 L
.7984 .30902 L
.80302 .30902 L
.80546 .30902 L
.80809 .30902 L
.8105 .30902 L
.8127 .30902 L
.81375 .30902 L
.81491 .30902 L
.81599 .30902 L
.817 .30902 L
.81818 .30902 L
.81941 .30902 L
.82047 .30902 L
.82163 .30902 L
.82287 .30902 L
.82421 .30902 L
.82661 .30902 L
.82905 .30902 L
.83134 .30902 L
.83564 .30902 L
.84078 .30902 L
.84552 .30902 L
.85624 .30902 L
Mistroke
.87498 .30902 L
.89561 .30902 L
.93591 .30902 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30902 L
.35784 .30902 L
.36253 .30902 L
.36724 .30902 L
.36972 .30902 L
.37235 .30902 L
.37463 .30902 L
.37573 .30902 L
.37677 .30902 L
.37799 .30902 L
.37911 .30902 L
Mistroke
.38031 .30902 L
.38162 .30902 L
.38227 .30902 L
.38296 .30902 L
.38419 .30902 L
.38551 .30902 L
.38695 .30902 L
.38955 .30902 L
.39197 .30902 L
.39649 .30902 L
.40134 .30902 L
.40698 .30902 L
.41232 .30902 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30902 L
.83155 .30902 L
.8367 .30902 L
.84136 .30902 L
.84361 .30902 L
.84604 .30902 L
.84835 .30902 L
.85045 .30902 L
.85159 .30902 L
.85283 .30902 L
.85414 .30902 L
.85538 .30902 L
.85653 .30902 L
.85776 .30902 L
.85881 .30902 L
.85997 .30902 L
.86063 .30902 L
.86132 .30902 L
.86256 .30902 L
.86535 .30902 L
.86777 .30902 L
.87041 .30902 L
.87569 .30902 L
.88133 .30902 L
.89148 .30902 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32045 L
.10458 .33271 L
.14415 .34381 L
.18221 .35393 L
.22272 .36392 L
.26171 .37261 L
.30316 .38069 L
.34309 .38722 L
.3815 .39222 L
.40095 .39425 L
.42237 .39607 L
.44268 .3974 L
.45178 .39787 L
.46172 .39829 L
.4671 .39848 L
.4721 .39863 L
.47727 .39875 L
.48196 .39885 L
.48658 .39892 L
.4887 .39894 L
.49093 .39897 L
.49332 .39898 L
.49438 .39899 L
.49552 .399 L
.49675 .399 L
.49789 .399 L
.49859 .39901 L
.49925 .39901 L
.50049 .39901 L
.50163 .39901 L
.50286 .399 L
.50401 .399 L
.50508 .39899 L
.50754 .39898 L
.51014 .39896 L
.51268 .39893 L
.51504 .3989 L
.5204 .3988 L
.5293 .39859 L
.53882 .39827 L
.54906 .39783 L
.56016 .39724 L
.58032 .39587 L
.62123 .39191 L
.66064 .38667 L
.69852 .38039 L
.73886 .37249 L
.77769 .36382 L
.81897 .35362 L
Mistroke
.85873 .34302 L
.89697 .33227 L
.93767 .32042 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30958 L
.10458 .31015 L
.14415 .3106 L
.18221 .31094 L
.20178 .31107 L
.21267 .31112 L
.22272 .31117 L
.23293 .3112 L
.23832 .31121 L
.24402 .31122 L
.24641 .31123 L
.24897 .31123 L
.25119 .31123 L
.25361 .31124 L
.25507 .31124 L
.25643 .31124 L
.25773 .31124 L
.2584 .31124 L
.25912 .31124 L
.25983 .31124 L
.26048 .31124 L
.26176 .31124 L
.26293 .31124 L
.26416 .31124 L
.26538 .31124 L
.26607 .31124 L
.26671 .31124 L
.26912 .31124 L
.27131 .31124 L
.27364 .31123 L
.27847 .31123 L
.2838 .31122 L
.29326 .31119 L
.30213 .31116 L
.32232 .31107 L
.34082 .31094 L
.38045 .31059 L
.41855 .31015 L
.45912 .30961 L
.49816 .30904 L
.53966 .30844 L
.57964 .3079 L
.61811 .30746 L
.63759 .30727 L
.65902 .30709 L
.67938 .30696 L
.69843 .30687 L
.70884 .30684 L
.71396 .30682 L
Mistroke
.71872 .30681 L
.72301 .30681 L
.72758 .3068 L
.7302 .3068 L
.73148 .3068 L
.73266 .3068 L
.73371 .3068 L
.73487 .3068 L
.73603 .30679 L
.73725 .30679 L
.73856 .30679 L
.73977 .30679 L
.7404 .30679 L
.7411 .3068 L
.74251 .3068 L
.74375 .3068 L
.74508 .3068 L
.74748 .3068 L
.74985 .3068 L
.75235 .3068 L
.7568 .30681 L
.76198 .30682 L
.7668 .30683 L
.77773 .30687 L
.78828 .30692 L
.79823 .30697 L
.81683 .30709 L
.85534 .30743 L
.89632 .3079 L
.93577 .30843 L
.97371 .30898 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.14918 .30902 L
.15465 .30902 L
.15946 .30902 L
.16457 .30902 L
.16917 .30902 L
.17178 .30902 L
.17423 .30902 L
.17538 .30902 L
.17647 .30902 L
.17746 .30902 L
.17852 .30902 L
.17967 .30902 L
.18073 .30902 L
.182 .30902 L
.18314 .30902 L
.18435 .30902 L
.18547 .30902 L
.1867 .30902 L
.18802 .30902 L
.19071 .30902 L
.19317 .30902 L
.1979 .30902 L
.20239 .30902 L
.21236 .30902 L
.22321 .30902 L
.24299 .30902 L
.26399 .30902 L
.30174 .30902 L
.34195 .30902 L
.38063 .30902 L
.40028 .30902 L
.42177 .30902 L
.44253 .30902 L
.4614 .30902 L
.47149 .30902 L
.47611 .30902 L
.48101 .30902 L
.4835 .30902 L
.48624 .30902 L
.48876 .30902 L
.49106 .30902 L
.49378 .30902 L
.49527 .30902 L
.49596 .30902 L
Mistroke
.49669 .30902 L
.498 .30902 L
.49921 .30902 L
.49996 .30902 L
.50065 .30902 L
.50196 .30902 L
.50313 .30902 L
.50438 .30902 L
.50556 .30902 L
.50663 .30902 L
.50926 .30902 L
.51175 .30902 L
.5167 .30902 L
.52208 .30902 L
.53169 .30902 L
.54056 .30902 L
.55926 .30902 L
.57988 .30902 L
.62014 .30902 L
.65888 .30902 L
.70007 .30902 L
.72063 .30902 L
.73974 .30902 L
.75939 .30902 L
.77791 .30902 L
.78775 .30902 L
.79293 .30902 L
.7984 .30902 L
.80302 .30902 L
.80546 .30902 L
.80809 .30902 L
.8105 .30902 L
.8127 .30902 L
.81375 .30902 L
.81491 .30902 L
.81599 .30902 L
.817 .30902 L
.81818 .30902 L
.81941 .30902 L
.82047 .30902 L
.82163 .30902 L
.82287 .30902 L
.82421 .30902 L
.82661 .30902 L
.82905 .30902 L
.83134 .30902 L
.83564 .30902 L
.84078 .30902 L
.84552 .30902 L
.85624 .30902 L
Mistroke
.87498 .30902 L
.89561 .30902 L
.93591 .30902 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30902 L
.35784 .30902 L
.36253 .30902 L
.36724 .30902 L
.36972 .30902 L
.37235 .30902 L
.37463 .30902 L
.37573 .30902 L
.37677 .30902 L
.37799 .30902 L
.37911 .30902 L
Mistroke
.38031 .30902 L
.38162 .30902 L
.38227 .30902 L
.38296 .30902 L
.38419 .30902 L
.38551 .30902 L
.38695 .30902 L
.38955 .30902 L
.39197 .30902 L
.39649 .30902 L
.40134 .30902 L
.40698 .30902 L
.41232 .30902 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30902 L
.83155 .30902 L
.8367 .30902 L
.84136 .30902 L
.84361 .30902 L
.84604 .30902 L
.84835 .30902 L
.85045 .30902 L
.85159 .30902 L
.85283 .30902 L
.85414 .30902 L
.85538 .30902 L
.85653 .30902 L
.85776 .30902 L
.85881 .30902 L
.85997 .30902 L
.86063 .30902 L
.86132 .30902 L
.86256 .30902 L
.86535 .30902 L
.86777 .30902 L
.87041 .30902 L
.87569 .30902 L
.88133 .30902 L
.89148 .30902 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31913 L
.10458 .32996 L
.14415 .33977 L
.18221 .34871 L
.22272 .35754 L
.26171 .36523 L
.30316 .37237 L
.34309 .37814 L
.3815 .38256 L
.40095 .38435 L
.42237 .38597 L
.44268 .38714 L
.45178 .38756 L
.46172 .38793 L
.4671 .38809 L
.4721 .38823 L
.47727 .38834 L
.48196 .38842 L
.48658 .38848 L
.4887 .38851 L
.49093 .38853 L
.49332 .38854 L
.49438 .38855 L
.49552 .38855 L
.49675 .38856 L
.49789 .38856 L
.49859 .38856 L
.49925 .38856 L
.50049 .38856 L
.50163 .38856 L
.50286 .38856 L
.50401 .38856 L
.50508 .38855 L
.50754 .38854 L
.51014 .38852 L
.51268 .38849 L
.51504 .38846 L
.5204 .38838 L
.5293 .38819 L
.53882 .38791 L
.54906 .38752 L
.56016 .387 L
.58032 .38579 L
.62123 .38229 L
.66064 .37765 L
.69852 .37211 L
.73886 .36512 L
.77769 .35746 L
.81897 .34845 L
Mistroke
.85873 .33907 L
.89697 .32957 L
.93767 .3191 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30936 L
.10458 .30971 L
.14415 .30998 L
.18221 .31019 L
.20178 .31027 L
.21267 .3103 L
.22272 .31033 L
.23293 .31035 L
.23832 .31036 L
.24402 .31036 L
.24641 .31037 L
.24897 .31037 L
.25119 .31037 L
.25361 .31037 L
.25507 .31037 L
.25643 .31037 L
.25773 .31037 L
.2584 .31037 L
.25912 .31037 L
.25983 .31037 L
.26048 .31037 L
.26176 .31037 L
.26293 .31037 L
.26416 .31037 L
.26538 .31037 L
.26607 .31037 L
.26671 .31037 L
.26912 .31037 L
.27131 .31037 L
.27364 .31037 L
.27847 .31037 L
.2838 .31036 L
.29326 .31034 L
.30213 .31033 L
.32232 .31027 L
.34082 .31019 L
.38045 .30998 L
.41855 .30971 L
.45912 .30938 L
.49816 .30903 L
.53966 .30867 L
.57964 .30834 L
.61811 .30806 L
.63759 .30795 L
.65902 .30784 L
.67938 .30776 L
.69843 .30771 L
.70884 .30769 L
.71396 .30768 L
Mistroke
.71872 .30767 L
.72301 .30767 L
.72758 .30766 L
.7302 .30766 L
.73148 .30766 L
.73266 .30766 L
.73371 .30766 L
.73487 .30766 L
.73603 .30766 L
.73725 .30766 L
.73856 .30766 L
.73977 .30766 L
.7404 .30766 L
.7411 .30766 L
.74251 .30766 L
.74375 .30766 L
.74508 .30766 L
.74748 .30766 L
.74985 .30766 L
.75235 .30767 L
.7568 .30767 L
.76198 .30768 L
.7668 .30768 L
.77773 .30771 L
.78828 .30773 L
.79823 .30777 L
.81683 .30784 L
.85534 .30805 L
.89632 .30833 L
.93577 .30866 L
.97371 .30899 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.14918 .30902 L
.15465 .30902 L
.15946 .30902 L
.16457 .30902 L
.16917 .30902 L
.17178 .30902 L
.17423 .30902 L
.17538 .30902 L
.17647 .30902 L
.17746 .30902 L
.17852 .30902 L
.17967 .30902 L
.18073 .30902 L
.182 .30902 L
.18314 .30902 L
.18435 .30902 L
.18547 .30902 L
.1867 .30902 L
.18802 .30902 L
.19071 .30902 L
.19317 .30902 L
.1979 .30902 L
.20239 .30902 L
.21236 .30902 L
.22321 .30902 L
.24299 .30902 L
.26399 .30902 L
.30174 .30902 L
.34195 .30902 L
.38063 .30902 L
.40028 .30902 L
.42177 .30902 L
.44253 .30902 L
.4614 .30902 L
.47149 .30902 L
.47611 .30902 L
.48101 .30902 L
.4835 .30902 L
.48624 .30902 L
.48876 .30902 L
.49106 .30902 L
.49378 .30902 L
.49527 .30902 L
.49596 .30902 L
Mistroke
.49669 .30902 L
.498 .30902 L
.49921 .30902 L
.49996 .30902 L
.50065 .30902 L
.50196 .30902 L
.50313 .30902 L
.50438 .30902 L
.50556 .30902 L
.50663 .30902 L
.50926 .30902 L
.51175 .30902 L
.5167 .30902 L
.52208 .30902 L
.53169 .30902 L
.54056 .30902 L
.55926 .30902 L
.57988 .30902 L
.62014 .30902 L
.65888 .30902 L
.70007 .30902 L
.72063 .30902 L
.73974 .30902 L
.75939 .30902 L
.77791 .30902 L
.78775 .30902 L
.79293 .30902 L
.7984 .30902 L
.80302 .30902 L
.80546 .30902 L
.80809 .30902 L
.8105 .30902 L
.8127 .30902 L
.81375 .30902 L
.81491 .30902 L
.81599 .30902 L
.817 .30902 L
.81818 .30902 L
.81941 .30902 L
.82047 .30902 L
.82163 .30902 L
.82287 .30902 L
.82421 .30902 L
.82661 .30902 L
.82905 .30902 L
.83134 .30902 L
.83564 .30902 L
.84078 .30902 L
.84552 .30902 L
.85624 .30902 L
Mistroke
.87498 .30902 L
.89561 .30902 L
.93591 .30902 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30902 L
.35784 .30902 L
.36253 .30902 L
.36724 .30902 L
.36972 .30902 L
.37235 .30902 L
.37463 .30902 L
.37573 .30902 L
.37677 .30902 L
.37799 .30902 L
.37911 .30902 L
Mistroke
.38031 .30902 L
.38162 .30902 L
.38227 .30902 L
.38296 .30902 L
.38419 .30902 L
.38551 .30902 L
.38695 .30902 L
.38955 .30902 L
.39197 .30902 L
.39649 .30902 L
.40134 .30902 L
.40698 .30902 L
.41232 .30902 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30902 L
.83155 .30902 L
.8367 .30902 L
.84136 .30902 L
.84361 .30902 L
.84604 .30902 L
.84835 .30902 L
.85045 .30902 L
.85159 .30902 L
.85283 .30902 L
.85414 .30902 L
.85538 .30902 L
.85653 .30902 L
.85776 .30902 L
.85881 .30902 L
.85997 .30902 L
.86063 .30902 L
.86132 .30902 L
.86256 .30902 L
.86535 .30902 L
.86777 .30902 L
.87041 .30902 L
.87569 .30902 L
.88133 .30902 L
.89148 .30902 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31795 L
.10458 .32753 L
.14415 .3362 L
.18221 .34411 L
.22272 .35191 L
.26171 .3587 L
.30316 .36502 L
.34309 .37012 L
.3815 .37403 L
.40095 .37561 L
.42237 .37704 L
.44268 .37808 L
.45178 .37844 L
.46172 .37877 L
.4671 .37892 L
.4721 .37903 L
.47727 .37913 L
.48196 .37921 L
.48658 .37926 L
.4887 .37928 L
.49093 .3793 L
.49332 .37931 L
.49438 .37932 L
.49552 .37932 L
.49675 .37933 L
.49789 .37933 L
.49859 .37933 L
.49925 .37933 L
.50049 .37933 L
.50163 .37933 L
.50286 .37933 L
.50401 .37932 L
.50508 .37932 L
.50754 .37931 L
.51014 .37929 L
.51268 .37927 L
.51504 .37924 L
.5204 .37917 L
.5293 .379 L
.53882 .37875 L
.54906 .37841 L
.56016 .37795 L
.58032 .37688 L
.62123 .37378 L
.66064 .36969 L
.69852 .36478 L
.73886 .35861 L
.77769 .35184 L
.81897 .34387 L
Mistroke
.85873 .33558 L
.89697 .32718 L
.93767 .31793 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30923 L
.10458 .30944 L
.14415 .30961 L
.18221 .30973 L
.20178 .30978 L
.21267 .3098 L
.22272 .30982 L
.23293 .30983 L
.23832 .30984 L
.24402 .30984 L
.24641 .30984 L
.24897 .30984 L
.25119 .30984 L
.25361 .30984 L
.25507 .30984 L
.25643 .30984 L
.25773 .30984 L
.2584 .30985 L
.25912 .30985 L
.25983 .30985 L
.26048 .30985 L
.26176 .30985 L
.26293 .30985 L
.26416 .30985 L
.26538 .30985 L
.26607 .30984 L
.26671 .30984 L
.26912 .30984 L
.27131 .30984 L
.27364 .30984 L
.27847 .30984 L
.2838 .30984 L
.29326 .30983 L
.30213 .30982 L
.32232 .30978 L
.34082 .30974 L
.38045 .3096 L
.41855 .30944 L
.45912 .30924 L
.49816 .30903 L
.53966 .3088 L
.57964 .3086 L
.61811 .30843 L
.63759 .30836 L
.65902 .3083 L
.67938 .30825 L
.69843 .30822 L
.70884 .3082 L
.71396 .3082 L
Mistroke
.71872 .3082 L
.72301 .30819 L
.72758 .30819 L
.7302 .30819 L
.73148 .30819 L
.73266 .30819 L
.73371 .30819 L
.73487 .30819 L
.73603 .30819 L
.73725 .30819 L
.73856 .30819 L
.73977 .30819 L
.7404 .30819 L
.7411 .30819 L
.74251 .30819 L
.74375 .30819 L
.74508 .30819 L
.74748 .30819 L
.74985 .30819 L
.75235 .30819 L
.7568 .30819 L
.76198 .3082 L
.7668 .3082 L
.77773 .30822 L
.78828 .30823 L
.79823 .30825 L
.81683 .3083 L
.85534 .30842 L
.89632 .3086 L
.93577 .3088 L
.97371 .309 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.14918 .30902 L
.15465 .30902 L
.15946 .30902 L
.16457 .30902 L
.16917 .30902 L
.17178 .30902 L
.17423 .30902 L
.17538 .30902 L
.17647 .30902 L
.17746 .30902 L
.17852 .30902 L
.17967 .30902 L
.18073 .30902 L
.182 .30902 L
.18314 .30902 L
.18435 .30902 L
.18547 .30902 L
.1867 .30902 L
.18802 .30902 L
.19071 .30902 L
.19317 .30902 L
.1979 .30902 L
.20239 .30902 L
.21236 .30902 L
.22321 .30902 L
.24299 .30902 L
.26399 .30902 L
.30174 .30902 L
.34195 .30902 L
.38063 .30902 L
.40028 .30902 L
.42177 .30902 L
.44253 .30902 L
.4614 .30902 L
.47149 .30902 L
.47611 .30902 L
.48101 .30902 L
.4835 .30902 L
.48624 .30902 L
.48876 .30902 L
.49106 .30902 L
.49378 .30902 L
.49527 .30902 L
.49596 .30902 L
Mistroke
.49669 .30902 L
.498 .30902 L
.49921 .30902 L
.49996 .30902 L
.50065 .30902 L
.50196 .30902 L
.50313 .30902 L
.50438 .30902 L
.50556 .30902 L
.50663 .30902 L
.50926 .30902 L
.51175 .30902 L
.5167 .30902 L
.52208 .30902 L
.53169 .30902 L
.54056 .30902 L
.55926 .30902 L
.57988 .30902 L
.62014 .30902 L
.65888 .30902 L
.70007 .30902 L
.72063 .30902 L
.73974 .30902 L
.75939 .30902 L
.77791 .30902 L
.78775 .30902 L
.79293 .30902 L
.7984 .30902 L
.80302 .30902 L
.80546 .30902 L
.80809 .30902 L
.8105 .30902 L
.8127 .30902 L
.81375 .30902 L
.81491 .30902 L
.81599 .30902 L
.817 .30902 L
.81818 .30902 L
.81941 .30902 L
.82047 .30902 L
.82163 .30902 L
.82287 .30902 L
.82421 .30902 L
.82661 .30902 L
.82905 .30902 L
.83134 .30902 L
.83564 .30902 L
.84078 .30902 L
.84552 .30902 L
.85624 .30902 L
Mistroke
.87498 .30902 L
.89561 .30902 L
.93591 .30902 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30902 L
.35784 .30902 L
.36253 .30902 L
.36724 .30902 L
.36972 .30902 L
.37235 .30902 L
.37463 .30902 L
.37573 .30902 L
.37677 .30902 L
.37799 .30902 L
.37911 .30902 L
Mistroke
.38031 .30902 L
.38162 .30902 L
.38227 .30902 L
.38296 .30902 L
.38419 .30902 L
.38551 .30902 L
.38695 .30902 L
.38955 .30902 L
.39197 .30902 L
.39649 .30902 L
.40134 .30902 L
.40698 .30902 L
.41232 .30902 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30902 L
.83155 .30902 L
.8367 .30902 L
.84136 .30902 L
.84361 .30902 L
.84604 .30902 L
.84835 .30902 L
.85045 .30902 L
.85159 .30902 L
.85283 .30902 L
.85414 .30902 L
.85538 .30902 L
.85653 .30902 L
.85776 .30902 L
.85881 .30902 L
.85997 .30902 L
.86063 .30902 L
.86132 .30902 L
.86256 .30902 L
.86535 .30902 L
.86777 .30902 L
.87041 .30902 L
.87569 .30902 L
.88133 .30902 L
.89148 .30902 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31692 L
.10458 .32538 L
.14415 .33305 L
.18221 .34003 L
.22272 .34693 L
.26171 .35294 L
.30316 .35852 L
.34309 .36303 L
.3815 .36648 L
.40095 .36788 L
.42237 .36914 L
.44268 .37006 L
.45178 .37038 L
.46172 .37067 L
.4671 .3708 L
.4721 .37091 L
.47727 .37099 L
.48196 .37106 L
.48658 .37111 L
.4887 .37113 L
.49093 .37114 L
.49332 .37115 L
.49438 .37116 L
.49552 .37116 L
.49675 .37117 L
.49789 .37117 L
.49859 .37117 L
.49925 .37117 L
.50049 .37117 L
.50163 .37117 L
.50286 .37117 L
.50401 .37116 L
.50508 .37116 L
.50754 .37115 L
.51014 .37113 L
.51268 .37111 L
.51504 .37109 L
.5204 .37103 L
.5293 .37088 L
.53882 .37066 L
.54906 .37036 L
.56016 .36995 L
.58032 .369 L
.62123 .36627 L
.66064 .36265 L
.69852 .35831 L
.73886 .35285 L
.77769 .34687 L
.81897 .33983 L
Mistroke
.85873 .3325 L
.89697 .32507 L
.93767 .31689 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30914 L
.10458 .30927 L
.14415 .30938 L
.18221 .30945 L
.20178 .30948 L
.21267 .3095 L
.22272 .30951 L
.23293 .30951 L
.23832 .30952 L
.24402 .30952 L
.24641 .30952 L
.24897 .30952 L
.25119 .30952 L
.25361 .30952 L
.25507 .30952 L
.25643 .30952 L
.25773 .30952 L
.2584 .30952 L
.25912 .30952 L
.25983 .30952 L
.26048 .30952 L
.26176 .30952 L
.26293 .30952 L
.26416 .30952 L
.26538 .30952 L
.26607 .30952 L
.26671 .30952 L
.26912 .30952 L
.27131 .30952 L
.27364 .30952 L
.27847 .30952 L
.2838 .30952 L
.29326 .30951 L
.30213 .3095 L
.32232 .30948 L
.34082 .30946 L
.38045 .30938 L
.41855 .30928 L
.45912 .30915 L
.49816 .30902 L
.53966 .30889 L
.57964 .30876 L
.61811 .30866 L
.63759 .30862 L
.65902 .30858 L
.67938 .30855 L
.69843 .30853 L
.70884 .30852 L
.71396 .30852 L
Mistroke
.71872 .30852 L
.72301 .30851 L
.72758 .30851 L
.7302 .30851 L
.73148 .30851 L
.73266 .30851 L
.73371 .30851 L
.73487 .30851 L
.73603 .30851 L
.73725 .30851 L
.73856 .30851 L
.73977 .30851 L
.7404 .30851 L
.7411 .30851 L
.74251 .30851 L
.74375 .30851 L
.74508 .30851 L
.74748 .30851 L
.74985 .30851 L
.75235 .30851 L
.7568 .30852 L
.76198 .30852 L
.7668 .30852 L
.77773 .30853 L
.78828 .30854 L
.79823 .30855 L
.81683 .30858 L
.85534 .30866 L
.89632 .30876 L
.93577 .30888 L
.97371 .30901 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.14918 .30902 L
.15465 .30902 L
.15946 .30902 L
.16457 .30902 L
.16917 .30902 L
.17178 .30902 L
.17423 .30902 L
.17538 .30902 L
.17647 .30902 L
.17746 .30902 L
.17852 .30902 L
.17967 .30902 L
.18073 .30902 L
.182 .30902 L
.18314 .30902 L
.18435 .30902 L
.18547 .30902 L
.1867 .30902 L
.18802 .30902 L
.19071 .30902 L
.19317 .30902 L
.1979 .30902 L
.20239 .30902 L
.21236 .30902 L
.22321 .30902 L
.24299 .30902 L
.26399 .30902 L
.30174 .30902 L
.34195 .30902 L
.38063 .30902 L
.40028 .30902 L
.42177 .30902 L
.44253 .30902 L
.4614 .30902 L
.47149 .30902 L
.47611 .30902 L
.48101 .30902 L
.4835 .30902 L
.48624 .30902 L
.48876 .30902 L
.49106 .30902 L
.49378 .30902 L
.49527 .30902 L
.49596 .30902 L
Mistroke
.49669 .30902 L
.498 .30902 L
.49921 .30902 L
.49996 .30902 L
.50065 .30902 L
.50196 .30902 L
.50313 .30902 L
.50438 .30902 L
.50556 .30902 L
.50663 .30902 L
.50926 .30902 L
.51175 .30902 L
.5167 .30902 L
.52208 .30902 L
.53169 .30902 L
.54056 .30902 L
.55926 .30902 L
.57988 .30902 L
.62014 .30902 L
.65888 .30902 L
.70007 .30902 L
.72063 .30902 L
.73974 .30902 L
.75939 .30902 L
.77791 .30902 L
.78775 .30902 L
.79293 .30902 L
.7984 .30902 L
.80302 .30902 L
.80546 .30902 L
.80809 .30902 L
.8105 .30902 L
.8127 .30902 L
.81375 .30902 L
.81491 .30902 L
.81599 .30902 L
.817 .30902 L
.81818 .30902 L
.81941 .30902 L
.82047 .30902 L
.82163 .30902 L
.82287 .30902 L
.82421 .30902 L
.82661 .30902 L
.82905 .30902 L
.83134 .30902 L
.83564 .30902 L
.84078 .30902 L
.84552 .30902 L
.85624 .30902 L
Mistroke
.87498 .30902 L
.89561 .30902 L
.93591 .30902 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30902 L
.35784 .30902 L
.36253 .30902 L
.36724 .30902 L
.36972 .30902 L
.37235 .30902 L
.37463 .30902 L
.37573 .30902 L
.37677 .30902 L
.37799 .30902 L
.37911 .30902 L
Mistroke
.38031 .30902 L
.38162 .30902 L
.38227 .30902 L
.38296 .30902 L
.38419 .30902 L
.38551 .30902 L
.38695 .30902 L
.38955 .30902 L
.39197 .30902 L
.39649 .30902 L
.40134 .30902 L
.40698 .30902 L
.41232 .30902 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30902 L
.83155 .30902 L
.8367 .30902 L
.84136 .30902 L
.84361 .30902 L
.84604 .30902 L
.84835 .30902 L
.85045 .30902 L
.85159 .30902 L
.85283 .30902 L
.85414 .30902 L
.85538 .30902 L
.85653 .30902 L
.85776 .30902 L
.85881 .30902 L
.85997 .30902 L
.86063 .30902 L
.86132 .30902 L
.86256 .30902 L
.86535 .30902 L
.86777 .30902 L
.87041 .30902 L
.87569 .30902 L
.88133 .30902 L
.89148 .30902 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .316 L
.10458 .32348 L
.14415 .33026 L
.18221 .33643 L
.22272 .34253 L
.26171 .34784 L
.30316 .35278 L
.34309 .35676 L
.3815 .35981 L
.40095 .36105 L
.42237 .36216 L
.44268 .36298 L
.45178 .36326 L
.46172 .36352 L
.4671 .36363 L
.4721 .36372 L
.47727 .3638 L
.48196 .36386 L
.48658 .3639 L
.4887 .36392 L
.49093 .36393 L
.49332 .36394 L
.49438 .36395 L
.49552 .36395 L
.49675 .36395 L
.49789 .36395 L
.49859 .36395 L
.49925 .36396 L
.50049 .36396 L
.50163 .36395 L
.50286 .36395 L
.50401 .36395 L
.50508 .36395 L
.50754 .36394 L
.51014 .36392 L
.51268 .36391 L
.51504 .36389 L
.5204 .36383 L
.5293 .3637 L
.53882 .36351 L
.54906 .36324 L
.56016 .36288 L
.58032 .36204 L
.62123 .35962 L
.66064 .35642 L
.69852 .35259 L
.73886 .34777 L
.77769 .34247 L
.81897 .33625 L
Mistroke
.85873 .32978 L
.89697 .32321 L
.93767 .31598 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30909 L
.10458 .30917 L
.14415 .30924 L
.18221 .30928 L
.20178 .3093 L
.21267 .30931 L
.22272 .30932 L
.23293 .30932 L
.23832 .30932 L
.24402 .30932 L
.24641 .30932 L
.24897 .30932 L
.25119 .30932 L
.25361 .30933 L
.25507 .30933 L
.25643 .30933 L
.25773 .30933 L
.2584 .30933 L
.25912 .30933 L
.25983 .30933 L
.26048 .30933 L
.26176 .30933 L
.26293 .30933 L
.26416 .30933 L
.26538 .30933 L
.26607 .30933 L
.26671 .30933 L
.26912 .30933 L
.27131 .30933 L
.27364 .30932 L
.27847 .30932 L
.2838 .30932 L
.29326 .30932 L
.30213 .30931 L
.32232 .3093 L
.34082 .30928 L
.38045 .30924 L
.41855 .30918 L
.45912 .3091 L
.49816 .30902 L
.53966 .30894 L
.57964 .30886 L
.61811 .3088 L
.63759 .30877 L
.65902 .30875 L
.67938 .30873 L
.69843 .30872 L
.70884 .30871 L
.71396 .30871 L
Mistroke
.71872 .30871 L
.72301 .30871 L
.72758 .30871 L
.7302 .30871 L
.73148 .30871 L
.73266 .30871 L
.73371 .30871 L
.73487 .30871 L
.73603 .30871 L
.73725 .30871 L
.73856 .30871 L
.73977 .30871 L
.7404 .30871 L
.7411 .30871 L
.74251 .30871 L
.74375 .30871 L
.74508 .30871 L
.74748 .30871 L
.74985 .30871 L
.75235 .30871 L
.7568 .30871 L
.76198 .30871 L
.7668 .30871 L
.77773 .30872 L
.78828 .30873 L
.79823 .30873 L
.81683 .30875 L
.85534 .3088 L
.89632 .30886 L
.93577 .30894 L
.97371 .30901 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.14918 .30902 L
.15465 .30902 L
.15946 .30902 L
.16457 .30902 L
.16917 .30902 L
.17178 .30902 L
.17423 .30902 L
.17538 .30902 L
.17647 .30902 L
.17746 .30902 L
.17852 .30902 L
.17967 .30902 L
.18073 .30902 L
.182 .30902 L
.18314 .30902 L
.18435 .30902 L
.18547 .30902 L
.1867 .30902 L
.18802 .30902 L
.19071 .30902 L
.19317 .30902 L
.1979 .30902 L
.20239 .30902 L
.21236 .30902 L
.22321 .30902 L
.24299 .30902 L
.26399 .30902 L
.30174 .30902 L
.34195 .30902 L
.38063 .30902 L
.40028 .30902 L
.42177 .30902 L
.44253 .30902 L
.4614 .30902 L
.47149 .30902 L
.47611 .30902 L
.48101 .30902 L
.4835 .30902 L
.48624 .30902 L
.48876 .30902 L
.49106 .30902 L
.49378 .30902 L
.49527 .30902 L
.49596 .30902 L
Mistroke
.49669 .30902 L
.498 .30902 L
.49921 .30902 L
.49996 .30902 L
.50065 .30902 L
.50196 .30902 L
.50313 .30902 L
.50438 .30902 L
.50556 .30902 L
.50663 .30902 L
.50926 .30902 L
.51175 .30902 L
.5167 .30902 L
.52208 .30902 L
.53169 .30902 L
.54056 .30902 L
.55926 .30902 L
.57988 .30902 L
.62014 .30902 L
.65888 .30902 L
.70007 .30902 L
.72063 .30902 L
.73974 .30902 L
.75939 .30902 L
.77791 .30902 L
.78775 .30902 L
.79293 .30902 L
.7984 .30902 L
.80302 .30902 L
.80546 .30902 L
.80809 .30902 L
.8105 .30902 L
.8127 .30902 L
.81375 .30902 L
.81491 .30902 L
.81599 .30902 L
.817 .30902 L
.81818 .30902 L
.81941 .30902 L
.82047 .30902 L
.82163 .30902 L
.82287 .30902 L
.82421 .30902 L
.82661 .30902 L
.82905 .30902 L
.83134 .30902 L
.83564 .30902 L
.84078 .30902 L
.84552 .30902 L
.85624 .30902 L
Mistroke
.87498 .30902 L
.89561 .30902 L
.93591 .30902 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30902 L
.35784 .30902 L
.36253 .30902 L
.36724 .30902 L
.36972 .30902 L
.37235 .30902 L
.37463 .30902 L
.37573 .30902 L
.37677 .30902 L
.37799 .30902 L
.37911 .30902 L
Mistroke
.38031 .30902 L
.38162 .30902 L
.38227 .30902 L
.38296 .30902 L
.38419 .30902 L
.38551 .30902 L
.38695 .30902 L
.38955 .30902 L
.39197 .30902 L
.39649 .30902 L
.40134 .30902 L
.40698 .30902 L
.41232 .30902 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30902 L
.83155 .30902 L
.8367 .30902 L
.84136 .30902 L
.84361 .30902 L
.84604 .30902 L
.84835 .30902 L
.85045 .30902 L
.85159 .30902 L
.85283 .30902 L
.85414 .30902 L
.85538 .30902 L
.85653 .30902 L
.85776 .30902 L
.85881 .30902 L
.85997 .30902 L
.86063 .30902 L
.86132 .30902 L
.86256 .30902 L
.86535 .30902 L
.86777 .30902 L
.87041 .30902 L
.87569 .30902 L
.88133 .30902 L
.89148 .30902 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31519 L
.10458 .3218 L
.14415 .32779 L
.18221 .33325 L
.22272 .33864 L
.26171 .34333 L
.30316 .3477 L
.34309 .35122 L
.3815 .35392 L
.40095 .35501 L
.42237 .356 L
.44268 .35671 L
.45178 .35697 L
.46172 .35719 L
.4671 .35729 L
.4721 .35737 L
.47727 .35744 L
.48196 .35749 L
.48658 .35753 L
.4887 .35755 L
.49093 .35756 L
.49332 .35757 L
.49438 .35757 L
.49552 .35757 L
.49675 .35758 L
.49789 .35758 L
.49859 .35758 L
.49925 .35758 L
.50049 .35758 L
.50163 .35758 L
.50286 .35758 L
.50401 .35757 L
.50508 .35757 L
.50754 .35756 L
.51014 .35755 L
.51268 .35754 L
.51504 .35752 L
.5204 .35747 L
.5293 .35735 L
.53882 .35718 L
.54906 .35694 L
.56016 .35663 L
.58032 .35588 L
.62123 .35375 L
.66064 .35092 L
.69852 .34753 L
.73886 .34327 L
.77769 .33859 L
.81897 .33309 L
Mistroke
.85873 .32737 L
.89697 .32156 L
.93767 .31517 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30906 L
.10458 .30911 L
.14415 .30915 L
.18221 .30918 L
.20178 .30919 L
.21267 .3092 L
.22272 .3092 L
.23293 .3092 L
.23832 .3092 L
.24402 .3092 L
.24641 .3092 L
.24897 .3092 L
.25119 .3092 L
.25361 .30921 L
.25507 .30921 L
.25643 .30921 L
.25773 .30921 L
.2584 .30921 L
.25912 .30921 L
.25983 .30921 L
.26048 .30921 L
.26176 .30921 L
.26293 .30921 L
.26416 .30921 L
.26538 .30921 L
.26607 .30921 L
.26671 .30921 L
.26912 .30921 L
.27131 .30921 L
.27364 .3092 L
.27847 .3092 L
.2838 .3092 L
.29326 .3092 L
.30213 .3092 L
.32232 .30919 L
.34082 .30918 L
.38045 .30915 L
.41855 .30911 L
.45912 .30907 L
.49816 .30902 L
.53966 .30897 L
.57964 .30892 L
.61811 .30888 L
.63759 .30887 L
.65902 .30885 L
.67938 .30884 L
.69843 .30883 L
.70884 .30883 L
.71396 .30883 L
Mistroke
.71872 .30883 L
.72301 .30883 L
.72758 .30883 L
.7302 .30883 L
.73148 .30883 L
.73266 .30883 L
.73371 .30883 L
.73487 .30883 L
.73603 .30883 L
.73725 .30883 L
.73856 .30883 L
.73977 .30883 L
.7404 .30883 L
.7411 .30883 L
.74251 .30883 L
.74375 .30883 L
.74508 .30883 L
.74748 .30883 L
.74985 .30883 L
.75235 .30883 L
.7568 .30883 L
.76198 .30883 L
.7668 .30883 L
.77773 .30883 L
.78828 .30884 L
.79823 .30884 L
.81683 .30885 L
.85534 .30888 L
.89632 .30892 L
.93577 .30897 L
.97371 .30901 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.14918 .30902 L
.15465 .30902 L
.15946 .30902 L
.16457 .30902 L
.16917 .30902 L
.17178 .30902 L
.17423 .30902 L
.17538 .30902 L
.17647 .30902 L
.17746 .30902 L
.17852 .30902 L
.17967 .30902 L
.18073 .30902 L
.182 .30902 L
.18314 .30902 L
.18435 .30902 L
.18547 .30902 L
.1867 .30902 L
.18802 .30902 L
.19071 .30902 L
.19317 .30902 L
.1979 .30902 L
.20239 .30902 L
.21236 .30902 L
.22321 .30902 L
.24299 .30902 L
.26399 .30902 L
.30174 .30902 L
.34195 .30902 L
.38063 .30902 L
.40028 .30902 L
.42177 .30902 L
.44253 .30902 L
.4614 .30902 L
.47149 .30902 L
.47611 .30902 L
.48101 .30902 L
.4835 .30902 L
.48624 .30902 L
.48876 .30902 L
.49106 .30902 L
.49378 .30902 L
.49527 .30902 L
.49596 .30902 L
Mistroke
.49669 .30902 L
.498 .30902 L
.49921 .30902 L
.49996 .30902 L
.50065 .30902 L
.50196 .30902 L
.50313 .30902 L
.50438 .30902 L
.50556 .30902 L
.50663 .30902 L
.50926 .30902 L
.51175 .30902 L
.5167 .30902 L
.52208 .30902 L
.53169 .30902 L
.54056 .30902 L
.55926 .30902 L
.57988 .30902 L
.62014 .30902 L
.65888 .30902 L
.70007 .30902 L
.72063 .30902 L
.73974 .30902 L
.75939 .30902 L
.77791 .30902 L
.78775 .30902 L
.79293 .30902 L
.7984 .30902 L
.80302 .30902 L
.80546 .30902 L
.80809 .30902 L
.8105 .30902 L
.8127 .30902 L
.81375 .30902 L
.81491 .30902 L
.81599 .30902 L
.817 .30902 L
.81818 .30902 L
.81941 .30902 L
.82047 .30902 L
.82163 .30902 L
.82287 .30902 L
.82421 .30902 L
.82661 .30902 L
.82905 .30902 L
.83134 .30902 L
.83564 .30902 L
.84078 .30902 L
.84552 .30902 L
.85624 .30902 L
Mistroke
.87498 .30902 L
.89561 .30902 L
.93591 .30902 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30902 L
.35784 .30902 L
.36253 .30902 L
.36724 .30902 L
.36972 .30902 L
.37235 .30902 L
.37463 .30902 L
.37573 .30902 L
.37677 .30902 L
.37799 .30902 L
.37911 .30902 L
Mistroke
.38031 .30902 L
.38162 .30902 L
.38227 .30902 L
.38296 .30902 L
.38419 .30902 L
.38551 .30902 L
.38695 .30902 L
.38955 .30902 L
.39197 .30902 L
.39649 .30902 L
.40134 .30902 L
.40698 .30902 L
.41232 .30902 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30902 L
.83155 .30902 L
.8367 .30902 L
.84136 .30902 L
.84361 .30902 L
.84604 .30902 L
.84835 .30902 L
.85045 .30902 L
.85159 .30902 L
.85283 .30902 L
.85414 .30902 L
.85538 .30902 L
.85653 .30902 L
.85776 .30902 L
.85881 .30902 L
.85997 .30902 L
.86063 .30902 L
.86132 .30902 L
.86256 .30902 L
.86535 .30902 L
.86777 .30902 L
.87041 .30902 L
.87569 .30902 L
.88133 .30902 L
.89148 .30902 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31447 L
.10458 .32032 L
.14415 .32561 L
.18221 .33044 L
.22272 .3352 L
.26171 .33935 L
.30316 .34321 L
.34309 .34632 L
.3815 .3487 L
.40095 .34967 L
.42237 .35054 L
.44268 .35118 L
.45178 .3514 L
.46172 .3516 L
.4671 .35169 L
.4721 .35176 L
.47727 .35182 L
.48196 .35187 L
.48658 .3519 L
.4887 .35191 L
.49093 .35192 L
.49332 .35193 L
.49438 .35194 L
.49552 .35194 L
.49675 .35194 L
.49789 .35194 L
.49859 .35194 L
.49925 .35194 L
.50049 .35194 L
.50163 .35194 L
.50286 .35194 L
.50401 .35194 L
.50508 .35194 L
.50754 .35193 L
.51014 .35192 L
.51268 .35191 L
.51504 .35189 L
.5204 .35185 L
.5293 .35174 L
.53882 .35159 L
.54906 .35138 L
.56016 .3511 L
.58032 .35045 L
.62123 .34856 L
.66064 .34606 L
.69852 .34306 L
.73886 .33929 L
.77769 .33516 L
.81897 .3303 L
Mistroke
.85873 .32524 L
.89697 .32011 L
.93767 .31446 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30905 L
.10458 .30908 L
.14415 .3091 L
.18221 .30912 L
.20178 .30912 L
.21267 .30913 L
.22272 .30913 L
.23293 .30913 L
.23832 .30913 L
.24402 .30913 L
.24641 .30913 L
.24897 .30913 L
.25119 .30913 L
.25361 .30913 L
.25507 .30913 L
.25643 .30913 L
.25773 .30913 L
.2584 .30913 L
.25912 .30913 L
.25983 .30913 L
.26048 .30913 L
.26176 .30913 L
.26293 .30913 L
.26416 .30913 L
.26538 .30913 L
.26607 .30913 L
.26671 .30913 L
.26912 .30913 L
.27131 .30913 L
.27364 .30913 L
.27847 .30913 L
.2838 .30913 L
.29326 .30913 L
.30213 .30913 L
.32232 .30912 L
.34082 .30912 L
.38045 .3091 L
.41855 .30908 L
.45912 .30905 L
.49816 .30902 L
.53966 .30899 L
.57964 .30896 L
.61811 .30894 L
.63759 .30893 L
.65902 .30892 L
.67938 .30891 L
.69843 .30891 L
.70884 .3089 L
.71396 .3089 L
Mistroke
.71872 .3089 L
.72301 .3089 L
.72758 .3089 L
.7302 .3089 L
.73148 .3089 L
.73266 .3089 L
.73371 .3089 L
.73487 .3089 L
.73603 .3089 L
.73725 .3089 L
.73856 .3089 L
.73977 .3089 L
.7404 .3089 L
.7411 .3089 L
.74251 .3089 L
.74375 .3089 L
.74508 .3089 L
.74748 .3089 L
.74985 .3089 L
.75235 .3089 L
.7568 .3089 L
.76198 .3089 L
.7668 .3089 L
.77773 .30891 L
.78828 .30891 L
.79823 .30891 L
.81683 .30892 L
.85534 .30893 L
.89632 .30896 L
.93577 .30899 L
.97371 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.14918 .30902 L
.15465 .30902 L
.15946 .30902 L
.16457 .30902 L
.16917 .30902 L
.17178 .30902 L
.17423 .30902 L
.17538 .30902 L
.17647 .30902 L
.17746 .30902 L
.17852 .30902 L
.17967 .30902 L
.18073 .30902 L
.182 .30902 L
.18314 .30902 L
.18435 .30902 L
.18547 .30902 L
.1867 .30902 L
.18802 .30902 L
.19071 .30902 L
.19317 .30902 L
.1979 .30902 L
.20239 .30902 L
.21236 .30902 L
.22321 .30902 L
.24299 .30902 L
.26399 .30902 L
.30174 .30902 L
.34195 .30902 L
.38063 .30902 L
.40028 .30902 L
.42177 .30902 L
.44253 .30902 L
.4614 .30902 L
.47149 .30902 L
.47611 .30902 L
.48101 .30902 L
.4835 .30902 L
.48624 .30902 L
.48876 .30902 L
.49106 .30902 L
.49378 .30902 L
.49527 .30902 L
.49596 .30902 L
Mistroke
.49669 .30902 L
.498 .30902 L
.49921 .30902 L
.49996 .30902 L
.50065 .30902 L
.50196 .30902 L
.50313 .30902 L
.50438 .30902 L
.50556 .30902 L
.50663 .30902 L
.50926 .30902 L
.51175 .30902 L
.5167 .30902 L
.52208 .30902 L
.53169 .30902 L
.54056 .30902 L
.55926 .30902 L
.57988 .30902 L
.62014 .30902 L
.65888 .30902 L
.70007 .30902 L
.72063 .30902 L
.73974 .30902 L
.75939 .30902 L
.77791 .30902 L
.78775 .30902 L
.79293 .30902 L
.7984 .30902 L
.80302 .30902 L
.80546 .30902 L
.80809 .30902 L
.8105 .30902 L
.8127 .30902 L
.81375 .30902 L
.81491 .30902 L
.81599 .30902 L
.817 .30902 L
.81818 .30902 L
.81941 .30902 L
.82047 .30902 L
.82163 .30902 L
.82287 .30902 L
.82421 .30902 L
.82661 .30902 L
.82905 .30902 L
.83134 .30902 L
.83564 .30902 L
.84078 .30902 L
.84552 .30902 L
.85624 .30902 L
Mistroke
.87498 .30902 L
.89561 .30902 L
.93591 .30902 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30902 L
.35784 .30902 L
.36253 .30902 L
.36724 .30902 L
.36972 .30902 L
.37235 .30902 L
.37463 .30902 L
.37573 .30902 L
.37677 .30902 L
.37799 .30902 L
.37911 .30902 L
Mistroke
.38031 .30902 L
.38162 .30902 L
.38227 .30902 L
.38296 .30902 L
.38419 .30902 L
.38551 .30902 L
.38695 .30902 L
.38955 .30902 L
.39197 .30902 L
.39649 .30902 L
.40134 .30902 L
.40698 .30902 L
.41232 .30902 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30902 L
.83155 .30902 L
.8367 .30902 L
.84136 .30902 L
.84361 .30902 L
.84604 .30902 L
.84835 .30902 L
.85045 .30902 L
.85159 .30902 L
.85283 .30902 L
.85414 .30902 L
.85538 .30902 L
.85653 .30902 L
.85776 .30902 L
.85881 .30902 L
.85997 .30902 L
.86063 .30902 L
.86132 .30902 L
.86256 .30902 L
.86535 .30902 L
.86777 .30902 L
.87041 .30902 L
.87569 .30902 L
.88133 .30902 L
.89148 .30902 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31384 L
.10458 .31901 L
.14415 .32369 L
.18221 .32795 L
.22272 .33216 L
.26171 .33583 L
.30316 .33924 L
.34309 .34199 L
.3815 .3441 L
.40095 .34495 L
.42237 .34572 L
.44268 .34628 L
.45178 .34648 L
.46172 .34666 L
.4671 .34674 L
.4721 .3468 L
.47727 .34685 L
.48196 .34689 L
.48658 .34692 L
.4887 .34693 L
.49093 .34694 L
.49332 .34695 L
.49438 .34695 L
.49552 .34696 L
.49675 .34696 L
.49789 .34696 L
.49859 .34696 L
.49925 .34696 L
.50049 .34696 L
.50163 .34696 L
.50286 .34696 L
.50401 .34696 L
.50508 .34696 L
.50754 .34695 L
.51014 .34694 L
.51268 .34693 L
.51504 .34691 L
.5204 .34687 L
.5293 .34678 L
.53882 .34665 L
.54906 .34646 L
.56016 .34622 L
.58032 .34564 L
.62123 .34397 L
.66064 .34176 L
.69852 .33911 L
.73886 .33578 L
.77769 .33212 L
.81897 .32783 L
Mistroke
.85873 .32335 L
.89697 .31882 L
.93767 .31383 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30903 L
.10458 .30905 L
.14415 .30907 L
.18221 .30908 L
.20178 .30908 L
.21267 .30908 L
.22272 .30908 L
.23293 .30909 L
.23832 .30909 L
.24402 .30909 L
.24641 .30909 L
.24897 .30909 L
.25119 .30909 L
.25361 .30909 L
.25507 .30909 L
.25643 .30909 L
.25773 .30909 L
.2584 .30909 L
.25912 .30909 L
.25983 .30909 L
.26048 .30909 L
.26176 .30909 L
.26293 .30909 L
.26416 .30909 L
.26538 .30909 L
.26607 .30909 L
.26671 .30909 L
.26912 .30909 L
.27131 .30909 L
.27364 .30909 L
.27847 .30909 L
.2838 .30909 L
.29326 .30909 L
.30213 .30908 L
.32232 .30908 L
.34082 .30908 L
.38045 .30907 L
.41855 .30905 L
.45912 .30904 L
.49816 .30902 L
.53966 .309 L
.57964 .30898 L
.61811 .30897 L
.63759 .30896 L
.65902 .30896 L
.67938 .30895 L
.69843 .30895 L
.70884 .30895 L
.71396 .30895 L
Mistroke
.71872 .30895 L
.72301 .30895 L
.72758 .30895 L
.7302 .30895 L
.73148 .30895 L
.73266 .30895 L
.73371 .30895 L
.73487 .30895 L
.73603 .30895 L
.73725 .30895 L
.73856 .30895 L
.73977 .30895 L
.7404 .30895 L
.7411 .30895 L
.74251 .30895 L
.74375 .30895 L
.74508 .30895 L
.74748 .30895 L
.74985 .30895 L
.75235 .30895 L
.7568 .30895 L
.76198 .30895 L
.7668 .30895 L
.77773 .30895 L
.78828 .30895 L
.79823 .30895 L
.81683 .30896 L
.85534 .30897 L
.89632 .30898 L
.93577 .309 L
.97371 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.14918 .30902 L
.15465 .30902 L
.15946 .30902 L
.16457 .30902 L
.16917 .30902 L
.17178 .30902 L
.17423 .30902 L
.17538 .30902 L
.17647 .30902 L
.17746 .30902 L
.17852 .30902 L
.17967 .30902 L
.18073 .30902 L
.182 .30902 L
.18314 .30902 L
.18435 .30902 L
.18547 .30902 L
.1867 .30902 L
.18802 .30902 L
.19071 .30902 L
.19317 .30902 L
.1979 .30902 L
.20239 .30902 L
.21236 .30902 L
.22321 .30902 L
.24299 .30902 L
.26399 .30902 L
.30174 .30902 L
.34195 .30902 L
.38063 .30902 L
.40028 .30902 L
.42177 .30902 L
.44253 .30902 L
.4614 .30902 L
.47149 .30902 L
.47611 .30902 L
.48101 .30902 L
.4835 .30902 L
.48624 .30902 L
.48876 .30902 L
.49106 .30902 L
.49378 .30902 L
.49527 .30902 L
.49596 .30902 L
Mistroke
.49669 .30902 L
.498 .30902 L
.49921 .30902 L
.49996 .30902 L
.50065 .30902 L
.50196 .30902 L
.50313 .30902 L
.50438 .30902 L
.50556 .30902 L
.50663 .30902 L
.50926 .30902 L
.51175 .30902 L
.5167 .30902 L
.52208 .30902 L
.53169 .30902 L
.54056 .30902 L
.55926 .30902 L
.57988 .30902 L
.62014 .30902 L
.65888 .30902 L
.70007 .30902 L
.72063 .30902 L
.73974 .30902 L
.75939 .30902 L
.77791 .30902 L
.78775 .30902 L
.79293 .30902 L
.7984 .30902 L
.80302 .30902 L
.80546 .30902 L
.80809 .30902 L
.8105 .30902 L
.8127 .30902 L
.81375 .30902 L
.81491 .30902 L
.81599 .30902 L
.817 .30902 L
.81818 .30902 L
.81941 .30902 L
.82047 .30902 L
.82163 .30902 L
.82287 .30902 L
.82421 .30902 L
.82661 .30902 L
.82905 .30902 L
.83134 .30902 L
.83564 .30902 L
.84078 .30902 L
.84552 .30902 L
.85624 .30902 L
Mistroke
.87498 .30902 L
.89561 .30902 L
.93591 .30902 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30902 L
.35784 .30902 L
.36253 .30902 L
.36724 .30902 L
.36972 .30902 L
.37235 .30902 L
.37463 .30902 L
.37573 .30902 L
.37677 .30902 L
.37799 .30902 L
.37911 .30902 L
Mistroke
.38031 .30902 L
.38162 .30902 L
.38227 .30902 L
.38296 .30902 L
.38419 .30902 L
.38551 .30902 L
.38695 .30902 L
.38955 .30902 L
.39197 .30902 L
.39649 .30902 L
.40134 .30902 L
.40698 .30902 L
.41232 .30902 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30902 L
.83155 .30902 L
.8367 .30902 L
.84136 .30902 L
.84361 .30902 L
.84604 .30902 L
.84835 .30902 L
.85045 .30902 L
.85159 .30902 L
.85283 .30902 L
.85414 .30902 L
.85538 .30902 L
.85653 .30902 L
.85776 .30902 L
.85881 .30902 L
.85997 .30902 L
.86063 .30902 L
.86132 .30902 L
.86256 .30902 L
.86535 .30902 L
.86777 .30902 L
.87041 .30902 L
.87569 .30902 L
.88133 .30902 L
.89148 .30902 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31328 L
.10458 .31785 L
.14415 .32198 L
.18221 .32576 L
.22272 .32948 L
.26171 .33272 L
.30316 .33573 L
.34309 .33816 L
.3815 .34003 L
.40095 .34078 L
.42237 .34146 L
.44268 .34196 L
.45178 .34213 L
.46172 .34229 L
.4671 .34236 L
.4721 .34241 L
.47727 .34246 L
.48196 .3425 L
.48658 .34252 L
.4887 .34253 L
.49093 .34254 L
.49332 .34255 L
.49438 .34255 L
.49552 .34255 L
.49675 .34255 L
.49789 .34256 L
.49859 .34256 L
.49925 .34256 L
.50049 .34256 L
.50163 .34256 L
.50286 .34256 L
.50401 .34255 L
.50508 .34255 L
.50754 .34255 L
.51014 .34254 L
.51268 .34253 L
.51504 .34252 L
.5204 .34248 L
.5293 .3424 L
.53882 .34228 L
.54906 .34212 L
.56016 .3419 L
.58032 .34139 L
.62123 .33991 L
.66064 .33796 L
.69852 .33562 L
.73886 .33267 L
.77769 .32944 L
.81897 .32564 L
Mistroke
.85873 .32169 L
.89697 .31768 L
.93767 .31327 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30903 L
.10458 .30904 L
.14415 .30905 L
.18221 .30905 L
.20178 .30906 L
.21267 .30906 L
.22272 .30906 L
.23293 .30906 L
.23832 .30906 L
.24402 .30906 L
.24641 .30906 L
.24897 .30906 L
.25119 .30906 L
.25361 .30906 L
.25507 .30906 L
.25643 .30906 L
.25773 .30906 L
.2584 .30906 L
.25912 .30906 L
.25983 .30906 L
.26048 .30906 L
.26176 .30906 L
.26293 .30906 L
.26416 .30906 L
.26538 .30906 L
.26607 .30906 L
.26671 .30906 L
.26912 .30906 L
.27131 .30906 L
.27364 .30906 L
.27847 .30906 L
.2838 .30906 L
.29326 .30906 L
.30213 .30906 L
.32232 .30906 L
.34082 .30905 L
.38045 .30905 L
.41855 .30904 L
.45912 .30903 L
.49816 .30902 L
.53966 .30901 L
.57964 .309 L
.61811 .30899 L
.63759 .30898 L
.65902 .30898 L
.67938 .30898 L
.69843 .30898 L
.70884 .30897 L
.71396 .30897 L
Mistroke
.71872 .30897 L
.72301 .30897 L
.72758 .30897 L
.7302 .30897 L
.73148 .30897 L
.73266 .30897 L
.73371 .30897 L
.73487 .30897 L
.73603 .30897 L
.73725 .30897 L
.73856 .30897 L
.73977 .30897 L
.7404 .30897 L
.7411 .30897 L
.74251 .30897 L
.74375 .30897 L
.74508 .30897 L
.74748 .30897 L
.74985 .30897 L
.75235 .30897 L
.7568 .30897 L
.76198 .30897 L
.7668 .30897 L
.77773 .30898 L
.78828 .30898 L
.79823 .30898 L
.81683 .30898 L
.85534 .30899 L
.89632 .309 L
.93577 .30901 L
.97371 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.14918 .30902 L
.15465 .30902 L
.15946 .30902 L
.16457 .30902 L
.16917 .30902 L
.17178 .30902 L
.17423 .30902 L
.17538 .30902 L
.17647 .30902 L
.17746 .30902 L
.17852 .30902 L
.17967 .30902 L
.18073 .30902 L
.182 .30902 L
.18314 .30902 L
.18435 .30902 L
.18547 .30902 L
.1867 .30902 L
.18802 .30902 L
.19071 .30902 L
.19317 .30902 L
.1979 .30902 L
.20239 .30902 L
.21236 .30902 L
.22321 .30902 L
.24299 .30902 L
.26399 .30902 L
.30174 .30902 L
.34195 .30902 L
.38063 .30902 L
.40028 .30902 L
.42177 .30902 L
.44253 .30902 L
.4614 .30902 L
.47149 .30902 L
.47611 .30902 L
.48101 .30902 L
.4835 .30902 L
.48624 .30902 L
.48876 .30902 L
.49106 .30902 L
.49378 .30902 L
.49527 .30902 L
.49596 .30902 L
Mistroke
.49669 .30902 L
.498 .30902 L
.49921 .30902 L
.49996 .30902 L
.50065 .30902 L
.50196 .30902 L
.50313 .30902 L
.50438 .30902 L
.50556 .30902 L
.50663 .30902 L
.50926 .30902 L
.51175 .30902 L
.5167 .30902 L
.52208 .30902 L
.53169 .30902 L
.54056 .30902 L
.55926 .30902 L
.57988 .30902 L
.62014 .30902 L
.65888 .30902 L
.70007 .30902 L
.72063 .30902 L
.73974 .30902 L
.75939 .30902 L
.77791 .30902 L
.78775 .30902 L
.79293 .30902 L
.7984 .30902 L
.80302 .30902 L
.80546 .30902 L
.80809 .30902 L
.8105 .30902 L
.8127 .30902 L
.81375 .30902 L
.81491 .30902 L
.81599 .30902 L
.817 .30902 L
.81818 .30902 L
.81941 .30902 L
.82047 .30902 L
.82163 .30902 L
.82287 .30902 L
.82421 .30902 L
.82661 .30902 L
.82905 .30902 L
.83134 .30902 L
.83564 .30902 L
.84078 .30902 L
.84552 .30902 L
.85624 .30902 L
Mistroke
.87498 .30902 L
.89561 .30902 L
.93591 .30902 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30902 L
.35784 .30902 L
.36253 .30902 L
.36724 .30902 L
.36972 .30902 L
.37235 .30902 L
.37463 .30902 L
.37573 .30902 L
.37677 .30902 L
.37799 .30902 L
.37911 .30902 L
Mistroke
.38031 .30902 L
.38162 .30902 L
.38227 .30902 L
.38296 .30902 L
.38419 .30902 L
.38551 .30902 L
.38695 .30902 L
.38955 .30902 L
.39197 .30902 L
.39649 .30902 L
.40134 .30902 L
.40698 .30902 L
.41232 .30902 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30902 L
.83155 .30902 L
.8367 .30902 L
.84136 .30902 L
.84361 .30902 L
.84604 .30902 L
.84835 .30902 L
.85045 .30902 L
.85159 .30902 L
.85283 .30902 L
.85414 .30902 L
.85538 .30902 L
.85653 .30902 L
.85776 .30902 L
.85881 .30902 L
.85997 .30902 L
.86063 .30902 L
.86132 .30902 L
.86256 .30902 L
.86535 .30902 L
.86777 .30902 L
.87041 .30902 L
.87569 .30902 L
.88133 .30902 L
.89148 .30902 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31279 L
.10458 .31682 L
.14415 .32048 L
.18221 .32381 L
.22272 .3271 L
.26171 .32997 L
.30316 .33263 L
.34309 .33478 L
.3815 .33643 L
.40095 .3371 L
.42237 .3377 L
.44268 .33814 L
.45178 .33829 L
.46172 .33843 L
.4671 .33849 L
.4721 .33854 L
.47727 .33858 L
.48196 .33861 L
.48658 .33864 L
.4887 .33864 L
.49093 .33865 L
.49332 .33866 L
.49438 .33866 L
.49552 .33866 L
.49675 .33866 L
.49789 .33866 L
.49859 .33866 L
.49925 .33866 L
.50049 .33866 L
.50163 .33866 L
.50286 .33866 L
.50401 .33866 L
.50508 .33866 L
.50754 .33865 L
.51014 .33865 L
.51268 .33864 L
.51504 .33863 L
.5204 .3386 L
.5293 .33853 L
.53882 .33842 L
.54906 .33828 L
.56016 .33808 L
.58032 .33763 L
.62123 .33632 L
.66064 .3346 L
.69852 .33253 L
.73886 .32993 L
.77769 .32707 L
.81897 .32371 L
Mistroke
.85873 .32022 L
.89697 .31668 L
.93767 .31277 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30903 L
.14415 .30904 L
.18221 .30904 L
.20178 .30904 L
.21267 .30904 L
.22272 .30904 L
.23293 .30904 L
.23832 .30904 L
.24402 .30904 L
.24641 .30904 L
.24897 .30904 L
.25119 .30904 L
.25361 .30904 L
.25507 .30904 L
.25643 .30904 L
.25773 .30904 L
.2584 .30904 L
.25912 .30904 L
.25983 .30904 L
.26048 .30904 L
.26176 .30904 L
.26293 .30904 L
.26416 .30904 L
.26538 .30904 L
.26607 .30904 L
.26671 .30904 L
.26912 .30904 L
.27131 .30904 L
.27364 .30904 L
.27847 .30904 L
.2838 .30904 L
.29326 .30904 L
.30213 .30904 L
.32232 .30904 L
.34082 .30904 L
.38045 .30904 L
.41855 .30903 L
.45912 .30902 L
.49816 .30902 L
.53966 .30901 L
.57964 .309 L
.61811 .309 L
.63759 .309 L
.65902 .30899 L
.67938 .30899 L
.69843 .30899 L
.70884 .30899 L
.71396 .30899 L
Mistroke
.71872 .30899 L
.72301 .30899 L
.72758 .30899 L
.7302 .30899 L
.73148 .30899 L
.73266 .30899 L
.73371 .30899 L
.73487 .30899 L
.73603 .30899 L
.73725 .30899 L
.73856 .30899 L
.73977 .30899 L
.7404 .30899 L
.7411 .30899 L
.74251 .30899 L
.74375 .30899 L
.74508 .30899 L
.74748 .30899 L
.74985 .30899 L
.75235 .30899 L
.7568 .30899 L
.76198 .30899 L
.7668 .30899 L
.77773 .30899 L
.78828 .30899 L
.79823 .30899 L
.81683 .30899 L
.85534 .309 L
.89632 .309 L
.93577 .30901 L
.97371 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.14918 .30902 L
.15465 .30902 L
.15946 .30902 L
.16457 .30902 L
.16917 .30902 L
.17178 .30902 L
.17423 .30902 L
.17538 .30902 L
.17647 .30902 L
.17746 .30902 L
.17852 .30902 L
.17967 .30902 L
.18073 .30902 L
.182 .30902 L
.18314 .30902 L
.18435 .30902 L
.18547 .30902 L
.1867 .30902 L
.18802 .30902 L
.19071 .30902 L
.19317 .30902 L
.1979 .30902 L
.20239 .30902 L
.21236 .30902 L
.22321 .30902 L
.24299 .30902 L
.26399 .30902 L
.30174 .30902 L
.34195 .30902 L
.38063 .30902 L
.40028 .30902 L
.42177 .30902 L
.44253 .30902 L
.4614 .30902 L
.47149 .30902 L
.47611 .30902 L
.48101 .30902 L
.4835 .30902 L
.48624 .30902 L
.48876 .30902 L
.49106 .30902 L
.49378 .30902 L
.49527 .30902 L
.49596 .30902 L
Mistroke
.49669 .30902 L
.498 .30902 L
.49921 .30902 L
.49996 .30902 L
.50065 .30902 L
.50196 .30902 L
.50313 .30902 L
.50438 .30902 L
.50556 .30902 L
.50663 .30902 L
.50926 .30902 L
.51175 .30902 L
.5167 .30902 L
.52208 .30902 L
.53169 .30902 L
.54056 .30902 L
.55926 .30902 L
.57988 .30902 L
.62014 .30902 L
.65888 .30902 L
.70007 .30902 L
.72063 .30902 L
.73974 .30902 L
.75939 .30902 L
.77791 .30902 L
.78775 .30902 L
.79293 .30902 L
.7984 .30902 L
.80302 .30902 L
.80546 .30902 L
.80809 .30902 L
.8105 .30902 L
.8127 .30902 L
.81375 .30902 L
.81491 .30902 L
.81599 .30902 L
.817 .30902 L
.81818 .30902 L
.81941 .30902 L
.82047 .30902 L
.82163 .30902 L
.82287 .30902 L
.82421 .30902 L
.82661 .30902 L
.82905 .30902 L
.83134 .30902 L
.83564 .30902 L
.84078 .30902 L
.84552 .30902 L
.85624 .30902 L
Mistroke
.87498 .30902 L
.89561 .30902 L
.93591 .30902 L
.97471 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.12038 .30902 L
.12507 .30902 L
.12951 .30902 L
.13178 .30902 L
.13422 .30902 L
.13549 .30902 L
.13666 .30902 L
.13784 .30902 L
.13895 .30902 L
.14022 .30902 L
.1409 .30902 L
.14161 .30902 L
.1423 .30902 L
.14295 .30902 L
.14415 .30902 L
.14531 .30902 L
.14656 .30902 L
.14773 .30902 L
.14881 .30902 L
.15143 .30902 L
.15392 .30902 L
.15886 .30902 L
.16423 .30902 L
.17383 .30902 L
.1827 .30902 L
.20137 .30902 L
.22197 .30902 L
.26217 .30902 L
.30086 .30902 L
.32051 .30902 L
.3309 .30902 L
.342 .30902 L
.35275 .30902 L
.35784 .30902 L
.36253 .30902 L
.36724 .30902 L
.36972 .30902 L
.37235 .30902 L
.37463 .30902 L
.37573 .30902 L
.37677 .30902 L
.37799 .30902 L
.37911 .30902 L
Mistroke
.38031 .30902 L
.38162 .30902 L
.38227 .30902 L
.38296 .30902 L
.38419 .30902 L
.38551 .30902 L
.38695 .30902 L
.38955 .30902 L
.39197 .30902 L
.39649 .30902 L
.40134 .30902 L
.40698 .30902 L
.41232 .30902 L
.42232 .30902 L
.44227 .30902 L
.4607 .30902 L
.50002 .30902 L
.53782 .30902 L
.55884 .30902 L
.56803 .30902 L
.57808 .30902 L
.58722 .30902 L
.59696 .30902 L
.60236 .30902 L
.60726 .30902 L
.60962 .30902 L
.61086 .30902 L
.61218 .30902 L
.61333 .30902 L
.61459 .30902 L
.61574 .30902 L
.61682 .30902 L
.61808 .30902 L
.61871 .30902 L
.61941 .30902 L
.62065 .30902 L
.62181 .30902 L
.62248 .30902 L
.62318 .30902 L
.62443 .30902 L
.62578 .30902 L
.62725 .30902 L
.62973 .30902 L
.63238 .30902 L
.63715 .30902 L
.64214 .30902 L
.64686 .30902 L
.6557 .30902 L
.67568 .30902 L
.69413 .30902 L
Mistroke
.7335 .30902 L
.77136 .30902 L
.79241 .30902 L
.81166 .30902 L
.82118 .30902 L
.8262 .30902 L
.83155 .30902 L
.8367 .30902 L
.84136 .30902 L
.84361 .30902 L
.84604 .30902 L
.84835 .30902 L
.85045 .30902 L
.85159 .30902 L
.85283 .30902 L
.85414 .30902 L
.85538 .30902 L
.85653 .30902 L
.85776 .30902 L
.85881 .30902 L
.85997 .30902 L
.86063 .30902 L
.86132 .30902 L
.86256 .30902 L
.86535 .30902 L
.86777 .30902 L
.87041 .30902 L
.87569 .30902 L
.88133 .30902 L
.89148 .30902 L
.90173 .30902 L
.91284 .30902 L
.933 .30902 L
.97393 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .31235 L
.10458 .31592 L
.14415 .31915 L
.18221 .3221 L
.22272 .325 L
.26171 .32754 L
.30316 .32989 L
.34309 .33179 L
.3815 .33325 L
.40095 .33384 L
.42237 .33437 L
.44268 .33476 L
.45178 .33489 L
.46172 .33501 L
.4671 .33507 L
.4721 .33511 L
.47727 .33515 L
.48196 .33518 L
.48658 .3352 L
.4887 .3352 L
.49093 .33521 L
.49332 .33522 L
.49438 .33522 L
.49552 .33522 L
.49675 .33522 L
.49789 .33522 L
.49859 .33522 L
.49925 .33522 L
.50049 .33522 L
.50163 .33522 L
.50286 .33522 L
.50401 .33522 L
.50508 .33522 L
.50754 .33522 L
.51014 .33521 L
.51268 .3352 L
.51504 .33519 L
.5204 .33516 L
.5293 .3351 L
.53882 .33501 L
.54906 .33488 L
.56016 .33471 L
.58032 .33431 L
.62123 .33316 L
.66064 .33163 L
.69852 .3298 L
.73886 .3275 L
.77769 .32498 L
.81897 .32201 L
Mistroke
.85873 .31892 L
.89697 .31579 L
.93767 .31234 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30903 L
.14415 .30903 L
.18221 .30903 L
.20178 .30903 L
.21267 .30903 L
.22272 .30903 L
.23293 .30903 L
.23832 .30903 L
.24402 .30903 L
.24641 .30903 L
.24897 .30903 L
.25119 .30903 L
.25361 .30903 L
.25507 .30903 L
.25643 .30903 L
.25773 .30903 L
.2584 .30903 L
.25912 .30903 L
.25983 .30903 L
.26048 .30903 L
.26176 .30903 L
.26293 .30903 L
.26416 .30903 L
.26538 .30903 L
.26607 .30903 L
.26671 .30903 L
.26912 .30903 L
.27131 .30903 L
.27364 .30903 L
.27847 .30903 L
.2838 .30903 L
.29326 .30903 L
.30213 .30903 L
.32232 .30903 L
.34082 .30903 L
.38045 .30903 L
.41855 .30903 L
.45912 .30902 L
.49816 .30902 L
.53966 .30901 L
.57964 .30901 L
.61811 .30901 L
.63759 .309 L
.65902 .309 L
.67938 .309 L
.69843 .309 L
.70884 .309 L
.71396 .309 L
Mistroke
.71872 .309 L
.72301 .309 L
.72758 .309 L
.7302 .309 L
.73148 .309 L
.73266 .309 L
.73371 .309 L
.73487 .309 L
.73603 .309 L
.73725 .309 L
.73856 .309 L
.73977 .309 L
.7404 .309 L
.7411 .309 L
.74251 .309 L
.74375 .309 L
.74508 .309 L
.74748 .309 L
.74985 .309 L
.75235 .309 L
.7568 .309 L
.76198 .309 L
.7668 .309 L
.77773 .309 L
.78828 .309 L
.79823 .309 L
.81683 .309 L
.85534 .30901 L
.89632 .30901 L
.93577 .30901 L
.97371 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{540.5, 334.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:S0001XB000`400?l00000o`00003ooooooooo
ooooojGooooo003oooooooooooooYOooool00?oooooooooooonUooooo`00ooooooooooooojGooooo
003oooooooooooooYOooool00?oooooooooooonUooooo`00ooooooooooooojGooooo003ooooooooo
ooooYOooool00?oooooooooooonUooooo`00ooooooooooooojGooooo003oooooooooooooYOooool0
0?oooooooooooonUooooo`00ooooooooooooojGooooo000aooooo`Co000000?o410@ooooooooool0
oooooom;ooooo`Co000000?o410@ooooooooool0oooooolKooooo`00<oooool00ol0003ooooooooo
o`3oooooodoooooo00?o0000ooooooooool0oooooolMooooo`00:?ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool2o`000?oooooo?Oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3
o`000?oooooo5_ooool003?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
odOooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooaKooooo000cooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom7ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooolFooooo`00<oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?ooooooAoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
5_ooool003?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodOooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooaKooooo000aooooo`03oeEEEOmVIVKo
000000Oooooo0_l0003oooooodKooooo00?oEEEEofIVI_l000001_ooool2o`000?oooooo5oooool0
03_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_o
oooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo
00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo0_l0
003oooooodoooooo0_l0003ooooooaOooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool0
0ol0003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0
003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003o
ooooooooo`3ooooooaKooooo000kooooo`;o0000oooooom?ooooo`;o0000oooooolGooooo`00>ooo
ool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool0
0ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0
003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool2o`000?oo
ooooCoooool2o`000?oooooo5oooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`00
0?oooooooooo0?oooooo5_ooool001Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3oooooobcooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
oooooaKooooo000Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo;?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`3ooooooaKooooo000@ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`03ooooo`;o0000oooooolUooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`02ooooo`?o0000oooooolFooooo`006?oo
ool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo;?ooool01Ol0003ooooooooooooooooo000000ko
oooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oo
oooo5_ooool001Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo;?ooool01Ol0
003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooolFooooo`006?ooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo;?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo5_ooool001Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`;o0000ooooool]ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool2o`000?oooooo5oooool0
01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000
ooooooooool0ooooool/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
0005ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo00?o0000ooooooooool0oooooom>
ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo00?o0000ooooooooool0oooooom>oooo
o`03o`000?oooooooooo0?oooooo5_ooool003_ooooo0_l0003oooooodoooooo0_l0003ooooooaOo
oooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo
000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000k
ooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000koooo
o`;o0000oooooom?ooooo`;o0000oooooolGooooo`00>oooool00ol0003oooooooooo`3oooooodko
oooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo
00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o
0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o0000
ooooooooool0oooooolFooooo`00>oooool2o`000?ooooooCoooool2o`000?oooooo5oooool0023o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0ooooooldooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
5_ooool0023ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo=?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooolFooooo`00
6?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0ooooool/ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooaKooooo000Pooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`;o0000ooooooleoooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`?o0000oooooolF
ooooo`008?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo=?ooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo5_ooool0023ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0ooooooldooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo5_ooool0023ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ooooooldooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo5_ooool0
023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo=Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`;o0000oooooolGooooo`00>oooool0
0ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0
003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003o
ooooooooo`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool2o`000?oooooo
Coooool2o`000?oooooo5oooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oo
oooooooo0?oooooo5_ooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooo
oooo0?oooooo5_ooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo
0?oooooo5_ooool003_ooooo0_l0003oooooodoooooo0_l0003ooooooaOooooo000kooooo`03o`00
0?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oo
oooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooo
oooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`;o0000oooooom?oooo
o`;o0000oooooolGooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o0000oooooooo
ool0oooooolFooooo`006?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0ooooool/oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3ooooooaKooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0ooooool/ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool0oooooolFooooo`004?ooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool2o`00
0?oooooo9Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00_ooool3o`000?oooooo5_ooool001Sooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooobcooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3ooooooaKooooo000H
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooobcooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004oooo
o`03o`000?oooooooooo0?oooooo5_ooool001Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
obcooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3ooooooaKooooo000Hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool2o`000?oooooo;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo0_l0003ooooooaOooooo000Hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo0?oooooo;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001Oooool00ol0003oooooooooo`3ooooooaKooooo000k
ooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000koooo
o`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`03
o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`;o0000
9_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00007Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool07?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`07_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`09oooool4o`000003oa0@4?oooooooooo04gooooo0_l0000Vooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Looooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Mooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Wooooo`Co000000?o410@oooo
ooooool05Oooool003_ooooo00?o0000ooooooooool09Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q02Wooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`0Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Nooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool07Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:Oooool00ol0003ooooo
ooooo`0Gooooo`00>oooool00ol0003oooooooooo`0Uooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP0Nooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001ko
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000007_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Yooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool09Oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h07oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Noooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001gooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000:Oooool00ol0003o
ooooooooo`0Gooooo`00>oooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP0Mooooo`05o`000?ooooooooooooooool000002oooool01?m4
A4CogMgMooooool0000Oooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q01kooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S80:Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02Gooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01kooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0001oooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?nHV9SooooooiRHV?lQ8B407Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P0Yooooo`03o`000?oooooooooo01Oooooo000kooooo`;o00009_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool07?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00CogMgMoeEEEOoooooo00007oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oeEEEOl0003o410@olc<c00Nooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<02Wooooo00?o0000ooooooooool0Coooool2o`0002Kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01gooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0001oooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`07Oooool01Ol0003ooooooooooooooooo000000_o
oooo00Goc<c<o`000?l0003o0000olc<c00Yooooo`03o`000?oooooooooo01Oooooo000kooooo`03
o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
01_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001oooooo00Go410@
oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo023ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100:Oooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
01cooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001oooooo00Go410@
oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo01oooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100:Oooool00ol0003oooooooooo`0Gooooo`00
>oooool00ol0003oooooooooo`0Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@01gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000001oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH023ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000:Oooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41007_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
k^k^odA4A?l000007oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0
7oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000Yoooo
o`03o`000?oooooooooo01Oooooo000kooooo`03o`000?oooooooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`07Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00gooooo00?oMgMgo`000?ooool07_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00Coc<c<odA4A?l0003o410@7_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@0Wooooo`03oeEEEOmVIVKo0000057ooooo00?o0000ooooooooool09Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Nooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Nooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY02Oooooo00?oEEEEofIVI_l000006Oooool003_ooooo0_l0
003oooooodoooooo0_l0003ooooooaOooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool0
0ol0003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0
003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003o
ooooooooo`3ooooooaKooooo000doooooooo00003Ol00015oooooooo00003Ol0000Booooo`00>ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05ooo
ool003_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo04oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo01Oooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooo
oaKooooo000kooooo`;o0000oooooom?ooooo`;o0000oooooolGooooo`00>oooool00ol0003ooooo
ooooo`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003ooooooooo
o`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3o
ooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool2o`000?ooooooCoooool2o`00
0?oooooo5oooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oo
oooo5_ooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo
5_ooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_oo
ool003_ooooo0_l0003oooooodoooooo0_l0003ooooooaOooooo000kooooo`03o`000?oooooooooo
0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?oo
ooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?oooooo
C_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`;o0000oooooom?ooooo`;o0000oooo
oolGooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooooolF
ooooo`006?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0ooooool/ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01?ooool00ol0003oooooooooo`3ooooooaKooooo000Hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0ooooool/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool0oooooolFooooo`006?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo;?oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?oooooo5_ooool001Sooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool2o`000?oooooo
;Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`03ooooo`?o0000oooooolFooooo`006?ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0ooooool/ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3ooooooaKooooo000H
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0ooooool/ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
oooooolFooooo`006?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ooooool/ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3ooooooaKooooo000Hooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooo
ool]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00005ooooo`;o0000oooooolGooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo
00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o
0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o0000
ooooooooool0oooooolFooooo`00>oooool2o`000?ooooooCoooool2o`000?oooooo5oooool003_o
oooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo
00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo00?o
0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo0_l0003o
ooooodoooooo0_l0003ooooooaOooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0
003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003o
ooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003ooooo
ooooo`3ooooooaKooooo000kooooo`;o0000oooooom?ooooo`;o0000oooooolGooooo`00>oooool0
0ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`008?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocCooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooolFooooo`00
8?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0ooooooldooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3ooooooaKooooo000Pooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`;o0000ooooooleoooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooolF
ooooo`008?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocCooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo00?ooooo00?o0000ooooooooool0oooooolFooooo`008?ooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
=?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004oooo
o`03o`000?oooooooooo0?oooooo5_ooool0023ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ooooooldooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo5_ooool0
023ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo0_l0003o
ooooocGooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo0_l0
003ooooooaOooooo000Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o
0000ooooooooool0ooooooldooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o
0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o0000
ooooooooool0oooooolFooooo`00>oooool2o`000?ooooooCoooool2o`000?oooooo5oooool003_o
oooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo
00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo00?o
0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo00?o0000
ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo0_l0003ooooo
odoooooo0_l0003ooooooaOooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003o
ooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003ooooo
ooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003ooooooooo
o`3ooooooaKooooo000kooooo`;o0000oooooom?ooooo`;o0000oooooolGooooo`006?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo;?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo5_ooool001Sooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0ooooool/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
0?oooooo5_ooool001Sooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobcooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`3ooooooaKooooo000Hooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0_l0003oooooobgooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool00ooo
ool3o`000?oooooo5_ooool001Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
;?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooolFooooo`006?ooool01Ol@413o
oooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0?oooooo;?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo5_ooool0
01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo;?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0oooooolFooooo`006?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo1Ol00004ooooo`Co00001Oooool2o`000?oooooo5oooool003_ooooo00?o0000oooooooo
ool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo00?o0000ooooooooool0
oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo00?o0000ooooooooool0oooo
oom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo0_l0003oooooodoooooo0_l0003o
oooooaOooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooo
oaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKo
oooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo
000kooooo`;o0000oooooom?ooooo`;o0000oooooolGooooo`00>oooool00ol0003oooooooooo`3o
ooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3ooooo
odkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodko
oooo00?o0000ooooooooool0oooooolFooooo`00>oooool2o`000?ooooooCoooool2o`000?oooooo
5oooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_oo
ool0037ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool4
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooolFooooo`00<oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooAoooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?oooooo5_ooool003?ooooo00?o0000ooooooooool01Oooool2o`000?oo
ooooB?ooool00ol0003oooooooooo`04ooooo`?o0000oooooolFooooo`00<oooool00ol0003ooooo
ooooo`3oooooodoooooo00?o0000ooooooooool0oooooolMooooo`00<oooool00ol0003ooooooooo
o`3oooooodoooooo00?o0000ooooooooool0oooooolMooooo`00<oooool00ol0003oooooooooo`3o
ooooodoooooo00?o0000ooooooooool0oooooolMooooo`00<oooool00ol0003oooooooooo`3ooooo
odoooooo00?o0000ooooooooool0oooooolMooooo`00<Oooool00omEEEGoIVIVo`00003oooooodoo
oooo00?oEEEEofIVI_l00000oooooolOooooo`00ooooooooooooojGooooo003oooooooooooooYOoo
ool00?oooooooooooonUooooo`00Z?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo01Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c03oooooobkooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`0Gooooo`;o000000?o410@ooooooooool0Q_ooool00:Wooooo00Go
0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b0?oo
oooo;oooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo
08Oooooo002Yooooo`05o`000?ooooooooooooooool000007?ooool00ol0003oooooooooo`3ooooo
obgooooo00Go0000ooooooooooooooooo`00000Hooooo`Go0000R?ooool00:Wooooo00Go0000oooo
ooooooooooooo`000009ooooo`Ko00003?ooool00onYZJWo410@ooooo`3oooooobkooooo00Go0000
ooooooooooooooooo`000009ooooo`Ko00002Oooool01?m4A4CogMgMooooool00029ooooo`00ZOoo
ool01Ol0003oQhN7oooooonYZJWo000001[ooooo00?o410@o`000?nj^[X0ooooool_ooooo`05o`00
0?n7QhOoooooojVYZOl000006?ooool01?oMgMgoEEEEooooool00029ooooo`00Z?ooool00ol@413o
0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o^[Zjob4Q8Oooool0ooooool]ooooo`03
oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05oooool00omgMgOoc<c<o`000029ooooo`00
a_ooool01Ol@413oV9RHoooooonj^[[o00000?ooooooCOooool00oo^k^koA4A4o`000029ooooo`00
a_ooool01OnYZJWo410@o`000?l@413oZJVY0?ooooooC_ooool00omgMgOo0000ooooo`28ooooo`00
ooooooooooooojGooooo003oooooooooooooYOooool00?oooooooooooonUooooo`00oooooooooooo
ojGooooo003oooooooooooooYOooool00?oooooooooooonUooooo`00ooooooooooooojGooooo003o
ooooooooooooYOooool00?oooooooooooonUooooo`00ooooooooooooojGooooo003ooooooooooooo
YOooool00?oooooooooooonUooooo`00ooooooooooooojGooooo003oooooooooooooYOooool00?oo
oooooooooonUooooo`00ooooooooooooojGooooo003oooooooooooooYOooool00?oooooooooooonU
ooooo`00ooooooooooooojGooooo003oooooooooooooYOooool00?oooooooooooonUooooo`00oooo
ooooooooojGooooo003oooooooooooooYOooool00?oooooooooooonUooooo`00<Oooool4o`000003
oa0@4?oooooooooo0?ooooooBoooool4o`000003oa0@4?oooooooooo0?oooooo6oooool003?ooooo
00?o0000ooooooooool0oooooom?ooooo`03o`000?oooooooooo0?oooooo7Oooool002Sooooo1_l0
0005ooooo`03o`000?oooooooooo00Gooooo0_l0003oooooocgooooo1_l00005ooooo`03o`000?oo
oooooooo00Cooooo0ol0003ooooooaKooooo000cooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooom7ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolF
ooooo`00<oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooAoooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo5_ooool003?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooodOooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3ooooooaKooooo000cooooo`03o`000?oooooooooo00Gooooo0_l0003oooooodSooooo
00?o0000ooooooooool01?ooool2o`000?oooooo5oooool0037ooooo00?oEEEEofIVI_l000001ooo
ool00ol0003oooooooooo`3oooooodGooooo00?oEEEEofIVI_l000001_ooool00ol0003ooooooooo
o`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3o
oooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooo
oaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKo
oooo000kooooo`;o0000oooooom?ooooo`;o0000oooooolGooooo`00>oooool00ol0003ooooooooo
o`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3o
ooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3ooooo
odkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool2o`000?ooooooCoooool2o`000?oo
oooo5oooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo
5_ooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_oo
ool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool0
03_ooooo0_l0003oooooodoooooo0_l0003ooooooaOooooo000Hooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0ooooool/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00?o0000ooooooooool0oooooolFooooo`006?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3oooooobcooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooolFooooo`00
4?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobCooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0oooooolFooooo`006?ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`;o0000ooooool]oooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00?ooooo0ol0003ooooooaKooooo000Hooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3oooooobcooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo5_ooool001Sooooo
00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3oooooobcooooo00Go410@oooooooooooooooooa0@400>oooo
o`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
oaKooooo000Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooobcooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0?oooooo5_ooool001Sooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooobgooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Gooooo0_l0003ooooooaOooooo000kooooo`03o`00
0?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oo
oooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooo
oooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`;o0000oooooom?oooo
o`;o0000oooooolGooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o0000oooooooo
ool0oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0
oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooo
oolFooooo`00>oooool2o`000?ooooooCoooool2o`000?oooooo5oooool003_ooooo00?o0000oooo
ooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo00?o0000oooooooo
ool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo00?o0000ooooooooool0
oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo0_l0003oooooodoooooo0_l0
003ooooooaOooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3o
oooooaKooooo000Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003o
ooooooooo`3ooooooaKooooo000Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocCooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
0?oooooo5_ooool001Sooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo;?ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolF
ooooo`008?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool2
o`000?oooooo=Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00ooo
ool3o`000?oooooo5_ooool0023ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocCooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3ooooo
oaKooooo000Pooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0?oooooo=?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3ooooooaKooooo000Pooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaKooooo000Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0
003oooooocGooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool2o`000?oooooo
5oooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_oo
ool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool0
03_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_o
oooo0_l0003oooooodoooooo0_l0003ooooooaOooooo000kooooo`03o`000?oooooooooo0?oooooo
C_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_oo
ool00ol0003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool0
0ol0003oooooooooo`3ooooooaKooooo000kooooo`;o0000oooooom?ooooo`;o0000oooooolGoooo
o`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`00
>oooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>ooo
ool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool2
o`000?ooooooCoooool2o`000?oooooo5oooool003_ooooo00?o0000ooooooooool0oooooom>oooo
o`03o`000?oooooooooo0?oooooo5_ooool001Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooolFooooo`006?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo;?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo5_ooool0013ooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo
oooo00?ooooo0_l0003oooooobGooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo0ol0003ooooooaKooooo000H
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0ooooool/ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
oooooolFooooo`006?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0ooooool/ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01?ooool00ol0003oooooooooo`3ooooooaKooooo000Hooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0ooooool/ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolFooooo`006?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Oooooo0_l0003oooooobgooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`;o0000oooooolGoooo
o`006?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool00ol0003oooooooooo`3oooooobcooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo00?o0000ooooooooool0
oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooo
oolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooooolF
ooooo`00>oooool2o`0002Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<01kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<02Oooooo1?l000000ol@413oooooooooo`1=ooooo`;o00009_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00007_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool07?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`07Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`09ooo
ool4o`000003oa0@4?oooooooooo01Gooooo000kooooo`03o`000?oooooooooo02Gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Mooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0N
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@0Yooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool09Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
02Wooooo00?o0000ooooooooool05oooool003_ooooo00?o0000ooooooooool09Oooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h07_ooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000Nooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000001kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000:Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01oooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00007_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`00000Mooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000002Wooooo00?o0000ooooooooool05oooool003_ooooo00?o0000ooooooooool09Oooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h07Oooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00007oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@0Nooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b02Wooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`0Uooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Nooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Oooooo`05o`000?oooooooooo
ooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01gooooo00Go0000oooooooooooooooo
o`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80:Oooool00ol0003oooooooooo`0Gooooo`00
>oooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`0Looooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000O
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<01kooooo
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0:Oooool00ol0
003oooooooooo`1?ooooo`03o`000?oooooooooo02Gooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo01gooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0001oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`07Oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Yooooo`03o`000?oooooooooo01Oooooo000kooooo`;o00009_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00cooooo
00?oMgMgolc<c?l000007oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qooo
ool08?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Y
ooooo`03o`000?oooooooooo04oooooo0_l0000Vooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Looooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000Oooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Oooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@02Wooooo00?o0000
ooooooooool05oooool003_ooooo00?o0000ooooooooool09Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Mooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00oo^k^koA4A4o`00000Oooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV00Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000002Wooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Uooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@01kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_m4A4Co000001oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03omgMgOl@413oV9RH01oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooookZj^_l00000:Oooool00ol0003oooooooooo`0Gooooo`00>oooool00ol0003oooooooooo`0U
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<01gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo01kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool00omEEEGoIVIVo`00001Aooooo`03o`00
0?oooooooooo02Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`07_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool07_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@7Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Wooooo`03oeEEEOmVIVKo0000
01Wooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKo
oooo000kooooo`;o0000oooooom?ooooo`;o0000oooooolGooooo`00>oooool00ol0003ooooooooo
o`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3o
ooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3ooooo
odkooooo00?o0000ooooooooool0oooooolFooooo`00=?ooooooo`0000go0000AOooooooo`0000go
00004_ooool003_ooooo00?o0000ooooooooool00oooool;o`0000Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`07ooooo`[o00001Oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`00>ooo
ool00ol0003oooooooooo`0>ooooo`_o0000__oooolEo`00067ooooo00?o0000ooooooooool0oooo
oolFooooo`00>oooool00ol0003oooooooooo`0IoooooaGo0000W_ooool;o`0007Kooooo00?o0000
ooooooooool0oooooolFooooo`00>oooool2o`0002oooooo2_l00029ooooo`_o0000POooool2o`00
0?oooooo5oooool003_ooooo00?o0000ooooooooool0>?oooolFo`0005kooooo5Ol0002<ooooo`03
o`000?oooooooooo0?oooooo5_ooool003_ooooo00?o0000ooooooooool0C_oooolGo`0003;ooooo
5Ol0002Qooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo00?o0000ooooooooool0IOoo
oolbo`000;Kooooo00?o0000ooooooooool0oooooolFooooo`00>oooool2o`000?ooooooCoooool2
o`000?oooooo5oooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo
0?oooooo5_ooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oo
oooo5_ooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo
5_ooool003_ooooo0_l0003oooooodoooooo0_l0003ooooooaOooooo000kooooo`03o`000?oooooo
oooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo
0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?oo
ooooC_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`;o0000oooooom?ooooo`;o0000
oooooolGooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooo
oolFooooo`006?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0ooooool/ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`3ooooooaKooooo000Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0ooooool/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0oooooolFooooo`006?ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`;o0000ooooool]ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;o
oooo0ol0003ooooooaKooooo000Hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0ooooool/ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool0oooooolFooooo`006?ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0ooooool/ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3ooooooaKooooo
000Hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0ooooool/ooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooolFooooo`006?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ooooool/oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaKooooo000Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000
ooooool]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00005ooooo`;o0000oooooolGooooo`00>oooool00ol0003oooooooooo`3oooooodko
oooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo
00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o
0000ooooooooool0oooooolFooooo`00>oooool2o`000?ooooooCoooool2o`000?oooooo5oooool0
03_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_o
oooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo
00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo0_l0
003oooooodoooooo0_l0003ooooooaOooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool0
0ol0003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0
003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003o
ooooooooo`3ooooooaKooooo000kooooo`;o0000oooooom?ooooo`;o0000oooooolGooooo`00>ooo
ool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`008?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`3oooooocCooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooolFoooo
o`008?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0ooooooldooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3ooooooaKooooo000Poooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`;o0000oooooole
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooo
oolFooooo`008?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocCooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0oooooolFooooo`008?ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
oooo=?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004
ooooo`03o`000?oooooooooo0?oooooo5_ooool0023ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ooooooldooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo5_oo
ool0023ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo0_l0
003oooooocGooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo
0_l0003ooooooaOooooo000Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo
00?o0000ooooooooool0ooooooldooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Go
oooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo
00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3oooooodkooooo00?o
0000ooooooooool0oooooolFooooo`00>oooool2o`000?ooooooCoooool2o`000?oooooo5oooool0
03_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_o
oooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo
00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo0_l0
003oooooodoooooo0_l0003ooooooaOooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool0
0ol0003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0
003oooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003o
ooooooooo`3ooooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003ooooo
ooooo`3ooooooaKooooo000kooooo`;o0000oooooom?ooooo`;o0000oooooolGooooo`006?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo;?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo5_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0ooooool/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo0?oooooo5_ooool001Sooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobcooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3ooooooaKooooo000Hooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0_l0003oooooobgooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
0oooool3o`000?oooooo5_ooool001Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
oooo;?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooolFooooo`006?ooool01Ol@
413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo;?ooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo5_oo
ool001Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo;?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolFooooo`006?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo;Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo1Ol00004ooooo`Co00001Oooool2o`000?oooooo5oooool003_ooooo00?o0000oooo
ooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo00?o0000oooooooo
ool0oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo00?o0000ooooooooool0
oooooom>ooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo0_l0003oooooodoooooo0_l0
003ooooooaOooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3o
oooooaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooo
oaKooooo000kooooo`03o`000?oooooooooo0?ooooooC_ooool00ol0003oooooooooo`3ooooooaKo
oooo000kooooo`;o0000oooooom?ooooo`;o0000oooooolGooooo`00>oooool00ol0003ooooooooo
o`3oooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3o
ooooodkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool00ol0003oooooooooo`3ooooo
odkooooo00?o0000ooooooooool0oooooolFooooo`00>oooool2o`000?ooooooCoooool2o`000?oo
oooo5oooool003_ooooo00?o0000ooooooooool0oooooom>ooooo`03o`000?oooooooooo0?oooooo
5_ooool0037ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOoo
ool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooolFooooo`00<oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooAoooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooo5_ooool003?ooooo00?o0000ooooooooool01Oooool2o`00
0?ooooooB?ooool00ol0003oooooooooo`04ooooo`?o0000oooooolFooooo`00<oooool00ol0003o
ooooooooo`3oooooodoooooo00?o0000ooooooooool0oooooolMooooo`00<oooool00ol0003ooooo
ooooo`3oooooodoooooo00?o0000ooooooooool0oooooolMooooo`00<oooool00ol0003ooooooooo
o`3oooooodoooooo00?o0000ooooooooool0oooooolMooooo`00<oooool00ol0003oooooooooo`3o
ooooodoooooo00?o0000ooooooooool0oooooolMooooo`00<Oooool00omEEEGoIVIVo`00003ooooo
odoooooo00?oEEEEofIVI_l00000oooooolOooooo`00ooooooooooooojGooooo003ooooooooooooo
YOooool00:Sooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co0000
00?o410@ooooooooool0ooooool[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool05Oooool5o`0008Sooooo002Yooooo`05o`000?ooooooooooooooool000002Oooool6o`0000co
oooo00?o0000ooooooooool0ooooool^ooooo`05o`000?ooooooooooooooool000002Oooool6o`00
00Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A028ooooo`00ZOooool01Ol0003ooooooooooooooooo
000001_ooooo00?o0000ooooooooool0ooooool^ooooo`05o`000?ooooooooooooooool000006Ooo
ool00onHV9So8B4Qonk^kP29ooooo`00ZOooool01Ol0003ooooooooooooooooo000000Wooooo1_l0
000<ooooo`03o`000?oooooooooo0?oooooo;_ooool01Ol0003ooooooooooooooooo000000Wooooo
1_l0000;ooooo`03oiRHV?lQ8B7ok^k^08Sooooo002Yooooo`05o`000?n7QhOoooooojVYZOl00000
6oooool00ol0003oooooooooo`3oooooobkooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03
ogMgMomVIVKooooo08Oooooo002Xooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
6Oooool00ol0003oooooooooo`3oooooobgooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooo
ooooo`0Jooooo`03o`000?oooooooooo08Kooooo0039ooooo`03o`000?oooooooooo0?ooooooBooo
ool01Ol0003o^[ZjoooooonHV9So410@08Sooooo0037ooooo`03oeEEEOmVIVKo00000?ooooooCOoo
ool01OnHV9So410@o`000?lQ8B7oc<c<08Sooooo003oooooooooooooYOooool00?oooooooooooonU
ooooo`00ooooooooooooojGooooo003oooooooooooooYOooool00?oooooooooooonUooooo`00oooo
ooooooooojGooooo003oooooooooooooYOooool00?oooooooooooonUooooo`00ooooooooooooojGo
oooo003oooooooooooooYOooool00?oooooooooooonUooooo`00ooooooooooooojGooooo003ooooo
ooooooooYOooool00001\
\>"],
  ImageRangeCache->{{{0, 674.625}, {416.562, 0}} -> {0, 0, 0, 0}, {{16.3125, \
322}, {406.625, 217.688}} -> {0, -1, 0, 0}, {{352.562, 658.25}, {406.625, \
217.688}} -> {-1, -1, 0, 0}, {{16.3125, 322}, {198.812, 9.875}} -> {0, -3, 0, \
0}, {{352.562, 658.25}, {198.812, 9.875}} -> {-1, -3, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "All of the modes approach zero amplitude as time progresses,  because the \
boundary conditions on the eigenmodes dictate that the temperature equals \
zero at the slab faces.  Thus, in equilibrium the temperature deviation ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["T",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is zero throughout the slab. The higher-order modes equilibrate more \
rapidly, because they have larger gradients and therefore larger heat fluxes \
according to Eq. ",
  ButtonBox["(3.1.37)",
    ButtonData:>"(3.1.37)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example",
  FontWeight->"Bold"]], "Subsubsection"],

Cell[TextData[{
  "In this example, we will assume a point heat source of the form ",
  Cell[BoxData[
      \(TraditionalForm\`S(x) = \ \[Delta](x - L/2)\)]],
  ". We consider a slab of material of unit width, ",
  Cell[BoxData[
      \(TraditionalForm\`L = 1\)]],
  ", with thermal diffusivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] = 1\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] = 1\)]],
  " as well. Initially,  the slab has a temperature distribution ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = \(\(T\_o\)(x) = x\^3\)\)]],
  ", and the boundary conditions are ",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t) = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`T(1, t) = 1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Then the equilibrium temperature distribution is given by  Eq. ",
  ButtonBox["(3.1.49)",
    ButtonData:>"(3.1.49)",
    ButtonStyle->"Hyperlink"],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(C\_1\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  " chosen to match the boundary conditions,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_eq\)(0) = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_eq\)(L)\  = \ 1\)]],
  ". After performing the required integrals, we obtain ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1 = 0, \ C\_2 = 3/2\)]],
  ", and"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\(T\_eq\)(x)\  = \ 
      3  x/2\ \  - \ \((x - 1/2)\)\ \(h(
            x - 1/2)\)\)\(,\)\)\)]]], "NumberedEquation",
  CellTags->"(3.1.63)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is a Heaviside step function. This equilibrium temperature distribution \
is displayed in Cell ",
  ButtonBox["3.8",
    ButtonData:>"Cell 3.8",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Teq[x_]\  = 
        3  x/2\ \  - \ \((x - 1/2)\)\ UnitStep[x - 1/2];\)\), "\n", 
    \(\(Plot[Teq[x], {x, 0, 1}, 
        AxesLabel \[Rule] {"\<x\>", \*"\"\<\!\(T\_eq\)[x]\>\""}];\)\)}], \
"Input",
  ShowCellTags->True,
  CellTags->"Cell 3.8"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -18.7188 0 ]
[.02381 .64303 18.7188 12.9375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -79.7188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.9375 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(eq) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.438 13.000 moveto
(@) show
84.438 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.438 13.000 moveto
(D) show
96.438 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .05053 L
.10458 .08959 L
.14415 .12628 L
.18221 .16156 L
.22272 .19911 L
.26171 .23526 L
.30316 .27368 L
.34309 .3107 L
.3815 .34631 L
.42237 .3842 L
.46172 .42068 L
.48147 .43899 L
.49012 .44701 L
.49468 .45124 L
.49719 .45356 L
.49842 .4547 L
.49955 .45575 L
.50085 .45643 L
.50154 .45664 L
.50226 .45687 L
.50471 .45762 L
.5095 .4591 L
.51896 .46203 L
.53984 .46848 L
.57781 .48021 L
.61824 .4927 L
.65714 .50473 L
.6985 .51751 L
.73835 .52982 L
.77668 .54167 L
.81746 .55427 L
.85673 .5664 L
.89448 .57807 L
.93468 .59049 L
.97337 .60245 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool0059oo`<000Ioo`8000Aoo`D002Ioo`<000Ioo`8000Ioo`<002Eoo`<000Ioo`8000Eoo`<002Mo
o`<000Ioo`8000Eoo`<002moo`D0029oo`00DGoo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo
000UOol01@00Oomoogoo00001Goo0P001goo00<007ooOol08goo00D007ooOomoo`0000Eoo`8000Ao
o`05001oogooOol0000UOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00031oo`03001o
ogoo029oo`00DGoo00D007ooOomoo`0000eoo`03001oogoo02Eoo`05001oogooOol0000;Ool5000T
Ool01@00Oomoogoo00002goo00D007ooOomoo`0002Eoo`05001oogooOol0000;Ool01@00Oomoogoo
0000<7oo00<007ooOol08Woo001AOol01@00Oomoogoo00003Woo00<007ooOol097oo00D007ooOomo
o`0000]oo`04001oogoo000UOol01@00Oomoogoo00002goo00D007ooOomoo`0002Eoo`05001oogoo
Ool0000;Ool01@00Oomoogoo0000<7oo00<007ooOol08Woo001AOol01@00Oomoogoo00003goo00<0
07ooOol08goo00D007ooOomoo`0000aoo`03001oo`0002Eoo`05001oogooOol0000;Ool4000VOol0
1@00Oomoogoo000037oo0`00<Goo00<007ooOol08Woo001AOol01@00Oomoogoo00003goo00<007oo
Ool08goo00D007ooOomoo`0000aoo`03001oo`0002Eoo`05001oogooOol0000;Ool00`00Oomoo`0W
Ool01@00Oomoogoo00002goo00D007ooOomoo`00031oo`03001oogoo029oo`00DGoo00D007ooOomo
o`0000]oo`05001oogooOol0000UOol01@00Oomoogoo00003Goo0P009Goo00D007ooOomoo`0000ao
o`03001oogoo02Ioo`05001oogooOol0000;Ool01@00Oomoogoo0000<7oo00<007ooOol08Woo001B
Ool3000=Ool3000WOol3000?Ool00`00Oomoo`0TOol3000>Ool3000VOol3000=Ool3000_Ool3000T
Ool00?moofUoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOolaOol20002Ool2000=
Ool0029oo`03001oogoo0?mooc9oo`04001oogoo000>Ool0029oo`03001oogoo0?mooc=oo`8000mo
o`006gooo`00<@0037oo0P003goo000ROol00`00Ool0000<Ool00`00Oomoo`0;Ool00`00Oomoo`0<
Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<
Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<
Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<
Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0@Ool01000Oomoo`003Woo000ROol01000
Oomoo`00=Woo00<007ooOol0=goo00<007ooOol0=Woo00<007ooOol0=goo00<007ooOol0=goo00<0
07ooOol03goo0P000Woo0P003Goo000ROol01@00Oomoogoo0000ogoo@Woo000ROol00`00Oomoo`02
Ool00`00Oomoo`3oOoloOol0029oo`03001oogoo00=oo`03001oogoo0?moocioo`008Woo00<007oo
Ool017oo00<007ooOol0ogoo?Goo000ROol00`00Oomoo`05Ool00`00Oomoo`3oOollOol0029oo`03
001oogoo00Ioo`03001oogoo0?mooc]oo`008Woo0`001goo00<007ooOol0ogoo>Woo000ROol00`00
Oomoo`08Ool00`00Oomoo`3oOoliOol0029oo`03001oogoo00Uoo`800?moocUoo`008Woo00<007oo
Ool02goo00<007ooOol0ogoo=Woo000ROol00`00Oomoo`0<Ool00`00Oomoo`3oOoleOol0029oo`03
001oogoo00eoo`03001oogoo0?moocAoo`008Woo00<007ooOol03Woo00<007ooOol0ogoo<goo000R
Ool00`00Oomoo`0?Ool00`00Oomoo`3oOolbOol0029oo`03001oogoo011oo`03001oogoo0?mooc5o
o`008Woo0`004Goo00<007ooOol0ogoo<7oo000ROol00`00Oomoo`0BOol00`00Oomoo`3oOol_Ool0
029oo`03001oogoo01=oo`03001oogoo0?moobioo`008Woo00<007ooOol057oo00<007ooOol0ogoo
;Goo000ROol00`00Oomoo`0EOol00`00Oomoo`3oOol/Ool0029oo`03001oogoo01Ioo`800?moobao
o`008Woo00<007ooOol067oo00<007ooOol0ogoo:Goo000ROol00`00Oomoo`0IOol00`00Oomoo`3o
OolXOol0029oo`03001oogoo01Yoo`03001oogoo0?moobMoo`008Woo0`006goo00<007ooOol0ogoo
9Woo000ROol00`00Oomoo`0LOol00`00Oomoo`3oOolUOol0029oo`03001oogoo01eoo`03001oogoo
0?moobAoo`008Woo00<007ooOol07Woo00<007ooOol0ogoo8goo000ROol00`00Oomoo`0OOol00`00
Oomoo`3oOolROol0029oo`03001oogoo021oo`03001oogoo0?moob5oo`002Goo0`001Woo0P0017oo
1@001Goo00<007ooOol08Goo00<007ooOol0ogoo87oo0008Ool01@00Oomoogoo00001Goo0P001Goo
00@007ooOol000Eoo`03001oogoo029oo`03001oogoo0?mooamoo`0027oo00D007ooOomoo`0000eo
o`03001oogoo00Eoo`03001oogoo02=oo`03001oogoo0?mooaioo`0027oo00D007ooOomoo`0000io
o`03001oogoo00Aoo`<002Aoo`03001oogoo0?mooaeoo`0027oo00D007ooOomoo`0000moo`03001o
ogoo00=oo`03001oogoo02Eoo`03001oogoo0?mooaaoo`0027oo00D007ooOomoo`0000moo`03001o
ogoo00=oo`03001oogoo02Ioo`03001oogoo0?mooa]oo`0027oo00D007ooOomoo`0000]oo`05001o
ogooOol00005Ool00`00Oomoo`0WOol00`00Oomoo`3oOolJOol000Uoo`<000eoo`<000Ioo`03001o
ogoo02Qoo`03001oogoo0?mooaUoo`008Woo00<007ooOol0:Goo00<007ooOol0ogoo67oo000ROol0
0`00Oomoo`0ZOol00`00Oomoo`3oOolGOol0029oo`03001oogoo02]oo`03001oogoo0?mooaIoo`00
8Woo00<007ooOol0;7oo00<007ooOol0ogoo5Goo000ROol3000]Ool2003oOolEOol0029oo`03001o
ogoo02moo`03001oogoo0?mooa9oo`008Woo00<007ooOol0<7oo00<007ooOol0ogoo4Goo000ROol0
0`00Oomoo`0aOol00`00Oomoo`3oOol@Ool0029oo`03001oogoo039oo`03001oogoo0?moo`moo`00
8Woo00<007ooOol0<goo0P00ogoo3goo000ROol00`00Oomoo`0eOol00`00Oomoo`3oOol<Ool0029o
o`03001oogoo03Ioo`03001oogoo0?moo`]oo`008Woo00<007ooOol0=goo00<007ooOol0ogoo2Woo
000ROol3000hOol00`00Oomoo`3oOol9Ool0029oo`03001oogoo03Uoo`03001oogoo0?moo`Qoo`00
8Woo00<007ooOol0>Woo00<007ooOol0ogoo1goo000ROol00`00Oomoo`0kOol00`00Oomoo`3oOol6
Ool0029oo`03001oogoo03aoo`03001oogoo0?moo`Eoo`008Woo00<007ooOol0?Goo00<007ooOol0
ogoo17oo000ROol00`00Oomoo`0nOol00`00Oomoo`3oOol3Ool0029oo`03001oogoo03moo`03001o
ogoo0?moo`9oo`008Woo00<007ooOol0@7oo00<007ooOol0ogoo0Goo000ROol30011Ool00`00Oomo
o`3oOol0029oo`03001oogoo049oo`03001oogoo0?ioo`008Woo00<007ooOol0@goo00<007ooOol0
oGoo000ROol00`00Oomoo`14Ool00`00Oomoo`3lOol0029oo`03001oogoo04Eoo`800?aoo`008Woo
00<007ooOol0Agoo00<007ooOol0nGoo0009Ool30006Ool20006Ool30005Ool00`00Oomoo`18Ool0
0`00Oomoo`3hOol000Qoo`05001oogooOol00005Ool20007Ool00`00Oomoo`04Ool00`00Oomoo`19
Ool00`00Oomoo`3gOol000Qoo`05001oogooOol0000;Ool50005Ool3001:Ool00`00Oomoo`3fOol0
00Qoo`05001oogooOol0000;Ool01000Oomoo`001Woo00<007ooOol0Bgoo00<007ooOol0mGoo0008
Ool01@00Oomoogoo000037oo00<007oo00001Woo00<007ooOol0C7oo00<007ooOol0m7oo0008Ool0
1@00Oomoogoo000037oo00<007oo00001Woo00<007ooOol0CGoo00<007ooOol0lgoo0008Ool01@00
Oomoogoo00003Goo0P001Woo00<007ooOol0CWoo00<007ooOol0lWoo0009Ool3000?Ool00`00Oomo
o`04Ool00`00Oomoo`1?Ool00`00Oomoo`3aOol0029oo`03001oogoo051oo`03001oogoo0?1oo`00
8Woo00<007ooOol0DGoo00<007ooOol0kgoo000ROol00`00Oomoo`1BOol2003_Ool0029oo`<005Ao
o`03001oogoo0>aoo`008Woo00<007ooOol0EGoo00<007ooOol0jgoo000ROol00`00Oomoo`1FOol0
0`00Oomoo`3ZOol0029oo`03001oogoo05Moo`03001oogoo0>Uoo`008Woo00<007ooOol0F7oo00<0
07ooOol0j7oo000ROol00`00Oomoo`1IOol00`00Oomoo`3WOol0029oo`03001oogoo05Yoo`03001o
ogoo0>Ioo`008Woo00<007ooOol0Fgoo00<007ooOol0iGoo000ROol00`00Oomoo`1LOol00`00Oomo
o`3TOol0029oo`<005eoo`03001oogoo0>=oo`008Woo00<007ooOol0GWoo0P00hgoo000ROol00`00
Oomoo`1POol00`00Oomoo`3POol0029oo`03001oogoo065oo`03001oogoo0=moo`008Woo00<007oo
Ool0HWoo00<007ooOol0gWoo000ROol00`00Oomoo`1SOol00`00Oomoo`3MOol0029oo`03001oogoo
06Aoo`03001oogoo0=aoo`008Woo00<007ooOol0IGoo00<007ooOol0fgoo000ROol00`00Oomoo`1V
Ool00`00Oomoo`3JOol0029oo`<006Moo`03001oogoo0=Uoo`008Woo00<007ooOol0J7oo00<007oo
Ool0f7oo000ROol00`00Oomoo`1YOol00`00Oomoo`3GOol0029oo`03001oogoo06Yoo`800=Moo`00
8Woo00<007ooOol0K7oo00<007ooOol0e7oo000ROol00`00Oomoo`1]Ool00`00Oomoo`3COol0029o
o`03001oogoo06ioo`03001oogoo0=9oo`002Goo0`001Woo0P001Goo0`001Woo00<007ooOol0Kgoo
00<007ooOol0dGoo0008Ool01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0000Eoo`03001o
ogoo071oo`03001oogoo0=1oo`0027oo00D007ooOomoo`0000]oo`05001oogooOol00005Ool3001a
Ool00`00Oomoo`3?Ool000Qoo`05001oogooOol0000;Ool01@00Oomoogoo00001Goo00<007ooOol0
LWoo00<007ooOol0cWoo0008Ool01@00Oomoogoo00002goo10001Woo00<007ooOol0Lgoo00<007oo
Ool0cGoo0008Ool01@00Oomoogoo00002goo00<007ooOol01goo00<007ooOol0M7oo00<007ooOol0
c7oo0008Ool01@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol0MGoo00<007ooOol0bgoo
0009Ool3000>Ool30005Ool00`00Oomoo`1fOol2003;Ool0029oo`03001oogoo07Qoo`03001oogoo
0<Qoo`008Woo00<007ooOol0NGoo00<007ooOol0agoo000ROol00`00Oomoo`1jOol00`00Oomoo`36
Ool0029oo`<007]oo`03001oogoo0<Eoo`008Woo00<007ooOol0O7oo00<007ooOol0a7oo000ROol0
0`00Oomoo`1mOol00`00Oomoo`33Ool0029oo`03001oogoo07ioo`03001oogoo0<9oo`008Woo00<0
07ooOol0Ogoo00<007ooOol0`Goo000ROol00`00Oomoo`20Ool00`00Oomoo`30Ool0029oo`03001o
ogoo085oo`03001oogoo0;moo`008Woo00<007ooOol0PWoo00<007ooOol0_Woo000ROol00`00Oomo
o`23Ool00`00Oomoo`2mOol0029oo`<008Aoo`03001oogoo0;aoo`008Woo00<007ooOol0QGoo00<0
07ooOol0^goo000ROol00`00Oomoo`26Ool00`00Oomoo`2jOol0029oo`03001oogoo08Moo`03001o
ogoo0;Uoo`008Woo00<007ooOol0R7oo0P00^Goo000ROol00`00Oomoo`2:Ool00`00Oomoo`2fOol0
029oo`03001oogoo08]oo`03001oogoo0;Eoo`008Woo00<007ooOol0S7oo00<007ooOol0]7oo000R
Ool00`00Oomoo`2=Ool00`00Oomoo`2cOol0029oo`<008eoo`<00;=oo`008Woo00<007ooOol0T7oo
0`00/7oo000ROol00`00Oomoo`2COol5002[Ool0029oo`03001oogoo09Qoo`@00:Moo`008Woo00<0
07ooOol0W7oo0`00Y7oo000ROol00`00Oomoo`2OOol3002QOol000Uoo`<000Ioo`8000Eoo`<000Io
o`03001oogoo0:9oo`<009ioo`0027oo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol00005
Ool00`00Oomoo`2UOol3002KOol000Qoo`05001oogooOol0000;Ool01@00Oomoogoo00001Goo00<0
07ooOol0Z7oo0`00V7oo0008Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Eoo`<00:]oo`<0
09Eoo`0027oo00D007ooOomoo`0000aoo`<000Ioo`03001oogoo0:ioo`<0099oo`0027oo00D007oo
Oomoo`0000]oo`05001oogooOol00005Ool00`00Oomoo`2aOol3002?Ool000Qoo`05001oogooOol0
000;Ool01@00Oomoogoo00001Goo00<007ooOol0]7oo1000Rgoo0009Ool3000=Ool30006Ool00`00
Oomoo`2hOol40027Ool0029oo`03001oogoo0;aoo`@008=oo`008Woo00<007ooOol0`7oo0`00P7oo
000ROol00`00Oomoo`33Ool3001mOol0029oo`03001oogoo0<Ioo`<007Yoo`008Woo0`00bGoo1000
MWoo000ROol00`00Oomoo`3=Ool3001cOol0029oo`03001oogoo0=1oo`<0071oo`008Woo00<007oo
Ool0dgoo0`00KGoo000ROol00`00Oomoo`3FOol2001[Ool0029oo`03001oogoo0=Qoo`<006Qoo`00
8Woo00<007ooOol0fgoo0`00IGoo000ROol00`00Oomoo`3NOol3001ROol0029oo`<00>5oo`<005mo
o`008Woo00<007ooOol0i7oo1@00FWoo000ROol00`00Oomoo`3YOol4001FOol0029oo`03001oogoo
0>eoo`<005=oo`008Woo00<007ooOol0l7oo0`00D7oo000ROol00`00Oomoo`3cOol3001=Ool0029o
o`03001oogoo0?Ioo`<004Yoo`008Woo00<007ooOol0nGoo0`00Agoo000ROol00`00Oomoo`3lOol3
0014Ool0029oo`<00?moo`<0045oo`008Woo00<007ooOol0ogoo0goo0`00?Woo000ROol00`00Oomo
o`3oOol6Ool3000kOol0029oo`03001oogoo0?moo`Uoo`@003Moo`008Woo00<007ooOol0ogoo3Goo
1000<goo000ROol00`00Oomoo`3oOolAOol4000_Ool0029oo`03001oogoo0?mooaEoo`<002aoo`00
6Goo1@0017oo00<007ooOol0ogoo67oo0`00:Goo000KOol00`00Oomoo`04Ool00`00Oomoo`3oOolK
Ool3000VOol001]oo`03001oogoo00Aoo`<00?mooaioo`8002Aoo`006goo00<007ooOol017oo00<0
07ooOol0ogooA7oo000KOol00`00Oomoo`04Ool00`00Oomoo`3oOom4Ool001]oo`03001oogoo00Ao
o`03001oogoo0?moodAoo`006goo00<007ooOol017oo00<007ooOol0ogooA7oo000IOol30006Ool0
0`00Oomoo`3oOom4Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo000LOol3003oOom:Ool001eoo`03001oogoo0?moodUoo`005Woo0`00
0Woo0`001goo0P002goo0P00ogoo=Goo000EOol20003Ool01000Oomoo`001goo00<007ooOol02goo
00<007ooOol0ogoo<goo000?Ool500000goo001oo`0200001Goo001oogoo00001goo00@007ooOomo
o`80009oo`8000Aoo`03001oogoo0?mooc=oo`004Goo00<007ooOol00Woo0P000goo0`001goo00<0
07ooOol00Woo00@007ooOol000Eoo`03001oogoo0?mooc=oo`004Goo00<007ooOol04Goo00<007oo
Ool00goo0P001Woo00<007ooOol0ogoo<goo000AOol00`00Oomoo`0AOol00`00Oomoo`03Ool20006
Ool00`00Oomoo`3oOolcOol0015oo`03001oogoo015oo`03001oogoo009oo`04001oogoo0005Ool0
0`00Oomoo`3oOolcOol000ioo`04001oogoo0002Ool00`00Oomoo`0>Ool01000Oomoogoo0P000Woo
0P0017oo00<007ooOol0ogoo<goo000>Ool01000Oomoo`000Woo00<007ooOol03Woo00<007ooOol0
2goo00<007ooOol0ogoo<goo000>Ool7000@Ool2000;Ool2003oOoleOol00?moofUoo`00ogooJGoo
003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "\tThe solution for the deviation from equilibrium,  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  ",  is given by Eq. ",
  ButtonBox["(3.1.61)",
    ButtonData:>"(3.1.61)",
    ButtonStyle->"Hyperlink"],
  ". The constants ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A\_n\)\(\ \)\)\)]],
  "are determined by the initial condition, ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_o\)(x) = x\^3\)]],
  ", via Eqs. ",
  ButtonBox["(3.1.62)",
    ButtonData:>"(3.1.62)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.1.63)",
    ButtonData:>"(3.1.63)",
    ButtonStyle->"Hyperlink"],
  ". The required integrals are performed using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and the behavior of ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " is plotted in Cell ",
  ButtonBox["3.9",
    ButtonData:>"Cell 3.9",
    ButtonStyle->"Hyperlink"],
  ", keeping ",
  Cell[BoxData[
      \(TraditionalForm\`10\)]],
  " Fourier modes in the solution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*parameters*) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      RowBox[{\(\[Chi] = \(L = 1\); \ M = 20;\), "\[IndentingNewLine]", 
        StyleBox[\( (*\ define\ the\ initial\ condition\ *) \),
          FontColor->RGBColor[1, 0, 0]], "\n", \(T0[x_]\  = \ x\^3;\), "\n", 
        StyleBox[\( (*determine\ the\ constants\ A\_n*) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\n", \(A[n_]\  := \ 
            2/L\ Integrate[
                Sin[n\ \[Pi]\ x/L]\ \((T0[x] - Teq[x])\), {x, 0, L}];\), "\n",
         
        StyleBox[\( (*Fourier\ series\ for\ \[CapitalDelta]T\ *) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\n", \(\[CapitalDelta]T[x_, t_]\  = \ 
            Sum[A[n]\ Exp[\(-\((n\ Pi/L)\)^2\)\ \[Chi]\ t]\ Sin[
                  n\ Pi\ x/L], {n, 1, M}];\), "\n", 
        StyleBox[\( (*The\ full\ solution*) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\n", \(T[x_, t_] = Teq[x]\  + \ \[CapitalDelta]T[x, t];\), "\n", 
        StyleBox[\( (*Plot\ the\ result*) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\n", \(Table[
            Plot[T[x, t], {x, 0, L}, PlotRange \[Rule] {{0, L}, {0, 1}}, 
              PlotLabel \[Rule] "\<t = \>" <> ToString[t], 
              AxesLabel \[Rule] {"\<x\>", "\<T\>"}, 
              PlotStyle \[Rule] Thickness[0.01]], {t, 0, 0.4, \ 
              0.4/20}];\)}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.9"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .00013 L
.05077 7e-05 L
.05371 5e-05 L
.05648 4e-05 L
.05769 4e-05 L
.05898 3e-05 L
.05965 3e-05 L
.06038 3e-05 L
.06168 3e-05 L
.06248 3e-05 L
.06324 3e-05 L
.06392 3e-05 L
.06466 3e-05 L
.06546 3e-05 L
.06632 3e-05 L
.06713 3e-05 L
.06786 4e-05 L
.0693 4e-05 L
.07085 5e-05 L
.07365 7e-05 L
.07648 .0001 L
.07946 .00014 L
.08481 .00024 L
.09505 .00048 L
.10462 .00077 L
.12636 .00143 L
.14593 .00196 L
.15625 .00227 L
.16721 .00271 L
.1788 .00335 L
.18952 .0041 L
.21064 .00592 L
.25028 .00966 L
.27059 .012 L
.29249 .01538 L
.33569 .02359 L
.35724 .02795 L
.3773 .03281 L
.41731 .04547 L
.45831 .05868 L
.46906 .06267 L
.48072 .06803 L
.50188 .08071 L
.51174 .08319 L
.51728 .08514 L
.52234 .08724 L
.53397 .09303 L
.54484 .09931 L
.58622 .125 L
Mistroke
.62797 .15267 L
.66812 .18455 L
.71086 .2219 L
.752 .26279 L
.79571 .31148 L
.83784 .36332 L
.87837 .41903 L
.92148 .48341 L
.963 .55203 L
1 .61803 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool005=oo`<000Ioo`8000Aoo`D002Moo`<000Ioo`8000Ioo`<002Qoo`<000Ioo`8000Eoo`<002Qo
o`<000Ioo`8000Eoo`<0035oo`D001Yoo`00DWoo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo
000VOol01@00Oomoogoo00001Goo0P001goo00<007ooOol09Woo00D007ooOomoo`0000Eoo`8000Ao
o`05001oogooOol0000VOol01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00039oo`03001o
ogoo01Yoo`00DWoo00D007ooOomoo`0000eoo`03001oogoo02Ioo`05001oogooOol0000;Ool5000W
Ool01@00Oomoogoo00002goo00D007ooOomoo`0002Ioo`05001oogooOol0000;Ool01@00Oomoogoo
0000<Woo00<007ooOol06Woo001BOol01@00Oomoogoo00003Woo00<007ooOol09Goo00D007ooOomo
o`0000]oo`04001oogoo000XOol01@00Oomoogoo00002goo00D007ooOomoo`0002Ioo`05001oogoo
Ool0000;Ool01@00Oomoogoo0000<Woo00<007ooOol06Woo001BOol01@00Oomoogoo00003goo00<0
07ooOol097oo00D007ooOomoo`0000aoo`03001oo`0002Qoo`05001oogooOol0000;Ool4000WOol0
1@00Oomoogoo000037oo0`00<goo00<007ooOol06Woo001BOol01@00Oomoogoo00003goo00<007oo
Ool097oo00D007ooOomoo`0000aoo`03001oo`0002Qoo`05001oogooOol0000;Ool00`00Oomoo`0X
Ool01@00Oomoogoo00002goo00D007ooOomoo`00039oo`03001oogoo01Yoo`00DWoo00D007ooOomo
o`0000]oo`05001oogooOol0000VOol01@00Oomoogoo00003Goo0P00:7oo00D007ooOomoo`0000ao
o`03001oogoo02Moo`05001oogooOol0000;Ool01@00Oomoogoo0000<Woo00<007ooOol06Woo001C
Ool3000=Ool3000XOol3000?Ool00`00Oomoo`0WOol3000>Ool3000WOol3000=Ool3000aOol3000L
Ool00?moofUoo`00ogooJGoo003oOomGOol20002Ool2000<Ool00?mooeQoo`04001oogoo000=Ool0
0?mooeUoo`8000ioo`0087ooo`00;@0037oo0P003Woo000POoln000>Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00
Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00
Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`09Ool01000
Oomoo`003Goo000QOol00`00Oomoo`0POolS000aOol00`00Oomoo`0iOol00`00Oomoo`0hOol00`00
Oomoo`0iOol00`00Oomoo`08Ool20002Ool2000<Ool0025oo`03001oogoo03Uooa<00?Qoo`008Goo
00<007ooOol0@Woo4000lWoo000QOol00`00Oomoo`1;Ool=003/Ool0025oo`03001oogoo055oo`h0
0>Eoo`008Goo00<007ooOol0Egoo3`00gWoo000QOol00`00Oomoo`1NOol=003IOol0025oo`8006Io
o`T00=Ioo`008Goo00<007ooOol0JWoo1`00dgoo000QOol00`00Oomoo`1]Ool7003@Ool0025oo`03
001oogoo071oo`L00<eoo`008Goo00<007ooOol0Lgoo1`00bWoo000QOol00`00Oomoo`1fOol70037
Ool0025oo`03001oogoo07Uoo`L00<Aoo`008Goo00<007ooOol0O7oo1`00`Goo000QOol00`00Oomo
o`1oOol7002nOol0025oo`8008=oo`L00;]oo`008Goo00<007ooOol0QGoo1`00^7oo000QOol00`00
Oomoo`28Ool6002fOol0025oo`03001oogoo08]oo`D00;Aoo`008Goo00<007ooOol0SGoo1000/goo
000QOol00`00Oomoo`2?Ool4002aOol0025oo`03001oogoo091oo`H00:ioo`008Goo00<007ooOol0
TWoo1`00Zgoo000QOol00`00Oomoo`2EOol6002YOol0025oo`03001oogoo09Qoo`@00:Qoo`008Goo
0P00Vgoo1000YWoo000QOol00`00Oomoo`2KOol4002UOol0025oo`03001oogoo09eoo`@00:=oo`00
8Goo00<007ooOol0WWoo1@00XGoo000QOol00`00Oomoo`2POol5002OOol0025oo`03001oogoo0:9o
o`D009eoo`0027oo0`001Woo0P0017oo1@001Goo00<007ooOol0Y7oo1000W7oo0007Ool01@00Oomo
ogoo00001Goo0P001Goo00@007ooOol000Eoo`03001oogoo0:Ioo`@009Yoo`001goo00D007ooOomo
o`0000eoo`03001oogoo00Eoo`03001oogoo0:Moo`D009Qoo`001goo00D007ooOomoo`0000ioo`03
001oogoo00Aoo`<00:Uoo`D009Ioo`001goo00D007ooOomoo`0000moo`03001oogoo00=oo`03001o
ogoo0:]oo`@009Eoo`001goo00D007ooOomoo`0000moo`03001oogoo00=oo`03001oogoo0:eoo`<0
09Aoo`001goo00D007ooOomoo`0000]oo`05001oogooOol00005Ool00`00Oomoo`2^Ool4002BOol0
00Qoo`<000eoo`<000Ioo`03001oogoo0:moo`@0095oo`008Goo00<007ooOol0/Goo0`00T7oo000Q
Ool00`00Oomoo`2bOol4002>Ool0025oo`03001oogoo0;=oo`@008eoo`008Goo00<007ooOol0]Goo
0`00S7oo000QOol2002gOol4002:Ool0025oo`03001oogoo0;Moo`@008Uoo`008Goo00<007ooOol0
^Goo0`00R7oo000QOol00`00Oomoo`2jOol40026Ool0025oo`03001oogoo0;]oo`@008Eoo`008Goo
00<007ooOol0_Goo0`00Q7oo000QOol00`00Oomoo`2nOol40022Ool0025oo`03001oogoo0;moo`@0
085oo`008Goo00<007ooOol0`Goo0`00P7oo000QOol20033Ool4001nOol0025oo`03001oogoo0<=o
o`@007eoo`008Goo00<007ooOol0aGoo0`00O7oo000QOol00`00Oomoo`36Ool3001kOol0025oo`03
001oogoo0<Moo`<007Yoo`008Goo00<007ooOol0b7oo1000N7oo000QOol00`00Oomoo`39Ool4001g
Ool0025oo`03001oogoo0<]oo`<007Ioo`008Goo00<007ooOol0c7oo0`00MGoo000QOol2003>Ool3
001dOol0025oo`03001oogoo0<ioo`<007=oo`008Goo00<007ooOol0cgoo0`00LWoo000QOol00`00
Oomoo`3@Ool3001aOol0025oo`03001oogoo0=5oo`<0071oo`008Goo00<007ooOol0dWoo0`00Kgoo
000QOol00`00Oomoo`3COol3001^Ool000Qoo`<000Ioo`8000Ioo`<000Eoo`03001oogoo0=Aoo`<0
06eoo`001goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo00Aoo`03001oogoo0=Eoo`<006ao
o`001goo00D007ooOomoo`0000]oo`D000Eoo`03001oogoo0=Ioo`<006]oo`001goo00D007ooOomo
o`0000]oo`04001oogoo0006Ool3003GOol3001ZOol000Moo`05001oogooOol0000<Ool00`00Ool0
0006Ool00`00Oomoo`3HOol3001YOol000Moo`05001oogooOol0000<Ool00`00Ool00006Ool00`00
Oomoo`3IOol3001XOol000Moo`05001oogooOol0000=Ool20006Ool00`00Oomoo`3JOol3001WOol0
00Qoo`<000moo`03001oogoo00Aoo`03001oogoo0=]oo`<006Ioo`008Goo00<007ooOol0g7oo0P00
IWoo000QOol00`00Oomoo`3LOol3001UOol0025oo`03001oogoo0=eoo`<006Aoo`008Goo00<007oo
Ool0gWoo0`00Hgoo000QOol2003POol3001ROol0025oo`03001oogoo0>1oo`<0065oo`008Goo00<0
07ooOol0hGoo0`00H7oo000QOol00`00Oomoo`3ROol3001OOol0025oo`03001oogoo0>=oo`8005mo
o`008Goo00<007ooOol0hgoo0`00GWoo000QOol00`00Oomoo`3TOol3001MOol0025oo`03001oogoo
0>Eoo`<005aoo`008Goo00<007ooOol0iWoo0`00Fgoo000QOol2003XOol3001JOol0025oo`03001o
ogoo0>Qoo`<005Uoo`008Goo00<007ooOol0jGoo0P00FGoo000QOol00`00Oomoo`3YOol3001HOol0
025oo`03001oogoo0>Yoo`<005Moo`008Goo00<007ooOol0jgoo0`00EWoo000QOol00`00Oomoo`3/
Ool3001EOol0025oo`03001oogoo0>eoo`<005Aoo`008Goo00<007ooOol0kWoo0`00Dgoo000QOol2
003`Ool3001BOol0025oo`03001oogoo0?1oo`80059oo`008Goo00<007ooOol0l7oo0`00DGoo000Q
Ool00`00Oomoo`3aOol3001@Ool0025oo`03001oogoo0?9oo`<004moo`008Goo00<007ooOol0lgoo
0`00CWoo000QOol00`00Oomoo`3dOol3001=Ool000Qoo`<000Ioo`8000Eoo`<000Ioo`03001oogoo
0?Eoo`<004aoo`001goo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol00005Ool00`00Oomo
o`3fOol2001<Ool000Moo`05001oogooOol0000;Ool01@00Oomoogoo00001Goo0`00mWoo0`00Bgoo
0007Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Eoo`03001oogoo0?Moo`<004Yoo`001goo
00D007ooOomoo`0000]oo`@000Ioo`03001oogoo0?Qoo`8004Yoo`001goo00D007ooOomoo`0000]o
o`03001oogoo00Moo`03001oogoo0?Qoo`<004Uoo`001goo00D007ooOomoo`0000aoo`03001oogoo
00Ioo`03001oogoo0?Uoo`<004Qoo`0027oo0`003Woo0`001Goo00<007ooOol0nWoo0`00Agoo000Q
Ool00`00Oomoo`3kOol20017Ool0025oo`03001oogoo0?]oo`<004Ioo`008Goo00<007ooOol0o7oo
0`00AGoo000QOol00`00Oomoo`3mOol20015Ool0025oo`800?ioo`<004Aoo`008Goo00<007ooOol0
oWoo0`00@goo000QOol00`00Oomoo`3oOol30012Ool0025oo`03001oogoo0?moo`5oo`80049oo`00
8Goo00<007ooOol0ogoo0Goo0`00@Goo000QOol00`00Oomoo`3oOol2Ool30010Ool0025oo`03001o
ogoo0?moo`=oo`80041oo`008Goo00<007ooOol0ogoo0goo0`00?goo000QOol00`00Oomoo`3oOol4
Ool3000nOol0025oo`800?moo`Ioo`8003ioo`008Goo00<007ooOol0ogoo1Goo0`00?Goo000QOol0
0`00Oomoo`3oOol6Ool3000lOol0025oo`03001oogoo0?moo`Moo`8003aoo`008Goo00<007ooOol0
ogoo1goo0`00>goo000QOol00`00Oomoo`3oOol8Ool3000jOol0025oo`03001oogoo0?moo`Uoo`<0
03Uoo`008Goo00<007ooOol0ogoo2Woo0P00>Goo000QOol00`00Oomoo`3oOol:Ool3000hOol0025o
o`800?moo`aoo`<003Moo`008Goo00<007ooOol0ogoo37oo0P00=goo000QOol00`00Oomoo`3oOol<
Ool3000fOol0025oo`03001oogoo0?moo`eoo`<003Eoo`008Goo00<007ooOol0ogoo3Woo0P00=Goo
000QOol00`00Oomoo`3oOol>Ool3000dOol0025oo`03001oogoo0?moo`moo`<003=oo`0027oo0`00
1Woo0P001Goo0`001Woo00<007ooOol0ogoo47oo0P00<goo0007Ool01@00Oomoogoo00001Goo0P00
17oo00D007ooOomoo`0000Eoo`03001oogoo0?mooa1oo`<0039oo`001goo00D007ooOomoo`0000]o
o`05001oogooOol00005Ool3003oOolAOol3000aOol000Moo`05001oogooOol0000;Ool01@00Oomo
ogoo00001Goo00<007ooOol0ogoo4Woo0P00<Goo0007Ool01@00Oomoogoo000037oo0`001Woo00<0
07ooOol0ogoo4Woo0`00<7oo0007Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Eoo`03001o
ogoo0?mooa=oo`80031oo`001goo00D007ooOomoo`0000]oo`05001oogooOol00005Ool00`00Oomo
o`3oOolCOol3000_Ool000Qoo`<000eoo`<000Ioo`03001oogoo0?mooaAoo`<002ioo`008Goo00<0
07ooOol0ogoo5Goo0P00;Woo000QOol00`00Oomoo`3oOolEOol3000]Ool0025oo`03001oogoo0?mo
oaIoo`8002eoo`008Goo0P00ogoo5goo0`00;7oo000QOol00`00Oomoo`3oOolGOol3000[Ool0025o
o`03001oogoo0?mooaQoo`8002]oo`008Goo00<007ooOol0ogoo67oo0`00:Woo000QOol00`00Oomo
o`3oOolIOol2000ZOol0025oo`03001oogoo0?mooaUoo`<002Uoo`008Goo00<007ooOol0ogoo6Woo
0`00:7oo000QOol00`00Oomoo`3oOolKOol2000XOol0025oo`03001oogoo0?mooa]oo`<002Moo`00
8Goo00<007ooOol0ogoo77oo0P009goo000QOol2003oOolMOol3000VOol0025oo`03001oogoo0?mo
oaeoo`8002Ioo`008Goo00<007ooOol0ogoo7Goo0`009Goo000QOol00`00Oomoo`3oOolNOol2000U
Ool0025oo`03001oogoo0?mooaioo`<002Aoo`008Goo00<007ooOol0ogoo7goo0`008goo000QOol0
0`00Oomoo`3oOolPOol2000SOol0025oo`03001oogoo0?moob1oo`<0029oo`008Goo00<007ooOol0
ogoo8Goo0P008Woo000QOol2003oOolROol3000QOol0025oo`03001oogoo0?moob9oo`80025oo`00
8Goo00<007ooOol0ogoo8Woo0`0087oo000QOol00`00Oomoo`3oOolSOol2000POol0025oo`03001o
ogoo0?moob=oo`<001moo`008Goo00<007ooOol0ogoo97oo0`007Woo000QOol00`00Oomoo`3oOolU
Ool2000NOol001Qoo`D000Aoo`03001oogoo0?moobEoo`<001eoo`006Woo00<007ooOol017oo00<0
07ooOol0ogoo9Woo0P007Goo000JOol00`00Oomoo`04Ool3003oOolVOol3000LOol001Yoo`03001o
ogoo0?moobioo`8001aoo`006Woo00<007ooOol0ogooC7oo000JOol00`00Oomoo`3oOom<Ool001Yo
o`03001oogoo0?moodaoo`0067oo0`00ogooCWoo003oOomYOol00?moofUoo`00ogooJGoo002VOol3
000JOol3002ROol00:Eoo`05001oogooOol00009Ool60009Ool01@00Oomoogoo0000XGoo002UOol0
0`00Oomoo`0JOol01@00Oomoogoo0000XGoo000OOol50021Ool00`00Oomoo`0;Ool60009Ool01@00
Oomoogoo0000XGoo000QOol00`00Oomoo`21Ool00`00Oomoo`0JOol01@00Oomoogoo0000XGoo000Q
Ool00`00Oomoo`1oOol6000IOol01@00Oomoogoo0000XGoo000QOol00`00Oomoo`21Ool00`00Oomo
o`0JOol01@00Oomoogoo0000XGoo000QOol00`00Oomoo`21Ool00`00Oomoo`0KOol3002ROol001io
o`04001oogoo0002Ool00`00Oomoo`3oOom2Ool001ioo`04001oogoo0002Ool00`00Oomoo`3oOom2
Ool001ioo`L00?moodAoo`00ogooJGoo003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .00338 L
.08481 .00746 L
.12636 .01207 L
.16632 .0176 L
.20885 .02512 L
.2498 .03439 L
.29331 .047 L
.33524 .06238 L
.37557 .08069 L
.41848 .10445 L
.4598 .13197 L
.48055 .14763 L
.48962 .15488 L
.49442 .15881 L
.49705 .16099 L
.49834 .16207 L
.49953 .16307 L
.50089 .16367 L
.50161 .16384 L
.50237 .16401 L
.50495 .16462 L
.50998 .16587 L
.51991 .16857 L
.54183 .1756 L
.5817 .19226 L
.62415 .2155 L
.665 .24315 L
.70843 .278 L
.75027 .31658 L
.79051 .35791 L
.83333 .40589 L
.87456 .45538 L
.9142 .50532 L
.95642 .56029 L
.99704 .6141 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<?ooool4o`000003oa0@4?oooooooooo01Sooooo001Booooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<_ooool00ol0003oooooooooo`0Jooooo`00D_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Ko
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool0
0ol0003oooooooooo`0Jooooo`00D_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Voooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03;ooooo00?o
0000ooooooooool06_ooool005;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Gooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03o`00
0?oooooooooo01[ooooo001Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Tooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Xooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03;ooooo00?o0000ooooooooool06_oo
ool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000booooo`03o`000?oooooooooo01[ooooo001B
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Looooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomGooooo`;o00000_ooool2o`0000cooooo003ooooooeOo
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`00oooooomHooooo`04omgMgOl0003o410@
olc<c0gooooo000Poooooooo0000;Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kPgooooo000Poooo
oaGo00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo000Qoooo
o`03o`000?oooooooooo00?ooooo6?l0000Nooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool02?ooool2o`0000;ooooo0_l0000<ooooo`008Oooool00ol0003oooooooooo`0@oooooa7o
0000oooooolTooooo`008Oooool00ol0003oooooooooo`0Joooooa3o0000oooooolKooooo`008Ooo
ool00ol0003oooooooooo`0Poooooa;o0000oooooolCooooo`008Oooool00ol0003oooooooooo`0Y
ooooo`go0000ooooool?ooooo`008Oooool00ol0003oooooooooo`0aooooo`Wo0000ooooool;oooo
o`008Oooool00ol0003oooooooooo`0eooooo`[o0000ooooool6ooooo`008Oooool2o`0003[ooooo
3Ol0003nooooo`008Oooool00ol0003oooooooooo`0nooooo`go0000nOooool0027ooooo00?o0000
ooooooooool0AOooool9o`000?Kooooo000Qooooo`03o`000?oooooooooo04[ooooo1ol0003coooo
o`008Oooool00ol0003oooooooooo`1=ooooo`Oo0000l?ooool0027ooooo00?o0000ooooooooool0
D?ooool7o`000>gooooo000Qooooo`03o`000?oooooooooo05?ooooo1ol0003Zooooo`008Oooool0
0ol0003oooooooooo`1Fooooo`Ko0000j?ooool0027ooooo00?o0000ooooooooool0FOooool5o`00
0>Kooooo000Qooooo`;o0000G?ooool6o`000>?ooooo000Qooooo`03o`000?oooooooooo05gooooo
1_l0003Qooooo`008Oooool00ol0003oooooooooo`1Pooooo`Ko0000g_ooool0027ooooo00?o0000
ooooooooool0H_ooool6o`000=cooooo000Qooooo`03o`000?oooooooooo06Gooooo1Ol0003Joooo
o`008Oooool00ol0003oooooooooo`1Wooooo`Ko0000eoooool0027ooooo00?o0000ooooooooool0
JOooool6o`000=Gooooo000Qooooo`03o`000?oooooooooo06cooooo1Ol0003Cooooo`008Oooool0
0ol0003oooooooooo`1^ooooo`Go0000dOooool0027ooooo00?o0000ooooooooool0L?ooool5o`00
0<oooooo000Qooooo`;o0000Loooool4o`000<kooooo000Qooooo`03o`000?oooooooooo07Cooooo
1?l0003<ooooo`008Oooool00ol0003oooooooooo`1eooooo`Go0000b_ooool0027ooooo00?o0000
ooooooooool0Moooool5o`000<Sooooo000Qooooo`03o`000?oooooooooo07Wooooo1?l00037oooo
o`008Oooool00ol0003oooooooooo`1kooooo`Co0000aOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0O?ooool4o`000<Co
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`03o`000?oooooooooo07kooooo1?l00032ooooo`001oooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`1ooooo
o`Co0000`Oooool000Oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Gooooo0ol00021ooooo`Co0000_oooool000Oooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0P_ooool4o`000;kooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
08Cooooo1?l0002looooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo08Gooooo1?l0002kooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oo
oooooooo08Oooooo0ol0002jooooo`008Oooool00ol0003oooooooooo`28ooooo`?o0000^Oooool0
027ooooo00?o0000ooooooooool0ROooool3o`000;Sooooo000Qooooo`03o`000?oooooooooo08[o
oooo1?l0002fooooo`008Oooool00ol0003oooooooooo`2;ooooo`Co0000]Oooool0027ooooo0_l0
002>ooooo`?o0000]?ooool0027ooooo00?o0000ooooooooool0S_ooool3o`000;?ooooo000Qoooo
o`03o`000?oooooooooo08oooooo1?l0002aooooo`008Oooool00ol0003oooooooooo`2@ooooo`So
0000[?ooool0027ooooo00?o0000ooooooooool0TOooool:o`000:Wooooo000Qooooo`03o`000?oo
oooooooo09Oooooo1ol0002Vooooo`008Oooool00ol0003oooooooooo`2Jooooo`Oo0000Xoooool0
027ooooo00?o0000ooooooooool0WOooool6o`000:7ooooo000Qooooo`03o`000?oooooooooo0:3o
oooo1_l0002Nooooo`008Oooool2o`000:?ooooo1_l0002Looooo`008Oooool00ol0003ooooooooo
o`2Uooooo`Go0000V_ooool0027ooooo00?o0000ooooooooool0Yoooool5o`0009Sooooo000Qoooo
o`03o`000?oooooooooo0:Wooooo1Ol0002Fooooo`008Oooool00ol0003oooooooooo`2[ooooo`Go
0000U?ooool0027ooooo00?o0000ooooooooool0[Oooool5o`0009;ooooo000Qooooo`03o`000?oo
oooooooo0:oooooo1?l0002Aooooo`008Oooool00ol0003oooooooooo`2aooooo`Co0000Soooool0
027ooooo00?o0000ooooooooool0/_ooool5o`0008gooooo000Qooooo`;o0000]Oooool5o`0008_o
oooo000Qooooo`03o`000?oooooooooo0;Kooooo1?l0002:ooooo`008Oooool00ol0003ooooooooo
o`2hooooo`Co0000R?ooool0027ooooo00?o0000ooooooooool0^Oooool4o`0008Oooooo000Qoooo
o`03o`000?oooooooooo0;_ooooo1?l00025ooooo`008Oooool00ol0003oooooooooo`2looooo`Co
0000Q?ooool0027ooooo00?o0000ooooooooool0__ooool4o`0008;ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo0;oooooo1?l00021ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0`Oooool4o`0007oooooo
0007ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000ooooooooool0
`_ooool4o`0007kooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgM
ooooool00006ooooo`?o0000a?ooool3o`0007gooooo0007ooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo0<Gooooo0ol0001loooo
o`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0
003oooooooooo`36ooooo`?o0000Noooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0aoooool4o`0007Wooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo
0<Sooooo1?l0001hooooo`008Oooool00ol0003oooooooooo`3:ooooo`?o0000Moooool0027ooooo
00?o0000ooooooooool0boooool3o`0007Kooooo000Qooooo`03o`000?oooooooooo0<cooooo0ol0
001eooooo`008Oooool00ol0003oooooooooo`3=ooooo`?o0000M?ooool0027ooooo0_l0003?oooo
o`Co0000L_ooool0027ooooo00?o0000ooooooooool0coooool4o`00077ooooo000Qooooo`03o`00
0?oooooooooo0=7ooooo0ol0001`ooooo`008Oooool00ol0003oooooooooo`3Booooo`?o0000Kooo
ool0027ooooo00?o0000ooooooooool0doooool3o`0006kooooo000Qooooo`03o`000?oooooooooo
0=Cooooo1?l0001/ooooo`008Oooool00ol0003oooooooooo`3Eooooo`Co0000Joooool0027ooooo
00?o0000ooooooooool0eoooool3o`0006[ooooo000Qooooo`03o`000?oooooooooo0=Sooooo0ol0
001Yooooo`008Oooool2o`000=[ooooo0ol0001Xooooo`008Oooool00ol0003oooooooooo`3Joooo
o`?o0000Ioooool0027ooooo00?o0000ooooooooool0foooool3o`0006Kooooo000Qooooo`03o`00
0?oooooooooo0=cooooo0_l0001Vooooo`008Oooool00ol0003oooooooooo`3Looooo`?o0000IOoo
ool0027ooooo00?o0000ooooooooool0gOooool3o`0006Cooooo000Qooooo`03o`000?oooooooooo
0=kooooo0ol0001Sooooo`008Oooool00ol0003oooooooooo`3Oooooo`?o0000H_ooool0027ooooo
00?o0000ooooooooool0h?ooool3o`00067ooooo000Qooooo`;o0000h_ooool3o`00063ooooo000Q
ooooo`03o`000?oooooooooo0>;ooooo0ol0001Oooooo`008Oooool00ol0003oooooooooo`3Soooo
o`?o0000G_ooool0027ooooo00?o0000ooooooooool0i?ooool3o`0005gooooo000Qooooo`03o`00
0?oooooooooo0>Gooooo0ol0001Looooo`008Oooool00ol0003oooooooooo`3Vooooo`?o0000Fooo
ool0027ooooo00?o0000ooooooooool0ioooool3o`0005[ooooo0007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oo
oooooooo0>Sooooo0_l0001Jooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3Xooooo`?o0000
FOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00001Oooool3o`000>Wooooo0ol0001Hooooo`001oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0>[ooooo0ol0001Goooo
o`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c005
ooooo`03o`000?oooooooooo0>_ooooo0ol0001Fooooo`001oooool01Ol@413ooooooooooooooooo
410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`3/ooooo`?o0000EOooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000
ooooooooool0kOooool3o`0005Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
1?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo0>kooooo0_l0001Dooooo`008Oooool0
0ol0003oooooooooo`3^ooooo`?o0000Doooool0027ooooo00?o0000ooooooooool0koooool3o`00
05;ooooo000Qooooo`03o`000?oooooooooo0?3ooooo0ol0001Aooooo`008Oooool00ol0003ooooo
ooooo`3aooooo`?o0000D?ooool0027ooooo0_l0003cooooo`?o0000Coooool0027ooooo00?o0000
ooooooooool0loooool3o`0004kooooo000Qooooo`03o`000?oooooooooo0?Cooooo0_l0001>oooo
o`008Oooool00ol0003oooooooooo`3dooooo`?o0000COooool0027ooooo00?o0000ooooooooool0
mOooool3o`0004cooooo000Qooooo`03o`000?oooooooooo0?Kooooo0ol0001;ooooo`008Oooool0
0ol0003oooooooooo`3gooooo`?o0000B_ooool0027ooooo00?o0000ooooooooool0n?ooool3o`00
04Wooooo000Qooooo`03o`000?oooooooooo0?Wooooo0ol00018ooooo`008Oooool2o`000?_ooooo
0ol00017ooooo`008Oooool00ol0003oooooooooo`3kooooo`;o0000Aoooool0027ooooo00?o0000
ooooooooool0noooool3o`0004Kooooo000Qooooo`03o`000?oooooooooo0?cooooo0ol00015oooo
o`008Oooool00ol0003oooooooooo`3mooooo`?o0000A?ooool0027ooooo00?o0000ooooooooool0
o_ooool3o`0004?ooooo000Qooooo`03o`000?oooooooooo0?oooooo0ol00012ooooo`008Oooool0
0ol0003oooooooooo`3oooooo`7ooooo0ol00011ooooo`008Oooool00ol0003oooooooooo`3ooooo
o`;ooooo0_l00011ooooo`008Oooool2o`000?oooooo0oooool3o`00043ooooo000Qooooo`03o`00
0?oooooooooo0?oooooo0oooool3o`0003oooooo000Qooooo`03o`000?oooooooooo0?oooooo1?oo
ool3o`0003kooooo000Qooooo`03o`000?oooooooooo0?oooooo1Oooool2o`0003kooooo000Qoooo
o`03o`000?oooooooooo0?oooooo1Oooool3o`0003gooooo000Qooooo`03o`000?oooooooooo0?oo
oooo1_ooool3o`0003cooooo000Qooooo`03o`000?oooooooooo0?oooooo1oooool3o`0003_ooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c005ooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003_ooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05oooo
o`03o`000?oooooooooo0?oooooo2?ooool3o`0003[ooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0003oooooo`Wooooo0ol0000i
ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P05ooooo`03o`000?oooooooooo0?oooooo2_ooool2o`0003Wooooo0007ooooo`05o`000?oooooo
ooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000ooooooooool0
ooooool:ooooo`?o0000>?ooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001Oooool00ol0003oooooooooo`3oooooo`_ooooo0ol0000gooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000005oooo
o`03o`000?oooooooooo0?oooooo3?ooool3o`0003Kooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0ooooool=
ooooo`;o0000=_ooool0027ooooo00?o0000ooooooooool0ooooool=ooooo`?o0000=Oooool0027o
oooo00?o0000ooooooooool0ooooool>ooooo`?o0000=?ooool0027ooooo00?o0000ooooooooool0
ooooool?ooooo`?o0000<oooool0027ooooo0_l0003ooooooa7ooooo0ol0000booooo`008Oooool0
0ol0003oooooooooo`3ooooooa7ooooo0_l0000booooo`008Oooool00ol0003oooooooooo`3ooooo
oa7ooooo0ol0000aooooo`008Oooool00ol0003oooooooooo`3ooooooa;ooooo0ol0000`ooooo`00
8Oooool00ol0003oooooooooo`3ooooooa?ooooo0ol0000_ooooo`008Oooool00ol0003ooooooooo
o`3ooooooaCooooo0ol0000^ooooo`008Oooool00ol0003oooooooooo`3ooooooaGooooo0ol0000]
ooooo`008Oooool00ol0003oooooooooo`3ooooooaKooooo0_l0000]ooooo`008Oooool00ol0003o
ooooooooo`3ooooooaKooooo0ol0000/ooooo`008Oooool00ol0003oooooooooo`3ooooooaOooooo
0ol0000[ooooo`008Oooool2o`000?oooooo6Oooool3o`0002[ooooo000Qooooo`03o`000?oooooo
oooo0?oooooo6Oooool3o`0002Wooooo000Qooooo`03o`000?oooooooooo0?oooooo6_ooool2o`00
02Wooooo000Qooooo`03o`000?oooooooooo0?oooooo6_ooool3o`0002Sooooo000Qooooo`03o`00
0?oooooooooo0?oooooo6oooool3o`0002Oooooo000Qooooo`03o`000?oooooooooo0?oooooo7?oo
ool3o`0002Kooooo000Qooooo`03o`000?oooooooooo0?oooooo7Oooool2o`0002Kooooo000Qoooo
o`03o`000?oooooooooo0?oooooo7Oooool3o`0002Gooooo000Qooooo`03o`000?oooooooooo0?oo
oooo7_ooool3o`0002Cooooo000Qooooo`;o0000oooooolPooooo`?o00008oooool0027ooooo00?o
0000ooooooooool0oooooolPooooo`;o00008oooool0027ooooo00?o0000ooooooooool0oooooolP
ooooo`?o00008_ooool0027ooooo00?o0000ooooooooool0oooooolQooooo`?o00008Oooool0027o
oooo00?o0000ooooooooool0oooooolRooooo`?o00008?ooool0027ooooo00?o0000ooooooooool0
oooooolSooooo`;o00008?ooool0027ooooo00?o0000ooooooooool0oooooolSooooo`?o00007ooo
ool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo9?ooool3
o`0001kooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolUoooo
o`?o00007Oooool001[ooooo00?o0000ooooooooool01?ooool3o`000?oooooo9_ooool3o`0001co
oooo000Jooooo`03o`000?oooooooooo0?oooooo;_ooool2o`0001cooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Hooooo`03oeEEEOmVIVKo00000?ooooooC_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool009[ooooo00GoV9RHo`000?l0003oA4A4okZj^P0H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`Go0000U?ooool009[ooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
2Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OnHV9So8B4Qonk^k_ooooooA4A409Cooooo002Jooooo`03o`000?oooooooooo
01[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?oo
ool00onHV9So8B4Qonk^kP2Eooooo`007oooool01Ol@413o0000o`000?l0003o410@07Kooooo00?o
0000ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001Oooool00onHV9So8B4Qonk^kP2Dooooo`008Oooool00ol0003ooooo
ooooo`1fooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`2Cooooo`008Oooool00ol0003o
ooooooooo`1dooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo09;ooooo000Qoooo
o`03o`000?oooooooooo07Kooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooooiRHV?l@4100
U?ooool0027ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c02Dooooo`007_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
0?oooooo@_ooool001kooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`3ooooo
od;ooooo000Nooooo`Oo0000oooooom4ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .00801 L
.08481 .01721 L
.12636 .02674 L
.16632 .03712 L
.20885 .04991 L
.2498 .06431 L
.29331 .08231 L
.33524 .10268 L
.37557 .12542 L
.41848 .15331 L
.4598 .18406 L
.48055 .201 L
.48962 .20873 L
.49442 .2129 L
.49705 .21521 L
.49834 .21635 L
.49953 .2174 L
.50089 .21806 L
.50161 .21826 L
.50237 .21847 L
.50495 .21919 L
.50998 .22064 L
.51991 .22369 L
.54183 .23127 L
.5817 .24813 L
.62415 .27038 L
.665 .29591 L
.70843 .32727 L
.75027 .36131 L
.79051 .39727 L
.83333 .43855 L
.87456 .48075 L
.9142 .52307 L
.95642 .56943 L
.99704 .61472 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<?ooool4o`000003oa0@4?oooooooooo01Sooooo001Booooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<_ooool00ol0003oooooooooo`0Jooooo`00D_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Ko
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool0
0ol0003oooooooooo`0Jooooo`00D_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Voooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03;ooooo00?o
0000ooooooooool06_ooool005;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Gooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03o`00
0?oooooooooo01[ooooo001Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Tooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Xooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03;ooooo00?o0000ooooooooool06_oo
ool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000booooo`03o`000?oooooooooo01[ooooo001B
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Looooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomGooooo`;o00000_ooool2o`0000cooooo003ooooooeOo
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`00oooooomHooooo`04omgMgOl0003o410@
olc<c0gooooo000Poooooooo0000;Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kPgooooo000Poooo
o`_o00001Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMg
MomgMgOo<S8b3Oooool0027ooooo00?o0000ooooooooool03?l0000]ooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02?ooool2o`0000;ooooo0_l0000<ooooo`008Oooool00ol0003o
ooooooooo`06ooooo`_o0000ooooooldooooo`008Oooool00ol0003oooooooooo`0;ooooo`_o0000
ooooool_ooooo`008Oooool00ol0003oooooooooo`0@ooooo`[o0000ooooool[ooooo`008Oooool0
0ol0003oooooooooo`0Eooooo`Wo0000oooooolWooooo`008Oooool00ol0003oooooooooo`0Ioooo
o`Wo0000oooooolSooooo`008Oooool00ol0003oooooooooo`0Mooooo`Wo0000oooooolOooooo`00
8Oooool2o`0002;ooooo2Ol0003ooooooa_ooooo000Qooooo`03o`000?oooooooooo02Gooooo2Ol0
003ooooooaOooooo000Qooooo`03o`000?oooooooooo02Wooooo2Ol0003ooooooa?ooooo000Qoooo
o`03o`000?oooooooooo02gooooo2?l0003ooooooa3ooooo000Qooooo`03o`000?oooooooooo037o
oooo1ol0003oooooo`gooooo000Qooooo`03o`000?oooooooooo03Cooooo1ol0003oooooo`[ooooo
000Qooooo`03o`000?oooooooooo03Oooooo1ol0003oooooo`Oooooo000Qooooo`03o`000?oooooo
oooo03[ooooo1ol0003oooooo`Cooooo000Qooooo`03o`000?oooooooooo03gooooo1ol0003ooooo
o`7ooooo000Qooooo`;o0000@Oooool7o`000?gooooo000Qooooo`03o`000?oooooooooo04?ooooo
1ol0003jooooo`008Oooool00ol0003oooooooooo`16ooooo`Ko0000n?ooool0027ooooo00?o0000
ooooooooool0BOooool5o`000?Kooooo000Qooooo`03o`000?oooooooooo04_ooooo1_l0003coooo
o`008Oooool00ol0003oooooooooo`1=ooooo`Ko0000lOooool0027ooooo00?o0000ooooooooool0
D?ooool5o`000>oooooo000Qooooo`03o`000?oooooooooo05;ooooo1Ol0003]ooooo`008Oooool0
0ol0003oooooooooo`1Dooooo`Go0000joooool0027ooooo00?o0000ooooooooool0E_ooool5o`00
0>Wooooo000Qooooo`;o0000FOooool5o`000>Oooooo000Qooooo`03o`000?oooooooooo05[ooooo
1Ol0003Uooooo`008Oooool00ol0003oooooooooo`1Looooo`Go0000hoooool0027ooooo00?o0000
ooooooooool0G_ooool5o`000>7ooooo000Qooooo`03o`000?oooooooooo063ooooo1Ol0003Ooooo
o`008Oooool00ol0003oooooooooo`1Rooooo`Go0000gOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0I?ooool5o`000=_o
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`03o`000?oooooooooo06Kooooo1Ol0003Iooooo`001oooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`1Xoooo
o`Go0000eoooool000Oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Gooooo0ol0001Zooooo`Go0000eOooool000Oooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0K?ooool4o`000=Cooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
06kooooo1?l0003Booooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo06oooooo1?l0003Aooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oo
oooooooo077ooooo1?l0003?ooooo`008Oooool00ol0003oooooooooo`1booooo`Co0000c_ooool0
027ooooo00?o0000ooooooooool0M?ooool3o`000<gooooo000Qooooo`03o`000?oooooooooo07Go
oooo1?l0003;ooooo`008Oooool00ol0003oooooooooo`1fooooo`Co0000b_ooool0027ooooo0_l0
001iooooo`Co0000b?ooool0027ooooo00?o0000ooooooooool0NOooool4o`000<Oooooo000Qoooo
o`03o`000?oooooooooo07_ooooo0ol00036ooooo`008Oooool00ol0003oooooooooo`1looooo`Co
0000a?ooool0027ooooo00?o0000ooooooooool0OOooool4o`000<?ooooo000Qooooo`03o`000?oo
oooooooo07oooooo0ol00032ooooo`008Oooool00ol0003oooooooooo`20ooooo`Co0000`?ooool0
027ooooo00?o0000ooooooooool0POooool4o`000;oooooo000Qooooo`03o`000?oooooooooo08?o
oooo0ol0002nooooo`008Oooool2o`0008Gooooo1?l0002looooo`008Oooool00ol0003ooooooooo
o`25ooooo`Co0000^oooool0027ooooo00?o0000ooooooooool0Qoooool3o`000;[ooooo000Qoooo
o`03o`000?oooooooooo08Sooooo0ol0002iooooo`008Oooool00ol0003oooooooooo`29ooooo`?o
0000^?ooool0027ooooo00?o0000ooooooooool0R_ooool4o`000;Kooooo000Qooooo`03o`000?oo
oooooooo08_ooooo1?l0002eooooo`008Oooool00ol0003oooooooooo`2=ooooo`?o0000]?ooool0
027ooooo00?o0000ooooooooool0S_ooool3o`000;?ooooo000Qooooo`;o0000T?ooool4o`000;7o
oooo000Qooooo`03o`000?oooooooooo093ooooo1Ol0002_ooooo`008Oooool00ol0003ooooooooo
o`2Aooooo`Oo0000[?ooool0027ooooo00?o0000ooooooooool0U?ooool7o`000:Wooooo000Qoooo
o`03o`000?oooooooooo09Oooooo1ol0002Vooooo`008Oooool00ol0003oooooooooo`2Jooooo`Oo
0000Xoooool0027ooooo00?o0000ooooooooool0WOooool6o`000:7ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo0:3ooooo1_l0002Nooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0X_ooool6o`0009cooooo
0007ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000ooooooooool0
YOooool5o`0009[ooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgM
ooooool00006ooooo`?o0000Yoooool5o`0009Sooooo0007ooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo0:Wooooo1Ol0002Foooo
o`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0
003oooooooooo`2[ooooo`Go0000U?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0[Oooool5o`0009;ooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo
0:oooooo1?l0002Aooooo`008Oooool00ol0003oooooooooo`2aooooo`Co0000Soooool0027ooooo
00?o0000ooooooooool0/_ooool5o`0008gooooo000Qooooo`03o`000?oooooooooo0;Cooooo1Ol0
002;ooooo`008Oooool00ol0003oooooooooo`2fooooo`Go0000ROooool0027ooooo0_l0002ioooo
o`Co0000R?ooool0027ooooo00?o0000ooooooooool0^_ooool4o`0008Kooooo000Qooooo`03o`00
0?oooooooooo0;_ooooo1Ol00024ooooo`008Oooool00ol0003oooooooooo`2mooooo`Co0000Pooo
ool0027ooooo00?o0000ooooooooool0_oooool4o`00087ooooo000Qooooo`03o`000?oooooooooo
0<3ooooo1Ol0001oooooo`008Oooool00ol0003oooooooooo`32ooooo`Co0000O_ooool0027ooooo
00?o0000ooooooooool0a?ooool3o`0007gooooo000Qooooo`03o`000?oooooooooo0<Gooooo1?l0
001kooooo`008Oooool2o`000<Oooooo1?l0001jooooo`008Oooool00ol0003oooooooooo`38oooo
o`?o0000NOooool0027ooooo00?o0000ooooooooool0bOooool3o`0007Sooooo000Qooooo`03o`00
0?oooooooooo0<[ooooo1?l0001fooooo`008Oooool00ol0003oooooooooo`3;ooooo`Co0000MOoo
ool0027ooooo00?o0000ooooooooool0cOooool3o`0007Cooooo000Qooooo`03o`000?oooooooooo
0<kooooo1?l0001booooo`008Oooool00ol0003oooooooooo`3?ooooo`Co0000LOooool0027ooooo
00?o0000ooooooooool0dOooool3o`00073ooooo000Qooooo`;o0000doooool4o`0006kooooo000Q
ooooo`03o`000?oooooooooo0=?ooooo1?l0001]ooooo`008Oooool00ol0003oooooooooo`3Eoooo
o`?o0000K?ooool0027ooooo00?o0000ooooooooool0e_ooool3o`0006_ooooo000Qooooo`03o`00
0?oooooooooo0=Oooooo1?l0001Yooooo`008Oooool00ol0003oooooooooo`3Hooooo`Co0000J?oo
ool0027ooooo00?o0000ooooooooool0f_ooool3o`0006Oooooo0007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oo
oooooooo0=_ooooo1?l0001Uooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3Looooo`Co0000
I?ooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00001Oooool3o`000=kooooo0ol0001Sooooo`001oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0=oooooo0ol0001Roooo
o`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c005
ooooo`03o`000?oooooooooo0>3ooooo0ol0001Qooooo`001oooool01Ol@413ooooooooooooooooo
410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`3Qooooo`Co0000Goooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000
ooooooooool0h_ooool4o`0005kooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
1?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo0>Cooooo0ol0001Mooooo`008Oooool0
0ol0003oooooooooo`3Uooooo`?o0000G?ooool0027ooooo00?o0000ooooooooool0i_ooool3o`00
05_ooooo000Qooooo`03o`000?oooooooooo0>Oooooo0ol0001Jooooo`008Oooool00ol0003ooooo
ooooo`3Xooooo`;o0000F_ooool0027ooooo0_l0003Yooooo`?o0000FOooool0027ooooo00?o0000
ooooooooool0jOooool3o`0005Sooooo000Qooooo`03o`000?oooooooooo0>[ooooo0ol0001Goooo
o`008Oooool00ol0003oooooooooo`3[ooooo`?o0000E_ooool0027ooooo00?o0000ooooooooool0
k?ooool3o`0005Gooooo000Qooooo`03o`000?oooooooooo0>gooooo0ol0001Dooooo`008Oooool0
0ol0003oooooooooo`3^ooooo`?o0000Doooool0027ooooo00?o0000ooooooooool0koooool3o`00
05;ooooo000Qooooo`03o`000?oooooooooo0?3ooooo0ol0001Aooooo`008Oooool2o`000?;ooooo
0ol0001@ooooo`008Oooool00ol0003oooooooooo`3booooo`?o0000Coooool0027ooooo00?o0000
ooooooooool0loooool4o`0004gooooo000Qooooo`03o`000?oooooooooo0?Cooooo1?l0001<oooo
o`008Oooool00ol0003oooooooooo`3fooooo`?o0000Boooool0027ooooo00?o0000ooooooooool0
moooool3o`0004[ooooo000Qooooo`03o`000?oooooooooo0?Sooooo0ol00019ooooo`008Oooool0
0ol0003oooooooooo`3iooooo`?o0000B?ooool0027ooooo00?o0000ooooooooool0n_ooool3o`00
04Oooooo000Qooooo`;o0000o?ooool3o`0004Kooooo000Qooooo`03o`000?oooooooooo0?cooooo
0ol00015ooooo`008Oooool00ol0003oooooooooo`3mooooo`?o0000A?ooool0027ooooo00?o0000
ooooooooool0o_ooool3o`0004?ooooo000Qooooo`03o`000?oooooooooo0?oooooo0ol00012oooo
o`008Oooool00ol0003oooooooooo`3oooooo`7ooooo0ol00011ooooo`008Oooool00ol0003ooooo
ooooo`3oooooo`;ooooo0_l00011ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooo`;o
oooo0ol00010ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooo`?ooooo0ol0000ooooo
o`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005
ooooo`?o0000ooooool4ooooo`?o0000?_ooool000Oooooo00Go0000ooooooooooooooooo`00000;
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`3oooooo`Gooooo0ol0
000mooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000
olc<c005ooooo`03o`000?oooooooooo0?oooooo1_ooool3o`0003cooooo0007ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Gooooo00?o0000oooooooo
ool0ooooool7ooooo`?o0000>oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000koooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05
ooooo`03o`000?oooooooooo0?oooooo2?ooool3o`0003[ooooo000Qooooo`03o`000?oooooooooo
0?oooooo2Oooool3o`0003Wooooo000Qooooo`03o`000?oooooooooo0?oooooo2_ooool3o`0003So
oooo000Qooooo`03o`000?oooooooooo0?oooooo2oooool3o`0003Oooooo000Qooooo`;o0000oooo
ool=ooooo`?o0000=_ooool0027ooooo00?o0000ooooooooool0ooooool=ooooo`;o0000=_ooool0
027ooooo00?o0000ooooooooool0ooooool=ooooo`?o0000=Oooool0027ooooo00?o0000oooooooo
ool0ooooool>ooooo`?o0000=?ooool0027ooooo00?o0000ooooooooool0ooooool?ooooo`?o0000
<oooool0027ooooo00?o0000ooooooooool0ooooool@ooooo`?o0000<_ooool0027ooooo00?o0000
ooooooooool0oooooolAooooo`?o0000<Oooool0027ooooo00?o0000ooooooooool0oooooolBoooo
o`?o0000<?ooool0027ooooo00?o0000ooooooooool0oooooolCooooo`?o0000;oooool0027ooooo
00?o0000ooooooooool0oooooolDooooo`?o0000;_ooool0027ooooo0_l0003ooooooaKooooo0ol0
000]ooooo`008Oooool00ol0003oooooooooo`3ooooooaKooooo0ol0000/ooooo`008Oooool00ol0
003oooooooooo`3ooooooaOooooo0ol0000[ooooo`008Oooool00ol0003oooooooooo`3ooooooaSo
oooo0ol0000Zooooo`008Oooool00ol0003oooooooooo`3ooooooaWooooo0ol0000Yooooo`008Ooo
ool00ol0003oooooooooo`3ooooooa[ooooo0_l0000Yooooo`008Oooool00ol0003oooooooooo`3o
oooooa[ooooo0ol0000Xooooo`008Oooool00ol0003oooooooooo`3ooooooa_ooooo0ol0000Woooo
o`008Oooool00ol0003oooooooooo`3ooooooacooooo0ol0000Vooooo`008Oooool2o`000?oooooo
7_ooool3o`0002Gooooo000Qooooo`03o`000?oooooooooo0?oooooo7_ooool3o`0002Cooooo000Q
ooooo`03o`000?oooooooooo0?oooooo7oooool3o`0002?ooooo000Qooooo`03o`000?oooooooooo
0?oooooo8?ooool3o`0002;ooooo000Qooooo`03o`000?oooooooooo0?oooooo8Oooool3o`00027o
oooo000Qooooo`03o`000?oooooooooo0?oooooo8_ooool3o`00023ooooo000Qooooo`03o`000?oo
oooooooo0?oooooo8oooool3o`0001oooooo000Hooooo`Co000000?o410@ooooooooool00_ooool0
0ol0003oooooooooo`3oooooobCooooo0ol0000Nooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?oooooo9Oooool3o`0001gooooo000Jooooo`03o`000?oooooooooo00Co
oooo0ol0003oooooobKooooo0ol0000Looooo`006_ooool00ol0003oooooooooo`3oooooobkooooo
0_l0000Looooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006?ooool00omEEEGo
IVIVo`00003oooooodkooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Joooo
o`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`000003oa0@4?oooooooooo09;ooooo
002Jooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool0Toooool009[ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`Go0000U?ooool001oooooo00Go410@o`00
0?l0003o0000oa0@401fooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00CoA4A4omgMgOoooooo
0000UOooool0027ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Jooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00CogMgMoeEE
EOoooooo0000UOooool0027ooooo00?o0000ooooooooool0M?ooool00ol@413o0000o`000003o`00
01Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?oo
ool00omgMgOoc<c<o`00002Eooooo`008Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooo
oooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1?ooool00oo^k^koA4A4o`00002Eooooo`008Oooool00ol0003oooooooooo`1fooooo`03o`000?oo
oooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00omgMgOo0000ooooo`2Dooooo`007_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo0?oooooo@_ooool001kooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`3ooooood;ooooo000Nooooo`Oo0000oooooom4ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .0127 L
.08481 .02699 L
.12636 .04123 L
.16632 .05603 L
.20885 .07337 L
.2498 .09195 L
.29331 .11407 L
.33524 .13802 L
.37557 .16377 L
.41848 .19431 L
.4598 .22697 L
.48055 .24461 L
.48962 .2526 L
.49442 .25688 L
.49705 .25925 L
.49834 .26042 L
.49953 .2615 L
.50089 .26219 L
.50161 .2624 L
.50237 .26262 L
.50495 .26339 L
.50998 .26493 L
.51991 .26812 L
.54183 .27587 L
.5817 .29241 L
.62415 .31347 L
.665 .33701 L
.70843 .36536 L
.75027 .39567 L
.79051 .42732 L
.83333 .46335 L
.87456 .49992 L
.9142 .53643 L
.95642 .5763 L
.99704 .61519 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<?ooool4o`000003oa0@4?oooooooooo01Sooooo001Booooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<_ooool00ol0003oooooooooo`0Jooooo`00D_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Ko
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool0
0ol0003oooooooooo`0Jooooo`00D_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Voooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03;ooooo00?o
0000ooooooooool06_ooool005;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Gooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03o`00
0?oooooooooo01[ooooo001Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Tooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Xooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03;ooooo00?o0000ooooooooool06_oo
ool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000booooo`03o`000?oooooooooo01[ooooo001B
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Looooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomGooooo`;o00000_ooool2o`0000cooooo003ooooooeOo
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`00oooooomHooooo`04omgMgOl0003o410@
olc<c0gooooo000Poooooooo0000;Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kPgooooo000Poooo
o`Oo00002Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMg
MomgMgOo<S8b3Oooool0027ooooo00?o0000ooooool000001_l0000cooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02?ooool2o`0000;ooooo0_l0000<ooooo`008Oooool00ol0003o
ooooooooo`02ooooo`Oo0000oooooollooooo`008Oooool00ol0003oooooooooo`05ooooo`Oo0000
ooooooliooooo`008Oooool00ol0003oooooooooo`08ooooo`Oo0000oooooolfooooo`008Oooool0
0ol0003oooooooooo`0;ooooo`So0000oooooolbooooo`008Oooool00ol0003oooooooooo`0>oooo
o`So0000ooooool_ooooo`008Oooool00ol0003oooooooooo`0Booooo`So0000ooooool[ooooo`00
8Oooool2o`0001Kooooo2?l0003oooooobSooooo000Qooooo`03o`000?oooooooooo01Wooooo1ol0
003oooooobGooooo000Qooooo`03o`000?oooooooooo01cooooo1ol0003oooooob;ooooo000Qoooo
o`03o`000?oooooooooo01oooooo1_l0003oooooob3ooooo000Qooooo`03o`000?oooooooooo02;o
oooo1_l0003ooooooagooooo000Qooooo`03o`000?oooooooooo02Cooooo1_l0003ooooooa_ooooo
000Qooooo`03o`000?oooooooooo02Oooooo1Ol0003ooooooaWooooo000Qooooo`03o`000?oooooo
oooo02Wooooo1_l0003ooooooaKooooo000Qooooo`03o`000?oooooooooo02_ooooo1_l0003ooooo
oaCooooo000Qooooo`;o0000;oooool6o`000?oooooo4Oooool0027ooooo00?o0000ooooooooool0
<?ooool6o`000?oooooo3oooool0027ooooo00?o0000ooooooooool0<oooool5o`000?oooooo3Ooo
ool0027ooooo00?o0000ooooooooool0=Oooool6o`000?oooooo2_ooool0027ooooo00?o0000oooo
ooooool0=oooool6o`000?oooooo2?ooool0027ooooo00?o0000ooooooooool0>_ooool6o`000?oo
oooo1Oooool0027ooooo00?o0000ooooooooool0??ooool7o`000?oooooo0_ooool0027ooooo00?o
0000ooooooooool0?oooool6o`000?oooooo000Qooooo`03o`000?oooooooooo04;ooooo1_l0003l
ooooo`008Oooool00ol0003oooooooooo`14ooooo`Ko0000n_ooool0027ooooo0_l00018ooooo`Go
0000n?ooool0027ooooo00?o0000ooooooooool0BOooool5o`000?Kooooo000Qooooo`03o`000?oo
oooooooo04_ooooo1Ol0003dooooo`008Oooool00ol0003oooooooooo`1=ooooo`Co0000loooool0
027ooooo00?o0000ooooooooool0Coooool4o`000?7ooooo000Qooooo`03o`000?oooooooooo053o
oooo1Ol0003_ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001Oooool00ol0003oooooooooo`1Booooo`Go0000kOooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000oooo
ooooool0E?ooool5o`000>_ooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo05Kooooo1?l0003Zooooo`001oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`0005Sooooo1?l0003Xoooo
o`001oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0
003oooooooooo`1Iooooo`Go0000i_ooool000Oooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Foooool4o`000>Gooooo0007ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000
ooooooooool0GOooool4o`000>?ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0G_ooool5o`000>7ooooo000Q
ooooo`03o`000?oooooooooo063ooooo1?l0003Pooooo`008Oooool00ol0003oooooooooo`1Roooo
o`Co0000g_ooool0027ooooo00?o0000ooooooooool0Hoooool4o`000=gooooo000Qooooo`03o`00
0?oooooooooo06Gooooo1?l0003Kooooo`008Oooool2o`0006Oooooo1?l0003Jooooo`008Oooool0
0ol0003oooooooooo`1Xooooo`Co0000f?ooool0027ooooo00?o0000ooooooooool0JOooool4o`00
0=Oooooo000Qooooo`03o`000?oooooooooo06_ooooo1?l0003Eooooo`008Oooool00ol0003ooooo
ooooo`1/ooooo`Co0000e?ooool0027ooooo00?o0000ooooooooool0K_ooool4o`000=;ooooo000Q
ooooo`03o`000?oooooooooo06oooooo1?l0003Aooooo`008Oooool00ol0003oooooooooo`1aoooo
o`Co0000coooool0027ooooo00?o0000ooooooooool0L_ooool4o`000<kooooo000Qooooo`;o0000
MOooool3o`000<gooooo000Qooooo`03o`000?oooooooooo07Gooooo1?l0003;ooooo`008Oooool0
0ol0003oooooooooo`1fooooo`Co0000b_ooool0027ooooo00?o0000ooooooooool0N?ooool4o`00
0<Sooooo000Qooooo`03o`000?oooooooooo07Wooooo1?l00037ooooo`008Oooool00ol0003ooooo
ooooo`1kooooo`?o0000a_ooool0027ooooo00?o0000ooooooooool0O?ooool3o`000<Gooooo000Q
ooooo`03o`000?oooooooooo07gooooo0ol00034ooooo`008Oooool00ol0003oooooooooo`1noooo
o`Co0000`_ooool0027ooooo0_l00020ooooo`Co0000`Oooool0027ooooo00?o0000ooooooooool0
POooool3o`000<3ooooo000Qooooo`03o`000?oooooooooo08;ooooo0ol0002oooooo`008Oooool0
0ol0003oooooooooo`23ooooo`?o0000__ooool0027ooooo00?o0000ooooooooool0Q?ooool4o`00
0;cooooo000Qooooo`03o`000?oooooooooo08Gooooo1?l0002kooooo`008Oooool00ol0003ooooo
ooooo`27ooooo`?o0000^_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0R?ooool3o`000;Wooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`29ooooo`?o0000^?ooool000Oooooo00Go410@oooooooooooooooo
oa0@400;ooooo`Go00001Oooool00ol0003oooooooooo`2:ooooo`Co0000]_ooool000Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo0ol0002;ooooo`Co
0000]Oooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
00Kooooo00?o0000ooooooooool0SOooool3o`000;Cooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo08kooooo0_l0002doooo
o`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0
003oooooooooo`2>ooooo`Co0000/_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0Soooool6o`000:oooooo000Qooooo`03
o`000?oooooooooo097ooooo1ol0002/ooooo`008Oooool00ol0003oooooooooo`2Dooooo`Oo0000
ZOooool0027ooooo00?o0000ooooooooool0Uoooool7o`000:Kooooo000Qooooo`03o`000?oooooo
oooo09[ooooo1ol0002Sooooo`008Oooool2o`0009kooooo1_l0002Qooooo`008Oooool00ol0003o
ooooooooo`2Pooooo`Ko0000W_ooool0027ooooo00?o0000ooooooooool0X_ooool6o`0009cooooo
000Qooooo`03o`000?oooooooooo0:Gooooo1Ol0002Jooooo`008Oooool00ol0003oooooooooo`2W
ooooo`Go0000V?ooool0027ooooo00?o0000ooooooooool0ZOooool5o`0009Kooooo000Qooooo`03
o`000?oooooooooo0:_ooooo1Ol0002Dooooo`008Oooool00ol0003oooooooooo`2]ooooo`Ko0000
TOooool0027ooooo00?o0000ooooooooool0[oooool6o`0008oooooo000Qooooo`;o0000/oooool5
o`0008gooooo000Qooooo`03o`000?oooooooooo0;Cooooo1Ol0002;ooooo`008Oooool00ol0003o
ooooooooo`2fooooo`Go0000ROooool0027ooooo00?o0000ooooooooool0^?ooool4o`0008Sooooo
000Qooooo`03o`000?oooooooooo0;[ooooo1?l00026ooooo`008Oooool00ol0003oooooooooo`2k
ooooo`Go0000Q?ooool0027ooooo00?o0000ooooooooool0_Oooool4o`0008?ooooo000Qooooo`03
o`000?oooooooooo0;oooooo1?l00021ooooo`008Oooool00ol0003oooooooooo`30ooooo`Go0000
Ooooool0027ooooo0_l00033ooooo`Co0000O_ooool0027ooooo00?o0000ooooooooool0a?ooool4
o`0007cooooo000Qooooo`03o`000?oooooooooo0<Gooooo1?l0001kooooo`008Oooool00ol0003o
ooooooooo`37ooooo`Co0000NOooool0027ooooo00?o0000ooooooooool0b?ooool4o`0007Sooooo
000Qooooo`03o`000?oooooooooo0<[ooooo0ol0001gooooo`008Oooool00ol0003oooooooooo`3;
ooooo`Co0000MOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0c?ooool4o`0007Cooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@05ooooo`03o`000?oooooooooo0<kooooo1?l0001booooo`001oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000coooool4o`00077o
oooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Gooooo00?o0000ooooooooool0dOooool4o`0006oooooo0007ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0d_ooool4
o`0006kooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`07
ooooo`03o`000?oooooooooo0=Cooooo1?l0001/ooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?ogMgMoa0@4?nHV9P01oooool00ol0003oooooooooo`3Eooooo`Co0000Joooool0
00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o
0000ooooooooool0eoooool3o`0006[ooooo000Qooooo`03o`000?oooooooooo0=Sooooo1?l0001X
ooooo`008Oooool00ol0003oooooooooo`3Iooooo`Co0000Ioooool0027ooooo00?o0000oooooooo
ool0foooool4o`0006Gooooo000Qooooo`03o`000?oooooooooo0=cooooo1?l0001Tooooo`008Ooo
ool2o`000=oooooo0ol0001Sooooo`008Oooool00ol0003oooooooooo`3Oooooo`Co0000HOooool0
027ooooo00?o0000ooooooooool0h?ooool4o`00063ooooo000Qooooo`03o`000?oooooooooo0>;o
oooo0ol0001Oooooo`008Oooool00ol0003oooooooooo`3Sooooo`Co0000GOooool0027ooooo00?o
0000ooooooooool0i?ooool4o`0005cooooo000Qooooo`03o`000?oooooooooo0>Kooooo0ol0001K
ooooo`008Oooool00ol0003oooooooooo`3Wooooo`Co0000FOooool0027ooooo00?o0000oooooooo
ool0j?ooool4o`0005Sooooo000Qooooo`;o0000joooool3o`0005Oooooo000Qooooo`03o`000?oo
oooooooo0>_ooooo0ol0001Fooooo`008Oooool00ol0003oooooooooo`3/ooooo`?o0000EOooool0
027ooooo00?o0000ooooooooool0kOooool3o`0005Cooooo000Qooooo`03o`000?oooooooooo0>ko
oooo0ol0001Cooooo`008Oooool00ol0003oooooooooo`3_ooooo`?o0000D_ooool0027ooooo00?o
0000ooooooooool0l?ooool3o`00057ooooo000Qooooo`03o`000?oooooooooo0?7ooooo0ol0001@
ooooo`008Oooool00ol0003oooooooooo`3booooo`?o0000Coooool0027ooooo0_l0003dooooo`Co
0000COooool0027ooooo00?o0000ooooooooool0m?ooool4o`0004cooooo000Qooooo`03o`000?oo
oooooooo0?Kooooo0ol0001;ooooo`008Oooool00ol0003oooooooooo`3gooooo`?o0000B_ooool0
027ooooo00?o0000ooooooooool0n?ooool3o`0004Wooooo000Qooooo`03o`000?oooooooooo0?Wo
oooo1?l00017ooooo`008Oooool00ol0003oooooooooo`3jooooo`Co0000A_ooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Go
oooo00?o0000ooooooooool0o?ooool3o`0004Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo
0?gooooo0ol00014ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000005ooooo`?o0000o_ooool3o`0004?ooooo0007ooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Gooooo00?o0000ooooooooool0oooo
ool3o`0004;ooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`00
0?l0003oc<c<00Gooooo00?o0000ooooooooool0ooooool1ooooo`?o0000@Oooool000Oooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001Oooool00ol0003o
ooooooooo`3oooooo`;ooooo0ol00010ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_oooooo^[Zjo`000005ooooo`03o`000?oooooooooo0?oooooo0oooool3o`00
03oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Gooooo00?o0000ooooooooool0ooooool4ooooo`?o0000?_ooool0027ooooo00?o0000oooo
ooooool0ooooool5ooooo`?o0000?Oooool0027ooooo00?o0000ooooooooool0ooooool6ooooo`?o
0000??ooool0027ooooo00?o0000ooooooooool0ooooool7ooooo`?o0000>oooool0027ooooo0_l0
003oooooo`Wooooo0ol0000jooooo`008Oooool00ol0003oooooooooo`3oooooo`Wooooo0ol0000i
ooooo`008Oooool00ol0003oooooooooo`3oooooo`[ooooo0ol0000hooooo`008Oooool00ol0003o
ooooooooo`3oooooo`_ooooo0ol0000gooooo`008Oooool00ol0003oooooooooo`3oooooo`cooooo
1?l0000eooooo`008Oooool00ol0003oooooooooo`3oooooo`gooooo1?l0000dooooo`008Oooool0
0ol0003oooooooooo`3oooooo`oooooo0ol0000cooooo`008Oooool00ol0003oooooooooo`3ooooo
oa3ooooo0ol0000booooo`008Oooool00ol0003oooooooooo`3ooooooa7ooooo0ol0000aooooo`00
8Oooool00ol0003oooooooooo`3ooooooa;ooooo0ol0000`ooooo`008Oooool2o`000?oooooo5?oo
ool3o`0002oooooo000Qooooo`03o`000?oooooooooo0?oooooo5?ooool3o`0002kooooo000Qoooo
o`03o`000?oooooooooo0?oooooo5Oooool3o`0002gooooo000Qooooo`03o`000?oooooooooo0?oo
oooo5_ooool3o`0002cooooo000Qooooo`03o`000?oooooooooo0?oooooo5oooool3o`0002_ooooo
000Qooooo`03o`000?oooooooooo0?oooooo6?ooool3o`0002[ooooo000Qooooo`03o`000?oooooo
oooo0?oooooo6Oooool4o`0002Sooooo000Qooooo`03o`000?oooooooooo0?oooooo6_ooool4o`00
02Oooooo000Qooooo`03o`000?oooooooooo0?oooooo7?ooool3o`0002Kooooo000Qooooo`;o0000
oooooolNooooo`?o00009Oooool0027ooooo00?o0000ooooooooool0oooooolNooooo`?o00009?oo
ool0027ooooo00?o0000ooooooooool0oooooolOooooo`?o00008oooool0027ooooo00?o0000oooo
ooooool0oooooolPooooo`?o00008_ooool0027ooooo00?o0000ooooooooool0oooooolQooooo`?o
00008Oooool0027ooooo00?o0000ooooooooool0oooooolRooooo`?o00008?ooool0027ooooo00?o
0000ooooooooool0oooooolSooooo`?o00007oooool001Sooooo1?l000000ol@413oooooooooo`02
ooooo`03o`000?oooooooooo0?oooooo9?ooool3o`0001kooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooolUooooo`?o00007Oooool001[ooooo00?o0000oooooooo
ool01?ooool3o`000?oooooo9_ooool3o`0001cooooo000Jooooo`03o`000?oooooooooo0?oooooo
;_ooool2o`0001cooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Hooooo`03
oeEEEOmVIVKo00000?ooooooC_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
09[ooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`0U?ooool009[ooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmEEEGoMgMgoooooonHV9So8B4Q09Cooooo002Jooooo`03o`000?oooooooooo01[ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol0003ooooo
oooooooooooo000009Cooooo000Oooooo`05oa0@4?l0003o0000o`000?l@4100M_ooool00ol0003o
ooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?nHV9SooooooiRHV?lQ8B40U?ooool0027ooooo00?o0000
ooooooooool0M_ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oeEEEOl0003o410@olc<c02Dooooo`00
8Oooool00ol0003oooooooooo`1dooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oeEEEOn7QhOooooo
09Kooooo000Qooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool06_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03omgMgOl@413o
V9RH09Kooooo000Qooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool06_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`04olc<c?m4
A4Co0000oa0@49Cooooo000Nooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
oooooom2ooooo`007_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo0?oooooo
@_ooool001kooooo1ol0003oooooodCooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .0169 L
.08481 .0357 L
.12636 .05408 L
.16632 .07271 L
.20885 .09391 L
.2498 .11592 L
.29331 .14135 L
.33524 .16809 L
.37557 .19609 L
.41848 .22851 L
.4598 .26243 L
.48055 .28049 L
.48962 .28861 L
.49442 .29295 L
.49705 .29535 L
.49834 .29653 L
.49953 .29762 L
.50089 .29832 L
.50161 .29854 L
.50237 .29877 L
.50495 .29956 L
.50998 .30114 L
.51991 .30437 L
.54183 .31208 L
.5817 .3281 L
.62415 .34795 L
.665 .36969 L
.70843 .39547 L
.75027 .42269 L
.79051 .45087 L
.83333 .4827 L
.87456 .51484 L
.9142 .54681 L
.95642 .58164 L
.99704 .61556 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<?ooool4o`000003oa0@4?oooooooooo01Sooooo001Booooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<_ooool00ol0003oooooooooo`0Jooooo`00D_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Ko
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool0
0ol0003oooooooooo`0Jooooo`00D_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Voooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03;ooooo00?o
0000ooooooooool06_ooool005;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Gooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03o`00
0?oooooooooo01[ooooo001Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Tooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Xooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03;ooooo00?o0000ooooooooool06_oo
ool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000booooo`03o`000?oooooooooo01[ooooo001B
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Looooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomGooooo`;o00000_ooool2o`0000cooooo003ooooooeOo
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`00oooooomHooooo`04omgMgOl0003o410@
olc<c0gooooo000Poooooooo0000;Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kPgooooo000Poooo
o`Ko00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMg
MomgMgOo<S8b3Oooool0027ooooo1ol0000eooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool02?ooool2o`0000;ooooo0_l0000<ooooo`008Oooool01?l0003oooooooooooooool5o`00
0?oooooo?oooool0027ooooo00?o0000ooooooooool00oooool6o`000?oooooo??ooool0027ooooo
00?o0000ooooooooool01Oooool6o`000?oooooo>_ooool0027ooooo00?o0000ooooooooool02?oo
ool6o`000?oooooo=oooool0027ooooo00?o0000ooooooooool02_ooool6o`000?oooooo=Oooool0
027ooooo00?o0000ooooooooool03Oooool5o`000?oooooo<oooool0027ooooo0_l0000@ooooo`Ko
0000ooooool`ooooo`008Oooool00ol0003oooooooooo`0Aooooo`Ko0000ooooool^ooooo`008Ooo
ool00ol0003oooooooooo`0Dooooo`Go0000ooooool/ooooo`008Oooool00ol0003oooooooooo`0F
ooooo`Ko0000oooooolYooooo`008Oooool00ol0003oooooooooo`0Hooooo`Ko0000oooooolWoooo
o`008Oooool00ol0003oooooooooo`0Kooooo`Go0000oooooolUooooo`008Oooool00ol0003ooooo
ooooo`0Mooooo`Ko0000oooooolRooooo`008Oooool00ol0003oooooooooo`0Oooooo`Ko0000oooo
oolPooooo`008Oooool00ol0003oooooooooo`0Rooooo`Go0000oooooolNooooo`008Oooool2o`00
02Gooooo1Ol0003ooooooacooooo000Qooooo`03o`000?oooooooooo02Kooooo1Ol0003ooooooa[o
oooo000Qooooo`03o`000?oooooooooo02Sooooo1Ol0003ooooooaSooooo000Qooooo`03o`000?oo
oooooooo02[ooooo1Ol0003ooooooaKooooo000Qooooo`03o`000?oooooooooo02cooooo1Ol0003o
oooooaCooooo000Qooooo`03o`000?oooooooooo02kooooo1Ol0003ooooooa;ooooo000Qooooo`03
o`000?oooooooooo033ooooo1Ol0003ooooooa3ooooo000Qooooo`03o`000?oooooooooo03;ooooo
1Ol0003oooooo`kooooo000Qooooo`03o`000?oooooooooo03Cooooo1Ol0003oooooo`cooooo000Q
ooooo`03o`000?oooooooooo03Kooooo1Ol0003oooooo`[ooooo000Qooooo`;o0000>Oooool5o`00
0?oooooo2?ooool0027ooooo00?o0000ooooooooool0>_ooool5o`000?oooooo1_ooool0027ooooo
00?o0000ooooooooool0??ooool5o`000?oooooo1?ooool0027ooooo00?o0000ooooooooool0?_oo
ool5o`000?oooooo0_ooool0027ooooo00?o0000ooooooooool0@?ooool4o`000?oooooo0Oooool0
027ooooo00?o0000ooooooooool0@_ooool4o`000?kooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo04?ooooo1Ol0003loooo
o`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01Oooool00ol0003oooooooooo`15ooooo`Go0000n_ooool000Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0Aoooool5
o`000?Sooooo0007ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05
ooooo`?o0000BOooool5o`000?Kooooo0007ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo04_ooooo1Ol0003dooooo`001oooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1=
ooooo`Co0000loooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001Oooool00ol0003oooooooooo`1?ooooo`Co0000lOooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003ooooo
ooooo`1@ooooo`Go0000koooool0027ooooo00?o0000ooooooooool0D_ooool5o`000>gooooo000Q
ooooo`03o`000?oooooooooo05Cooooo1?l0003/ooooo`008Oooool00ol0003oooooooooo`1Foooo
o`Co0000j_ooool0027ooooo00?o0000ooooooooool0Eoooool4o`000>Wooooo000Qooooo`;o0000
F_ooool4o`000>Oooooo000Qooooo`03o`000?oooooooooo05[ooooo1?l0003Vooooo`008Oooool0
0ol0003oooooooooo`1Looooo`Co0000i?ooool0027ooooo00?o0000ooooooooool0GOooool4o`00
0>?ooooo000Qooooo`03o`000?oooooooooo05oooooo1?l0003Qooooo`008Oooool00ol0003ooooo
ooooo`1Pooooo`Co0000h?ooool0027ooooo00?o0000ooooooooool0H_ooool4o`000=kooooo000Q
ooooo`03o`000?oooooooooo06?ooooo1?l0003Mooooo`008Oooool00ol0003oooooooooo`1Uoooo
o`Co0000foooool0027ooooo0_l0001Wooooo`Co0000f_ooool0027ooooo00?o0000ooooooooool0
J?ooool4o`000=Sooooo000Qooooo`03o`000?oooooooooo06Wooooo1?l0003Gooooo`008Oooool0
0ol0003oooooooooo`1[ooooo`Co0000eOooool0027ooooo00?o0000ooooooooool0K?ooool4o`00
0=Cooooo000Qooooo`03o`000?oooooooooo06kooooo0ol0003Cooooo`008Oooool00ol0003ooooo
ooooo`1_ooooo`Co0000dOooool0027ooooo00?o0000ooooooooool0L?ooool4o`000=3ooooo000Q
ooooo`03o`000?oooooooooo07;ooooo0ol0003?ooooo`008Oooool2o`0007Cooooo0ol0003>oooo
o`008Oooool00ol0003oooooooooo`1dooooo`Co0000c?ooool0027ooooo00?o0000ooooooooool0
MOooool4o`000<_ooooo000Qooooo`03o`000?oooooooooo07Oooooo0ol0003:ooooo`008Oooool0
0ol0003oooooooooo`1hooooo`Co0000b?ooool0027ooooo00?o0000ooooooooool0NOooool4o`00
0<Oooooo000Qooooo`03o`000?oooooooooo07_ooooo0ol00036ooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`1looooo`?o0000aOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07gooooo0ol00034ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`03o`000?oooooooooo07ko
oooo1?l00032ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo00001_ooool3o`0007oooooo1?l00031ooooo`001oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`21ooooo`?o0000`?ooool0
00Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o0000
ooooooooool0P_ooool3o`000;oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`000006ooooo`03o`000?oooooooooo08?ooooo0ol0002nooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`24
ooooo`?o0000_Oooool0027ooooo00?o0000ooooooooool0QOooool3o`000;cooooo000Qooooo`03
o`000?oooooooooo08Kooooo0ol0002kooooo`008Oooool00ol0003oooooooooo`27ooooo`?o0000
^_ooool0027ooooo00?o0000ooooooooool0R?ooool3o`000;Wooooo000Qooooo`;o0000R_ooool3
o`000;Sooooo000Qooooo`03o`000?oooooooooo08[ooooo1?l0002fooooo`008Oooool00ol0003o
ooooooooo`2;ooooo`Co0000]Oooool0027ooooo00?o0000ooooooooool0SOooool3o`000;Cooooo
000Qooooo`03o`000?oooooooooo08kooooo0ol0002cooooo`008Oooool00ol0003oooooooooo`2?
ooooo`Co0000/Oooool0027ooooo00?o0000ooooooooool0T?ooool5o`000:oooooo000Qooooo`03
o`000?oooooooooo097ooooo1ol0002/ooooo`008Oooool00ol0003oooooooooo`2Dooooo`Oo0000
ZOooool0027ooooo0_l0002Hooooo`Oo0000Y_ooool0027ooooo00?o0000ooooooooool0V_ooool7
o`000:?ooooo000Qooooo`03o`000?oooooooooo09gooooo1_l0002Qooooo`008Oooool00ol0003o
ooooooooo`2Pooooo`Ko0000W_ooool0027ooooo00?o0000ooooooooool0X_ooool6o`0009cooooo
000Qooooo`03o`000?oooooooooo0:Gooooo1Ol0002Jooooo`008Oooool00ol0003oooooooooo`2W
ooooo`Go0000V?ooool0027ooooo00?o0000ooooooooool0ZOooool5o`0009Kooooo000Qooooo`03
o`000?oooooooooo0:_ooooo1Ol0002Dooooo`008Oooool2o`000:kooooo1_l0002Aooooo`008Ooo
ool00ol0003oooooooooo`2_ooooo`Ko0000Soooool0027ooooo00?o0000ooooooooool0/_ooool5
o`0008gooooo000Qooooo`03o`000?oooooooooo0;Cooooo1Ol0002;ooooo`008Oooool00ol0003o
ooooooooo`2fooooo`Go0000ROooool0027ooooo00?o0000ooooooooool0^?ooool5o`0008Oooooo
000Qooooo`03o`000?oooooooooo0;[ooooo1Ol00025ooooo`001oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003ooooo
ooooo`2looooo`Go0000Poooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0__ooool5o`00087o
oooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000
00Gooooo0ol00030ooooo`Go0000Ooooool000Oooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`32ooooo`Co0000O_ooool0
00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01Ooo
ool00ol0003oooooooooo`34ooooo`Co0000O?ooool000Oooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo00Oooooo00?o0000ooooooooool0aOooool5o`0007[ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV007ooooo`03o`000?oo
oooooooo0<Oooooo1?l0001iooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Co
c<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`39ooooo`Co0000Moooool0027ooooo00?o
0000ooooooooool0b_ooool5o`0007Gooooo000Qooooo`03o`000?oooooooooo0<cooooo1?l0001d
ooooo`008Oooool00ol0003oooooooooo`3>ooooo`Co0000L_ooool0027ooooo00?o0000oooooooo
ool0coooool4o`00077ooooo000Qooooo`;o0000d_ooool4o`0006oooooo000Qooooo`03o`000?oo
oooooooo0=;ooooo1Ol0001]ooooo`008Oooool00ol0003oooooooooo`3Dooooo`Co0000K?ooool0
027ooooo00?o0000ooooooooool0e_ooool4o`0006[ooooo000Qooooo`03o`000?oooooooooo0=Oo
oooo1Ol0001Xooooo`008Oooool00ol0003oooooooooo`3Iooooo`Co0000Ioooool0027ooooo00?o
0000ooooooooool0foooool4o`0006Gooooo000Qooooo`03o`000?oooooooooo0=cooooo1?l0001T
ooooo`008Oooool00ol0003oooooooooo`3Nooooo`Co0000H_ooool0027ooooo0_l0003Pooooo`Co
0000HOooool0027ooooo00?o0000ooooooooool0hOooool4o`0005oooooo000Qooooo`03o`000?oo
oooooooo0>;ooooo1?l0001Nooooo`008Oooool00ol0003oooooooooo`3Tooooo`Co0000G?ooool0
027ooooo00?o0000ooooooooool0iOooool4o`0005_ooooo000Qooooo`03o`000?oooooooooo0>Oo
oooo1?l0001Iooooo`008Oooool00ol0003oooooooooo`3Xooooo`Co0000F?ooool0027ooooo00?o
0000ooooooooool0j_ooool3o`0005Oooooo000Qooooo`03o`000?oooooooooo0>_ooooo0ol0001F
ooooo`008Oooool2o`000>gooooo0ol0001Eooooo`008Oooool00ol0003oooooooooo`3]ooooo`Co
0000Doooool0027ooooo00?o0000ooooooooool0k_ooool4o`0005;ooooo000Qooooo`03o`000?oo
oooooooo0?3ooooo0ol0001Aooooo`008Oooool00ol0003oooooooooo`3aooooo`?o0000D?ooool0
027ooooo00?o0000ooooooooool0l_ooool3o`0004oooooo000Qooooo`03o`000?oooooooooo0??o
oooo1?l0001=ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3dooooo`Co0000C?ooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00Gooooo00?o0000ooooooooool0m_ooool4o`0004[ooooo0007ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0003gooooo`Co0000BOoo
ool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
1Oooool00ol0003oooooooooo`3iooooo`Co0000Aoooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003oooooooooo`3jooooo`Co
0000A_ooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001Oooool00ol0003oooooooooo`3looooo`?o0000AOooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3m
ooooo`Co0000@oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT01Oooool00ol0003oooooooooo`3nooooo`Co0000@_ooool0027ooooo00?o0000
ooooooooool0ooooool1ooooo`Co0000@?ooool0027ooooo00?o0000ooooooooool0ooooool2oooo
o`Co0000?oooool0027ooooo00?o0000ooooooooool0ooooool4ooooo`?o0000?_ooool0027ooooo
0_l0003oooooo`Kooooo0ol0000mooooo`008Oooool00ol0003oooooooooo`3oooooo`Kooooo0ol0
000looooo`008Oooool00ol0003oooooooooo`3oooooo`Oooooo0ol0000kooooo`008Oooool00ol0
003oooooooooo`3oooooo`Sooooo0ol0000jooooo`008Oooool00ol0003oooooooooo`3oooooo`Wo
oooo0ol0000iooooo`008Oooool00ol0003oooooooooo`3oooooo`[ooooo0ol0000hooooo`008Ooo
ool00ol0003oooooooooo`3oooooo`_ooooo0ol0000gooooo`008Oooool00ol0003oooooooooo`3o
ooooo`cooooo1?l0000eooooo`008Oooool00ol0003oooooooooo`3oooooo`gooooo1?l0000doooo
o`008Oooool00ol0003oooooooooo`3oooooo`oooooo0ol0000cooooo`008Oooool2o`000?oooooo
4Oooool4o`00037ooooo000Qooooo`03o`000?oooooooooo0?oooooo4Oooool4o`00033ooooo000Q
ooooo`03o`000?oooooooooo0?oooooo4oooool3o`0002oooooo000Qooooo`03o`000?oooooooooo
0?oooooo5?ooool3o`0002kooooo000Qooooo`03o`000?oooooooooo0?oooooo5Oooool4o`0002co
oooo000Qooooo`03o`000?oooooooooo0?oooooo5_ooool4o`0002_ooooo000Qooooo`03o`000?oo
oooooooo0?oooooo6?ooool3o`0002[ooooo000Qooooo`03o`000?oooooooooo0?oooooo6Oooool4
o`0002Sooooo000Qooooo`03o`000?oooooooooo0?oooooo6_ooool4o`0002Oooooo000Qooooo`;o
0000oooooolMooooo`?o00009_ooool0027ooooo00?o0000ooooooooool0oooooolMooooo`?o0000
9Oooool0027ooooo00?o0000ooooooooool0oooooolNooooo`?o00009?ooool0027ooooo00?o0000
ooooooooool0oooooolOooooo`Co00008_ooool0027ooooo00?o0000ooooooooool0oooooolPoooo
o`Co00008Oooool0027ooooo00?o0000ooooooooool0oooooolRooooo`?o00008?ooool0027ooooo
00?o0000ooooooooool0oooooolSooooo`?o00007oooool001Sooooo1?l000000ol@413ooooooooo
o`02ooooo`03o`000?oooooooooo0?oooooo9?ooool3o`0001kooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooolUooooo`?o00007Oooool001[ooooo00?o0000oooo
ooooool01?ooool3o`000?oooooo9_ooool3o`0001cooooo000Jooooo`03o`000?oooooooooo0?oo
oooo;_ooool2o`0001cooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Hoooo
o`03oeEEEOmVIVKo00000?ooooooC_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool009[ooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`0U?ooool009[ooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q09Cooooo002Jooooo`03o`000?oooooooooo01[ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol0003o
oooooooooooooooo000009Cooooo000Oooooo`05oa0@4?l0003o0000o`000?l@4100M_ooool00ol0
003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
ooooooooooooooooo`000003ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80U?ooool0027ooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003ooooooooooooooooo000000?ooooo00Goc<c<o`000?l0003o0000olc<c02Doooo
o`008Oooool00ol0003oooooooooo`1dooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?nj^[[o
oooookZj^_l@4100U?ooool0027ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00Go0000okZj^_oooooo^[Zjo`00002Dooooo`008Oooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01OnYZJWo410@o`000?l@413oZJVY09Cooooo000Nooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool0oooooom2ooooo`007_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo0?oooooo@_ooool001kooooo1ol0003oooooodCooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .02049 L
.08481 .04315 L
.12636 .06504 L
.16632 .0869 L
.20885 .11131 L
.2498 .13617 L
.29331 .16429 L
.33524 .19325 L
.37557 .223 L
.41848 .25684 L
.4598 .29166 L
.48055 .30999 L
.48962 .31819 L
.49442 .32256 L
.49705 .32498 L
.49834 .32617 L
.49953 .32726 L
.50089 .32797 L
.50161 .32819 L
.50237 .32843 L
.50495 .32923 L
.50998 .33081 L
.51991 .33404 L
.54183 .34165 L
.5817 .35711 L
.62415 .37586 L
.665 .39603 L
.70843 .41964 L
.75027 .44432 L
.79051 .46967 L
.83333 .49812 L
.87456 .52671 L
.9142 .55506 L
.95642 .58587 L
.99704 .61584 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1@00000;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`H00000=P3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`3o
ool01@00003o0?oood00oooo000Q0?ooo`030000003oool0oooo0080oooo1@00003o0?oooch0oooo
000Q0?ooo`030000003oool0oooo00@0oooo1@00003o0?oooc`0oooo000Q0?ooo`030000003oool0
oooo00H0oooo1@00003o0?ooocX0oooo000Q0?ooo`030000003oool0oooo00P0oooo1@00003o0?oo
ocP0oooo000Q0?ooo`030000003oool0oooo00X0oooo1@00003o0?ooocH0oooo000Q0?ooo`800000
3@3oool500000?l0oooo=03oool00240oooo00<000000?ooo`3oool03P3oool500000?l0oooo<P3o
ool00240oooo00<000000?ooo`3oool0403oool500000?l0oooo<03oool00240oooo00<000000?oo
o`3oool04P3oool500000?l0oooo;P3oool00240oooo00<000000?ooo`3oool0503oool500000?l0
oooo;03oool00240oooo00<000000?ooo`3oool05P3oool500000?l0oooo:P3oool00240oooo00<0
00000?ooo`3oool0603oool500000?l0oooo:03oool00240oooo00<000000?ooo`3oool06P3oool5
00000?l0oooo9P3oool00240oooo00<000000?ooo`3oool0703oool500000?l0oooo903oool00240
oooo0P00000O0?ooo`D00000o`3ooolR0?ooo`008@3oool00`000000oooo0?ooo`0P0?ooo`D00000
o`3ooolP0?ooo`008@3oool00`000000oooo0?ooo`0R0?ooo`D00000o`3ooolN0?ooo`008@3oool0
0`000000oooo0?ooo`0T0?ooo`@00000o`3ooolM0?ooo`008@3oool00`000000oooo0?ooo`0V0?oo
o`@00000o`3ooolK0?ooo`008@3oool00`000000oooo0?ooo`0W0?ooo`D00000o`3ooolI0?ooo`00
8@3oool00`000000oooo0?ooo`0Y0?ooo`@00000o`3ooolH0?ooo`008@3oool00`000000oooo0?oo
o`0[0?ooo`@00000o`3ooolF0?ooo`008@3oool00`000000oooo0?ooo`0/0?ooo`D00000o`3ooolD
0?ooo`008@3oool00`000000oooo0?ooo`0^0?ooo`D00000o`3ooolB0?ooo`008@3oool200000340
oooo1000003o0?oooa40oooo000Q0?ooo`030000003oool0oooo0380oooo1000003o0?ooo`l0oooo
000Q0?ooo`030000003oool0oooo03<0oooo1@00003o0?ooo`d0oooo000Q0?ooo`030000003oool0
oooo03D0oooo1000003o0?ooo``0oooo000Q0?ooo`030000003oool0oooo03L0oooo1000003o0?oo
o`X0oooo000Q0?ooo`030000003oool0oooo03P0oooo1@00003o0?ooo`P0oooo00070?ooo`050>k^
kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo1@0000050?ooo`030000003oool0oooo03X0
oooo1000003o0?ooo`L0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0
oooo00D0VIVI028R8P3^k^h0oooo04A4A0050?ooo`030000003oool0oooo03`0oooo1000003o0?oo
o`D0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`2IVIT08R8R0>k^kP060?oo
o`030000003oool0oooo03d0oooo1@00003o0?ooo`<0oooo00070?ooo`050000003oool0oooo0?oo
o`0000003@3oool00`2IVIT08R8R0>k^kP050?ooo`<00000?`3oool400000?l0oooo0P3oool000L0
oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1VIVH0oooo00@0oooo00<000000?oo
o`3oool0@@3oool400000?l0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0480oooo1@00003m0?ooo`001`3oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@050?ooo`030000003oool0
oooo04@0oooo1000003l0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00/0oooo00D0VIVI
014A4@0000008R8R0<c<c0050?ooo`030000003oool0oooo04H0oooo1000003j0?ooo`008@3oool0
0`000000oooo0?ooo`170?ooo`@00000n@3oool00240oooo00<000000?ooo`3oool0B@3oool40000
0?L0oooo000Q0?ooo`030000003oool0oooo04X0oooo1@00003e0?ooo`008@3oool00`000000oooo
0?ooo`1<0?ooo`@00000m03oool00240oooo0P00001?0?ooo`@00000lP3oool00240oooo00<00000
0?ooo`3oool0C`3oool500000?00oooo000Q0?ooo`030000003oool0oooo0540oooo1000003_0?oo
o`008@3oool00`000000oooo0?ooo`1C0?ooo`@00000k@3oool00240oooo00<000000?ooo`3oool0
E03oool400000>`0oooo000Q0?ooo`030000003oool0oooo05H0oooo0`00003[0?ooo`008@3oool0
0`000000oooo0?ooo`1G0?ooo`@00000j@3oool00240oooo00<000000?ooo`3oool0F03oool40000
0>P0oooo000Q0?ooo`030000003oool0oooo05X0oooo0`00003W0?ooo`008@3oool2000005`0oooo
1000003U0?ooo`008@3oool00`000000oooo0?ooo`1L0?ooo`@00000i03oool00240oooo00<00000
0?ooo`3oool0GP3oool300000><0oooo000Q0?ooo`030000003oool0oooo05l0oooo1000003Q0?oo
o`008@3oool00`000000oooo0?ooo`1P0?ooo`@00000h03oool00240oooo00<000000?ooo`3oool0
HP3oool400000=h0oooo000Q0?ooo`030000003oool0oooo06<0oooo1000003M0?ooo`008@3oool0
0`000000oooo0?ooo`1U0?ooo`@00000f`3oool00240oooo00<000000?ooo`3oool0IP3oool40000
0=X0oooo000Q0?ooo`800000J@3oool400000=P0oooo000Q0?ooo`030000003oool0oooo06T0oooo
1000003G0?ooo`008@3oool00`000000oooo0?ooo`1[0?ooo`@00000e@3oool00240oooo00<00000
0?ooo`3oool0K03oool400000=@0oooo000Q0?ooo`030000003oool0oooo06h0oooo0`00003C0?oo
o`008@3oool00`000000oooo0?ooo`1_0?ooo`<00000dP3oool00240oooo00<000000?ooo`3oool0
L03oool300000=40oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8PH0oooo
0P0000000`0A4A40oooo0?ooo`030?ooo`030000003oool0oooo0740oooo1000003?0?ooo`001`3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R870?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0LP3oool400000<h0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A40
2`3oool5000000D0oooo00<000000?ooo`3oool0M03oool300000<d0oooo00070?ooo`050000003o
ool0oooo0?ooo`0000002`3oool01014A4@0gMgM0?ooo`0000060?ooo`<00000M@3oool300000<`0
oooo00070?ooo`050000003oool0oooo0?ooo`0000002`3oool0103MgMd0EEEE0?ooo`0000060?oo
o`030000003oool0oooo07H0oooo0`00003;0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A
00`0oooo00<0MgMg0<c<c00000001P3oool00`000000oooo0?ooo`1g0?ooo`<00000bP3oool000L0
oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`030>k^kP14A4@0000000H0oooo00<000000?oo
o`3oool0N03oool400000<P0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h03@3oool00`1g
MgL000000?ooo`050?ooo`030000003oool0oooo07T0oooo100000370?ooo`008@3oool00`000000
oooo0?ooo`1k0?ooo`<00000aP3oool00240oooo00<000000?ooo`3oool0O03oool300000<D0oooo
000Q0?ooo`030000003oool0oooo07d0oooo0`0000340?ooo`008@3oool00`000000oooo0?ooo`1n
0?ooo`@00000`P3oool00240oooo0P0000200?ooo`@00000`@3oool00240oooo00<000000?ooo`3o
ool0P@3oool300000<00oooo000Q0?ooo`030000003oool0oooo0880oooo0`00002o0?ooo`008@3o
ool00`000000oooo0?ooo`230?ooo`<00000_P3oool00240oooo00<000000?ooo`3oool0Q03oool4
00000;`0oooo000Q0?ooo`030000003oool0oooo08D0oooo1000002k0?ooo`008@3oool00`000000
oooo0?ooo`270?ooo`<00000^P3oool00240oooo00<000000?ooo`3oool0R03oool300000;T0oooo
000Q0?ooo`030000003oool0oooo08T0oooo0`00002h0?ooo`008@3oool2000008/0oooo0`00002g
0?ooo`008@3oool00`000000oooo0?ooo`2;0?ooo`<00000]P3oool00240oooo00<000000?ooo`3o
ool0S03oool300000;D0oooo000Q0?ooo`030000003oool0oooo08d0oooo0`00002d0?ooo`008@3o
ool00`000000oooo0?ooo`2>0?ooo`<00000/`3oool00240oooo00<000000?ooo`3oool0S`3oool4
00000;40oooo000Q0?ooo`030000003oool0oooo0900oooo1@00002_0?ooo`008@3oool00`000000
oooo0?ooo`2A0?ooo`L00000[03oool00240oooo00<000000?ooo`3oool0U03oool700000:T0oooo
000Q0?ooo`800000V03oool700000:H0oooo000Q0?ooo`030000003oool0oooo09X0oooo1`00002S
0?ooo`008@3oool00`000000oooo0?ooo`2M0?ooo`L00000X03oool00240oooo00<000000?ooo`3o
ool0X03oool7000009d0oooo000Q0?ooo`030000003oool0oooo0:<0oooo1`00002J0?ooo`008@3o
ool00`000000oooo0?ooo`2V0?ooo`H00000V03oool00240oooo00<000000?ooo`3oool0Z@3oool5
000009H0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo00D0k^k^
03<c<`0000004A4A0<c<c0050?ooo`030000003oool0oooo0:/0oooo1@00002D0?ooo`001`3oool0
1@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R8R80
1@3oool00`000000oooo0?ooo`2]0?ooo`H00000T@3oool000L0oooo00D04A4A0?ooo`3oool0oooo
014A4@0;0?ooo`050000003oool0oooo0?ooo`0000001@3oool300000:l0oooo1P00002?0?ooo`00
1`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P050?oo
o`030000003oool0oooo0;80oooo1@00002=0?ooo`001`3oool01@000000oooo0?ooo`3oool00000
00/0oooo00D0000005EEE@0000004A4A0<c<c0050?ooo`030000003oool0oooo0;@0oooo1@00002;
0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo00<0EEEE08R8R03oool01`3oool0
0`000000oooo0?ooo`2f0?ooo`D00000R@3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;
0?ooo`030=gMg@0A4A40VIVI00L0oooo00<000000?ooo`3oool0^03oool5000008L0oooo00070?oo
o`050>k^kP0c<c<0000003<c<`3^k^h0303oool0103<c<`0A4A40000000A4A450?ooo`030000003o
ool0oooo0;X0oooo1@0000250?ooo`008@3oool00`000000oooo0?ooo`2l0?ooo`D00000P`3oool0
0240oooo00<000000?ooo`3oool0_P3oool500000840oooo000Q0?ooo`030000003oool0oooo0<00
oooo1@00001o0?ooo`008@3oool00`000000oooo0?ooo`320?ooo`D00000O@3oool00240oooo0P00
00350?ooo`D00000N`3oool00240oooo00<000000?ooo`3oool0aP3oool5000007T0oooo000Q0?oo
o`030000003oool0oooo0<P0oooo1000001h0?ooo`008@3oool00`000000oooo0?ooo`3:0?ooo`@0
0000MP3oool00240oooo00<000000?ooo`3oool0b`3oool5000007@0oooo000Q0?ooo`030000003o
ool0oooo0<d0oooo1@00001b0?ooo`008@3oool00`000000oooo0?ooo`3?0?ooo`D00000L03oool0
0240oooo00<000000?ooo`3oool0d@3oool5000006h0oooo000Q0?ooo`030000003oool0oooo0=<0
oooo1@00001/0?ooo`008@3oool200000=H0oooo1000001[0?ooo`008@3oool00`000000oooo0?oo
o`3G0?ooo`@00000J@3oool00240oooo00<000000?ooo`3oool0f03oool5000006L0oooo000Q0?oo
o`030000003oool0oooo0=X0oooo1@00001U0?ooo`008@3oool00`000000oooo0?ooo`3L0?ooo`@0
0000I03oool00240oooo00<000000?ooo`3oool0gP3oool400000680oooo000Q0?ooo`030000003o
ool0oooo0=l0oooo1000001Q0?ooo`008@3oool00`000000oooo0?ooo`3Q0?ooo`@00000G`3oool0
0240oooo00<000000?ooo`3oool0hP3oool4000005h0oooo000Q0?ooo`800000i@3oool4000005`0
oooo000Q0?ooo`030000003oool0oooo0>D0oooo1000001K0?ooo`008@3oool00`000000oooo0?oo
o`3W0?ooo`@00000F@3oool00240oooo00<000000?ooo`3oool0j03oool4000005P0oooo000Q0?oo
o`030000003oool0oooo0>X0oooo1000001F0?ooo`008@3oool00`000000oooo0?ooo`3[0?ooo`@0
0000E@3oool00240oooo00<000000?ooo`3oool0k@3oool4000005<0oooo00070?ooo`050>k^kP0c
<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo00D0c<c<028R8P0000008R8R0<c<c0050?ooo`03
0000003oool0oooo0>h0oooo1000001B0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0
oooo0P0R8R840?ooo`05028R8P2IVIT0oooo09VIV@0R8R801@3oool00`000000oooo0?ooo`3`0?oo
o`@00000D03oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo
0?ooo`0000001@3oool300000?40oooo1000001?0?ooo`001`3oool01@000000oooo0?ooo`3oool0
000000/0oooo00D0<c<c09VIV@3oool0VIVI03<c<`050?ooo`030000003oool0oooo0?<0oooo1000
001=0?ooo`001`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<0000000000000000
0<c<c0050?ooo`030000003oool0oooo0?@0oooo1000001<0?ooo`001`3oool01@0A4A40oooo0?oo
o`3oool04A4A00/0oooo00D04A4A0;^k^`3oool0^k^k014A4@050?ooo`030000003oool0oooo0?H0
oooo1000001:0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3o
ool0^k^k000000050?ooo`030000003oool0oooo0?L0oooo100000190?ooo`001`3oool01@3^k^h0
<c<c0000000c<c<0k^k^00/0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP050?ooo`030000003oool0
oooo0?T0oooo100000170?ooo`008@3oool00`000000oooo0?ooo`3j0?ooo`@00000AP3oool00240
oooo00<000000?ooo`3oool0o03oool3000004D0oooo000Q0?ooo`030000003oool0oooo0?d0oooo
100000130?ooo`008@3oool200000?l0oooo100000120?ooo`008@3oool00`000000oooo0?ooo`3o
0?ooo`40oooo100000100?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`80oooo1000000o0?oo
o`008@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo0`00000n0?ooo`008@3oool00`000000oooo
0?ooo`3o0?ooo`D0oooo1000000l0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`H0oooo1000
000k0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo1000000i0?ooo`008@3oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo1000000h0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`/0
oooo0`00000g0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo``0oooo1000000e0?ooo`008@3o
ool200000?l0oooo3P3oool4000003@0oooo000Q0?ooo`030000003oool0oooo0?l0oooo3`3oool4
00000380oooo000Q0?ooo`030000003oool0oooo0?l0oooo403oool400000340oooo000Q0?ooo`03
0000003oool0oooo0?l0oooo4P3oool4000002l0oooo000Q0?ooo`030000003oool0oooo0?l0oooo
4`3oool4000002h0oooo000Q0?ooo`030000003oool0oooo0?l0oooo5@3oool3000002d0oooo000Q
0?ooo`030000003oool0oooo0?l0oooo5P3oool4000002/0oooo000Q0?ooo`030000003oool0oooo
0?l0oooo5`3oool4000002X0oooo000Q0?ooo`030000003oool0oooo0?l0oooo6@3oool4000002P0
oooo000Q0?ooo`800000o`3ooolK0?ooo`@000009`3oool00240oooo00<000000?ooo`3oool0o`3o
oolL0?ooo`<000009P3oool00240oooo00<000000?ooo`3oool0o`3ooolM0?ooo`@00000903oool0
0240oooo00<000000?ooo`3oool0o`3ooolN0?ooo`@000008`3oool00240oooo00<000000?ooo`3o
ool0o`3ooolP0?ooo`<000008P3oool00240oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`@00000
803oool00240oooo00<000000?ooo`3oool0o`3ooolR0?ooo`@000007`3oool001P0oooo10000000
0`0A4A40oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo903oool3000001h0oooo000J0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`<000007@3oool001X0
oooo00<000000?ooo`3oool0103oool300000?l0oooo9P3oool3000001`0oooo000J0?ooo`030000
003oool0oooo0?l0oooo;P3oool2000001`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03o
ool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000H0?ooo`80EEEE00<000000?ooo`3oool0o`3ooom<0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00WP3oool01@2IVIT0000000000014A4@0^k^k01P0oooo00D0k^k^
03<c<`000000<c<c0>k^kP050?ooo`808R8R1@3oool400000003014A4@3oool0oooo09D0oooo002N
0?ooo`05014A4@2k^k/0k^k^07MgM`0A4A402@3oool6000000T0oooo00D0MgMg09VIV@3oool0VIVI
07MgM`050?ooo`808R8R1`3oool00`000000oooo0?ooo`2G0?ooo`00WP3oool00`000000oooo0?oo
o`0J0?ooo`05014A4@3oool0oooo0?ooo`0A4A403P3oool00`000000oooo0?ooo`2G0?ooo`007`3o
ool01@0A4A4000000000000000004A4A07X0oooo00<000000?ooo`3oool02`3oool6000000T0oooo
00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo09L0oooo000Q0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool06P3oool01@000000oooo0?ooo`3oool0000000h0
oooo00<000000?ooo`3oool0U`3oool00240oooo00<000000?ooo`3oool0N03oool00`0A4A400000
00000003000001T0oooo00D04A4A0?ooo`3oool0oooo014A4@0>0?ooo`030000003oool0oooo09L0
oooo000Q0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool06P3oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg00h0oooo00<000000?ooo`3oool0U`3oool00240oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`0J0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool205EEE@03
0000003oool0oooo09L0oooo000N0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0o`3ooom20?ooo`007P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0
oooo@P3oool001h0oooo1`00003o0?oood@0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?oo
ofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .0235 L
.08481 .0494 L
.12636 .07422 L
.16632 .09877 L
.20885 .12585 L
.2498 .15305 L
.29331 .18336 L
.33524 .21412 L
.37557 .24528 L
.41848 .28023 L
.4598 .31572 L
.48055 .33424 L
.48962 .34249 L
.49442 .34688 L
.49705 .3493 L
.49834 .3505 L
.49953 .35159 L
.50089 .35231 L
.50161 .35253 L
.50237 .35276 L
.50495 .35356 L
.50998 .35515 L
.51991 .35837 L
.54183 .36585 L
.5817 .3808 L
.62415 .39858 L
.665 .41744 L
.70843 .43925 L
.75027 .46183 L
.79051 .48485 L
.83333 .51056 L
.87456 .53628 L
.9142 .5617 L
.95642 .58928 L
.99704 .61608 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1@00000;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`D00000=`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`3o
ool01000003o0?oood40oooo000Q0?ooo`040000003oool0oooo0?ooo`D00000o`3ooolo0?ooo`00
8@3oool00`000000oooo0?ooo`030?ooo`@00000o`3oooln0?ooo`008@3oool00`000000oooo0?oo
o`050?ooo`@00000o`3oooll0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`D00000o`3ooolj
0?ooo`008@3oool00`000000oooo0?ooo`080?ooo`D00000o`3ooolh0?ooo`008@3oool2000000/0
oooo1000003o0?ooocL0oooo000Q0?ooo`030000003oool0oooo00`0oooo1000003o0?ooocD0oooo
000Q0?ooo`030000003oool0oooo00d0oooo1@00003o0?oooc<0oooo000Q0?ooo`030000003oool0
oooo00l0oooo1@00003o0?oooc40oooo000Q0?ooo`030000003oool0oooo0140oooo1000003o0?oo
oc00oooo000Q0?ooo`030000003oool0oooo01<0oooo1000003o0?ooobh0oooo000Q0?ooo`030000
003oool0oooo01@0oooo1@00003o0?ooob`0oooo000Q0?ooo`030000003oool0oooo01H0oooo1@00
003o0?ooobX0oooo000Q0?ooo`030000003oool0oooo01P0oooo1000003o0?ooobT0oooo000Q0?oo
o`8000006`3oool400000?l0oooo9`3oool00240oooo00<000000?ooo`3oool06`3oool500000?l0
oooo9@3oool00240oooo00<000000?ooo`3oool07@3oool400000?l0oooo903oool00240oooo00<0
00000?ooo`3oool07`3oool400000?l0oooo8P3oool00240oooo00<000000?ooo`3oool0803oool5
00000?l0oooo803oool00240oooo00<000000?ooo`3oool08P3oool500000?l0oooo7P3oool00240
oooo00<000000?ooo`3oool0903oool400000?l0oooo7@3oool00240oooo00<000000?ooo`3oool0
9P3oool400000?l0oooo6`3oool00240oooo00<000000?ooo`3oool09`3oool500000?l0oooo6@3o
ool00240oooo00<000000?ooo`3oool0:@3oool400000?l0oooo603oool00240oooo0P00000/0?oo
o`@00000o`3ooolF0?ooo`008@3oool00`000000oooo0?ooo`0/0?ooo`D00000o`3ooolD0?ooo`00
8@3oool00`000000oooo0?ooo`0^0?ooo`@00000o`3ooolC0?ooo`008@3oool00`000000oooo0?oo
o`0`0?ooo`<00000o`3ooolB0?ooo`008@3oool00`000000oooo0?ooo`0a0?ooo`@00000o`3oool@
0?ooo`008@3oool00`000000oooo0?ooo`0b0?ooo`@00000o`3oool?0?ooo`001`3oool01@3^k^h0
<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`D000001@3oool00`000000oooo0?ooo`0d0?oo
o`<00000o`3oool>0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?oo
o`0509VIV@0R8R80k^k^0?ooo`14A4@01@3oool00`000000oooo0?ooo`0e0?ooo`@00000o`3oool<
0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<0VIVI028R8P3^k^h01P3oool0
0`000000oooo0?ooo`0f0?ooo`@00000o`3oool;0?ooo`001`3oool01@000000oooo0?ooo`3oool0
000000d0oooo00<0VIVI028R8P3^k^h01@3oool3000003P0oooo0`00003o0?ooo`X0oooo00070?oo
o`050000003oool0oooo0?ooo`0000003P3oool00`1gMgL0IVIV0?ooo`040?ooo`030000003oool0
oooo03T0oooo1000003o0?ooo`P0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03X0oooo1000003o0?ooo`L0oooo00070?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2IVIT04A4A00D0oooo00<0
00000?ooo`3oool0?03oool400000?l0oooo1@3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`0509VIV@0A4A400000028R8P3<c<`01@3oool00`000000oooo0?ooo`0m0?ooo`D00000
o`3oool30?ooo`008@3oool00`000000oooo0?ooo`0o0?ooo`@00000o`3oool20?ooo`008@3oool0
0`000000oooo0?ooo`110?ooo`@00000o`3oool00240oooo00<000000?ooo`3oool0@P3oool50000
0?d0oooo000Q0?ooo`030000003oool0oooo04@0oooo1000003l0?ooo`008@3oool2000004L0oooo
1000003j0?ooo`008@3oool00`000000oooo0?ooo`170?ooo`@00000n@3oool00240oooo00<00000
0?ooo`3oool0B@3oool400000?L0oooo000Q0?ooo`030000003oool0oooo04X0oooo1000003f0?oo
o`008@3oool00`000000oooo0?ooo`1<0?ooo`@00000m03oool00240oooo00<000000?ooo`3oool0
C@3oool400000?<0oooo000Q0?ooo`030000003oool0oooo04l0oooo0`00003b0?ooo`008@3oool0
0`000000oooo0?ooo`1@0?ooo`@00000l03oool00240oooo00<000000?ooo`3oool0D@3oool40000
0>l0oooo000Q0?ooo`800000E03oool400000>d0oooo000Q0?ooo`030000003oool0oooo05@0oooo
1000003/0?ooo`008@3oool00`000000oooo0?ooo`1F0?ooo`<00000j`3oool00240oooo00<00000
0?ooo`3oool0E`3oool400000>T0oooo000Q0?ooo`030000003oool0oooo05P0oooo1000003X0?oo
o`008@3oool00`000000oooo0?ooo`1J0?ooo`<00000i`3oool00240oooo00<000000?ooo`3oool0
F`3oool400000>D0oooo000Q0?ooo`030000003oool0oooo05`0oooo1000003T0?ooo`008@3oool0
0`000000oooo0?ooo`1N0?ooo`<00000h`3oool00240oooo0P00001P0?ooo`@00000h@3oool00240
oooo00<000000?ooo`3oool0H03oool400000>00oooo000Q0?ooo`030000003oool0oooo0680oooo
0`00003O0?ooo`008@3oool00`000000oooo0?ooo`1S0?ooo`@00000g@3oool00240oooo00<00000
0?ooo`3oool0I03oool400000=`0oooo000Q0?ooo`030000003oool0oooo06H0oooo0`00003K0?oo
o`008@3oool00`000000oooo0?ooo`1W0?ooo`@00000f@3oool000L0oooo00D0k^k^03<c<`000000
<c<c0>k^kP050?ooo`808R8R1P3oool200000003014A4@3oool0oooo00<0oooo00<000000?ooo`3o
ool0J03oool400000=P0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1Z0?ooo`<00000e`3oool000L0oooo
00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`D000001@3oool00`000000oooo0?ooo`1[0?ooo`@0
0000e@3oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`0404A4A03MgMd0oooo0000
00H0oooo0`00001/0?ooo`@00000e03oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`040=gMg@1EEED0oooo000000H0oooo00<000000?ooo`3oool0KP3oool300000=<0oooo00070?oo
o`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<000000060?ooo`030000003oool0
oooo06l0oooo0`00003B0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^
04A4A00000001P3oool00`000000oooo0?ooo`1`0?ooo`<00000d@3oool000L0oooo00D0k^k^03<c
<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo00D0oooo00<000000?ooo`3oool0L@3oool4
00000<l0oooo000Q0?ooo`030000003oool0oooo0780oooo1000003>0?ooo`008@3oool00`000000
oooo0?ooo`1d0?ooo`<00000c@3oool00240oooo00<000000?ooo`3oool0M@3oool300000<`0oooo
000Q0?ooo`030000003oool0oooo07H0oooo0`00003;0?ooo`008@3oool2000007P0oooo0`00003:
0?ooo`008@3oool00`000000oooo0?ooo`1h0?ooo`@00000b03oool00240oooo00<000000?ooo`3o
ool0N@3oool400000<L0oooo000Q0?ooo`030000003oool0oooo07/0oooo0`0000360?ooo`008@3o
ool00`000000oooo0?ooo`1l0?ooo`<00000a@3oool00240oooo00<000000?ooo`3oool0O@3oool3
00000<@0oooo000Q0?ooo`030000003oool0oooo07h0oooo100000320?ooo`008@3oool00`000000
oooo0?ooo`1o0?ooo`@00000`@3oool00240oooo00<000000?ooo`3oool0P@3oool300000<00oooo
000Q0?ooo`800000P`3oool300000;l0oooo000Q0?ooo`030000003oool0oooo08<0oooo0`00002n
0?ooo`008@3oool00`000000oooo0?ooo`240?ooo`<00000_@3oool00240oooo00<000000?ooo`3o
ool0Q@3oool300000;`0oooo000Q0?ooo`030000003oool0oooo08H0oooo0`00002k0?ooo`008@3o
ool00`000000oooo0?ooo`270?ooo`<00000^P3oool00240oooo00<000000?ooo`3oool0R03oool3
00000;T0oooo000Q0?ooo`030000003oool0oooo08T0oooo0`00002h0?ooo`008@3oool00`000000
oooo0?ooo`2:0?ooo`@00000]P3oool00240oooo0P00002<0?ooo`@00000]@3oool00240oooo00<0
00000?ooo`3oool0S@3oool300000;@0oooo000Q0?ooo`030000003oool0oooo08h0oooo0`00002c
0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`@00000/@3oool00240oooo00<000000?ooo`3o
ool0T03oool500000:l0oooo000Q0?ooo`030000003oool0oooo0940oooo1`00002/0?ooo`008@3o
ool00`000000oooo0?ooo`2D0?ooo`L00000Z@3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^
kP050?ooo`808R8R103oool01@3^k^h0<c<c0000000A4A40c<c<00D0oooo00<000000?ooo`3oool0
U`3oool700000:H0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo
00D0EEEE07MgM`3oool0VIVI028R8P050?ooo`030000003oool0oooo09X0oooo1`00002S0?ooo`00
1`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo00D000000?ooo`3oool0oooo000000050?oo
o`<00000W@3oool700000:00oooo00070?ooo`050000003oool0oooo0?ooo`0000002`3oool01@00
0000VIVI0?ooo`2IVIT08R8R00D0oooo00<000000?ooo`3oool0X03oool7000009d0oooo00070?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@000000EEEE0000000A4A40c<c<00D0oooo00<0
00000?ooo`3oool0X`3oool7000009X0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3o
ool00`1EEED0R8R80?ooo`070?ooo`030000003oool0oooo0:H0oooo1P00002H0?ooo`001`3oool0
1@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT01`3oool00`000000oooo0?oo
o`2Y0?ooo`D00000UP3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`040<c<c014
A4@00000014A4@D0oooo00<000000?ooo`3oool0Z`3oool5000009@0oooo000Q0?ooo`030000003o
ool0oooo0:d0oooo1P00002A0?ooo`008@3oool00`000000oooo0?ooo`2_0?ooo`H00000S`3oool0
0240oooo00<000000?ooo`3oool0/P3oool5000008d0oooo000Q0?ooo`030000003oool0oooo0;@0
oooo1@00002;0?ooo`008@3oool200000;L0oooo1P0000280?ooo`008@3oool00`000000oooo0?oo
o`2h0?ooo`H00000QP3oool00240oooo00<000000?ooo`3oool0^`3oool5000008@0oooo000Q0?oo
o`030000003oool0oooo0;d0oooo1P0000210?ooo`008@3oool00`000000oooo0?ooo`2o0?ooo`H0
0000O`3oool00240oooo00<000000?ooo`3oool0`P3oool5000007d0oooo000Q0?ooo`030000003o
ool0oooo0<@0oooo1@00001k0?ooo`008@3oool00`000000oooo0?ooo`360?ooo`D00000N@3oool0
0240oooo00<000000?ooo`3oool0b03oool4000007P0oooo000Q0?ooo`800000b`3oool4000007H0
oooo000Q0?ooo`030000003oool0oooo0</0oooo1@00001d0?ooo`008@3oool00`000000oooo0?oo
o`3=0?ooo`D00000LP3oool00240oooo00<000000?ooo`3oool0c`3oool500000700oooo000Q0?oo
o`030000003oool0oooo0=40oooo1@00001^0?ooo`008@3oool00`000000oooo0?ooo`3C0?ooo`D0
0000K03oool00240oooo00<000000?ooo`3oool0e@3oool4000006/0oooo000Q0?ooo`030000003o
ool0oooo0=L0oooo1000001Y0?ooo`008@3oool00`000000oooo0?ooo`3H0?ooo`D00000I`3oool0
0240oooo0P00003K0?ooo`D00000I@3oool00240oooo00<000000?ooo`3oool0g03oool5000006<0
oooo000Q0?ooo`030000003oool0oooo0=h0oooo1@00001Q0?ooo`008@3oool00`000000oooo0?oo
o`3P0?ooo`D00000G`3oool00240oooo00<000000?ooo`3oool0hP3oool5000005d0oooo000Q0?oo
o`030000003oool0oooo0>@0oooo1@00001K0?ooo`008@3oool00`000000oooo0?ooo`3V0?ooo`D0
0000F@3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R103oool01@3<c<`0
8R8R0000000R8R80c<c<00D0oooo00<000000?ooo`3oool0j03oool4000005P0oooo00070?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D08R8R09VIV@3oool0VIVI028R8P05
0?ooo`030000003oool0oooo0>X0oooo1000001F0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool0
4A4A00/0oooo00D000000?ooo`3oool0oooo000000050?ooo`<00000j`3oool4000005D0oooo0007
0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c00D0oooo
00<000000?ooo`3oool0k@3oool4000005<0oooo00070?ooo`050000003oool0oooo0?ooo`000000
2`3oool01@3<c<`00000000000000000c<c<00D0oooo00<000000?ooo`3oool0kP3oool400000580
oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A
00D0oooo00<000000?ooo`3oool0l03oool400000500oooo00070?ooo`0507MgM`2IVIT0oooo09VI
V@1gMgL02`3oool01@000000^k^k0?ooo`2k^k/0000000D0oooo00<000000?ooo`3oool0l@3oool4
000004l0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2ZZZX04A4A0000000A
4A40ZZZZ00D0oooo00<000000?ooo`3oool0l`3oool4000004d0oooo000Q0?ooo`030000003oool0
oooo0?@0oooo1000001<0?ooo`008@3oool00`000000oooo0?ooo`3f0?ooo`@00000BP3oool00240
oooo00<000000?ooo`3oool0m`3oool5000004P0oooo000Q0?ooo`800000nP3oool4000004L0oooo
000Q0?ooo`030000003oool0oooo0?/0oooo100000150?ooo`008@3oool00`000000oooo0?ooo`3l
0?ooo`D00000@`3oool00240oooo00<000000?ooo`3oool0oP3oool400000480oooo000Q0?ooo`03
0000003oool0oooo0?l0oooo0@3oool400000400oooo000Q0?ooo`030000003oool0oooo0?l0oooo
0P3oool4000003l0oooo000Q0?ooo`030000003oool0oooo0?l0oooo103oool4000003d0oooo000Q
0?ooo`030000003oool0oooo0?l0oooo1@3oool5000003/0oooo000Q0?ooo`030000003oool0oooo
0?l0oooo1`3oool4000003X0oooo000Q0?ooo`030000003oool0oooo0?l0oooo2@3oool4000003P0
oooo000Q0?ooo`800000o`3oool;0?ooo`@00000=`3oool00240oooo00<000000?ooo`3oool0o`3o
ool<0?ooo`@00000=@3oool00240oooo00<000000?ooo`3oool0o`3oool=0?ooo`@00000=03oool0
0240oooo00<000000?ooo`3oool0o`3oool?0?ooo`@00000<P3oool00240oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`D00000<03oool00240oooo00<000000?ooo`3oool0o`3ooolB0?ooo`@00000
;`3oool00240oooo00<000000?ooo`3oool0o`3ooolD0?ooo`@00000;@3oool00240oooo00<00000
0?ooo`3oool0o`3ooolE0?ooo`D00000:`3oool00240oooo00<000000?ooo`3oool0o`3ooolG0?oo
o`@00000:P3oool00240oooo0P00003o0?oooaX0oooo1000000X0?ooo`008@3oool00`000000oooo
0?ooo`3o0?oooaX0oooo1000000W0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooa`0oooo1000
000U0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooad0oooo1000000T0?ooo`008@3oool00`00
0000oooo0?ooo`3o0?oooal0oooo1000000R0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooob00
oooo1000000Q0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooob80oooo1000000O0?ooo`00603o
ool400000003014A4@3oool0oooo0080oooo00<000000?ooo`3oool0o`3ooolS0?ooo`@000007P3o
ool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooobD0oooo0`00000M
0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`<00000o`3ooolV0?ooo`<00000703oool001X0
oooo00<000000?ooo`3oool0o`3oool^0?ooo`800000703oool001X0oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0
oooo0?l0ooooC03oool001P0oooo0P1EEED00`000000oooo0?ooo`3o0?oood`0oooo003o0?ooofT0
oooo003o0?ooofT0oooo003o0?ooofT0oooo002J0?ooo`0509VIV@000000000004A4A02k^k/0603o
ool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?ooo`@0000000<04A4A0?ooo`3oool0
1@00002D0?ooo`00VP3oool01@0A4A40^k^k0>k^kP1gMgL04A4A00T0oooo1P0000090?ooo`0507Mg
M`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool00P3oool01@2IVIT0
8R8R0>k^kP3oool0A4A409@0oooo002J0?ooo`030000003oool0oooo01X0oooo00D04A4A0?ooo`3o
ool0oooo014A4@0>0?ooo`030000003oool0oooo00<0oooo00<0VIVI028R8P3^k^h0U@3oool001l0
oooo00D04A4A0000000000000000014A4@1f0?ooo`030000003oool0oooo00/0oooo1P0000090?oo
o`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`040?ooo`0309VIV@0R8R80
k^k^09@0oooo000Q0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool06P3oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool01@3oool00`1gMgL0IVIV0?ooo`2C
0?ooo`008@3oool00`000000oooo0?ooo`1d0?ooo`03014A4@000000000000<000006@3oool01@0A
4A40oooo0?ooo`3oool04A4A00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2B
0?ooo`008@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01X0oooo00D0MgMg09VI
V@3oool0VIVI07MgM`0>0?ooo`030000003oool0oooo0080oooo00D000000;^k^`3oool0VIVI014A
4@2D0?ooo`008@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01X0oooo00D0k^k^
03<c<`000000<c<c0>k^kP0<0?ooo`80EEEE00<000000?ooo`3oool00P3oool01@2IVIT04A4A0000
000R8R80c<c<09@0oooo000N0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
o`3ooom20?ooo`007P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0oooo
@P3oool001h0oooo1`00003o0?oood@0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .02601 L
.08481 .05459 L
.12636 .08184 L
.16632 .10861 L
.20885 .1379 L
.2498 .16702 L
.29331 .19913 L
.33524 .23135 L
.37557 .26364 L
.41848 .29948 L
.4598 .3355 L
.48055 .35415 L
.48962 .36244 L
.49442 .36685 L
.49705 .36927 L
.49834 .37047 L
.49953 .37157 L
.50089 .37228 L
.50161 .3725 L
.50237 .37274 L
.50495 .37354 L
.50998 .37512 L
.51991 .37832 L
.54183 .38569 L
.5817 .40019 L
.62415 .41716 L
.665 .43491 L
.70843 .45523 L
.75027 .47608 L
.79051 .49721 L
.83333 .52067 L
.87456 .54405 L
.9142 .56709 L
.95642 .59204 L
.99704 .61626 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`D00000=`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`00
00000`00003o0?oood80oooo000Q0?ooo`040000003oool0oooo0?ooo`@00000o`3ooom00?ooo`00
8@3oool00`000000oooo0?ooo`020?ooo`@00000o`3ooolo0?ooo`008@3oool00`000000oooo0?oo
o`040?ooo`@00000o`3ooolm0?ooo`008@3oool00`000000oooo0?ooo`050?ooo`@00000o`3oooll
0?ooo`008@3oool00`000000oooo0?ooo`070?ooo`@00000o`3ooolj0?ooo`008@3oool2000000T0
oooo1@00003o0?ooocP0oooo000Q0?ooo`030000003oool0oooo00X0oooo1000003o0?ooocL0oooo
000Q0?ooo`030000003oool0oooo00`0oooo1000003o0?ooocD0oooo000Q0?ooo`030000003oool0
oooo00d0oooo1@00003o0?oooc<0oooo000Q0?ooo`030000003oool0oooo00l0oooo1@00003o0?oo
oc40oooo000Q0?ooo`030000003oool0oooo0140oooo1000003o0?oooc00oooo000Q0?ooo`030000
003oool0oooo01<0oooo1000003o0?ooobh0oooo000Q0?ooo`030000003oool0oooo01@0oooo1@00
003o0?ooob`0oooo000Q0?ooo`030000003oool0oooo01H0oooo1000003o0?ooob/0oooo000Q0?oo
o`8000006@3oool400000?l0oooo:@3oool00240oooo00<000000?ooo`3oool06@3oool400000?l0
oooo:03oool00240oooo00<000000?ooo`3oool06`3oool400000?l0oooo9P3oool00240oooo00<0
00000?ooo`3oool0703oool400000?l0oooo9@3oool00240oooo00<000000?ooo`3oool07P3oool4
00000?l0oooo8`3oool00240oooo00<000000?ooo`3oool07`3oool400000?l0oooo8P3oool00240
oooo00<000000?ooo`3oool08@3oool400000?l0oooo803oool00240oooo00<000000?ooo`3oool0
8P3oool400000?l0oooo7`3oool00240oooo00<000000?ooo`3oool0903oool400000?l0oooo7@3o
ool00240oooo00<000000?ooo`3oool09@3oool400000?l0oooo703oool00240oooo0P00000X0?oo
o`@00000o`3ooolJ0?ooo`008@3oool00`000000oooo0?ooo`0X0?ooo`@00000o`3ooolI0?ooo`00
8@3oool00`000000oooo0?ooo`0Z0?ooo`@00000o`3ooolG0?ooo`008@3oool00`000000oooo0?oo
o`0[0?ooo`@00000o`3ooolF0?ooo`008@3oool00`000000oooo0?ooo`0]0?ooo`@00000o`3ooolD
0?ooo`008@3oool00`000000oooo0?ooo`0^0?ooo`@00000o`3ooolC0?ooo`001`3oool01@3^k^h0
<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`D000001@3oool00`000000oooo0?ooo`0`0?oo
o`<00000o`3ooolB0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?oo
o`0509VIV@0R8R80k^k^0?ooo`14A4@01@3oool00`000000oooo0?ooo`0a0?ooo`@00000o`3oool@
0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<0VIVI028R8P3^k^h01P3oool0
0`000000oooo0?ooo`0b0?ooo`@00000o`3oool?0?ooo`001`3oool01@000000oooo0?ooo`3oool0
000000d0oooo00<0VIVI028R8P3^k^h01@3oool3000003@0oooo0`00003o0?ooo`h0oooo00070?oo
o`050000003oool0oooo0?ooo`0000003P3oool00`1gMgL0IVIV0?ooo`040?ooo`030000003oool0
oooo03D0oooo1000003o0?ooo``0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03H0oooo1000003o0?ooo`/0oooo00070?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2IVIT04A4A00D0oooo00<0
00000?ooo`3oool0>03oool300000?l0oooo2P3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`0509VIV@0A4A400000028R8P3<c<`01@3oool00`000000oooo0?ooo`0i0?ooo`@00000
o`3oool80?ooo`008@3oool00`000000oooo0?ooo`0j0?ooo`@00000o`3oool70?ooo`008@3oool0
0`000000oooo0?ooo`0l0?ooo`@00000o`3oool50?ooo`008@3oool00`000000oooo0?ooo`0m0?oo
o`@00000o`3oool40?ooo`008@3oool00`000000oooo0?ooo`0o0?ooo`@00000o`3oool20?ooo`00
8@3oool200000440oooo1000003o0?ooo`40oooo000Q0?ooo`030000003oool0oooo0480oooo0`00
003o0?ooo`008@3oool00`000000oooo0?ooo`130?ooo`@00000o@3oool00240oooo00<000000?oo
o`3oool0A03oool400000?`0oooo000Q0?ooo`030000003oool0oooo04H0oooo1000003j0?ooo`00
8@3oool00`000000oooo0?ooo`170?ooo`@00000n@3oool00240oooo00<000000?ooo`3oool0B@3o
ool400000?L0oooo000Q0?ooo`030000003oool0oooo04X0oooo1000003f0?ooo`008@3oool00`00
0000oooo0?ooo`1<0?ooo`@00000m03oool00240oooo0P00001>0?ooo`@00000l`3oool00240oooo
00<000000?ooo`3oool0C`3oool300000?80oooo000Q0?ooo`030000003oool0oooo0500oooo1000
003`0?ooo`008@3oool00`000000oooo0?ooo`1A0?ooo`@00000k`3oool00240oooo00<000000?oo
o`3oool0D`3oool400000>d0oooo000Q0?ooo`030000003oool0oooo05@0oooo1000003/0?ooo`00
8@3oool00`000000oooo0?ooo`1F0?ooo`<00000j`3oool00240oooo00<000000?ooo`3oool0E`3o
ool300000>X0oooo000Q0?ooo`030000003oool0oooo05P0oooo0`00003Y0?ooo`008@3oool20000
05X0oooo1000003W0?ooo`008@3oool00`000000oooo0?ooo`1J0?ooo`@00000iP3oool00240oooo
00<000000?ooo`3oool0G03oool300000>D0oooo000Q0?ooo`030000003oool0oooo05d0oooo0`00
003T0?ooo`008@3oool00`000000oooo0?ooo`1N0?ooo`<00000h`3oool00240oooo00<000000?oo
o`3oool0G`3oool400000>40oooo000Q0?ooo`030000003oool0oooo0600oooo1000003P0?ooo`00
1`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A0?ooo`3o
ool00`3oool00`000000oooo0?ooo`1R0?ooo`<00000g`3oool000L0oooo00D0MgMg09VIV@3oool0
VIVI07MgM`050?ooo`808R8R1`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06<0
oooo0`00003N0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@0000050?ooo`03
0000003oool0oooo06@0oooo0`00003M0?ooo`001`3oool01@000000oooo0?ooo`3oool0000000/0
oooo00@0A4A40=gMg@3oool000001P3oool3000006D0oooo1000003K0?ooo`001`3oool01@000000
oooo0?ooo`3oool0000000/0oooo00@0gMgM05EEE@3oool000001P3oool00`000000oooo0?ooo`1V
0?ooo`@00000fP3oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0307MgM`3<c<`0
000000H0oooo00<000000?ooo`3oool0J03oool300000=T0oooo00070?ooo`0507MgM`2IVIT0oooo
09VIV@1gMgL0303oool00`3^k^h0A4A4000000060?ooo`030000003oool0oooo06T0oooo0`00003H
0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00d0oooo00<0MgMg0000003oool01@3oool0
0`000000oooo0?ooo`1Z0?ooo`<00000e`3oool00240oooo00<000000?ooo`3oool0J`3oool40000
0=D0oooo000Q0?ooo`030000003oool0oooo06`0oooo1000003D0?ooo`008@3oool00`000000oooo
0?ooo`1^0?ooo`<00000d`3oool00240oooo00<000000?ooo`3oool0K`3oool400000=40oooo000Q
0?ooo`800000L@3oool400000=00oooo000Q0?ooo`030000003oool0oooo0780oooo0`00003?0?oo
o`008@3oool00`000000oooo0?ooo`1c0?ooo`<00000cP3oool00240oooo00<000000?ooo`3oool0
M03oool400000<`0oooo000Q0?ooo`030000003oool0oooo07D0oooo1000003;0?ooo`008@3oool0
0`000000oooo0?ooo`1g0?ooo`<00000bP3oool00240oooo00<000000?ooo`3oool0N03oool40000
0<P0oooo000Q0?ooo`030000003oool0oooo07T0oooo100000370?ooo`008@3oool00`000000oooo
0?ooo`1k0?ooo`<00000aP3oool00240oooo0P00001m0?ooo`<00000a@3oool00240oooo00<00000
0?ooo`3oool0O@3oool300000<@0oooo000Q0?ooo`030000003oool0oooo07h0oooo0`0000330?oo
o`008@3oool00`000000oooo0?ooo`1o0?ooo`<00000`P3oool00240oooo00<000000?ooo`3oool0
P03oool300000<40oooo000Q0?ooo`030000003oool0oooo0840oooo0`0000300?ooo`008@3oool0
0`000000oooo0?ooo`220?ooo`<00000_`3oool00240oooo00<000000?ooo`3oool0P`3oool30000
0;h0oooo000Q0?ooo`030000003oool0oooo08@0oooo0`00002m0?ooo`008@3oool2000008H0oooo
0`00002l0?ooo`008@3oool00`000000oooo0?ooo`260?ooo`<00000^`3oool00240oooo00<00000
0?ooo`3oool0Q`3oool300000;X0oooo000Q0?ooo`030000003oool0oooo08P0oooo0`00002i0?oo
o`008@3oool00`000000oooo0?ooo`290?ooo`<00000^03oool00240oooo00<000000?ooo`3oool0
RP3oool400000;H0oooo000Q0?ooo`030000003oool0oooo08/0oooo1000002e0?ooo`001`3oool0
1@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c<c<00000014A4@3<c<`0
1@3oool00`000000oooo0?ooo`2=0?ooo`<00000]03oool000L0oooo00D0MgMg09VIV@3oool0VIVI
07MgM`050?ooo`808R8R103oool01@1EEED0MgMg0?ooo`2IVIT08R8R00D0oooo00<000000?ooo`3o
ool0SP3oool300000;<0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000
oooo0?ooo`3oool0000000D0oooo0`00002?0?ooo`@00000/@3oool000L0oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`050000002IVIT0oooo09VIV@0R8R801@3oool00`000000oooo0?ooo`2@
0?ooo`D00000[`3oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED0
0000014A4@3<c<`01@3oool00`000000oooo0?ooo`2A0?ooo`L00000[03oool000L0oooo00D04A4A
0?ooo`3oool0oooo014A4@0;0?ooo`0305EEE@28R8P0oooo00L0oooo00<000000?ooo`3oool0U03o
ool700000:T0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool00`3MgMd04A4A09VI
V@070?ooo`030000003oool0oooo09L0oooo1`00002V0?ooo`001`3oool01@3^k^h0<c<c0000000c
<c<0k^k^00`0oooo00@0c<c<04A4A00000004A4A1@3oool00`000000oooo0?ooo`2J0?ooo`L00000
X`3oool00240oooo00<000000?ooo`3oool0W@3oool700000:00oooo000Q0?ooo`030000003oool0
oooo0:00oooo1`00002M0?ooo`008@3oool00`000000oooo0?ooo`2S0?ooo`L00000VP3oool00240
oooo00<000000?ooo`3oool0YP3oool6000009P0oooo000Q0?ooo`800000ZP3oool6000009D0oooo
000Q0?ooo`030000003oool0oooo0:/0oooo1`00002B0?ooo`008@3oool00`000000oooo0?ooo`2^
0?ooo`H00000T03oool00240oooo00<000000?ooo`3oool0/@3oool6000008d0oooo000Q0?ooo`03
0000003oool0oooo0;<0oooo1P00002;0?ooo`008@3oool00`000000oooo0?ooo`2f0?ooo`D00000
R@3oool00240oooo00<000000?ooo`3oool0^03oool5000008L0oooo000Q0?ooo`030000003oool0
oooo0;X0oooo1@0000250?ooo`008@3oool00`000000oooo0?ooo`2l0?ooo`D00000P`3oool00240
oooo0P00002o0?ooo`D00000P@3oool00240oooo00<000000?ooo`3oool0`03oool5000007l0oooo
000Q0?ooo`030000003oool0oooo0<80oooo1@00001m0?ooo`008@3oool00`000000oooo0?ooo`34
0?ooo`D00000N`3oool00240oooo00<000000?ooo`3oool0aP3oool6000007P0oooo000Q0?ooo`03
0000003oool0oooo0<P0oooo1P00001f0?ooo`008@3oool00`000000oooo0?ooo`3;0?ooo`D00000
M03oool00240oooo00<000000?ooo`3oool0c@3oool500000780oooo000Q0?ooo`030000003oool0
oooo0<l0oooo1@00001`0?ooo`008@3oool200000=80oooo1@00001^0?ooo`008@3oool00`000000
oooo0?ooo`3C0?ooo`H00000J`3oool00240oooo00<000000?ooo`3oool0e@3oool6000006T0oooo
000Q0?ooo`030000003oool0oooo0=P0oooo1@00001W0?ooo`008@3oool00`000000oooo0?ooo`3J
0?ooo`D00000I@3oool00240oooo00<000000?ooo`3oool0g03oool5000006<0oooo000Q0?ooo`03
0000003oool0oooo0=h0oooo1@00001Q0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0
oooo0P0R8R840?ooo`050<c<c00R8R800000028R8P3<c<`01@3oool00`000000oooo0?ooo`3P0?oo
o`D00000G`3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@0R
8R80VIVI0?ooo`2IVIT08R8R00D0oooo00<000000?ooo`3oool0hP3oool5000005d0oooo00070?oo
o`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000000D0oooo0`00
003T0?ooo`D00000F`3oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`0503<c<`2I
VIT0oooo09VIV@0c<c<01@3oool00`000000oooo0?ooo`3V0?ooo`D00000F@3oool000L0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`050<c<c000000000000000003<c<`01@3oool00`000000
oooo0?ooo`3X0?ooo`D00000E`3oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`05
014A4@2k^k/0oooo0;^k^`0A4A401@3oool00`000000oooo0?ooo`3Z0?ooo`@00000EP3oool000L0
oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo0;^k^`0000001@3oool0
0`000000oooo0?ooo`3/0?ooo`@00000E03oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP0;
0?ooo`050:ZZZP0A4A400000014A4@2ZZZX01@3oool00`000000oooo0?ooo`3]0?ooo`D00000DP3o
ool00240oooo00<000000?ooo`3oool0k`3oool400000540oooo000Q0?ooo`030000003oool0oooo
0?40oooo1000001?0?ooo`008@3oool00`000000oooo0?ooo`3b0?ooo`D00000C@3oool00240oooo
0P00003e0?ooo`D00000B`3oool00240oooo00<000000?ooo`3oool0mP3oool5000004T0oooo000Q
0?ooo`030000003oool0oooo0?P0oooo1@0000170?ooo`008@3oool00`000000oooo0?ooo`3j0?oo
o`@00000AP3oool00240oooo00<000000?ooo`3oool0o03oool4000004@0oooo000Q0?ooo`030000
003oool0oooo0?d0oooo1@0000120?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`D00000@03o
ool00240oooo00<000000?ooo`3oool0o`3oool20?ooo`@00000?`3oool00240oooo00<000000?oo
o`3oool0o`3oool40?ooo`@00000?@3oool00240oooo00<000000?ooo`3oool0o`3oool50?ooo`D0
0000>`3oool00240oooo0P00003o0?ooo`P0oooo1000000j0?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo1000000h0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo1000000g
0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo``0oooo1000000e0?ooo`008@3oool00`000000
oooo0?ooo`3o0?ooo`d0oooo1@00000c0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo
1@00000a0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooa40oooo1@00000_0?ooo`008@3oool0
0`000000oooo0?ooo`3o0?oooa<0oooo1000000^0?ooo`008@3oool00`000000oooo0?ooo`3o0?oo
oaD0oooo1000000/0?ooo`008@3oool200000?l0oooo5`3oool5000002X0oooo000Q0?ooo`030000
003oool0oooo0?l0oooo603oool5000002P0oooo000Q0?ooo`030000003oool0oooo0?l0oooo6P3o
ool4000002L0oooo000Q0?ooo`030000003oool0oooo0?l0oooo703oool4000002D0oooo000Q0?oo
o`030000003oool0oooo0?l0oooo7@3oool4000002@0oooo000Q0?ooo`030000003oool0oooo0?l0
oooo7`3oool400000280oooo000Q0?ooo`030000003oool0oooo0?l0oooo803oool400000240oooo
000H0?ooo`@0000000<04A4A0?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooob80oooo1000
000O0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo8`3oool4
000001h0oooo000J0?ooo`030000003oool0oooo00@0oooo0`00003o0?ooobD0oooo1000000L0?oo
o`006P3oool00`000000oooo0?ooo`3o0?ooobd0oooo0`00000L0?ooo`006P3oool00`000000oooo
0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<00000
0?ooo`3oool0o`3ooom<0?ooo`00603oool205EEE@030000003oool0oooo0?l0ooooC03oool00?l0
ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool009X0oooo00D0VIVI000000000000A4A40;^k
^`0H0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8PD0oooo100000000`0A4A40oooo
0?ooo`020?ooo`80000000<04A4A0?ooo`3oool0TP3oool009X0oooo00D04A4A0;^k^`3^k^h0MgMg
014A4@090?ooo`H000002@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R870?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0T`3oool009X0oooo00<000000?ooo`3oool0
6P3oool01@0A4A40oooo0?ooo`3oool04A4A00h0oooo00<000000?ooo`3oool00P3oool5000009@0
oooo000O0?ooo`05014A4@00000000000000000A4A40MP3oool00`000000oooo0?ooo`0;0?ooo`H0
00002@3oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool00P3oool01014
A4@0gMgM0?ooo`00002E0?ooo`008@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo
01X0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo0080oooo00@0gMgM
05EEE@3oool00000U@3oool00240oooo00<000000?ooo`3oool0M03oool00`0A4A40000000000003
000001T0oooo00D04A4A0?ooo`3oool0oooo014A4@0>0?ooo`030000003oool0oooo00<0oooo00<0
MgMg0<c<c0000000U@3oool00240oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0J
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL03P3oool00`000000oooo0?ooo`030?ooo`030>k^kP14
A4@0000009D0oooo000Q0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool06P3oool0
1@3^k^h0<c<c0000000c<c<0k^k^00`0oooo0P1EEED00`000000oooo0?ooo`040?ooo`0307MgM`00
0000oooo09@0oooo000N0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3o
oom20?ooo`007P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0oooo@P3o
ool001h0oooo1`00003o0?oood@0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .02807 L
.08481 .05887 L
.12636 .08813 L
.16632 .11674 L
.20885 .14784 L
.2498 .17854 L
.29331 .21213 L
.33524 .24554 L
.37557 .27875 L
.41848 .3153 L
.4598 .35174 L
.48055 .37051 L
.48962 .37882 L
.49442 .38324 L
.49705 .38567 L
.49834 .38686 L
.49953 .38796 L
.50089 .38867 L
.50161 .3889 L
.50237 .38913 L
.50495 .38993 L
.50998 .39151 L
.51991 .39469 L
.54183 .40196 L
.5817 .41608 L
.62415 .43236 L
.665 .44921 L
.70843 .46829 L
.75027 .48773 L
.79051 .5073 L
.83333 .52892 L
.87456 .55039 L
.9142 .57149 L
.95642 .5943 L
.99704 .61642 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`D00000=`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`00
00000`00003o0?oood80oooo000Q0?ooo`040000003oool0oooo0?ooo`@00000o`3ooom00?ooo`00
8@3oool00`000000oooo0?ooo`020?ooo`@00000o`3ooolo0?ooo`008@3oool00`000000oooo0?oo
o`040?ooo`@00000o`3ooolm0?ooo`008@3oool00`000000oooo0?ooo`050?ooo`@00000o`3oooll
0?ooo`008@3oool00`000000oooo0?ooo`070?ooo`@00000o`3ooolj0?ooo`008@3oool2000000T0
oooo1000003o0?ooocT0oooo000Q0?ooo`030000003oool0oooo00X0oooo1000003o0?ooocL0oooo
000Q0?ooo`030000003oool0oooo00/0oooo1000003o0?ooocH0oooo000Q0?ooo`030000003oool0
oooo00d0oooo0`00003o0?ooocD0oooo000Q0?ooo`030000003oool0oooo00h0oooo1000003o0?oo
oc<0oooo000Q0?ooo`030000003oool0oooo00l0oooo1000003o0?oooc80oooo000Q0?ooo`030000
003oool0oooo0140oooo1000003o0?oooc00oooo000Q0?ooo`030000003oool0oooo0180oooo1000
003o0?ooobl0oooo000Q0?ooo`030000003oool0oooo01@0oooo0`00003o0?ooobh0oooo000Q0?oo
o`8000005P3oool400000?l0oooo;03oool00240oooo00<000000?ooo`3oool05P3oool400000?l0
oooo:`3oool00240oooo00<000000?ooo`3oool0603oool400000?l0oooo:@3oool00240oooo00<0
00000?ooo`3oool06@3oool400000?l0oooo:03oool00240oooo00<000000?ooo`3oool06`3oool4
00000?l0oooo9P3oool00240oooo00<000000?ooo`3oool0703oool400000?l0oooo9@3oool00240
oooo00<000000?ooo`3oool07P3oool400000?l0oooo8`3oool00240oooo00<000000?ooo`3oool0
7`3oool400000?l0oooo8P3oool00240oooo00<000000?ooo`3oool08@3oool400000?l0oooo803o
ool00240oooo00<000000?ooo`3oool08P3oool400000?l0oooo7`3oool00240oooo0P00000U0?oo
o`<00000o`3ooolN0?ooo`008@3oool00`000000oooo0?ooo`0U0?ooo`@00000o`3ooolL0?ooo`00
8@3oool00`000000oooo0?ooo`0V0?ooo`@00000o`3ooolK0?ooo`008@3oool00`000000oooo0?oo
o`0X0?ooo`<00000o`3ooolJ0?ooo`008@3oool00`000000oooo0?ooo`0Y0?ooo`@00000o`3ooolH
0?ooo`008@3oool00`000000oooo0?ooo`0Z0?ooo`@00000o`3ooolG0?ooo`001`3oool01@3^k^h0
<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`D000001@3oool00`000000oooo0?ooo`0/0?oo
o`<00000o`3ooolF0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?oo
o`0509VIV@0R8R80k^k^0?ooo`14A4@01@3oool00`000000oooo0?ooo`0]0?ooo`@00000o`3ooolD
0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<0VIVI028R8P3^k^h01P3oool0
0`000000oooo0?ooo`0^0?ooo`@00000o`3ooolC0?ooo`001`3oool01@000000oooo0?ooo`3oool0
000000d0oooo00<0VIVI028R8P3^k^h01@3oool300000300oooo0`00003o0?oooa80oooo00070?oo
o`050000003oool0oooo0?ooo`0000003P3oool00`1gMgL0IVIV0?ooo`040?ooo`030000003oool0
oooo0340oooo1000003o0?oooa00oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0380oooo1000003o0?ooo`l0oooo00070?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2IVIT04A4A00D0oooo00<0
00000?ooo`3oool0=03oool300000?l0oooo3P3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`0509VIV@0A4A400000028R8P3<c<`01@3oool00`000000oooo0?ooo`0e0?ooo`@00000
o`3oool<0?ooo`008@3oool00`000000oooo0?ooo`0f0?ooo`@00000o`3oool;0?ooo`008@3oool0
0`000000oooo0?ooo`0h0?ooo`<00000o`3oool:0?ooo`008@3oool00`000000oooo0?ooo`0i0?oo
o`@00000o`3oool80?ooo`008@3oool00`000000oooo0?ooo`0j0?ooo`@00000o`3oool70?ooo`00
8@3oool2000003d0oooo1000003o0?ooo`D0oooo000Q0?ooo`030000003oool0oooo03d0oooo1000
003o0?ooo`@0oooo000Q0?ooo`030000003oool0oooo03l0oooo1000003o0?ooo`80oooo000Q0?oo
o`030000003oool0oooo0400oooo1000003o0?ooo`40oooo000Q0?ooo`030000003oool0oooo0480
oooo0`00003o0?ooo`008@3oool00`000000oooo0?ooo`130?ooo`@00000o@3oool00240oooo00<0
00000?ooo`3oool0A03oool400000?`0oooo000Q0?ooo`030000003oool0oooo04H0oooo1000003j
0?ooo`008@3oool00`000000oooo0?ooo`170?ooo`@00000n@3oool00240oooo0P00001:0?ooo`<0
0000n03oool00240oooo00<000000?ooo`3oool0BP3oool400000?H0oooo000Q0?ooo`030000003o
ool0oooo04/0oooo1000003e0?ooo`008@3oool00`000000oooo0?ooo`1=0?ooo`<00000m03oool0
0240oooo00<000000?ooo`3oool0CP3oool300000?<0oooo000Q0?ooo`030000003oool0oooo04l0
oooo1000003a0?ooo`008@3oool00`000000oooo0?ooo`1@0?ooo`@00000l03oool00240oooo00<0
00000?ooo`3oool0DP3oool300000>l0oooo000Q0?ooo`030000003oool0oooo05<0oooo1000003]
0?ooo`008@3oool2000005D0oooo1000003/0?ooo`008@3oool00`000000oooo0?ooo`1F0?ooo`<0
0000j`3oool00240oooo00<000000?ooo`3oool0E`3oool300000>X0oooo000Q0?ooo`030000003o
ool0oooo05P0oooo0`00003Y0?ooo`008@3oool00`000000oooo0?ooo`1I0?ooo`@00000i`3oool0
0240oooo00<000000?ooo`3oool0FP3oool400000>H0oooo000Q0?ooo`030000003oool0oooo05`0
oooo0`00003U0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80
000000<04A4A0?ooo`3oool00`3oool00`000000oooo0?ooo`1M0?ooo`<00000i03oool000L0oooo
00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R1`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo05h0oooo0`00003S0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0
oooo1@0000050?ooo`030000003oool0oooo05l0oooo1000003Q0?ooo`001`3oool01@000000oooo
0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool000001P3oool300000600oooo1000003P0?oo
o`001`3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0gMgM05EEE@3oool000001P3oool0
0`000000oooo0?ooo`1R0?ooo`<00000g`3oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<
0?ooo`0307MgM`3<c<`0000000H0oooo00<000000?ooo`3oool0H`3oool300000=h0oooo00070?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`3^k^h0A4A4000000060?ooo`030000003oool0
oooo06@0oooo0`00003M0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00d0oooo00<0MgMg
0000003oool01@3oool00`000000oooo0?ooo`1U0?ooo`@00000f`3oool00240oooo00<000000?oo
o`3oool0IP3oool400000=X0oooo000Q0?ooo`030000003oool0oooo06P0oooo0`00003I0?ooo`00
8@3oool00`000000oooo0?ooo`1Y0?ooo`<00000f03oool00240oooo00<000000?ooo`3oool0JP3o
ool300000=L0oooo000Q0?ooo`800000K03oool400000=D0oooo000Q0?ooo`030000003oool0oooo
06`0oooo1000003D0?ooo`008@3oool00`000000oooo0?ooo`1^0?ooo`<00000d`3oool00240oooo
00<000000?ooo`3oool0K`3oool300000=80oooo000Q0?ooo`030000003oool0oooo0700oooo0`00
003A0?ooo`008@3oool00`000000oooo0?ooo`1a0?ooo`@00000c`3oool00240oooo00<000000?oo
o`3oool0LP3oool400000<h0oooo000Q0?ooo`030000003oool0oooo07@0oooo0`00003=0?ooo`00
8@3oool00`000000oooo0?ooo`1e0?ooo`<00000c03oool00240oooo0P00001g0?ooo`<00000b`3o
ool00240oooo00<000000?ooo`3oool0M`3oool300000<X0oooo000Q0?ooo`030000003oool0oooo
07P0oooo100000380?ooo`008@3oool00`000000oooo0?ooo`1i0?ooo`@00000a`3oool00240oooo
00<000000?ooo`3oool0N`3oool300000<H0oooo000Q0?ooo`030000003oool0oooo07`0oooo0`00
00350?ooo`008@3oool00`000000oooo0?ooo`1m0?ooo`<00000a03oool00240oooo00<000000?oo
o`3oool0OP3oool300000<<0oooo000Q0?ooo`030000003oool0oooo07l0oooo0`0000320?ooo`00
8@3oool200000840oooo0`0000310?ooo`008@3oool00`000000oooo0?ooo`210?ooo`<00000`03o
ool00240oooo00<000000?ooo`3oool0PP3oool300000;l0oooo000Q0?ooo`030000003oool0oooo
08<0oooo0`00002n0?ooo`008@3oool00`000000oooo0?ooo`240?ooo`@00000_03oool00240oooo
00<000000?ooo`3oool0Q@3oool400000;/0oooo000Q0?ooo`030000003oool0oooo08L0oooo0`00
002j0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`01@3oool00`000000oooo0?ooo`280?ooo`<00000^@3oool000L0oooo00D0
MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@1EEED0MgMg0?ooo`2IVIT08R8R00D0
oooo00<000000?ooo`3oool0R@3oool300000;P0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A
4A402`3oool01@000000oooo0?ooo`3oool0000000D0oooo0`00002:0?ooo`<00000]`3oool000L0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000002IVIT0oooo09VIV@0R8R801@3oool0
0`000000oooo0?ooo`2;0?ooo`<00000]P3oool000L0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`050000001EEED00000014A4@3<c<`01@3oool00`000000oooo0?ooo`2<0?ooo`<00000]@3o
ool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`0305EEE@28R8P0oooo00L0oooo00<0
00000?ooo`3oool0S@3oool300000;@0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3o
ool00`3MgMd04A4A09VIV@070?ooo`030000003oool0oooo08h0oooo0`00002c0?ooo`001`3oool0
1@3^k^h0<c<c0000000c<c<0k^k^00`0oooo00@0c<c<04A4A00000004A4A1@3oool00`000000oooo
0?ooo`2?0?ooo`@00000/@3oool00240oooo00<000000?ooo`3oool0T03oool500000:l0oooo000Q
0?ooo`030000003oool0oooo0940oooo1`00002/0?ooo`008@3oool00`000000oooo0?ooo`2D0?oo
o`L00000Z@3oool00240oooo00<000000?ooo`3oool0U`3oool700000:H0oooo000Q0?ooo`800000
V`3oool700000:<0oooo000Q0?ooo`030000003oool0oooo09d0oooo1`00002P0?ooo`008@3oool0
0`000000oooo0?ooo`2P0?ooo`L00000W@3oool00240oooo00<000000?ooo`3oool0X`3oool70000
09X0oooo000Q0?ooo`030000003oool0oooo0:H0oooo1P00002H0?ooo`008@3oool00`000000oooo
0?ooo`2Y0?ooo`H00000U@3oool00240oooo00<000000?ooo`3oool0Z`3oool700000980oooo000Q
0?ooo`030000003oool0oooo0:h0oooo1P00002@0?ooo`008@3oool00`000000oooo0?ooo`2a0?oo
o`H00000S@3oool00240oooo0P00002d0?ooo`H00000R`3oool00240oooo00<000000?ooo`3oool0
]P3oool6000008P0oooo000Q0?ooo`030000003oool0oooo0;P0oooo1P0000260?ooo`008@3oool0
0`000000oooo0?ooo`2k0?ooo`D00000Q03oool00240oooo00<000000?ooo`3oool0_@3oool60000
0840oooo000Q0?ooo`030000003oool0oooo0;l0oooo1P00001o0?ooo`008@3oool00`000000oooo
0?ooo`320?ooo`H00000O03oool00240oooo00<000000?ooo`3oool0a03oool7000007T0oooo000Q
0?ooo`030000003oool0oooo0<L0oooo1P00001g0?ooo`008@3oool200000</0oooo1P00001d0?oo
o`008@3oool00`000000oooo0?ooo`3<0?ooo`H00000LP3oool00240oooo00<000000?ooo`3oool0
c`3oool500000700oooo000Q0?ooo`030000003oool0oooo0=40oooo1@00001^0?ooo`008@3oool0
0`000000oooo0?ooo`3C0?ooo`H00000J`3oool00240oooo00<000000?ooo`3oool0e@3oool60000
06T0oooo000Q0?ooo`030000003oool0oooo0=P0oooo1@00001W0?ooo`001`3oool01@3^k^h0<c<c
0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050<c<c00R8R800000028R8P3<c<`01@3oool00`00
0000oooo0?ooo`3J0?ooo`D00000I@3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?oo
o`808R8R103oool01@0R8R80VIVI0?ooo`2IVIT08R8R00D0oooo00<000000?ooo`3oool0g03oool5
000006<0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3o
ool0000000D0oooo0`00003N0?ooo`D00000H@3oool000L0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`0503<c<`2IVIT0oooo09VIV@0c<c<01@3oool00`000000oooo0?ooo`3P0?ooo`D00000
G`3oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050<c<c000000000000000003<
c<`01@3oool00`000000oooo0?ooo`3R0?ooo`D00000G@3oool000L0oooo00D04A4A0?ooo`3oool0
oooo014A4@0;0?ooo`05014A4@2k^k/0oooo0;^k^`0A4A401@3oool00`000000oooo0?ooo`3T0?oo
o`D00000F`3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo
0;^k^`0000001@3oool00`000000oooo0?ooo`3V0?ooo`D00000F@3oool000L0oooo00D0k^k^03<c
<`000000<c<c0>k^kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX01@3oool00`000000oooo0?oo
o`3X0?ooo`D00000E`3oool00240oooo00<000000?ooo`3oool0jP3oool4000005H0oooo000Q0?oo
o`030000003oool0oooo0>`0oooo1000001D0?ooo`008@3oool00`000000oooo0?ooo`3]0?ooo`D0
0000DP3oool00240oooo0P00003`0?ooo`@00000D@3oool00240oooo00<000000?ooo`3oool0l@3o
ool4000004l0oooo000Q0?ooo`030000003oool0oooo0?80oooo1@00001=0?ooo`008@3oool00`00
0000oooo0?ooo`3d0?ooo`D00000B`3oool00240oooo00<000000?ooo`3oool0mP3oool5000004T0
oooo000Q0?ooo`030000003oool0oooo0?P0oooo1P0000160?ooo`008@3oool00`000000oooo0?oo
o`3j0?ooo`H00000A03oool00240oooo00<000000?ooo`3oool0o@3oool500000480oooo000Q0?oo
o`030000003oool0oooo0?l0oooo1@0000100?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`80
oooo1@00000n0?ooo`008@3oool200000?l0oooo1@3oool5000003`0oooo000Q0?ooo`030000003o
ool0oooo0?l0oooo1P3oool4000003/0oooo000Q0?ooo`030000003oool0oooo0?l0oooo203oool4
000003T0oooo000Q0?ooo`030000003oool0oooo0?l0oooo2@3oool5000003L0oooo000Q0?ooo`03
0000003oool0oooo0?l0oooo2`3oool5000003D0oooo000Q0?ooo`030000003oool0oooo0?l0oooo
3@3oool5000003<0oooo000Q0?ooo`030000003oool0oooo0?l0oooo3`3oool500000340oooo000Q
0?ooo`030000003oool0oooo0?l0oooo4@3oool5000002l0oooo000Q0?ooo`030000003oool0oooo
0?l0oooo4`3oool4000002h0oooo000Q0?ooo`800000o`3ooolF0?ooo`@00000;03oool00240oooo
00<000000?ooo`3oool0o`3ooolF0?ooo`D00000:P3oool00240oooo00<000000?ooo`3oool0o`3o
oolH0?ooo`D00000:03oool00240oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`D000009P3oool0
0240oooo00<000000?ooo`3oool0o`3ooolL0?ooo`@000009@3oool00240oooo00<000000?ooo`3o
ool0o`3ooolN0?ooo`@000008`3oool00240oooo00<000000?ooo`3oool0o`3ooolO0?ooo`D00000
8@3oool001P0oooo100000000`0A4A40oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo8@3o
ool400000200oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooolS
0?ooo`@000007P3oool001X0oooo00<000000?ooo`3oool0103oool300000?l0oooo903oool50000
01`0oooo000J0?ooo`030000003oool0oooo0?l0oooo;@3oool3000001`0oooo000J0?ooo`030000
003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool0
0`000000oooo0?ooo`3o0?oood`0oooo000H0?ooo`80EEEE00<000000?ooo`3oool0o`3ooom<0?oo
o`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00VP3oool01@2IVIT0000000000014
A4@0^k^k01P0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1@3oool400000008014A
4@3oool0oooo0>k^kP0c<c<00000014A4@3<c<bD0?ooo`00VP3oool01@0A4A40^k^k0>k^kP1gMgL0
4A4A00T0oooo1P0000090?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<0
00000?ooo`3oool00P3oool01@1EEED0MgMg0?ooo`2IVIT08R8R09@0oooo002J0?ooo`030000003o
ool0oooo01X0oooo00D04A4A0?ooo`3oool0oooo014A4@0>0?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo0000002D0?ooo`007`3oool01@0A4A4000000000000000004A4A07H0
oooo00<000000?ooo`3oool02`3oool6000000T0oooo00D000000?ooo`3oool0oooo0000000>0?oo
o`030000003oool0oooo0080oooo00D0000009VIV@3oool0VIVI028R8P2D0?ooo`008@3oool00`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo01X0oooo00D000000?ooo`3oool0oooo0000000>
0?ooo`030000003oool0oooo0080oooo00D0000005EEE@0000004A4A0<c<c02D0?ooo`008@3oool0
0`000000oooo0?ooo`1d0?ooo`03014A4@000000000000<000006@3oool01@0A4A40oooo0?ooo`3o
ool04A4A00h0oooo00<000000?ooo`3oool00P3oool00`1EEED0R8R80?ooo`2F0?ooo`008@3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01X0oooo00D0MgMg09VIV@3oool0VIVI07Mg
M`0>0?ooo`030000003oool0oooo0080oooo00<0gMgM014A4@2IVIT0UP3oool00240oooo00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`0J0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303o
ool205EEE@030000003oool0oooo00<0oooo00@0c<c<04A4A00000004A4AU03oool001h0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oood80oooo000N0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0o`3ooom20?ooo`007P3oool700000?l0ooooA03o
ool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .02978 L
.08481 .0624 L
.12636 .09332 L
.16632 .12343 L
.20885 .15602 L
.2498 .18802 L
.29331 .22282 L
.33524 .25721 L
.37557 .29117 L
.41848 .32831 L
.4598 .36509 L
.48055 .38394 L
.48962 .39227 L
.49442 .39669 L
.49705 .39912 L
.49834 .40032 L
.49953 .40142 L
.50089 .40213 L
.50161 .40235 L
.50237 .40259 L
.50495 .40339 L
.50998 .40497 L
.51991 .40812 L
.54183 .41531 L
.5817 .42911 L
.62415 .44483 L
.665 .46092 L
.70843 .479 L
.75027 .49727 L
.79051 .51556 L
.83333 .53568 L
.87456 .55558 L
.9142 .57509 L
.95642 .59614 L
.99704 .61654 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`@00000>03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`00
00000`00003o0?oood80oooo000Q0?ooo`030000003oool0oooo00@00000o`3ooom10?ooo`008@3o
ool00`000000oooo0?ooo`020?ooo`<00000o`3ooom00?ooo`008@3oool00`000000oooo0?ooo`03
0?ooo`@00000o`3oooln0?ooo`008@3oool00`000000oooo0?ooo`040?ooo`@00000o`3ooolm0?oo
o`008@3oool00`000000oooo0?ooo`060?ooo`<00000o`3oooll0?ooo`008@3oool2000000P0oooo
1000003o0?ooocX0oooo000Q0?ooo`030000003oool0oooo00P0oooo1000003o0?ooocT0oooo000Q
0?ooo`030000003oool0oooo00X0oooo1000003o0?ooocL0oooo000Q0?ooo`030000003oool0oooo
00/0oooo1000003o0?ooocH0oooo000Q0?ooo`030000003oool0oooo00d0oooo0`00003o0?ooocD0
oooo000Q0?ooo`030000003oool0oooo00h0oooo1000003o0?oooc<0oooo000Q0?ooo`030000003o
ool0oooo00l0oooo1000003o0?oooc80oooo000Q0?ooo`030000003oool0oooo0140oooo1000003o
0?oooc00oooo000Q0?ooo`030000003oool0oooo0180oooo1000003o0?ooobl0oooo000Q0?ooo`80
00005@3oool300000?l0oooo;P3oool00240oooo00<000000?ooo`3oool05@3oool400000?l0oooo
;03oool00240oooo00<000000?ooo`3oool05P3oool400000?l0oooo:`3oool00240oooo00<00000
0?ooo`3oool0603oool300000?l0oooo:P3oool00240oooo00<000000?ooo`3oool06@3oool40000
0?l0oooo:03oool00240oooo00<000000?ooo`3oool06P3oool400000?l0oooo9`3oool00240oooo
00<000000?ooo`3oool0703oool300000?l0oooo9P3oool00240oooo00<000000?ooo`3oool07@3o
ool400000?l0oooo903oool00240oooo00<000000?ooo`3oool07P3oool400000?l0oooo8`3oool0
0240oooo00<000000?ooo`3oool0803oool300000?l0oooo8P3oool00240oooo0P00000R0?ooo`@0
0000o`3ooolP0?ooo`008@3oool00`000000oooo0?ooo`0R0?ooo`@00000o`3ooolO0?ooo`008@3o
ool00`000000oooo0?ooo`0T0?ooo`<00000o`3ooolN0?ooo`008@3oool00`000000oooo0?ooo`0U
0?ooo`@00000o`3ooolL0?ooo`008@3oool00`000000oooo0?ooo`0V0?ooo`@00000o`3ooolK0?oo
o`008@3oool00`000000oooo0?ooo`0X0?ooo`<00000o`3ooolJ0?ooo`001`3oool01@3^k^h0<c<c
0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`D000001@3oool00`000000oooo0?ooo`0Y0?ooo`@0
0000o`3ooolH0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05
09VIV@0R8R80k^k^0?ooo`14A4@01@3oool00`000000oooo0?ooo`0Z0?ooo`@00000o`3ooolG0?oo
o`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<0VIVI028R8P3^k^h01P3oool00`00
0000oooo0?ooo`0/0?ooo`<00000o`3ooolF0?ooo`001`3oool01@000000oooo0?ooo`3oool00000
00d0oooo00<0VIVI028R8P3^k^h01@3oool3000002d0oooo1000003o0?oooa@0oooo00070?ooo`05
0000003oool0oooo0?ooo`0000003P3oool00`1gMgL0IVIV0?ooo`040?ooo`030000003oool0oooo
02h0oooo1000003o0?oooa<0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0300oooo0`00003o0?oooa80oooo00070?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2IVIT04A4A00D0oooo00<00000
0?ooo`3oool0<@3oool300000?l0oooo4@3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP0;
0?ooo`0509VIV@0A4A400000028R8P3<c<`01@3oool00`000000oooo0?ooo`0b0?ooo`<00000o`3o
ool@0?ooo`008@3oool00`000000oooo0?ooo`0c0?ooo`@00000o`3oool>0?ooo`008@3oool00`00
0000oooo0?ooo`0d0?ooo`@00000o`3oool=0?ooo`008@3oool00`000000oooo0?ooo`0f0?ooo`<0
0000o`3oool<0?ooo`008@3oool00`000000oooo0?ooo`0g0?ooo`<00000o`3oool;0?ooo`008@3o
ool2000003T0oooo0`00003o0?ooo`X0oooo000Q0?ooo`030000003oool0oooo03T0oooo1000003o
0?ooo`P0oooo000Q0?ooo`030000003oool0oooo03X0oooo1000003o0?ooo`L0oooo000Q0?ooo`03
0000003oool0oooo03`0oooo1000003o0?ooo`D0oooo000Q0?ooo`030000003oool0oooo03d0oooo
1000003o0?ooo`@0oooo000Q0?ooo`030000003oool0oooo03l0oooo1000003o0?ooo`80oooo000Q
0?ooo`030000003oool0oooo0400oooo1000003o0?ooo`40oooo000Q0?ooo`030000003oool0oooo
0480oooo0`00003o0?ooo`008@3oool00`000000oooo0?ooo`130?ooo`@00000o@3oool00240oooo
0P0000150?ooo`@00000o03oool00240oooo00<000000?ooo`3oool0AP3oool400000?X0oooo000Q
0?ooo`030000003oool0oooo04L0oooo1000003i0?ooo`008@3oool00`000000oooo0?ooo`190?oo
o`<00000n03oool00240oooo00<000000?ooo`3oool0BP3oool400000?H0oooo000Q0?ooo`030000
003oool0oooo04/0oooo1000003e0?ooo`008@3oool00`000000oooo0?ooo`1=0?ooo`<00000m03o
ool00240oooo00<000000?ooo`3oool0CP3oool300000?<0oooo000Q0?ooo`030000003oool0oooo
04l0oooo1000003a0?ooo`008@3oool200000540oooo1000003`0?ooo`008@3oool00`000000oooo
0?ooo`1B0?ooo`<00000k`3oool00240oooo00<000000?ooo`3oool0D`3oool400000>d0oooo000Q
0?ooo`030000003oool0oooo05@0oooo1000003/0?ooo`008@3oool00`000000oooo0?ooo`1F0?oo
o`<00000j`3oool00240oooo00<000000?ooo`3oool0E`3oool300000>X0oooo000Q0?ooo`030000
003oool0oooo05P0oooo0`00003Y0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo
0P0R8R860?ooo`80000000<04A4A0?ooo`3oool00`3oool00`000000oooo0?ooo`1I0?ooo`<00000
j03oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R1`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo05X0oooo0`00003W0?ooo`001`3oool01@0A4A40oooo0?oo
o`3oool04A4A00/0oooo1@0000050?ooo`030000003oool0oooo05/0oooo0`00003V0?ooo`001`3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool000001P3oool3000005`0
oooo0`00003U0?ooo`001`3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0gMgM05EEE@3o
ool000001P3oool00`000000oooo0?ooo`1M0?ooo`<00000i03oool000L0oooo00D04A4A0?ooo`3o
ool0oooo014A4@0<0?ooo`0307MgM`3<c<`0000000H0oooo00<000000?ooo`3oool0GP3oool30000
0><0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`3^k^h0A4A4000000060?oo
o`030000003oool0oooo05l0oooo1000003Q0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^
00d0oooo00<0MgMg0000003oool01@3oool00`000000oooo0?ooo`1P0?ooo`@00000h03oool00240
oooo00<000000?ooo`3oool0HP3oool300000=l0oooo000Q0?ooo`030000003oool0oooo06<0oooo
0`00003N0?ooo`008@3oool00`000000oooo0?ooo`1T0?ooo`<00000g@3oool00240oooo00<00000
0?ooo`3oool0I@3oool400000=/0oooo000Q0?ooo`800000I`3oool400000=X0oooo000Q0?ooo`03
0000003oool0oooo06P0oooo0`00003I0?ooo`008@3oool00`000000oooo0?ooo`1Y0?ooo`<00000
f03oool00240oooo00<000000?ooo`3oool0JP3oool300000=L0oooo000Q0?ooo`030000003oool0
oooo06/0oooo1000003E0?ooo`008@3oool00`000000oooo0?ooo`1/0?ooo`@00000e03oool00240
oooo00<000000?ooo`3oool0KP3oool300000=<0oooo000Q0?ooo`030000003oool0oooo06l0oooo
0`00003B0?ooo`008@3oool00`000000oooo0?ooo`1`0?ooo`<00000d@3oool00240oooo0P00001b
0?ooo`@00000c`3oool00240oooo00<000000?ooo`3oool0LP3oool400000<h0oooo000Q0?ooo`03
0000003oool0oooo07@0oooo0`00003=0?ooo`008@3oool00`000000oooo0?ooo`1e0?ooo`<00000
c03oool00240oooo00<000000?ooo`3oool0MP3oool300000</0oooo000Q0?ooo`030000003oool0
oooo07L0oooo0`00003:0?ooo`008@3oool00`000000oooo0?ooo`1h0?ooo`@00000b03oool00240
oooo00<000000?ooo`3oool0N@3oool400000<L0oooo000Q0?ooo`030000003oool0oooo07/0oooo
0`0000360?ooo`008@3oool2000007d0oooo0`0000350?ooo`008@3oool00`000000oooo0?ooo`1m
0?ooo`<00000a03oool00240oooo00<000000?ooo`3oool0OP3oool300000<<0oooo000Q0?ooo`03
0000003oool0oooo07l0oooo0`0000320?ooo`008@3oool00`000000oooo0?ooo`200?ooo`<00000
`@3oool00240oooo00<000000?ooo`3oool0P@3oool300000<00oooo000Q0?ooo`030000003oool0
oooo0880oooo0`00002o0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R84
0?ooo`050>k^kP0c<c<00000014A4@3<c<`01@3oool00`000000oooo0?ooo`230?ooo`<00000_P3o
ool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@1EEED0MgMg0?oo
o`2IVIT08R8R00D0oooo00<000000?ooo`3oool0Q03oool400000;`0oooo00070?ooo`05014A4@3o
ool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000000D0oooo0`0000250?ooo`@0
0000^`3oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000002IVIT0oooo09VI
V@0R8R801@3oool00`000000oooo0?ooo`270?ooo`<00000^P3oool000L0oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`01@3oool00`000000oooo0?ooo`28
0?ooo`<00000^@3oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`0305EEE@28R8P0
oooo00L0oooo00<000000?ooo`3oool0R@3oool300000;P0oooo00070?ooo`0507MgM`2IVIT0oooo
09VIV@1gMgL02`3oool00`3MgMd04A4A09VIV@070?ooo`030000003oool0oooo08X0oooo0`00002g
0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00`0oooo00@0c<c<04A4A00000004A4A1@3o
ool00`000000oooo0?ooo`2;0?ooo`<00000]P3oool00240oooo00<000000?ooo`3oool0S03oool3
00000;D0oooo000Q0?ooo`030000003oool0oooo08d0oooo0`00002d0?ooo`008@3oool00`000000
oooo0?ooo`2>0?ooo`<00000/`3oool00240oooo00<000000?ooo`3oool0S`3oool400000;40oooo
000Q0?ooo`800000T@3oool500000:l0oooo000Q0?ooo`030000003oool0oooo0940oooo1`00002/
0?ooo`008@3oool00`000000oooo0?ooo`2D0?ooo`L00000Z@3oool00240oooo00<000000?ooo`3o
ool0U`3oool700000:H0oooo000Q0?ooo`030000003oool0oooo09X0oooo1`00002S0?ooo`008@3o
ool00`000000oooo0?ooo`2M0?ooo`L00000X03oool00240oooo00<000000?ooo`3oool0X03oool7
000009d0oooo000Q0?ooo`030000003oool0oooo0:<0oooo1`00002J0?ooo`008@3oool00`000000
oooo0?ooo`2V0?ooo`H00000V03oool00240oooo0P00002Z0?ooo`H00000U@3oool00240oooo00<0
00000?ooo`3oool0Z`3oool700000980oooo000Q0?ooo`030000003oool0oooo0:h0oooo1P00002@
0?ooo`008@3oool00`000000oooo0?ooo`2a0?ooo`H00000S@3oool00240oooo00<000000?ooo`3o
ool0/`3oool7000008X0oooo000Q0?ooo`030000003oool0oooo0;H0oooo1`0000270?ooo`008@3o
ool00`000000oooo0?ooo`2i0?ooo`L00000Q03oool00240oooo00<000000?ooo`3oool0_03oool7
00000840oooo000Q0?ooo`030000003oool0oooo0;l0oooo1P00001o0?ooo`008@3oool200000<<0
oooo1@00001m0?ooo`008@3oool00`000000oooo0?ooo`340?ooo`D00000N`3oool00240oooo00<0
00000?ooo`3oool0aP3oool6000007P0oooo000Q0?ooo`030000003oool0oooo0<P0oooo1P00001f
0?ooo`008@3oool00`000000oooo0?ooo`3;0?ooo`D00000M03oool00240oooo00<000000?ooo`3o
ool0c@3oool500000780oooo000Q0?ooo`030000003oool0oooo0<l0oooo1P00001_0?ooo`001`3o
ool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050<c<c00R8R800000028R8P3<
c<`01@3oool00`000000oooo0?ooo`3A0?ooo`L00000K03oool000L0oooo00D0MgMg09VIV@3oool0
VIVI07MgM`050?ooo`808R8R103oool01@0R8R80VIVI0?ooo`2IVIT08R8R00D0oooo00<000000?oo
o`3oool0e03oool6000006X0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@00
0000oooo0?ooo`3oool0000000D0oooo0`00003G0?ooo`H00000I`3oool000L0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`0503<c<`2IVIT0oooo09VIV@0c<c<01@3oool00`000000oooo0?oo
o`3I0?ooo`H00000I@3oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050<c<c000
000000000000003<c<`01@3oool00`000000oooo0?ooo`3L0?ooo`D00000H`3oool000L0oooo00D0
4A4A0?ooo`3oool0oooo014A4@0;0?ooo`05014A4@2k^k/0oooo0;^k^`0A4A401@3oool00`000000
oooo0?ooo`3N0?ooo`D00000H@3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`05
0000002k^k/0oooo0;^k^`0000001@3oool00`000000oooo0?ooo`3P0?ooo`D00000G`3oool000L0
oooo00D0k^k^03<c<`000000<c<c0>k^kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX01@3oool0
0`000000oooo0?ooo`3R0?ooo`D00000G@3oool00240oooo00<000000?ooo`3oool0i03oool50000
05/0oooo000Q0?ooo`030000003oool0oooo0>H0oooo1@00001I0?ooo`008@3oool00`000000oooo
0?ooo`3X0?ooo`D00000E`3oool00240oooo0P00003[0?ooo`D00000E@3oool00240oooo00<00000
0?ooo`3oool0k03oool5000005<0oooo000Q0?ooo`030000003oool0oooo0>h0oooo1@00001A0?oo
o`008@3oool00`000000oooo0?ooo`3`0?ooo`D00000C`3oool00240oooo00<000000?ooo`3oool0
lP3oool5000004d0oooo000Q0?ooo`030000003oool0oooo0?@0oooo1P00001:0?ooo`008@3oool0
0`000000oooo0?ooo`3f0?ooo`L00000A`3oool00240oooo00<000000?ooo`3oool0n@3oool60000
04D0oooo000Q0?ooo`030000003oool0oooo0?`0oooo1P0000120?ooo`008@3oool00`000000oooo
0?ooo`3n0?ooo`H00000@03oool00240oooo0P00003o0?ooo`<0oooo1@00000n0?ooo`008@3oool0
0`000000oooo0?ooo`3o0?ooo`@0oooo1@00000l0?ooo`008@3oool00`000000oooo0?ooo`3o0?oo
o`H0oooo1000000k0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo1000000i0?ooo`00
8@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo1@00000g0?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooo`/0oooo1@00000e0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`d0oooo1@00000c
0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo1@00000a0?ooo`008@3oool00`000000
oooo0?ooo`3o0?oooa40oooo1@00000_0?ooo`008@3oool200000?l0oooo503oool4000002h0oooo
000Q0?ooo`030000003oool0oooo0?l0oooo5@3oool4000002`0oooo000Q0?ooo`030000003oool0
oooo0?l0oooo5P3oool5000002X0oooo000Q0?ooo`030000003oool0oooo0?l0oooo603oool50000
02P0oooo000Q0?ooo`030000003oool0oooo0?l0oooo6P3oool5000002H0oooo000Q0?ooo`030000
003oool0oooo0?l0oooo703oool5000002@0oooo000Q0?ooo`030000003oool0oooo0?l0oooo7P3o
ool500000280oooo000H0?ooo`@0000000<04A4A0?ooo`3oool00P3oool00`000000oooo0?ooo`3o
0?ooob00oooo1@00000P0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0?l0oooo8P3oool5000001h0oooo000J0?ooo`030000003oool0oooo00@0oooo0`00003o0?ooob@0
oooo1@00000L0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooobd0oooo0`00000L0?ooo`006P3o
ool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool0
01X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00603oool205EEE@030000003oool0oooo0?l0
ooooC03oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool009X0oooo00D0VIVI0000
00000000A4A40;^k^`0H0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8PD0oooo1000
0000200A4A40oooo0?ooo`3<c<`08R8R0000000R8R80c<c<U03oool009X0oooo00D04A4A0;^k^`3^
k^h0MgMg014A4@090?ooo`H000002@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R87
0?ooo`030000003oool0oooo0080oooo00D08R8R09VIV@3oool0VIVI028R8P2D0?ooo`00VP3oool0
0`000000oooo0?ooo`0J0?ooo`05014A4@3oool0oooo0?ooo`0A4A403P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000U03oool001l0oooo00D04A4A0000000000000000
014A4@1f0?ooo`030000003oool0oooo00/0oooo1P0000090?ooo`050000003oool0oooo0?ooo`00
00003P3oool00`000000oooo0?ooo`020?ooo`0503<c<`2IVIT0oooo09VIV@0c<c<0U03oool00240
oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?oo
o`0000003P3oool00`000000oooo0?ooo`020?ooo`050<c<c000000000000000003<c<`0U03oool0
0240oooo00<000000?ooo`3oool0M03oool00`0A4A40000000000003000001T0oooo00D04A4A0?oo
o`3oool0oooo014A4@0>0?ooo`030000003oool0oooo0080oooo00D04A4A0;^k^`3oool0^k^k014A
4@2D0?ooo`008@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01X0oooo00D0MgMg
09VIV@3oool0VIVI07MgM`0>0?ooo`030000003oool0oooo0080oooo00D000000;^k^`3oool0^k^k
0000002D0?ooo`008@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01X0oooo00D0
k^k^03<c<`000000<c<c0>k^kP0<0?ooo`80EEEE00<000000?ooo`3oool00P3oool01@2ZZZX04A4A
0000000A4A40ZZZZ09@0oooo000N0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0o`3ooom20?ooo`007P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0
oooo@P3oool001h0oooo1`00003o0?oood@0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?oo
ofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .03118 L
.08481 .0653 L
.12636 .09758 L
.16632 .12893 L
.20885 .16274 L
.2498 .19581 L
.29331 .23161 L
.33524 .2668 L
.37557 .30138 L
.41848 .33899 L
.4598 .37604 L
.48055 .39497 L
.48962 .40331 L
.49442 .40774 L
.49705 .41017 L
.49834 .41136 L
.49953 .41247 L
.50089 .41318 L
.50161 .4134 L
.50237 .41364 L
.50495 .41444 L
.50998 .41601 L
.51991 .41915 L
.54183 .42626 L
.5817 .4398 L
.62415 .45506 L
.665 .47053 L
.70843 .48777 L
.75027 .50509 L
.79051 .52233 L
.83333 .54121 L
.87456 .55983 L
.9142 .57804 L
.95642 .59765 L
.99704 .61665 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`@00000>03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`00
00000`00003o0?oood80oooo000Q0?ooo`030000003oool0oooo00@00000o`3ooom10?ooo`008@3o
ool00`000000oooo0?ooo`020?ooo`<00000o`3ooom00?ooo`008@3oool00`000000oooo0?ooo`03
0?ooo`@00000o`3oooln0?ooo`008@3oool00`000000oooo0?ooo`040?ooo`@00000o`3ooolm0?oo
o`008@3oool00`000000oooo0?ooo`060?ooo`<00000o`3oooll0?ooo`008@3oool2000000P0oooo
1000003o0?ooocX0oooo000Q0?ooo`030000003oool0oooo00P0oooo1000003o0?ooocT0oooo000Q
0?ooo`030000003oool0oooo00X0oooo0`00003o0?ooocP0oooo000Q0?ooo`030000003oool0oooo
00/0oooo0`00003o0?ooocL0oooo000Q0?ooo`030000003oool0oooo00`0oooo1000003o0?ooocD0
oooo000Q0?ooo`030000003oool0oooo00d0oooo1000003o0?oooc@0oooo000Q0?ooo`030000003o
ool0oooo00l0oooo0`00003o0?oooc<0oooo000Q0?ooo`030000003oool0oooo0100oooo1000003o
0?oooc40oooo000Q0?ooo`030000003oool0oooo0140oooo1000003o0?oooc00oooo000Q0?ooo`80
0000503oool300000?l0oooo;`3oool00240oooo00<000000?ooo`3oool0503oool300000?l0oooo
;P3oool00240oooo00<000000?ooo`3oool05@3oool400000?l0oooo;03oool00240oooo00<00000
0?ooo`3oool05P3oool400000?l0oooo:`3oool00240oooo00<000000?ooo`3oool0603oool30000
0?l0oooo:P3oool00240oooo00<000000?ooo`3oool06@3oool400000?l0oooo:03oool00240oooo
00<000000?ooo`3oool06P3oool400000?l0oooo9`3oool00240oooo00<000000?ooo`3oool0703o
ool300000?l0oooo9P3oool00240oooo00<000000?ooo`3oool07@3oool400000?l0oooo903oool0
0240oooo00<000000?ooo`3oool07P3oool400000?l0oooo8`3oool00240oooo0P00000Q0?ooo`<0
0000o`3ooolR0?ooo`008@3oool00`000000oooo0?ooo`0Q0?ooo`@00000o`3ooolP0?ooo`008@3o
ool00`000000oooo0?ooo`0R0?ooo`@00000o`3ooolO0?ooo`008@3oool00`000000oooo0?ooo`0T
0?ooo`<00000o`3ooolN0?ooo`008@3oool00`000000oooo0?ooo`0U0?ooo`@00000o`3ooolL0?oo
o`008@3oool00`000000oooo0?ooo`0V0?ooo`@00000o`3ooolK0?ooo`001`3oool01@3^k^h0<c<c
0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`D000001@3oool00`000000oooo0?ooo`0X0?ooo`<0
0000o`3ooolJ0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05
09VIV@0R8R80k^k^0?ooo`14A4@01@3oool00`000000oooo0?ooo`0Y0?ooo`@00000o`3ooolH0?oo
o`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<0VIVI028R8P3^k^h01P3oool00`00
0000oooo0?ooo`0Z0?ooo`@00000o`3ooolG0?ooo`001`3oool01@000000oooo0?ooo`3oool00000
00d0oooo00<0VIVI028R8P3^k^h01@3oool3000002`0oooo0`00003o0?oooaH0oooo00070?ooo`05
0000003oool0oooo0?ooo`0000003P3oool00`1gMgL0IVIV0?ooo`040?ooo`030000003oool0oooo
02d0oooo1000003o0?oooa@0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02h0oooo1000003o0?oooa<0oooo00070?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2IVIT04A4A00D0oooo00<00000
0?ooo`3oool0<03oool300000?l0oooo4P3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP0;
0?ooo`0509VIV@0A4A400000028R8P3<c<`01@3oool00`000000oooo0?ooo`0a0?ooo`<00000o`3o
oolA0?ooo`008@3oool00`000000oooo0?ooo`0b0?ooo`<00000o`3oool@0?ooo`008@3oool00`00
0000oooo0?ooo`0c0?ooo`<00000o`3oool?0?ooo`008@3oool00`000000oooo0?ooo`0d0?ooo`<0
0000o`3oool>0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`<00000o`3oool=0?ooo`008@3o
ool2000003L0oooo0`00003o0?ooo``0oooo000Q0?ooo`030000003oool0oooo03L0oooo0`00003o
0?ooo`/0oooo000Q0?ooo`030000003oool0oooo03P0oooo0`00003o0?ooo`X0oooo000Q0?ooo`03
0000003oool0oooo03T0oooo1000003o0?ooo`P0oooo000Q0?ooo`030000003oool0oooo03X0oooo
1000003o0?ooo`L0oooo000Q0?ooo`030000003oool0oooo03`0oooo1000003o0?ooo`D0oooo000Q
0?ooo`030000003oool0oooo03d0oooo1000003o0?ooo`@0oooo000Q0?ooo`030000003oool0oooo
03l0oooo1000003o0?ooo`80oooo000Q0?ooo`030000003oool0oooo0400oooo1000003o0?ooo`40
oooo000Q0?ooo`800000@`3oool300000?l0oooo000Q0?ooo`030000003oool0oooo04<0oooo1000
003m0?ooo`008@3oool00`000000oooo0?ooo`140?ooo`@00000o03oool00240oooo00<000000?oo
o`3oool0AP3oool400000?X0oooo000Q0?ooo`030000003oool0oooo04L0oooo1000003i0?ooo`00
8@3oool00`000000oooo0?ooo`190?ooo`<00000n03oool00240oooo00<000000?ooo`3oool0BP3o
ool300000?L0oooo000Q0?ooo`030000003oool0oooo04/0oooo0`00003f0?ooo`008@3oool00`00
0000oooo0?ooo`1<0?ooo`@00000m03oool00240oooo0P00001>0?ooo`@00000l`3oool00240oooo
00<000000?ooo`3oool0C`3oool300000?80oooo000Q0?ooo`030000003oool0oooo0500oooo0`00
003a0?ooo`008@3oool00`000000oooo0?ooo`1A0?ooo`<00000l03oool00240oooo00<000000?oo
o`3oool0DP3oool300000>l0oooo000Q0?ooo`030000003oool0oooo05<0oooo1000003]0?ooo`00
8@3oool00`000000oooo0?ooo`1D0?ooo`@00000k03oool000L0oooo00D0k^k^03<c<`000000<c<c
0>k^kP050?ooo`808R8R1P3oool200000003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0
EP3oool300000>/0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1G0?ooo`<00000jP3oool000L0oooo00D0
4A4A0?ooo`3oool0oooo014A4@0;0?ooo`D000001@3oool00`000000oooo0?ooo`1H0?ooo`<00000
j@3oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`0404A4A03MgMd0oooo000000H0
oooo0`00001I0?ooo`<00000j03oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`04
0=gMg@1EEED0oooo000000H0oooo00<000000?ooo`3oool0FP3oool300000>L0oooo00070?ooo`05
014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<000000060?ooo`030000003oool0oooo
05/0oooo0`00003V0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4
A00000001P3oool00`000000oooo0?ooo`1L0?ooo`<00000i@3oool000L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo00D0oooo00<000000?ooo`3oool0G@3oool30000
0>@0oooo000Q0?ooo`030000003oool0oooo05h0oooo0`00003S0?ooo`008@3oool00`000000oooo
0?ooo`1O0?ooo`@00000h@3oool00240oooo00<000000?ooo`3oool0H03oool400000>00oooo000Q
0?ooo`030000003oool0oooo0680oooo0`00003O0?ooo`008@3oool2000006@0oooo0`00003N0?oo
o`008@3oool00`000000oooo0?ooo`1T0?ooo`<00000g@3oool00240oooo00<000000?ooo`3oool0
I@3oool400000=/0oooo000Q0?ooo`030000003oool0oooo06H0oooo1000003J0?ooo`008@3oool0
0`000000oooo0?ooo`1X0?ooo`<00000f@3oool00240oooo00<000000?ooo`3oool0J@3oool30000
0=P0oooo000Q0?ooo`030000003oool0oooo06X0oooo0`00003G0?ooo`008@3oool00`000000oooo
0?ooo`1[0?ooo`@00000e@3oool00240oooo00<000000?ooo`3oool0K03oool400000=@0oooo000Q
0?ooo`800000K`3oool300000=<0oooo000Q0?ooo`030000003oool0oooo06l0oooo0`00003B0?oo
o`008@3oool00`000000oooo0?ooo`1`0?ooo`<00000d@3oool00240oooo00<000000?ooo`3oool0
L@3oool400000<l0oooo000Q0?ooo`030000003oool0oooo0780oooo1000003>0?ooo`008@3oool0
0`000000oooo0?ooo`1d0?ooo`<00000c@3oool00240oooo00<000000?ooo`3oool0M@3oool30000
0<`0oooo000Q0?ooo`030000003oool0oooo07H0oooo0`00003;0?ooo`008@3oool00`000000oooo
0?ooo`1g0?ooo`<00000bP3oool00240oooo0P00001i0?ooo`@00000b03oool00240oooo00<00000
0?ooo`3oool0N@3oool400000<L0oooo000Q0?ooo`030000003oool0oooo07/0oooo0`0000360?oo
o`008@3oool00`000000oooo0?ooo`1l0?ooo`<00000a@3oool00240oooo00<000000?ooo`3oool0
O@3oool300000<@0oooo000Q0?ooo`030000003oool0oooo07h0oooo0`0000330?ooo`008@3oool0
0`000000oooo0?ooo`1o0?ooo`<00000`P3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP05
0?ooo`808R8R103oool01@3^k^h0<c<c0000000A4A40c<c<00D0oooo00<000000?ooo`3oool0P03o
ool300000<40oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0
EEEE07MgM`3oool0VIVI028R8P050?ooo`030000003oool0oooo0840oooo0`0000300?ooo`001`3o
ool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo00D000000?ooo`3oool0oooo000000050?ooo`<0
0000PP3oool300000;l0oooo00070?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000
VIVI0?ooo`2IVIT08R8R00D0oooo00<000000?ooo`3oool0P`3oool300000;h0oooo00070?ooo`05
0000003oool0oooo0?ooo`0000002`3oool01@000000EEEE0000000A4A40c<c<00D0oooo00<00000
0?ooo`3oool0Q03oool300000;d0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool0
0`1EEED0R8R80?ooo`070?ooo`030000003oool0oooo08D0oooo0`00002l0?ooo`001`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT01`3oool00`000000oooo0?ooo`26
0?ooo`<00000^`3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`040<c<c014A4@0
0000014A4@D0oooo00<000000?ooo`3oool0Q`3oool300000;X0oooo000Q0?ooo`030000003oool0
oooo08P0oooo0`00002i0?ooo`008@3oool00`000000oooo0?ooo`290?ooo`<00000^03oool00240
oooo00<000000?ooo`3oool0RP3oool400000;H0oooo000Q0?ooo`030000003oool0oooo08/0oooo
1000002e0?ooo`008@3oool2000008h0oooo0`00002d0?ooo`008@3oool00`000000oooo0?ooo`2>
0?ooo`<00000/`3oool00240oooo00<000000?ooo`3oool0S`3oool300000;80oooo000Q0?ooo`03
0000003oool0oooo0900oooo1@00002_0?ooo`008@3oool00`000000oooo0?ooo`2A0?ooo`L00000
[03oool00240oooo00<000000?ooo`3oool0U03oool700000:T0oooo000Q0?ooo`030000003oool0
oooo09L0oooo1`00002V0?ooo`008@3oool00`000000oooo0?ooo`2J0?ooo`L00000X`3oool00240
oooo00<000000?ooo`3oool0W@3oool700000:00oooo000Q0?ooo`800000X@3oool7000009d0oooo
000Q0?ooo`030000003oool0oooo0:<0oooo1`00002J0?ooo`008@3oool00`000000oooo0?ooo`2V
0?ooo`H00000V03oool00240oooo00<000000?ooo`3oool0Z@3oool6000009D0oooo000Q0?ooo`03
0000003oool0oooo0:/0oooo1`00002B0?ooo`008@3oool00`000000oooo0?ooo`2^0?ooo`H00000
T03oool00240oooo00<000000?ooo`3oool0/@3oool6000008d0oooo000Q0?ooo`030000003oool0
oooo0;<0oooo1`00002:0?ooo`008@3oool00`000000oooo0?ooo`2f0?ooo`L00000Q`3oool00240
oooo0P00002j0?ooo`L00000Q03oool00240oooo00<000000?ooo`3oool0_03oool700000840oooo
000Q0?ooo`030000003oool0oooo0;l0oooo1P00001o0?ooo`008@3oool00`000000oooo0?ooo`32
0?ooo`H00000O03oool00240oooo00<000000?ooo`3oool0a03oool7000007T0oooo000Q0?ooo`03
0000003oool0oooo0<L0oooo1P00001g0?ooo`008@3oool00`000000oooo0?ooo`3:0?ooo`H00000
M03oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R103oool01@3<c<`08R8R
0000000R8R80c<c<00D0oooo00<000000?ooo`3oool0c03oool600000780oooo00070?ooo`0507Mg
M`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D08R8R09VIV@3oool0VIVI028R8P050?oo
o`030000003oool0oooo0<l0oooo1P00001_0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A
00/0oooo00D000000?ooo`3oool0oooo000000050?ooo`<00000d@3oool7000006`0oooo00070?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c00D0oooo00<0
00000?ooo`3oool0e03oool6000006X0oooo00070?ooo`050000003oool0oooo0?ooo`0000002`3o
ool01@3<c<`00000000000000000c<c<00D0oooo00<000000?ooo`3oool0e`3oool6000006L0oooo
00070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A00D0
oooo00<000000?ooo`3oool0f@3oool6000006D0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL02`3oool01@000000^k^k0?ooo`2k^k/0000000D0oooo00<000000?ooo`3oool0g03oool50000
06<0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2ZZZX04A4A0000000A4A40
ZZZZ00D0oooo00<000000?ooo`3oool0gP3oool500000640oooo000Q0?ooo`030000003oool0oooo
0>00oooo1@00001O0?ooo`008@3oool00`000000oooo0?ooo`3R0?ooo`D00000G@3oool00240oooo
00<000000?ooo`3oool0i03oool5000005/0oooo000Q0?ooo`800000i`3oool5000005T0oooo000Q
0?ooo`030000003oool0oooo0>P0oooo1P00001F0?ooo`008@3oool00`000000oooo0?ooo`3Z0?oo
o`H00000E03oool00240oooo00<000000?ooo`3oool0k@3oool500000580oooo000Q0?ooo`030000
003oool0oooo0>l0oooo1P00001?0?ooo`008@3oool00`000000oooo0?ooo`3a0?ooo`H00000C@3o
ool00240oooo00<000000?ooo`3oool0m03oool5000004/0oooo000Q0?ooo`030000003oool0oooo
0?H0oooo1@0000190?ooo`008@3oool00`000000oooo0?ooo`3h0?ooo`H00000AP3oool00240oooo
00<000000?ooo`3oool0nP3oool6000004@0oooo000Q0?ooo`800000oP3oool500000480oooo000Q
0?ooo`030000003oool0oooo0?l0oooo1@0000100?ooo`008@3oool00`000000oooo0?ooo`3o0?oo
o`80oooo1@00000n0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo1P00000k0?ooo`00
8@3oool00`000000oooo0?ooo`3o0?ooo`H0oooo1P00000i0?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo1@00000g0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo1@00000e
0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`d0oooo1@00000c0?ooo`008@3oool00`000000
oooo0?ooo`3o0?ooo`l0oooo1@00000a0?ooo`008@3oool200000?l0oooo4P3oool6000002h0oooo
000Q0?ooo`030000003oool0oooo0?l0oooo4`3oool6000002`0oooo000Q0?ooo`030000003oool0
oooo0?l0oooo5P3oool5000002X0oooo000Q0?ooo`030000003oool0oooo0?l0oooo603oool50000
02P0oooo000Q0?ooo`030000003oool0oooo0?l0oooo6P3oool5000002H0oooo000Q0?ooo`030000
003oool0oooo0?l0oooo703oool5000002@0oooo000Q0?ooo`030000003oool0oooo0?l0oooo7P3o
ool500000280oooo000H0?ooo`@0000000<04A4A0?ooo`3oool00P3oool00`000000oooo0?ooo`3o
0?ooob00oooo1@00000P0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0?l0oooo8P3oool5000001h0oooo000J0?ooo`030000003oool0oooo00@0oooo0`00003o0?ooob@0
oooo1@00000L0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooobd0oooo0`00000L0?ooo`006P3o
ool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool0
01X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00603oool205EEE@030000003oool0oooo0?l0
ooooC03oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool009h0oooo00D0VIVI0000
00000000A4A40;^k^`0H0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo1@00
002H0?ooo`00WP3oool01@0A4A40^k^k0>k^kP1gMgL04A4A00T0oooo1P0000090?ooo`0507MgM`2I
VIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A02H0?ooo`00
WP3oool00`000000oooo0?ooo`0J0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`2IVIT0
8R8R0>k^kP2I0?ooo`007`3oool01@0A4A4000000000000000004A4A07X0oooo00<000000?ooo`3o
ool02`3oool6000000T0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`0309VIV@0R8R80k^k^
09P0oooo000Q0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool06P3oool01@000000
oooo0?ooo`3oool0000000h0oooo00<0MgMg06IVIP3oool0U`3oool00240oooo00<000000?ooo`3o
ool0N03oool00`0A4A40000000000003000001T0oooo00D04A4A0?ooo`3oool0oooo014A4@0?0?oo
o`030000003oool0oooo09H0oooo000Q0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3o
ool06P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@2H
0?ooo`008@3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo01X0oooo00D0k^k^03<c
<`000000<c<c0>k^kP0;0?ooo`0509VIV@0A4A400000028R8P3<c<`0V03oool001h0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oood80oooo000N0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0o`3ooom20?ooo`007P3oool700000?l0ooooA03oool0
0?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .03233 L
.08481 .06768 L
.12636 .10108 L
.16632 .13345 L
.20885 .16827 L
.2498 .20221 L
.29331 .23882 L
.33524 .27468 L
.37557 .30976 L
.41848 .34776 L
.4598 .38504 L
.48055 .40402 L
.48962 .41237 L
.49442 .4168 L
.49705 .41924 L
.49834 .42043 L
.49953 .42153 L
.50089 .42225 L
.50161 .42247 L
.50237 .4227 L
.50495 .4235 L
.50998 .42507 L
.51991 .4282 L
.54183 .43525 L
.5817 .44858 L
.62415 .46345 L
.665 .47841 L
.70843 .49497 L
.75027 .5115 L
.79051 .52788 L
.83333 .54575 L
.87456 .56331 L
.9142 .58045 L
.95642 .59889 L
.99704 .61673 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`@00000>03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`00
00000P00003o0?oood<0oooo000Q0?ooo`030000003oool0oooo00<00000o`3ooom20?ooo`008@3o
ool010000000oooo0?ooo`3oool400000?l0oooo@03oool00240oooo00<000000?ooo`3oool00P3o
ool400000?l0oooo?`3oool00240oooo00<000000?ooo`3oool0103oool300000?l0oooo?P3oool0
0240oooo00<000000?ooo`3oool01@3oool300000?l0oooo?@3oool00240oooo0P0000070?ooo`<0
0000o`3oooll0?ooo`008@3oool00`000000oooo0?ooo`070?ooo`@00000o`3ooolj0?ooo`008@3o
ool00`000000oooo0?ooo`080?ooo`@00000o`3oooli0?ooo`008@3oool00`000000oooo0?ooo`0:
0?ooo`@00000o`3ooolg0?ooo`008@3oool00`000000oooo0?ooo`0;0?ooo`@00000o`3ooolf0?oo
o`008@3oool00`000000oooo0?ooo`0=0?ooo`<00000o`3ooole0?ooo`008@3oool00`000000oooo
0?ooo`0>0?ooo`@00000o`3ooolc0?ooo`008@3oool00`000000oooo0?ooo`0?0?ooo`@00000o`3o
oolb0?ooo`008@3oool00`000000oooo0?ooo`0A0?ooo`@00000o`3oool`0?ooo`008@3oool20000
01<0oooo1000003o0?ooobl0oooo000Q0?ooo`030000003oool0oooo01@0oooo0`00003o0?ooobh0
oooo000Q0?ooo`030000003oool0oooo01D0oooo1000003o0?ooob`0oooo000Q0?ooo`030000003o
ool0oooo01H0oooo1000003o0?ooob/0oooo000Q0?ooo`030000003oool0oooo01P0oooo0`00003o
0?ooobX0oooo000Q0?ooo`030000003oool0oooo01T0oooo0`00003o0?ooobT0oooo000Q0?ooo`03
0000003oool0oooo01X0oooo0`00003o0?ooobP0oooo000Q0?ooo`030000003oool0oooo01/0oooo
1000003o0?ooobH0oooo000Q0?ooo`030000003oool0oooo01`0oooo1000003o0?ooobD0oooo000Q
0?ooo`030000003oool0oooo01h0oooo0`00003o0?ooob@0oooo000Q0?ooo`800000803oool30000
0?l0oooo8`3oool00240oooo00<000000?ooo`3oool0803oool300000?l0oooo8P3oool00240oooo
00<000000?ooo`3oool08@3oool400000?l0oooo803oool00240oooo00<000000?ooo`3oool08P3o
ool400000?l0oooo7`3oool00240oooo00<000000?ooo`3oool0903oool300000?l0oooo7P3oool0
0240oooo00<000000?ooo`3oool09@3oool300000?l0oooo7@3oool000L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R103oool5000000D0oooo00<000000?ooo`3oool09P3oool30000
0?l0oooo703oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@2I
VIT08R8R0>k^kP3oool0A4A400D0oooo00<000000?ooo`3oool09`3oool400000?l0oooo6P3oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^00H0oooo00<00000
0?ooo`3oool0:03oool400000?l0oooo6@3oool000L0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`0309VIV@0R8R80k^k^00D0oooo0`00000Z0?ooo`<00000o`3ooolH0?ooo`001`3oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<0MgMg06IVIP3oool0103oool00`000000oooo0?ooo`0[
0?ooo`<00000o`3ooolG0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00l0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0/0?ooo`<00000o`3ooolF0?ooo`001`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@050?ooo`030000003o
ool0oooo02d0oooo1000003o0?oooa@0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3o
ool01@2IVIT04A4A0000000R8R80c<c<00D0oooo00<000000?ooo`3oool0;P3oool400000?l0oooo
4`3oool00240oooo00<000000?ooo`3oool0<03oool300000?l0oooo4P3oool00240oooo00<00000
0?ooo`3oool0<@3oool300000?l0oooo4@3oool00240oooo00<000000?ooo`3oool0<P3oool30000
0?l0oooo403oool00240oooo00<000000?ooo`3oool0<`3oool400000?l0oooo3P3oool00240oooo
0P00000e0?ooo`@00000o`3oool=0?ooo`008@3oool00`000000oooo0?ooo`0f0?ooo`<00000o`3o
ool<0?ooo`008@3oool00`000000oooo0?ooo`0g0?ooo`<00000o`3oool;0?ooo`008@3oool00`00
0000oooo0?ooo`0h0?ooo`<00000o`3oool:0?ooo`008@3oool00`000000oooo0?ooo`0i0?ooo`@0
0000o`3oool80?ooo`008@3oool00`000000oooo0?ooo`0j0?ooo`@00000o`3oool70?ooo`008@3o
ool00`000000oooo0?ooo`0l0?ooo`<00000o`3oool60?ooo`008@3oool00`000000oooo0?ooo`0m
0?ooo`@00000o`3oool40?ooo`008@3oool00`000000oooo0?ooo`0n0?ooo`@00000o`3oool30?oo
o`008@3oool200000440oooo0`00003o0?ooo`80oooo000Q0?ooo`030000003oool0oooo0440oooo
0`00003o0?ooo`40oooo000Q0?ooo`030000003oool0oooo0480oooo1000003n0?ooo`008@3oool0
0`000000oooo0?ooo`130?ooo`@00000o@3oool00240oooo00<000000?ooo`3oool0A@3oool30000
0?`0oooo000Q0?ooo`030000003oool0oooo04H0oooo1000003j0?ooo`008@3oool00`000000oooo
0?ooo`170?ooo`@00000n@3oool00240oooo00<000000?ooo`3oool0B@3oool300000?P0oooo000Q
0?ooo`030000003oool0oooo04X0oooo0`00003g0?ooo`008@3oool2000004`0oooo0`00003f0?oo
o`008@3oool00`000000oooo0?ooo`1<0?ooo`@00000m03oool00240oooo00<000000?ooo`3oool0
C@3oool400000?<0oooo000Q0?ooo`030000003oool0oooo04l0oooo0`00003b0?ooo`008@3oool0
0`000000oooo0?ooo`1@0?ooo`<00000l@3oool00240oooo00<000000?ooo`3oool0D@3oool30000
0?00oooo000Q0?ooo`030000003oool0oooo0580oooo0`00003_0?ooo`001`3oool01@3^k^h0<c<c
0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A0?ooo`3oool00`3oool00`000000
oooo0?ooo`1C0?ooo`@00000k@3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`80
8R8R1`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05@0oooo1000003/0?ooo`00
1`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@0000050?ooo`030000003oool0oooo05H0
oooo0`00003[0?ooo`001`3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3o
ool000001P3oool3000005L0oooo0`00003Z0?ooo`001`3oool01@000000oooo0?ooo`3oool00000
00/0oooo00@0gMgM05EEE@3oool000001P3oool00`000000oooo0?ooo`1H0?ooo`<00000j@3oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0307MgM`3<c<`0000000H0oooo00<00000
0?ooo`3oool0F@3oool300000>P0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool0
0`3^k^h0A4A4000000060?ooo`030000003oool0oooo05X0oooo0`00003W0?ooo`001`3oool01@3^
k^h0<c<c0000000c<c<0k^k^00d0oooo00<0MgMg0000003oool01@3oool00`000000oooo0?ooo`1K
0?ooo`<00000iP3oool00240oooo00<000000?ooo`3oool0G03oool300000>D0oooo000Q0?ooo`03
0000003oool0oooo05d0oooo0`00003T0?ooo`008@3oool00`000000oooo0?ooo`1N0?ooo`<00000
h`3oool00240oooo00<000000?ooo`3oool0G`3oool400000>40oooo000Q0?ooo`800000H@3oool4
00000>00oooo000Q0?ooo`030000003oool0oooo0680oooo0`00003O0?ooo`008@3oool00`000000
oooo0?ooo`1S0?ooo`<00000gP3oool00240oooo00<000000?ooo`3oool0I03oool300000=d0oooo
000Q0?ooo`030000003oool0oooo06D0oooo1000003K0?ooo`008@3oool00`000000oooo0?ooo`1V
0?ooo`@00000fP3oool00240oooo00<000000?ooo`3oool0J03oool300000=T0oooo000Q0?ooo`03
0000003oool0oooo06T0oooo0`00003H0?ooo`008@3oool00`000000oooo0?ooo`1Z0?ooo`<00000
e`3oool00240oooo0P00001/0?ooo`@00000e@3oool00240oooo00<000000?ooo`3oool0K03oool4
00000=@0oooo000Q0?ooo`030000003oool0oooo06h0oooo0`00003C0?ooo`008@3oool00`000000
oooo0?ooo`1_0?ooo`<00000dP3oool00240oooo00<000000?ooo`3oool0L03oool300000=40oooo
000Q0?ooo`030000003oool0oooo0740oooo0`00003@0?ooo`008@3oool00`000000oooo0?ooo`1b
0?ooo`<00000c`3oool00240oooo00<000000?ooo`3oool0L`3oool300000<h0oooo000Q0?ooo`03
0000003oool0oooo07@0oooo0`00003=0?ooo`008@3oool2000007H0oooo0`00003<0?ooo`008@3o
ool00`000000oooo0?ooo`1f0?ooo`<00000b`3oool00240oooo00<000000?ooo`3oool0M`3oool3
00000<X0oooo000Q0?ooo`030000003oool0oooo07P0oooo100000380?ooo`008@3oool00`000000
oooo0?ooo`1i0?ooo`@00000a`3oool00240oooo00<000000?ooo`3oool0N`3oool300000<H0oooo
000Q0?ooo`030000003oool0oooo07`0oooo0`0000350?ooo`001`3oool01@3^k^h0<c<c0000000c
<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c<c<00000014A4@3<c<`01@3oool00`000000oooo
0?ooo`1m0?ooo`<00000a03oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R
103oool01@1EEED0MgMg0?ooo`2IVIT08R8R00D0oooo00<000000?ooo`3oool0OP3oool300000<<0
oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool00000
00D0oooo0`00001o0?ooo`<00000`P3oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`050000002IVIT0oooo09VIV@0R8R801@3oool00`000000oooo0?ooo`200?ooo`<00000`@3oool0
00L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`01@3o
ool00`000000oooo0?ooo`210?ooo`<00000`03oool000L0oooo00D04A4A0?ooo`3oool0oooo014A
4@0;0?ooo`0305EEE@28R8P0oooo00L0oooo00<000000?ooo`3oool0PP3oool300000;l0oooo0007
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool00`3MgMd04A4A09VIV@070?ooo`030000003o
ool0oooo08<0oooo0`00002n0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00`0oooo00@0
c<c<04A4A00000004A4A1@3oool00`000000oooo0?ooo`240?ooo`@00000_03oool00240oooo00<0
00000?ooo`3oool0Q@3oool400000;/0oooo000Q0?ooo`030000003oool0oooo08L0oooo0`00002j
0?ooo`008@3oool00`000000oooo0?ooo`280?ooo`<00000^@3oool00240oooo00<000000?ooo`3o
ool0R@3oool300000;P0oooo000Q0?ooo`800000R`3oool300000;L0oooo000Q0?ooo`030000003o
ool0oooo08/0oooo0`00002f0?ooo`008@3oool00`000000oooo0?ooo`2<0?ooo`<00000]@3oool0
0240oooo00<000000?ooo`3oool0S@3oool300000;@0oooo000Q0?ooo`030000003oool0oooo08h0
oooo0`00002c0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`@00000/@3oool00240oooo00<0
00000?ooo`3oool0T03oool500000:l0oooo000Q0?ooo`030000003oool0oooo0940oooo1`00002/
0?ooo`008@3oool00`000000oooo0?ooo`2D0?ooo`L00000Z@3oool00240oooo0P00002H0?ooo`L0
0000YP3oool00240oooo00<000000?ooo`3oool0VP3oool700000:<0oooo000Q0?ooo`030000003o
ool0oooo09d0oooo1`00002P0?ooo`008@3oool00`000000oooo0?ooo`2P0?ooo`L00000W@3oool0
0240oooo00<000000?ooo`3oool0X`3oool7000009X0oooo000Q0?ooo`030000003oool0oooo0:H0
oooo1`00002G0?ooo`008@3oool00`000000oooo0?ooo`2Y0?ooo`L00000U03oool00240oooo00<0
00000?ooo`3oool0[03oool700000940oooo000Q0?ooo`030000003oool0oooo0:l0oooo1`00002>
0?ooo`008@3oool200000;<0oooo2000002:0?ooo`008@3oool00`000000oooo0?ooo`2e0?ooo`P0
0000Q`3oool00240oooo00<000000?ooo`3oool0^@3oool7000008@0oooo000Q0?ooo`030000003o
ool0oooo0;`0oooo1`0000210?ooo`008@3oool00`000000oooo0?ooo`2o0?ooo`H00000O`3oool0
0240oooo00<000000?ooo`3oool0`P3oool6000007`0oooo000Q0?ooo`030000003oool0oooo0<@0
oooo1`00001i0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`01@3oool00`000000oooo0?ooo`370?ooo`H00000M`3oool000L0
oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@0R8R80VIVI0?ooo`2IVIT0
8R8R00D0oooo00<000000?ooo`3oool0bP3oool6000007@0oooo00070?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000000D0oooo0`00003<0?ooo`H00000LP3o
ool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`0503<c<`2IVIT0oooo09VIV@0c<c<0
1@3oool00`000000oooo0?ooo`3?0?ooo`H00000K`3oool000L0oooo00D000000?ooo`3oool0oooo
0000000;0?ooo`050<c<c000000000000000003<c<`01@3oool00`000000oooo0?ooo`3A0?ooo`L0
0000K03oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`05014A4@2k^k/0oooo0;^k
^`0A4A401@3oool00`000000oooo0?ooo`3D0?ooo`H00000JP3oool000L0oooo00D0MgMg09VIV@3o
ool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo0;^k^`0000001@3oool00`000000oooo0?ooo`3G
0?ooo`H00000I`3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP0;0?ooo`050:ZZZP0A4A40
0000014A4@2ZZZX01@3oool00`000000oooo0?ooo`3I0?ooo`H00000I@3oool00240oooo00<00000
0?ooo`3oool0g03oool600000680oooo000Q0?ooo`030000003oool0oooo0=h0oooo1P00001P0?oo
o`008@3oool00`000000oooo0?ooo`3Q0?ooo`D00000GP3oool00240oooo0P00003T0?ooo`H00000
F`3oool00240oooo00<000000?ooo`3oool0i@3oool6000005T0oooo000Q0?ooo`030000003oool0
oooo0>P0oooo1@00001G0?ooo`008@3oool00`000000oooo0?ooo`3Z0?ooo`D00000E@3oool00240
oooo00<000000?ooo`3oool0k03oool5000005<0oooo000Q0?ooo`030000003oool0oooo0>h0oooo
1@00001A0?ooo`008@3oool00`000000oooo0?ooo`3`0?ooo`D00000C`3oool00240oooo00<00000
0?ooo`3oool0lP3oool5000004d0oooo000Q0?ooo`030000003oool0oooo0?@0oooo1P00001:0?oo
o`008@3oool00`000000oooo0?ooo`3f0?ooo`L00000A`3oool00240oooo0P00003j0?ooo`H00000
A@3oool00240oooo00<000000?ooo`3oool0o03oool600000480oooo000Q0?ooo`030000003oool0
oooo0?h0oooo1P0000100?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`80oooo1@00000n0?oo
o`008@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo1P00000k0?ooo`008@3oool00`000000oooo
0?ooo`3o0?ooo`H0oooo1P00000i0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo1@00
000g0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo1@00000e0?ooo`008@3oool00`00
0000oooo0?ooo`3o0?ooo`d0oooo1P00000b0?ooo`008@3oool200000?l0oooo403oool7000002l0
oooo000Q0?ooo`030000003oool0oooo0?l0oooo4P3oool6000002d0oooo000Q0?ooo`030000003o
ool0oooo0?l0oooo5@3oool6000002X0oooo000Q0?ooo`030000003oool0oooo0?l0oooo5`3oool6
000002P0oooo000Q0?ooo`030000003oool0oooo0?l0oooo6P3oool5000002H0oooo000Q0?ooo`03
0000003oool0oooo0?l0oooo703oool5000002@0oooo000Q0?ooo`030000003oool0oooo0?l0oooo
7P3oool500000280oooo000H0?ooo`@0000000<04A4A0?ooo`3oool00P3oool00`000000oooo0?oo
o`3o0?ooob00oooo1@00000P0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0?l0oooo8P3oool5000001h0oooo000J0?ooo`030000003oool0oooo00@0oooo0`00003o0?oo
ob@0oooo1@00000L0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooobd0oooo0`00000L0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03o
ool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00603oool205EEE@030000003oool0oooo
0?l0ooooC03oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool009X0oooo00D0VIVI
000000000000A4A40;^k^`0H0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo
1@0000030?ooo`D00000U03oool009X0oooo00D04A4A0;^k^`3^k^h0MgMg014A4@090?ooo`H00000
2@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0509VIV@0R8R80k^k^0?oo
o`14A4@00`3oool01@2IVIT08R8R0>k^kP3oool0A4A409@0oooo002J0?ooo`030000003oool0oooo
01X0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^00D0oooo00<0VIVI
028R8P3^k^h0U@3oool001l0oooo00D04A4A0000000000000000014A4@1f0?ooo`030000003oool0
oooo00/0oooo1P0000090?ooo`050000003oool0oooo0?ooo`0000003@3oool00`2IVIT08R8R0>k^
kP050?ooo`0309VIV@0R8R80k^k^09@0oooo000Q0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool06P3oool01@000000oooo0?ooo`3oool0000000h0oooo00<0MgMg06IVIP3oool01@3o
ool00`1gMgL0IVIV0?ooo`2C0?ooo`008@3oool00`000000oooo0?ooo`1d0?ooo`03014A4@000000
000000<000006@3oool01@0A4A40oooo0?ooo`3oool04A4A00l0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`2B0?ooo`008@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo01X0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
0`3oool01@000000^k^k0?ooo`2IVIT04A4A09@0oooo000Q0?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool06P3oool01@3^k^h0<c<c0000000c<c<0k^k^00/0oooo00D0VIVI014A4@00
00008R8R0<c<c0030?ooo`0509VIV@0A4A400000028R8P3<c<`0U03oool001h0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`3o0?oood80oooo000N0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0o`3ooom20?ooo`007P3oool700000?l0ooooA03oool00?l0
ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .03327 L
.08481 .06964 L
.12636 .10395 L
.16632 .13716 L
.20885 .17281 L
.2498 .20747 L
.29331 .24475 L
.33524 .28114 L
.37557 .31664 L
.41848 .35496 L
.4598 .39242 L
.48055 .41145 L
.48962 .41981 L
.49442 .42424 L
.49705 .42668 L
.49834 .42788 L
.49953 .42898 L
.50089 .42969 L
.50161 .42991 L
.50237 .43015 L
.50495 .43095 L
.50998 .43251 L
.51991 .43563 L
.54183 .44263 L
.5817 .45578 L
.62415 .47034 L
.665 .48488 L
.70843 .50088 L
.75027 .51676 L
.79051 .53243 L
.83333 .54947 L
.87456 .56617 L
.9142 .58244 L
.95642 .59991 L
.99704 .6168 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`@00000>03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`00
00000P00003o0?oood<0oooo000Q0?ooo`030000003oool0oooo00<00000o`3ooom20?ooo`008@3o
ool010000000oooo0?ooo`3oool400000?l0oooo@03oool00240oooo00<000000?ooo`3oool00P3o
ool400000?l0oooo?`3oool00240oooo00<000000?ooo`3oool0103oool300000?l0oooo?P3oool0
0240oooo00<000000?ooo`3oool01@3oool300000?l0oooo?@3oool00240oooo0P0000070?ooo`<0
0000o`3oooll0?ooo`008@3oool00`000000oooo0?ooo`070?ooo`@00000o`3ooolj0?ooo`008@3o
ool00`000000oooo0?ooo`080?ooo`@00000o`3oooli0?ooo`008@3oool00`000000oooo0?ooo`0:
0?ooo`<00000o`3ooolh0?ooo`008@3oool00`000000oooo0?ooo`0;0?ooo`<00000o`3ooolg0?oo
o`008@3oool00`000000oooo0?ooo`0<0?ooo`@00000o`3ooole0?ooo`008@3oool00`000000oooo
0?ooo`0=0?ooo`@00000o`3ooold0?ooo`008@3oool00`000000oooo0?ooo`0?0?ooo`<00000o`3o
oolc0?ooo`008@3oool00`000000oooo0?ooo`0@0?ooo`@00000o`3ooola0?ooo`008@3oool20000
0180oooo1000003o0?oooc00oooo000Q0?ooo`030000003oool0oooo01<0oooo0`00003o0?ooobl0
oooo000Q0?ooo`030000003oool0oooo01@0oooo0`00003o0?ooobh0oooo000Q0?ooo`030000003o
ool0oooo01D0oooo1000003o0?ooob`0oooo000Q0?ooo`030000003oool0oooo01H0oooo1000003o
0?ooob/0oooo000Q0?ooo`030000003oool0oooo01P0oooo0`00003o0?ooobX0oooo000Q0?ooo`03
0000003oool0oooo01T0oooo0`00003o0?ooobT0oooo000Q0?ooo`030000003oool0oooo01X0oooo
0`00003o0?ooobP0oooo000Q0?ooo`030000003oool0oooo01/0oooo1000003o0?ooobH0oooo000Q
0?ooo`030000003oool0oooo01`0oooo1000003o0?ooobD0oooo000Q0?ooo`8000007`3oool30000
0?l0oooo903oool00240oooo00<000000?ooo`3oool07`3oool300000?l0oooo8`3oool00240oooo
00<000000?ooo`3oool0803oool300000?l0oooo8P3oool00240oooo00<000000?ooo`3oool08@3o
ool400000?l0oooo803oool00240oooo00<000000?ooo`3oool08P3oool400000?l0oooo7`3oool0
0240oooo00<000000?ooo`3oool0903oool300000?l0oooo7P3oool000L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R103oool5000000D0oooo00<000000?ooo`3oool09@3oool30000
0?l0oooo7@3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@2I
VIT08R8R0>k^kP3oool0A4A400D0oooo00<000000?ooo`3oool09P3oool300000?l0oooo703oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^00H0oooo00<00000
0?ooo`3oool09`3oool400000?l0oooo6P3oool000L0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`0309VIV@0R8R80k^k^00D0oooo0`00000X0?ooo`@00000o`3ooolI0?ooo`001`3oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<0MgMg06IVIP3oool0103oool00`000000oooo0?ooo`0Z
0?ooo`<00000o`3ooolH0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00l0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0[0?ooo`<00000o`3ooolG0?ooo`001`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@050?ooo`030000003o
ool0oooo02`0oooo0`00003o0?oooaH0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3o
ool01@2IVIT04A4A0000000R8R80c<c<00D0oooo00<000000?ooo`3oool0;@3oool400000?l0oooo
503oool00240oooo00<000000?ooo`3oool0;P3oool400000?l0oooo4`3oool00240oooo00<00000
0?ooo`3oool0<03oool300000?l0oooo4P3oool00240oooo00<000000?ooo`3oool0<@3oool30000
0?l0oooo4@3oool00240oooo00<000000?ooo`3oool0<P3oool300000?l0oooo403oool00240oooo
0P00000d0?ooo`<00000o`3oool?0?ooo`008@3oool00`000000oooo0?ooo`0d0?ooo`<00000o`3o
ool>0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`<00000o`3oool=0?ooo`008@3oool00`00
0000oooo0?ooo`0f0?ooo`<00000o`3oool<0?ooo`008@3oool00`000000oooo0?ooo`0g0?ooo`<0
0000o`3oool;0?ooo`008@3oool00`000000oooo0?ooo`0h0?ooo`<00000o`3oool:0?ooo`008@3o
ool00`000000oooo0?ooo`0i0?ooo`@00000o`3oool80?ooo`008@3oool00`000000oooo0?ooo`0j
0?ooo`@00000o`3oool70?ooo`008@3oool00`000000oooo0?ooo`0l0?ooo`<00000o`3oool60?oo
o`008@3oool2000003h0oooo1000003o0?ooo`@0oooo000Q0?ooo`030000003oool0oooo03h0oooo
1000003o0?ooo`<0oooo000Q0?ooo`030000003oool0oooo0400oooo0`00003o0?ooo`80oooo000Q
0?ooo`030000003oool0oooo0440oooo0`00003o0?ooo`40oooo000Q0?ooo`030000003oool0oooo
0480oooo1000003n0?ooo`008@3oool00`000000oooo0?ooo`130?ooo`@00000o@3oool00240oooo
00<000000?ooo`3oool0A@3oool300000?`0oooo000Q0?ooo`030000003oool0oooo04H0oooo1000
003j0?ooo`008@3oool00`000000oooo0?ooo`170?ooo`@00000n@3oool00240oooo0P00001:0?oo
o`<00000n03oool00240oooo00<000000?ooo`3oool0BP3oool300000?L0oooo000Q0?ooo`030000
003oool0oooo04/0oooo0`00003f0?ooo`008@3oool00`000000oooo0?ooo`1<0?ooo`@00000m03o
ool00240oooo00<000000?ooo`3oool0C@3oool400000?<0oooo000Q0?ooo`030000003oool0oooo
04l0oooo0`00003b0?ooo`008@3oool00`000000oooo0?ooo`1@0?ooo`<00000l@3oool000L0oooo
00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1P3oool200000003014A4@3oool0oooo00<0
oooo00<000000?ooo`3oool0D@3oool300000?00oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL01@3oool2028R8PL0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1B0?ooo`<0
0000k`3oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`D000001@3oool00`000000
oooo0?ooo`1C0?ooo`@00000k@3oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`04
04A4A03MgMd0oooo000000H0oooo0`00001D0?ooo`@00000k03oool000L0oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000000H0oooo00<000000?ooo`3oool0EP3oool3
00000>/0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<00000006
0?ooo`030000003oool0oooo05L0oooo0`00003Z0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00`0oooo00<0k^k^04A4A00000001P3oool00`000000oooo0?ooo`1H0?ooo`<00000j@3oool0
00L0oooo00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo00D0oooo00<00000
0?ooo`3oool0F@3oool300000>P0oooo000Q0?ooo`030000003oool0oooo05X0oooo0`00003W0?oo
o`008@3oool00`000000oooo0?ooo`1K0?ooo`<00000iP3oool00240oooo00<000000?ooo`3oool0
G03oool300000>D0oooo000Q0?ooo`030000003oool0oooo05d0oooo0`00003T0?ooo`008@3oool2
000005l0oooo0`00003S0?ooo`008@3oool00`000000oooo0?ooo`1O0?ooo`@00000h@3oool00240
oooo00<000000?ooo`3oool0H03oool400000>00oooo000Q0?ooo`030000003oool0oooo0680oooo
0`00003O0?ooo`008@3oool00`000000oooo0?ooo`1S0?ooo`<00000gP3oool00240oooo00<00000
0?ooo`3oool0I03oool300000=d0oooo000Q0?ooo`030000003oool0oooo06D0oooo1000003K0?oo
o`008@3oool00`000000oooo0?ooo`1V0?ooo`@00000fP3oool00240oooo00<000000?ooo`3oool0
J03oool300000=T0oooo000Q0?ooo`800000JP3oool300000=P0oooo000Q0?ooo`030000003oool0
oooo06X0oooo0`00003G0?ooo`008@3oool00`000000oooo0?ooo`1[0?ooo`@00000e@3oool00240
oooo00<000000?ooo`3oool0K03oool400000=@0oooo000Q0?ooo`030000003oool0oooo06h0oooo
0`00003C0?ooo`008@3oool00`000000oooo0?ooo`1_0?ooo`<00000dP3oool00240oooo00<00000
0?ooo`3oool0L03oool300000=40oooo000Q0?ooo`030000003oool0oooo0740oooo0`00003@0?oo
o`008@3oool00`000000oooo0?ooo`1b0?ooo`<00000c`3oool00240oooo0P00001d0?ooo`<00000
cP3oool00240oooo00<000000?ooo`3oool0M03oool300000<d0oooo000Q0?ooo`030000003oool0
oooo07D0oooo0`00003<0?ooo`008@3oool00`000000oooo0?ooo`1f0?ooo`<00000b`3oool00240
oooo00<000000?ooo`3oool0M`3oool300000<X0oooo000Q0?ooo`030000003oool0oooo07P0oooo
100000380?ooo`008@3oool00`000000oooo0?ooo`1i0?ooo`@00000a`3oool000L0oooo00D0k^k^
03<c<`000000<c<c0>k^kP050?ooo`808R8R103oool01@3^k^h0<c<c0000000A4A40c<c<00D0oooo
00<000000?ooo`3oool0N`3oool300000<H0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0
1@3oool2028R8P@0oooo00D0EEEE07MgM`3oool0VIVI028R8P050?ooo`030000003oool0oooo07`0
oooo0`0000350?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`<00000O@3oool300000<@0oooo00070?ooo`050000003oool0oooo0?oo
o`0000002`3oool01@000000VIVI0?ooo`2IVIT08R8R00D0oooo00<000000?ooo`3oool0OP3oool3
00000<<0oooo00070?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000EEEE0000000A
4A40c<c<00D0oooo00<000000?ooo`3oool0O`3oool300000<80oooo00070?ooo`05014A4@3oool0
oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`070?ooo`030000003oool0oooo0800oooo0`00
00310?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT01`3o
ool00`000000oooo0?ooo`210?ooo`<00000`03oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0<0?ooo`040<c<c014A4@00000014A4@D0oooo00<000000?ooo`3oool0PP3oool300000;l0oooo
000Q0?ooo`030000003oool0oooo08<0oooo0`00002n0?ooo`008@3oool00`000000oooo0?ooo`24
0?ooo`<00000_@3oool00240oooo00<000000?ooo`3oool0Q@3oool300000;`0oooo000Q0?ooo`03
0000003oool0oooo08H0oooo0`00002k0?ooo`008@3oool2000008P0oooo0`00002j0?ooo`008@3o
ool00`000000oooo0?ooo`280?ooo`<00000^@3oool00240oooo00<000000?ooo`3oool0R@3oool3
00000;P0oooo000Q0?ooo`030000003oool0oooo08X0oooo1000002f0?ooo`008@3oool00`000000
oooo0?ooo`2;0?ooo`@00000]@3oool00240oooo00<000000?ooo`3oool0S@3oool300000;@0oooo
000Q0?ooo`030000003oool0oooo08h0oooo0`00002c0?ooo`008@3oool00`000000oooo0?ooo`2?
0?ooo`@00000/@3oool00240oooo00<000000?ooo`3oool0T03oool500000:l0oooo000Q0?ooo`80
0000TP3oool700000:`0oooo000Q0?ooo`030000003oool0oooo09@0oooo1`00002Y0?ooo`008@3o
ool00`000000oooo0?ooo`2G0?ooo`L00000YP3oool00240oooo00<000000?ooo`3oool0VP3oool7
00000:<0oooo000Q0?ooo`030000003oool0oooo09d0oooo1`00002P0?ooo`008@3oool00`000000
oooo0?ooo`2P0?ooo`L00000W@3oool00240oooo00<000000?ooo`3oool0X`3oool7000009X0oooo
000Q0?ooo`030000003oool0oooo0:H0oooo1`00002G0?ooo`008@3oool00`000000oooo0?ooo`2Y
0?ooo`L00000U03oool00240oooo0P00002]0?ooo`L00000T@3oool00240oooo00<000000?ooo`3o
ool0[`3oool7000008h0oooo000Q0?ooo`030000003oool0oooo0;80oooo2000002:0?ooo`008@3o
ool00`000000oooo0?ooo`2e0?ooo`P00000Q`3oool00240oooo00<000000?ooo`3oool0^@3oool7
000008@0oooo000Q0?ooo`030000003oool0oooo0;`0oooo1`0000210?ooo`008@3oool00`000000
oooo0?ooo`2o0?ooo`H00000O`3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`80
8R8R103oool01@3<c<`08R8R0000000R8R80c<c<00D0oooo00<000000?ooo`3oool0`P3oool60000
07`0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D08R8R09VI
V@3oool0VIVI028R8P050?ooo`030000003oool0oooo0<@0oooo1`00001i0?ooo`001`3oool01@0A
4A40oooo0?ooo`3oool04A4A00/0oooo00D000000?ooo`3oool0oooo000000050?ooo`<00000a`3o
ool6000007L0oooo00070?ooo`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?oo
o`2IVIT0<c<c00D0oooo00<000000?ooo`3oool0bP3oool6000007@0oooo00070?ooo`050000003o
ool0oooo0?ooo`0000002`3oool01@3<c<`00000000000000000c<c<00D0oooo00<000000?ooo`3o
ool0c03oool600000780oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@0A4A40
^k^k0?ooo`2k^k/04A4A00D0oooo00<000000?ooo`3oool0c`3oool6000006l0oooo00070?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2k^k/0000000D0oooo00<00000
0?ooo`3oool0d@3oool7000006`0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool0
1@2ZZZX04A4A0000000A4A40ZZZZ00D0oooo00<000000?ooo`3oool0e03oool6000006X0oooo000Q
0?ooo`030000003oool0oooo0=L0oooo1P00001W0?ooo`008@3oool00`000000oooo0?ooo`3I0?oo
o`H00000I@3oool00240oooo00<000000?ooo`3oool0g03oool600000680oooo000Q0?ooo`800000
g`3oool600000600oooo000Q0?ooo`030000003oool0oooo0>40oooo1@00001N0?ooo`008@3oool0
0`000000oooo0?ooo`3S0?ooo`H00000F`3oool00240oooo00<000000?ooo`3oool0i@3oool60000
05T0oooo000Q0?ooo`030000003oool0oooo0>P0oooo1P00001F0?ooo`008@3oool00`000000oooo
0?ooo`3Z0?ooo`H00000E03oool00240oooo00<000000?ooo`3oool0k@3oool500000580oooo000Q
0?ooo`030000003oool0oooo0>l0oooo1P00001?0?ooo`008@3oool00`000000oooo0?ooo`3a0?oo
o`H00000C@3oool00240oooo00<000000?ooo`3oool0m03oool6000004X0oooo000Q0?ooo`800000
m`3oool7000004L0oooo000Q0?ooo`030000003oool0oooo0?T0oooo1P0000150?ooo`008@3oool0
0`000000oooo0?ooo`3l0?ooo`H00000@P3oool00240oooo00<000000?ooo`3oool0oP3oool60000
0400oooo000Q0?ooo`030000003oool0oooo0?l0oooo0P3oool6000003d0oooo000Q0?ooo`030000
003oool0oooo0?l0oooo103oool7000003X0oooo000Q0?ooo`030000003oool0oooo0?l0oooo1`3o
ool7000003L0oooo000Q0?ooo`030000003oool0oooo0?l0oooo2P3oool6000003D0oooo000Q0?oo
o`030000003oool0oooo0?l0oooo3@3oool5000003<0oooo000Q0?ooo`800000o`3oool@0?ooo`D0
0000<@3oool00240oooo00<000000?ooo`3oool0o`3ooolA0?ooo`H00000;P3oool00240oooo00<0
00000?ooo`3oool0o`3ooolC0?ooo`H00000;03oool00240oooo00<000000?ooo`3oool0o`3ooolF
0?ooo`D00000:P3oool00240oooo00<000000?ooo`3oool0o`3ooolH0?ooo`D00000:03oool00240
oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`H000009@3oool00240oooo00<000000?ooo`3oool0
o`3ooolL0?ooo`H000008`3oool001P0oooo100000000`0A4A40oooo0?ooo`020?ooo`030000003o
ool0oooo0?l0oooo7`3oool500000240oooo000J0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0o`3ooolQ0?ooo`H000007P3oool001X0oooo00<000000?ooo`3oool0103oool30000
0?l0oooo8`3oool6000001`0oooo000J0?ooo`030000003oool0oooo0?l0oooo;@3oool3000001`0
oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3o
oom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000H0?ooo`80EEEE00<000000?oo
o`3oool0o`3ooom<0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00VP3oool0
1@2IVIT0000000000014A4@0^k^k01P0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R
103oool5000000D0oooo0P0000000`0A4A40oooo0?ooo`2B0?ooo`00VP3oool01@0A4A40^k^k0>k^
kP1gMgL04A4A00T0oooo1P0000090?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0
oooo00D0VIVI028R8P3^k^h0oooo04A4A0060?ooo`030000003oool0oooo09<0oooo002J0?ooo`03
0000003oool0oooo01X0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^
00@0oooo1@00002D0?ooo`007`3oool01@0A4A4000000000000000004A4A07H0oooo00<000000?oo
o`3oool02`3oool6000000T0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`0309VIV@0R8R80
k^k^00<0oooo00@0A4A40=gMg@3oool00000U@3oool00240oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`1gMgL0IVIV0?oo
o`020?ooo`040=gMg@1EEED0oooo000009D0oooo000Q0?ooo`030000003oool0oooo07@0oooo00<0
4A4A0000000000000`00000I0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`020?ooo`0307MgM`3<c<`0000009D0oooo000Q0?ooo`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool06P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0
VIVI014A4@040?ooo`030>k^kP14A4@0000009D0oooo000Q0?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool06P3oool01@3^k^h0<c<c0000000c<c<0k^k^00/0oooo00D0VIVI014A4@00
00008R8R0<c<c0050?ooo`0307MgM`000000oooo09@0oooo000N0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0o`3ooom20?ooo`007P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0?l0oooo@P3oool001h0oooo1`00003o0?oood@0oooo003o0?ooofT0oooo
003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .03405 L
.08481 .07125 L
.12636 .10632 L
.16632 .14021 L
.20885 .17654 L
.2498 .21179 L
.29331 .24961 L
.33524 .28645 L
.37557 .32229 L
.41848 .36087 L
.4598 .39848 L
.48055 .41754 L
.48962 .42592 L
.49442 .43035 L
.49705 .43279 L
.49834 .43399 L
.49953 .43509 L
.50089 .4358 L
.50161 .43602 L
.50237 .43626 L
.50495 .43706 L
.50998 .43862 L
.51991 .44173 L
.54183 .44869 L
.5817 .46169 L
.62415 .47599 L
.665 .49019 L
.70843 .50572 L
.75027 .52108 L
.79051 .53617 L
.83333 .55253 L
.87456 .56852 L
.9142 .58406 L
.95642 .60074 L
.99704 .61686 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`@00000>03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`00
00000P00003o0?oood<0oooo000Q0?ooo`030000003oool0oooo00<00000o`3ooom20?ooo`008@3o
ool010000000oooo0?ooo`3oool400000?l0oooo@03oool00240oooo00<000000?ooo`3oool00P3o
ool400000?l0oooo?`3oool00240oooo00<000000?ooo`3oool0103oool300000?l0oooo?P3oool0
0240oooo00<000000?ooo`3oool01@3oool300000?l0oooo?@3oool00240oooo0P0000070?ooo`<0
0000o`3oooll0?ooo`008@3oool00`000000oooo0?ooo`070?ooo`@00000o`3ooolj0?ooo`008@3o
ool00`000000oooo0?ooo`080?ooo`@00000o`3oooli0?ooo`008@3oool00`000000oooo0?ooo`0:
0?ooo`<00000o`3ooolh0?ooo`008@3oool00`000000oooo0?ooo`0;0?ooo`<00000o`3ooolg0?oo
o`008@3oool00`000000oooo0?ooo`0<0?ooo`@00000o`3ooole0?ooo`008@3oool00`000000oooo
0?ooo`0=0?ooo`@00000o`3ooold0?ooo`008@3oool00`000000oooo0?ooo`0?0?ooo`<00000o`3o
oolc0?ooo`008@3oool00`000000oooo0?ooo`0@0?ooo`@00000o`3ooola0?ooo`008@3oool20000
0180oooo1000003o0?oooc00oooo000Q0?ooo`030000003oool0oooo01<0oooo0`00003o0?ooobl0
oooo000Q0?ooo`030000003oool0oooo01@0oooo0`00003o0?ooobh0oooo000Q0?ooo`030000003o
ool0oooo01D0oooo1000003o0?ooob`0oooo000Q0?ooo`030000003oool0oooo01H0oooo1000003o
0?ooob/0oooo000Q0?ooo`030000003oool0oooo01P0oooo0`00003o0?ooobX0oooo000Q0?ooo`03
0000003oool0oooo01T0oooo0`00003o0?ooobT0oooo000Q0?ooo`030000003oool0oooo01X0oooo
0`00003o0?ooobP0oooo000Q0?ooo`030000003oool0oooo01/0oooo0`00003o0?ooobL0oooo000Q
0?ooo`030000003oool0oooo01`0oooo0`00003o0?ooobH0oooo000Q0?ooo`8000007P3oool30000
0?l0oooo9@3oool00240oooo00<000000?ooo`3oool07P3oool300000?l0oooo903oool00240oooo
00<000000?ooo`3oool07`3oool300000?l0oooo8`3oool00240oooo00<000000?ooo`3oool0803o
ool300000?l0oooo8P3oool00240oooo00<000000?ooo`3oool08@3oool400000?l0oooo803oool0
0240oooo00<000000?ooo`3oool08P3oool400000?l0oooo7`3oool000L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R103oool5000000D0oooo00<000000?ooo`3oool0903oool30000
0?l0oooo7P3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@2I
VIT08R8R0>k^kP3oool0A4A400D0oooo00<000000?ooo`3oool09@3oool300000?l0oooo7@3oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^00H0oooo00<00000
0?ooo`3oool09P3oool300000?l0oooo703oool000L0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`0309VIV@0R8R80k^k^00D0oooo0`00000W0?ooo`@00000o`3ooolJ0?ooo`001`3oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<0MgMg06IVIP3oool0103oool00`000000oooo0?ooo`0X
0?ooo`@00000o`3ooolI0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00l0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0Z0?ooo`<00000o`3ooolH0?ooo`001`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@050?ooo`030000003o
ool0oooo02/0oooo0`00003o0?oooaL0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3o
ool01@2IVIT04A4A0000000R8R80c<c<00D0oooo00<000000?ooo`3oool0;03oool300000?l0oooo
5P3oool00240oooo00<000000?ooo`3oool0;@3oool400000?l0oooo503oool00240oooo00<00000
0?ooo`3oool0;P3oool400000?l0oooo4`3oool00240oooo00<000000?ooo`3oool0<03oool30000
0?l0oooo4P3oool00240oooo00<000000?ooo`3oool0<@3oool300000?l0oooo4@3oool00240oooo
0P00000c0?ooo`<00000o`3oool@0?ooo`008@3oool00`000000oooo0?ooo`0c0?ooo`<00000o`3o
ool?0?ooo`008@3oool00`000000oooo0?ooo`0d0?ooo`<00000o`3oool>0?ooo`008@3oool00`00
0000oooo0?ooo`0e0?ooo`<00000o`3oool=0?ooo`008@3oool00`000000oooo0?ooo`0f0?ooo`<0
0000o`3oool<0?ooo`008@3oool00`000000oooo0?ooo`0g0?ooo`<00000o`3oool;0?ooo`008@3o
ool00`000000oooo0?ooo`0h0?ooo`<00000o`3oool:0?ooo`008@3oool00`000000oooo0?ooo`0i
0?ooo`@00000o`3oool80?ooo`008@3oool00`000000oooo0?ooo`0j0?ooo`@00000o`3oool70?oo
o`008@3oool2000003d0oooo0`00003o0?ooo`H0oooo000Q0?ooo`030000003oool0oooo03d0oooo
1000003o0?ooo`@0oooo000Q0?ooo`030000003oool0oooo03h0oooo1000003o0?ooo`<0oooo000Q
0?ooo`030000003oool0oooo0400oooo0`00003o0?ooo`80oooo000Q0?ooo`030000003oool0oooo
0440oooo0`00003o0?ooo`40oooo000Q0?ooo`030000003oool0oooo0480oooo1000003n0?ooo`00
8@3oool00`000000oooo0?ooo`130?ooo`@00000o@3oool00240oooo00<000000?ooo`3oool0A@3o
ool300000?`0oooo000Q0?ooo`030000003oool0oooo04H0oooo1000003j0?ooo`008@3oool20000
04P0oooo1000003i0?ooo`008@3oool00`000000oooo0?ooo`190?ooo`<00000n03oool00240oooo
00<000000?ooo`3oool0BP3oool300000?L0oooo000Q0?ooo`030000003oool0oooo04/0oooo0`00
003f0?ooo`008@3oool00`000000oooo0?ooo`1<0?ooo`@00000m03oool00240oooo00<000000?oo
o`3oool0C@3oool400000?<0oooo000Q0?ooo`030000003oool0oooo04l0oooo0`00003b0?ooo`00
1`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A0?ooo`3o
ool00`3oool00`000000oooo0?ooo`1@0?ooo`<00000l@3oool000L0oooo00D0MgMg09VIV@3oool0
VIVI07MgM`050?ooo`808R8R1`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0540
oooo0`00003`0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@0000050?ooo`03
0000003oool0oooo0580oooo0`00003_0?ooo`001`3oool01@000000oooo0?ooo`3oool0000000/0
oooo00@0A4A40=gMg@3oool000001P3oool3000005<0oooo1000003]0?ooo`001`3oool01@000000
oooo0?ooo`3oool0000000/0oooo00@0gMgM05EEE@3oool000001P3oool00`000000oooo0?ooo`1D
0?ooo`@00000k03oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0307MgM`3<c<`0
000000H0oooo00<000000?ooo`3oool0EP3oool300000>/0oooo00070?ooo`0507MgM`2IVIT0oooo
09VIV@1gMgL0303oool00`3^k^h0A4A4000000060?ooo`030000003oool0oooo05L0oooo0`00003Z
0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00d0oooo00<0MgMg0000003oool01@3oool0
0`000000oooo0?ooo`1H0?ooo`<00000j@3oool00240oooo00<000000?ooo`3oool0F@3oool30000
0>P0oooo000Q0?ooo`030000003oool0oooo05X0oooo0`00003W0?ooo`008@3oool00`000000oooo
0?ooo`1K0?ooo`<00000iP3oool00240oooo00<000000?ooo`3oool0G03oool300000>D0oooo000Q
0?ooo`800000GP3oool300000>@0oooo000Q0?ooo`030000003oool0oooo05h0oooo0`00003S0?oo
o`008@3oool00`000000oooo0?ooo`1O0?ooo`@00000h@3oool00240oooo00<000000?ooo`3oool0
H03oool400000>00oooo000Q0?ooo`030000003oool0oooo0680oooo0`00003O0?ooo`008@3oool0
0`000000oooo0?ooo`1S0?ooo`<00000gP3oool00240oooo00<000000?ooo`3oool0I03oool30000
0=d0oooo000Q0?ooo`030000003oool0oooo06D0oooo0`00003L0?ooo`008@3oool00`000000oooo
0?ooo`1V0?ooo`<00000f`3oool00240oooo0P00001X0?ooo`<00000fP3oool00240oooo00<00000
0?ooo`3oool0J03oool300000=T0oooo000Q0?ooo`030000003oool0oooo06T0oooo0`00003H0?oo
o`008@3oool00`000000oooo0?ooo`1Z0?ooo`<00000e`3oool00240oooo00<000000?ooo`3oool0
J`3oool400000=D0oooo000Q0?ooo`030000003oool0oooo06`0oooo1000003D0?ooo`008@3oool0
0`000000oooo0?ooo`1^0?ooo`<00000d`3oool00240oooo00<000000?ooo`3oool0K`3oool30000
0=80oooo000Q0?ooo`030000003oool0oooo0700oooo0`00003A0?ooo`008@3oool200000780oooo
0`00003@0?ooo`008@3oool00`000000oooo0?ooo`1b0?ooo`<00000c`3oool00240oooo00<00000
0?ooo`3oool0L`3oool300000<h0oooo000Q0?ooo`030000003oool0oooo07@0oooo0`00003=0?oo
o`008@3oool00`000000oooo0?ooo`1e0?ooo`<00000c03oool00240oooo00<000000?ooo`3oool0
MP3oool300000</0oooo000Q0?ooo`030000003oool0oooo07L0oooo0`00003:0?ooo`001`3oool0
1@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c<c<00000014A4@3<c<`0
1@3oool00`000000oooo0?ooo`1h0?ooo`@00000b03oool000L0oooo00D0MgMg09VIV@3oool0VIVI
07MgM`050?ooo`808R8R103oool01@1EEED0MgMg0?ooo`2IVIT08R8R00D0oooo00<000000?ooo`3o
ool0N@3oool400000<L0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000
oooo0?ooo`3oool0000000D0oooo0`00001k0?ooo`<00000aP3oool000L0oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`050000002IVIT0oooo09VIV@0R8R801@3oool00`000000oooo0?ooo`1l
0?ooo`<00000a@3oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED0
0000014A4@3<c<`01@3oool00`000000oooo0?ooo`1m0?ooo`<00000a03oool000L0oooo00D04A4A
0?ooo`3oool0oooo014A4@0;0?ooo`0305EEE@28R8P0oooo00L0oooo00<000000?ooo`3oool0OP3o
ool300000<<0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool00`3MgMd04A4A09VI
V@070?ooo`030000003oool0oooo07l0oooo0`0000320?ooo`001`3oool01@3^k^h0<c<c0000000c
<c<0k^k^00`0oooo00@0c<c<04A4A00000004A4A1@3oool00`000000oooo0?ooo`200?ooo`<00000
`@3oool00240oooo00<000000?ooo`3oool0P@3oool300000<00oooo000Q0?ooo`030000003oool0
oooo0880oooo0`00002o0?ooo`008@3oool00`000000oooo0?ooo`230?ooo`<00000_P3oool00240
oooo00<000000?ooo`3oool0Q03oool400000;`0oooo000Q0?ooo`800000QP3oool400000;/0oooo
000Q0?ooo`030000003oool0oooo08L0oooo0`00002j0?ooo`008@3oool00`000000oooo0?ooo`28
0?ooo`<00000^@3oool00240oooo00<000000?ooo`3oool0R@3oool300000;P0oooo000Q0?ooo`03
0000003oool0oooo08X0oooo0`00002g0?ooo`008@3oool00`000000oooo0?ooo`2;0?ooo`<00000
]P3oool00240oooo00<000000?ooo`3oool0S03oool300000;D0oooo000Q0?ooo`030000003oool0
oooo08d0oooo0`00002d0?ooo`008@3oool00`000000oooo0?ooo`2>0?ooo`<00000/`3oool00240
oooo0P00002@0?ooo`@00000/@3oool00240oooo00<000000?ooo`3oool0T03oool500000:l0oooo
000Q0?ooo`030000003oool0oooo0940oooo1`00002/0?ooo`008@3oool00`000000oooo0?ooo`2D
0?ooo`L00000Z@3oool00240oooo00<000000?ooo`3oool0U`3oool700000:H0oooo000Q0?ooo`03
0000003oool0oooo09X0oooo1`00002S0?ooo`008@3oool00`000000oooo0?ooo`2M0?ooo`L00000
X03oool00240oooo00<000000?ooo`3oool0X03oool7000009d0oooo000Q0?ooo`030000003oool0
oooo0:<0oooo1`00002J0?ooo`008@3oool200000:L0oooo1`00002G0?ooo`008@3oool00`000000
oooo0?ooo`2Y0?ooo`L00000U03oool00240oooo00<000000?ooo`3oool0[03oool700000940oooo
000Q0?ooo`030000003oool0oooo0:l0oooo1`00002>0?ooo`008@3oool00`000000oooo0?ooo`2b
0?ooo`P00000RP3oool00240oooo00<000000?ooo`3oool0]@3oool8000008L0oooo000Q0?ooo`03
0000003oool0oooo0;T0oooo1`0000240?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0
oooo0P0R8R840?ooo`050<c<c00R8R800000028R8P3<c<`01@3oool00`000000oooo0?ooo`2l0?oo
o`L00000P@3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@0R
8R80VIVI0?ooo`2IVIT08R8R00D0oooo00<000000?ooo`3oool0_`3oool6000007l0oooo00070?oo
o`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000000D0oooo0`00
00320?ooo`H00000O03oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`0503<c<`2I
VIT0oooo09VIV@0c<c<01@3oool00`000000oooo0?ooo`340?ooo`L00000N@3oool000L0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`050<c<c000000000000000003<c<`01@3oool00`000000
oooo0?ooo`370?ooo`H00000M`3oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`05
014A4@2k^k/0oooo0;^k^`0A4A401@3oool00`000000oooo0?ooo`3:0?ooo`H00000M03oool000L0
oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo0;^k^`0000001@3oool0
0`000000oooo0?ooo`3<0?ooo`L00000L@3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP0;
0?ooo`050:ZZZP0A4A400000014A4@2ZZZX01@3oool00`000000oooo0?ooo`3?0?ooo`L00000KP3o
ool00240oooo00<000000?ooo`3oool0dP3oool7000006/0oooo000Q0?ooo`030000003oool0oooo
0=D0oooo1`00001X0?ooo`008@3oool00`000000oooo0?ooo`3H0?ooo`L00000I@3oool00240oooo
0P00003L0?ooo`L00000HP3oool00240oooo00<000000?ooo`3oool0gP3oool600000600oooo000Q
0?ooo`030000003oool0oooo0>40oooo1@00001N0?ooo`008@3oool00`000000oooo0?ooo`3S0?oo
o`H00000F`3oool00240oooo00<000000?ooo`3oool0i@3oool6000005T0oooo000Q0?ooo`030000
003oool0oooo0>P0oooo1P00001F0?ooo`008@3oool00`000000oooo0?ooo`3Z0?ooo`H00000E03o
ool00240oooo00<000000?ooo`3oool0k@3oool500000580oooo000Q0?ooo`030000003oool0oooo
0>l0oooo1P00001?0?ooo`008@3oool00`000000oooo0?ooo`3a0?ooo`L00000C03oool00240oooo
0P00003e0?ooo`L00000B@3oool00240oooo00<000000?ooo`3oool0m`3oool7000004H0oooo000Q
0?ooo`030000003oool0oooo0?X0oooo1`0000130?ooo`008@3oool00`000000oooo0?ooo`3m0?oo
o`L00000@03oool00240oooo00<000000?ooo`3oool0o`3oool10?ooo`H00000?P3oool00240oooo
00<000000?ooo`3oool0o`3oool40?ooo`H00000>`3oool00240oooo00<000000?ooo`3oool0o`3o
ool60?ooo`H00000>@3oool00240oooo00<000000?ooo`3oool0o`3oool90?ooo`D00000=`3oool0
0240oooo00<000000?ooo`3oool0o`3oool;0?ooo`D00000=@3oool00240oooo0P00003o0?ooo`h0
oooo1P00000b0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo1`00000_0?ooo`008@3o
ool00`000000oooo0?ooo`3o0?oooa80oooo1P00000]0?ooo`008@3oool00`000000oooo0?ooo`3o
0?oooaD0oooo1P00000Z0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooaL0oooo1P00000X0?oo
o`008@3oool00`000000oooo0?ooo`3o0?oooaX0oooo1P00000U0?ooo`008@3oool00`000000oooo
0?ooo`3o0?oooa`0oooo1P00000S0?ooo`00603oool400000003014A4@3oool0oooo0080oooo00<0
00000?ooo`3oool0o`3ooolO0?ooo`D000008@3oool001X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?ooob40oooo1P00000N0?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`<00000o`3ooolS0?ooo`H00000703oool001X0oooo00<000000?ooo`3oool0o`3oool]0?ooo`<0
0000703oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001P0oooo0P1EEED00`00
0000oooo0?ooo`3o0?oood`0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo002J
0?ooo`0509VIV@000000000004A4A02k^k/0603oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo
0P0R8R840?ooo`D000000`3oool01@3^k^h0<c<c0000000A4A40c<c<09@0oooo002J0?ooo`05014A
4@2k^k/0k^k^07MgM`0A4A402@3oool6000000T0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?oo
o`808R8R103oool01@2IVIT08R8R0>k^kP3oool0A4A400<0oooo00D0EEEE07MgM`3oool0VIVI028R
8P2D0?ooo`00VP3oool00`000000oooo0?ooo`0J0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303o
ool00`2IVIT08R8R0>k^kP040?ooo`050000003oool0oooo0?ooo`000000U03oool001l0oooo00D0
4A4A0000000000000000014A4@1f0?ooo`030000003oool0oooo00/0oooo1P0000090?ooo`050000
003oool0oooo0?ooo`0000003@3oool00`2IVIT08R8R0>k^kP030?ooo`050000002IVIT0oooo09VI
V@0R8R80U03oool00240oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0J0?ooo`05
0000003oool0oooo0?ooo`0000003P3oool00`1gMgL0IVIV0?ooo`020?ooo`050000001EEED00000
014A4@3<c<`0U03oool00240oooo00<000000?ooo`3oool0M03oool00`0A4A400000000000030000
01T0oooo00D04A4A0?ooo`3oool0oooo014A4@0?0?ooo`060000003oool0oooo0?ooo`1EEED0R8R8
U`3oool00240oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0J0?ooo`0507MgM`2I
VIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2IVIT04A4A00<0oooo00<0gMgM014A4@2I
VIT0UP3oool00240oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0J0?ooo`050>k^
kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<00@0oooo00@0c<c<04A4
A00000004A4AU03oool001h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o
0?oood80oooo000N0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooom2
0?ooo`007P3oool700000?l0ooooA03oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .03469 L
.08481 .07257 L
.12636 .10826 L
.16632 .14272 L
.20885 .1796 L
.2498 .21533 L
.29331 .25361 L
.33524 .29081 L
.37557 .32693 L
.41848 .36572 L
.4598 .40346 L
.48055 .42255 L
.48962 .43093 L
.49442 .43537 L
.49705 .43781 L
.49834 .439 L
.49953 .4401 L
.50089 .44082 L
.50161 .44104 L
.50237 .44127 L
.50495 .44207 L
.50998 .44363 L
.51991 .44674 L
.54183 .45366 L
.5817 .46654 L
.62415 .48063 L
.665 .49455 L
.70843 .5097 L
.75027 .52462 L
.79051 .53924 L
.83333 .55504 L
.87456 .57045 L
.9142 .5854 L
.95642 .60143 L
.99704 .6169 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`@00000>03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`00
00000P00003o0?oood<0oooo000Q0?ooo`030000003oool0oooo00<00000o`3ooom20?ooo`008@3o
ool010000000oooo0?ooo`3oool400000?l0oooo@03oool00240oooo00<000000?ooo`3oool00P3o
ool400000?l0oooo?`3oool00240oooo00<000000?ooo`3oool0103oool300000?l0oooo?P3oool0
0240oooo00<000000?ooo`3oool01@3oool300000?l0oooo?@3oool00240oooo0P0000070?ooo`<0
0000o`3oooll0?ooo`008@3oool00`000000oooo0?ooo`070?ooo`@00000o`3ooolj0?ooo`008@3o
ool00`000000oooo0?ooo`080?ooo`@00000o`3oooli0?ooo`008@3oool00`000000oooo0?ooo`0:
0?ooo`<00000o`3ooolh0?ooo`008@3oool00`000000oooo0?ooo`0;0?ooo`<00000o`3ooolg0?oo
o`008@3oool00`000000oooo0?ooo`0<0?ooo`<00000o`3ooolf0?ooo`008@3oool00`000000oooo
0?ooo`0=0?ooo`<00000o`3ooole0?ooo`008@3oool00`000000oooo0?ooo`0>0?ooo`@00000o`3o
oolc0?ooo`008@3oool00`000000oooo0?ooo`0?0?ooo`@00000o`3ooolb0?ooo`008@3oool20000
0180oooo0`00003o0?oooc40oooo000Q0?ooo`030000003oool0oooo0180oooo0`00003o0?oooc00
oooo000Q0?ooo`030000003oool0oooo01<0oooo0`00003o0?ooobl0oooo000Q0?ooo`030000003o
ool0oooo01@0oooo0`00003o0?ooobh0oooo000Q0?ooo`030000003oool0oooo01D0oooo1000003o
0?ooob`0oooo000Q0?ooo`030000003oool0oooo01H0oooo1000003o0?ooob/0oooo000Q0?ooo`03
0000003oool0oooo01P0oooo0`00003o0?ooobX0oooo000Q0?ooo`030000003oool0oooo01T0oooo
0`00003o0?ooobT0oooo000Q0?ooo`030000003oool0oooo01X0oooo0`00003o0?ooobP0oooo000Q
0?ooo`030000003oool0oooo01/0oooo1000003o0?ooobH0oooo000Q0?ooo`8000007@3oool40000
0?l0oooo9@3oool00240oooo00<000000?ooo`3oool07P3oool300000?l0oooo903oool00240oooo
00<000000?ooo`3oool07`3oool300000?l0oooo8`3oool00240oooo00<000000?ooo`3oool0803o
ool300000?l0oooo8P3oool00240oooo00<000000?ooo`3oool08@3oool400000?l0oooo803oool0
0240oooo00<000000?ooo`3oool08P3oool400000?l0oooo7`3oool000L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R103oool5000000D0oooo00<000000?ooo`3oool0903oool30000
0?l0oooo7P3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@2I
VIT08R8R0>k^kP3oool0A4A400D0oooo00<000000?ooo`3oool09@3oool300000?l0oooo7@3oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^00H0oooo00<00000
0?ooo`3oool09P3oool300000?l0oooo703oool000L0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`0309VIV@0R8R80k^k^00D0oooo0`00000W0?ooo`<00000o`3ooolK0?ooo`001`3oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<0MgMg06IVIP3oool0103oool00`000000oooo0?ooo`0X
0?ooo`<00000o`3ooolJ0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00l0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0Y0?ooo`<00000o`3ooolI0?ooo`001`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@050?ooo`030000003o
ool0oooo02X0oooo0`00003o0?oooaP0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3o
ool01@2IVIT04A4A0000000R8R80c<c<00D0oooo00<000000?ooo`3oool0:`3oool300000?l0oooo
5`3oool00240oooo00<000000?ooo`3oool0;03oool300000?l0oooo5P3oool00240oooo00<00000
0?ooo`3oool0;@3oool400000?l0oooo503oool00240oooo00<000000?ooo`3oool0;P3oool40000
0?l0oooo4`3oool00240oooo00<000000?ooo`3oool0<03oool300000?l0oooo4P3oool00240oooo
0P00000b0?ooo`<00000o`3ooolA0?ooo`008@3oool00`000000oooo0?ooo`0b0?ooo`<00000o`3o
ool@0?ooo`008@3oool00`000000oooo0?ooo`0c0?ooo`<00000o`3oool?0?ooo`008@3oool00`00
0000oooo0?ooo`0d0?ooo`<00000o`3oool>0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`<0
0000o`3oool=0?ooo`008@3oool00`000000oooo0?ooo`0f0?ooo`<00000o`3oool<0?ooo`008@3o
ool00`000000oooo0?ooo`0g0?ooo`<00000o`3oool;0?ooo`008@3oool00`000000oooo0?ooo`0h
0?ooo`<00000o`3oool:0?ooo`008@3oool00`000000oooo0?ooo`0i0?ooo`@00000o`3oool80?oo
o`008@3oool2000003/0oooo1000003o0?ooo`L0oooo000Q0?ooo`030000003oool0oooo03`0oooo
0`00003o0?ooo`H0oooo000Q0?ooo`030000003oool0oooo03d0oooo1000003o0?ooo`@0oooo000Q
0?ooo`030000003oool0oooo03h0oooo1000003o0?ooo`<0oooo000Q0?ooo`030000003oool0oooo
0400oooo0`00003o0?ooo`80oooo000Q0?ooo`030000003oool0oooo0440oooo0`00003o0?ooo`40
oooo000Q0?ooo`030000003oool0oooo0480oooo1000003n0?ooo`008@3oool00`000000oooo0?oo
o`130?ooo`@00000o@3oool00240oooo00<000000?ooo`3oool0A@3oool300000?`0oooo000Q0?oo
o`800000A`3oool400000?X0oooo000Q0?ooo`030000003oool0oooo04L0oooo1000003i0?ooo`00
8@3oool00`000000oooo0?ooo`190?ooo`<00000n03oool00240oooo00<000000?ooo`3oool0BP3o
ool300000?L0oooo000Q0?ooo`030000003oool0oooo04/0oooo0`00003f0?ooo`008@3oool00`00
0000oooo0?ooo`1<0?ooo`<00000m@3oool00240oooo00<000000?ooo`3oool0C@3oool300000?@0
oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8PH0oooo0P0000000`0A4A40
oooo0?ooo`030?ooo`030000003oool0oooo04h0oooo0`00003c0?ooo`001`3oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg00D0oooo0P0R8R870?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0C`3oool300000?80oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool5000000D0
oooo00<000000?ooo`3oool0D03oool300000?40oooo00070?ooo`050000003oool0oooo0?ooo`00
00002`3oool01014A4@0gMgM0?ooo`0000060?ooo`<00000D@3oool300000?00oooo00070?ooo`05
0000003oool0oooo0?ooo`0000002`3oool0103MgMd0EEEE0?ooo`0000060?ooo`030000003oool0
oooo0580oooo0`00003_0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<0MgMg
0<c<c00000001P3oool00`000000oooo0?ooo`1C0?ooo`@00000k@3oool000L0oooo00D0MgMg09VI
V@3oool0VIVI07MgM`0<0?ooo`030>k^kP14A4@0000000H0oooo00<000000?ooo`3oool0E03oool4
00000>`0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h03@3oool00`1gMgL000000?ooo`05
0?ooo`030000003oool0oooo05H0oooo0`00003[0?ooo`008@3oool00`000000oooo0?ooo`1G0?oo
o`<00000jP3oool00240oooo00<000000?ooo`3oool0F03oool300000>T0oooo000Q0?ooo`030000
003oool0oooo05T0oooo0`00003X0?ooo`008@3oool00`000000oooo0?ooo`1J0?ooo`<00000i`3o
ool00240oooo0P00001L0?ooo`<00000iP3oool00240oooo00<000000?ooo`3oool0G03oool30000
0>D0oooo000Q0?ooo`030000003oool0oooo05d0oooo0`00003T0?ooo`008@3oool00`000000oooo
0?ooo`1N0?ooo`<00000h`3oool00240oooo00<000000?ooo`3oool0G`3oool400000>40oooo000Q
0?ooo`030000003oool0oooo0600oooo1000003P0?ooo`008@3oool00`000000oooo0?ooo`1R0?oo
o`<00000g`3oool00240oooo00<000000?ooo`3oool0H`3oool300000=h0oooo000Q0?ooo`030000
003oool0oooo06@0oooo0`00003M0?ooo`008@3oool2000006H0oooo1000003K0?ooo`008@3oool0
0`000000oooo0?ooo`1V0?ooo`@00000fP3oool00240oooo00<000000?ooo`3oool0J03oool30000
0=T0oooo000Q0?ooo`030000003oool0oooo06T0oooo0`00003H0?ooo`008@3oool00`000000oooo
0?ooo`1Z0?ooo`<00000e`3oool00240oooo00<000000?ooo`3oool0J`3oool400000=D0oooo000Q
0?ooo`030000003oool0oooo06`0oooo1000003D0?ooo`008@3oool00`000000oooo0?ooo`1^0?oo
o`<00000d`3oool00240oooo00<000000?ooo`3oool0K`3oool300000=80oooo000Q0?ooo`800000
L@3oool300000=40oooo000Q0?ooo`030000003oool0oooo0740oooo0`00003@0?ooo`008@3oool0
0`000000oooo0?ooo`1b0?ooo`<00000c`3oool00240oooo00<000000?ooo`3oool0L`3oool30000
0<h0oooo000Q0?ooo`030000003oool0oooo07@0oooo0`00003=0?ooo`008@3oool00`000000oooo
0?ooo`1e0?ooo`<00000c03oool00240oooo00<000000?ooo`3oool0MP3oool300000</0oooo0007
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo00D0k^k^03<c<`0000004A4A
0<c<c0050?ooo`030000003oool0oooo07L0oooo0`00003:0?ooo`001`3oool01@1gMgL0VIVI0?oo
o`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R8R801@3oool00`000000
oooo0?ooo`1h0?ooo`@00000b03oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`05
0000003oool0oooo0?ooo`0000001@3oool3000007T0oooo100000370?ooo`001`3oool01@000000
oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P050?ooo`030000003oool0
oooo07/0oooo0`0000360?ooo`001`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D00000
05EEE@0000004A4A0<c<c0050?ooo`030000003oool0oooo07`0oooo0`0000350?ooo`001`3oool0
1@0A4A40oooo0?ooo`3oool04A4A00/0oooo00<0EEEE08R8R03oool01`3oool00`000000oooo0?oo
o`1m0?ooo`<00000a03oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`030=gMg@0A
4A40VIVI00L0oooo00<000000?ooo`3oool0OP3oool300000<<0oooo00070?ooo`050>k^kP0c<c<0
000003<c<`3^k^h0303oool0103<c<`0A4A40000000A4A450?ooo`030000003oool0oooo07l0oooo
0`0000320?ooo`008@3oool00`000000oooo0?ooo`200?ooo`<00000`@3oool00240oooo00<00000
0?ooo`3oool0P@3oool300000<00oooo000Q0?ooo`030000003oool0oooo0880oooo0`00002o0?oo
o`008@3oool00`000000oooo0?ooo`230?ooo`<00000_P3oool00240oooo0P0000250?ooo`<00000
_@3oool00240oooo00<000000?ooo`3oool0Q@3oool300000;`0oooo000Q0?ooo`030000003oool0
oooo08H0oooo0`00002k0?ooo`008@3oool00`000000oooo0?ooo`270?ooo`<00000^P3oool00240
oooo00<000000?ooo`3oool0R03oool300000;T0oooo000Q0?ooo`030000003oool0oooo08T0oooo
0`00002h0?ooo`008@3oool00`000000oooo0?ooo`2:0?ooo`@00000]P3oool00240oooo00<00000
0?ooo`3oool0R`3oool400000;D0oooo000Q0?ooo`030000003oool0oooo08d0oooo0`00002d0?oo
o`008@3oool2000008l0oooo0P00002d0?ooo`008@3oool00`000000oooo0?ooo`2>0?ooo`@00000
/P3oool00240oooo00<000000?ooo`3oool0S`3oool500000;00oooo000Q0?ooo`030000003oool0
oooo0940oooo1`00002/0?ooo`008@3oool00`000000oooo0?ooo`2C0?ooo`P00000Z@3oool00240
oooo00<000000?ooo`3oool0U`3oool700000:H0oooo000Q0?ooo`030000003oool0oooo09X0oooo
1`00002S0?ooo`008@3oool00`000000oooo0?ooo`2M0?ooo`L00000X03oool00240oooo00<00000
0?ooo`3oool0X03oool7000009d0oooo000Q0?ooo`800000Y03oool7000009X0oooo000Q0?ooo`03
0000003oool0oooo0:H0oooo1`00002G0?ooo`008@3oool00`000000oooo0?ooo`2Y0?ooo`L00000
U03oool00240oooo00<000000?ooo`3oool0[03oool700000940oooo000Q0?ooo`030000003oool0
oooo0:l0oooo1`00002>0?ooo`008@3oool00`000000oooo0?ooo`2b0?ooo`P00000RP3oool00240
oooo00<000000?ooo`3oool0]@3oool8000008L0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^
k^h01@3oool2028R8P@0oooo00D0c<c<028R8P0000008R8R0<c<c0050?ooo`030000003oool0oooo
0;T0oooo1`0000240?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?oo
o`05028R8P2IVIT0oooo09VIV@0R8R801@3oool00`000000oooo0?ooo`2l0?ooo`L00000P@3oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`0000001@3o
ool300000;l0oooo1P00001o0?ooo`001`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
<c<c09VIV@3oool0VIVI03<c<`050?ooo`030000003oool0oooo0<80oooo1P00001l0?ooo`001`3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c0050?ooo`03
0000003oool0oooo0<@0oooo1`00001i0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0
oooo00D04A4A0;^k^`3oool0^k^k014A4@050?ooo`030000003oool0oooo0<L0oooo1P00001g0?oo
o`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0^k^k00000005
0?ooo`030000003oool0oooo0<X0oooo1P00001d0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0
k^k^00/0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP050?ooo`030000003oool0oooo0<`0oooo1`00
001a0?ooo`008@3oool00`000000oooo0?ooo`3?0?ooo`L00000KP3oool00240oooo00<000000?oo
o`3oool0dP3oool7000006/0oooo000Q0?ooo`030000003oool0oooo0=D0oooo1`00001X0?ooo`00
8@3oool200000=T0oooo1`00001U0?ooo`008@3oool00`000000oooo0?ooo`3K0?ooo`L00000HP3o
ool00240oooo00<000000?ooo`3oool0gP3oool600000600oooo000Q0?ooo`030000003oool0oooo
0>40oooo1@00001N0?ooo`008@3oool00`000000oooo0?ooo`3S0?ooo`H00000F`3oool00240oooo
00<000000?ooo`3oool0i@3oool7000005P0oooo000Q0?ooo`030000003oool0oooo0>P0oooo1`00
001E0?ooo`008@3oool00`000000oooo0?ooo`3[0?ooo`L00000DP3oool00240oooo00<000000?oo
o`3oool0kP3oool7000004l0oooo000Q0?ooo`030000003oool0oooo0?40oooo1P00001=0?ooo`00
8@3oool200000?D0oooo1P00001:0?ooo`008@3oool00`000000oooo0?ooo`3f0?ooo`L00000A`3o
ool00240oooo00<000000?ooo`3oool0n@3oool6000004D0oooo000Q0?ooo`030000003oool0oooo
0?`0oooo1P0000120?ooo`008@3oool00`000000oooo0?ooo`3n0?ooo`H00000@03oool00240oooo
00<000000?ooo`3oool0o`3oool20?ooo`H00000?@3oool00240oooo00<000000?ooo`3oool0o`3o
ool40?ooo`L00000>P3oool00240oooo00<000000?ooo`3oool0o`3oool70?ooo`L00000=`3oool0
0240oooo00<000000?ooo`3oool0o`3oool:0?ooo`H00000=@3oool00240oooo0P00003o0?ooo`h0
oooo1P00000b0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo1`00000_0?ooo`008@3o
ool00`000000oooo0?ooo`3o0?oooa80oooo1P00000]0?ooo`008@3oool00`000000oooo0?ooo`3o
0?oooaD0oooo1P00000Z0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooaL0oooo1P00000X0?oo
o`008@3oool00`000000oooo0?ooo`3o0?oooaX0oooo1P00000U0?ooo`008@3oool00`000000oooo
0?ooo`3o0?oooa`0oooo1P00000S0?ooo`00603oool400000003014A4@3oool0oooo0080oooo00<0
00000?ooo`3oool0o`3ooolO0?ooo`D000008@3oool001X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?ooob40oooo1P00000N0?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`<00000o`3ooolS0?ooo`H00000703oool001X0oooo00<000000?ooo`3oool0o`3oool]0?ooo`<0
0000703oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001P0oooo0P1EEED00`00
0000oooo0?ooo`3o0?oood`0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo002J
0?ooo`0509VIV@000000000004A4A02k^k/0603oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo
0P0R8R840?ooo`D000000`3oool01@3<c<`08R8R0000000R8R80c<c<09@0oooo002J0?ooo`05014A
4@2k^k/0k^k^07MgM`0A4A402@3oool6000000T0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?oo
o`808R8R103oool01@2IVIT08R8R0>k^kP3oool0A4A400<0oooo00D08R8R09VIV@3oool0VIVI028R
8P2D0?ooo`00VP3oool00`000000oooo0?ooo`0J0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303o
ool00`2IVIT08R8R0>k^kP040?ooo`050000003oool0oooo0?ooo`000000U03oool001l0oooo00D0
4A4A0000000000000000014A4@1f0?ooo`030000003oool0oooo00/0oooo1P0000090?ooo`050000
003oool0oooo0?ooo`0000003@3oool00`2IVIT08R8R0>k^kP030?ooo`0503<c<`2IVIT0oooo09VI
V@0c<c<0U03oool00240oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0J0?ooo`05
0000003oool0oooo0?ooo`0000003P3oool00`1gMgL0IVIV0?ooo`020?ooo`050<c<c00000000000
0000003<c<`0U03oool00240oooo00<000000?ooo`3oool0M03oool00`0A4A400000000000030000
01T0oooo00D04A4A0?ooo`3oool0oooo014A4@0?0?ooo`090000003oool0oooo0?ooo`0A4A40^k^k
0?ooo`2k^k/04A4A09@0oooo000Q0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
6P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@030?oo
o`050000002k^k/0oooo0;^k^`000000U03oool00240oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`0J0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R
8R80c<c<00<0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP2D0?ooo`007P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0?l0oooo@P3oool001h0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`3o0?oood80oooo000N0?ooo`L00000o`3ooom40?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .03521 L
.08481 .07365 L
.12636 .10985 L
.16632 .14477 L
.20885 .18211 L
.2498 .21824 L
.29331 .25689 L
.33524 .29439 L
.37557 .33073 L
.41848 .3697 L
.4598 .40754 L
.48055 .42666 L
.48962 .43505 L
.49442 .43949 L
.49705 .44192 L
.49834 .44312 L
.49953 .44422 L
.50089 .44493 L
.50161 .44516 L
.50237 .44539 L
.50495 .44619 L
.50998 .44775 L
.51991 .45085 L
.54183 .45775 L
.5817 .47052 L
.62415 .48444 L
.665 .49812 L
.70843 .51297 L
.75027 .52753 L
.79051 .54176 L
.83333 .5571 L
.87456 .57203 L
.9142 .5865 L
.95642 .60199 L
.99704 .61694 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`@00000>03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`00
00000P00003o0?oood<0oooo000Q0?ooo`030000003oool0oooo00<00000o`3ooom20?ooo`008@3o
ool010000000oooo0?ooo`3oool300000?l0oooo@@3oool00240oooo00<000000?ooo`3oool00P3o
ool300000?l0oooo@03oool00240oooo00<000000?ooo`3oool00`3oool300000?l0oooo?`3oool0
0240oooo00<000000?ooo`3oool0103oool300000?l0oooo?P3oool00240oooo0P0000060?ooo`<0
0000o`3ooolm0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`<00000o`3oooll0?ooo`008@3o
ool00`000000oooo0?ooo`070?ooo`@00000o`3ooolj0?ooo`008@3oool00`000000oooo0?ooo`08
0?ooo`@00000o`3oooli0?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`<00000o`3ooolh0?oo
o`008@3oool00`000000oooo0?ooo`0;0?ooo`<00000o`3ooolg0?ooo`008@3oool00`000000oooo
0?ooo`0<0?ooo`@00000o`3ooole0?ooo`008@3oool00`000000oooo0?ooo`0=0?ooo`@00000o`3o
oold0?ooo`008@3oool00`000000oooo0?ooo`0?0?ooo`<00000o`3ooolc0?ooo`008@3oool20000
0140oooo1000003o0?oooc40oooo000Q0?ooo`030000003oool0oooo0140oooo1000003o0?oooc00
oooo000Q0?ooo`030000003oool0oooo01<0oooo0`00003o0?ooobl0oooo000Q0?ooo`030000003o
ool0oooo01@0oooo0`00003o0?ooobh0oooo000Q0?ooo`030000003oool0oooo01D0oooo1000003o
0?ooob`0oooo000Q0?ooo`030000003oool0oooo01H0oooo1000003o0?ooob/0oooo000Q0?ooo`03
0000003oool0oooo01P0oooo0`00003o0?ooobX0oooo000Q0?ooo`030000003oool0oooo01T0oooo
0`00003o0?ooobT0oooo000Q0?ooo`030000003oool0oooo01X0oooo0`00003o0?ooobP0oooo000Q
0?ooo`030000003oool0oooo01/0oooo0`00003o0?ooobL0oooo000Q0?ooo`8000007@3oool30000
0?l0oooo9P3oool00240oooo00<000000?ooo`3oool07@3oool300000?l0oooo9@3oool00240oooo
00<000000?ooo`3oool07P3oool300000?l0oooo903oool00240oooo00<000000?ooo`3oool07`3o
ool300000?l0oooo8`3oool00240oooo00<000000?ooo`3oool0803oool300000?l0oooo8P3oool0
0240oooo00<000000?ooo`3oool08@3oool400000?l0oooo803oool000L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R103oool5000000D0oooo00<000000?ooo`3oool08P3oool40000
0?l0oooo7`3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@2I
VIT08R8R0>k^kP3oool0A4A400D0oooo00<000000?ooo`3oool0903oool300000?l0oooo7P3oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^00H0oooo00<00000
0?ooo`3oool09@3oool300000?l0oooo7@3oool000L0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`0309VIV@0R8R80k^k^00D0oooo0`00000V0?ooo`<00000o`3ooolL0?ooo`001`3oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<0MgMg06IVIP3oool0103oool00`000000oooo0?ooo`0W
0?ooo`@00000o`3ooolJ0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00l0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`@00000o`3ooolI0?ooo`001`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@050?ooo`030000003o
ool0oooo02X0oooo0`00003o0?oooaP0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3o
ool01@2IVIT04A4A0000000R8R80c<c<00D0oooo00<000000?ooo`3oool0:`3oool300000?l0oooo
5`3oool00240oooo00<000000?ooo`3oool0;03oool300000?l0oooo5P3oool00240oooo00<00000
0?ooo`3oool0;@3oool400000?l0oooo503oool00240oooo00<000000?ooo`3oool0;P3oool40000
0?l0oooo4`3oool00240oooo00<000000?ooo`3oool0<03oool300000?l0oooo4P3oool00240oooo
0P00000b0?ooo`<00000o`3ooolA0?ooo`008@3oool00`000000oooo0?ooo`0b0?ooo`<00000o`3o
ool@0?ooo`008@3oool00`000000oooo0?ooo`0c0?ooo`<00000o`3oool?0?ooo`008@3oool00`00
0000oooo0?ooo`0d0?ooo`<00000o`3oool>0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`<0
0000o`3oool=0?ooo`008@3oool00`000000oooo0?ooo`0f0?ooo`<00000o`3oool<0?ooo`008@3o
ool00`000000oooo0?ooo`0g0?ooo`<00000o`3oool;0?ooo`008@3oool00`000000oooo0?ooo`0h
0?ooo`<00000o`3oool:0?ooo`008@3oool00`000000oooo0?ooo`0i0?ooo`@00000o`3oool80?oo
o`008@3oool2000003/0oooo1000003o0?ooo`L0oooo000Q0?ooo`030000003oool0oooo03`0oooo
0`00003o0?ooo`H0oooo000Q0?ooo`030000003oool0oooo03d0oooo0`00003o0?ooo`D0oooo000Q
0?ooo`030000003oool0oooo03h0oooo0`00003o0?ooo`@0oooo000Q0?ooo`030000003oool0oooo
03l0oooo1000003o0?ooo`80oooo000Q0?ooo`030000003oool0oooo0400oooo1000003o0?ooo`40
oooo000Q0?ooo`030000003oool0oooo0480oooo0`00003o0?ooo`008@3oool00`000000oooo0?oo
o`130?ooo`<00000oP3oool00240oooo00<000000?ooo`3oool0A03oool300000?d0oooo000Q0?oo
o`800000AP3oool300000?`0oooo000Q0?ooo`030000003oool0oooo04H0oooo1000003j0?ooo`00
8@3oool00`000000oooo0?ooo`170?ooo`@00000n@3oool00240oooo00<000000?ooo`3oool0B@3o
ool300000?P0oooo000Q0?ooo`030000003oool0oooo04X0oooo0`00003g0?ooo`008@3oool00`00
0000oooo0?ooo`1;0?ooo`<00000mP3oool00240oooo00<000000?ooo`3oool0C03oool300000?D0
oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8PH0oooo0P0000000`0A4A40
oooo0?ooo`030?ooo`030000003oool0oooo04d0oooo0`00003d0?ooo`001`3oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg00D0oooo0P0R8R870?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0CP3oool300000?<0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool5000000D0
oooo00<000000?ooo`3oool0C`3oool300000?80oooo00070?ooo`050000003oool0oooo0?ooo`00
00002`3oool01014A4@0gMgM0?ooo`0000060?ooo`<00000D03oool300000?40oooo00070?ooo`05
0000003oool0oooo0?ooo`0000002`3oool0103MgMd0EEEE0?ooo`0000060?ooo`030000003oool0
oooo0540oooo0`00003`0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<0MgMg
0<c<c00000001P3oool00`000000oooo0?ooo`1B0?ooo`<00000k`3oool000L0oooo00D0MgMg09VI
V@3oool0VIVI07MgM`0<0?ooo`030>k^kP14A4@0000000H0oooo00<000000?ooo`3oool0D`3oool4
00000>d0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h03@3oool00`1gMgL000000?ooo`05
0?ooo`030000003oool0oooo05@0oooo1000003/0?ooo`008@3oool00`000000oooo0?ooo`1F0?oo
o`<00000j`3oool00240oooo00<000000?ooo`3oool0E`3oool300000>X0oooo000Q0?ooo`030000
003oool0oooo05P0oooo0`00003Y0?ooo`008@3oool00`000000oooo0?ooo`1I0?ooo`<00000j03o
ool00240oooo0P00001K0?ooo`<00000i`3oool00240oooo00<000000?ooo`3oool0F`3oool30000
0>H0oooo000Q0?ooo`030000003oool0oooo05`0oooo0`00003U0?ooo`008@3oool00`000000oooo
0?ooo`1M0?ooo`<00000i03oool00240oooo00<000000?ooo`3oool0GP3oool300000><0oooo000Q
0?ooo`030000003oool0oooo05l0oooo1000003Q0?ooo`008@3oool00`000000oooo0?ooo`1P0?oo
o`@00000h03oool00240oooo00<000000?ooo`3oool0HP3oool300000=l0oooo000Q0?ooo`030000
003oool0oooo06<0oooo0`00003N0?ooo`008@3oool2000006D0oooo0`00003M0?ooo`008@3oool0
0`000000oooo0?ooo`1U0?ooo`<00000g03oool00240oooo00<000000?ooo`3oool0IP3oool30000
0=/0oooo000Q0?ooo`030000003oool0oooo06L0oooo0`00003J0?ooo`008@3oool00`000000oooo
0?ooo`1X0?ooo`<00000f@3oool00240oooo00<000000?ooo`3oool0J@3oool300000=P0oooo000Q
0?ooo`030000003oool0oooo06X0oooo0`00003G0?ooo`008@3oool00`000000oooo0?ooo`1[0?oo
o`@00000e@3oool00240oooo00<000000?ooo`3oool0K03oool400000=@0oooo000Q0?ooo`800000
K`3oool300000=<0oooo000Q0?ooo`030000003oool0oooo06l0oooo0`00003B0?ooo`008@3oool0
0`000000oooo0?ooo`1`0?ooo`<00000d@3oool00240oooo00<000000?ooo`3oool0L@3oool40000
0<l0oooo000Q0?ooo`030000003oool0oooo0780oooo1000003>0?ooo`008@3oool00`000000oooo
0?ooo`1d0?ooo`<00000c@3oool00240oooo00<000000?ooo`3oool0M@3oool300000<`0oooo0007
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo00D0k^k^03<c<`0000004A4A
0<c<c0050?ooo`030000003oool0oooo07H0oooo0`00003;0?ooo`001`3oool01@1gMgL0VIVI0?oo
o`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R8R801@3oool00`000000
oooo0?ooo`1g0?ooo`<00000bP3oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`05
0000003oool0oooo0?ooo`0000001@3oool3000007P0oooo100000380?ooo`001`3oool01@000000
oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P050?ooo`030000003oool0
oooo07T0oooo100000370?ooo`001`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D00000
05EEE@0000004A4A0<c<c0050?ooo`030000003oool0oooo07/0oooo0`0000360?ooo`001`3oool0
1@0A4A40oooo0?ooo`3oool04A4A00/0oooo00<0EEEE08R8R03oool01`3oool00`000000oooo0?oo
o`1l0?ooo`<00000a@3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`030=gMg@0A
4A40VIVI00L0oooo00<000000?ooo`3oool0O@3oool300000<@0oooo00070?ooo`050>k^kP0c<c<0
000003<c<`3^k^h0303oool0103<c<`0A4A40000000A4A450?ooo`030000003oool0oooo07h0oooo
0`0000330?ooo`008@3oool00`000000oooo0?ooo`1o0?ooo`<00000`P3oool00240oooo00<00000
0?ooo`3oool0P03oool300000<40oooo000Q0?ooo`030000003oool0oooo0840oooo0`0000300?oo
o`008@3oool00`000000oooo0?ooo`220?ooo`<00000_`3oool00240oooo0P0000240?ooo`<00000
_P3oool00240oooo00<000000?ooo`3oool0Q03oool300000;d0oooo000Q0?ooo`030000003oool0
oooo08D0oooo0`00002l0?ooo`008@3oool00`000000oooo0?ooo`260?ooo`<00000^`3oool00240
oooo00<000000?ooo`3oool0Q`3oool300000;X0oooo000Q0?ooo`030000003oool0oooo08P0oooo
0`00002i0?ooo`008@3oool00`000000oooo0?ooo`290?ooo`<00000^03oool00240oooo00<00000
0?ooo`3oool0RP3oool300000;L0oooo000Q0?ooo`030000003oool0oooo08/0oooo0`00002f0?oo
o`008@3oool2000008d0oooo0`00002e0?ooo`008@3oool00`000000oooo0?ooo`2=0?ooo`<00000
]03oool00240oooo00<000000?ooo`3oool0SP3oool300000;<0oooo000Q0?ooo`030000003oool0
oooo08l0oooo1000002a0?ooo`008@3oool00`000000oooo0?ooo`2@0?ooo`P00000[03oool00240
oooo00<000000?ooo`3oool0T@3oool:00000:T0oooo000Q0?ooo`030000003oool0oooo09L0oooo
1`00002V0?ooo`008@3oool00`000000oooo0?ooo`2J0?ooo`L00000X`3oool00240oooo00<00000
0?ooo`3oool0W@3oool700000:00oooo000Q0?ooo`800000X@3oool7000009d0oooo000Q0?ooo`03
0000003oool0oooo0:<0oooo1`00002J0?ooo`008@3oool00`000000oooo0?ooo`2V0?ooo`L00000
U`3oool00240oooo00<000000?ooo`3oool0Z@3oool7000009@0oooo000Q0?ooo`030000003oool0
oooo0:`0oooo1`00002A0?ooo`008@3oool00`000000oooo0?ooo`2_0?ooo`L00000SP3oool00240
oooo00<000000?ooo`3oool0/P3oool8000008X0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^
k^h01@3oool2028R8P@0oooo00D0c<c<028R8P0000008R8R0<c<c0050?ooo`030000003oool0oooo
0;D0oooo200000270?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?oo
o`05028R8P2IVIT0oooo09VIV@0R8R801@3oool00`000000oooo0?ooo`2i0?ooo`L00000Q03oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`0000001@3o
ool300000;`0oooo1`0000210?ooo`001`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
<c<c09VIV@3oool0VIVI03<c<`050?ooo`030000003oool0oooo0;l0oooo1P00001o0?ooo`001`3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c0050?ooo`03
0000003oool0oooo0<80oooo1P00001l0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0
oooo00D04A4A0;^k^`3oool0^k^k014A4@050?ooo`030000003oool0oooo0<@0oooo1`00001i0?oo
o`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0^k^k00000005
0?ooo`030000003oool0oooo0<L0oooo1P00001g0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0
k^k^00/0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP050?ooo`030000003oool0oooo0<X0oooo1P00
001d0?ooo`008@3oool00`000000oooo0?ooo`3<0?ooo`L00000L@3oool00240oooo00<000000?oo
o`3oool0c`3oool7000006h0oooo000Q0?ooo`030000003oool0oooo0=80oooo1`00001[0?ooo`00
8@3oool200000=H0oooo1`00001X0?ooo`008@3oool00`000000oooo0?ooo`3H0?ooo`P00000I03o
ool00240oooo00<000000?ooo`3oool0f`3oool800000640oooo000Q0?ooo`030000003oool0oooo
0=l0oooo1`00001N0?ooo`008@3oool00`000000oooo0?ooo`3R0?ooo`L00000F`3oool00240oooo
00<000000?ooo`3oool0i@3oool6000005T0oooo000Q0?ooo`030000003oool0oooo0>P0oooo1P00
001F0?ooo`008@3oool00`000000oooo0?ooo`3Z0?ooo`H00000E03oool00240oooo00<000000?oo
o`3oool0k@3oool500000580oooo000Q0?ooo`030000003oool0oooo0>l0oooo1P00001?0?ooo`00
8@3oool200000?80oooo1`00001<0?ooo`008@3oool00`000000oooo0?ooo`3d0?ooo`L00000B@3o
ool00240oooo00<000000?ooo`3oool0m`3oool7000004H0oooo000Q0?ooo`030000003oool0oooo
0?X0oooo1`0000130?ooo`008@3oool00`000000oooo0?ooo`3m0?ooo`L00000@03oool00240oooo
00<000000?ooo`3oool0o`3oool10?ooo`H00000?P3oool00240oooo00<000000?ooo`3oool0o`3o
ool40?ooo`H00000>`3oool00240oooo00<000000?ooo`3oool0o`3oool60?ooo`H00000>@3oool0
0240oooo00<000000?ooo`3oool0o`3oool90?ooo`D00000=`3oool00240oooo0P00003o0?ooo``0
oooo1P00000d0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`d0oooo1`00000a0?ooo`008@3o
ool00`000000oooo0?ooo`3o0?oooa00oooo1`00000^0?ooo`008@3oool00`000000oooo0?ooo`3o
0?oooa<0oooo1`00000[0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooaH0oooo1`00000X0?oo
o`008@3oool00`000000oooo0?ooo`3o0?oooaT0oooo1`00000U0?ooo`008@3oool00`000000oooo
0?ooo`3o0?oooa`0oooo1P00000S0?ooo`00603oool400000003014A4@3oool0oooo0080oooo00<0
00000?ooo`3oool0o`3ooolO0?ooo`D000008@3oool001X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?ooob40oooo1P00000N0?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`<00000o`3ooolS0?ooo`H00000703oool001X0oooo00<000000?ooo`3oool0o`3oool]0?ooo`<0
0000703oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001P0oooo0P1EEED00`00
0000oooo0?ooo`3o0?oood`0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo002N
0?ooo`0509VIV@000000000004A4A02k^k/0603oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo
0P0R8R840?ooo`0509VIV@0A4A40000003<c<`3<c<`0V03oool009h0oooo00D04A4A0;^k^`3^k^h0
MgMg014A4@090?ooo`H000002@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?oo
o`05014A4@2k^k/0oooo07MgM`0c<c<0V03oool009h0oooo00<000000?ooo`3oool06P3oool01@0A
4A40oooo0?ooo`3oool04A4A00l0oooo00<000000?ooo`3oool0UP3oool001l0oooo00D04A4A0000
000000000000014A4@1j0?ooo`030000003oool0oooo00/0oooo1P0000090?ooo`050000003oool0
oooo0?ooo`0000003P3oool00`2ZZZX04A4A0?ooo`2G0?ooo`008@3oool00`000000oooo0?ooo`1j
0?ooo`030000003oool0oooo01X0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`03014A4@00
0000^k^k09P0oooo000Q0?ooo`030000003oool0oooo07P0oooo00<04A4A0000000000000`00000I
0?ooo`05014A4@3oool0oooo0?ooo`0A4A403P3oool00`2k^k/08R8R0?ooo`2G0?ooo`008@3oool0
0`000000oooo0?ooo`1j0?ooo`030000003oool0oooo01X0oooo00D0MgMg09VIV@3oool0VIVI07Mg
M`0;0?ooo`05014A4@2IVIT0oooo0;^k^`000000V03oool00240oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0J0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2ZZZX04A4A
0000000A4A40ZZZZ09P0oooo000N0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0o`3ooom20?ooo`007P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0
oooo@P3oool001h0oooo1`00003o0?oood@0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?oo
ofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.32) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .03564 L
.08481 .07454 L
.12636 .11115 L
.16632 .14646 L
.20885 .18417 L
.2498 .22063 L
.29331 .25958 L
.33524 .29732 L
.37557 .33386 L
.41848 .37297 L
.4598 .4109 L
.48055 .43003 L
.48962 .43843 L
.49442 .44287 L
.49705 .4453 L
.49834 .4465 L
.49953 .4476 L
.50089 .44831 L
.50161 .44854 L
.50237 .44877 L
.50495 .44957 L
.50998 .45113 L
.51991 .45422 L
.54183 .4611 L
.5817 .47379 L
.62415 .48756 L
.665 .50106 L
.70843 .51565 L
.75027 .52992 L
.79051 .54383 L
.83333 .55879 L
.87456 .57333 L
.9142 .5874 L
.95642 .60245 L
.99704 .61697 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`@00000>03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`00
00000P00003o0?oood<0oooo000Q0?ooo`030000003oool0oooo00<00000o`3ooom20?ooo`008@3o
ool010000000oooo0?ooo`3oool300000?l0oooo@@3oool00240oooo00<000000?ooo`3oool00P3o
ool300000?l0oooo@03oool00240oooo00<000000?ooo`3oool00`3oool300000?l0oooo?`3oool0
0240oooo00<000000?ooo`3oool0103oool300000?l0oooo?P3oool00240oooo0P0000060?ooo`<0
0000o`3ooolm0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`<00000o`3oooll0?ooo`008@3o
ool00`000000oooo0?ooo`070?ooo`@00000o`3ooolj0?ooo`008@3oool00`000000oooo0?ooo`08
0?ooo`@00000o`3oooli0?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`<00000o`3ooolh0?oo
o`008@3oool00`000000oooo0?ooo`0;0?ooo`<00000o`3ooolg0?ooo`008@3oool00`000000oooo
0?ooo`0<0?ooo`@00000o`3ooole0?ooo`008@3oool00`000000oooo0?ooo`0=0?ooo`@00000o`3o
oold0?ooo`008@3oool00`000000oooo0?ooo`0?0?ooo`<00000o`3ooolc0?ooo`008@3oool20000
0140oooo1000003o0?oooc40oooo000Q0?ooo`030000003oool0oooo0140oooo1000003o0?oooc00
oooo000Q0?ooo`030000003oool0oooo01<0oooo0`00003o0?ooobl0oooo000Q0?ooo`030000003o
ool0oooo01@0oooo0`00003o0?ooobh0oooo000Q0?ooo`030000003oool0oooo01D0oooo1000003o
0?ooob`0oooo000Q0?ooo`030000003oool0oooo01H0oooo1000003o0?ooob/0oooo000Q0?ooo`03
0000003oool0oooo01P0oooo0`00003o0?ooobX0oooo000Q0?ooo`030000003oool0oooo01T0oooo
0`00003o0?ooobT0oooo000Q0?ooo`030000003oool0oooo01X0oooo0`00003o0?ooobP0oooo000Q
0?ooo`030000003oool0oooo01/0oooo0`00003o0?ooobL0oooo000Q0?ooo`8000007@3oool30000
0?l0oooo9P3oool00240oooo00<000000?ooo`3oool07@3oool300000?l0oooo9@3oool00240oooo
00<000000?ooo`3oool07P3oool300000?l0oooo903oool00240oooo00<000000?ooo`3oool07`3o
ool300000?l0oooo8`3oool00240oooo00<000000?ooo`3oool0803oool300000?l0oooo8P3oool0
0240oooo00<000000?ooo`3oool08@3oool400000?l0oooo803oool000L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R103oool5000000D0oooo00<000000?ooo`3oool08P3oool40000
0?l0oooo7`3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@2I
VIT08R8R0>k^kP3oool0A4A400D0oooo00<000000?ooo`3oool0903oool300000?l0oooo7P3oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^00H0oooo00<00000
0?ooo`3oool09@3oool300000?l0oooo7@3oool000L0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`0309VIV@0R8R80k^k^00D0oooo0`00000V0?ooo`<00000o`3ooolL0?ooo`001`3oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<0MgMg06IVIP3oool0103oool00`000000oooo0?ooo`0W
0?ooo`<00000o`3ooolK0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00l0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`<00000o`3ooolJ0?ooo`001`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@050?ooo`030000003o
ool0oooo02T0oooo0`00003o0?oooaT0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3o
ool01@2IVIT04A4A0000000R8R80c<c<00D0oooo00<000000?ooo`3oool0:P3oool300000?l0oooo
603oool00240oooo00<000000?ooo`3oool0:`3oool300000?l0oooo5`3oool00240oooo00<00000
0?ooo`3oool0;03oool300000?l0oooo5P3oool00240oooo00<000000?ooo`3oool0;@3oool40000
0?l0oooo503oool00240oooo00<000000?ooo`3oool0;P3oool400000?l0oooo4`3oool00240oooo
0P00000a0?ooo`<00000o`3ooolB0?ooo`008@3oool00`000000oooo0?ooo`0a0?ooo`<00000o`3o
oolA0?ooo`008@3oool00`000000oooo0?ooo`0b0?ooo`<00000o`3oool@0?ooo`008@3oool00`00
0000oooo0?ooo`0c0?ooo`<00000o`3oool?0?ooo`008@3oool00`000000oooo0?ooo`0d0?ooo`<0
0000o`3oool>0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`<00000o`3oool=0?ooo`008@3o
ool00`000000oooo0?ooo`0f0?ooo`<00000o`3oool<0?ooo`008@3oool00`000000oooo0?ooo`0g
0?ooo`<00000o`3oool;0?ooo`008@3oool00`000000oooo0?ooo`0h0?ooo`<00000o`3oool:0?oo
o`008@3oool2000003X0oooo1000003o0?ooo`P0oooo000Q0?ooo`030000003oool0oooo03X0oooo
1000003o0?ooo`L0oooo000Q0?ooo`030000003oool0oooo03`0oooo0`00003o0?ooo`H0oooo000Q
0?ooo`030000003oool0oooo03d0oooo0`00003o0?ooo`D0oooo000Q0?ooo`030000003oool0oooo
03h0oooo0`00003o0?ooo`@0oooo000Q0?ooo`030000003oool0oooo03l0oooo1000003o0?ooo`80
oooo000Q0?ooo`030000003oool0oooo0400oooo1000003o0?ooo`40oooo000Q0?ooo`030000003o
ool0oooo0480oooo0`00003o0?ooo`008@3oool00`000000oooo0?ooo`130?ooo`<00000oP3oool0
0240oooo0P0000150?ooo`<00000o@3oool00240oooo00<000000?ooo`3oool0A@3oool300000?`0
oooo000Q0?ooo`030000003oool0oooo04H0oooo1000003j0?ooo`008@3oool00`000000oooo0?oo
o`170?ooo`@00000n@3oool00240oooo00<000000?ooo`3oool0B@3oool300000?P0oooo000Q0?oo
o`030000003oool0oooo04X0oooo0`00003g0?ooo`008@3oool00`000000oooo0?ooo`1;0?ooo`<0
0000mP3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1P3oool200000003
014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0C03oool400000?@0oooo00070?ooo`0507Mg
M`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1=0?ooo`@00000l`3oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`D0
00001@3oool00`000000oooo0?ooo`1?0?ooo`<00000lP3oool000L0oooo00D000000?ooo`3oool0
oooo0000000;0?ooo`0404A4A03MgMd0oooo000000H0oooo0`00001@0?ooo`<00000l@3oool000L0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000000H0oooo00<00000
0?ooo`3oool0D@3oool300000?00oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool0
0`1gMgL0c<c<000000060?ooo`030000003oool0oooo0580oooo0`00003_0?ooo`001`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A00000001P3oool00`000000oooo0?ooo`1C
0?ooo`<00000kP3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000
oooo00D0oooo00<000000?ooo`3oool0E03oool300000>d0oooo000Q0?ooo`030000003oool0oooo
05D0oooo0`00003/0?ooo`008@3oool00`000000oooo0?ooo`1F0?ooo`<00000j`3oool00240oooo
00<000000?ooo`3oool0E`3oool300000>X0oooo000Q0?ooo`030000003oool0oooo05P0oooo0`00
003Y0?ooo`008@3oool2000005X0oooo0`00003X0?ooo`008@3oool00`000000oooo0?ooo`1J0?oo
o`<00000i`3oool00240oooo00<000000?ooo`3oool0F`3oool300000>H0oooo000Q0?ooo`030000
003oool0oooo05`0oooo0`00003U0?ooo`008@3oool00`000000oooo0?ooo`1M0?ooo`<00000i03o
ool00240oooo00<000000?ooo`3oool0GP3oool300000><0oooo000Q0?ooo`030000003oool0oooo
05l0oooo1000003Q0?ooo`008@3oool00`000000oooo0?ooo`1P0?ooo`@00000h03oool00240oooo
00<000000?ooo`3oool0HP3oool300000=l0oooo000Q0?ooo`800000I03oool300000=h0oooo000Q
0?ooo`030000003oool0oooo06@0oooo0`00003M0?ooo`008@3oool00`000000oooo0?ooo`1U0?oo
o`@00000f`3oool00240oooo00<000000?ooo`3oool0IP3oool400000=X0oooo000Q0?ooo`030000
003oool0oooo06P0oooo0`00003I0?ooo`008@3oool00`000000oooo0?ooo`1Y0?ooo`<00000f03o
ool00240oooo00<000000?ooo`3oool0JP3oool300000=L0oooo000Q0?ooo`030000003oool0oooo
06/0oooo1000003E0?ooo`008@3oool00`000000oooo0?ooo`1/0?ooo`@00000e03oool00240oooo
0P00001_0?ooo`<00000d`3oool00240oooo00<000000?ooo`3oool0K`3oool300000=80oooo000Q
0?ooo`030000003oool0oooo0700oooo0`00003A0?ooo`008@3oool00`000000oooo0?ooo`1a0?oo
o`<00000d03oool00240oooo00<000000?ooo`3oool0LP3oool300000<l0oooo000Q0?ooo`030000
003oool0oooo07<0oooo0`00003>0?ooo`008@3oool00`000000oooo0?ooo`1d0?ooo`<00000c@3o
ool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R103oool01@3^k^h0<c<c0000
000A4A40c<c<00D0oooo00<000000?ooo`3oool0M@3oool300000<`0oooo00070?ooo`0507MgM`2I
VIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0EEEE07MgM`3oool0VIVI028R8P050?ooo`03
0000003oool0oooo07H0oooo0`00003;0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0
oooo00D000000?ooo`3oool0oooo000000050?ooo`<00000M`3oool300000<X0oooo00070?ooo`05
0000003oool0oooo0?ooo`0000002`3oool01@000000VIVI0?ooo`2IVIT08R8R00D0oooo00<00000
0?ooo`3oool0N03oool400000<P0oooo00070?ooo`050000003oool0oooo0?ooo`0000002`3oool0
1@000000EEEE0000000A4A40c<c<00D0oooo00<000000?ooo`3oool0N@3oool400000<L0oooo0007
0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`070?ooo`030000003o
ool0oooo07/0oooo0`0000360?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00<0
gMgM014A4@2IVIT01`3oool00`000000oooo0?ooo`1l0?ooo`<00000a@3oool000L0oooo00D0k^k^
03<c<`000000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4@D0oooo00<000000?ooo`3oool0
O@3oool300000<@0oooo000Q0?ooo`030000003oool0oooo07h0oooo0`0000330?ooo`008@3oool0
0`000000oooo0?ooo`1o0?ooo`<00000`P3oool00240oooo00<000000?ooo`3oool0P03oool30000
0<40oooo000Q0?ooo`030000003oool0oooo0840oooo0`0000300?ooo`008@3oool2000008<0oooo
0`00002o0?ooo`008@3oool00`000000oooo0?ooo`230?ooo`<00000_P3oool00240oooo00<00000
0?ooo`3oool0Q03oool300000;d0oooo000Q0?ooo`030000003oool0oooo08D0oooo0`00002l0?oo
o`008@3oool00`000000oooo0?ooo`260?ooo`<00000^`3oool00240oooo00<000000?ooo`3oool0
Q`3oool300000;X0oooo000Q0?ooo`030000003oool0oooo08P0oooo0`00002i0?ooo`008@3oool0
0`000000oooo0?ooo`290?ooo`<00000^03oool00240oooo00<000000?ooo`3oool0RP3oool30000
0;L0oooo000Q0?ooo`800000S03oool300000;H0oooo000Q0?ooo`030000003oool0oooo08`0oooo
0`00002e0?ooo`008@3oool00`000000oooo0?ooo`2=0?ooo`<00000]03oool00240oooo00<00000
0?ooo`3oool0SP3oool300000;<0oooo000Q0?ooo`030000003oool0oooo08l0oooo1000002a0?oo
o`008@3oool00`000000oooo0?ooo`2@0?ooo`P00000[03oool00240oooo00<000000?ooo`3oool0
T@3oool:00000:T0oooo000Q0?ooo`030000003oool0oooo09L0oooo1`00002V0?ooo`008@3oool0
0`000000oooo0?ooo`2J0?ooo`L00000X`3oool00240oooo0P00002N0?ooo`L00000X03oool00240
oooo00<000000?ooo`3oool0X03oool7000009d0oooo000Q0?ooo`030000003oool0oooo0:<0oooo
1`00002J0?ooo`008@3oool00`000000oooo0?ooo`2V0?ooo`L00000U`3oool00240oooo00<00000
0?ooo`3oool0Z@3oool7000009@0oooo000Q0?ooo`030000003oool0oooo0:`0oooo1`00002A0?oo
o`008@3oool00`000000oooo0?ooo`2_0?ooo`L00000SP3oool000L0oooo00D0k^k^03<c<`000000
<c<c0>k^kP050?ooo`808R8R103oool01@3<c<`08R8R0000000R8R80c<c<00D0oooo00<000000?oo
o`3oool0/P3oool8000008X0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R
8P@0oooo00D08R8R09VIV@3oool0VIVI028R8P050?ooo`030000003oool0oooo0;D0oooo20000027
0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`<00000^@3oool7000008@0oooo00070?ooo`050000003oool0oooo0?ooo`0000002`3o
ool01@0c<c<0VIVI0?ooo`2IVIT0<c<c00D0oooo00<000000?ooo`3oool0_03oool700000840oooo
00070?ooo`050000003oool0oooo0?ooo`0000002`3oool01@3<c<`00000000000000000c<c<00D0
oooo00<000000?ooo`3oool0_`3oool6000007l0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A
4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A00D0oooo00<000000?ooo`3oool0`P3oool60000
07`0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2k^k/0
000000D0oooo00<000000?ooo`3oool0a03oool7000007T0oooo00070?ooo`050>k^kP0c<c<00000
03<c<`3^k^h02`3oool01@2ZZZX04A4A0000000A4A40ZZZZ00D0oooo00<000000?ooo`3oool0a`3o
ool6000007L0oooo000Q0?ooo`030000003oool0oooo0<X0oooo1P00001d0?ooo`008@3oool00`00
0000oooo0?ooo`3<0?ooo`L00000L@3oool00240oooo00<000000?ooo`3oool0c`3oool7000006h0
oooo000Q0?ooo`800000d`3oool7000006/0oooo000Q0?ooo`030000003oool0oooo0=D0oooo1`00
001X0?ooo`008@3oool00`000000oooo0?ooo`3H0?ooo`P00000I03oool00240oooo00<000000?oo
o`3oool0f`3oool800000640oooo000Q0?ooo`030000003oool0oooo0=l0oooo1`00001N0?ooo`00
8@3oool00`000000oooo0?ooo`3R0?ooo`L00000F`3oool00240oooo00<000000?ooo`3oool0i@3o
ool7000005P0oooo000Q0?ooo`030000003oool0oooo0>P0oooo1`00001E0?ooo`008@3oool00`00
0000oooo0?ooo`3[0?ooo`L00000DP3oool00240oooo00<000000?ooo`3oool0kP3oool7000004l0
oooo000Q0?ooo`800000lP3oool6000004d0oooo000Q0?ooo`030000003oool0oooo0?@0oooo1P00
001:0?ooo`008@3oool00`000000oooo0?ooo`3f0?ooo`L00000A`3oool00240oooo00<000000?oo
o`3oool0n@3oool6000004D0oooo000Q0?ooo`030000003oool0oooo0?`0oooo1P0000120?ooo`00
8@3oool00`000000oooo0?ooo`3n0?ooo`H00000@03oool00240oooo00<000000?ooo`3oool0o`3o
ool20?ooo`H00000?@3oool00240oooo00<000000?ooo`3oool0o`3oool40?ooo`L00000>P3oool0
0240oooo00<000000?ooo`3oool0o`3oool70?ooo`L00000=`3oool00240oooo0P00003o0?ooo`/0
oooo1`00000d0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`d0oooo1`00000a0?ooo`008@3o
ool00`000000oooo0?ooo`3o0?oooa00oooo1`00000^0?ooo`008@3oool00`000000oooo0?ooo`3o
0?oooa<0oooo1`00000[0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooaH0oooo1`00000X0?oo
o`008@3oool00`000000oooo0?ooo`3o0?oooaT0oooo1`00000U0?ooo`008@3oool00`000000oooo
0?ooo`3o0?oooa`0oooo1P00000S0?ooo`00603oool400000003014A4@3oool0oooo0080oooo00<0
00000?ooo`3oool0o`3ooolO0?ooo`D000008@3oool001X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?ooob40oooo1P00000N0?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`<00000o`3ooolS0?ooo`H00000703oool001X0oooo00<000000?ooo`3oool0o`3oool]0?ooo`<0
0000703oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001P0oooo0P1EEED00`00
0000oooo0?ooo`3o0?oood`0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo002J
0?ooo`0509VIV@000000000004A4A02k^k/0603oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo
0P0R8R840?ooo`0509VIV@0A4A40000003<c<`3<c<`00`3oool5000009@0oooo002J0?ooo`05014A
4@2k^k/0k^k^07MgM`0A4A402@3oool6000000T0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?oo
o`808R8R103oool01@0A4A40^k^k0?ooo`1gMgL0<c<c00<0oooo00D0VIVI028R8P3^k^h0oooo04A4
A02D0?ooo`00VP3oool00`000000oooo0?ooo`0J0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3o
ool00`000000oooo0?ooo`020?ooo`0309VIV@0R8R80k^k^09D0oooo000O0?ooo`05014A4@000000
00000000000A4A40MP3oool00`000000oooo0?ooo`0;0?ooo`H000002@3oool01@000000oooo0?oo
o`3oool0000000h0oooo00<0ZZZZ014A4@3oool0103oool00`2IVIT08R8R0>k^kP2D0?ooo`008@3o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01X0oooo00D000000?ooo`3oool0oooo
0000000=0?ooo`03014A4@000000^k^k00H0oooo00<0MgMg06IVIP3oool0T`3oool00240oooo00<0
00000?ooo`3oool0M03oool00`0A4A40000000000003000001T0oooo00D04A4A0?ooo`3oool0oooo
014A4@0>0?ooo`030;^k^`0R8R80oooo00H0oooo00<000000?ooo`3oool0TP3oool00240oooo00<0
00000?ooo`3oool0MP3oool00`000000oooo0?ooo`0J0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0
2`3oool01@0A4A40VIVI0?ooo`2k^k/0000000<0oooo00D000000;^k^`3oool0VIVI014A4@2D0?oo
o`008@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01X0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX00`3oool01@2IVIT04A4A0000000R
8R80c<c<09@0oooo000N0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3o
oom20?ooo`007P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0oooo@P3o
ool001h0oooo1`00003o0?oood@0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.34) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .03599 L
.08481 .07527 L
.12636 .11223 L
.16632 .14784 L
.20885 .18586 L
.2498 .22259 L
.29331 .26179 L
.33524 .29974 L
.37557 .33642 L
.41848 .37566 L
.4598 .41365 L
.48055 .4328 L
.48962 .4412 L
.49442 .44564 L
.49705 .44808 L
.49834 .44927 L
.49953 .45038 L
.50089 .45109 L
.50161 .45131 L
.50237 .45154 L
.50495 .45234 L
.50998 .4539 L
.51991 .45699 L
.54183 .46385 L
.5817 .47648 L
.62415 .49013 L
.665 .50347 L
.70843 .51785 L
.75027 .53188 L
.79051 .54552 L
.83333 .56017 L
.87456 .57439 L
.9142 .58814 L
.95642 .60283 L
.99704 .617 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`@00000>03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`00
00000P00003o0?oood<0oooo000Q0?ooo`030000003oool0oooo00<00000o`3ooom20?ooo`008@3o
ool010000000oooo0?ooo`3oool300000?l0oooo@@3oool00240oooo00<000000?ooo`3oool00P3o
ool300000?l0oooo@03oool00240oooo00<000000?ooo`3oool00`3oool300000?l0oooo?`3oool0
0240oooo00<000000?ooo`3oool0103oool300000?l0oooo?P3oool00240oooo0P0000060?ooo`<0
0000o`3ooolm0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`<00000o`3oooll0?ooo`008@3o
ool00`000000oooo0?ooo`070?ooo`@00000o`3ooolj0?ooo`008@3oool00`000000oooo0?ooo`08
0?ooo`@00000o`3oooli0?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`<00000o`3ooolh0?oo
o`008@3oool00`000000oooo0?ooo`0;0?ooo`<00000o`3ooolg0?ooo`008@3oool00`000000oooo
0?ooo`0<0?ooo`@00000o`3ooole0?ooo`008@3oool00`000000oooo0?ooo`0=0?ooo`@00000o`3o
oold0?ooo`008@3oool00`000000oooo0?ooo`0?0?ooo`<00000o`3ooolc0?ooo`008@3oool20000
0140oooo1000003o0?oooc40oooo000Q0?ooo`030000003oool0oooo0140oooo1000003o0?oooc00
oooo000Q0?ooo`030000003oool0oooo01<0oooo0`00003o0?ooobl0oooo000Q0?ooo`030000003o
ool0oooo01@0oooo0`00003o0?ooobh0oooo000Q0?ooo`030000003oool0oooo01D0oooo0`00003o
0?ooobd0oooo000Q0?ooo`030000003oool0oooo01H0oooo0`00003o0?ooob`0oooo000Q0?ooo`03
0000003oool0oooo01L0oooo0`00003o0?ooob/0oooo000Q0?ooo`030000003oool0oooo01P0oooo
0`00003o0?ooobX0oooo000Q0?ooo`030000003oool0oooo01T0oooo0`00003o0?ooobT0oooo000Q
0?ooo`030000003oool0oooo01X0oooo0`00003o0?ooobP0oooo000Q0?ooo`800000703oool30000
0?l0oooo9`3oool00240oooo00<000000?ooo`3oool0703oool300000?l0oooo9P3oool00240oooo
00<000000?ooo`3oool07@3oool300000?l0oooo9@3oool00240oooo00<000000?ooo`3oool07P3o
ool300000?l0oooo903oool00240oooo00<000000?ooo`3oool07`3oool300000?l0oooo8`3oool0
0240oooo00<000000?ooo`3oool0803oool300000?l0oooo8P3oool000L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R103oool5000000D0oooo00<000000?ooo`3oool08@3oool40000
0?l0oooo803oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@2I
VIT08R8R0>k^kP3oool0A4A400D0oooo00<000000?ooo`3oool08P3oool400000?l0oooo7`3oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^00H0oooo00<00000
0?ooo`3oool0903oool300000?l0oooo7P3oool000L0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`0309VIV@0R8R80k^k^00D0oooo0`00000U0?ooo`<00000o`3ooolM0?ooo`001`3oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<0MgMg06IVIP3oool0103oool00`000000oooo0?ooo`0V
0?ooo`<00000o`3ooolL0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00l0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`@00000o`3ooolJ0?ooo`001`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@050?ooo`030000003o
ool0oooo02P0oooo1000003o0?oooaT0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3o
ool01@2IVIT04A4A0000000R8R80c<c<00D0oooo00<000000?ooo`3oool0:P3oool300000?l0oooo
603oool00240oooo00<000000?ooo`3oool0:`3oool300000?l0oooo5`3oool00240oooo00<00000
0?ooo`3oool0;03oool300000?l0oooo5P3oool00240oooo00<000000?ooo`3oool0;@3oool40000
0?l0oooo503oool00240oooo00<000000?ooo`3oool0;P3oool400000?l0oooo4`3oool00240oooo
0P00000a0?ooo`<00000o`3ooolB0?ooo`008@3oool00`000000oooo0?ooo`0a0?ooo`<00000o`3o
oolA0?ooo`008@3oool00`000000oooo0?ooo`0b0?ooo`<00000o`3oool@0?ooo`008@3oool00`00
0000oooo0?ooo`0c0?ooo`<00000o`3oool?0?ooo`008@3oool00`000000oooo0?ooo`0d0?ooo`<0
0000o`3oool>0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`<00000o`3oool=0?ooo`008@3o
ool00`000000oooo0?ooo`0f0?ooo`<00000o`3oool<0?ooo`008@3oool00`000000oooo0?ooo`0g
0?ooo`<00000o`3oool;0?ooo`008@3oool00`000000oooo0?ooo`0h0?ooo`<00000o`3oool:0?oo
o`008@3oool2000003X0oooo1000003o0?ooo`P0oooo000Q0?ooo`030000003oool0oooo03X0oooo
1000003o0?ooo`L0oooo000Q0?ooo`030000003oool0oooo03`0oooo0`00003o0?ooo`H0oooo000Q
0?ooo`030000003oool0oooo03d0oooo0`00003o0?ooo`D0oooo000Q0?ooo`030000003oool0oooo
03h0oooo0`00003o0?ooo`@0oooo000Q0?ooo`030000003oool0oooo03l0oooo1000003o0?ooo`80
oooo000Q0?ooo`030000003oool0oooo0400oooo1000003o0?ooo`40oooo000Q0?ooo`030000003o
ool0oooo0480oooo0`00003o0?ooo`008@3oool00`000000oooo0?ooo`130?ooo`<00000oP3oool0
0240oooo0P0000150?ooo`<00000o@3oool00240oooo00<000000?ooo`3oool0A@3oool300000?`0
oooo000Q0?ooo`030000003oool0oooo04H0oooo1000003j0?ooo`008@3oool00`000000oooo0?oo
o`170?ooo`@00000n@3oool00240oooo00<000000?ooo`3oool0B@3oool300000?P0oooo000Q0?oo
o`030000003oool0oooo04X0oooo0`00003g0?ooo`008@3oool00`000000oooo0?ooo`1;0?ooo`<0
0000mP3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1P3oool200000003
014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0C03oool300000?D0oooo00070?ooo`0507Mg
M`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1=0?ooo`<00000m03oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`D0
00001@3oool00`000000oooo0?ooo`1>0?ooo`<00000l`3oool000L0oooo00D000000?ooo`3oool0
oooo0000000;0?ooo`0404A4A03MgMd0oooo000000H0oooo0`00001?0?ooo`<00000lP3oool000L0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000000H0oooo00<00000
0?ooo`3oool0D03oool300000?40oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool0
0`1gMgL0c<c<000000060?ooo`030000003oool0oooo0540oooo0`00003`0?ooo`001`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A00000001P3oool00`000000oooo0?ooo`1B
0?ooo`<00000k`3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000
oooo00D0oooo00<000000?ooo`3oool0D`3oool400000>d0oooo000Q0?ooo`030000003oool0oooo
05@0oooo1000003/0?ooo`008@3oool00`000000oooo0?ooo`1F0?ooo`<00000j`3oool00240oooo
00<000000?ooo`3oool0E`3oool300000>X0oooo000Q0?ooo`030000003oool0oooo05P0oooo0`00
003Y0?ooo`008@3oool2000005X0oooo0`00003X0?ooo`008@3oool00`000000oooo0?ooo`1J0?oo
o`<00000i`3oool00240oooo00<000000?ooo`3oool0F`3oool300000>H0oooo000Q0?ooo`030000
003oool0oooo05`0oooo0`00003U0?ooo`008@3oool00`000000oooo0?ooo`1M0?ooo`<00000i03o
ool00240oooo00<000000?ooo`3oool0GP3oool300000><0oooo000Q0?ooo`030000003oool0oooo
05l0oooo1000003Q0?ooo`008@3oool00`000000oooo0?ooo`1P0?ooo`@00000h03oool00240oooo
00<000000?ooo`3oool0HP3oool300000=l0oooo000Q0?ooo`800000I03oool300000=h0oooo000Q
0?ooo`030000003oool0oooo06@0oooo0`00003M0?ooo`008@3oool00`000000oooo0?ooo`1U0?oo
o`<00000g03oool00240oooo00<000000?ooo`3oool0IP3oool300000=/0oooo000Q0?ooo`030000
003oool0oooo06L0oooo0`00003J0?ooo`008@3oool00`000000oooo0?ooo`1X0?ooo`<00000f@3o
ool00240oooo00<000000?ooo`3oool0J@3oool300000=P0oooo000Q0?ooo`030000003oool0oooo
06X0oooo0`00003G0?ooo`008@3oool00`000000oooo0?ooo`1[0?ooo`@00000e@3oool00240oooo
0P00001]0?ooo`@00000e03oool00240oooo00<000000?ooo`3oool0KP3oool300000=<0oooo000Q
0?ooo`030000003oool0oooo06l0oooo0`00003B0?ooo`008@3oool00`000000oooo0?ooo`1`0?oo
o`<00000d@3oool00240oooo00<000000?ooo`3oool0L@3oool300000=00oooo000Q0?ooo`030000
003oool0oooo0780oooo0`00003?0?ooo`008@3oool00`000000oooo0?ooo`1c0?ooo`<00000cP3o
ool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R103oool01@3^k^h0<c<c0000
000A4A40c<c<00D0oooo00<000000?ooo`3oool0M03oool300000<d0oooo00070?ooo`0507MgM`2I
VIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0EEEE07MgM`3oool0VIVI028R8P050?ooo`03
0000003oool0oooo07D0oooo0`00003<0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0
oooo00D000000?ooo`3oool0oooo000000050?ooo`<00000MP3oool300000</0oooo00070?ooo`05
0000003oool0oooo0?ooo`0000002`3oool01@000000VIVI0?ooo`2IVIT08R8R00D0oooo00<00000
0?ooo`3oool0M`3oool300000<X0oooo00070?ooo`050000003oool0oooo0?ooo`0000002`3oool0
1@000000EEEE0000000A4A40c<c<00D0oooo00<000000?ooo`3oool0N03oool400000<P0oooo0007
0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`070?ooo`030000003o
ool0oooo07T0oooo100000370?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00<0
gMgM014A4@2IVIT01`3oool00`000000oooo0?ooo`1k0?ooo`<00000aP3oool000L0oooo00D0k^k^
03<c<`000000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4@D0oooo00<000000?ooo`3oool0
O03oool300000<D0oooo000Q0?ooo`030000003oool0oooo07d0oooo0`0000340?ooo`008@3oool0
0`000000oooo0?ooo`1n0?ooo`<00000``3oool00240oooo00<000000?ooo`3oool0O`3oool30000
0<80oooo000Q0?ooo`030000003oool0oooo0800oooo0`0000310?ooo`008@3oool200000880oooo
0`0000300?ooo`008@3oool00`000000oooo0?ooo`220?ooo`<00000_`3oool00240oooo00<00000
0?ooo`3oool0P`3oool300000;h0oooo000Q0?ooo`030000003oool0oooo08@0oooo0`00002m0?oo
o`008@3oool00`000000oooo0?ooo`250?ooo`<00000_03oool00240oooo00<000000?ooo`3oool0
QP3oool300000;/0oooo000Q0?ooo`030000003oool0oooo08L0oooo0`00002j0?ooo`008@3oool0
0`000000oooo0?ooo`280?ooo`<00000^@3oool00240oooo00<000000?ooo`3oool0R@3oool30000
0;P0oooo000Q0?ooo`800000R`3oool400000;H0oooo000Q0?ooo`030000003oool0oooo08/0oooo
1000002e0?ooo`008@3oool00`000000oooo0?ooo`2=0?ooo`<00000]03oool00240oooo00<00000
0?ooo`3oool0SP3oool200000;@0oooo000Q0?ooo`030000003oool0oooo08h0oooo1000002b0?oo
o`008@3oool00`000000oooo0?ooo`2?0?ooo`D00000/03oool00240oooo00<000000?ooo`3oool0
T@3oool700000:`0oooo000Q0?ooo`030000003oool0oooo09<0oooo2000002Y0?ooo`008@3oool0
0`000000oooo0?ooo`2G0?ooo`L00000YP3oool00240oooo0P00002K0?ooo`L00000X`3oool00240
oooo00<000000?ooo`3oool0W@3oool700000:00oooo000Q0?ooo`030000003oool0oooo0:00oooo
1`00002M0?ooo`008@3oool00`000000oooo0?ooo`2S0?ooo`L00000VP3oool00240oooo00<00000
0?ooo`3oool0YP3oool7000009L0oooo000Q0?ooo`030000003oool0oooo0:T0oooo1`00002D0?oo
o`008@3oool00`000000oooo0?ooo`2/0?ooo`L00000T@3oool000L0oooo00D0k^k^03<c<`000000
<c<c0>k^kP050?ooo`808R8R103oool01@3<c<`08R8R0000000R8R80c<c<00D0oooo00<000000?oo
o`3oool0[`3oool7000008h0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R
8P@0oooo00D08R8R09VIV@3oool0VIVI028R8P050?ooo`030000003oool0oooo0;80oooo2000002:
0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`<00000]@3oool8000008L0oooo00070?ooo`050000003oool0oooo0?ooo`0000002`3o
ool01@0c<c<0VIVI0?ooo`2IVIT0<c<c00D0oooo00<000000?ooo`3oool0^@3oool7000008@0oooo
00070?ooo`050000003oool0oooo0?ooo`0000002`3oool01@3<c<`00000000000000000c<c<00D0
oooo00<000000?ooo`3oool0_03oool700000840oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A
4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A00D0oooo00<000000?ooo`3oool0_`3oool70000
07h0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2k^k/0
000000D0oooo00<000000?ooo`3oool0`P3oool7000007/0oooo00070?ooo`050>k^kP0c<c<00000
03<c<`3^k^h02`3oool01@2ZZZX04A4A0000000A4A40ZZZZ00D0oooo00<000000?ooo`3oool0a@3o
ool7000007P0oooo000Q0?ooo`030000003oool0oooo0<P0oooo1`00001e0?ooo`008@3oool00`00
0000oooo0?ooo`3;0?ooo`P00000L@3oool00240oooo00<000000?ooo`3oool0cP3oool8000006h0
oooo000Q0?ooo`800000d`3oool7000006/0oooo000Q0?ooo`030000003oool0oooo0=D0oooo1`00
001X0?ooo`008@3oool00`000000oooo0?ooo`3H0?ooo`P00000I03oool00240oooo00<000000?oo
o`3oool0f`3oool800000640oooo000Q0?ooo`030000003oool0oooo0=l0oooo1`00001N0?ooo`00
8@3oool00`000000oooo0?ooo`3R0?ooo`L00000F`3oool00240oooo00<000000?ooo`3oool0i@3o
ool6000005T0oooo000Q0?ooo`030000003oool0oooo0>P0oooo1P00001F0?ooo`008@3oool00`00
0000oooo0?ooo`3Z0?ooo`H00000E03oool00240oooo00<000000?ooo`3oool0k@3oool500000580
oooo000Q0?ooo`800000l03oool6000004l0oooo000Q0?ooo`030000003oool0oooo0?40oooo1`00
001<0?ooo`008@3oool00`000000oooo0?ooo`3d0?ooo`L00000B@3oool00240oooo00<000000?oo
o`3oool0m`3oool7000004H0oooo000Q0?ooo`030000003oool0oooo0?X0oooo1`0000130?ooo`00
8@3oool00`000000oooo0?ooo`3m0?ooo`L00000@03oool00240oooo00<000000?ooo`3oool0o`3o
ool10?ooo`L00000?@3oool00240oooo00<000000?ooo`3oool0o`3oool40?ooo`L00000>P3oool0
0240oooo00<000000?ooo`3oool0o`3oool70?ooo`L00000=`3oool00240oooo0P00003o0?ooo`/0
oooo1P00000e0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`d0oooo1P00000b0?ooo`008@3o
ool00`000000oooo0?ooo`3o0?ooo`l0oooo1`00000_0?ooo`008@3oool00`000000oooo0?ooo`3o
0?oooa80oooo1P00000]0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooaD0oooo1P00000Z0?oo
o`008@3oool00`000000oooo0?ooo`3o0?oooaL0oooo1`00000W0?ooo`008@3oool00`000000oooo
0?ooo`3o0?oooaX0oooo1`00000T0?ooo`00603oool400000003014A4@3oool0oooo0080oooo00<0
00000?ooo`3oool0o`3ooolM0?ooo`L000008@3oool001X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?ooob00oooo1`00000N0?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`<00000o`3ooolS0?ooo`H00000703oool001X0oooo00<000000?ooo`3oool0o`3oool]0?ooo`<0
0000703oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001P0oooo0P1EEED00`00
0000oooo0?ooo`3o0?oood`0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo002J
0?ooo`0509VIV@000000000004A4A02k^k/0603oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo
0P0R8R840?ooo`0509VIV@0A4A40000003<c<`3<c<`01@3oool200000003014A4@3oool0oooo0980
oooo002J0?ooo`05014A4@2k^k/0k^k^07MgM`0A4A402@3oool6000000T0oooo00D0MgMg09VIV@3o
ool0VIVI07MgM`050?ooo`808R8R103oool01@0A4A40^k^k0?ooo`1gMgL0<c<c00H0oooo00<00000
0?ooo`3oool0T`3oool009X0oooo00<000000?ooo`3oool06P3oool01@0A4A40oooo0?ooo`3oool0
4A4A00l0oooo00@000000?ooo`3oool0oooo1@00002D0?ooo`007`3oool01@0A4A40000000000000
00004A4A07H0oooo00<000000?ooo`3oool02`3oool6000000T0oooo00D000000?ooo`3oool0oooo
0000000>0?ooo`030:ZZZP0A4A40oooo0080oooo00@0A4A40=gMg@3oool00000U@3oool00240oooo
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`00
00003@3oool00`0A4A4000000;^k^`030?ooo`040=gMg@1EEED0oooo000009D0oooo000Q0?ooo`03
0000003oool0oooo07@0oooo00<04A4A0000000000000`00000I0?ooo`05014A4@3oool0oooo0?oo
o`0A4A403P3oool00`2k^k/08R8R0?ooo`030?ooo`0307MgM`3<c<`0000009D0oooo000Q0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool06P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
00/0oooo00D04A4A09VIV@3oool0^k^k000000040?ooo`030>k^kP14A4@0000009D0oooo000Q0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool06P3oool01@3^k^h0<c<c0000000c<c<0
k^k^00/0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP050?ooo`0307MgM`000000oooo09@0oooo000N
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooom20?ooo`007P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0oooo@P3oool001h0oooo1`00003o
0?oood@0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .03628 L
.08481 .07587 L
.12636 .11311 L
.16632 .14898 L
.20885 .18725 L
.2498 .2242 L
.29331 .2636 L
.33524 .30171 L
.37557 .33853 L
.41848 .37786 L
.4598 .41591 L
.48055 .43508 L
.48962 .44348 L
.49442 .44792 L
.49705 .45035 L
.49834 .45155 L
.49953 .45265 L
.50089 .45337 L
.50161 .45359 L
.50237 .45382 L
.50495 .45462 L
.50998 .45618 L
.51991 .45926 L
.54183 .46611 L
.5817 .47868 L
.62415 .49224 L
.665 .50545 L
.70843 .51966 L
.75027 .53349 L
.79051 .54692 L
.83333 .56131 L
.87456 .57527 L
.9142 .58874 L
.95642 .60314 L
.99704 .61702 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`@00000>03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`00
00000P00003o0?oood<0oooo000Q0?ooo`030000003oool0oooo00<00000o`3ooom20?ooo`008@3o
ool010000000oooo0?ooo`3oool300000?l0oooo@@3oool00240oooo00<000000?ooo`3oool00P3o
ool300000?l0oooo@03oool00240oooo00<000000?ooo`3oool00`3oool300000?l0oooo?`3oool0
0240oooo00<000000?ooo`3oool0103oool300000?l0oooo?P3oool00240oooo0P0000060?ooo`<0
0000o`3ooolm0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`<00000o`3oooll0?ooo`008@3o
ool00`000000oooo0?ooo`070?ooo`@00000o`3ooolj0?ooo`008@3oool00`000000oooo0?ooo`08
0?ooo`@00000o`3oooli0?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`<00000o`3ooolh0?oo
o`008@3oool00`000000oooo0?ooo`0;0?ooo`<00000o`3ooolg0?ooo`008@3oool00`000000oooo
0?ooo`0<0?ooo`<00000o`3ooolf0?ooo`008@3oool00`000000oooo0?ooo`0=0?ooo`<00000o`3o
oole0?ooo`008@3oool00`000000oooo0?ooo`0>0?ooo`@00000o`3ooolc0?ooo`008@3oool20000
0100oooo1000003o0?oooc80oooo000Q0?ooo`030000003oool0oooo0140oooo0`00003o0?oooc40
oooo000Q0?ooo`030000003oool0oooo0180oooo0`00003o0?oooc00oooo000Q0?ooo`030000003o
ool0oooo01<0oooo0`00003o0?ooobl0oooo000Q0?ooo`030000003oool0oooo01@0oooo0`00003o
0?ooobh0oooo000Q0?ooo`030000003oool0oooo01D0oooo1000003o0?ooob`0oooo000Q0?ooo`03
0000003oool0oooo01H0oooo1000003o0?ooob/0oooo000Q0?ooo`030000003oool0oooo01P0oooo
0`00003o0?ooobX0oooo000Q0?ooo`030000003oool0oooo01T0oooo0`00003o0?ooobT0oooo000Q
0?ooo`030000003oool0oooo01X0oooo0`00003o0?ooobP0oooo000Q0?ooo`800000703oool30000
0?l0oooo9`3oool00240oooo00<000000?ooo`3oool0703oool300000?l0oooo9P3oool00240oooo
00<000000?ooo`3oool07@3oool300000?l0oooo9@3oool00240oooo00<000000?ooo`3oool07P3o
ool300000?l0oooo903oool00240oooo00<000000?ooo`3oool07`3oool300000?l0oooo8`3oool0
0240oooo00<000000?ooo`3oool0803oool300000?l0oooo8P3oool000L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R103oool5000000D0oooo00<000000?ooo`3oool08@3oool40000
0?l0oooo803oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@2I
VIT08R8R0>k^kP3oool0A4A400D0oooo00<000000?ooo`3oool08P3oool400000?l0oooo7`3oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^00H0oooo00<00000
0?ooo`3oool0903oool300000?l0oooo7P3oool000L0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`0309VIV@0R8R80k^k^00D0oooo0`00000U0?ooo`<00000o`3ooolM0?ooo`001`3oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<0MgMg06IVIP3oool0103oool00`000000oooo0?ooo`0V
0?ooo`<00000o`3ooolL0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00l0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`@00000o`3ooolJ0?ooo`001`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@050?ooo`030000003o
ool0oooo02P0oooo1000003o0?oooaT0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3o
ool01@2IVIT04A4A0000000R8R80c<c<00D0oooo00<000000?ooo`3oool0:P3oool300000?l0oooo
603oool00240oooo00<000000?ooo`3oool0:`3oool300000?l0oooo5`3oool00240oooo00<00000
0?ooo`3oool0;03oool300000?l0oooo5P3oool00240oooo00<000000?ooo`3oool0;@3oool30000
0?l0oooo5@3oool00240oooo00<000000?ooo`3oool0;P3oool300000?l0oooo503oool00240oooo
0P00000`0?ooo`<00000o`3ooolC0?ooo`008@3oool00`000000oooo0?ooo`0`0?ooo`<00000o`3o
oolB0?ooo`008@3oool00`000000oooo0?ooo`0a0?ooo`<00000o`3ooolA0?ooo`008@3oool00`00
0000oooo0?ooo`0b0?ooo`<00000o`3oool@0?ooo`008@3oool00`000000oooo0?ooo`0c0?ooo`<0
0000o`3oool?0?ooo`008@3oool00`000000oooo0?ooo`0d0?ooo`<00000o`3oool>0?ooo`008@3o
ool00`000000oooo0?ooo`0e0?ooo`<00000o`3oool=0?ooo`008@3oool00`000000oooo0?ooo`0f
0?ooo`<00000o`3oool<0?ooo`008@3oool00`000000oooo0?ooo`0g0?ooo`<00000o`3oool;0?oo
o`008@3oool2000003T0oooo0`00003o0?ooo`X0oooo000Q0?ooo`030000003oool0oooo03T0oooo
1000003o0?ooo`P0oooo000Q0?ooo`030000003oool0oooo03X0oooo1000003o0?ooo`L0oooo000Q
0?ooo`030000003oool0oooo03`0oooo0`00003o0?ooo`H0oooo000Q0?ooo`030000003oool0oooo
03d0oooo0`00003o0?ooo`D0oooo000Q0?ooo`030000003oool0oooo03h0oooo0`00003o0?ooo`@0
oooo000Q0?ooo`030000003oool0oooo03l0oooo1000003o0?ooo`80oooo000Q0?ooo`030000003o
ool0oooo0400oooo1000003o0?ooo`40oooo000Q0?ooo`030000003oool0oooo0480oooo0`00003o
0?ooo`008@3oool2000004@0oooo0`00003n0?ooo`008@3oool00`000000oooo0?ooo`140?ooo`<0
0000o@3oool00240oooo00<000000?ooo`3oool0A@3oool300000?`0oooo000Q0?ooo`030000003o
ool0oooo04H0oooo1000003j0?ooo`008@3oool00`000000oooo0?ooo`170?ooo`@00000n@3oool0
0240oooo00<000000?ooo`3oool0B@3oool300000?P0oooo000Q0?ooo`030000003oool0oooo04X0
oooo0`00003g0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80
000000<04A4A0?ooo`3oool00`3oool00`000000oooo0?ooo`1;0?ooo`<00000mP3oool000L0oooo
00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R1`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04`0oooo0`00003e0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0
oooo1@0000050?ooo`030000003oool0oooo04d0oooo0`00003d0?ooo`001`3oool01@000000oooo
0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool000001P3oool3000004h0oooo0`00003c0?oo
o`001`3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0gMgM05EEE@3oool000001P3oool0
0`000000oooo0?ooo`1?0?ooo`<00000lP3oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<
0?ooo`0307MgM`3<c<`0000000H0oooo00<000000?ooo`3oool0D03oool300000?40oooo00070?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`3^k^h0A4A4000000060?ooo`030000003oool0
oooo0540oooo0`00003`0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00d0oooo00<0MgMg
0000003oool01@3oool00`000000oooo0?ooo`1B0?ooo`<00000k`3oool00240oooo00<000000?oo
o`3oool0D`3oool400000>d0oooo000Q0?ooo`030000003oool0oooo05@0oooo1000003/0?ooo`00
8@3oool00`000000oooo0?ooo`1F0?ooo`<00000j`3oool00240oooo00<000000?ooo`3oool0E`3o
ool300000>X0oooo000Q0?ooo`800000F@3oool300000>T0oooo000Q0?ooo`030000003oool0oooo
05T0oooo0`00003X0?ooo`008@3oool00`000000oooo0?ooo`1J0?ooo`<00000i`3oool00240oooo
00<000000?ooo`3oool0F`3oool300000>H0oooo000Q0?ooo`030000003oool0oooo05`0oooo0`00
003U0?ooo`008@3oool00`000000oooo0?ooo`1M0?ooo`<00000i03oool00240oooo00<000000?oo
o`3oool0GP3oool300000><0oooo000Q0?ooo`030000003oool0oooo05l0oooo1000003Q0?ooo`00
8@3oool00`000000oooo0?ooo`1P0?ooo`@00000h03oool00240oooo0P00001S0?ooo`<00000g`3o
ool00240oooo00<000000?ooo`3oool0H`3oool300000=h0oooo000Q0?ooo`030000003oool0oooo
06@0oooo0`00003M0?ooo`008@3oool00`000000oooo0?ooo`1U0?ooo`<00000g03oool00240oooo
00<000000?ooo`3oool0IP3oool300000=/0oooo000Q0?ooo`030000003oool0oooo06L0oooo0`00
003J0?ooo`008@3oool00`000000oooo0?ooo`1X0?ooo`<00000f@3oool00240oooo00<000000?oo
o`3oool0J@3oool300000=P0oooo000Q0?ooo`030000003oool0oooo06X0oooo0`00003G0?ooo`00
8@3oool2000006`0oooo1000003E0?ooo`008@3oool00`000000oooo0?ooo`1/0?ooo`@00000e03o
ool00240oooo00<000000?ooo`3oool0KP3oool300000=<0oooo000Q0?ooo`030000003oool0oooo
06l0oooo0`00003B0?ooo`008@3oool00`000000oooo0?ooo`1`0?ooo`<00000d@3oool00240oooo
00<000000?ooo`3oool0L@3oool300000=00oooo000Q0?ooo`030000003oool0oooo0780oooo0`00
003?0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`01@3oool00`000000oooo0?ooo`1c0?ooo`<00000cP3oool000L0oooo00D0
MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@1EEED0MgMg0?ooo`2IVIT08R8R00D0
oooo00<000000?ooo`3oool0M03oool300000<d0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A
4A402`3oool01@000000oooo0?ooo`3oool0000000D0oooo0`00001e0?ooo`<00000c03oool000L0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000002IVIT0oooo09VIV@0R8R801@3oool0
0`000000oooo0?ooo`1f0?ooo`<00000b`3oool000L0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`050000001EEED00000014A4@3<c<`01@3oool00`000000oooo0?ooo`1g0?ooo`<00000bP3o
ool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`0305EEE@28R8P0oooo00L0oooo00<0
00000?ooo`3oool0N03oool400000<P0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3o
ool00`3MgMd04A4A09VIV@070?ooo`030000003oool0oooo07T0oooo100000370?ooo`001`3oool0
1@3^k^h0<c<c0000000c<c<0k^k^00`0oooo00@0c<c<04A4A00000004A4A1@3oool00`000000oooo
0?ooo`1k0?ooo`<00000aP3oool00240oooo00<000000?ooo`3oool0O03oool300000<D0oooo000Q
0?ooo`030000003oool0oooo07d0oooo0`0000340?ooo`008@3oool00`000000oooo0?ooo`1n0?oo
o`<00000``3oool00240oooo00<000000?ooo`3oool0O`3oool300000<80oooo000Q0?ooo`800000
P@3oool300000<40oooo000Q0?ooo`030000003oool0oooo0840oooo0`0000300?ooo`008@3oool0
0`000000oooo0?ooo`220?ooo`<00000_`3oool00240oooo00<000000?ooo`3oool0P`3oool30000
0;h0oooo000Q0?ooo`030000003oool0oooo08@0oooo0`00002m0?ooo`008@3oool00`000000oooo
0?ooo`250?ooo`<00000_03oool00240oooo00<000000?ooo`3oool0QP3oool300000;/0oooo000Q
0?ooo`030000003oool0oooo08L0oooo0`00002j0?ooo`008@3oool00`000000oooo0?ooo`280?oo
o`<00000^@3oool00240oooo0P00002:0?ooo`<00000^03oool00240oooo00<000000?ooo`3oool0
RP3oool400000;H0oooo000Q0?ooo`030000003oool0oooo08/0oooo1000002e0?ooo`008@3oool0
0`000000oooo0?ooo`2=0?ooo`<00000]03oool00240oooo00<000000?ooo`3oool0SP3oool30000
0;<0oooo000Q0?ooo`030000003oool0oooo08l0oooo0`00002b0?ooo`008@3oool00`000000oooo
0?ooo`2@0?ooo`D00000[`3oool00240oooo00<000000?ooo`3oool0T@3oool700000:`0oooo000Q
0?ooo`030000003oool0oooo09@0oooo1`00002Y0?ooo`008@3oool2000009P0oooo1`00002V0?oo
o`008@3oool00`000000oooo0?ooo`2J0?ooo`L00000X`3oool00240oooo00<000000?ooo`3oool0
W@3oool700000:00oooo000Q0?ooo`030000003oool0oooo0:00oooo1`00002M0?ooo`008@3oool0
0`000000oooo0?ooo`2S0?ooo`L00000VP3oool00240oooo00<000000?ooo`3oool0YP3oool70000
09L0oooo000Q0?ooo`030000003oool0oooo0:T0oooo1`00002D0?ooo`001`3oool01@3^k^h0<c<c
0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050<c<c00R8R800000028R8P3<c<`01@3oool00`00
0000oooo0?ooo`2/0?ooo`L00000T@3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?oo
o`808R8R103oool01@0R8R80VIVI0?ooo`2IVIT08R8R00D0oooo00<000000?ooo`3oool0[`3oool7
000008h0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3o
ool0000000D0oooo0`00002b0?ooo`P00000RP3oool000L0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`0503<c<`2IVIT0oooo09VIV@0c<c<01@3oool00`000000oooo0?ooo`2e0?ooo`P00000
Q`3oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050<c<c000000000000000003<
c<`01@3oool00`000000oooo0?ooo`2i0?ooo`L00000Q03oool000L0oooo00D04A4A0?ooo`3oool0
oooo014A4@0;0?ooo`05014A4@2k^k/0oooo0;^k^`0A4A401@3oool00`000000oooo0?ooo`2l0?oo
o`L00000P@3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo
0;^k^`0000001@3oool00`000000oooo0?ooo`2o0?ooo`L00000OP3oool000L0oooo00D0k^k^03<c
<`000000<c<c0>k^kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX01@3oool00`000000oooo0?oo
o`320?ooo`L00000N`3oool00240oooo00<000000?ooo`3oool0a@3oool7000007P0oooo000Q0?oo
o`030000003oool0oooo0<P0oooo1`00001e0?ooo`008@3oool00`000000oooo0?ooo`3;0?ooo`P0
0000L@3oool00240oooo0P00003?0?ooo`P00000KP3oool00240oooo00<000000?ooo`3oool0dP3o
ool7000006/0oooo000Q0?ooo`030000003oool0oooo0=D0oooo1`00001X0?ooo`008@3oool00`00
0000oooo0?ooo`3H0?ooo`P00000I03oool00240oooo00<000000?ooo`3oool0f`3oool800000640
oooo000Q0?ooo`030000003oool0oooo0=l0oooo1`00001N0?ooo`008@3oool00`000000oooo0?oo
o`3R0?ooo`L00000F`3oool00240oooo00<000000?ooo`3oool0i@3oool7000005P0oooo000Q0?oo
o`030000003oool0oooo0>P0oooo1`00001E0?ooo`008@3oool00`000000oooo0?ooo`3[0?ooo`L0
0000DP3oool00240oooo0P00003_0?ooo`L00000C`3oool00240oooo00<000000?ooo`3oool0l@3o
ool7000004`0oooo000Q0?ooo`030000003oool0oooo0?@0oooo1`0000190?ooo`008@3oool00`00
0000oooo0?ooo`3g0?ooo`L00000AP3oool00240oooo00<000000?ooo`3oool0nP3oool7000004<0
oooo000Q0?ooo`030000003oool0oooo0?d0oooo1`0000100?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooo`40oooo1`00000m0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo1`00000j
0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo1`00000g0?ooo`008@3oool200000?l0
oooo2`3oool6000003D0oooo000Q0?ooo`030000003oool0oooo0?l0oooo3@3oool600000380oooo
000Q0?ooo`030000003oool0oooo0?l0oooo3`3oool7000002l0oooo000Q0?ooo`030000003oool0
oooo0?l0oooo4P3oool6000002d0oooo000Q0?ooo`030000003oool0oooo0?l0oooo5@3oool60000
02X0oooo000Q0?ooo`030000003oool0oooo0?l0oooo5`3oool7000002L0oooo000Q0?ooo`030000
003oool0oooo0?l0oooo6P3oool7000002@0oooo000H0?ooo`@0000000<04A4A0?ooo`3oool00P3o
ool00`000000oooo0?ooo`3o0?oooad0oooo1`00000Q0?ooo`006P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0?l0oooo803oool7000001h0oooo000J0?ooo`030000003oool0oooo
00@0oooo0`00003o0?ooob<0oooo1P00000L0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooobd0
oooo0`00000L0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003o
ool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00603oool205EE
E@030000003oool0oooo0?l0ooooC03oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3o
ool009X0oooo00D0VIVI000000000000A4A40;^k^`0H0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0
1@3oool2028R8P@0oooo00D0VIVI014A4@000000<c<c0<c<c0030?ooo`050>k^kP0c<c<00000014A
4@3<c<`0U03oool009X0oooo00D04A4A0;^k^`3^k^h0MgMg014A4@090?ooo`H000002@3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05014A4@2k^k/0oooo07MgM`0c<c<00`3o
ool01@1EEED0MgMg0?ooo`2IVIT08R8R09@0oooo002J0?ooo`030000003oool0oooo01X0oooo00D0
4A4A0?ooo`3oool0oooo014A4@0?0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`2B0?ooo`007`3oool01@0A4A4000000000000000004A4A07H0oooo00<000000?ooo`3o
ool02`3oool6000000T0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030:ZZZP0A4A40oooo
0080oooo00D0000009VIV@3oool0VIVI028R8P2D0?ooo`008@3oool00`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo01X0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`03014A4@000000
^k^k00<0oooo00D0000005EEE@0000004A4A0<c<c02D0?ooo`008@3oool00`000000oooo0?ooo`1d
0?ooo`03014A4@000000000000<000006@3oool01@0A4A40oooo0?ooo`3oool04A4A00h0oooo00<0
^k^k028R8P3oool00P3oool00`1EEED0R8R80?ooo`2F0?ooo`008@3oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo01X0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`05014A4@2I
VIT0oooo0;^k^`0000000`3oool00`3MgMd04A4A09VIV@2F0?ooo`008@3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo01X0oooo00D0k^k^03<c<`000000<c<c0>k^kP0;0?ooo`050:ZZ
ZP0A4A400000014A4@2ZZZX0103oool0103<c<`0A4A40000000A4A6D0?ooo`007P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0oooo@P3oool001h0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`3o0?oood80oooo000N0?ooo`L00000o`3ooom40?ooo`00
o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.38) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .03652 L
.08481 .07637 L
.12636 .11383 L
.16632 .14991 L
.20885 .18839 L
.2498 .22552 L
.29331 .26509 L
.33524 .30334 L
.37557 .34026 L
.41848 .37967 L
.4598 .41776 L
.48055 .43694 L
.48962 .44534 L
.49442 .44979 L
.49705 .45222 L
.49834 .45342 L
.49953 .45452 L
.50089 .45524 L
.50161 .45546 L
.50237 .45569 L
.50495 .45649 L
.50998 .45805 L
.51991 .46113 L
.54183 .46796 L
.5817 .48049 L
.62415 .49397 L
.665 .50707 L
.70843 .52114 L
.75027 .53481 L
.79051 .54806 L
.83333 .56225 L
.87456 .57598 L
.9142 .58924 L
.95642 .6034 L
.99704 .61704 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`@00000>03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`00
00000P00003o0?oood<0oooo000Q0?ooo`030000003oool0oooo00<00000o`3ooom20?ooo`008@3o
ool010000000oooo0?ooo`3oool300000?l0oooo@@3oool00240oooo00<000000?ooo`3oool00P3o
ool300000?l0oooo@03oool00240oooo00<000000?ooo`3oool00`3oool300000?l0oooo?`3oool0
0240oooo00<000000?ooo`3oool0103oool300000?l0oooo?P3oool00240oooo0P0000060?ooo`<0
0000o`3ooolm0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`<00000o`3oooll0?ooo`008@3o
ool00`000000oooo0?ooo`070?ooo`@00000o`3ooolj0?ooo`008@3oool00`000000oooo0?ooo`08
0?ooo`@00000o`3oooli0?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`<00000o`3ooolh0?oo
o`008@3oool00`000000oooo0?ooo`0;0?ooo`<00000o`3ooolg0?ooo`008@3oool00`000000oooo
0?ooo`0<0?ooo`<00000o`3ooolf0?ooo`008@3oool00`000000oooo0?ooo`0=0?ooo`<00000o`3o
oole0?ooo`008@3oool00`000000oooo0?ooo`0>0?ooo`@00000o`3ooolc0?ooo`008@3oool20000
0100oooo1000003o0?oooc80oooo000Q0?ooo`030000003oool0oooo0140oooo0`00003o0?oooc40
oooo000Q0?ooo`030000003oool0oooo0180oooo0`00003o0?oooc00oooo000Q0?ooo`030000003o
ool0oooo01<0oooo0`00003o0?ooobl0oooo000Q0?ooo`030000003oool0oooo01@0oooo0`00003o
0?ooobh0oooo000Q0?ooo`030000003oool0oooo01D0oooo1000003o0?ooob`0oooo000Q0?ooo`03
0000003oool0oooo01H0oooo1000003o0?ooob/0oooo000Q0?ooo`030000003oool0oooo01P0oooo
0`00003o0?ooobX0oooo000Q0?ooo`030000003oool0oooo01T0oooo0`00003o0?ooobT0oooo000Q
0?ooo`030000003oool0oooo01X0oooo0`00003o0?ooobP0oooo000Q0?ooo`800000703oool30000
0?l0oooo9`3oool00240oooo00<000000?ooo`3oool0703oool300000?l0oooo9P3oool00240oooo
00<000000?ooo`3oool07@3oool300000?l0oooo9@3oool00240oooo00<000000?ooo`3oool07P3o
ool300000?l0oooo903oool00240oooo00<000000?ooo`3oool07`3oool300000?l0oooo8`3oool0
0240oooo00<000000?ooo`3oool0803oool300000?l0oooo8P3oool000L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R103oool5000000D0oooo00<000000?ooo`3oool08@3oool40000
0?l0oooo803oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@2I
VIT08R8R0>k^kP3oool0A4A400D0oooo00<000000?ooo`3oool08P3oool400000?l0oooo7`3oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^00H0oooo00<00000
0?ooo`3oool0903oool300000?l0oooo7P3oool000L0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`0309VIV@0R8R80k^k^00D0oooo0`00000U0?ooo`<00000o`3ooolM0?ooo`001`3oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<0MgMg06IVIP3oool0103oool00`000000oooo0?ooo`0V
0?ooo`<00000o`3ooolL0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00l0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`<00000o`3ooolK0?ooo`001`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@050?ooo`030000003o
ool0oooo02P0oooo0`00003o0?oooaX0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3o
ool01@2IVIT04A4A0000000R8R80c<c<00D0oooo00<000000?ooo`3oool0:@3oool300000?l0oooo
6@3oool00240oooo00<000000?ooo`3oool0:P3oool300000?l0oooo603oool00240oooo00<00000
0?ooo`3oool0:`3oool300000?l0oooo5`3oool00240oooo00<000000?ooo`3oool0;03oool30000
0?l0oooo5P3oool00240oooo00<000000?ooo`3oool0;@3oool400000?l0oooo503oool00240oooo
0P00000_0?ooo`@00000o`3ooolC0?ooo`008@3oool00`000000oooo0?ooo`0`0?ooo`<00000o`3o
oolB0?ooo`008@3oool00`000000oooo0?ooo`0a0?ooo`<00000o`3ooolA0?ooo`008@3oool00`00
0000oooo0?ooo`0b0?ooo`<00000o`3oool@0?ooo`008@3oool00`000000oooo0?ooo`0c0?ooo`<0
0000o`3oool?0?ooo`008@3oool00`000000oooo0?ooo`0d0?ooo`<00000o`3oool>0?ooo`008@3o
ool00`000000oooo0?ooo`0e0?ooo`<00000o`3oool=0?ooo`008@3oool00`000000oooo0?ooo`0f
0?ooo`<00000o`3oool<0?ooo`008@3oool00`000000oooo0?ooo`0g0?ooo`<00000o`3oool;0?oo
o`008@3oool2000003T0oooo0`00003o0?ooo`X0oooo000Q0?ooo`030000003oool0oooo03T0oooo
1000003o0?ooo`P0oooo000Q0?ooo`030000003oool0oooo03X0oooo1000003o0?ooo`L0oooo000Q
0?ooo`030000003oool0oooo03`0oooo0`00003o0?ooo`H0oooo000Q0?ooo`030000003oool0oooo
03d0oooo0`00003o0?ooo`D0oooo000Q0?ooo`030000003oool0oooo03h0oooo0`00003o0?ooo`@0
oooo000Q0?ooo`030000003oool0oooo03l0oooo1000003o0?ooo`80oooo000Q0?ooo`030000003o
ool0oooo0400oooo1000003o0?ooo`40oooo000Q0?ooo`030000003oool0oooo0480oooo0`00003o
0?ooo`008@3oool2000004@0oooo0`00003n0?ooo`008@3oool00`000000oooo0?ooo`140?ooo`<0
0000o@3oool00240oooo00<000000?ooo`3oool0A@3oool300000?`0oooo000Q0?ooo`030000003o
ool0oooo04H0oooo1000003j0?ooo`008@3oool00`000000oooo0?ooo`170?ooo`@00000n@3oool0
0240oooo00<000000?ooo`3oool0B@3oool300000?P0oooo000Q0?ooo`030000003oool0oooo04X0
oooo0`00003g0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80
000000<04A4A0?ooo`3oool00`3oool00`000000oooo0?ooo`1;0?ooo`<00000mP3oool000L0oooo
00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R1`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04`0oooo0`00003e0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0
oooo1@0000050?ooo`030000003oool0oooo04d0oooo0`00003d0?ooo`001`3oool01@000000oooo
0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool000001P3oool3000004h0oooo0`00003c0?oo
o`001`3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0gMgM05EEE@3oool000001P3oool0
0`000000oooo0?ooo`1?0?ooo`<00000lP3oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<
0?ooo`0307MgM`3<c<`0000000H0oooo00<000000?ooo`3oool0D03oool300000?40oooo00070?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`3^k^h0A4A4000000060?ooo`030000003oool0
oooo0540oooo0`00003`0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00d0oooo00<0MgMg
0000003oool01@3oool00`000000oooo0?ooo`1B0?ooo`<00000k`3oool00240oooo00<000000?oo
o`3oool0D`3oool400000>d0oooo000Q0?ooo`030000003oool0oooo05@0oooo1000003/0?ooo`00
8@3oool00`000000oooo0?ooo`1F0?ooo`<00000j`3oool00240oooo00<000000?ooo`3oool0E`3o
ool300000>X0oooo000Q0?ooo`800000F@3oool300000>T0oooo000Q0?ooo`030000003oool0oooo
05T0oooo0`00003X0?ooo`008@3oool00`000000oooo0?ooo`1J0?ooo`<00000i`3oool00240oooo
00<000000?ooo`3oool0F`3oool300000>H0oooo000Q0?ooo`030000003oool0oooo05`0oooo0`00
003U0?ooo`008@3oool00`000000oooo0?ooo`1M0?ooo`<00000i03oool00240oooo00<000000?oo
o`3oool0GP3oool300000><0oooo000Q0?ooo`030000003oool0oooo05l0oooo1000003Q0?ooo`00
8@3oool00`000000oooo0?ooo`1P0?ooo`@00000h03oool00240oooo0P00001S0?ooo`<00000g`3o
ool00240oooo00<000000?ooo`3oool0H`3oool300000=h0oooo000Q0?ooo`030000003oool0oooo
06@0oooo0`00003M0?ooo`008@3oool00`000000oooo0?ooo`1U0?ooo`<00000g03oool00240oooo
00<000000?ooo`3oool0IP3oool300000=/0oooo000Q0?ooo`030000003oool0oooo06L0oooo0`00
003J0?ooo`008@3oool00`000000oooo0?ooo`1X0?ooo`<00000f@3oool00240oooo00<000000?oo
o`3oool0J@3oool300000=P0oooo000Q0?ooo`030000003oool0oooo06X0oooo0`00003G0?ooo`00
8@3oool2000006`0oooo1000003E0?ooo`008@3oool00`000000oooo0?ooo`1/0?ooo`@00000e03o
ool00240oooo00<000000?ooo`3oool0KP3oool300000=<0oooo000Q0?ooo`030000003oool0oooo
06l0oooo0`00003B0?ooo`008@3oool00`000000oooo0?ooo`1`0?ooo`<00000d@3oool00240oooo
00<000000?ooo`3oool0L@3oool300000=00oooo000Q0?ooo`030000003oool0oooo0780oooo0`00
003?0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`01@3oool00`000000oooo0?ooo`1c0?ooo`<00000cP3oool000L0oooo00D0
MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@1EEED0MgMg0?ooo`2IVIT08R8R00D0
oooo00<000000?ooo`3oool0M03oool300000<d0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A
4A402`3oool01@000000oooo0?ooo`3oool0000000D0oooo0`00001e0?ooo`<00000c03oool000L0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000002IVIT0oooo09VIV@0R8R801@3oool0
0`000000oooo0?ooo`1f0?ooo`<00000b`3oool000L0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`050000001EEED00000014A4@3<c<`01@3oool00`000000oooo0?ooo`1g0?ooo`<00000bP3o
ool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`0305EEE@28R8P0oooo00L0oooo00<0
00000?ooo`3oool0N03oool400000<P0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3o
ool00`3MgMd04A4A09VIV@070?ooo`030000003oool0oooo07T0oooo100000370?ooo`001`3oool0
1@3^k^h0<c<c0000000c<c<0k^k^00`0oooo00@0c<c<04A4A00000004A4A1@3oool00`000000oooo
0?ooo`1k0?ooo`<00000aP3oool00240oooo00<000000?ooo`3oool0O03oool300000<D0oooo000Q
0?ooo`030000003oool0oooo07d0oooo0`0000340?ooo`008@3oool00`000000oooo0?ooo`1n0?oo
o`<00000``3oool00240oooo00<000000?ooo`3oool0O`3oool300000<80oooo000Q0?ooo`800000
P@3oool300000<40oooo000Q0?ooo`030000003oool0oooo0840oooo0`0000300?ooo`008@3oool0
0`000000oooo0?ooo`220?ooo`<00000_`3oool00240oooo00<000000?ooo`3oool0P`3oool30000
0;h0oooo000Q0?ooo`030000003oool0oooo08@0oooo0`00002m0?ooo`008@3oool00`000000oooo
0?ooo`250?ooo`<00000_03oool00240oooo00<000000?ooo`3oool0QP3oool300000;/0oooo000Q
0?ooo`030000003oool0oooo08L0oooo0`00002j0?ooo`008@3oool00`000000oooo0?ooo`280?oo
o`<00000^@3oool00240oooo0P00002:0?ooo`<00000^03oool00240oooo00<000000?ooo`3oool0
RP3oool300000;L0oooo000Q0?ooo`030000003oool0oooo08/0oooo0`00002f0?ooo`008@3oool0
0`000000oooo0?ooo`2<0?ooo`<00000]@3oool00240oooo00<000000?ooo`3oool0S@3oool30000
0;@0oooo000Q0?ooo`030000003oool0oooo08h0oooo0`00002c0?ooo`008@3oool00`000000oooo
0?ooo`2?0?ooo`@00000/@3oool00240oooo00<000000?ooo`3oool0T03oool800000:`0oooo000Q
0?ooo`030000003oool0oooo0940oooo2P00002Y0?ooo`008@3oool2000009P0oooo1`00002V0?oo
o`008@3oool00`000000oooo0?ooo`2J0?ooo`L00000X`3oool00240oooo00<000000?ooo`3oool0
W@3oool700000:00oooo000Q0?ooo`030000003oool0oooo0:00oooo1`00002M0?ooo`008@3oool0
0`000000oooo0?ooo`2S0?ooo`L00000VP3oool00240oooo00<000000?ooo`3oool0YP3oool70000
09L0oooo000Q0?ooo`030000003oool0oooo0:T0oooo1`00002D0?ooo`001`3oool01@3^k^h0<c<c
0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050<c<c00R8R800000028R8P3<c<`01@3oool00`00
0000oooo0?ooo`2/0?ooo`L00000T@3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?oo
o`808R8R103oool01@0R8R80VIVI0?ooo`2IVIT08R8R00D0oooo00<000000?ooo`3oool0[`3oool7
000008h0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3o
ool0000000D0oooo0`00002b0?ooo`P00000RP3oool000L0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`0503<c<`2IVIT0oooo09VIV@0c<c<01@3oool00`000000oooo0?ooo`2e0?ooo`P00000
Q`3oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050<c<c000000000000000003<
c<`01@3oool00`000000oooo0?ooo`2i0?ooo`L00000Q03oool000L0oooo00D04A4A0?ooo`3oool0
oooo014A4@0;0?ooo`05014A4@2k^k/0oooo0;^k^`0A4A401@3oool00`000000oooo0?ooo`2l0?oo
o`L00000P@3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo
0;^k^`0000001@3oool00`000000oooo0?ooo`2o0?ooo`L00000OP3oool000L0oooo00D0k^k^03<c
<`000000<c<c0>k^kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX01@3oool00`000000oooo0?oo
o`320?ooo`L00000N`3oool00240oooo00<000000?ooo`3oool0a@3oool7000007P0oooo000Q0?oo
o`030000003oool0oooo0<P0oooo1`00001e0?ooo`008@3oool00`000000oooo0?ooo`3;0?ooo`P0
0000L@3oool00240oooo0P00003?0?ooo`P00000KP3oool00240oooo00<000000?ooo`3oool0dP3o
ool7000006/0oooo000Q0?ooo`030000003oool0oooo0=D0oooo1`00001X0?ooo`008@3oool00`00
0000oooo0?ooo`3H0?ooo`P00000I03oool00240oooo00<000000?ooo`3oool0f`3oool800000640
oooo000Q0?ooo`030000003oool0oooo0=l0oooo1`00001N0?ooo`008@3oool00`000000oooo0?oo
o`3R0?ooo`L00000F`3oool00240oooo00<000000?ooo`3oool0i@3oool7000005P0oooo000Q0?oo
o`030000003oool0oooo0>P0oooo1`00001E0?ooo`008@3oool00`000000oooo0?ooo`3[0?ooo`L0
0000DP3oool00240oooo0P00003_0?ooo`L00000C`3oool00240oooo00<000000?ooo`3oool0l@3o
ool6000004d0oooo000Q0?ooo`030000003oool0oooo0?@0oooo1P00001:0?ooo`008@3oool00`00
0000oooo0?ooo`3f0?ooo`L00000A`3oool00240oooo00<000000?ooo`3oool0n@3oool6000004D0
oooo000Q0?ooo`030000003oool0oooo0?`0oooo1P0000120?ooo`008@3oool00`000000oooo0?oo
o`3n0?ooo`L00000?`3oool00240oooo00<000000?ooo`3oool0o`3oool20?ooo`P00000>`3oool0
0240oooo00<000000?ooo`3oool0o`3oool50?ooo`P00000>03oool00240oooo0P00003o0?ooo`X0
oooo1`00000e0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo``0oooo1`00000b0?ooo`008@3o
ool00`000000oooo0?ooo`3o0?ooo`l0oooo1`00000_0?ooo`008@3oool00`000000oooo0?ooo`3o
0?oooa80oooo1P00000]0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooaD0oooo1P00000Z0?oo
o`008@3oool00`000000oooo0?ooo`3o0?oooaL0oooo1`00000W0?ooo`008@3oool00`000000oooo
0?ooo`3o0?oooaX0oooo1`00000T0?ooo`00603oool400000003014A4@3oool0oooo0080oooo00<0
00000?ooo`3oool0o`3ooolM0?ooo`L000008@3oool001X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?ooob00oooo1`00000N0?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`<00000o`3ooolS0?ooo`H00000703oool001X0oooo00<000000?ooo`3oool0o`3oool]0?ooo`<0
0000703oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001P0oooo0P1EEED00`00
0000oooo0?ooo`3o0?oood`0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo002J
0?ooo`0509VIV@000000000004A4A02k^k/0603oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo
0P0R8R840?ooo`0509VIV@0A4A40000003<c<`3<c<`00`3oool01@3<c<`08R8R0000000R8R80c<c<
09@0oooo002J0?ooo`05014A4@2k^k/0k^k^07MgM`0A4A402@3oool6000000T0oooo00D0MgMg09VI
V@3oool0VIVI07MgM`050?ooo`808R8R103oool01@0A4A40^k^k0?ooo`1gMgL0<c<c00<0oooo00D0
8R8R09VIV@3oool0VIVI028R8P2D0?ooo`00VP3oool00`000000oooo0?ooo`0J0?ooo`05014A4@3o
ool0oooo0?ooo`0A4A403`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool0TP3oool001l0oooo00D04A4A0000000000000000014A4@1f0?ooo`030000003oool0oooo00/0
oooo1P0000090?ooo`050000003oool0oooo0?ooo`0000003P3oool00`2ZZZX04A4A0?ooo`020?oo
o`0503<c<`2IVIT0oooo09VIV@0c<c<0U03oool00240oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`0A4A4000000;^k^`03
0?ooo`050<c<c000000000000000003<c<`0U03oool00240oooo00<000000?ooo`3oool0M03oool0
0`0A4A40000000000003000001T0oooo00D04A4A0?ooo`3oool0oooo014A4@0>0?ooo`030;^k^`0R
8R80oooo0080oooo00D04A4A0;^k^`3oool0^k^k014A4@2D0?ooo`008@3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo01X0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`05014A
4@2IVIT0oooo0;^k^`0000000`3oool01@000000^k^k0?ooo`2k^k/0000009@0oooo000Q0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool06P3oool01@3^k^h0<c<c0000000c<c<0k^k^
00/0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP030?ooo`050:ZZZP0A4A400000014A4@2ZZZX0U03o
ool001h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oood80oooo000N
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooom20?ooo`007P3oool7
00000?l0ooooA03oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
0 0 m
.04057 .03671 L
.08481 .07677 L
.12636 .11442 L
.16632 .15068 L
.20885 .18933 L
.2498 .2266 L
.29331 .26632 L
.33524 .30467 L
.37557 .34167 L
.41848 .38115 L
.4598 .41928 L
.48055 .43847 L
.48962 .44688 L
.49442 .45132 L
.49705 .45376 L
.49834 .45496 L
.49953 .45606 L
.50089 .45677 L
.50161 .45699 L
.50237 .45723 L
.50495 .45802 L
.50998 .45958 L
.51991 .46266 L
.54183 .46948 L
.5817 .48197 L
.62415 .49538 L
.665 .50841 L
.70843 .52236 L
.75027 .53589 L
.79051 .549 L
.83333 .56302 L
.87456 .57657 L
.9142 .58965 L
.95642 .60361 L
.99704 .61705 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00DP3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D000009P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool09@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`09P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0<03oool400000003014A4@3oool0oooo01P0oooo001B0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00V
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool09P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R809P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80<P3oool00`000000oooo0?ooo`0J0?ooo`00DP3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h09`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000W0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000000oooo0?ooo`0J0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h09P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
:03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0V0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0380oooo00<0
00000?ooo`3oool06P3oool00580oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`09P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00b0?ooo`030000
003oool0oooo01X0oooo001B0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0T0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000X0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0X0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A0380oooo00<000000?ooo`3oool06P3o
ool00580oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
9P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000:03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0:03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000b0?ooo`030000003oool0oooo01X0oooo001B
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4BH0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0<03oool205EEE@030000003oool0oooo01X0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeL0oooo0P0000020?ooo`800000303oool00?l0
ooooE`3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo003o0?oooeP0oooo00@0gMgM0000
00000000c<c<3@3oool00200ooooo`00000]000000/0oooo00@0k^k^028R8P000000k^k^3@3oool0
0200oooo1000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01@3^
k^h08R8R07MgM`1gMgL0<c<c00d0oooo000Q0?ooo`@00000>03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`800000303oool00240oooo00<000000?ooo`00
00000P00003o0?oood<0oooo000Q0?ooo`030000003oool0oooo00<00000o`3ooom20?ooo`008@3o
ool010000000oooo0?ooo`3oool300000?l0oooo@@3oool00240oooo00<000000?ooo`3oool00P3o
ool300000?l0oooo@03oool00240oooo00<000000?ooo`3oool00`3oool300000?l0oooo?`3oool0
0240oooo00<000000?ooo`3oool0103oool300000?l0oooo?P3oool00240oooo0P0000060?ooo`<0
0000o`3ooolm0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`<00000o`3oooll0?ooo`008@3o
ool00`000000oooo0?ooo`070?ooo`@00000o`3ooolj0?ooo`008@3oool00`000000oooo0?ooo`08
0?ooo`@00000o`3oooli0?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`<00000o`3ooolh0?oo
o`008@3oool00`000000oooo0?ooo`0;0?ooo`<00000o`3ooolg0?ooo`008@3oool00`000000oooo
0?ooo`0<0?ooo`<00000o`3ooolf0?ooo`008@3oool00`000000oooo0?ooo`0=0?ooo`<00000o`3o
oole0?ooo`008@3oool00`000000oooo0?ooo`0>0?ooo`@00000o`3ooolc0?ooo`008@3oool20000
0100oooo1000003o0?oooc80oooo000Q0?ooo`030000003oool0oooo0140oooo0`00003o0?oooc40
oooo000Q0?ooo`030000003oool0oooo0180oooo0`00003o0?oooc00oooo000Q0?ooo`030000003o
ool0oooo01<0oooo0`00003o0?ooobl0oooo000Q0?ooo`030000003oool0oooo01@0oooo0`00003o
0?ooobh0oooo000Q0?ooo`030000003oool0oooo01D0oooo1000003o0?ooob`0oooo000Q0?ooo`03
0000003oool0oooo01H0oooo1000003o0?ooob/0oooo000Q0?ooo`030000003oool0oooo01P0oooo
0`00003o0?ooobX0oooo000Q0?ooo`030000003oool0oooo01T0oooo0`00003o0?ooobT0oooo000Q
0?ooo`030000003oool0oooo01X0oooo0`00003o0?ooobP0oooo000Q0?ooo`800000703oool30000
0?l0oooo9`3oool00240oooo00<000000?ooo`3oool0703oool300000?l0oooo9P3oool00240oooo
00<000000?ooo`3oool07@3oool300000?l0oooo9@3oool00240oooo00<000000?ooo`3oool07P3o
ool300000?l0oooo903oool00240oooo00<000000?ooo`3oool07`3oool300000?l0oooo8`3oool0
0240oooo00<000000?ooo`3oool0803oool300000?l0oooo8P3oool000L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R103oool5000000D0oooo00<000000?ooo`3oool08@3oool40000
0?l0oooo803oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@2I
VIT08R8R0>k^kP3oool0A4A400D0oooo00<000000?ooo`3oool08P3oool400000?l0oooo7`3oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^00H0oooo00<00000
0?ooo`3oool0903oool300000?l0oooo7P3oool000L0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`0309VIV@0R8R80k^k^00D0oooo0`00000U0?ooo`<00000o`3ooolM0?ooo`001`3oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<0MgMg06IVIP3oool0103oool00`000000oooo0?ooo`0V
0?ooo`<00000o`3ooolL0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00l0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`<00000o`3ooolK0?ooo`001`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@050?ooo`030000003o
ool0oooo02P0oooo0`00003o0?oooaX0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3o
ool01@2IVIT04A4A0000000R8R80c<c<00D0oooo00<000000?ooo`3oool0:@3oool300000?l0oooo
6@3oool00240oooo00<000000?ooo`3oool0:P3oool300000?l0oooo603oool00240oooo00<00000
0?ooo`3oool0:`3oool300000?l0oooo5`3oool00240oooo00<000000?ooo`3oool0;03oool30000
0?l0oooo5P3oool00240oooo00<000000?ooo`3oool0;@3oool400000?l0oooo503oool00240oooo
0P00000_0?ooo`@00000o`3ooolC0?ooo`008@3oool00`000000oooo0?ooo`0`0?ooo`<00000o`3o
oolB0?ooo`008@3oool00`000000oooo0?ooo`0a0?ooo`<00000o`3ooolA0?ooo`008@3oool00`00
0000oooo0?ooo`0b0?ooo`<00000o`3oool@0?ooo`008@3oool00`000000oooo0?ooo`0c0?ooo`<0
0000o`3oool?0?ooo`008@3oool00`000000oooo0?ooo`0d0?ooo`<00000o`3oool>0?ooo`008@3o
ool00`000000oooo0?ooo`0e0?ooo`<00000o`3oool=0?ooo`008@3oool00`000000oooo0?ooo`0f
0?ooo`<00000o`3oool<0?ooo`008@3oool00`000000oooo0?ooo`0g0?ooo`<00000o`3oool;0?oo
o`008@3oool2000003T0oooo0`00003o0?ooo`X0oooo000Q0?ooo`030000003oool0oooo03T0oooo
1000003o0?ooo`P0oooo000Q0?ooo`030000003oool0oooo03X0oooo1000003o0?ooo`L0oooo000Q
0?ooo`030000003oool0oooo03`0oooo0`00003o0?ooo`H0oooo000Q0?ooo`030000003oool0oooo
03d0oooo0`00003o0?ooo`D0oooo000Q0?ooo`030000003oool0oooo03h0oooo0`00003o0?ooo`@0
oooo000Q0?ooo`030000003oool0oooo03l0oooo0`00003o0?ooo`<0oooo000Q0?ooo`030000003o
ool0oooo0400oooo0`00003o0?ooo`80oooo000Q0?ooo`030000003oool0oooo0440oooo0`00003o
0?ooo`40oooo000Q0?ooo`800000@`3oool300000?l0oooo000Q0?ooo`030000003oool0oooo04<0
oooo0`00003n0?ooo`008@3oool00`000000oooo0?ooo`140?ooo`<00000o@3oool00240oooo00<0
00000?ooo`3oool0A@3oool300000?`0oooo000Q0?ooo`030000003oool0oooo04H0oooo1000003j
0?ooo`008@3oool00`000000oooo0?ooo`170?ooo`@00000n@3oool00240oooo00<000000?ooo`3o
ool0B@3oool300000?P0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8PH0
oooo0P0000000`0A4A40oooo0?ooo`030?ooo`030000003oool0oooo04X0oooo0`00003g0?ooo`00
1`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R870?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0B`3oool300000?H0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A
4A402`3oool5000000D0oooo00<000000?ooo`3oool0C03oool400000?@0oooo00070?ooo`050000
003oool0oooo0?ooo`0000002`3oool01014A4@0gMgM0?ooo`0000060?ooo`<00000C@3oool40000
0?<0oooo00070?ooo`050000003oool0oooo0?ooo`0000002`3oool0103MgMd0EEEE0?ooo`000006
0?ooo`030000003oool0oooo04l0oooo0`00003b0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0MgMg0<c<c00000001P3oool00`000000oooo0?ooo`1@0?ooo`<00000l@3oool0
00L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`030>k^kP14A4@0000000H0oooo00<00000
0?ooo`3oool0D@3oool300000?00oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h03@3oool0
0`1gMgL000000?ooo`050?ooo`030000003oool0oooo0580oooo0`00003_0?ooo`008@3oool00`00
0000oooo0?ooo`1C0?ooo`<00000kP3oool00240oooo00<000000?ooo`3oool0E03oool300000>d0
oooo000Q0?ooo`030000003oool0oooo05D0oooo0`00003/0?ooo`008@3oool00`000000oooo0?oo
o`1F0?ooo`<00000j`3oool00240oooo0P00001H0?ooo`<00000jP3oool00240oooo00<000000?oo
o`3oool0F03oool300000>T0oooo000Q0?ooo`030000003oool0oooo05T0oooo0`00003X0?ooo`00
8@3oool00`000000oooo0?ooo`1J0?ooo`<00000i`3oool00240oooo00<000000?ooo`3oool0F`3o
ool300000>H0oooo000Q0?ooo`030000003oool0oooo05`0oooo0`00003U0?ooo`008@3oool00`00
0000oooo0?ooo`1M0?ooo`<00000i03oool00240oooo00<000000?ooo`3oool0GP3oool300000><0
oooo000Q0?ooo`030000003oool0oooo05l0oooo1000003Q0?ooo`008@3oool200000640oooo1000
003P0?ooo`008@3oool00`000000oooo0?ooo`1R0?ooo`<00000g`3oool00240oooo00<000000?oo
o`3oool0H`3oool300000=h0oooo000Q0?ooo`030000003oool0oooo06@0oooo0`00003M0?ooo`00
8@3oool00`000000oooo0?ooo`1U0?ooo`<00000g03oool00240oooo00<000000?ooo`3oool0IP3o
ool300000=/0oooo000Q0?ooo`030000003oool0oooo06L0oooo0`00003J0?ooo`008@3oool00`00
0000oooo0?ooo`1X0?ooo`<00000f@3oool00240oooo00<000000?ooo`3oool0J@3oool300000=P0
oooo000Q0?ooo`800000J`3oool300000=L0oooo000Q0?ooo`030000003oool0oooo06/0oooo1000
003E0?ooo`008@3oool00`000000oooo0?ooo`1/0?ooo`@00000e03oool00240oooo00<000000?oo
o`3oool0KP3oool300000=<0oooo000Q0?ooo`030000003oool0oooo06l0oooo0`00003B0?ooo`00
8@3oool00`000000oooo0?ooo`1`0?ooo`<00000d@3oool00240oooo00<000000?ooo`3oool0L@3o
ool300000=00oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo00D0
k^k^03<c<`0000004A4A0<c<c0050?ooo`030000003oool0oooo0780oooo0`00003?0?ooo`001`3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R801@3oool00`000000oooo0?ooo`1c0?ooo`<00000cP3oool000L0oooo00D04A4A0?ooo`3oool0
oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`0000001@3oool3000007@0oooo0`00003=0?oo
o`001`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P05
0?ooo`030000003oool0oooo07D0oooo0`00003<0?ooo`001`3oool01@000000oooo0?ooo`3oool0
000000/0oooo00D0000005EEE@0000004A4A0<c<c0050?ooo`030000003oool0oooo07H0oooo0`00
003;0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo00<0EEEE08R8R03oool01`3o
ool00`000000oooo0?ooo`1g0?ooo`<00000bP3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07Mg
M`0;0?ooo`030=gMg@0A4A40VIVI00L0oooo00<000000?ooo`3oool0N03oool400000<P0oooo0007
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool0103<c<`0A4A40000000A4A450?ooo`030000
003oool0oooo07T0oooo100000370?ooo`008@3oool00`000000oooo0?ooo`1k0?ooo`<00000aP3o
ool00240oooo00<000000?ooo`3oool0O03oool300000<D0oooo000Q0?ooo`030000003oool0oooo
07d0oooo0`0000340?ooo`008@3oool00`000000oooo0?ooo`1n0?ooo`<00000``3oool00240oooo
0P0000200?ooo`<00000`P3oool00240oooo00<000000?ooo`3oool0P03oool300000<40oooo000Q
0?ooo`030000003oool0oooo0840oooo0`0000300?ooo`008@3oool00`000000oooo0?ooo`220?oo
o`<00000_`3oool00240oooo00<000000?ooo`3oool0P`3oool300000;h0oooo000Q0?ooo`030000
003oool0oooo08@0oooo0`00002m0?ooo`008@3oool00`000000oooo0?ooo`250?ooo`<00000_03o
ool00240oooo00<000000?ooo`3oool0QP3oool300000;/0oooo000Q0?ooo`030000003oool0oooo
08L0oooo0`00002j0?ooo`008@3oool2000008T0oooo0`00002i0?ooo`008@3oool00`000000oooo
0?ooo`290?ooo`<00000^03oool00240oooo00<000000?ooo`3oool0RP3oool400000;H0oooo000Q
0?ooo`030000003oool0oooo08/0oooo1000002e0?ooo`008@3oool00`000000oooo0?ooo`2=0?oo
o`<00000]03oool00240oooo00<000000?ooo`3oool0SP3oool300000;<0oooo000Q0?ooo`030000
003oool0oooo08l0oooo0`00002b0?ooo`008@3oool00`000000oooo0?ooo`2@0?ooo`D00000[`3o
ool00240oooo00<000000?ooo`3oool0T@3oool700000:`0oooo000Q0?ooo`800000U@3oool70000
0:T0oooo000Q0?ooo`030000003oool0oooo09L0oooo1`00002V0?ooo`008@3oool00`000000oooo
0?ooo`2J0?ooo`L00000X`3oool00240oooo00<000000?ooo`3oool0W@3oool700000:00oooo000Q
0?ooo`030000003oool0oooo0:00oooo1`00002M0?ooo`008@3oool00`000000oooo0?ooo`2S0?oo
o`L00000VP3oool00240oooo00<000000?ooo`3oool0YP3oool7000009L0oooo00070?ooo`050>k^
kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo00D0c<c<028R8P0000008R8R0<c<c0050?oo
o`030000003oool0oooo0:T0oooo1`00002D0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo09VIV@0R8R801@3oool00`000000oooo0?ooo`2/
0?ooo`L00000T@3oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0
oooo0?ooo`0000001@3oool300000:l0oooo1`00002>0?ooo`001`3oool01@000000oooo0?ooo`3o
ool0000000/0oooo00D0<c<c09VIV@3oool0VIVI03<c<`050?ooo`030000003oool0oooo0;80oooo
2000002:0?ooo`001`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<000000000000
00000<c<c0050?ooo`030000003oool0oooo0;D0oooo2@0000260?ooo`001`3oool01@0A4A40oooo
0?ooo`3oool04A4A00/0oooo00D04A4A0;^k^`3oool0^k^k014A4@050?ooo`030000003oool0oooo
0;T0oooo2@0000220?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k
^`3oool0^k^k000000050?ooo`030000003oool0oooo0;d0oooo2000001o0?ooo`001`3oool01@3^
k^h0<c<c0000000c<c<0k^k^00/0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP050?ooo`030000003o
ool0oooo0<40oooo1`00001l0?ooo`008@3oool00`000000oooo0?ooo`340?ooo`L00000N@3oool0
0240oooo00<000000?ooo`3oool0a`3oool6000007L0oooo000Q0?ooo`030000003oool0oooo0<X0
oooo1P00001d0?ooo`008@3oool200000<d0oooo1`00001a0?ooo`008@3oool00`000000oooo0?oo
o`3?0?ooo`L00000KP3oool00240oooo00<000000?ooo`3oool0dP3oool7000006/0oooo000Q0?oo
o`030000003oool0oooo0=D0oooo1`00001X0?ooo`008@3oool00`000000oooo0?ooo`3H0?ooo`P0
0000I03oool00240oooo00<000000?ooo`3oool0f`3oool800000640oooo000Q0?ooo`030000003o
ool0oooo0=l0oooo1`00001N0?ooo`008@3oool00`000000oooo0?ooo`3R0?ooo`L00000F`3oool0
0240oooo00<000000?ooo`3oool0i@3oool7000005P0oooo000Q0?ooo`030000003oool0oooo0>P0
oooo1`00001E0?ooo`008@3oool200000>`0oooo1`00001B0?ooo`008@3oool00`000000oooo0?oo
o`3^0?ooo`L00000C`3oool00240oooo00<000000?ooo`3oool0l@3oool7000004`0oooo000Q0?oo
o`030000003oool0oooo0?@0oooo1`0000190?ooo`008@3oool00`000000oooo0?ooo`3g0?ooo`L0
0000AP3oool00240oooo00<000000?ooo`3oool0nP3oool7000004<0oooo000Q0?ooo`030000003o
ool0oooo0?d0oooo1`0000100?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`40oooo1`00000m
0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo1`00000j0?ooo`008@3oool200000?l0
oooo203oool7000003L0oooo000Q0?ooo`030000003oool0oooo0?l0oooo2P3oool7000003@0oooo
000Q0?ooo`030000003oool0oooo0?l0oooo3@3oool700000340oooo000Q0?ooo`030000003oool0
oooo0?l0oooo403oool7000002h0oooo000Q0?ooo`030000003oool0oooo0?l0oooo4`3oool70000
02/0oooo000Q0?ooo`030000003oool0oooo0?l0oooo5P3oool8000002L0oooo000Q0?ooo`030000
003oool0oooo0?l0oooo6@3oool8000002@0oooo000H0?ooo`@0000000<04A4A0?ooo`3oool00P3o
ool00`000000oooo0?ooo`3o0?oooad0oooo1`00000Q0?ooo`006P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0?l0oooo803oool7000001h0oooo000J0?ooo`030000003oool0oooo
00@0oooo0`00003o0?ooob<0oooo1P00000L0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooobd0
oooo0`00000L0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003o
ool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00603oool205EE
E@030000003oool0oooo0?l0ooooC03oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3o
ool009h0oooo00D0VIVI000000000000A4A40;^k^`0H0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0
1@3oool2028R8PH0oooo0P0000000`0A4A40oooo0?ooo`2F0?ooo`00WP3oool01@0A4A40^k^k0>k^
kP1gMgL04A4A00T0oooo1P0000090?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0
oooo00<000000?ooo`3oool0U`3oool009h0oooo00<000000?ooo`3oool06P3oool01@0A4A40oooo
0?ooo`3oool04A4A00/0oooo1@00002H0?ooo`007`3oool01@0A4A4000000000000000004A4A07X0
oooo00<000000?ooo`3oool02`3oool6000000T0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`0404A4A03MgMd0oooo000009T0oooo000Q0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool06P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0gMgM05EEE@3oool00000V@3o
ool00240oooo00<000000?ooo`3oool0N03oool00`0A4A40000000000003000001T0oooo00D04A4A
0?ooo`3oool0oooo014A4@0<0?ooo`0307MgM`3<c<`0000009T0oooo000Q0?ooo`030000003oool0
oooo07X0oooo00<000000?ooo`3oool06P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0
k^k^04A4A0000000V@3oool00240oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0J
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h03@3oool00`1gMgL000000?ooo`2H0?ooo`007P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0oooo@P3oool001h0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oood80oooo000N0?ooo`L00000o`3ooom4
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "[Note the text within the brackets (* *) , which is ignored by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Comments such as these can be useful for documenting code.] The \
temperature  rapidly approaches the equilibrium temperature ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_eq\)(x)\)]],
  " as the point heat source raises the internal temperature of the slab.  "
}], "Text",
  CellTags->"i:115"],

Cell[TextData[{
  "\tObserve that the rate at which the equilibrium is approached is mainly \
determined by the lowest eigenmode. This is because the time dependence of \
the eigenmode amplitudes is given by  the factor ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[Chi]\)\ \(\((n\ \
\[Pi]/L)\)\^2\) t\)\)]],
  ". This factor decays rapidly for the modes with ",
  Cell[BoxData[
      \(TraditionalForm\`n >> 1\)]],
  ", so at large times the solution is approximately determined by the lowest \
mode:"
}], "Text",
  CellTags->"i:36"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`T(x, 
          t)\  \[TildeEqual] \(T\_eq\)(
            x) + \ \(A\_1\) \(\[ExponentialE]\^\(\(-\[Chi]\)\ \(\((\[Pi]/
                          L)\)\^2\) t\)\) sin\ \((\[Pi]\ x/L)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.64)"],

Cell[TextData[{
  "This equation implies that, for this problem, the maximum temperature \
deviation from equilibrium occurs at the center of the slab ",
  Cell[BoxData[
      \(TraditionalForm\`\((x = L/2)\)\)]],
  ", and has the time dependence ",
  Cell[BoxData[
      \(TraditionalForm\`\(A\_1\) \[ExponentialE]\^\(\(-\[Chi]\)\ \
\(\((\[Pi]/L)\)\^2\) t\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`A\_1\)]],
  "is determined from the initial condition by Eq. ",
  ButtonBox["(3.1.62)",
    ButtonData:>"(3.1.62)",
    ButtonStyle->"Hyperlink"],
  ". Thus, at long times, the rate at which the slab temperature approaches  \
equilibrium is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\ \((\[Pi]/L)\)\^2\)]],
  ". The larger the conductivity, the faster equilibrium is achieved. But the \
thicker the slab, the longer it takes for the heat to diffuse from the \
interior to the faces. "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Homogeneous von Neumann Boundary Conditions", "Section",
  CellTags->"c:20"],

Cell[CellGroupData[{

Cell["Separation-of-Variables Solution", "Subsubsection"],

Cell[TextData[{
  "\tLet us now consider the case of a uniform slab insulated on both sides, \
and with no source.  These conditions clearly satisfy Eq. ",
  ButtonBox["(3.1.51)",
    ButtonData:>"(3.1.51)",
    ButtonStyle->"Hyperlink"],
  ", so an equilibrium exists- in this case the trivial equilibrium ",
  Cell[BoxData[
      \(TraditionalForm\`T\_eq\  = \ constant\)]],
  ". The temperature within the slab now evolves according to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]T\/\[PartialD]t = \[Chi] \[PartialD]\^2 T\
\/\[PartialD]x\^2\)]],
  ","
}], "NumberedEquation",
  CellTags->"(3.1.65)"],

Cell["with homogeneous von Neumann boundary conditions", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\[PartialD]T\/\[PartialD]x\) \((0, 
          t)\)\  = \ \(\(\[PartialD]T\/\[PartialD]x\) \((L, t)\)\  = \ 
        0\)\)]]], "NumberedEquation",
  CellTags->"(3.1.66)"],

Cell[" and initial condition", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`T(x, 
        0)\  = \ \(\(\(T\_o\)(x)\)\(.\)\)\)]]], "NumberedEquation",
  CellTags->"(3.1.67)"],

Cell[TextData[{
  "\tThe solution of Eq. ",
  ButtonBox["(3.1.65)",
    ButtonData:>"(3.1.65)",
    ButtonStyle->"Hyperlink"],
  "  can again be obtained using the method of separation of variables. We \
now have no need to take out an equilibrium solution, since there is no \
source and the boundary conditions are already homogeneous. We look for a \
solution of the form ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t) = \ \(f(t)\)\ \(\[Psi](x)\)\)]],
  ". Substituting this expression into Eq. ",
  ButtonBox["(3.1.65)",
    ButtonData:>"(3.1.65)",
    ButtonStyle->"Hyperlink"],
  ", and dividing by ",
  Cell[BoxData[
      \(TraditionalForm\`\(f(t)\)\ \(\[Psi](x)\)\)]],
  ", we have"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(f(
                t)\)\) \[PartialD]f\/\[PartialD]t = \(\[Chi]\/\(\[Psi](
                x)\)\) \[PartialD]\^2 \[Psi]\/\[PartialD]x\^2\)]],
  ","
}], "Text"],

Cell[TextData[{
  "which can be separated into two ODEs, Eqs. ",
  ButtonBox["(3.1.57)",
    ButtonData:>"(3.1.57)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.1.58)",
    ButtonData:>"(3.1.58)",
    ButtonStyle->"Hyperlink"],
  ", just as before. We repeat these equations below:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(f(
                t)\)\) \[PartialD]f\/\[PartialD]t = \[Lambda]\)]],
  ","
}], "NumberedEquation",
  CellTags->"(3.1.68)"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Chi]\/\(\[Psi](
                x)\)\) \[PartialD]\^2 \[Psi]\/\[PartialD]x\^2 = \
\[Lambda]\)]],
  ","
}], "NumberedEquation",
  CellTags->"(3.1.69)"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Eigenvalue Problem", "Subsubsection",
  CellTags->"i:37"],

Cell[TextData[{
  "The separation constant ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " and the functions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x)\)]],
  " are determined by the homogeneous von Neumann boundary conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\^\[Prime]\)(
          0) = \(\(\[Psi]\^\[Prime]\)(L) = 0\)\)]],
  ". These boundary conditions yield another eigenvalue problem: for all but \
a special set of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  "-values, the only solution to Eq. ",
  ButtonBox["(3.1.69)",
    ButtonData:>"(3.1.69)",
    ButtonStyle->"Hyperlink"],
  " that satisfies these boundary conditions is the trivial solution  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] = 0\)]],
  ".   "
}], "Text"],

Cell[TextData[{
  "\tTo find the nontrivial solutions, we apply the boundary conditions to \
the general solution of Eq. ",
  ButtonBox["(3.1.69)",
    ButtonData:>"(3.1.69)",
    ButtonStyle->"Hyperlink"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x) = \ C\ cos\ k\ x\  + \ D\ sin\ k\ x\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`k = \@\(\(-\[Lambda]\)/\[Chi]\)\)]],
  ".  To match the condition that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\^\[Prime]\)(0) = 0\)]],
  ", we require that ",
  Cell[BoxData[
      \(TraditionalForm\`D = 0\)]],
  ", and to match the condition that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\^\[Prime]\)(L) = 0\)]],
  ", we find that either ",
  Cell[BoxData[
      \(TraditionalForm\`C = 0\)]],
  " (the trivial solution) or ",
  Cell[BoxData[
      \(TraditionalForm\`k\ sin\ k\ x\  = \ 0\)]],
  ". This equation can be satisfied with the choices ",
  Cell[BoxData[
      \(TraditionalForm\`k\  = \ n\ \[Pi]/L\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2, \(\(...\)\(.\)\)\)]],
  ", so we find that "
}], "Text",
  CellTags->"i:39"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Psi](x)\  = \ 
      C\ \(cos(n\ \[Pi]\ x/L)\)\)]]], "NumberedEquation",
  CellTags->"(3.1.70)"],

Cell["and", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = \(\[Lambda]\_n = \(-\[Chi]\)\ \((n\ \
\[Pi]/L)\)\^2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2, 3,  ... \)]]
}], "NumberedEquation",
  CellTags->"(3.1.71)"],

Cell["\<\
Forming a linear superposition of these solutions, we now \
obtain\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`T(x, 
          t)\  = \ \[Sum]\+\(n = 0\)\%\[Infinity] A\_n\ \[ExponentialE]\^\(\(\
\[Lambda]\_n\) t\)\ cos\ \((n\ \[Pi]\ x/L)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->{"(3.1.72)", "i:116"}],

Cell[TextData[{
  "where, as before, we absorb the constant ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " into the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  ". Note that we now keep the ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  " term  in the sum, since ",
  Cell[BoxData[
      \(TraditionalForm\`cos(0\ \[Pi]\ x)\  = 1\)]],
  " is a perfectly good eigenmode. "
}], "Text"],

Cell[TextData[{
  "\tJust as before, the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " are found by matching the initial condition, Eq. ",
  ButtonBox["(3.1.67)",
    ButtonData:>"(3.1.67)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 
          0) = \(\[Sum]\+\(n = 0\)\%\[Infinity] A\_n\ \(cos(
                n\ \[Pi]\ x/L)\) = \(T\_o\)(x)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "This is a Fourier ",
  StyleBox["cosine",
    FontSlant->"Italic"],
  " series, so the ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  "'s are determined as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`A\_n = \(2\/L\) \(\[Integral]\_0\%L\(\( T\_o\)(
                x)\) \(cos(n\ \[Pi]\ x/L)\) \[DifferentialD]x\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n > 0\)]],
  ",\n\n",
  Cell[BoxData[
      \(TraditionalForm\`A\_o = \(1\/L\) \(\[Integral]\_0\%L\(\( T\_o\)(
                x)\) \[DifferentialD]x\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.73)"],

Cell[TextData[{
  "The solution is again made up of a sum of eigenmodes.  Although the \
eigenmodes differ from the previous case, they still form a set of orthogonal \
Fourier modes, which can be used to match  to the initial conditions.  Note \
that the ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  " eigenmode  has a zero eigenvalue, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_o = 0\)]],
  ", so this mode does not decay with time. However, all of the higher-order \
modes do decay away. This has a simple physical interpretation: over time the \
initial temperature distribution simply becomes uniform within the slab, \
because the temperature equilibrates but heat cannot be conducted to the \
surroundings, due to the insulating boundary conditions."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example ",
  FontWeight->"Bold"]], "Subsubsection"],

Cell[TextData[{
  "Let us assume that an insulated slab of unit width has an initial \
temperature equal  ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_o\)(x)\  = \ 
        x\^2\/16 + x\^3 - \(65\ x\^4\)\/32 + x\^5\)]],
  ". This somewhat complicated initial condition is displayed in Cell ",
  ButtonBox["3.13",
    ButtonData:>"Cell 3.13",
    ButtonStyle->"Hyperlink"],
  ". It is chosen so as to have a peak in the center, and zero derivatives at \
each end point. "
}], "Text"],

Cell[TextData[{
  "\tThe  Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " are determined  according to Eqs. ",
  ButtonBox["(3.1.73)",
    ButtonData:>"(3.1.73)",
    ButtonStyle->"Hyperlink"],
  ".  The integrals are performed below, using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " :"
}], "Text"],

Cell[BoxData[{
    \(\(L = 1;\)\), "\n", 
    \(\(T0[x_]\  = \ x\^2\/16 + x\^3 - \(65\ x\^4\)\/32 + x\^5;\)\), "\n", 
    \(\(A[n_]\  = \ \((2/L)\) 
          Integrate[T0[x]\ Cos[n\ Pi\ x], {x, 0, L}]\ ;\)\), "\n", 
    \(\(A[0]\  = \ \((1/L)\) Integrate[T0[x], {x, 0, L}]\ ;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.10"],

Cell[TextData[{
  "The forms for ",
  Cell[BoxData[
      \(TraditionalForm\`A\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " are"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A[0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.11"],

Cell[BoxData[
    \(1\/32\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[A[n], n \[Element] Integers]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.12"],

Cell[BoxData[
    \(\(-\(\(3\ \((\(-160\)\ \((\(-1\) + \((\(-1\))\)\^n)\) + \((\(-8\) + 
                      23\ \((\(-1\))\)\^n)\)\ n\^2\ \[Pi]\^2)\)\)\/\(2\ n\^6\ \
\[Pi]\^6\)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This solution is shown in Cell ",
  ButtonBox["3.13",
    ButtonData:>"Cell 3.13",
    ButtonStyle->"Hyperlink"],
  ", keeping ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(=\)\(20\)\(\ \)\)\)]],
  "terms in the sum over eigenmodes, and again taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] = 1\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*parameters*) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{\(\[Chi] = 1;\), "\n", \(M = 20;\), "\n", 
          StyleBox[\( (*\ solution\ *) \),
            FontColor->RGBColor[1, 0, 0]], 
          "\n", \(T[x_, t_]\  = \ \ Sum[
                A[n]\ \(\[ExponentialE]\^\(\(-\((n\ Pi\ /
                                  L)\)^2\)\ \[Chi]\ t\)\) Cos[n\ Pi\ x], {n, 
                  0, M}];\), "\n", 
          StyleBox[\( (*Plot\ the\ result*) \),
            FontColor->RGBColor[1, 0, 0]], 
          "\n", \(Table[
            Plot[T[x, t], {x, 0, L}, PlotRange \[Rule] {{0, L}, {0,  .07}}, 
              PlotLabel \[Rule] "\<t = \>" <> ToString[t], 
              AxesLabel \[Rule] {"\<x\>", "\<T\>"}], {t, 0, 0.2, \ 
              0.2/20}]\)}], ";"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.13"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00772 0 m
.00942 2e-05 L
.01203 7e-05 L
.01479 .00013 L
.01975 .00028 L
.02486 .00049 L
.02966 .00073 L
.04057 .00148 L
.04627 .00201 L
.0517 .00259 L
.06188 .00395 L
.07284 .00584 L
.08481 .00844 L
.10547 .01438 L
.12749 .02284 L
.17115 .04632 L
.21322 .0775 L
.2537 .11467 L
.29675 .16055 L
.33821 .20912 L
.37808 .25779 L
.42053 .30944 L
.46138 .35653 L
.50481 .40121 L
.54665 .43669 L
.58689 .46191 L
.60766 .47109 L
.61814 .47466 L
.62971 .47774 L
.63488 .47881 L
.64031 .47975 L
.64495 .48039 L
.65003 .48092 L
.6529 .48114 L
.65551 .48129 L
.65696 .48135 L
.65772 .48138 L
.65853 .48141 L
.65923 .48142 L
.66001 .48144 L
.66137 .48146 L
.66275 .48146 L
.664 .48146 L
.6647 .48145 L
.66545 .48143 L
.66683 .4814 L
.66811 .48136 L
.66947 .4813 L
.67193 .48116 L
.67467 .48096 L
Mistroke
.67757 .48069 L
.68276 .48007 L
.68834 .4792 L
.69445 .478 L
.70542 .47522 L
.71564 .47191 L
.73706 .46279 L
.75655 .45204 L
.79845 .42223 L
.83875 .38713 L
.88162 .34697 L
.92291 .31115 L
.94202 .29721 L
.95205 .29095 L
.9626 .28535 L
.97193 .28138 L
.97686 .2797 L
.98212 .27823 L
.98698 .27721 L
.98928 .27683 L
.99139 .27655 L
.99352 .27632 L
.99462 .27623 L
.99582 .27615 L
.99687 .2761 L
.99785 .27606 L
.99889 .27604 L
1 .27603 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .03255 m
.00123 .03256 L
.00236 .03256 L
.00365 .03258 L
.00488 .0326 L
.00706 .03264 L
.00942 .03271 L
.01203 .03281 L
.01479 .03294 L
.01975 .03325 L
.02486 .03366 L
.02966 .03412 L
.04057 .03549 L
.0517 .03733 L
.06188 .03939 L
.08481 .04538 L
.10474 .05208 L
.1265 .06097 L
.16918 .08303 L
.21027 .10967 L
.25393 .14306 L
.296 .17916 L
.33648 .2163 L
.37953 .25682 L
.42099 .29516 L
.46086 .32979 L
.50331 .36256 L
.54416 .38869 L
.56496 .39957 L
.58759 .40936 L
.60932 .41668 L
.61969 .41943 L
.62943 .42158 L
.63886 .42325 L
.64903 .42461 L
.65452 .42516 L
.65752 .4254 L
.66031 .42559 L
.6629 .42573 L
.66525 .42584 L
.66787 .42593 L
.6693 .42597 L
.67066 .426 L
.67187 .42602 L
.67317 .42603 L
.6744 .42603 L
.67552 .42603 L
.67683 .42603 L
.67757 .42602 L
.67826 .42601 L
Mistroke
.67952 .42599 L
.68086 .42596 L
.68379 .42587 L
.68654 .42575 L
.69167 .42545 L
.69653 .42506 L
.70099 .42463 L
.71105 .42338 L
.7213 .42172 L
.73085 .41985 L
.75256 .41453 L
.79347 .40131 L
.83696 .38467 L
.87885 .36872 L
.91915 .35579 L
.93995 .3507 L
.95058 .34862 L
.96203 .34679 L
.97226 .34555 L
.97673 .34513 L
.98162 .34475 L
.98627 .34447 L
.99058 .34428 L
.99297 .34421 L
.99514 .34416 L
.99634 .34414 L
.99764 .34412 L
.99887 .34412 L
1 .34411 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .06674 m
.00123 .06674 L
.00236 .06675 L
.00365 .06676 L
.00488 .06677 L
.00706 .06682 L
.00942 .06688 L
.01203 .06697 L
.01479 .06709 L
.01975 .06736 L
.02486 .06773 L
.02966 .06814 L
.04057 .06937 L
.0517 .071 L
.06188 .07284 L
.08481 .07815 L
.1265 .09183 L
.16661 .10956 L
.20928 .13279 L
.25037 .15868 L
.29403 .18902 L
.3361 .21992 L
.37658 .25009 L
.41963 .28141 L
.46109 .30964 L
.50096 .33399 L
.54341 .35601 L
.58426 .37274 L
.60507 .37946 L
.62769 .38537 L
.64942 .38967 L
.65979 .39127 L
.66953 .3925 L
.67896 .39346 L
.68913 .39424 L
.69463 .39456 L
.70041 .39481 L
.70535 .39497 L
.70815 .39503 L
.71076 .39508 L
.7121 .3951 L
.71283 .3951 L
.71352 .39511 L
.71473 .39512 L
.71606 .39512 L
.7168 .39512 L
.71751 .39512 L
.71883 .39512 L
.71957 .39512 L
.72026 .39511 L
Mistroke
.72181 .3951 L
.72318 .39509 L
.72446 .39507 L
.72686 .39503 L
.72945 .39497 L
.73224 .39489 L
.73719 .39472 L
.74241 .39449 L
.75176 .39395 L
.77242 .39228 L
.79168 .39022 L
.83259 .3848 L
.87608 .37858 L
.89785 .37569 L
.91797 .37334 L
.93877 .37133 L
.95827 .36992 L
.96773 .36942 L
.97791 .36901 L
.98341 .36886 L
.98642 .36879 L
.98921 .36874 L
.9916 .36871 L
.99415 .36868 L
.99561 .36867 L
.99698 .36866 L
.99822 .36866 L
.99955 .36866 L
1 .36865 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .09618 m
.00123 .09618 L
.00236 .09619 L
.00365 .0962 L
.00488 .09621 L
.00706 .09625 L
.00942 .0963 L
.01203 .09638 L
.01479 .09648 L
.01975 .09671 L
.02486 .09701 L
.02966 .09736 L
.04057 .09839 L
.0517 .09976 L
.06188 .10129 L
.08481 .10573 L
.1265 .11713 L
.16661 .13183 L
.20928 .15097 L
.25037 .17218 L
.29403 .1969 L
.3361 .22198 L
.37658 .24642 L
.41963 .27187 L
.46109 .295 L
.50096 .3153 L
.54341 .33423 L
.58426 .34945 L
.62769 .36218 L
.64942 .3672 L
.66953 .37108 L
.69029 .37434 L
.70978 .37676 L
.72937 .3786 L
.73978 .37936 L
.75101 .38002 L
.76106 .38049 L
.77205 .38087 L
.7776 .38101 L
.78353 .38113 L
.7864 .38117 L
.78912 .38121 L
.79175 .38124 L
.7942 .38126 L
.79655 .38128 L
.79775 .38129 L
.79906 .38129 L
.79981 .3813 L
.8005 .3813 L
.80186 .3813 L
Mistroke
.80309 .3813 L
.80441 .3813 L
.80514 .3813 L
.80582 .3813 L
.80655 .3813 L
.80733 .3813 L
.80864 .3813 L
.81008 .38129 L
.81274 .38128 L
.81522 .38126 L
.82011 .38122 L
.82457 .38117 L
.83459 .38102 L
.85467 .38058 L
.87648 .37998 L
.91936 .37873 L
.94067 .3782 L
.9511 .37798 L
.96065 .37782 L
.96988 .37769 L
.9796 .37759 L
.98465 .37755 L
.98935 .37753 L
.99205 .37751 L
.9945 .37751 L
.99586 .37751 L
.99658 .3775 L
.99733 .3775 L
.99799 .3775 L
.99872 .3775 L
1 .3775 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .12059 m
.00123 .12059 L
.00236 .1206 L
.00365 .12061 L
.00488 .12062 L
.00706 .12065 L
.00942 .12069 L
.01203 .12075 L
.01479 .12083 L
.01975 .12102 L
.02486 .12127 L
.02966 .12156 L
.04057 .1224 L
.0517 .12353 L
.06188 .12479 L
.08481 .12844 L
.1265 .13781 L
.16661 .14987 L
.20928 .16558 L
.25037 .18299 L
.29403 .20329 L
.3361 .22394 L
.37658 .24418 L
.41963 .26543 L
.46109 .28503 L
.50096 .30258 L
.54341 .31945 L
.58426 .33362 L
.62769 .3463 L
.66953 .35614 L
.70978 .36352 L
.73013 .36652 L
.7526 .36932 L
.79383 .3732 L
.81414 .3746 L
.83604 .37579 L
.85708 .37667 L
.87924 .37736 L
.89997 .37784 L
.91925 .37815 L
.9303 .37829 L
.94073 .3784 L
.95003 .37847 L
.96025 .37854 L
.97029 .37859 L
.97579 .37861 L
.98093 .37862 L
.98573 .37863 L
.99012 .37864 L
.99255 .37864 L
Mistroke
.99383 .37864 L
.99519 .37864 L
.9965 .37864 L
.99769 .37864 L
.99888 .37864 L
1 .37864 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .14065 m
.00123 .14065 L
.00236 .14065 L
.00365 .14066 L
.00488 .14067 L
.00706 .14069 L
.00942 .14073 L
.01203 .14078 L
.01479 .14085 L
.01975 .141 L
.02486 .14121 L
.02966 .14144 L
.04057 .14214 L
.0517 .14306 L
.06188 .1441 L
.08481 .14711 L
.1265 .15482 L
.16661 .16477 L
.20928 .17774 L
.25037 .19216 L
.29403 .20905 L
.3361 .22633 L
.37658 .2434 L
.41963 .26153 L
.46109 .27849 L
.50096 .29397 L
.54341 .30923 L
.58426 .32247 L
.62769 .33483 L
.66953 .34499 L
.70978 .35315 L
.7526 .36018 L
.79383 .36547 L
.83347 .36934 L
.85549 .37103 L
.87568 .37233 L
.89672 .37343 L
.9163 .37425 L
.93617 .37489 L
.94668 .37515 L
.95791 .37538 L
.9683 .37554 L
.97416 .37561 L
.97956 .37566 L
.98429 .3757 L
.987 .37572 L
.98949 .37573 L
.99211 .37574 L
.99345 .37574 L
.99492 .37575 L
Mistroke
.99627 .37575 L
.99753 .37575 L
.99872 .37575 L
1 .37575 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .1572 m
.00123 .15721 L
.00236 .15721 L
.00365 .15721 L
.00488 .15722 L
.00706 .15724 L
.00942 .15727 L
.01203 .15731 L
.01479 .15737 L
.01975 .1575 L
.02486 .15767 L
.02966 .15787 L
.04057 .15844 L
.0517 .15921 L
.06188 .16007 L
.08481 .16257 L
.1265 .16898 L
.16661 .17727 L
.20928 .18811 L
.25037 .20021 L
.29403 .21446 L
.3361 .22914 L
.37658 .24377 L
.41963 .25947 L
.46109 .27436 L
.50096 .28816 L
.54341 .30203 L
.58426 .31436 L
.62769 .32619 L
.66953 .33624 L
.70978 .34462 L
.7526 .35214 L
.79383 .35807 L
.83347 .36262 L
.85549 .36468 L
.87568 .36629 L
.89672 .36769 L
.9163 .36875 L
.93617 .36959 L
.94735 .36996 L
.95791 .37025 L
.96821 .37046 L
.97364 .37055 L
.97939 .37063 L
.98422 .37068 L
.98679 .3707 L
.98954 .37072 L
.99207 .37073 L
.99438 .37074 L
.99549 .37074 L
Mistroke
.9967 .37075 L
.99784 .37075 L
.9989 .37075 L
1 .37075 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .17102 m
.00123 .17102 L
.00236 .17102 L
.00365 .17103 L
.00488 .17104 L
.00706 .17105 L
.00942 .17108 L
.01203 .17111 L
.01479 .17116 L
.01975 .17127 L
.02486 .17141 L
.02966 .17158 L
.04057 .17206 L
.0517 .17271 L
.06188 .17343 L
.08481 .17553 L
.1265 .18093 L
.16661 .18792 L
.20928 .19711 L
.25037 .20739 L
.29403 .21958 L
.3361 .23222 L
.37658 .24491 L
.41963 .25866 L
.46109 .27186 L
.50096 .28424 L
.54341 .29687 L
.58426 .30828 L
.62769 .31943 L
.66953 .32912 L
.70978 .33736 L
.7526 .34494 L
.79383 .35106 L
.83347 .35585 L
.87568 .3598 L
.89508 .36122 L
.9163 .3625 L
.93734 .36348 L
.94882 .36389 L
.9595 .3642 L
.96474 .36432 L
.97041 .36444 L
.97542 .36453 L
.98072 .3646 L
.9855 .36465 L
.98821 .36467 L
.99075 .36469 L
.99308 .3647 L
.99521 .36471 L
.99639 .36471 L
Mistroke
.99767 .36472 L
.99888 .36472 L
1 .36472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .1827 m
.00123 .1827 L
.00236 .1827 L
.00365 .18271 L
.00488 .18271 L
.00706 .18273 L
.00942 .18275 L
.01203 .18278 L
.01479 .18282 L
.01975 .18291 L
.02486 .18303 L
.02966 .18317 L
.04057 .18358 L
.0517 .18413 L
.06188 .18475 L
.08481 .18654 L
.1265 .19114 L
.16661 .19713 L
.20928 .205 L
.25037 .21386 L
.29403 .2244 L
.3361 .23541 L
.37658 .24653 L
.41963 .25868 L
.46109 .27044 L
.50096 .28159 L
.54341 .29308 L
.58426 .30359 L
.62769 .314 L
.66953 .32317 L
.70978 .33108 L
.7526 .33845 L
.79383 .34449 L
.83347 .34928 L
.87568 .35326 L
.9163 .35601 L
.93734 .35701 L
.94805 .35741 L
.9595 .35775 L
.97036 .358 L
.98023 .35816 L
.98499 .35821 L
.98749 .35823 L
.99015 .35825 L
.99247 .35826 L
.9937 .35827 L
.99502 .35827 L
.99623 .35828 L
.99734 .35828 L
.99845 .35828 L
Mistroke
.99951 .35828 L
1 .35828 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.09) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .1927 m
.00123 .1927 L
.00236 .1927 L
.00365 .1927 L
.00488 .19271 L
.00706 .19272 L
.00942 .19274 L
.01203 .19277 L
.01479 .1928 L
.01975 .19288 L
.02486 .19299 L
.02966 .19311 L
.04057 .19346 L
.0517 .19393 L
.06188 .19447 L
.08481 .19601 L
.1265 .19998 L
.16661 .20516 L
.20928 .21199 L
.25037 .2197 L
.29403 .22892 L
.3361 .23859 L
.37658 .24841 L
.41963 .25921 L
.46109 .26974 L
.50096 .2798 L
.54341 .29025 L
.58426 .29989 L
.62769 .30953 L
.66953 .3181 L
.70978 .32556 L
.7526 .33258 L
.79383 .33838 L
.83347 .34301 L
.87568 .34689 L
.9163 .34958 L
.93734 .35056 L
.94805 .35095 L
.9595 .35129 L
.97036 .35154 L
.98023 .35169 L
.98499 .35175 L
.98749 .35177 L
.99015 .35179 L
.99247 .3518 L
.9937 .3518 L
.99502 .35181 L
.99623 .35181 L
.99734 .35181 L
.99845 .35182 L
Mistroke
.99951 .35182 L
1 .35182 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20136 m
.00123 .20136 L
.00236 .20136 L
.00365 .20136 L
.00488 .20137 L
.00706 .20138 L
.00942 .20139 L
.01203 .20142 L
.01479 .20145 L
.01975 .20152 L
.02486 .20161 L
.02966 .20171 L
.04057 .20202 L
.0517 .20244 L
.06188 .2029 L
.08481 .20424 L
.1265 .20771 L
.16661 .21223 L
.20928 .21822 L
.25037 .22499 L
.29403 .23311 L
.3361 .24166 L
.37658 .2504 L
.41963 .26005 L
.46109 .2695 L
.50096 .27859 L
.54341 .28808 L
.58426 .2969 L
.62769 .30578 L
.66953 .31371 L
.70978 .32068 L
.7526 .32727 L
.79383 .33274 L
.83347 .33713 L
.87568 .34083 L
.9163 .34339 L
.93734 .34434 L
.94805 .34471 L
.9595 .34504 L
.97036 .34527 L
.98023 .34542 L
.98499 .34547 L
.98749 .34549 L
.99015 .34551 L
.99247 .34552 L
.9937 .34553 L
.99502 .34553 L
.99623 .34553 L
.99734 .34554 L
.99845 .34554 L
Mistroke
.99951 .34554 L
1 .34554 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.11) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20893 m
.00123 .20893 L
.00236 .20893 L
.00365 .20894 L
.00488 .20894 L
.00706 .20895 L
.00942 .20896 L
.01203 .20898 L
.01479 .20901 L
.01975 .20907 L
.02486 .20915 L
.02966 .20924 L
.04057 .20952 L
.0517 .20988 L
.06188 .21029 L
.08481 .21147 L
.10474 .21278 L
.1265 .21452 L
.16918 .21879 L
.21027 .22392 L
.25393 .23033 L
.296 .23732 L
.33648 .24466 L
.37953 .25297 L
.42099 .26132 L
.46086 .2695 L
.50331 .27824 L
.54416 .28654 L
.58759 .29507 L
.62943 .30288 L
.66967 .30991 L
.7125 .31674 L
.75372 .3226 L
.79336 .3275 L
.83558 .33186 L
.8762 .33517 L
.89683 .3365 L
.91939 .33769 L
.92982 .33815 L
.94095 .33856 L
.95138 .33889 L
.961 .33913 L
.97063 .33932 L
.9756 .3394 L
.98106 .33946 L
.98581 .33951 L
.99026 .33954 L
.99271 .33955 L
.99496 .33956 L
.99619 .33956 L
Mistroke
.99754 .33957 L
.99882 .33957 L
1 .33957 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .21561 m
.00123 .21561 L
.00236 .21561 L
.00365 .21562 L
.00488 .21562 L
.00706 .21563 L
.00942 .21564 L
.01203 .21566 L
.01479 .21568 L
.01975 .21573 L
.02486 .2158 L
.02966 .21589 L
.04057 .21613 L
.0517 .21645 L
.06188 .21681 L
.08481 .21785 L
.10474 .21902 L
.1265 .22056 L
.16918 .22435 L
.21027 .2289 L
.25393 .23461 L
.296 .24084 L
.33648 .2474 L
.37953 .25485 L
.42099 .26235 L
.46086 .26973 L
.50331 .27764 L
.54416 .28517 L
.58759 .29294 L
.62943 .30008 L
.66967 .30652 L
.7125 .31281 L
.75372 .31822 L
.79336 .32275 L
.83558 .3268 L
.8762 .32987 L
.89683 .33112 L
.91939 .33222 L
.94095 .33303 L
.95057 .33331 L
.961 .33356 L
.96647 .33367 L
.97151 .33375 L
.97624 .33382 L
.98143 .33388 L
.98609 .33392 L
.99045 .33395 L
.99286 .33396 L
.99505 .33397 L
.99627 .33397 L
Mistroke
.99759 .33397 L
.99884 .33397 L
1 .33397 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.13) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .22154 m
.00123 .22154 L
.00236 .22154 L
.00365 .22154 L
.00488 .22154 L
.00706 .22155 L
.00942 .22156 L
.01203 .22158 L
.01479 .2216 L
.01975 .22165 L
.02486 .22171 L
.02966 .22178 L
.04057 .222 L
.0517 .22228 L
.06188 .2226 L
.08481 .22353 L
.10474 .22457 L
.1265 .22594 L
.16918 .22932 L
.21027 .23338 L
.25393 .23848 L
.296 .24406 L
.33648 .24995 L
.37953 .25664 L
.42099 .2634 L
.46086 .27006 L
.50331 .27722 L
.54416 .28405 L
.58759 .29112 L
.62943 .29763 L
.66967 .30352 L
.7125 .30928 L
.75372 .31425 L
.79336 .31842 L
.83558 .32215 L
.8762 .32499 L
.89683 .32614 L
.91939 .32716 L
.94095 .32791 L
.95057 .32817 L
.961 .3284 L
.96647 .32849 L
.97151 .32857 L
.97624 .32863 L
.98143 .32869 L
.98609 .32873 L
.99045 .32875 L
.99286 .32876 L
.99505 .32877 L
.99627 .32877 L
Mistroke
.99759 .32877 L
.99884 .32877 L
1 .32877 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .22682 m
.00123 .22682 L
.00236 .22682 L
.00365 .22682 L
.00488 .22683 L
.00706 .22683 L
.00942 .22684 L
.01203 .22686 L
.01479 .22688 L
.01975 .22692 L
.02486 .22698 L
.02966 .22704 L
.04057 .22723 L
.0517 .22749 L
.06188 .22777 L
.08481 .22861 L
.10474 .22953 L
.1265 .23076 L
.16918 .23378 L
.21027 .23742 L
.25393 .242 L
.296 .24701 L
.33648 .2523 L
.37953 .25833 L
.42099 .26442 L
.46086 .27044 L
.50331 .27692 L
.54416 .28311 L
.58759 .28954 L
.62943 .29547 L
.66967 .30084 L
.7125 .3061 L
.75372 .31065 L
.79336 .31447 L
.83558 .31789 L
.8762 .3205 L
.89683 .32155 L
.91939 .3225 L
.94095 .32318 L
.95057 .32342 L
.961 .32363 L
.96647 .32372 L
.97151 .32379 L
.97624 .32385 L
.98143 .3239 L
.98609 .32394 L
.99045 .32396 L
.99286 .32397 L
.99505 .32398 L
.99627 .32398 L
Mistroke
.99759 .32398 L
.99884 .32398 L
1 .32398 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .23155 m
.00123 .23155 L
.00236 .23155 L
.00365 .23155 L
.00488 .23156 L
.00706 .23156 L
.00942 .23157 L
.01203 .23158 L
.01479 .2316 L
.01975 .23164 L
.02486 .23169 L
.02966 .23175 L
.04057 .23192 L
.0517 .23215 L
.06188 .23241 L
.08481 .23315 L
.10474 .23398 L
.1265 .23508 L
.16918 .2378 L
.21027 .24107 L
.25393 .24518 L
.296 .24969 L
.33648 .25445 L
.37953 .25989 L
.42099 .2654 L
.46086 .27084 L
.50331 .27671 L
.54416 .28232 L
.58759 .28816 L
.62943 .29355 L
.66967 .29844 L
.7125 .30324 L
.75372 .30739 L
.79336 .31088 L
.83558 .314 L
.8762 .31639 L
.89683 .31736 L
.91939 .31822 L
.94095 .31885 L
.95057 .31907 L
.961 .31926 L
.96647 .31934 L
.97151 .31941 L
.97624 .31946 L
.98143 .31951 L
.98609 .31954 L
.99045 .31956 L
.99286 .31957 L
.99505 .31958 L
.99627 .31958 L
Mistroke
.99759 .31958 L
.99884 .31958 L
1 .31958 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .2358 m
.00123 .2358 L
.00236 .2358 L
.00365 .2358 L
.00488 .2358 L
.00706 .23581 L
.00942 .23582 L
.01203 .23583 L
.01479 .23584 L
.01975 .23588 L
.02486 .23592 L
.02966 .23598 L
.04057 .23613 L
.0517 .23634 L
.06188 .23657 L
.08481 .23724 L
.10474 .23799 L
.1265 .23898 L
.16918 .24142 L
.21027 .24436 L
.25393 .24807 L
.296 .25213 L
.33648 .25643 L
.37953 .26134 L
.42099 .26631 L
.46086 .27124 L
.50331 .27655 L
.54416 .28164 L
.58759 .28694 L
.62943 .29184 L
.66967 .29628 L
.7125 .30065 L
.75372 .30443 L
.79336 .30761 L
.83558 .31047 L
.8762 .31264 L
.89683 .31353 L
.91939 .31431 L
.94095 .31489 L
.95057 .31509 L
.961 .31526 L
.96647 .31534 L
.97151 .3154 L
.97624 .31545 L
.98143 .31549 L
.98609 .31552 L
.99045 .31554 L
.99286 .31555 L
.99505 .31555 L
.99627 .31555 L
Mistroke
.99759 .31555 L
.99884 .31556 L
1 .31556 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.17) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .23962 m
.00123 .23962 L
.00236 .23962 L
.00365 .23963 L
.00488 .23963 L
.00706 .23963 L
.00942 .23964 L
.01203 .23965 L
.01479 .23966 L
.01975 .23969 L
.02486 .23973 L
.02966 .23978 L
.04057 .23992 L
.0517 .24011 L
.06188 .24031 L
.08481 .24092 L
.10474 .24159 L
.1265 .24249 L
.16918 .24469 L
.21027 .24734 L
.25393 .25068 L
.296 .25435 L
.33648 .25823 L
.37953 .26267 L
.42099 .26717 L
.46086 .27163 L
.50331 .27644 L
.54416 .28105 L
.58759 .28586 L
.62943 .2903 L
.66967 .29434 L
.7125 .29831 L
.75372 .30175 L
.79336 .30465 L
.83558 .30724 L
.8762 .30923 L
.89683 .31003 L
.91939 .31075 L
.94095 .31127 L
.95057 .31146 L
.961 .31162 L
.96647 .31169 L
.97151 .31174 L
.97624 .31178 L
.98143 .31182 L
.98609 .31185 L
.99045 .31187 L
.99286 .31187 L
.99505 .31188 L
.99627 .31188 L
Mistroke
.99759 .31188 L
.99884 .31188 L
1 .31188 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24307 m
.00123 .24307 L
.00236 .24307 L
.00365 .24307 L
.00488 .24307 L
.00706 .24308 L
.00942 .24308 L
.01203 .24309 L
.01479 .2431 L
.01975 .24313 L
.02486 .24317 L
.02966 .24321 L
.04057 .24334 L
.0517 .24351 L
.06188 .24369 L
.08481 .24424 L
.10474 .24485 L
.1265 .24565 L
.16918 .24764 L
.21027 .25003 L
.25393 .25305 L
.296 .25637 L
.33648 .25988 L
.37953 .26389 L
.42099 .26796 L
.46086 .27199 L
.50331 .27635 L
.54416 .28054 L
.58759 .28489 L
.62943 .28893 L
.66967 .29259 L
.7125 .2962 L
.75372 .29932 L
.79336 .30196 L
.83558 .30432 L
.8762 .30612 L
.89683 .30685 L
.91939 .30751 L
.94095 .30798 L
.95057 .30815 L
.961 .3083 L
.96647 .30836 L
.97151 .30841 L
.97624 .30845 L
.98143 .30848 L
.98609 .30851 L
.99045 .30852 L
.99286 .30853 L
.99505 .30853 L
.99627 .30854 L
Mistroke
.99759 .30854 L
.99884 .30854 L
1 .30854 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.19) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24618 m
.00123 .24618 L
.00236 .24618 L
.00365 .24618 L
.00488 .24618 L
.00706 .24619 L
.00942 .24619 L
.01203 .2462 L
.01479 .24621 L
.01975 .24624 L
.02486 .24627 L
.02966 .24631 L
.04057 .24642 L
.0517 .24657 L
.06188 .24674 L
.08481 .24724 L
.10474 .24779 L
.1265 .24851 L
.16918 .25031 L
.21027 .25247 L
.25393 .2552 L
.296 .2582 L
.33648 .26137 L
.37953 .265 L
.42099 .26868 L
.46086 .27234 L
.50331 .27629 L
.54416 .28008 L
.58759 .28403 L
.62943 .28769 L
.66967 .29101 L
.7125 .29429 L
.75372 .29712 L
.79336 .29951 L
.83558 .30166 L
.8762 .3033 L
.89683 .30397 L
.91939 .30456 L
.94095 .30499 L
.95057 .30514 L
.961 .30528 L
.96647 .30533 L
.97151 .30538 L
.97624 .30541 L
.98143 .30545 L
.98609 .30547 L
.99045 .30548 L
.99286 .30549 L
.99505 .30549 L
.99627 .30549 L
Mistroke
.99759 .30549 L
.99884 .3055 L
1 .3055 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 8.82906 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -24 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -24 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -24 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0.01)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.02)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(0.03)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(0.04)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.05)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.06)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.07)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24899 m
.00123 .24899 L
.00236 .24899 L
.00365 .24899 L
.00488 .24899 L
.00706 .249 L
.00942 .249 L
.01203 .24901 L
.01479 .24902 L
.01975 .24904 L
.02486 .24907 L
.02966 .24911 L
.04057 .24921 L
.0517 .24935 L
.06188 .2495 L
.08481 .24994 L
.10474 .25044 L
.1265 .2511 L
.16918 .25272 L
.21027 .25468 L
.25393 .25714 L
.296 .25986 L
.33648 .26273 L
.37953 .26601 L
.42099 .26935 L
.46086 .27266 L
.50331 .27623 L
.54416 .27967 L
.58759 .28325 L
.62943 .28657 L
.66967 .28959 L
.7125 .29255 L
.75372 .29513 L
.79336 .2973 L
.83558 .29925 L
.8762 .30074 L
.89683 .30134 L
.91939 .30188 L
.94095 .30227 L
.95057 .30241 L
.961 .30253 L
.96647 .30258 L
.97151 .30262 L
.97624 .30266 L
.98143 .30269 L
.98609 .30271 L
.99045 .30272 L
.99286 .30272 L
.99505 .30273 L
.99627 .30273 L
Mistroke
.99759 .30273 L
.99884 .30273 L
1 .30273 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "After a rapid period of relaxation, the ",
  Cell[BoxData[
      \(TraditionalForm\`n > 0\)]],
  " modes in the initial condition decay away and the solution settles down \
to a uniform temperature distribution. Again, in the long-time limit, the \
higher-order eigenmodes die away and the solution is approximately"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\  \[TildeEqual] 
        A\_o\  + \ \(A\_1\) \(\[ExponentialE]\^\(\(-\[Chi]\)\ \(\((\[Pi]/
                          L)\)\^2\) t\)\) \(cos(\[Pi]\ x/L)\)\)]],
  "."
}], "Text"],

Cell["\<\
Now the maximum deviation from equilibrium occurs at the edges, as \
the temperature gradients within the insulated slab equilibrate.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Homogeneous Mixed Boundary Conditions", "Section",
  CellTags->"c:21"],

Cell["\<\
\tLet us now turn to the case of no source and homogeneous mixed \
boundary conditions,\
\>", "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] \(\[PartialD]T\/\[PartialD]x\) \((0, t)\) = 
        a\ \ \(T(0, 
            t)\), \[IndentingNewLine]\[Kappa]\ \(\[PartialD]T\/\[PartialD]x\) \
\((L, t)\) = \(-b\)\ \(\(T(L, t)\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[{
  "If we again apply separation of variables to the heat equation, writing  \
",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\  = \ \(f(t)\)\ \(\[Psi](x)\)\)]],
  ", we are again led to Eqs. ",
  ButtonBox["(3.1.68)",
    ButtonData:>"(3.1.68)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.1.69)",
    ButtonData:>"(3.1.69)",
    ButtonStyle->"Hyperlink"],
  " for the functions ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  ". Equation ",
  ButtonBox["(3.1.68)",
    ButtonData:>"(3.1.68)",
    ButtonStyle->"Hyperlink"],
  " still has the general solution  ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \ A\ \[ExponentialE]\^\(\[Lambda]\ t\)\)]],
  ", and  Eq. ",
  ButtonBox["(3.1.69)",
    ButtonData:>"(3.1.69)",
    ButtonStyle->"Hyperlink"],
  " is ",
  "still",
  " an eigenvalue problem, with the general solution ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\[Psi](x)\  = \ A\ cos\ k\ x\  + B\ sin\ k\ x\),
            "TraditionalForm"], ","}], TraditionalForm]]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`k = \@\(\(-\[Lambda]\)/\[Chi]\)\)]],
  ". But now the boundary conditions on ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " are rather compicated:"
}], "Text",
  CellTags->"i:40"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] \(\[PartialD]\[Psi]\/\[PartialD]x\) \((0)\) \
= a\ \ \(\[Psi](
            0)\), \[IndentingNewLine]\[Kappa]\ \(\[PartialD]\[Psi]\/\
\[PartialD]x\) \((L)\) = \(-b\)\ \(\(\[Psi](L)\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[{
  "When these boundary conditions are used in the general solution  we obtain \
two coupled homogeneous equations for ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Kappa]\ k\ B\ \  = 
      a\ A, \[IndentingNewLine]\[Kappa]\ k\ \((\(-A\)\ sin\ k\ L + \ 
            B\ cos\ k\ L)\) = \(-\(b(
          A\ cos\ k\ L\  + \ B\ sin\ k\ L)\)\)\)]]], "NumberedEquation",
  CellTags->"(3.1.74)"],

Cell[TextData[{
  "A nontrivial solution to these coupled equations exists only for values of \
",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " that satisfy "
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\([\ 
            a\ b\  - \ \(\[Kappa]\^2\) k\^2]\)\ sin\ k\ L = \(\(-\((a + 
                b)\)\) \(\[Kappa]\)\(\ \)\(k\)\(\ \)\(cos\)\(\ \)\(k\)\(\ \
\)\(L\)\(\ \)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.75)"],

Cell[TextData[{
  "Again, we have an eigenvalue problem for the wavenumbers ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". Unfortunately, this equation cannot be solved analytically  for ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". However, numerical solutions can be found for specific values of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " using the numerical techniques developed in Chapter ",
  ButtonBox["9",
    ButtonData:>{"Chapter9.nb", None},
    ButtonStyle->"Hyperlink"],
  ". For example, if we take ",
  Cell[BoxData[
      \(TraditionalForm\`a = \(b = 2  \[Kappa]/L\)\)]],
  ", then Eq. ",
  ButtonBox["(3.1.75)",
    ButtonData:>"(3.1.75)",
    ButtonStyle->"Hyperlink"],
  " can be written as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\((4 - s\^2)\),
            "TraditionalForm"], 
          FormBox[\(sin\ s + 4\ s\ cos\ s = 0\),
            "TraditionalForm"]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`s \[Congruent] k\ L\)]],
  ". The first four solutions for ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " can be found graphically as shown in Cell ",
  ButtonBox["3.14",
    ButtonData:>"Cell 3.14",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Sin[s\ ] \((\(-s^2\) + \ 4)\) + 4\ s\ Cos[s], {s, 0, 10}, 
        AxesLabel \[Rule] {"\<s\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.14"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.416941 0.0053638 [
[.21429 .40444 -3 -9 ]
[.21429 .40444 3 0 ]
[.40476 .40444 -3 -9 ]
[.40476 .40444 3 0 ]
[.59524 .40444 -3 -9 ]
[.59524 .40444 3 0 ]
[.78571 .40444 -3 -9 ]
[.78571 .40444 3 0 ]
[.97619 .40444 -6 -9 ]
[.97619 .40444 6 0 ]
[1.025 .41694 0 -6 ]
[1.025 .41694 10 6 ]
[.01131 .09511 -18 -4.5 ]
[.01131 .09511 0 4.5 ]
[.01131 .20239 -18 -4.5 ]
[.01131 .20239 0 4.5 ]
[.01131 .30966 -18 -4.5 ]
[.01131 .30966 0 4.5 ]
[.01131 .52422 -12 -4.5 ]
[.01131 .52422 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .41694 m
.21429 .42319 L
s
[(2)] .21429 .40444 0 1 Mshowa
.40476 .41694 m
.40476 .42319 L
s
[(4)] .40476 .40444 0 1 Mshowa
.59524 .41694 m
.59524 .42319 L
s
[(6)] .59524 .40444 0 1 Mshowa
.78571 .41694 m
.78571 .42319 L
s
[(8)] .78571 .40444 0 1 Mshowa
.97619 .41694 m
.97619 .42319 L
s
[(10)] .97619 .40444 0 1 Mshowa
.125 Mabswid
.07143 .41694 m
.07143 .42069 L
s
.11905 .41694 m
.11905 .42069 L
s
.16667 .41694 m
.16667 .42069 L
s
.2619 .41694 m
.2619 .42069 L
s
.30952 .41694 m
.30952 .42069 L
s
.35714 .41694 m
.35714 .42069 L
s
.45238 .41694 m
.45238 .42069 L
s
.5 .41694 m
.5 .42069 L
s
.54762 .41694 m
.54762 .42069 L
s
.64286 .41694 m
.64286 .42069 L
s
.69048 .41694 m
.69048 .42069 L
s
.7381 .41694 m
.7381 .42069 L
s
.83333 .41694 m
.83333 .42069 L
s
.88095 .41694 m
.88095 .42069 L
s
.92857 .41694 m
.92857 .42069 L
s
.25 Mabswid
0 .41694 m
1 .41694 L
s
gsave
1.025 .41694 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .09511 m
.03006 .09511 L
s
[(-60)] .01131 .09511 1 0 Mshowa
.02381 .20239 m
.03006 .20239 L
s
[(-40)] .01131 .20239 1 0 Mshowa
.02381 .30966 m
.03006 .30966 L
s
[(-20)] .01131 .30966 1 0 Mshowa
.02381 .52422 m
.03006 .52422 L
s
[(20)] .01131 .52422 1 0 Mshowa
.125 Mabswid
.02381 .12193 m
.02756 .12193 L
s
.02381 .14875 m
.02756 .14875 L
s
.02381 .17557 m
.02756 .17557 L
s
.02381 .22921 m
.02756 .22921 L
s
.02381 .25603 m
.02756 .25603 L
s
.02381 .28285 m
.02756 .28285 L
s
.02381 .33648 m
.02756 .33648 L
s
.02381 .3633 m
.02756 .3633 L
s
.02381 .39012 m
.02756 .39012 L
s
.02381 .44376 m
.02756 .44376 L
s
.02381 .47058 m
.02756 .47058 L
s
.02381 .4974 m
.02756 .4974 L
s
.02381 .06829 m
.02756 .06829 L
s
.02381 .04147 m
.02756 .04147 L
s
.02381 .01466 m
.02756 .01466 L
s
.02381 .55104 m
.02756 .55104 L
s
.02381 .57785 m
.02756 .57785 L
s
.02381 .60467 m
.02756 .60467 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .41694 m
.04262 .42526 L
.06244 .43306 L
.07216 .43622 L
.08255 .43897 L
.08852 .44021 L
.09396 .4411 L
.09658 .44145 L
.09942 .44177 L
.1021 .44201 L
.10337 .4421 L
.10458 .44217 L
.10574 .44223 L
.10701 .44229 L
.10817 .44232 L
.10924 .44234 L
.11051 .44236 L
.11166 .44236 L
.1123 .44235 L
.11299 .44234 L
.11425 .44231 L
.11534 .44228 L
.11654 .44222 L
.11897 .44208 L
.12121 .4419 L
.12331 .44169 L
.12851 .44099 L
.13326 .44014 L
.14393 .43749 L
.15384 .43413 L
.16302 .43029 L
.18378 .41931 L
.22304 .39284 L
.26079 .3674 L
.28014 .35738 L
.28544 .35522 L
.29102 .35326 L
.29625 .35175 L
.301 .35066 L
.30335 .35023 L
.30591 .34984 L
.30832 .34955 L
.31054 .34935 L
.31176 .34927 L
.3129 .34922 L
.31415 .34918 L
.31485 .34917 L
.31549 .34916 L
.31678 .34917 L
.31751 .34918 L
Mistroke
.31818 .3492 L
.31942 .34925 L
.32074 .34934 L
.32198 .34944 L
.32312 .34955 L
.3257 .34988 L
.32798 .35025 L
.33038 .35072 L
.33454 .35176 L
.3391 .3532 L
.34934 .35764 L
.35865 .36312 L
.37958 .38041 L
.3987 .40179 L
.41948 .4301 L
.46031 .49474 L
.48061 .52715 L
.49963 .55489 L
.51806 .57734 L
.5281 .58711 L
.53743 .59432 L
.5425 .59741 L
.5471 .59968 L
.55221 .60158 L
.55501 .60233 L
.55627 .6026 L
.55766 .60285 L
.55874 .60301 L
.55991 .60314 L
.56114 .60324 L
.56229 .6033 L
.56343 .60332 L
.56451 .6033 L
.56549 .60326 L
.56655 .60318 L
.5677 .60307 L
.56897 .60289 L
.57155 .60239 L
.57393 .60175 L
.57617 .601 L
.58086 .59895 L
.58599 .59595 L
.59633 .58745 L
.60591 .57663 L
.61483 .56401 L
.63526 .52612 L
.65384 .48157 L
.69379 .36061 L
.73223 .22949 L
.75169 .16597 L
Mistroke
.77311 .10409 L
.78291 .07991 L
.79344 .05751 L
.80332 .04034 L
.81248 .02808 L
.81738 .02309 L
.8226 .01901 L
.82558 .01727 L
.82704 .01658 L
.82839 .01604 L
.82959 .01563 L
.83091 .01527 L
.83223 .015 L
.83296 .01489 L
.83363 .01481 L
.83488 .01473 L
.83559 .01472 L
.83624 .01473 L
.83744 .01481 L
.83871 .01498 L
.83984 .0152 L
.84091 .01547 L
.84333 .01631 L
.84594 .01757 L
.84834 .01905 L
.85373 .02353 L
.85847 .0288 L
.86354 .03581 L
.87267 .05204 L
.88352 .07737 L
.89337 .10596 L
.91257 .17629 L
.93337 .27227 L
.97431 .50545 L
.97619 .51705 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003ooooooona
ooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00oooooona
ooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00oooooona
ooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`007oooool00ol0003ooooooooo
o`3oooooohoooooo000Oooooo`03o`000?oooooooooo0?ooooooSoooool001oooooo00?o0000oooo
ooooool0oooooon?ooooo`007oooool00ol0003oooooooooo`3oooooohoooooo000Oooooo`03o`00
0?oooooooooo0?ooooooSoooool001oooooo00?o0000ooooooooool0oooooon?ooooo`007oooool3
o`000?oooooo<oooool7o`0005Gooooo000Oooooo`03o`000?oooooooooo0?oooooo<Oooool2o`00
00Oooooo0_l0001Cooooo`007oooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1@ooooo`007oooool00ol0003oooooooooo`3ooooooboooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1?ooooo`007oooool00ol0003ooooooooo
o`3oooooobkooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1>ooooo`007oooool0
0ol0003oooooooooo`3oooooobgooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=
ooooo`007oooool00ol0003oooooooooo`3oooooobcooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1=ooooo`007oooool00ol0003oooooooooo`3oooooob_ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`1<ooooo`007oooool00ol0003oooooooooo`3oooooob[ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1;ooooo`007oooool00ol0003ooooooooo
o`3oooooobWooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1;ooooo`007oooool3
o`000?oooooo:Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04[ooooo000Ooooo
o`03o`000?oooooooooo0?oooooo:?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
04[ooooo000Oooooo`03o`000?oooooooooo0?oooooo:?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo04Wooooo000Oooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo04Wooooo000Oooooo`03o`000?oooooooooo0?oooooo9ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Sooooo000Oooooo`03o`000?oooooo
oooo0?oooooo9oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Sooooo000Ooooo
o`03o`000?oooooooooo0?oooooo9_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
04Oooooo000Oooooo`03o`000?oooooooooo0?oooooo9_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo04Oooooo000Oooooo`03o`000?oooooooooo0?oooooo9Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo04Oooooo000Oooooo`03o`000?oooooooooo0?oooooo9Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04Kooooo000Oooooo`?o0000oooooolT
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0A_ooool001oooooo00?o0000oooo
ooooool0oooooolTooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0AOooool001oo
oooo00?o0000ooooooooool0oooooolTooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0AOooool001oooooo00?o0000ooooooooool0oooooolSooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0AOooool001oooooo00?o0000ooooooooool0oooooolSooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0A?ooool001oooooo00?o0000ooooooooool0oooooolR
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0A?ooool001oooooo00?o0000oooo
ooooool0oooooolRooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0@oooool001oo
oooo00?o0000ooooooooool0oooooolQooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0@oooool000[ooooo00Kok^k^odA4A?l0003o0000oeEEEOo^k^h4ooooo`04okZj^_l@413o0000
ogMgM`Oooooo00?o0000ooooooooool0oooooolQooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0@oooool000[ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`06olc<c?lb
<S;ok^k^onk^k_lQ8B7oZJVY1_ooool00ol0003oooooooooo`3oooooob3ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`12ooooo`002_ooool00ol@413oooooooooo`02ooooo`06o`00
0?oooooooooooooooom4A4CoZJVY0_ooool00onYZJWo<S8booooo`05ooooo`Co0000oooooolOoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0@_ooool00003ooooool0003o000000Go
00000_ooool00ol0003ok^k^ooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo8?ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo04;ooooo000:ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE0oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolO
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0@Oooool000[ooooo00Ko8B4QofIV
I_l0003o0000oeEEEOo^k^h3ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3ooooooaoooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`11ooooo`002_ooool00on7QhOoIVIVooooo`06ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A4
1_ooool00ol0003oooooooooo`3ooooooakooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`11ooooo`002oooool00olb<S;oIVIVomgMg@05ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;o
c<c<1_ooool00ol0003oooooooooo`3ooooooakooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`10ooooo`003?ooool01?mgMgOo410@o`000?lQ8B44ooooo`04okZj^_l@413o410@olc<
c0Oooooo00?o0000ooooooooool0oooooolMooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0@?ooool001oooooo00?o0000ooooooooool0oooooolMooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0@?ooool001oooooo00?o0000ooooooooool0oooooolMooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0?oooool001oooooo00?o0000ooooooooool0oooo
oolLooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0?oooool001oooooo00?o0000
ooooooooool0oooooolLooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0?oooool0
01oooooo0ol0003ooooooacooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0ooooo
o`007oooool00ol0003oooooooooo`3ooooooa_ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0nooooo`007oooool00ol0003oooooooooo`3ooooooa_ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0nooooo`007oooool00ol0003oooooooooo`3ooooooa_ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0nooooo`007oooool00ol0003oooooooooo`3o
oooooa[ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0nooooo`007oooool00ol0
003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0moooo
o`007oooool00ol0003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0mooooo`007oooool00ol0003oooooooooo`3ooooooaWooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0mooooo`007oooool00ol0003oooooooooo`3ooooooaWooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0looooo`007oooool00ol0003oooooooooo`3o
oooooaWooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0looooo`007oooool3o`00
0?oooooo6?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03cooooo000Oooooo`03
o`000?oooooooooo0?oooooo6?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03co
oooo000Oooooo`03o`000?oooooooooo0?oooooo6?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo03_ooooo000Oooooo`03o`000?oooooooooo0?oooooo5oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo03_ooooo000Oooooo`03o`000?oooooooooo0?oooooo5oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo03_ooooo000Oooooo`03o`000?oooooooooo
0?oooooo5oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03_ooooo000Oooooo`03
o`000?oooooooooo0?oooooo5_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03[o
oooo000Oooooo`03o`000?oooooooooo0?oooooo5_ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo03[ooooo000Oooooo`03o`000?oooooooooo0?oooooo5_ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo03[ooooo000Oooooo`03o`000?oooooooooo0?oooooo5Oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo03[ooooo000Oooooo`?o0000oooooolEoooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>Oooool001oooooo00?o0000oooooooo
ool0oooooolEooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>Oooool001oooooo
00?o0000ooooooooool0oooooolDooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
>Oooool001oooooo00?o0000ooooooooool0oooooolDooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool0>Oooool001oooooo00?o0000ooooooooool0oooooolDooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool0>?ooool001oooooo00?o0000ooooooooool0oooooolCoooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0>?ooool001oooooo00?o0000oooooooo
ool0oooooolCooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0>?ooool001oooooo
00?o0000ooooooooool0oooooolCooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
>?ooool000gooooo0_l000000ol@413oooooooooo`02ooooo`04okZj^_l@413o0000ogMgM`Oooooo
00?o0000ooooooooool0oooooolBooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
>?ooool000kooooo00?o0000ooooooooool00_ooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Ko
oooo00?o0000ooooooooool0oooooolBooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0=oooool000[ooooo1_l00003ooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1_ooool00ol0
003oooooooooo`3ooooooa;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0goooo
o`0000?oooooo`000?l000001Ol00002ooooo`05ofIVI_nYZJWoooooooooool000001?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo1?l0003ooooooa3ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0gooooo`002_ooool01Oo^k^ko8B4Qonk^k_oooooo0000
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?oooooo4Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03Oooooo000;ooooo`04
ojVYZOmVIVKoooooo`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?oooooo4Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
03Kooooo000<ooooo`03odA4A?o<c<co000000Cooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@6
ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo03Kooooo000<ooooo`03omgMgOm4A4Co000000Cooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<
c<`6ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo03Kooooo000=ooooo`03ohN7Qol0003ooooo00Cooooo00Co^[Zjoa0@4?l@413oc<c<1ooo
ool00ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0fooooo`007oooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`0fooooo`007oooool00ol0003oooooooooo`3oooooo`oooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0eooooo`007oooool00ol0003oooooooooo`3oooooo`oo
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0eooooo`007oooool00ol0003ooooo
ooooo`3oooooo`kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0eooooo`007ooo
ool3o`000?oooooo3_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo03Gooooo000O
ooooo`03o`000?oooooooooo0?oooooo3_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo03Cooooo000Oooooo`03o`000?oooooooooo0?oooooo3_ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo03Cooooo000Oooooo`03o`000?oooooooooo0?oooooo3Oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo03Cooooo000Oooooo`03o`000?oooooooooo0?oooooo
3Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo03Cooooo000Oooooo`03o`000?oo
oooooooo0?oooooo3Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo03Cooooo000O
ooooo`03o`000?oooooooooo0?oooooo3?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo03?ooooo000Oooooo`03o`000?oooooooooo0?oooooo3?ooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo03?ooooo000Oooooo`03o`000?oooooooooo0?oooooo3?ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo03?ooooo000Oooooo`03o`000?oooooooooo0?oooooo
2oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03?ooooo000Oooooo`?o0000oooo
ool;ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0<_ooool001oooooo00?o0000
ooooooooool0ooooool;ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0<_ooool0
01oooooo00?o0000ooooooooool0ooooool;ooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool0<_ooool001oooooo00?o0000ooooooooool0ooooool:ooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool0<_ooool001oooooo00?o0000ooooooooool0ooooool:ooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool0<_ooool001oooooo00?o0000ooooooooool0oooo
ool:ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0<Oooool001oooooo00?o0000
ooooooooool0ooooool9ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0<Oooool0
01oooooo00?o0000ooooooooool0ooooool9ooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool0<Oooool001oooooo00?o0000ooooooooool0ooooool9ooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool0<Oooool001oooooo00?o0000ooooooooool0ooooool8ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool0<Oooool001oooooo00?o0000ooooooooool0oooo
ool8ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0<?ooool001oooooo0ol0003o
ooooo`Sooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0`ooooo`007oooool00ol0
003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0`oooo
o`007oooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0D_ooool00ol0003o
ooooooooo`0`ooooo`007oooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
D_ooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003oooooooooo`3oooooo`Oooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`0_ooooo`007oooool00ol0003oooooooooo`3o
ooooo`Kooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0_ooooo`007oooool00ol0
003oooooooooo`3oooooo`Kooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0_oooo
o`002_ooool6o`0000Cooooo00Co^[Zjoa0@4?l0003oMgMg1oooool00ol0003oooooooooo`3ooooo
o`Kooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0_ooooo`002_ooool00onHV9So
0000olc<c002ooooo`06oa0@4?ooooooooooooooooo<c<co<S8b0_o^k^h00olQ8B7oZJVYooooo`05
ooooo`03o`000?oooooooooo0?oooooo1Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo02oooooo000;ooooo`03oiRHV?l0003oc<c<00Gooooo00KoA4A4ojVYZOooooooooooojVYZOlb
<S86ooooo`03o`000?oooooooooo0?oooooo1Oooool00ol0003oooooooooo`1Eooooo`03o`000?oo
oooooooo02oooooo00000ooooooo0000o`000005o`0000Cooooo00?oZJVYoa0@4?o<c<`01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo1?l0003oooooo`Cooooo00?o0000
ooooooooool0E_ooool00ol0003oooooooooo`0^ooooo`003Oooool00oo<c<co410@olc<c003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
o`Gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0^ooooo`003_ooool00onYZJWo
<S8booooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooo`Cooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0^ooooo`00
3oooool01_l0003oooooooooooooooooA4A4ojVYZ@;ooooo00?oZJVYodA4A?ooool01Oooool00ol0
003oooooooooo`3oooooo`Cooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0^oooo
o`002_ooool01_l0003oQhN7onk^k_ooooooMgMgoc8b<P?ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b
<_o<c<`6ooooo`03o`000?oooooooooo0?oooooo1?ooool00ol0003oooooooooo`1Gooooo`03o`00
0?oooooooooo02kooooo000:ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1?ooool01?nj^[[o
410@oa0@4?o<c<`7ooooo`03o`000?oooooooooo0?oooooo0oooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo02kooooo000Oooooo`03o`000?oooooooooo0?oooooo0oooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo02gooooo000Oooooo`03o`000?oooooooooo0?oooooo
0oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02gooooo000Oooooo`03o`000?oo
oooooooo0?oooooo0_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo02gooooo000O
ooooo`03o`000?oooooooooo0?oooooo0_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooo
oooo02gooooo000Oooooo`?o0000ooooool2ooooo`03o`000?oooooooooo05[ooooo00?o0000oooo
ooooool0;Oooool001oooooo00?o0000ooooooooool0ooooool2ooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool0;?ooool001oooooo00?o0000ooooooooool0ooooool1ooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool0;?ooool001oooooo00?o0000ooooooooool0oooo
ool1ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0;?ooool001oooooo00?o0000
ooooooooool0ooooool1ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0;?ooool0
01oooooo00?o0000ooooooooool0JOooool:o`0008cooooo00?o0000ooooooooool0GOooool00ol0
003oooooooooo`0/ooooo`007oooool00ol0003oooooooooo`1Uooooo`Co00002_ooool3o`0008Wo
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0/ooooo`007oooool00ol0003ooooo
ooooo`1Qooooo`Co00004Oooool3o`0008Kooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ooooo`0[ooooo`007oooool00ol0003oooooooooo`1Oooooo`;o00006?ooool3o`0008;ooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`0[ooooo`007oooool00ol0003oooooooooo`1M
ooooo`;o00007Oooool2o`00083ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0[
ooooo`007oooool3o`0005_ooooo0_l0000Qooooo`;o0000O_ooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo02_ooooo000Oooooo`03o`000?oooooooooo05Wooooo0_l0000Uooooo`03
o`000?oooooooooo07_ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0[ooooo`00
7oooool00ol0003oooooooooo`1Gooooo`;o0000:?ooool00ol0003oooooooooo`1iooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool0:oooool001oooooo00?o0000ooooooooool0E_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0HOoo
ool00ol0003oooooooooo`0Zooooo`007oooool00ol0003oooooooooo`1Dooooo`;o0000;Oooool0
0ol0003oooooooooo`1gooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0:_ooool0
01oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
07Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Zooooo`007oooool00ol0003o
ooooooooo`13ooooo`Ko00002Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oo
oooo0_l000000ol@413oooooooooo`11ooooo`06onk^k_m4A4Co0000o`000?mEEEGok^k^8Oooool0
0ol0003oooooooooo`0Oooooo`06onk^k_m4A4Co0000o`000?m4A4Cok^k^?Oooool00ol0003ooooo
ooooo`04o`000003oa0@4?oooooooooo00;ooooo00Co^[Zjoa0@4?l0003oMgMg7Oooool001oooooo
00?o0000ooooooooool0@oooool00onHV9So0000olc<c002ooooo`03oa0@4?oooooooooo00Gooooo
0_l0000dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@_ooool01_mEEEGoMgMg
ooooooooooooMgMgoeEEEB7ooooo00?o0000ooooooooool07oooool01_lb<S;oMgMgonk^k_o^k^ko
MgMgoc8b<Sgooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`06olc<c?lb
<S;ok^k^onk^k_lQ8B7oZJVY7?ooool001oooooo00?o0000ooooooooool0A?ooool00onHV9So0000
olc<c008ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00oooool6o`0004?ooooo
00?o410@ooooooooool00_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0looooo`05o`000?ooooooooooooooool0
00001Oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<Qcooooo000Oooooo`03o`000?oooooooooo
04Gooooo00?oZJVYoa0@4?o<c<`01Oooool2o`0003Sooooo00?o0000ooooooooool00_ooool01OmV
IVKoZJVYoooooooooooo000004Cooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo023ooooo00Ko<S8bogMgMoo^k^kok^k^ogMgMolb<S8nooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01[o
oooo000Oooooo`03o`000?oooooooooo04Kooooo00?oc<c<oa0@4?o<c<`00oooool00ol0003ooooo
ooooo`0iooooo`09o`000?ooooooooooooooooo^k^ko8B4Qonk^k_oooooo000004Cooooo00Ko0000
oeEEEOo^k^koooooogMgMomEEEDPooooo`03o`000?oooooooooo023ooooo00?ogMgMo`000?l00000
0_l000000ooMgMgoooooooooo`0looooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01[ooooo000Oooooo`?o0000Aoooool01OnYZJWo<S8b
oooooooooooo000003gooooo00So0000ooooooooooooooooojVYZOmVIVKoooooo`0004Cooooo00Ko
8B4QofIVI_l0003o0000oeEEEOo^k^hOooooo`03o`000?oooooooooo027ooooo00Ko<S8bofIVI_o^
k^kok^k^ofIVI_lb<S8nooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01[ooooo000Oooooo`03o`000?oooooooooo04Sooooo0ol0000o
ooooo`07o`000?oooooooooooooooom4A4Coc<c<o`000014ooooo`03ohN7QomVIVKooooo02;ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo
00Go0000ooooooooooooooooo`000005ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A47?ooool0
01oooooo00?o0000ooooooooool0@oooool01_l0003oQhN7onk^k_ooooooMgMgo`0004;ooooo00Ko
0000oooooooooooogMgModA4A?l00015ooooo`03oc8b<_mVIVKogMgM027ooooo00?o0000oooooooo
ool08Oooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<Skooooo00Go0000ooooool0003oA4A4o`00
0005ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<7?ooool001oooooo00?o0000ooooooooool0
@oooool00onYZJWo<S8bo`000002o`000003onk^k_oooooooooo047ooooo00Go0000oooooooooooo
QhN7o`000016ooooo`04ogMgMol@413o0000ob4Q8Akooooo00?o0000ooooooooool08_ooool01_o^
k^koA4A4o`000?l0003oA4A4onk^kSoooooo00Co0000olc<c?mEEEGo00001_ooool01?nj^[[o410@
oa0@4?o<c<`Mooooo`007oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0JOooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02Sooooo
000Oooooo`03o`000?oooooooooo04?ooooo0_l00018ooooo`03o`000?oooooooooo06Wooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`0Xooooo`007oooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo01cooooo00Ko410@oc8b<_l0003o0000ob4Q8Oo<c<`6ooooo`007ooo
ool00ol0003oooooooooo`10ooooo`;o0000COooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo06Sooooo00?o0000ooooooooool07?ooool01_l0003oZJVYooooooooooooZJVYoa0@40Ko
oooo000Oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool07oooool00oo<c<co0000
ooooo`05ooooo`007oooool00ol0003oooooooooo`0mooooo`;o0000DOooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool06oooool00onYZJWo8B4Qo`00
0002o`000003ohN7Qooooooooooo00Cooooo000Foooooooo0000P_l0000=ooooo`04o`000?nHV9So
^[ZjokZj^PSooooo000Oooooo`03o`000?oooooo000000;o00003_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool2o`0000[ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03oooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool05?ooool01_l0003o^[Zjooooooo^k^koMgMgo`0000Kooooo000Oooooo`03o`00
0?oooooooooo00;ooooo0ol0000cooooo`;o00003?ooool00ol0003oooooooooo`16ooooo`04o`00
0?ooooooooooo`0004Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`06
olc<c?lQ8B7o0000o`000?lb<S;o00001_ooool001oooooo00?o0000ooooooooool01Oooool2o`00
02oooooo0_l0001Kooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`0Wooooo`007oooool00ol0003oooooooooo`07ooooo`?o0000:_ooool2o`0005ko
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo02Ko
oooo000Oooooo`03o`000?oooooooooo00[ooooo0_l0000Vooooo`;o0000HOooool00ol0003ooooo
ooooo`1Nooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool09_ooool001oooooo00?o
0000ooooooooool03?ooool3o`00027ooooo0_l0001Sooooo`03o`000?oooooooooo05gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Vooooo`007oooool00ol0003oooooooooo`0?
ooooo`Co00006_ooool3o`0006Kooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Kooooo000Oooooo`03o`000?oooooooooo01?ooooo0ol0000Coooo
o`Co0000J_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09_ooool001oooooo00?o0000ooooooooool05_ooool4o`0000Wooooo1_l0001^ooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Vooooo`00
7oooool3o`0001[ooooo2_l0001dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`0Uooooo`007oooool00ol0003oooooooooo`2Iooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0Uooooo`007oooool0
0ol0003oooooooooo`2Iooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`0Uooooo`007oooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo
05Kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Uooooo`007oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`0Uooooo`007oooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo05Cooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Tooooo`007oooool00ol0003ooooooooo
o`2Looooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`0Tooooo`007oooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`0Tooooo`007oooool00ol0003oooooooooo`2Moooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0Toooo
o`007oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool0Loooool00ol0003oooooooooo`0Tooooo`007oooool00ol0003oooooooooo`2Nooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0Tooooo`007ooo
ool3o`0009oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1eooooo`03o`000?oo
oooooooo02?ooooo000Oooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`1eooooo`03o`000?oooooooooo02?ooooo000Oooooo`03o`000?oooooooooo
0:3ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo
02?ooooo000Oooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`1fooooo`03o`000?oooooooooo02?ooooo000Oooooo`03o`000?oooooooooo0:7ooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo02?ooooo
000Oooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`1fooooo`03o`000?oooooooooo02?ooooo000Oooooo`03o`000?oooooooooo0:?ooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo02;ooooo000Ooooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1hoooo
o`03o`000?oooooooooo02;ooooo000Oooooo`03o`000?oooooooooo0:Cooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo02;ooooo000Oooooo`03o`00
0?oooooooooo0:Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1iooooo`03o`00
0?oooooooooo02;ooooo000Oooooo`?o0000YOooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool08_ooool001oooooo00?o0000ooooooooool0Y_ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool08Oooool0
01oooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool08Oooool001oooooo00?o0000ooooooooool0Yoooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool08Oooool001oooooo
00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo07cooooo
00?o0000ooooooooool08Oooool001oooooo00?o0000ooooooooool0ZOooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool08Oooool001oooooo00?o0000
ooooooooool0ZOooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo07kooooo00?o0000
ooooooooool08?ooool001oooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool08?ooool000[ooooo1_l00004ooooo`04
okZj^_l@413o0000ogMgM`Oooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0:;ooooo000:ooooo`03oiRHV?l0003oc<c<00;ooooo00Ko410@oooooooo
ooooooooolc<c?lb<S82onk^kP03ob4Q8OnYZJWooooo00Gooooo00?o0000ooooooooool0Zoooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0:;ooooo000;ooooo`03oiRHV?l0003oc<c<
00Gooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S86ooooo`Co0000Zoooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo0:;ooooo000<ooooo`03ojVYZOl@413oc<c<00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:gooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`2Sooooo`003Oooool00oo<c<co410@olc<c003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2]oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Xoooool000kooooo00?oZJVYoc8b<_oo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0[_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:Cooooo000?ooooo`06o`00
0?oooooooooooooooom4A4CoZJVY0_ooool00onYZJWoA4A4ooooo`05ooooo`03o`000?oooooooooo
0:oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2Tooooo`002_ooool01_l0003o
QhN7onk^k_ooooooMgMgoc8b<P?ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`6ooooo`03o`00
0?oooooooooo0:oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Uooooo`002_oo
ool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPCooooo00Co^[Zjoa0@4?l@413oc<c<1oooool00ol0
003oooooooooo`2`ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Y_ooool001oo
oooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0:Ko
oooo000Oooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`2Wooooo`007oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0Yoooool001oooooo0ol0002booooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0Z?ooool001oooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo0:Sooooo000Oooooo`03o`000?oooooooooo0;Cooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`2Yooooo`007oooool00ol0003oooooooooo`2dooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0Z_ooool001oooooo00?o0000ooooooooool0]Ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0:[ooooo000Oooooo`03o`000?oooooo
oooo0;Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2[ooooo`007oooool00ol0
003oooooooooo`2gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Zoooool001oo
oooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0:co
oooo000Oooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`2]ooooo`007oooool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0[Oooool001oooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo0:kooooo000Oooooo`?o0000^oooool2o`0001oooooo00?o0000oooo
ooooool0[oooool001oooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo0;3ooooo000Oooooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`2aooooo`007oooool00ol0003oooooooooo`2oooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0/_ooool001oooooo00?o0000ooooooooool0`?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0;?ooooo000Oooooo`03o`000?oooooooooo
0<7ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2dooooo`007oooool00ol0003o
ooooooooo`32ooooo`;o00004_ooool00ol0003oooooooooo`2eooooo`007oooool00ol0003ooooo
ooooo`34ooooo`;o00003_ooool2o`000;Sooooo000Oooooo`03o`000?oooooooooo0<Kooooo0_l0
000:ooooo`;o0000^_ooool001oooooo00?o0000ooooooooool0b?ooool:o`000;cooooo000Ooooo
o`?o0000oooooon?ooooo`007oooool00ol0003oooooooooo`3oooooohoooooo000Oooooo`03o`00
0?oooooooooo0?ooooooSoooool001oooooo00?o0000ooooooooool0oooooon?ooooo`007oooool0
0ol0003oooooooooo`3oooooohoooooo000Oooooo`03o`000?oooooooooo0?ooooooSoooool00?oo
oooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oo
oooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oo
oooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.870074, -84.7067, \
0.0410431, 0.72875}}]
}, Open  ]],

Cell[TextData[{
  "The plot shows that there are solutions at ",
  Cell[BoxData[
      \(TraditionalForm\`s \[TildeEqual] 1.7, 4, 7, \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`9.5\)]],
  ". The solution at ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0\)]],
  " is trivial, and those at ",
  Cell[BoxData[
      \(TraditionalForm\`s < 0\)]],
  " provide modes that are merely opposite in sign to those with ",
  Cell[BoxData[
      \(TraditionalForm\`s > 0\)]],
  ". The corresponding ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Lambda]\)\(-\)\)\)]],
  "values can then be picked out using the following table of ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " commands:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Lambda]\  = \(-Table[
              s /. \(FindRoot[
                    Sin[s\ ] \((\(-s^2\) + \ 4)\) + 4\ s\ Cos[s], {s, 
                      1.8 + 2.5  n}]\)[\([1]\)], {n, 0, 3}]^2\) \[Chi]/
          L^2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.15"],

Cell[BoxData[
    \({\(-\(\(2.960695537584314`\ \[Chi]\)\/L\^2\)\), \
\(-\(\(16.463433474377243`\ \[Chi]\)\/L\^2\)\), \(-\(\(46.93944731976795`\ \
\[Chi]\)\/L\^2\)\), \(-\(\(96.55736812178876`\ \[Chi]\)\/L\^2\)\)}\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "In Cell ",
  ButtonBox["3.16",
    ButtonData:>"Cell 3.16",
    ButtonStyle->"Hyperlink"],
  ", we show the form of the corresponding  eigenmodes, taking ",
  Cell[BoxData[
      \(TraditionalForm\`A = 1\)]],
  " and with ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  "  given in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " by Eq ",
  ButtonBox["(3.1.74)",
    ButtonData:>"(3.1.74)",
    ButtonStyle->"Hyperlink"],
  ". The time dependence ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[Lambda]\_n\ t\)\)]],
  " of the modes is also displayed."
}], "Text",
  CellTags->"i:38"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(L = 1; \[Chi] = 1; a = \(b = 2\ \[Kappa]/L\);\), "\n", 
    \(\(k = \@\(\(-\[Lambda]\)/\[Chi]\);\)\), "\n", 
    \(\(\(A = 1;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(B = \ a\ \ A/\((\[Kappa]\ k\ )\);\)\), "\n", 
    \(\(\(\[Psi][n_, 
          x_]\  := \ \ A\ Cos[\@\(\(-\[Lambda][\([n]\)]\)/\[Chi]\)\ x]\  + \ 
          B[\([n]\)]\ Sin[\@\(\(-\[Lambda][\([n]\)]\)/\[Chi]\)\ x];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(p[n_, t_]\  := \ 
        Plot[\ Exp[\[Lambda][\([n]\)] t]\ \[Psi][n, x], {x, 0, L}, 
          DisplayFunction \[Rule] Identity, PlotRange \[Rule] {\(-2\), 2}, 
          PlotLabel \[Rule] "\<n = \>" <> ToString[n]];\)\), "\n", 
    \(\(Table[
        Show[GraphicsArray[Table[{{p[1, t], p[2, t]}, {p[3, t], p[4, t]}}]], 
          DisplayFunction \[Rule] $DisplayFunction], {t, 0, 
          0.2,  .01}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.16"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .46353 m
.03279 .46611 L
.04262 .4682 L
.04758 .46895 L
.0503 .46927 L
.05288 .46952 L
.05528 .46971 L
.05655 .46978 L
.05789 .46985 L
.05902 .4699 L
.06026 .46994 L
.06139 .46996 L
.06244 .46997 L
.0631 .46997 L
.06379 .46997 L
.06504 .46996 L
.06581 .46995 L
.06653 .46993 L
.06788 .46989 L
.06917 .46983 L
.07036 .46977 L
.07305 .46958 L
.07529 .46937 L
.07776 .4691 L
.08274 .4684 L
.08819 .4674 L
.09404 .46605 L
.10458 .46293 L
.11475 .45907 L
.12582 .45396 L
.14594 .44235 L
.18672 .41058 L
.22599 .37175 L
.26374 .32969 L
.30394 .28331 L
.34263 .24065 L
.38377 .20112 L
.4043 .18472 L
.42339 .17189 L
.44182 .16195 L
.45206 .15754 L
.4615 .15419 L
.47175 .15137 L
.47714 .15023 L
.48285 .14928 L
.48524 .14897 L
.48781 .14868 L
.49003 .14847 L
.49244 .1483 L
.49391 .14821 L
Mistroke
.49527 .14815 L
.49658 .14811 L
.4973 .14809 L
.49796 .14808 L
.49921 .14806 L
.49991 .14806 L
.50056 .14806 L
.50175 .14807 L
.503 .1481 L
.50423 .14813 L
.50556 .14819 L
.50797 .14832 L
.51033 .1485 L
.5125 .14871 L
.51744 .14932 L
.52268 .1502 L
.5314 .15215 L
.54102 .15502 L
.56041 .16302 L
.58128 .1748 L
.62247 .20659 L
.66215 .2457 L
.70031 .28818 L
.74092 .33503 L
.78002 .3781 L
.82157 .41785 L
.84241 .43434 L
.8616 .44705 L
.88033 .45692 L
.88988 .46093 L
.90012 .46443 L
.90539 .46591 L
.91038 .4671 L
.91524 .46806 L
.91974 .46878 L
.92399 .4693 L
.92616 .46951 L
.92851 .46969 L
.92973 .46977 L
.93085 .46983 L
.93199 .46988 L
.93305 .46992 L
.93421 .46995 L
.93549 .46997 L
.93673 .46997 L
.93743 .46997 L
.93806 .46997 L
.9392 .46995 L
.94026 .46992 L
.94143 .46988 L
Mistroke
.94268 .46983 L
.94524 .46967 L
.94757 .46948 L
.95207 .46899 L
.95635 .46837 L
.96584 .46645 L
.97619 .46353 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .46353 m
.02846 .46486 L
.03279 .46577 L
.03527 .46616 L
.03754 .46642 L
.03879 .46652 L
.03945 .46657 L
.04015 .46661 L
.04143 .46666 L
.04262 .46669 L
.04384 .46669 L
.04496 .46667 L
.04626 .46662 L
.04749 .46654 L
.04862 .46645 L
.04967 .46635 L
.05205 .46605 L
.05469 .4656 L
.05708 .46509 L
.06244 .46362 L
.06787 .46164 L
.07287 .4594 L
.08414 .45288 L
.10458 .43618 L
.1234 .4158 L
.14407 .38884 L
.18449 .32691 L
.2234 .26427 L
.24321 .23451 L
.26476 .2057 L
.2837 .18454 L
.29448 .17457 L
.30461 .16671 L
.31492 .1603 L
.32438 .1559 L
.32931 .15419 L
.33449 .15282 L
.33719 .15228 L
.3397 .15189 L
.34111 .15171 L
.34245 .15158 L
.34319 .15152 L
.34399 .15146 L
.34471 .15142 L
.34539 .15139 L
.34662 .15135 L
.34775 .15134 L
.34896 .15135 L
.35028 .15139 L
.35143 .15145 L
Mistroke
.35265 .15154 L
.35485 .15176 L
.35767 .15216 L
.36032 .15266 L
.36526 .15391 L
.37054 .15568 L
.37538 .1577 L
.38631 .16365 L
.40517 .17821 L
.42585 .19981 L
.46632 .25533 L
.50528 .31761 L
.5467 .38208 L
.56743 .41008 L
.5866 .43189 L
.60522 .4485 L
.61462 .45496 L
.61967 .45787 L
.62498 .46049 L
.62981 .46249 L
.6351 .46423 L
.63742 .46485 L
.6399 .46542 L
.64222 .46585 L
.64436 .46617 L
.64565 .46633 L
.64707 .46647 L
.64849 .46658 L
.64927 .46662 L
.64999 .46665 L
.65068 .46667 L
.65133 .46669 L
.65256 .46669 L
.65387 .46667 L
.65461 .46665 L
.6553 .46661 L
.65648 .46654 L
.65759 .46645 L
.66012 .46617 L
.66258 .4658 L
.66523 .46528 L
.67018 .464 L
.67479 .46245 L
.68525 .45764 L
.69544 .45129 L
.70634 .44276 L
.72766 .42132 L
.74781 .39606 L
.78624 .33853 L
.82713 .27252 L
Mistroke
.8665 .21488 L
.88627 .1912 L
.90435 .17381 L
.91364 .16667 L
.92378 .16037 L
.92933 .1576 L
.93448 .15548 L
.93941 .15385 L
.94196 .15317 L
.94466 .15256 L
.9466 .1522 L
.94872 .15188 L
.95066 .15165 L
.95246 .15149 L
.95356 .15143 L
.95459 .15138 L
.95552 .15135 L
.95654 .15134 L
.95763 .15135 L
.9588 .15138 L
.9598 .15142 L
.9609 .15149 L
.96186 .15156 L
.96288 .15166 L
.9647 .15187 L
.96879 .15256 L
.97232 .15338 L
.97619 .15451 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .46353 m
.06244 .47567 L
.10458 .488 L
.14415 .49863 L
.18221 .50794 L
.22272 .51681 L
.26171 .52431 L
.30316 .5311 L
.34309 .53647 L
.3815 .54052 L
.40095 .54214 L
.42237 .5436 L
.44268 .54466 L
.45178 .54503 L
.46172 .54536 L
.4671 .54551 L
.4721 .54563 L
.47727 .54573 L
.48196 .5458 L
.48658 .54586 L
.4887 .54588 L
.49093 .54589 L
.49332 .54591 L
.49438 .54591 L
.49552 .54592 L
.49675 .54592 L
.49789 .54592 L
.49859 .54593 L
.49925 .54593 L
.50049 .54593 L
.50163 .54593 L
.50286 .54592 L
.50401 .54592 L
.50508 .54592 L
.50754 .5459 L
.51014 .54589 L
.51268 .54586 L
.51504 .54584 L
.5204 .54577 L
.5293 .54559 L
.53882 .54534 L
.54906 .545 L
.56016 .54453 L
.58032 .54344 L
.60019 .54206 L
.62123 .54027 L
.65912 .5362 L
.69946 .53071 L
.73829 .52431 L
.77956 .51634 L
Mistroke
.81932 .50758 L
.85757 .49819 L
.89827 .4872 L
.93745 .47571 L
.97619 .46353 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .46353 m
.04262 .46913 L
.06244 .47392 L
.08255 .47757 L
.09396 .4791 L
.09905 .47965 L
.10458 .48016 L
.11004 .48057 L
.11508 .48086 L
.11989 .48107 L
.12232 .48115 L
.12369 .48119 L
.125 .48121 L
.12615 .48123 L
.12741 .48125 L
.12855 .48126 L
.12962 .48127 L
.13088 .48128 L
.13202 .48127 L
.13334 .48127 L
.13459 .48126 L
.13568 .48125 L
.13684 .48123 L
.1389 .48119 L
.14113 .48112 L
.14357 .48104 L
.14881 .4808 L
.15378 .48049 L
.16308 .4797 L
.1731 .47855 L
.184 .47695 L
.20377 .47313 L
.22478 .4678 L
.26253 .45505 L
.30273 .43734 L
.34142 .41674 L
.38256 .39165 L
.42218 .36508 L
.46029 .33802 L
.50085 .30839 L
.5399 .27988 L
.5814 .25047 L
.62138 .22386 L
.65985 .20057 L
.70076 .179 L
.74017 .16195 L
.77805 .14944 L
.7975 .14462 L
.81839 .1407 L
.82852 .13928 L
Mistroke
.83387 .13865 L
.83957 .13808 L
.84504 .13763 L
.85 .1373 L
.85239 .13717 L
.85498 .13705 L
.85744 .13696 L
.85967 .13689 L
.86205 .13683 L
.86336 .1368 L
.8646 .13678 L
.86575 .13677 L
.86681 .13676 L
.86797 .13676 L
.8692 .13676 L
.87044 .13676 L
.87113 .13677 L
.87177 .13677 L
.87294 .13679 L
.87417 .13681 L
.87679 .13686 L
.87965 .13695 L
.88242 .13705 L
.88493 .13717 L
.89057 .13751 L
.90073 .13836 L
.91073 .13951 L
.91995 .14085 L
.94076 .14481 L
.95764 .14898 L
.97619 .15451 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<?0001i2000`400?l00000o`00003ooooooooo
oooooooooooo4_ooool00?oooooooooooooooooooa;ooooo003ooooooooooooooooooolBooooo`00
oooooooooooooooooooo4_ooool00?oooooooooooooooooooa;ooooo003ooooooooooooooooooolB
ooooo`00oooooooooooooooooooo4_ooool00?oooooooooooooooooooa;ooooo003ooooooooooooo
oooooolBooooo`00oooooooooooooooooooo4_ooool00?oooooooooooooooooooa;ooooo003ooooo
oooooooooooooolBooooo`00oooooooooooooooooooo4_ooool00?oooooooooooooooooooa;ooooo
003ooooooooooooooooooolBooooo`00oooooooooooooooooooo4_ooool003Gooooo1_l0003ooooo
oh7ooooo1_l0003oooooodoooooo000eooooo`03oiRHV?l0003oc<c<00;ooooo00?o410@oooooooo
ool0oooooomoooooo`03oiRHV?l0003oc<c<00;ooooo00?o410@ooooooooool0oooooom=ooooo`00
=_ooool00onHV9So0000olc<c03oooooohCooooo00?oV9RHo`000?o<c<`0oooooomAooooo`00;?oo
ool7o`0000Cooooo00?oZJVYoa0@4?o<c<`01oooool3o`000?ooooooKoooool7o`0000Cooooo00?o
ZJVYoa0@4?o<c<`01oooool3o`000?ooooooA_ooool003Sooooo00?oc<c<oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`3oooooog_ooooo00?oc<c<oa0@4?o<c<`01_ooool00ol0003oooooooooo`3o
ooooodKooooo000iooooo`03ojVYZOlb<S;ooooo00Gooooo00?o0000ooooooooool0oooooomloooo
o`03ojVYZOlb<S;ooooo00Gooooo00?o0000ooooooooool0oooooom6ooooo`00>_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?ooooooOOooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooA_ooool003Gooooo00Ko0000ohN7Qoo^k^koooooogMgMolb<S86oooo
o`03o`000?oooooooooo0?ooooooN?ooool01_l0003oQhN7onk^k_ooooooMgMgoc8b<PKooooo00?o
0000ooooooooool0oooooom6ooooo`00=Oooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPKooooo
0_l0003oooooogWooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h6ooooo`;o0000oooooom7oooo
o`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00
@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Ooo
ool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool2
o`000?ooooooQOooool2o`000?ooooooAoooool0047ooooo00?o0000ooooooooool0oooooon4oooo
o`03o`000?oooooooooo0?ooooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03
o`000?oooooooooo0?ooooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`00
0?oooooooooo0?ooooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oo
oooooooo0?ooooooA_ooool0047ooooo0_l0003oooooohGooooo0_l0003oooooodOooooo0011oooo
o`03o`000?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`3oooooodKooooo0011ooooo`03
o`000?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`3oooooodKooooo0011ooooo`03o`00
0?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oo
oooooooo0?ooooooQ?ooool00ol0003oooooooooo`3oooooodKooooo0011ooooo`;o0000oooooon5
ooooo`;o0000oooooom7ooooo`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000oooo
ooooool0oooooom6ooooo`009?ooool4o`000003oa0@4?oooooooooo00?ooooo00?oEEEEo`000?mE
EED01?ooool01_nHV9So410@o`000?l0003oA4A4onk^kPKooooo00?o0000ooooooooool0oooooomW
ooooo`Co000000?o410@ooooooooool00oooool00omEEEGo0000oeEEE@04ooooo`06oiRHV?l@413o
0000o`000?m4A4Cok^k^1_ooool00ol0003oooooooooo`3oooooodKooooo000Vooooo`03o`000?oo
oooooooo00Gooooo0ol00004ooooo`06oa0@4?n7QhOooooooooooomgMgOoA4A41_ooool00ol0003o
ooooooooo`3oooooofWooooo00?o0000ooooooooool01Oooool3o`0000Cooooo00Ko410@ohN7Qooo
ooooooooogMgMom4A4@6ooooo`03o`000?oooooooooo0?ooooooA_ooool002Kooooo00?o0000oooo
ooooool01Oooool00omEEEGo0000oeEEE@09ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooomYooooo`03o`000?oooooooooo00Gooooo00?oEEEEo`000?mEEED02Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooA_ooool001[ooooo1ol00005ooooo`03
o`000?oooooooooo013ooooo00?ok^k^o`000?ooool01Oooool3o`000?ooooooGOooool7o`0000Go
oooo00?o0000ooooooooool04?ooool00oo^k^ko0000ooooo`05ooooo`?o0000oooooom6ooooo`00
9_ooool00ol0003oooooooooo`0<ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV1_ooool00ol0
003oooooooooo`3oooooofWooooo00?o0000ooooooooool03?ooool01_l@413oV9RHoooooooooooo
MgMgofIVIPKooooo00?o0000ooooooooool0oooooom6ooooo`009_ooool00ol0003oooooooooo`0<
ooooo`05o`000?lQ8B7o0000o`000?mVIVH01oooool00ol0003oooooooooo`3oooooofWooooo00?o
0000ooooooooool03?ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000ooooooooool0
oooooom6ooooo`009_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0oooooomYooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`3oooooodKooooo000Tooooo`03o`000?m4A4Co000000kooooo00?o0000
ooooooooool02Oooool2o`000?ooooooJ?ooool00ol0003oA4A4o`00000>ooooo`03o`000?oooooo
oooo00Wooooo0_l0003oooooodOooooo000Tooooo`03olc<c?mEEEGo000000kooooo1Ol00007oooo
o`03o`000?oooooooooo0?ooooooIoooool00oo<c<coEEEEo`00000>ooooo`Go00001oooool00ol0
003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003o
ooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003ooooo
ooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003ooooooooo
o`3oooooodKooooo0011ooooo`;o0000oooooon5ooooo`;o0000oooooom7ooooo`00@Oooool00ol0
003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool00ol0003o
ooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool00ol0003ooooo
ooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool00ol0003ooooooooo
o`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool2o`000?ooooooQOooool2
o`000?ooooooAoooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo
0?ooooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo0?oo
ooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo0?oooooo
A_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo0?ooooooA_oo
ool0047ooooo0_l0003oooooohGooooo0_l0003oooooodOooooo0011ooooo`03o`000?oooooooooo
0?ooooooQ?ooool00ol0003oooooooooo`3oooooodKooooo000fooooo`Co000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`2=ooooo`Ko0000iOooool4o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom6ooooo`00>?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo08Kooooo2?l00005ooooo`Ko0000hOooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo05oooooo1?l0002hooooo`Co00009_ooool003Sooooo00?o0000ooooooooool01_oo
ool3o`0008?ooooo0ol0000Cooooo`?o0000g_ooool00ol0003oooooooooo`06ooooo`?o0000Fooo
ool5o`0000?ooooo1Ol0002_ooooo`Co00001?ooool4o`0002;ooooo000/ooooo`Oo00001Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo083ooooo0ol0000Iooooo`?o0000coooool7
o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Iooooo`;o00003Oooool3
o`000:Sooooo1?l0000^ooooo`00>?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool07Oooool3o`000=Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1Fooooo`?o00004_ooool2o`000:Cooooo0_l0000booooo`00>?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo07gooooo0_l0000Sooooo`;o0000e_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05Cooooo0_l0000Gooooo`03o`000?oooooooooo0:3o
oooo00?o0000ooooooooool0<_ooool003Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1kooooo`;o00009oooool2o`000=Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0WOooool2o`0003Gooooo
000fooooo`03o`000?m4A4Co000000Sooooo0_l0001jooooo`;o0000:oooool00ol0003ooooooooo
o`3?ooooo`03o`000?m4A4Co000000Sooooo0_l0001Cooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0Voooool00ol0003oooooooooo`0eooooo`00=_ooool00oo<c<coEEEEo`000008
ooooo`03o`000?oooooooooo07Oooooo0_l0000^ooooo`;o0000coooool00oo<c<coEEEEo`000008
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2I
ooooo`03o`000?oooooooooo03Kooooo0011ooooo`03o`000?oooooooooo07Kooooo00?o0000oooo
ooooool0<?ooool2o`000=Sooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0=_ooool0047ooooo00?o0000oooooooo
ool0M?ooool2o`0003Gooooo00?o0000ooooooooool0eOooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo023ooooo0_l0002Gooooo`03o`000?oooooooooo03Oooooo0011ooooo`03o`00
0?oooooooooo07?ooooo00?o0000ooooooooool0=_ooool2o`000=Gooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0
>?ooool0047ooooo0_l0001booooo`;o0000>oooool00ol0003oooooooooo`3Booooo`;o0000C_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0>Ooo
ool0047ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0looooo`;o0000d_ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Soooool0
0ol0003oooooooooo`0jooooo`00@Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0coooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0kooooo`00@Oooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0c_ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0S?ooool00ol0003o
ooooooooo`0kooooo`00@Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo04?ooooo
0_l0003>ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`2:ooooo`03o`000?oooooooooo03cooooo0011ooooo`;o0000K?ooool2o`0004Sooooo00?o
0000ooooooooool0boooool2o`0004Wooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`29ooooo`03o`000?oooooooooo03gooooo0011ooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo03kooooo0011oooo
o`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`39oooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`25oooo
o`03o`000?oooooooooo03oooooo0011ooooo`03o`000?oooooooooo06Sooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo043ooooo0011ooooo`;o0000
J?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo0<Oooooo0_l00016ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`11ooooo`00@Ooo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0a_oo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`11ooooo`00@Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo05?ooooo00?o0000ooooooooool0aOooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`12ooooo`009?ooool01?nj
^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo00KoV9RHoa0@4?l0003o0000odA4
A?o^k^h6ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`2Wooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool01_nHV9So
410@o`000?l0003oA4A4onk^kPKooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0@oooool002?ooooo00Koc<c<oc8b
<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool01_l@413oQhN7ooooooooooooMgMgodA4A0Ko
oooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo0:Go
oooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool01_l@413oQhN7oooooooo
ooooMgMgodA4A0Kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo07gooooo00?o0000ooooooooool0@oooool002?ooooo00KoA4A4ojVYZOoooooooooo
ojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Wooooo00?o0000ooooooooool01?ooool3o`0006;o
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`2Tooooo`06odA4A?nYZJWooooooooo
oonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@09ooooo`03o`000?oooooooooo00Cooooo0ol00012
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`14
ooooo`006_ooool7o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>oooo
o`03onk^k_l0003ooooo00Gooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo09[ooooo1ol00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03_ooool00oo^k^ko0000ooooo`05ooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo04Gooooo000Sooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_l@413oV9RHooooooooooooMgMg
ofIVIPKooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo0:;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`06oa0@4?nHV9So
oooooooooomgMgOoIVIV1_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`15ooooo`008oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o0000ofIVIP07ooooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`2Qooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oo
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool0A_ooool002?ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo0:3ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo07Gooooo00?o0000ooooooooool0Aoooool002?ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b
<_o<c<`<ooooo`03o`000?oooooooooo00Wooooo0_l0001Oooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool0X?ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00?o0000oooo
ooooool02Oooool2o`0003oooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo04Oooooo000Tooooo`04okZj^_l@413o410@olc<c0gooooo1Ol00007oooo
o`03o`000?oooooooooo05gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`2Poooo
o`04okZj^_l@413o410@olc<c0gooooo1Ol00007ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo04Sooooo0011oooo
o`03o`000?oooooooooo05cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`2loooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo04Wooooo0011ooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo04Wooooo0011ooooo`03o`00
0?oooooooooo05[ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo04[ooooo0011ooooo`;o0000;Oooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEE
EOl0003oEEEE00Cooooo1_l0000Fooooo`03o`000?oooooooooo00_ooooo00Co^[Zjoa0@4?l0003o
MgMg1_ooool00omEEEGo0000oeEEE@07ooooo`;o000000?o410@ooooooooool08_ooool01?nj^[[o
410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo00Kok^k^odA4A?l0003o0000oeEEEOo^
k^h>ooooo`03o`000?oooooooooo01;ooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000
oeEEE@04ooooo`06onk^k_m4A4Co0000o`000?m4A4Cok^k^;Oooool4o`000003oa0@4?oooooooooo
05cooooo0_l0000]ooooo`04okZj^_l@413o0000ogMgM`Kooooo00GoEEEEo`000?mEEEGoooooo`00
0002ooooo`Ko00009?ooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Oooooo
0_l000000ol@413oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00Co^[Zjoa0@4?l0003o
MgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06onk^k_m4A4Co0000o`000?mEEEGok^k^8oooool0
1?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo00Kok^k^odA4A?l0003o0000
odA4A?o^k^h4ooooo`03o`000?oooooooooo02Kooooo1?l000000ol@413oooooooooo`0Nooooo`00
@Oooool00ol0003oooooooooo`0[ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`00
00Cooooo00?oV9RHo`000?o<c<`00_ooool00ol@413oooooooooo`0Cooooo`03o`000?oooooooooo
00_ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00002?ooool00ol0003ooooooooo
o`0Rooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00KoEEEEogMgMooo
ooooooooogMgMomEEED?ooooo`03o`000?oooooooooo013ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q
8OnYZJT5ooooo`?o00001?ooool01_lb<S;oMgMgonk^k_o^k^koMgMgoc8b<Roooooo00?o0000oooo
ooooool0G_ooool00ol0003oooooooooo`0[ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Ooo
ool3o`000007ooooool0003ooooooooooonHV9So0000olc<c002ooooo`03oa0@4?oooooooooo027o
oooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00002?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01Oooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o0000
1?ooool01_mEEEGoMgMgooooooooooooMgMgoeEEEB;ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnY
ZJT5ooooo`?o00001?ooool01_lb<S;oMgMgonk^k_o^k^koMgMgoc8b<PCooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Pooooo`00@Oooool00ol0003oooooooooo`0[ooooo`06odA4
A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@05ooooo`03oiRHV?l0003oc<c<
01Kooooo00?o0000ooooooooool03?ooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?o
EEEEo`000?mEEED01?ooool6o`0002?ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03
oeEEEOl0003oEEEE00Cooooo00?o410@ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo013ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003o
EEEE00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool0:oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo
00CoEEEEo`000?mEEEGo00001?ooool00onHV9So0000olc<c00Uooooo`06odA4A?nYZJWooooooooo
oonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@04ooooo`Ko00002_ooool00ol0003oooooooooo`0F
ooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@04ooooo`03oa0@
4?oooooooooo00;ooooo00?o0000ooooooooool08?ooool01_m4A4CoZJVYooooooooooooZJVYoc8b
<PGooooo00?oEEEEo`000?mEEED01?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000:oooool00ol0003oooooooooo`0Pooooo`00@Oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00onYZJWo410@olc<c00Doooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:oooo
o`05ofIVI_nYZJWoooooooooool000009?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`06oc8b<_mgMgOo
k^k^onk^k_mgMgOo<S8b;oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?oZJVYoa0@4?o<c<`09?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo
00GoIVIVojVYZOooooooooooo`00000;ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko<S8bogMgMoo^
k^kok^k^ogMgMolb<S82ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool08?ooool0
047ooooo0_l0000/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00oo<
c<co410@olc<c00Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`05onk^k_lQ8B7ok^k^ooooool000009?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00[ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEDAooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03omgM
gOl0003o000000;o000000?ogMgMooooooooool0;Oooool00ol0003oooooooooo`1Nooooo`;o0000
;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00oo<c<co410@olc<c00Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2_ooool01Oo^k^ko8B4Qonk^k_oooooo000000cooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEDR
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ooMgMgo0000o`000002
o`000004omgMgOooooooooooo`0002cooooo00?o0000ooooooooool08?ooool0047ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?oZJVY
oc8b<_ooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02oooool01?nYZJWoIVIVooooool0000Tooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02_ooool01_lQ8B7oIVIVo`000?l0003oEEEEonk^kQ;ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko<S8bofIVI_o^
k^kok^k^ofIVI_lb<S8_ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool0
0onYZJWo<S8booooo`0Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool0
1?nYZJWoIVIVooooool0000=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0:ooooo`06ob4Q8OmVIVKo0000o`000?mEEEGok^k^8_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00So<S8bofIVI_o^k^kok^k^ofIVI_lb<S;o
ooooo`0002gooooo00?o0000ooooooooool08?ooool0047ooooo00?o0000ooooooooool0:oooool0
1_m4A4CoZJVYooooooooooooZJVYodA4A17ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0@ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A43_ooool00om4A4Coc<c<o`00000Toooo
o`06odA4A?nYZJWooooooooooonYZJWoA4A43?ooool00on7QhOoIVIVooooo`0Fooooo`03o`000?oo
oooooooo00cooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo02_o
oooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@6ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool08Oooool01_m4A4CoZJVYooooooooooooZJVYodA4A0kooooo00?oA4A4olc<c?l00000
3Oooool00ol0003oooooooooo`0Dooooo`06odA4A?nYZJWooooooooooonYZJWoA4A43?ooool00on7
QhOoIVIVooooo`0Uooooo`06odA4A?nYZJWooooooooooonYZJWoA4A43?ooool00ol0003ooooooooo
o`02ooooo`;o0000;_ooool00ol0003oooooooooo`0Pooooo`00@Oooool00ol0003oooooooooo`0[
ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool01_l0003oQhN7onk^k_ooooooMgMgoc8b
<Q3ooooo00?o0000ooooooooool04?ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0kooooo00?o
gMgModA4A?l000009?ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0gooooo00?o<S8bofIVI_oM
gMd05_ooool00ol0003oooooooooo`0;ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool0
1_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<Rgooooo00?o0000odA4A?l00000H?ooool00ol0003ooooo
ooooo`0[ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<1Oooool00ol0003oooooooooo`04oooo
o`06o`000?n7QhOok^k^oooooomgMgOo<S8b8oooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0ko
oooo00?ogMgModA4A?l000003_ooool00ol0003oooooooooo`0Cooooo`06olc<c?lb<S;ok^k^onk^
k_lb<S;oc<c<3Oooool00olb<S;oIVIVomgMg@0Tooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<
3?ooool01olb<S;oIVIVonk^k_o^k^koIVIVoc8b<_l00000;?ooool00ol0003oA4A4o`00000Roooo
o`00@Oooool00ol0003oooooooooo`0/ooooo`04okZj^_l@413o410@olc<c0gooooo00KoZJVYoc8b
<_l0003o0000oeEEEOo^k^h?ooooo`03o`000?oooooooooo01;ooooo00Co^[Zjoa0@4?l@413oc<c<
4?ooool00on7QhOo0000ooooo`0Tooooo`04okZj^_l@413o410@olc<c0oooooo00CoMgMgoa0@4?l0
003o8B4Q5Oooool00ol0003oooooooooo`0;ooooo`04okZj^_l@413o410@olc<c0gooooo00Kok^k^
odA4A?l0003o0000odA4A?o^k^h]ooooo`03olc<c?mEEEGo0000063ooooo00?o0000ooooooooool0
;?ooool01?nj^[[o410@oa0@4?o<c<`5ooooo`03o`000?oooooooooo00Gooooo00KoZJVYoc8b<_l0
003o0000oeEEEOo^k^hTooooo`04okZj^_l@413o410@olc<c13ooooo00?oQhN7o`000?ooool03Ooo
ool00ol0003oooooooooo`0Dooooo`04okZj^_l@413o410@olc<c0oooooo00CoMgMgoa0@4?l0003o
8B4Q8oooool01?nj^[[o410@oa0@4?o<c<`=ooooo`06onk^k_m4A4Co0000o`000?m4A4Co0000;Ooo
ool00oo<c<coEEEEo`00000Rooooo`00@Oooool2o`0005;ooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`2booooo`;o0000=_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool0DOooool0047ooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`1looooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`1Fooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0DOooool0047o
oooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo0;3o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0D_ooool0047ooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`20ooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0Doooool0047ooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo0:kooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo05kooooo00?o
0000ooooooooool0Doooool003[oooooool0000fo`00057oooooool0000fo`0001[ooooo0011oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo023ooooo0011ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0GOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool08?ooool0047ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`28ooooo`03o`00
0?oooooooooo0:_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo05Sooooo00?o0000ooooooooool0E_ooool0047ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0E_oo
ool0047ooooo0_l00019ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0ZOooool2
o`0002oooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo05Oooooo0011ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0S_ooool00ol0
003oooooooooo`2Xooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo05Sooooo0011ooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo05So
oooo0011ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0TOooool00ol0003ooooo
ooooo`2Vooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo05Wooooo0011ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0T_ooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0I_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo05[ooooo0011
ooooo`;o0000AOooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo0:Gooooo0_l0000/
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1J
ooooo`00@Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo09Kooooo00?o0000oooo
ooooool0Y?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`1Kooooo`00@Oooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo09Sooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Looooo`00
@Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`1Looooo`00@Oooool2o`00047ooooo00?o0000ooooooooool0W?oo
ool00ol0003oooooooooo`2Qooooo`;o0000:_ooool00ol0003oooooooooo`1/ooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0GOooool0047ooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`2Nooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0G_ooool0
047ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo
09oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool0G_ooool0047ooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`2Rooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0Goooool0047ooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo09gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool0H?ooool0047ooooo0_l0000looooo`03o`000?oooooooooo0:Kooooo00?o
0000ooooooooool0W?ooool2o`0002Oooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo063ooooo0011ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0Z?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0M?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo067ooooo000Toooo
o`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool01_nHV9So410@o`000?l0
003oA4A4onk^kPKooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2Zooooo`03o`00
0?oooooooooo07gooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06
oiRHV?l@413o0000o`000?m4A4Cok^k^1_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo07Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1Rooooo`008oooool01_o<
c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`06oa0@4?n7QhOooooooooooomgMgOo
A4A41_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo0:cooooo00?o0000oooooooo
ool0Noooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`06oa0@4?n7QhOo
oooooooooomgMgOoA4A41_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo07Oooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`1Rooooo`008oooool01_m4A4CoZJVYoooo
ooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED02Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0[_ooool00ol0003oooooooooo`1jooooo`06
odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@09ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0Hoooool002?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0>ooooo`03onk^k_l0003ooooo00Gooooo0ol0000fooooo`03o`000?oooooooooo
0;3ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00kooooo00?ok^k^o`000?ooool01Oooool3o`0002?ooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo06Cooooo000Sooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool01_l@413oV9RHooooooooooooMgMgofIVIPKooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV
1_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`1Tooooo`008oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00[ooooo00Go0000ob4Q8Ol0003o0000ofIVIP07ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0]?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0IOooool002?ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo
07Kooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool0I_ooool002?ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2hooooo`03o`00
0?oooooooooo07Gooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0I_ooool002Cooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool5o`00
00Oooooo0_l0000booooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0MOooool01?nj
^[[o410@oa0@4?o<c<`=ooooo`Go00001oooool2o`00023ooooo00?o0000ooooooooool0P?ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo06Oooooo0011ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
06Sooooo0011ooooo`03o`000?oooooooooo02kooooo0_l00030ooooo`03o`000?oooooooooo093o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0JOooool0047ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`31ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`24ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0JOooool0047ooooo0_l0
000]ooooo`03o`000?oooooooooo0<?ooooo00?o0000ooooooooool0S_ooool2o`0001gooooo00?o
0000ooooooooool0Q_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo06[ooooo0011
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0aOooool2o`0008kooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0Joooool0047ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`38oooo
o`03o`000?oooooooooo08_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2:oooo
o`03o`000?oooooooooo02_ooooo0_l0001^ooooo`00@Oooool00ol0003oooooooooo`0Xooooo`;o
0000c?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0S?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06kooooo0011ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0cOooool00ol0003oooooooooo`29ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo06oooooo0011ooooo`;o00009oooool00ol0003oooooooooo`3?ooooo`03o`000?oo
oooooooo08Sooooo0_l0000Hooooo`03o`000?oooooooooo093ooooo0_l0000Vooooo`03o`000?oo
oooooooo073ooooo0011ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0dOooool2
o`0008Sooooo00?o0000ooooooooool05Oooool2o`0009Gooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`1aooooo`00@Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
0=Cooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1booooo`00@Oooool00ol0003o
ooooooooo`0Rooooo`;o0000f?ooool2o`0008Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`2Hooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Loooool0047ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`3Jooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0M?ooool0047ooooo0_l0000Pooooo`;o0000g_ooool2o`0008;ooooo0_l0
000Booooo`03o`000?oooooooooo09cooooo0_l0000Kooooo`03o`000?oooooooooo07Gooooo0011
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0h?ooool2o`00083ooooo00?o0000
ooooooooool03oooool2o`000:7ooooo00?o0000ooooooooool05_ooool2o`0007Sooooo000foooo
o`Co000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`?o0000iOooool2o`00
07?ooooo1?l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0_l0002Toooo
o`;o00005Oooool00ol0003oooooooooo`1hooooo`00>?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Sooooo0ol0003Zooooo`?o0000L_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0@ooooo`;o
0000Noooool003Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`?o0000
l?ooool3o`0006oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`;o0000
Z_ooool3o`0000cooooo0ol0001mooooo`00>?ooool00ol0003oooooooooo`06ooooo`Ko00003ooo
ool3o`000?Kooooo0ol0000@ooooo`Ko0000E_ooool00ol0003oooooooooo`06ooooo`Go00000ooo
ool5o`000:oooooo1Ol00002ooooo`Go0000P?ooool003Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`Go00001?ooool6o`000?cooooo1ol00004ooooo`Go0000G?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo0ol0002hooooo`Co0000Q?ooool0
03Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`Go0000ooooool9oooo
o`Go0000HOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooA_ooool003So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooog_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3oooooodKooooo000fooooo`03o`000?m4A4Co000000Sooooo
0_l0003oooooog[ooooo00?o0000odA4A?l000002?ooool2o`000?ooooooAoooool003Kooooo00?o
c<c<oeEEEOl000002?ooool00ol0003oooooooooo`3oooooogWooooo00?oc<c<oeEEEOl000002?oo
ool00ol0003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool0
0ol0003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0
003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003o
ooooooooo`3oooooodKooooo0011ooooo`;o0000oooooon5ooooo`;o0000oooooom7ooooo`00@Ooo
ool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool0
0ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool00ol0
003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool00ol0003o
ooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool2o`000?oooooo
QOooool2o`000?ooooooAoooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oo
oooooooo0?ooooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooo
oooo0?ooooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo
0?ooooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo0?oo
ooooA_ooool0047ooooo0_l0003oooooohGooooo0_l0003oooooodOooooo0011ooooo`03o`000?oo
oooooooo0?ooooooQ?ooool00ol0003oooooooooo`3oooooodKooooo000Tooooo`Co000000?o410@
ooooooooool00oooool00omEEEGo0000oeEEE@04ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^
1_ooool00ol0003oooooooooo`3oooooofOooooo1?l000000ol@413oooooooooo`03ooooo`03oeEE
EOl0003oEEEE00Cooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h6ooooo`03o`000?oooooooooo
0?ooooooA_ooool002Kooooo00?o0000ooooooooool01Oooool3o`0000Cooooo00Ko410@ohN7Qooo
ooooooooogMgMom4A4@6ooooo`03o`000?oooooooooo0?ooooooJOooool00ol0003oooooooooo`05
ooooo`?o00001?ooool01_l@413oQhN7ooooooooooooMgMgodA4A0Kooooo00?o0000ooooooooool0
oooooom6ooooo`009_ooool00ol0003oooooooooo`05ooooo`03oeEEEOl0003oEEEE00Wooooo00?o
0000ooooooooool01?ooool3o`000?ooooooJOooool00ol0003oooooooooo`05ooooo`03oeEEEOl0
003oEEEE00Wooooo00?o0000ooooooooool01?ooool3o`000?ooooooA_ooool002Kooooo00?o0000
ooooooooool04?ooool00oo^k^ko0000ooooo`05ooooo`03o`000?oooooooooo0?ooooooJOooool0
0ol0003oooooooooo`0@ooooo`03onk^k_l0003ooooo00Gooooo00?o0000ooooooooool0oooooom6
ooooo`009_ooool00ol0003oooooooooo`0<ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV1_oo
ool00ol0003oooooooooo`3oooooofWooooo00?o0000ooooooooool03?ooool01_l@413oV9RHoooo
ooooooooMgMgofIVIPKooooo00?o0000ooooooooool0oooooom6ooooo`009_ooool00ol0003ooooo
ooooo`0<ooooo`05o`000?lQ8B7o0000o`000?mVIVH01oooool00ol0003oooooooooo`3oooooofWo
oooo00?o0000ooooooooool03?ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000oooo
ooooool0oooooom6ooooo`009_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0oooooomYooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`3oooooodKooooo000Tooooo`03o`000?m4A4Co000000kooooo
00?o0000ooooooooool02Oooool2o`000?ooooooJ?ooool00ol0003oA4A4o`00000>ooooo`03o`00
0?oooooooooo00Wooooo0_l0003oooooodOooooo000Tooooo`03olc<c?mEEEGo000000kooooo1Ol0
0007ooooo`03o`000?oooooooooo0?ooooooIoooool00oo<c<coEEEEo`00000>ooooo`Go00001ooo
ool00ol0003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool0
0ol0003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0
003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003o
ooooooooo`3oooooodKooooo0011ooooo`;o0000oooooon5ooooo`;o0000oooooom7ooooo`00@Ooo
ool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool0
0ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool00ol0
003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool00ol0003o
ooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool2o`000?oooooo
QOooool2o`000?ooooooAoooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oo
oooooooo0?ooooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooo
oooo0?ooooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo
0?ooooooA_ooool0047ooooo0_l0003oooooohGooooo0_l0003oooooodOooooo0011ooooo`03o`00
0?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oo
oooooooo0?ooooooQ?ooool00ol0003oooooooooo`3oooooodKooooo000eooooo`Ko00001_ooool0
0ol0003oooooooooo`3oooooogSooooo1_l00006ooooo`03o`000?oooooooooo0?ooooooA_ooool0
03Gooooo00?oV9RHo`000?o<c<`00_ooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooN?ooool00onHV9So0000olc<c002ooooo`03oa0@4?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooom6ooooo`00=_ooool00onHV9So0000olc<c008ooooo`?o0000oooooomiooooo`03
oiRHV?l0003oc<c<00Sooooo0ol0003oooooodKooooo000gooooo`03ojVYZOl@413oc<c<0?oooooo
Q?ooool00onYZJWo410@olc<c03ooooooe3ooooo000hooooo`03olc<c?l@413oc<c<0?ooooooQ?oo
ool00oo<c<co410@olc<c03oooooodoooooo000iooooo`03ojVYZOlb<S;ooooo0?ooooooQ?ooool0
0onYZJWo<S8booooo`3oooooodkooooo000jooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0
003oooooooooo`3oooooodgooooo000eooooo`06o`000?n7QhOok^k^oooooomgMgOo<S8boooooon1
ooooo`06o`000?n7QhOok^k^oooooomgMgOo<S8boooooom?ooooo`00=Oooool01_nYZJWo<S8bo`00
0?l0003oEEEEonk^k_ooooooPOooool01_nYZJWo<S8bo`000?l0003oEEEEonk^k_ooooooCoooool0
0?oooooooooooooooooooa;ooooo003ooooooooooooooooooolBooooo`00oooooooooooooooooooo
4_ooool00;kooooo00?o410@o`000?l000000_ooool2o`000003oa0@4?oooooooooo01[ooooo00Ko
ZJVYob4Q8Ol0003o0000oeEEEOo^k^kooooooegooooo00?o410@o`000?l000000_ooool2o`000003
oa0@4?oooooooooo01gooooo0_l000000ol@413oooooooooo`2Oooooo`00_oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00[ooooo1_l0000;ooooo`06oa0@4?nYZJWooooooooooomg
MgOo<S8boooooomNooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool6o`00
00oooooo00?o0000ooooooooool0X?ooool00;oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo0?ooooooG?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01_ooooo1_l0002Qooooo`00_oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01oooooo00?oMgMgob4Q8Oooool0oooooomMooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06oooool01OmVIVKoZJVYoooooooooooo00000:;ooooo002oooooo`03o`00
0?o^k^kooooo00;ooooo00?o0000ooooooooool02_ooool6o`0000gooooo00Co8B4Qo`000?l0003o
^[ZjoooooomNooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool02_ooool6o`0000_o
oooo00Gok^k^ob4Q8Oo^k^koooooo`00002Rooooo`00_oooool01_l0003oA4A4omgMgOooooooMgMg
oa0@423ooooo00?ok^k^ogMgMolb<S80oooooomNooooo`06o`000?m4A4CogMgMoooooomgMgOo410@
7_ooool01?nYZJWoIVIVooooool0002Rooooo`00__ooool01ol@413o0000ogMgMol@413o0000ob4Q
8Oo<c<`08_ooool00ol0003oooooooooo`3ooooooe_ooooo00Oo410@o`000?mgMgOo410@o`000?lQ
8B7oc<c<01oooooo00?oA4A4olc<c?l00000X_ooool00>;ooooo00Ko8B4QohN7QoooooooooooofIV
I_lb<S;ooooooh?ooooo00?ogMgModA4A?l00000X_ooool00>;ooooo00Ko^[ZjodA4A?l0003o0000
odA4A?o^k^koooooohCooooo00?oQhN7o`000?ooool0XOooool00?oooooooooooooooooooa;ooooo
003ooooooooooooooooooolBooooo`00oooooooooooooooooooo4_ooool00?oooooooooooooooooo
oa;ooooo003ooooooooooooooooooolBooooo`00oooooooooooooooooooo4_ooool00?oooooooooo
oooooooooa;ooooo003ooooooooooooooooooolBooooo`00oooooooooooooooooooo4_ooool00?oo
oooooooooooooooooa;ooooo003ooooooooooooooooooolBooooo`00oooooooooooooooooooo4_oo
ool00?oooooooooooooooooooa;ooooo003ooooooooooooooooooolBooooo`00oooooooooooooooo
oooo4_ooool00?oooooooooooooooooooa;ooooo003ooooooooooooooooooolBooooo`00oooooooo
oooooooooooo4_ooool00?oooooooooooooooooooa;ooooo003ooooooooooooooooooolBooooo`00
oooooooooooooooooooo4_ooool00?oooooooooooooooooooa;ooooo003ooooooooooooooooooolB
ooooo`00oooooooooooooooooooo4_ooool00?oooooooooooooooooooa;ooooo003ooooooooooooo
oooooolBooooo`00oooooooooooooooooooo4_ooool00?oooooooooooooooooooa;ooooo003ooooo
oooooooooooooolBooooo`00=Oooool6o`000?ooooooPOooool6o`000?ooooooCoooool003Gooooo
00?oV9RHo`000?o<c<`00_ooool00ol@413oooooooooo`3oooooogoooooo00?oV9RHo`000?o<c<`0
0_ooool00ol@413oooooooooo`3oooooodgooooo000fooooo`03oiRHV?l0003oc<c<0?ooooooQ?oo
ool00onHV9So0000olc<c03ooooooe7ooooo000/ooooo`Oo00001?ooool00onYZJWo410@olc<c007
ooooo`?o0000oooooom_ooooo`Oo00001?ooool00onYZJWo410@olc<c007ooooo`?o0000oooooom6
ooooo`00>?ooool00oo<c<co410@olc<c006ooooo`03o`000?oooooooooo0?ooooooNoooool00oo<
c<co410@olc<c006ooooo`03o`000?oooooooooo0?ooooooA_ooool003Wooooo00?oZJVYoc8b<_oo
ool01Oooool00ol0003oooooooooo`3oooooogcooooo00?oZJVYoc8b<_ooool01Oooool00ol0003o
ooooooooo`3oooooodKooooo000jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooommooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom6ooooo`00=Ooo
ool01_l0003oQhN7onk^k_ooooooMgMgoc8b<PKooooo00?o0000ooooooooool0oooooomhooooo`06
o`000?n7QhOok^k^oooooomgMgOo<S8b1_ooool00ol0003oooooooooo`3oooooodKooooo000eoooo
o`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1_ooool2o`000?ooooooNOooool01_nYZJWo<S8bo`00
0?l0003oEEEEonk^kPKooooo0_l0003oooooodOooooo0011ooooo`03o`000?oooooooooo0?oooooo
Q?ooool00ol0003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?oo
ool00ol0003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool0
0ol0003oooooooooo`3oooooodKooooo0011ooooo`;o0000oooooon5ooooo`;o0000oooooom7oooo
o`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00
@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Ooo
ool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool0
0ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool2o`00
0?ooooooQOooool2o`000?ooooooAoooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03
o`000?oooooooooo0?ooooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`00
0?oooooooooo0?ooooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oo
oooooooo0?ooooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooo
oooo0?ooooooA_ooool0047ooooo0_l0003oooooohGooooo0_l0003oooooodOooooo0011ooooo`03
o`000?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`3oooooodKooooo000Tooooo`Co0000
00?o410@ooooooooool00oooool00omEEEGo0000oeEEE@04ooooo`06oiRHV?l@413o0000o`000?m4
A4Cok^k^1_ooool00ol0003oooooooooo`3oooooofOooooo1?l000000ol@413oooooooooo`03oooo
o`03oeEEEOl0003oEEEE00Cooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h6ooooo`03o`000?oo
oooooooo0?ooooooA_ooool002Kooooo00?o0000ooooooooool01Oooool3o`0000Cooooo00Ko410@
ohN7QoooooooooooogMgMom4A4@6ooooo`03o`000?oooooooooo0?ooooooJOooool00ol0003ooooo
ooooo`05ooooo`?o00001?ooool01_l@413oQhN7ooooooooooooMgMgodA4A0Kooooo00?o0000oooo
ooooool0oooooom6ooooo`009_ooool00ol0003oooooooooo`05ooooo`03oeEEEOl0003oEEEE00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooofWooooo00?o0000oooooooo
ool01Oooool00omEEEGo0000oeEEE@09ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom6ooooo`006_ooool7o`0000Gooooo00?o0000ooooooooool04?ooool00oo^k^ko0000
ooooo`05ooooo`?o0000oooooomMooooo`Oo00001Oooool00ol0003oooooooooo`0@ooooo`03onk^
k_l0003ooooo00Gooooo0ol0003oooooodKooooo000Vooooo`03o`000?oooooooooo00cooooo00Ko
410@oiRHV?ooooooooooogMgMomVIVH6ooooo`03o`000?oooooooooo0?ooooooJOooool00ol0003o
ooooooooo`0<ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV1_ooool00ol0003oooooooooo`3o
ooooodKooooo000Vooooo`03o`000?oooooooooo00cooooo00Go0000ob4Q8Ol0003o0000ofIVIP07
ooooo`03o`000?oooooooooo0?ooooooJOooool00ol0003oooooooooo`0<ooooo`05o`000?lQ8B7o
0000o`000?mVIVH01oooool00ol0003oooooooooo`3oooooodKooooo000Vooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3oooooofWooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?ooooooA_ooool0
02Cooooo00?o0000odA4A?l000003_ooool00ol0003oooooooooo`09ooooo`;o0000oooooomXoooo
o`03o`000?m4A4Co000000kooooo00?o0000ooooooooool02Oooool2o`000?ooooooAoooool002Co
oooo00?oc<c<oeEEEOl000003_ooool5o`0000Oooooo00?o0000ooooooooool0oooooomWooooo`03
olc<c?mEEEGo000000kooooo1Ol00007ooooo`03o`000?oooooooooo0?ooooooA_ooool0047ooooo
00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo0?ooooooA_ooool0047ooooo00?o
0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo0?ooooooA_ooool0047ooooo00?o0000
ooooooooool0oooooon4ooooo`03o`000?oooooooooo0?ooooooA_ooool0047ooooo0_l0003ooooo
ohGooooo0_l0003oooooodOooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003o
ooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003ooooo
ooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003ooooooooo
o`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`3o
ooooodKooooo0011ooooo`;o0000oooooon5ooooo`;o0000oooooom7ooooo`00@Oooool00ol0003o
ooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool00ol0003ooooo
ooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool00ol0003ooooooooo
o`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool00ol0003oooooooooo`3o
ooooohCooooo00?o0000ooooooooool0m_oooolHo`0003Oooooo0011ooooo`;o0000oooooon5oooo
o`;o0000l?ooool7o`0001Sooooo2?l0000_ooooo`00@Oooool00ol0003oooooooooo`3oooooohCo
oooo00?o0000ooooooooool0j_ooool5o`0002Oooooo1?l0000[ooooo`00=_ooool4o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0oooooomiooooo`Co000000?o410@ooooooooool0
1?ooool00ol0003oooooooooo`3Wooooo`?o0000<?ooool3o`0002Sooooo000hooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooomkooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0i?ooool3o`0003Kooooo1?l0000Tooooo`00>?ooool00ol0003oooooooooo`06
ooooo`?o0000oooooomkooooo`03o`000?oooooooooo00Kooooo0ol0003Qooooo`?o0000?Oooool2
o`0002;ooooo000/ooooo`Oo00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?ooooooKoooool7o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Noooo
o`?o0000I?ooool003Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooog_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Kooooo`?o0000Ioooool003Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooog_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`3Iooooo`;o0000J_ooool003Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooog_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3Fooooo`?o0000K?ooool003Kooooo00?o0000odA4A?l000002?ooool2o`000?ooooooN_ooool0
0ol0003oA4A4o`000008ooooo`;o0000eOooool2o`0006oooooo000fooooo`03olc<c?mEEEGo0000
00Sooooo00?o0000ooooooooool0oooooomiooooo`03olc<c?mEEEGo000000Sooooo00?o0000oooo
ooooool0d_ooool2o`00077ooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003o
ooooooooo`3?ooooo`?o0000Loooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`00
0?oooooooooo0<gooooo0_l0001fooooo`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o
0000ooooooooool0boooool2o`0007Sooooo0011ooooo`;o0000oooooon5ooooo`;o0000b_ooool2
o`0007[ooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`37oooo
o`;o0000O?ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo0<Ko
oooo00?o0000ooooooooool0O?ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`00
0?oooooooooo0<Cooooo0_l0001oooooo`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o
0000ooooooooool0`_ooool2o`00087ooooo0011ooooo`;o0000oooooon5ooooo`;o0000`Oooool2
o`0008?ooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`2noooo
o`;o0000QOooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo0;go
oooo00?o0000ooooooooool0QOooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`00
0?oooooooooo0;_ooooo0_l00028ooooo`00@Oooool2o`000?ooooooQOooool2o`000;[ooooo0_l0
002:ooooo`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0^?ooool0
0ol0003oooooooooo`2:ooooo`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000oooo
ooooool0]_ooool2o`0008gooooo000Tooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`00
0?mEEED01?ooool01_nHV9So410@o`000?l0003oA4A4onk^kPKooooo00?o0000ooooooooool0oooo
oomWooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool01_nHV9So410@
o`000?l0003oA4A4onk^kPKooooo00?o0000ooooooooool0]?ooool2o`0008oooooo000Sooooo`06
olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7QoooooooooooogMg
Mom4A4@6ooooo`03o`000?oooooooooo0?ooooooI_ooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVY
Z@Gooooo0ol00004ooooo`06oa0@4?n7QhOooooooooooomgMgOoA4A41_ooool00ol0003ooooooooo
o`2cooooo`03o`000?oooooooooo08oooooo000Sooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b
1Oooool00omEEEGo0000oeEEE@09ooooo`03o`000?oooooooooo00Cooooo0ol0003oooooofKooooo
00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Wooooo00?o0000oooo
ooooool01?ooool3o`000;7ooooo0_l0002Booooo`006_ooool7o`0000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0>ooooo`03onk^k_l0003ooooo00Gooooo00?o0000oooooooo
ool0oooooomMooooo`Oo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00ko
oooo00?ok^k^o`000?ooool01Oooool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo09;o
oooo000Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_l@413oV9RH
ooooooooooooMgMgofIVIPKooooo00?o0000ooooooooool0oooooomVooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02_ooool01_l@413oV9RHooooooooooooMgMgofIVIPKooooo00?o
0000ooooooooool0[_ooool2o`0009Gooooo000Sooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02_ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000ooooooooool0oooo
oomVooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`00
0?l0003oIVIV00Oooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`2Eooooo`008ooo
ool01_m4A4CoZJVYooooooooooooZJVYodA4A0cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`3oooooofKooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0Zoooool2o`0009Sooooo000Sooooo`06olc<c?lb<S;ok^k^
onk^k_lb<S;oc<c<3?ooool00ol0003oooooooooo`09ooooo`;o0000oooooomWooooo`06olc<c?lb
<S;ok^k^onk^k_lb<S;oc<c<3?ooool00ol0003oooooooooo`09ooooo`;o0000Zoooool00ol0003o
ooooooooo`2Hooooo`009?ooool01?nj^[[o410@oa0@4?o<c<`=ooooo`Go00001oooool00ol0003o
ooooooooo`3oooooofOooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool5o`0000Oooooo00?o0000oooo
ooooool0Z?ooool2o`0009_ooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003o
ooooooooo`2Wooooo`03o`000?oooooooooo09_ooooo0011ooooo`03o`000?oooooooooo0?oooooo
Q?ooool00ol0003oooooooooo`2Uooooo`;o0000W_ooool0047ooooo00?o0000ooooooooool0oooo
oon4ooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool0W_ooool0047ooooo0_l0000]
ooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool6o`0002Cooooo00Co
^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@07ooooo`;o000000?o410@ooooooooool0
8_ooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo00Kok^k^odA4A?l0
003o0000oeEEEOo^k^hSooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?oo
ool01_o^k^koA4A4o`000?l0003oA4A4onk^kRgooooo1?l000000ol@413oooooooooo`1Looooo`;o
0000;Oooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo1_l0000Toooo
o`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01oooool2o`000003oa0@4?oooooo
oooo02;ooooo0ol000000omgMgOoooooooooo`04ooooo`03oeEEEOl0003oEEEE00Cooooo00Kok^k^
odA4A?l0003o0000oeEEEOo^k^hSooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mE
EED01?ooool01_o^k^koA4A4o`000?l0003oA4A4onk^kRgooooo1?l000000ol@413oooooooooo`0N
ooooo`00@Oooool00ol0003oooooooooo`0[ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Ooo
ool3o`0000Cooooo00?oV9RHo`000?o<c<`00_ooool00ol@413oooooooooo`0Qooooo`06olc<c?lb
<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Sooooo00?o0000ooooooooool08_ooool01_o<c<co
<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE
8_ooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`06oc8b<_mgMgOok^k^
onk^k_mgMgOo<S8b;oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo02_ooooo00Ko
c<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool00onHV9So0000olc<c002ooooo`03
oa0@4?oooooooooo027ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00002?ooool0
0ol0003oooooooooo`0Rooooo`06o`000?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo
00KoEEEEogMgMoooooooooooogMgMomEEEDRooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Ooo
ool3o`0000Cooooo00Ko<S8bogMgMoo^k^kok^k^ogMgMolb<S8_ooooo`03o`000?oooooooooo023o
oooo0011ooooo`03o`000?oooooooooo02_ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85oooo
o`03oeEEEOl0003oEEEE00Gooooo00?oV9RHo`000?o<c<`09Oooool01_m4A4CoZJVYoooooooooooo
ZJVYoc8b<PGooooo00?oEEEEo`000?mEEED01?ooool6o`0002?ooooo00KoA4A4ojVYZOoooooooooo
ojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Cooooo00?o410@ooooooooool00_ooool00ol0003o
ooooooooo`0Pooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo02_ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEE
EOl0003oEEEE00Gooooo00?oV9RHo`000?o<c<`09Oooool01_m4A4CoZJVYooooooooooooZJVYoc8b
<PGooooo00?oEEEEo`000?mEEED01?ooool6o`0002;ooooo00?o0000odA4A?nYZJT00_ooool00onY
ZJWo<S8booooo`04ooooo`03oeEEEOl0003oEEEE00Cooooo00?o410@ooooooooool00_ooool00ol0
003oooooooooo`0Pooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEE
E@04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0Pooooo`00@Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03?ooool00onYZJWo410@olc<c00Tooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02_ooool01OmVIVKoZJVYoooooooooooo000002Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko<S8bogMgMoo^k^kok^k^
ogMgMolb<S8_ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?oZJVYoa0@4?o<c<`09?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00GoIVIVojVYZOooooooooooo`00000Qoooo
o`;o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?o^k^kooooo
00;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00[ooooo00Ko<S8bogMgMoo^k^kok^k^ogMgMolb<S8_ooooo`03o`000?oooooooooo023ooooo0011
ooooo`;o0000;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?oc<c<
oa0@4?o<c<`08oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Gok^k^
ob4Q8Oo^k^koooooo`00000Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool01_l0003oEEEEonk^k_ooooooMgMgoeEEEB;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0:ooooo`03omgMgOl0003o000000;o000000?ogMgMooooooooool0;Oooool00ol0003o
ooooooooo`1Nooooo`;o0000;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00go
oooo00?oc<c<oa0@4?o<c<`08oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00Gok^k^ob4Q8Oo^k^koooooo`00000Pooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`0:ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE8_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00[ooooo00?ogMgMo`000?l000000_l000000ooMgMgooooo
ooooo`0]ooooo`03o`000?oooooooooo023ooooo0011ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03ojVYZOlb<S;ooooo02;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`04ojVYZOmVIVKoooooo`0002Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`06ob4Q8OmVIVKo0000o`000?mE
EEGok^k^8_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko<S8bofIV
I_o^k^kok^k^ofIVI_lb<S8_ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?oZJVYoc8b<_ooool08_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00CoZJVYofIVI_oooooo0000
7_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`06ob4Q
8OmVIVKo0000o`000?mEEEGok^k^8_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00[ooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb<S8_ooooo`03o`000?oooooooooo023ooooo0011
ooooo`03o`000?oooooooooo02_ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@Aooooo`03o`00
0?oooooooooo027ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@>ooooo`03odA4A?o<c<co0000
02Cooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03ohN7QomVIVKooooo02Gooooo00Ko
A4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo02_ooooo00KoA4A4ojVYZOoo
ooooooooojVYZOm4A4@Aooooo`03o`000?oooooooooo027ooooo00KoA4A4ojVYZOooooooooooojVY
ZOm4A4@>ooooo`03odA4A?o<c<co000001gooooo00?o0000ooooooooool01?ooool01_m4A4CoZJVY
ooooooooooooZJVYodA4A0cooooo00?oQhN7ofIVI_ooool09Oooool01_m4A4CoZJVYoooooooooooo
ZJVYodA4A0cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo023ooooo0011ooooo`03o`000?oooooooooo02_ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b
<_o<c<`<ooooo`06o`000?n7QhOok^k^oooooomgMgOo<S8b8oooool01_o<c<co<S8bonk^k_o^k^ko
<S8bolc<c0kooooo00?ogMgModA4A?l000009?ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0go
oooo00?o<S8bofIVI_oMgMd09?ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00Ko<S8b
ofIVI_o^k^kok^k^ofIVI_lb<S8]ooooo`03o`000?m4A4Co0000063ooooo00?o0000ooooooooool0
:oooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00Ko0000ohN7Qoo^k^koooooogMgMolb
<S8Sooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3_ooool00ooMgMgoA4A4o`00000Looooo`03
o`000?oooooooooo00Gooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`=ooooo`03oc8b<_mVIVKo
gMgM02Cooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`06oc8b<_mVIVKok^k^onk^k_mV
IVKo<S8b;Oooool00ol0003oA4A4o`00000Rooooo`00@Oooool00ol0003oooooooooo`0/ooooo`04
okZj^_l@413o410@olc<c0gooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^hTooooo`04okZj^_l@
413o410@olc<c13ooooo00?oQhN7o`000?ooool09?ooool01?nj^[[o410@oa0@4?o<c<`?ooooo`04
ogMgMol@413o0000ob4Q8B?ooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool01_o^k^koA4A4o`000?l0
003oA4A4onk^kRgooooo00?oc<c<oeEEEOl00000H?ooool00ol0003oooooooooo`0/ooooo`04okZj
^_l@413o410@olc<c0gooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^hTooooo`04okZj^_l@413o
410@olc<c13ooooo00?oQhN7o`000?ooool06Oooool2o`0000Wooooo00Co^[Zjoa0@4?l@413oc<c<
3oooool01?mgMgOo410@o`000?lQ8B4Sooooo`04okZj^_l@413o410@olc<c0gooooo00Kok^k^odA4
A?l0003o0000odA4A?o^k^h]ooooo`03olc<c?mEEEGo000002;ooooo0011ooooo`;o0000oooooon5
ooooo`;o0000Uoooool00ol0003oooooooooo`2/ooooo`00@Oooool00ol0003oooooooooo`3ooooo
ohCooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`2]ooooo`00@Oooool00ol0003o
ooooooooo`3oooooohCooooo00?o0000ooooooooool0Toooool2o`000;3ooooo0011ooooo`03o`00
0?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo0;3ooooo
0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`2Aooooo`03o`000?oo
oooooooo0;7ooooo000joooooooo0000=_l0001Aoooooooo0000=_l0000Jooooo`00@Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0GOooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08?ooool0047o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Oo
oooo0_l0000Oooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0Pooooo`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0
Roooool00ol0003oooooooooo`2gooooo`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o
0000ooooooooool0ROooool2o`000;[ooooo0011ooooo`;o0000oooooon5ooooo`;o0000ROooool0
0ol0003oooooooooo`2jooooo`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000oooo
ooooool0Qoooool00ol0003oooooooooo`2kooooo`00@Oooool00ol0003oooooooooo`3oooooohCo
oooo00?o0000ooooooooool0QOooool2o`000;kooooo0011ooooo`03o`000?oooooooooo0?oooooo
Q?ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo0;kooooo0011ooooo`03o`000?oo
oooooooo0?ooooooQ?ooool00ol0003oooooooooo`22ooooo`;o0000`Oooool0047ooooo0_l0003o
ooooohGooooo0_l00022ooooo`03o`000?oooooooooo0<7ooooo0011ooooo`03o`000?oooooooooo
0?ooooooQ?ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo0<;ooooo0011ooooo`03
o`000?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`1nooooo`;o0000aOooool0047ooooo
00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool0
aOooool0047ooooo0_l0003oooooohGooooo0_l0001looooo`;o0000b?ooool0047ooooo00?o0000
ooooooooool0oooooon4ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0b?ooool0
047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool0bOooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo07Oo
oooo0_l0003<ooooo`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`3<ooooo`00@Oooool2o`000?ooooooQOooool2o`0007Gooooo0_l0
003?ooooo`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`3?ooooo`009?ooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003o
EEEE00Cooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h6ooooo`03o`000?oooooooooo0?oooooo
Ioooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo00KoV9RHoa0@4?l0
003o0000odA4A?o^k^h6ooooo`03o`000?oooooooooo077ooooo0_l0003Booooo`008oooool01_o<
c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`06oa0@4?n7QhOooooooooooomgMgOo
A4A41_ooool00ol0003oooooooooo`3oooooofKooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5
ooooo`?o00001?ooool01_l@413oQhN7ooooooooooooMgMgodA4A0Kooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`3Booooo`008oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGo
oooo00?oEEEEo`000?mEEED02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
ooooI_ooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED02Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06kooooo0_l0003Eooooo`008oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?ok^k^o`000?ooool01Oooool3o`00
0?ooooooI_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?ok^k^o`00
0?ooool01Oooool3o`0006gooooo00?o0000ooooooooool0eOooool002?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0:ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV1_ooool0
0ol0003oooooooooo`3oooooofKooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:
ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV1_ooool00ol0003oooooooooo`1[ooooo`;o0000
f?ooool002?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?lQ
8B7o0000o`000?mVIVH01oooool00ol0003oooooooooo`3oooooofKooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000o`000?mVIVH01oooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo0=Sooooo000Sooooo`06odA4A?nYZJWooooooooooonY
ZJWoA4A43?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?ooooooI_ooool01_m4
A4CoZJVYooooooooooooZJVYodA4A0cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Xooooo`;o0000foooool002?ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0oooooomVooooo`06olc<c?lb<S;ok^k^onk^k_lb
<S;oc<c<3?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06Kooooo0_l0003Moooo
o`009?ooool01?nj^[[o410@oa0@4?o<c<`=ooooo`Go00001oooool2o`000?ooooooJ?ooool01?nj
^[[o410@oa0@4?o<c<`=ooooo`Go00001oooool2o`0006Kooooo00?o0000ooooooooool0gOooool0
047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo06?ooooo0_l0003Poooo
o`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0HOooool2o`000>;o
oooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo0>;ooooo0011ooooo`;o0000oooooon5ooooo`;o0000Goooool2o`000>Gooooo0011
ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`1Looooo`;o0000ioooool0
047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool0ioooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo05Wo
oooo0_l0003Zooooo`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0
Eoooool2o`000>cooooo0011ooooo`;o0000oooooon5ooooo`;o0000Eoooool00ol0003ooooooooo
o`3/ooooo`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0E?ooool2
o`000>oooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`1Boooo
o`;o0000lOooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo04oo
oooo0ol0003cooooo`00@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0
COooool2o`000?Kooooo0011ooooo`;o0000oooooon5ooooo`;o0000C?ooool2o`000?Sooooo0011
ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`18ooooo`?o0000n_ooool0
03Kooooo1?l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooNOooool4o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0A_ooool2o`000?gooooo000hooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooomkooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0@oooool3o`000?oooooo000hooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooomkooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
@?ooool3o`000?oooooo0oooool003Sooooo00?o0000ooooooooool01_ooool3o`000?oooooo8_oo
ool3o`0005Kooooo00?o0000ooooooooool01_ooool4o`0003cooooo0ol0003oooooo`Kooooo000h
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?l0003ooooooa[ooooo1?l0001I
ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo1Ol0000cooooo`Co0000oooo
ool9ooooo`00>?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo1?l0003o
oooooa;ooooo1?l0001Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool3
o`0002gooooo0ol0003oooooo`gooooo000hooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool4o`000?oooooo2oooool3o`00067ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`09ooooo`Co00009?ooool5o`000?oooooo4?ooool003Kooooo00?o0000odA4A?l0
00002?ooool2o`0000gooooo0ol0003oooooo`Gooooo0ol0001Rooooo`03o`000?m4A4Co000000So
oooo0_l0000>ooooo`Oo00005_ooool7o`000?oooooo5Oooool003Kooooo00?oc<c<oeEEEOl00000
2?ooool00ol0003oooooooooo`0?ooooo`?o0000o_ooool3o`0006Gooooo00?oc<c<oeEEEOl00000
2?ooool00ol0003oooooooooo`0DoooooaKo0000oooooolLooooo`00@Oooool00ol0003ooooooooo
o`0Booooo`?o0000n?ooool3o`0007?ooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool0
0ol0003oooooooooo`0Eooooo`Co0000l?ooool4o`0007Kooooo00?o0000ooooooooool0oooooom6
ooooo`00@Oooool00ol0003oooooooooo`0Iooooo`Co0000ioooool5o`0007[ooooo00?o0000oooo
ooooool0oooooom6ooooo`00@Oooool2o`0001kooooo1?l0003Oooooo`Co0000Ooooool2o`000?oo
ooooAoooool0047ooooo00?o0000ooooooooool08Oooool4o`000=Oooooo1?l00023ooooo`03o`00
0?oooooooooo0?ooooooA_ooool0047ooooo00?o0000ooooooooool09Oooool4o`000<oooooo1?l0
0027ooooo`03o`000?oooooooooo0?ooooooA_ooool0047ooooo00?o0000ooooooooool0:Oooool4
o`000<Oooooo1?l0002;ooooo`03o`000?oooooooooo0?ooooooA_ooool0047ooooo00?o0000oooo
ooooool0;Oooool4o`000;oooooo1?l0002?ooooo`03o`000?oooooooooo0?ooooooA_ooool0047o
oooo0_l0000booooo`Co0000]oooool4o`0009?ooooo0_l0003oooooodOooooo0011ooooo`03o`00
0?oooooooooo03Gooooo1?l0002_ooooo`Co0000Uoooool00ol0003oooooooooo`3oooooodKooooo
0011ooooo`03o`000?oooooooooo03Wooooo1Ol0002Uooooo`Go0000Voooool00ol0003ooooooooo
o`3oooooodKooooo0011ooooo`03o`000?oooooooooo03kooooo1_l0002Hooooo`Oo0000X?ooool0
0ol0003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo04Cooooo1_l0002<oooo
o`Ko0000Yoooool00ol0003oooooooooo`3oooooodKooooo0011ooooo`;o0000Boooool7o`0007oo
oooo1_l0002]ooooo`;o0000oooooom7ooooo`00@Oooool00ol0003oooooooooo`1Aooooo`Ko0000
Loooool6o`000;?ooooo00?o0000ooooooooool0oooooom6ooooo`009?ooool4o`000003oa0@4?oo
oooooooo00?ooooo00?oEEEEo`000?mEEED01?ooool01_nHV9So410@o`000?l0003oA4A4onk^kPKo
oooo00?o0000ooooooooool0Eoooool6o`0006Oooooo1_l0002Looooo`Co000000?o410@oooooooo
ool00oooool00omEEEGo0000oeEEE@04ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1_ooool0
0ol0003oooooooooo`3oooooodKooooo000Vooooo`03o`000?oooooooooo00Gooooo0ol00004oooo
o`06oa0@4?n7QhOooooooooooomgMgOoA4A41_ooool00ol0003oooooooooo`1Mooooo`Wo0000EOoo
ool9o`000:Cooooo00?o0000ooooooooool01Oooool3o`0000Cooooo00Ko410@ohN7Qooooooooooo
ogMgMom4A4@6ooooo`03o`000?oooooooooo0?ooooooA_ooool002Kooooo00?o0000ooooooooool0
1Oooool00omEEEGo0000oeEEE@09ooooo`03o`000?oooooooooo00Cooooo0ol0001Vooooo`Wo0000
@oooool9o`000:gooooo00?o0000ooooooooool01Oooool00omEEEGo0000oeEEE@09ooooo`03o`00
0?oooooooooo00Cooooo0ol0003oooooodKooooo000Vooooo`03o`000?oooooooooo013ooooo00?o
k^k^o`000?ooool01Oooool00ol0003oooooooooo`1_ooooo`go0000:_ooool<o`000;Kooooo00?o
0000ooooooooool04?ooool00oo^k^ko0000ooooo`05ooooo`03o`000?oooooooooo0?ooooooA_oo
ool002Kooooo00?o0000ooooooooool03?ooool01_l@413oV9RHooooooooooooMgMgofIVIPKooooo
00?o0000ooooooooool0O?oooolZo`000<;ooooo00?o0000ooooooooool03?ooool01_l@413oV9RH
ooooooooooooMgMgofIVIPKooooo00?o0000ooooooooool0oooooom6ooooo`009_ooool00ol0003o
ooooooooo`0<ooooo`05o`000?lQ8B7o0000o`000?mVIVH01oooool00ol0003oooooooooo`3ooooo
ofWooooo00?o0000ooooooooool03?ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000
ooooooooool0oooooom6ooooo`009_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0oooooomYooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`3oooooodKooooo000Tooooo`03o`000?m4A4Co000000ko
oooo00?o0000ooooooooool02Oooool2o`000?ooooooJ?ooool00ol0003oA4A4o`00000>ooooo`03
o`000?oooooooooo00Wooooo0_l0003oooooodOooooo000Tooooo`03olc<c?mEEEGo000000kooooo
1Ol00007ooooo`03o`000?oooooooooo0?ooooooIoooool00oo<c<coEEEEo`00000>ooooo`Go0000
1oooool00ol0003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?oo
ool00ol0003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool0
0ol0003oooooooooo`3oooooodKooooo0011ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0
003oooooooooo`3oooooodKooooo0011ooooo`;o0000oooooon5ooooo`;o0000oooooom7ooooo`00
@Oooool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Ooo
ool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool0
0ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool00ol0
003oooooooooo`3oooooohCooooo00?o0000ooooooooool0oooooom6ooooo`00@Oooool2o`000?oo
ooooQOooool2o`000?ooooooAoooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`00
0?oooooooooo0?ooooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oo
oooooooo0?ooooooA_ooool0047ooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooo
oooo0?ooooooA_ooool0047ooooo0_l0003oooooohGooooo0_l0003oooooodOooooo0011ooooo`03
o`000?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`3oooooodKooooo0011ooooo`03o`00
0?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`3oooooodKooooo000eooooo`Ko00001_oo
ool00ol0003oooooooooo`3oooooogSooooo1_l00006ooooo`03o`000?oooooooooo0?ooooooA_oo
ool003Gooooo00?oV9RHo`000?o<c<`00_ooool00ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooN?ooool00onHV9So0000olc<c002ooooo`03oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom6ooooo`00=_ooool00onHV9So0000olc<c008ooooo`?o0000oooooomioooo
o`03oiRHV?l0003oc<c<00Sooooo0ol0003oooooodKooooo000gooooo`03ojVYZOl@413oc<c<0?oo
ooooQ?ooool00onYZJWo410@olc<c03ooooooe3ooooo000hooooo`03olc<c?l@413oc<c<0?oooooo
Q?ooool00oo<c<co410@olc<c03oooooodoooooo000iooooo`03ojVYZOlb<S;ooooo0?ooooooQ?oo
ool00onYZJWo<S8booooo`3oooooodkooooo000jooooo`03o`000?oooooooooo0?ooooooQ?ooool0
0ol0003oooooooooo`3oooooodgooooo000eooooo`06o`000?n7QhOok^k^oooooomgMgOo<S8boooo
oon1ooooo`06o`000?n7QhOok^k^oooooomgMgOo<S8boooooom?ooooo`00=Oooool01_nYZJWo<S8b
o`000?l0003oEEEEonk^k_ooooooPOooool01_nYZJWo<S8bo`000?l0003oEEEEonk^k_ooooooCooo
ool00?oooooooooooooooooooa;ooooo003ooooooooooooooooooolBooooo`00oooooooooooooooo
oooo4_ooool00;kooooo00?o410@o`000?l000000_ooool2o`000003oa0@4?oooooooooo01_ooooo
1?l000000ol@413oooooooooo`3ooooooe_ooooo00?o410@o`000?l000000_ooool2o`000003oa0@
4?oooooooooo01[ooooo1_l0002Qooooo`00_oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00[ooooo1_l0000>ooooo`03o`000?oooooooooo0?ooooooG_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00[ooooo1_l0000;ooooo`03oiRHV?l0003oc<c<00;ooooo00?o
410@ooooooooool0Woooool00;oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo0?ooooooG_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01cooooo00?oV9RHo`000?o<c<`0Xoooool00;oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo0?ooooooG_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01gooooo00?oZJVYoa0@4?o<c<`0X_ooool00;oooooo00?o0000onk^k_oo
ool00_ooool00ol0003oooooooooo`0:ooooo`Ko00003_ooool00ol0003oooooooooo`3ooooooeko
oooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`0:ooooo`Ko00003_ooool00oo<c<co
410@olc<c02Qooooo`00_oooool01_l0003oA4A4omgMgOooooooMgMgoa0@423ooooo00?o0000oooo
ooooool0oooooomNooooo`06o`000?m4A4CogMgMoooooomgMgOo410@8Oooool00onYZJWo<S8boooo
o`2Pooooo`00__ooool01ol@413o0000ogMgMol@413o0000ob4Q8Oo<c<`08?ooool00ol0003ooooo
ooooo`3ooooooegooooo00Oo410@o`000?mgMgOo410@o`000?lQ8B7oc<c<02;ooooo00?o0000oooo
ooooool0Woooool00>?ooooo00?o0000odA4A?l00000oooooon3ooooo`06o`000?n7QhOok^k^oooo
oomgMgOo<S8bXOooool00>?ooooo00?oc<c<oeEEEOl00000oooooon3ooooo`06ojVYZOlb<S;o0000
o`000?mEEEGok^k^XOooool00?oooooooooooooooooooa;ooooo003ooooooooooooooooooolBoooo
o`00oooooooooooooooooooo4_ooool00?oooooooooooooooooooa;ooooo003ooooooooooooooooo
oolBooooo`00oooooooooooooooooooo4_ooool00?oooooooooooooooooooa;ooooo003ooooooooo
oooooooooolBooooo`00oooooooooooooooooooo4_ooool00?oooooooooooooooooooa;ooooo003o
oooooooooooooooooolBooooo`00oooooooooooooooooooo4_ooool00?oooooooooooooooooooa;o
oooo003ooooooooooooooooooolBooooo`00oooooooooooooooooooo4_ooool00001\
\>"],
  ImageRangeCache->{{{0, 782.062}, {483, 0}} -> {-0.050735, -0.0309017, \
0.00403063, 0.00403063}, {{18.875, 373.25}, {471.5, 252.438}} -> {-0.223418, \
-2.38331, 0.00511081, 0.0315028}, {{408.75, 763.125}, {471.5, 252.438}} -> \
{-1.5518, -2.38331, 0.00511081, 0.0315028}, {{18.875, 373.25}, {230.5, \
11.4375}} -> {-0.223418, -7.44477, 0.00511081, 0.0315028}, {{408.75, \
763.125}, {230.5, 11.4375}} -> {-1.5518, -7.44477, 0.00511081, 0.0315028}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .40564 m
.03279 .40726 L
.04262 .40857 L
.04758 .40903 L
.0503 .40924 L
.05288 .40939 L
.05528 .40951 L
.05655 .40956 L
.05789 .4096 L
.05902 .40963 L
.06026 .40965 L
.06139 .40967 L
.06244 .40967 L
.0631 .40968 L
.06379 .40968 L
.06504 .40967 L
.06581 .40966 L
.06653 .40965 L
.06788 .40962 L
.06917 .40959 L
.07036 .40955 L
.07305 .40943 L
.07529 .4093 L
.07776 .40913 L
.08274 .40869 L
.08819 .40807 L
.09404 .40722 L
.10458 .40527 L
.11475 .40286 L
.12582 .39966 L
.14594 .3924 L
.18672 .37253 L
.22599 .34825 L
.26374 .32195 L
.30394 .29294 L
.34263 .26626 L
.38377 .24154 L
.4043 .23129 L
.42339 .22326 L
.44182 .21705 L
.45206 .21428 L
.4615 .21219 L
.47175 .21043 L
.47714 .20972 L
.48285 .20912 L
.48524 .20892 L
.48781 .20874 L
.49003 .20862 L
.49244 .20851 L
.49391 .20845 L
Mistroke
.49527 .20842 L
.49658 .20839 L
.4973 .20838 L
.49796 .20837 L
.49921 .20836 L
.49991 .20836 L
.50056 .20836 L
.50175 .20837 L
.503 .20838 L
.50423 .2084 L
.50556 .20844 L
.50797 .20852 L
.51033 .20864 L
.5125 .20876 L
.51744 .20915 L
.52268 .20969 L
.5314 .21092 L
.54102 .21271 L
.56041 .21771 L
.58128 .22508 L
.62247 .24496 L
.66215 .26942 L
.70031 .29599 L
.74092 .32529 L
.78002 .35222 L
.82157 .37708 L
.84241 .38739 L
.8616 .39534 L
.88033 .40151 L
.88988 .40402 L
.90012 .40621 L
.90539 .40713 L
.91038 .40788 L
.91524 .40848 L
.91974 .40893 L
.92399 .40926 L
.92616 .40939 L
.92851 .4095 L
.92973 .40955 L
.93085 .40959 L
.93199 .40962 L
.93305 .40964 L
.93421 .40966 L
.93549 .40967 L
.93673 .40968 L
.93743 .40968 L
.93806 .40967 L
.9392 .40966 L
.94026 .40964 L
.94143 .40962 L
Mistroke
.94268 .40958 L
.94524 .40949 L
.94757 .40937 L
.95207 .40906 L
.95635 .40867 L
.96584 .40747 L
.97619 .40564 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36785 m
.02846 .36835 L
.03279 .3687 L
.03527 .36885 L
.03754 .36895 L
.03879 .36899 L
.03945 .36901 L
.04015 .36902 L
.04143 .36904 L
.04262 .36905 L
.04384 .36905 L
.04496 .36905 L
.04626 .36903 L
.04749 .369 L
.04862 .36896 L
.04967 .36892 L
.05205 .36881 L
.05469 .36864 L
.05708 .36845 L
.06244 .36788 L
.06787 .36713 L
.07287 .36628 L
.08414 .3638 L
.10458 .35744 L
.1234 .34968 L
.14407 .33941 L
.18449 .31583 L
.2234 .29198 L
.24321 .28065 L
.26476 .26968 L
.2837 .26162 L
.29448 .25782 L
.30461 .25483 L
.31492 .25239 L
.32438 .25072 L
.32931 .25006 L
.33449 .24954 L
.33719 .24934 L
.3397 .24919 L
.34111 .24912 L
.34245 .24907 L
.34319 .24905 L
.34399 .24902 L
.34471 .24901 L
.34539 .249 L
.34662 .24898 L
.34775 .24898 L
.34896 .24898 L
.35028 .249 L
.35143 .24902 L
Mistroke
.35265 .24906 L
.35485 .24914 L
.35767 .24929 L
.36032 .24948 L
.36526 .24996 L
.37054 .25063 L
.37538 .2514 L
.38631 .25367 L
.40517 .25921 L
.42585 .26744 L
.46632 .28857 L
.50528 .31229 L
.5467 .33684 L
.56743 .3475 L
.5866 .3558 L
.60522 .36213 L
.61462 .36459 L
.61967 .3657 L
.62498 .36669 L
.62981 .36745 L
.6351 .36812 L
.63742 .36835 L
.6399 .36857 L
.64222 .36873 L
.64436 .36886 L
.64565 .36892 L
.64707 .36897 L
.64849 .36901 L
.64927 .36903 L
.64999 .36904 L
.65068 .36905 L
.65133 .36905 L
.65256 .36905 L
.65387 .36905 L
.65461 .36904 L
.6553 .36902 L
.65648 .369 L
.65759 .36896 L
.66012 .36886 L
.66258 .36871 L
.66523 .36852 L
.67018 .36803 L
.67479 .36744 L
.68525 .36561 L
.69544 .36319 L
.70634 .35994 L
.72766 .35178 L
.74781 .34216 L
.78624 .32025 L
.82713 .29512 L
Mistroke
.8665 .27317 L
.88627 .26416 L
.90435 .25754 L
.91364 .25482 L
.92378 .25242 L
.92933 .25136 L
.93448 .25055 L
.93941 .24994 L
.94196 .24967 L
.94466 .24944 L
.9466 .24931 L
.94872 .24918 L
.95066 .2491 L
.95246 .24904 L
.95356 .24901 L
.95459 .24899 L
.95552 .24898 L
.95654 .24898 L
.95763 .24898 L
.9588 .24899 L
.9598 .24901 L
.9609 .24903 L
.96186 .24906 L
.96288 .2491 L
.9647 .24918 L
.96879 .24944 L
.97232 .24975 L
.97619 .25019 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .45902 m
.06244 .47081 L
.10458 .48278 L
.14415 .4931 L
.18221 .50214 L
.22272 .51075 L
.26171 .51803 L
.30316 .52462 L
.34309 .52983 L
.3815 .53376 L
.40095 .53534 L
.42237 .53676 L
.44268 .53778 L
.45178 .53814 L
.46172 .53846 L
.4671 .53861 L
.4721 .53872 L
.47727 .53882 L
.48196 .53889 L
.48658 .53895 L
.4887 .53897 L
.49093 .53898 L
.49332 .539 L
.49438 .539 L
.49552 .53901 L
.49675 .53901 L
.49789 .53901 L
.49859 .53901 L
.49925 .53901 L
.50049 .53901 L
.50163 .53901 L
.50286 .53901 L
.50401 .53901 L
.50508 .53901 L
.50754 .53899 L
.51014 .53898 L
.51268 .53895 L
.51504 .53893 L
.5204 .53886 L
.5293 .53869 L
.53882 .53845 L
.54906 .53811 L
.56016 .53766 L
.58032 .5366 L
.60019 .53526 L
.62123 .53352 L
.65912 .52958 L
.69946 .52424 L
.73829 .51803 L
.77956 .5103 L
Mistroke
.81932 .50179 L
.85757 .49267 L
.89827 .482 L
.93745 .47084 L
.97619 .45902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .44007 m
.04262 .44482 L
.06244 .44889 L
.08255 .45199 L
.09396 .45328 L
.09905 .45375 L
.10458 .45418 L
.11004 .45453 L
.11508 .45478 L
.11989 .45495 L
.12232 .45502 L
.12369 .45505 L
.125 .45507 L
.12615 .45509 L
.12741 .45511 L
.12855 .45512 L
.12962 .45512 L
.13088 .45513 L
.13202 .45513 L
.13334 .45512 L
.13459 .45511 L
.13568 .4551 L
.13684 .45509 L
.1389 .45505 L
.14113 .455 L
.14357 .45493 L
.14881 .45472 L
.15378 .45446 L
.16308 .45379 L
.1731 .45282 L
.184 .45146 L
.20377 .44822 L
.22478 .44369 L
.26253 .43288 L
.30273 .41786 L
.34142 .40039 L
.38256 .37911 L
.42218 .35657 L
.46029 .33362 L
.50085 .30849 L
.5399 .2843 L
.5814 .25936 L
.62138 .23678 L
.65985 .21703 L
.70076 .19873 L
.74017 .18427 L
.77805 .17367 L
.7975 .16958 L
.81839 .16625 L
.82852 .16504 L
Mistroke
.83387 .16451 L
.83957 .16403 L
.84504 .16365 L
.85 .16337 L
.85239 .16326 L
.85498 .16316 L
.85744 .16307 L
.85967 .16301 L
.86205 .16296 L
.86336 .16294 L
.8646 .16293 L
.86575 .16292 L
.86681 .16291 L
.86797 .16291 L
.8692 .16291 L
.87044 .16291 L
.87113 .16291 L
.87177 .16292 L
.87294 .16293 L
.87417 .16295 L
.87679 .16299 L
.87965 .16307 L
.88242 .16316 L
.88493 .16326 L
.89057 .16354 L
.90073 .16426 L
.91073 .16524 L
.91995 .16638 L
.94076 .16974 L
.95764 .17327 L
.97619 .17796 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36945 m
.03279 .37046 L
.04262 .37127 L
.04758 .37157 L
.0503 .37169 L
.05288 .37179 L
.05528 .37186 L
.05655 .37189 L
.05789 .37192 L
.05902 .37194 L
.06026 .37195 L
.06139 .37196 L
.06244 .37197 L
.0631 .37197 L
.06379 .37197 L
.06504 .37196 L
.06581 .37196 L
.06653 .37195 L
.06788 .37193 L
.06917 .37191 L
.07036 .37189 L
.07305 .37181 L
.07529 .37173 L
.07776 .37163 L
.08274 .37135 L
.08819 .37096 L
.09404 .37043 L
.10458 .36921 L
.11475 .3677 L
.12582 .36571 L
.14594 .36116 L
.18672 .34874 L
.22599 .33355 L
.26374 .3171 L
.30394 .29896 L
.34263 .28228 L
.38377 .26682 L
.4043 .26041 L
.42339 .25539 L
.44182 .2515 L
.45206 .24977 L
.4615 .24847 L
.47175 .24736 L
.47714 .24692 L
.48285 .24654 L
.48524 .24642 L
.48781 .24631 L
.49003 .24623 L
.49244 .24616 L
.49391 .24613 L
Mistroke
.49527 .2461 L
.49658 .24609 L
.4973 .24608 L
.49796 .24607 L
.49921 .24607 L
.49991 .24607 L
.50056 .24607 L
.50175 .24607 L
.503 .24608 L
.50423 .2461 L
.50556 .24612 L
.50797 .24617 L
.51033 .24624 L
.5125 .24632 L
.51744 .24656 L
.52268 .2469 L
.5314 .24767 L
.54102 .24879 L
.56041 .25192 L
.58128 .25652 L
.62247 .26896 L
.66215 .28425 L
.70031 .30087 L
.74092 .31919 L
.78002 .33604 L
.82157 .35158 L
.84241 .35803 L
.8616 .363 L
.88033 .36686 L
.88988 .36843 L
.90012 .3698 L
.90539 .37038 L
.91038 .37084 L
.91524 .37122 L
.91974 .3715 L
.92399 .3717 L
.92616 .37179 L
.92851 .37186 L
.92973 .37189 L
.93085 .37191 L
.93199 .37193 L
.93305 .37195 L
.93421 .37196 L
.93549 .37197 L
.93673 .37197 L
.93743 .37197 L
.93806 .37196 L
.9392 .37196 L
.94026 .37195 L
.94143 .37193 L
Mistroke
.94268 .37191 L
.94524 .37185 L
.94757 .37178 L
.95207 .37158 L
.95635 .37134 L
.96584 .37059 L
.97619 .36945 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .33142 m
.02846 .33161 L
.03279 .33174 L
.03527 .3318 L
.03754 .33184 L
.03879 .33185 L
.03945 .33186 L
.04015 .33187 L
.04143 .33187 L
.04262 .33188 L
.04384 .33188 L
.04496 .33187 L
.04626 .33187 L
.04749 .33186 L
.04862 .33184 L
.04967 .33183 L
.05205 .33178 L
.05469 .33172 L
.05708 .33165 L
.06244 .33143 L
.06787 .33114 L
.07287 .33082 L
.08414 .32987 L
.10458 .32745 L
.1234 .3245 L
.14407 .32059 L
.18449 .31161 L
.2234 .30253 L
.24321 .29822 L
.26476 .29404 L
.2837 .29097 L
.29448 .28952 L
.30461 .28839 L
.31492 .28746 L
.32438 .28682 L
.32931 .28657 L
.33449 .28637 L
.33719 .28629 L
.3397 .28624 L
.34111 .28621 L
.34245 .28619 L
.34319 .28618 L
.34399 .28617 L
.34471 .28617 L
.34539 .28616 L
.34662 .28616 L
.34775 .28616 L
.34896 .28616 L
.35028 .28616 L
.35143 .28617 L
Mistroke
.35265 .28619 L
.35485 .28622 L
.35767 .28628 L
.36032 .28635 L
.36526 .28653 L
.37054 .28679 L
.37538 .28708 L
.38631 .28794 L
.40517 .29005 L
.42585 .29318 L
.46632 .30123 L
.50528 .31026 L
.5467 .31961 L
.56743 .32367 L
.5866 .32683 L
.60522 .32924 L
.61462 .33018 L
.61967 .3306 L
.62498 .33098 L
.62981 .33127 L
.6351 .33152 L
.63742 .33161 L
.6399 .33169 L
.64222 .33176 L
.64436 .3318 L
.64565 .33182 L
.64707 .33184 L
.64849 .33186 L
.64927 .33187 L
.64999 .33187 L
.65068 .33187 L
.65133 .33188 L
.65256 .33188 L
.65387 .33187 L
.65461 .33187 L
.6553 .33187 L
.65648 .33186 L
.65759 .33184 L
.66012 .3318 L
.66258 .33175 L
.66523 .33167 L
.67018 .33149 L
.67479 .33126 L
.68525 .33056 L
.69544 .32964 L
.70634 .32841 L
.72766 .3253 L
.74781 .32164 L
.78624 .3133 L
.82713 .30373 L
Mistroke
.8665 .29537 L
.88627 .29194 L
.90435 .28941 L
.91364 .28838 L
.92378 .28747 L
.92933 .28706 L
.93448 .28676 L
.93941 .28652 L
.94196 .28642 L
.94466 .28633 L
.9466 .28628 L
.94872 .28623 L
.95066 .2862 L
.95246 .28618 L
.95356 .28617 L
.95459 .28616 L
.95552 .28616 L
.95654 .28616 L
.95763 .28616 L
.9588 .28616 L
.9598 .28617 L
.9609 .28618 L
.96186 .28619 L
.96288 .2862 L
.9647 .28623 L
.96879 .28633 L
.97232 .28645 L
.97619 .28662 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .45464 m
.06244 .46609 L
.10458 .47771 L
.14415 .48773 L
.18221 .4965 L
.22272 .50487 L
.26171 .51193 L
.30316 .51833 L
.34309 .52339 L
.3815 .52721 L
.40095 .52874 L
.42237 .53011 L
.44268 .53111 L
.45178 .53146 L
.46172 .53177 L
.4671 .53191 L
.4721 .53202 L
.47727 .53212 L
.48196 .53219 L
.48658 .53224 L
.4887 .53226 L
.49093 .53228 L
.49332 .53229 L
.49438 .53229 L
.49552 .5323 L
.49675 .5323 L
.49789 .5323 L
.49859 .5323 L
.49925 .5323 L
.50049 .5323 L
.50163 .5323 L
.50286 .5323 L
.50401 .5323 L
.50508 .5323 L
.50754 .53228 L
.51014 .53227 L
.51268 .53225 L
.51504 .53222 L
.5204 .53215 L
.5293 .53199 L
.53882 .53176 L
.54906 .53143 L
.56016 .53099 L
.58032 .52996 L
.60019 .52866 L
.62123 .52697 L
.65912 .52314 L
.69946 .51796 L
.73829 .51193 L
.77956 .50442 L
Mistroke
.81932 .49617 L
.85757 .48731 L
.89827 .47695 L
.93745 .46612 L
.97619 .45464 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .42018 m
.04262 .42421 L
.06244 .42765 L
.08255 .43029 L
.09396 .43138 L
.09905 .43178 L
.10458 .43215 L
.11004 .43244 L
.11508 .43265 L
.11989 .4328 L
.12232 .43286 L
.12369 .43288 L
.125 .4329 L
.12615 .43292 L
.12741 .43293 L
.12855 .43294 L
.12962 .43295 L
.13088 .43295 L
.13202 .43295 L
.13334 .43294 L
.13459 .43294 L
.13568 .43293 L
.13684 .43291 L
.1389 .43288 L
.14113 .43284 L
.14357 .43278 L
.14881 .4326 L
.15378 .43238 L
.16308 .43181 L
.1731 .43099 L
.184 .42984 L
.20377 .42709 L
.22478 .42325 L
.26253 .41408 L
.30273 .40134 L
.34142 .38652 L
.38256 .36847 L
.42218 .34935 L
.46029 .32988 L
.50085 .30857 L
.5399 .28805 L
.5814 .2669 L
.62138 .24775 L
.65985 .23099 L
.70076 .21547 L
.74017 .20321 L
.77805 .19421 L
.7975 .19074 L
.81839 .18792 L
.82852 .1869 L
Mistroke
.83387 .18645 L
.83957 .18604 L
.84504 .18571 L
.85 .18548 L
.85239 .18538 L
.85498 .1853 L
.85744 .18523 L
.85967 .18518 L
.86205 .18514 L
.86336 .18512 L
.8646 .1851 L
.86575 .1851 L
.86681 .18509 L
.86797 .18509 L
.8692 .18509 L
.87044 .18509 L
.87113 .18509 L
.87177 .1851 L
.87294 .18511 L
.87417 .18512 L
.87679 .18516 L
.87965 .18522 L
.88242 .1853 L
.88493 .18538 L
.89057 .18562 L
.90073 .18624 L
.91073 .18707 L
.91995 .18803 L
.94076 .19088 L
.95764 .19388 L
.97619 .19786 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .34681 m
.03279 .34744 L
.04262 .34795 L
.04758 .34813 L
.0503 .34821 L
.05288 .34827 L
.05528 .34832 L
.05655 .34834 L
.05789 .34836 L
.05902 .34837 L
.06026 .34838 L
.06139 .34838 L
.06244 .34838 L
.0631 .34839 L
.06379 .34838 L
.06504 .34838 L
.06581 .34838 L
.06653 .34837 L
.06788 .34836 L
.06917 .34835 L
.07036 .34833 L
.07305 .34829 L
.07529 .34824 L
.07776 .34817 L
.08274 .348 L
.08819 .34776 L
.09404 .34743 L
.10458 .34666 L
.11475 .34572 L
.12582 .34447 L
.14594 .34163 L
.18672 .33386 L
.22599 .32436 L
.26374 .31407 L
.30394 .30273 L
.34263 .29229 L
.38377 .28263 L
.4043 .27862 L
.42339 .27548 L
.44182 .27305 L
.45206 .27197 L
.4615 .27115 L
.47175 .27046 L
.47714 .27018 L
.48285 .26995 L
.48524 .26987 L
.48781 .2698 L
.49003 .26975 L
.49244 .26971 L
.49391 .26969 L
Mistroke
.49527 .26967 L
.49658 .26966 L
.4973 .26966 L
.49796 .26965 L
.49921 .26965 L
.49991 .26965 L
.50056 .26965 L
.50175 .26965 L
.503 .26966 L
.50423 .26967 L
.50556 .26968 L
.50797 .26971 L
.51033 .26976 L
.5125 .26981 L
.51744 .26996 L
.52268 .27017 L
.5314 .27065 L
.54102 .27135 L
.56041 .27331 L
.58128 .27619 L
.62247 .28397 L
.66215 .29353 L
.70031 .30392 L
.74092 .31538 L
.78002 .32591 L
.82157 .33564 L
.84241 .33967 L
.8616 .34278 L
.88033 .34519 L
.88988 .34617 L
.90012 .34703 L
.90539 .34739 L
.91038 .34768 L
.91524 .34792 L
.91974 .34809 L
.92399 .34822 L
.92616 .34827 L
.92851 .34832 L
.92973 .34834 L
.93085 .34835 L
.93199 .34836 L
.93305 .34837 L
.93421 .34838 L
.93549 .34838 L
.93673 .34839 L
.93743 .34838 L
.93806 .34838 L
.9392 .34838 L
.94026 .34837 L
.94143 .34836 L
Mistroke
.94268 .34835 L
.94524 .34831 L
.94757 .34826 L
.95207 .34814 L
.95635 .34799 L
.96584 .34752 L
.97619 .34681 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31755 m
.02846 .31762 L
.03279 .31767 L
.03527 .31769 L
.03754 .31771 L
.03879 .31771 L
.03945 .31771 L
.04015 .31772 L
.04143 .31772 L
.04262 .31772 L
.04384 .31772 L
.04496 .31772 L
.04626 .31772 L
.04749 .31771 L
.04862 .31771 L
.04967 .3177 L
.05205 .31769 L
.05469 .31766 L
.05708 .31763 L
.06244 .31755 L
.06787 .31744 L
.07287 .31732 L
.08414 .31696 L
.10458 .31604 L
.1234 .31491 L
.14407 .31342 L
.18449 .31 L
.2234 .30655 L
.24321 .3049 L
.26476 .30331 L
.2837 .30215 L
.29448 .30159 L
.30461 .30116 L
.31492 .30081 L
.32438 .30056 L
.32931 .30047 L
.33449 .30039 L
.33719 .30036 L
.3397 .30034 L
.34111 .30033 L
.34245 .30033 L
.34319 .30032 L
.34399 .30032 L
.34471 .30032 L
.34539 .30032 L
.34662 .30031 L
.34775 .30031 L
.34896 .30031 L
.35028 .30032 L
.35143 .30032 L
Mistroke
.35265 .30032 L
.35485 .30034 L
.35767 .30036 L
.36032 .30039 L
.36526 .30045 L
.37054 .30055 L
.37538 .30066 L
.38631 .30099 L
.40517 .3018 L
.42585 .30299 L
.46632 .30605 L
.50528 .30949 L
.5467 .31305 L
.56743 .3146 L
.5866 .3158 L
.60522 .31672 L
.61462 .31707 L
.61967 .31723 L
.62498 .31738 L
.62981 .31749 L
.6351 .31759 L
.63742 .31762 L
.6399 .31765 L
.64222 .31767 L
.64436 .31769 L
.64565 .3177 L
.64707 .31771 L
.64849 .31771 L
.64927 .31772 L
.64999 .31772 L
.65068 .31772 L
.65133 .31772 L
.65256 .31772 L
.65387 .31772 L
.65461 .31772 L
.6553 .31772 L
.65648 .31771 L
.65759 .31771 L
.66012 .31769 L
.66258 .31767 L
.66523 .31764 L
.67018 .31757 L
.67479 .31749 L
.68525 .31722 L
.69544 .31687 L
.70634 .3164 L
.72766 .31522 L
.74781 .31382 L
.78624 .31065 L
.82713 .307 L
Mistroke
.8665 .30382 L
.88627 .30251 L
.90435 .30155 L
.91364 .30116 L
.92378 .30081 L
.92933 .30066 L
.93448 .30054 L
.93941 .30045 L
.94196 .30041 L
.94466 .30038 L
.9466 .30036 L
.94872 .30034 L
.95066 .30033 L
.95246 .30032 L
.95356 .30032 L
.95459 .30031 L
.95552 .30031 L
.95654 .30031 L
.95763 .30031 L
.9588 .30031 L
.9598 .30032 L
.9609 .30032 L
.96186 .30032 L
.96288 .30033 L
.9647 .30034 L
.96879 .30038 L
.97232 .30043 L
.97619 .30049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .45039 m
.06244 .46151 L
.10458 .47279 L
.14415 .48251 L
.18221 .49103 L
.22272 .49915 L
.26171 .50601 L
.30316 .51223 L
.34309 .51714 L
.3815 .52084 L
.40095 .52233 L
.42237 .52366 L
.44268 .52463 L
.45178 .52497 L
.46172 .52527 L
.4671 .52541 L
.4721 .52552 L
.47727 .52561 L
.48196 .52568 L
.48658 .52573 L
.4887 .52575 L
.49093 .52576 L
.49332 .52578 L
.49438 .52578 L
.49552 .52578 L
.49675 .52579 L
.49789 .52579 L
.49859 .52579 L
.49925 .52579 L
.50049 .52579 L
.50163 .52579 L
.50286 .52579 L
.50401 .52579 L
.50508 .52578 L
.50754 .52577 L
.51014 .52575 L
.51268 .52573 L
.51504 .52571 L
.5204 .52564 L
.5293 .52549 L
.53882 .52526 L
.54906 .52494 L
.56016 .52451 L
.58032 .52351 L
.60019 .52225 L
.62123 .52061 L
.65912 .51689 L
.69946 .51187 L
.73829 .50601 L
.77956 .49872 L
Mistroke
.81932 .49071 L
.85757 .48211 L
.89827 .47205 L
.93745 .46154 L
.97619 .45039 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .4033 m
.04262 .40672 L
.06244 .40965 L
.08255 .41188 L
.09396 .41281 L
.09905 .41315 L
.10458 .41346 L
.11004 .41371 L
.11508 .41389 L
.11989 .41401 L
.12232 .41406 L
.12369 .41408 L
.125 .4141 L
.12615 .41411 L
.12741 .41412 L
.12855 .41413 L
.12962 .41413 L
.13088 .41414 L
.13202 .41414 L
.13334 .41413 L
.13459 .41413 L
.13568 .41412 L
.13684 .41411 L
.1389 .41408 L
.14113 .41404 L
.14357 .41399 L
.14881 .41384 L
.15378 .41365 L
.16308 .41317 L
.1731 .41247 L
.184 .4115 L
.20377 .40917 L
.22478 .40591 L
.26253 .39813 L
.30273 .38732 L
.34142 .37476 L
.38256 .35945 L
.42218 .34323 L
.46029 .32672 L
.50085 .30863 L
.5399 .29123 L
.5814 .27329 L
.62138 .25705 L
.65985 .24284 L
.70076 .22967 L
.74017 .21927 L
.77805 .21164 L
.7975 .2087 L
.81839 .2063 L
.82852 .20543 L
Mistroke
.83387 .20505 L
.83957 .20471 L
.84504 .20443 L
.85 .20423 L
.85239 .20415 L
.85498 .20408 L
.85744 .20402 L
.85967 .20398 L
.86205 .20394 L
.86336 .20392 L
.8646 .20391 L
.86575 .20391 L
.86681 .2039 L
.86797 .2039 L
.8692 .2039 L
.87044 .2039 L
.87113 .2039 L
.87177 .20391 L
.87294 .20391 L
.87417 .20393 L
.87679 .20396 L
.87965 .20401 L
.88242 .20408 L
.88493 .20415 L
.89057 .20435 L
.90073 .20487 L
.91073 .20558 L
.91995 .20639 L
.94076 .20881 L
.95764 .21136 L
.97619 .21473 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .33265 m
.03279 .33305 L
.04262 .33337 L
.04758 .33348 L
.0503 .33353 L
.05288 .33357 L
.05528 .3336 L
.05655 .33361 L
.05789 .33362 L
.05902 .33363 L
.06026 .33363 L
.06139 .33363 L
.06244 .33364 L
.0631 .33364 L
.06379 .33364 L
.06504 .33364 L
.06581 .33363 L
.06653 .33363 L
.06788 .33362 L
.06917 .33362 L
.07036 .33361 L
.07305 .33358 L
.07529 .33355 L
.07776 .3335 L
.08274 .3334 L
.08819 .33324 L
.09404 .33304 L
.10458 .33256 L
.11475 .33197 L
.12582 .33119 L
.14594 .32941 L
.18672 .32455 L
.22599 .31861 L
.26374 .31218 L
.30394 .30508 L
.34263 .29856 L
.38377 .29251 L
.4043 .29 L
.42339 .28804 L
.44182 .28652 L
.45206 .28585 L
.4615 .28534 L
.47175 .2849 L
.47714 .28473 L
.48285 .28458 L
.48524 .28454 L
.48781 .28449 L
.49003 .28446 L
.49244 .28443 L
.49391 .28442 L
Mistroke
.49527 .28441 L
.49658 .2844 L
.4973 .2844 L
.49796 .2844 L
.49921 .2844 L
.49991 .2844 L
.50056 .2844 L
.50175 .2844 L
.503 .2844 L
.50423 .28441 L
.50556 .28442 L
.50797 .28444 L
.51033 .28446 L
.5125 .2845 L
.51744 .28459 L
.52268 .28472 L
.5314 .28502 L
.54102 .28546 L
.56041 .28669 L
.58128 .28849 L
.62247 .29335 L
.66215 .29933 L
.70031 .30583 L
.74092 .313 L
.78002 .31958 L
.82157 .32566 L
.84241 .32819 L
.8616 .33013 L
.88033 .33164 L
.88988 .33225 L
.90012 .33279 L
.90539 .33301 L
.91038 .3332 L
.91524 .33334 L
.91974 .33345 L
.92399 .33353 L
.92616 .33357 L
.92851 .33359 L
.92973 .33361 L
.93085 .33362 L
.93199 .33362 L
.93305 .33363 L
.93421 .33363 L
.93549 .33364 L
.93673 .33364 L
.93743 .33364 L
.93806 .33364 L
.9392 .33363 L
.94026 .33363 L
.94143 .33362 L
Mistroke
.94268 .33361 L
.94524 .33359 L
.94757 .33356 L
.95207 .33349 L
.95635 .33339 L
.96584 .3331 L
.97619 .33265 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31226 m
.02846 .31229 L
.03279 .31231 L
.03527 .31232 L
.03754 .31233 L
.03879 .31233 L
.03945 .31233 L
.04015 .31233 L
.04143 .31233 L
.04262 .31233 L
.04384 .31233 L
.04496 .31233 L
.04626 .31233 L
.04749 .31233 L
.04862 .31233 L
.04967 .31232 L
.05205 .31232 L
.05469 .31231 L
.05708 .3123 L
.06244 .31227 L
.06787 .31223 L
.07287 .31218 L
.08414 .31204 L
.10458 .31169 L
.1234 .31126 L
.14407 .31069 L
.18449 .30939 L
.2234 .30808 L
.24321 .30745 L
.26476 .30685 L
.2837 .3064 L
.29448 .30619 L
.30461 .30603 L
.31492 .30589 L
.32438 .3058 L
.32931 .30576 L
.33449 .30573 L
.33719 .30572 L
.3397 .30571 L
.34111 .30571 L
.34245 .30571 L
.34319 .30571 L
.34399 .30571 L
.34471 .3057 L
.34539 .3057 L
.34662 .3057 L
.34775 .3057 L
.34896 .3057 L
.35028 .3057 L
.35143 .30571 L
Mistroke
.35265 .30571 L
.35485 .30571 L
.35767 .30572 L
.36032 .30573 L
.36526 .30576 L
.37054 .30579 L
.37538 .30584 L
.38631 .30596 L
.40517 .30627 L
.42585 .30672 L
.46632 .30789 L
.50528 .3092 L
.5467 .31055 L
.56743 .31114 L
.5866 .3116 L
.60522 .31195 L
.61462 .31208 L
.61967 .31215 L
.62498 .3122 L
.62981 .31224 L
.6351 .31228 L
.63742 .31229 L
.6399 .3123 L
.64222 .31231 L
.64436 .31232 L
.64565 .31232 L
.64707 .31233 L
.64849 .31233 L
.64927 .31233 L
.64999 .31233 L
.65068 .31233 L
.65133 .31233 L
.65256 .31233 L
.65387 .31233 L
.65461 .31233 L
.6553 .31233 L
.65648 .31233 L
.65759 .31233 L
.66012 .31232 L
.66258 .31231 L
.66523 .3123 L
.67018 .31227 L
.67479 .31224 L
.68525 .31214 L
.69544 .31201 L
.70634 .31183 L
.72766 .31138 L
.74781 .31085 L
.78624 .30964 L
.82713 .30825 L
Mistroke
.8665 .30704 L
.88627 .30654 L
.90435 .30617 L
.91364 .30602 L
.92378 .30589 L
.92933 .30583 L
.93448 .30579 L
.93941 .30576 L
.94196 .30574 L
.94466 .30573 L
.9466 .30572 L
.94872 .30571 L
.95066 .30571 L
.95246 .30571 L
.95356 .3057 L
.95459 .3057 L
.95552 .3057 L
.95654 .3057 L
.95763 .3057 L
.9588 .3057 L
.9598 .3057 L
.9609 .30571 L
.96186 .30571 L
.96288 .30571 L
.9647 .30571 L
.96879 .30573 L
.97232 .30575 L
.97619 .30577 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .44627 m
.06244 .45706 L
.10458 .46801 L
.14415 .47745 L
.18221 .48572 L
.22272 .49361 L
.26171 .50026 L
.30316 .5063 L
.34309 .51107 L
.3815 .51466 L
.40095 .51611 L
.42237 .5174 L
.44268 .51834 L
.45178 .51867 L
.46172 .51896 L
.4671 .5191 L
.4721 .5192 L
.47727 .51929 L
.48196 .51936 L
.48658 .51941 L
.4887 .51942 L
.49093 .51944 L
.49332 .51945 L
.49438 .51946 L
.49552 .51946 L
.49675 .51946 L
.49789 .51947 L
.49859 .51947 L
.49925 .51947 L
.50049 .51947 L
.50163 .51947 L
.50286 .51946 L
.50401 .51946 L
.50508 .51946 L
.50754 .51945 L
.51014 .51943 L
.51268 .51941 L
.51504 .51939 L
.5204 .51932 L
.5293 .51917 L
.53882 .51895 L
.54906 .51864 L
.56016 .51823 L
.58032 .51726 L
.60019 .51603 L
.62123 .51444 L
.65912 .51083 L
.69946 .50595 L
.73829 .50026 L
.77956 .49319 L
Mistroke
.81932 .4854 L
.85757 .47706 L
.89827 .4673 L
.93745 .45709 L
.97619 .44627 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .38899 m
.04262 .39189 L
.06244 .39437 L
.08255 .39626 L
.09396 .39705 L
.09905 .39734 L
.10458 .3976 L
.11004 .39781 L
.11508 .39797 L
.11989 .39807 L
.12232 .39811 L
.12369 .39813 L
.125 .39815 L
.12615 .39816 L
.12741 .39817 L
.12855 .39817 L
.12962 .39818 L
.13088 .39818 L
.13202 .39818 L
.13334 .39818 L
.13459 .39817 L
.13568 .39816 L
.13684 .39815 L
.1389 .39813 L
.14113 .3981 L
.14357 .39806 L
.14881 .39793 L
.15378 .39777 L
.16308 .39736 L
.1731 .39677 L
.184 .39594 L
.20377 .39396 L
.22478 .3912 L
.26253 .3846 L
.30273 .37544 L
.34142 .36478 L
.38256 .35179 L
.42218 .33804 L
.46029 .32403 L
.50085 .30869 L
.5399 .29393 L
.5814 .27871 L
.62138 .26494 L
.65985 .25288 L
.70076 .24172 L
.74017 .23289 L
.77805 .22642 L
.7975 .22392 L
.81839 .22189 L
.82852 .22116 L
Mistroke
.83387 .22083 L
.83957 .22054 L
.84504 .22031 L
.85 .22014 L
.85239 .22007 L
.85498 .22001 L
.85744 .21996 L
.85967 .21992 L
.86205 .21989 L
.86336 .21988 L
.8646 .21987 L
.86575 .21986 L
.86681 .21986 L
.86797 .21985 L
.8692 .21985 L
.87044 .21986 L
.87113 .21986 L
.87177 .21986 L
.87294 .21987 L
.87417 .21988 L
.87679 .21991 L
.87965 .21995 L
.88242 .22001 L
.88493 .22007 L
.89057 .22024 L
.90073 .22068 L
.91073 .22128 L
.91995 .22197 L
.94076 .22402 L
.95764 .22618 L
.97619 .22904 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .3238 m
.03279 .32404 L
.04262 .32424 L
.04758 .32432 L
.0503 .32435 L
.05288 .32437 L
.05528 .32439 L
.05655 .3244 L
.05789 .3244 L
.05902 .32441 L
.06026 .32441 L
.06139 .32441 L
.06244 .32441 L
.0631 .32441 L
.06379 .32441 L
.06504 .32441 L
.06581 .32441 L
.06653 .32441 L
.06788 .32441 L
.06917 .3244 L
.07036 .32439 L
.07305 .32438 L
.07529 .32436 L
.07776 .32433 L
.08274 .32426 L
.08819 .32417 L
.09404 .32404 L
.10458 .32374 L
.11475 .32337 L
.12582 .32288 L
.14594 .32177 L
.18672 .31873 L
.22599 .31502 L
.26374 .31099 L
.30394 .30656 L
.34263 .30248 L
.38377 .2987 L
.4043 .29713 L
.42339 .2959 L
.44182 .29495 L
.45206 .29453 L
.4615 .29421 L
.47175 .29394 L
.47714 .29383 L
.48285 .29374 L
.48524 .29371 L
.48781 .29368 L
.49003 .29366 L
.49244 .29364 L
.49391 .29363 L
Mistroke
.49527 .29363 L
.49658 .29362 L
.4973 .29362 L
.49796 .29362 L
.49921 .29362 L
.49991 .29362 L
.50056 .29362 L
.50175 .29362 L
.503 .29362 L
.50423 .29363 L
.50556 .29363 L
.50797 .29365 L
.51033 .29366 L
.5125 .29368 L
.51744 .29374 L
.52268 .29382 L
.5314 .29401 L
.54102 .29429 L
.56041 .29505 L
.58128 .29618 L
.62247 .29922 L
.66215 .30296 L
.70031 .30702 L
.74092 .31151 L
.78002 .31563 L
.82157 .31943 L
.84241 .32101 L
.8616 .32222 L
.88033 .32316 L
.88988 .32355 L
.90012 .32388 L
.90539 .32402 L
.91038 .32414 L
.91524 .32423 L
.91974 .3243 L
.92399 .32435 L
.92616 .32437 L
.92851 .32439 L
.92973 .32439 L
.93085 .3244 L
.93199 .32441 L
.93305 .32441 L
.93421 .32441 L
.93549 .32441 L
.93673 .32441 L
.93743 .32441 L
.93806 .32441 L
.9392 .32441 L
.94026 .32441 L
.94143 .32441 L
Mistroke
.94268 .3244 L
.94524 .32438 L
.94757 .32437 L
.95207 .32432 L
.95635 .32426 L
.96584 .32408 L
.97619 .3238 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31025 m
.02846 .31026 L
.03279 .31027 L
.03527 .31027 L
.03754 .31028 L
.03879 .31028 L
.03945 .31028 L
.04015 .31028 L
.04143 .31028 L
.04262 .31028 L
.04384 .31028 L
.04496 .31028 L
.04626 .31028 L
.04749 .31028 L
.04862 .31028 L
.04967 .31028 L
.05205 .31027 L
.05469 .31027 L
.05708 .31027 L
.06244 .31025 L
.06787 .31024 L
.07287 .31022 L
.08414 .31017 L
.10458 .31003 L
.1234 .30987 L
.14407 .30966 L
.18449 .30916 L
.2234 .30866 L
.24321 .30842 L
.26476 .30819 L
.2837 .30802 L
.29448 .30794 L
.30461 .30788 L
.31492 .30783 L
.32438 .30779 L
.32931 .30778 L
.33449 .30777 L
.33719 .30776 L
.3397 .30776 L
.34111 .30776 L
.34245 .30776 L
.34319 .30776 L
.34399 .30776 L
.34471 .30776 L
.34539 .30776 L
.34662 .30776 L
.34775 .30776 L
.34896 .30776 L
.35028 .30776 L
.35143 .30776 L
Mistroke
.35265 .30776 L
.35485 .30776 L
.35767 .30776 L
.36032 .30777 L
.36526 .30778 L
.37054 .30779 L
.37538 .30781 L
.38631 .30785 L
.40517 .30797 L
.42585 .30814 L
.46632 .30859 L
.50528 .30909 L
.5467 .3096 L
.56743 .30983 L
.5866 .31 L
.60522 .31013 L
.61462 .31019 L
.61967 .31021 L
.62498 .31023 L
.62981 .31025 L
.6351 .31026 L
.63742 .31026 L
.6399 .31027 L
.64222 .31027 L
.64436 .31027 L
.64565 .31028 L
.64707 .31028 L
.64849 .31028 L
.64927 .31028 L
.64999 .31028 L
.65068 .31028 L
.65133 .31028 L
.65256 .31028 L
.65387 .31028 L
.65461 .31028 L
.6553 .31028 L
.65648 .31028 L
.65759 .31028 L
.66012 .31027 L
.66258 .31027 L
.66523 .31027 L
.67018 .31026 L
.67479 .31024 L
.68525 .31021 L
.69544 .31016 L
.70634 .31009 L
.72766 .30992 L
.74781 .30971 L
.78624 .30925 L
.82713 .30872 L
Mistroke
.8665 .30826 L
.88627 .30807 L
.90435 .30793 L
.91364 .30788 L
.92378 .30783 L
.92933 .30781 L
.93448 .30779 L
.93941 .30778 L
.94196 .30777 L
.94466 .30776 L
.9466 .30776 L
.94872 .30776 L
.95066 .30776 L
.95246 .30776 L
.95356 .30776 L
.95459 .30776 L
.95552 .30776 L
.95654 .30776 L
.95763 .30776 L
.9588 .30776 L
.9598 .30776 L
.9609 .30776 L
.96186 .30776 L
.96288 .30776 L
.9647 .30776 L
.96879 .30776 L
.97232 .30777 L
.97619 .30778 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .44227 m
.06244 .45274 L
.10458 .46337 L
.14415 .47254 L
.18221 .48057 L
.22272 .48822 L
.26171 .49468 L
.30316 .50054 L
.34309 .50517 L
.3815 .50866 L
.40095 .51006 L
.42237 .51132 L
.44268 .51223 L
.45178 .51255 L
.46172 .51284 L
.4671 .51297 L
.4721 .51307 L
.47727 .51316 L
.48196 .51322 L
.48658 .51327 L
.4887 .51329 L
.49093 .5133 L
.49332 .51331 L
.49438 .51332 L
.49552 .51332 L
.49675 .51332 L
.49789 .51333 L
.49859 .51333 L
.49925 .51333 L
.50049 .51333 L
.50163 .51333 L
.50286 .51332 L
.50401 .51332 L
.50508 .51332 L
.50754 .51331 L
.51014 .51329 L
.51268 .51327 L
.51504 .51325 L
.5204 .51319 L
.5293 .51304 L
.53882 .51283 L
.54906 .51253 L
.56016 .51212 L
.58032 .51118 L
.60019 .50999 L
.62123 .50845 L
.65912 .50494 L
.69946 .5002 L
.73829 .49468 L
.77956 .48782 L
Mistroke
.81932 .48026 L
.85757 .47216 L
.89827 .46268 L
.93745 .45277 L
.97619 .44227 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37685 m
.04262 .37931 L
.06244 .38141 L
.08255 .38302 L
.09396 .38369 L
.09905 .38393 L
.10458 .38416 L
.11004 .38433 L
.11508 .38446 L
.11989 .38456 L
.12232 .38459 L
.12369 .38461 L
.125 .38462 L
.12615 .38463 L
.12741 .38463 L
.12855 .38464 L
.12962 .38464 L
.13088 .38464 L
.13202 .38464 L
.13334 .38464 L
.13459 .38464 L
.13568 .38463 L
.13684 .38462 L
.1389 .38461 L
.14113 .38458 L
.14357 .38454 L
.14881 .38443 L
.15378 .3843 L
.16308 .38395 L
.1731 .38345 L
.184 .38275 L
.20377 .38107 L
.22478 .37873 L
.26253 .37313 L
.30273 .36535 L
.34142 .35631 L
.38256 .3453 L
.42218 .33363 L
.46029 .32175 L
.50085 .30874 L
.5399 .29622 L
.5814 .28331 L
.62138 .27163 L
.65985 .2614 L
.70076 .25193 L
.74017 .24445 L
.77805 .23896 L
.7975 .23684 L
.81839 .23512 L
.82852 .23449 L
Mistroke
.83387 .23422 L
.83957 .23397 L
.84504 .23377 L
.85 .23363 L
.85239 .23357 L
.85498 .23352 L
.85744 .23348 L
.85967 .23344 L
.86205 .23342 L
.86336 .23341 L
.8646 .2334 L
.86575 .23339 L
.86681 .23339 L
.86797 .23339 L
.8692 .23339 L
.87044 .23339 L
.87113 .23339 L
.87177 .2334 L
.87294 .2334 L
.87417 .23341 L
.87679 .23343 L
.87965 .23347 L
.88242 .23352 L
.88493 .23357 L
.89057 .23372 L
.90073 .23409 L
.91073 .2346 L
.91995 .23518 L
.94076 .23693 L
.95764 .23875 L
.97619 .24118 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31826 m
.03279 .31841 L
.04262 .31854 L
.04758 .31858 L
.0503 .3186 L
.05288 .31862 L
.05528 .31863 L
.05655 .31863 L
.05789 .31864 L
.05902 .31864 L
.06026 .31864 L
.06139 .31865 L
.06244 .31865 L
.0631 .31865 L
.06379 .31865 L
.06504 .31865 L
.06581 .31864 L
.06653 .31864 L
.06788 .31864 L
.06917 .31864 L
.07036 .31863 L
.07305 .31862 L
.07529 .31861 L
.07776 .31859 L
.08274 .31855 L
.08819 .31849 L
.09404 .31841 L
.10458 .31822 L
.11475 .31799 L
.12582 .31769 L
.14594 .31699 L
.18672 .31509 L
.22599 .31277 L
.26374 .31025 L
.30394 .30748 L
.34263 .30493 L
.38377 .30256 L
.4043 .30158 L
.42339 .30081 L
.44182 .30022 L
.45206 .29996 L
.4615 .29975 L
.47175 .29959 L
.47714 .29952 L
.48285 .29946 L
.48524 .29944 L
.48781 .29943 L
.49003 .29941 L
.49244 .2994 L
.49391 .2994 L
Mistroke
.49527 .29939 L
.49658 .29939 L
.4973 .29939 L
.49796 .29939 L
.49921 .29939 L
.49991 .29939 L
.50056 .29939 L
.50175 .29939 L
.503 .29939 L
.50423 .29939 L
.50556 .2994 L
.50797 .2994 L
.51033 .29941 L
.5125 .29943 L
.51744 .29946 L
.52268 .29952 L
.5314 .29963 L
.54102 .2998 L
.56041 .30028 L
.58128 .30099 L
.62247 .30289 L
.66215 .30523 L
.70031 .30777 L
.74092 .31057 L
.78002 .31315 L
.82157 .31553 L
.84241 .31651 L
.8616 .31727 L
.88033 .31786 L
.88988 .3181 L
.90012 .31831 L
.90539 .3184 L
.91038 .31847 L
.91524 .31853 L
.91974 .31857 L
.92399 .31861 L
.92616 .31862 L
.92851 .31863 L
.92973 .31863 L
.93085 .31864 L
.93199 .31864 L
.93305 .31864 L
.93421 .31864 L
.93549 .31865 L
.93673 .31865 L
.93743 .31865 L
.93806 .31865 L
.9392 .31864 L
.94026 .31864 L
.94143 .31864 L
Mistroke
.94268 .31864 L
.94524 .31863 L
.94757 .31862 L
.95207 .31859 L
.95635 .31855 L
.96584 .31844 L
.97619 .31826 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30949 m
.02846 .30949 L
.03279 .30949 L
.03527 .3095 L
.03754 .3095 L
.03879 .3095 L
.03945 .3095 L
.04015 .3095 L
.04143 .3095 L
.04262 .3095 L
.04384 .3095 L
.04496 .3095 L
.04626 .3095 L
.04749 .3095 L
.04862 .3095 L
.04967 .3095 L
.05205 .3095 L
.05469 .30949 L
.05708 .30949 L
.06244 .30949 L
.06787 .30948 L
.07287 .30948 L
.08414 .30946 L
.10458 .3094 L
.1234 .30934 L
.14407 .30926 L
.18449 .30907 L
.2234 .30888 L
.24321 .30879 L
.26476 .3087 L
.2837 .30864 L
.29448 .30861 L
.30461 .30858 L
.31492 .30856 L
.32438 .30855 L
.32931 .30855 L
.33449 .30854 L
.33719 .30854 L
.3397 .30854 L
.34111 .30854 L
.34245 .30854 L
.34319 .30854 L
.34399 .30854 L
.34471 .30854 L
.34539 .30854 L
.34662 .30854 L
.34775 .30854 L
.34896 .30854 L
.35028 .30854 L
.35143 .30854 L
Mistroke
.35265 .30854 L
.35485 .30854 L
.35767 .30854 L
.36032 .30854 L
.36526 .30854 L
.37054 .30855 L
.37538 .30856 L
.38631 .30857 L
.40517 .30862 L
.42585 .30868 L
.46632 .30885 L
.50528 .30904 L
.5467 .30924 L
.56743 .30932 L
.5866 .30939 L
.60522 .30944 L
.61462 .30946 L
.61967 .30947 L
.62498 .30948 L
.62981 .30948 L
.6351 .30949 L
.63742 .30949 L
.6399 .30949 L
.64222 .30949 L
.64436 .3095 L
.64565 .3095 L
.64707 .3095 L
.64849 .3095 L
.64927 .3095 L
.64999 .3095 L
.65068 .3095 L
.65133 .3095 L
.65256 .3095 L
.65387 .3095 L
.65461 .3095 L
.6553 .3095 L
.65648 .3095 L
.65759 .3095 L
.66012 .3095 L
.66258 .30949 L
.66523 .30949 L
.67018 .30949 L
.67479 .30948 L
.68525 .30947 L
.69544 .30945 L
.70634 .30942 L
.72766 .30936 L
.74781 .30928 L
.78624 .30911 L
.82713 .30891 L
Mistroke
.8665 .30873 L
.88627 .30866 L
.90435 .3086 L
.91364 .30858 L
.92378 .30856 L
.92933 .30856 L
.93448 .30855 L
.93941 .30854 L
.94196 .30854 L
.94466 .30854 L
.9466 .30854 L
.94872 .30854 L
.95066 .30854 L
.95246 .30854 L
.95356 .30854 L
.95459 .30854 L
.95552 .30854 L
.95654 .30854 L
.95763 .30854 L
.9588 .30854 L
.9598 .30854 L
.9609 .30854 L
.96186 .30854 L
.96288 .30854 L
.9647 .30854 L
.96879 .30854 L
.97232 .30854 L
.97619 .30855 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .43838 m
.06244 .44855 L
.10458 .45887 L
.14415 .46777 L
.18221 .47556 L
.22272 .48299 L
.26171 .48927 L
.30316 .49496 L
.34309 .49945 L
.3815 .50284 L
.40095 .5042 L
.42237 .50542 L
.44268 .5063 L
.45178 .50662 L
.46172 .50689 L
.4671 .50702 L
.4721 .50712 L
.47727 .5072 L
.48196 .50726 L
.48658 .50731 L
.4887 .50733 L
.49093 .50734 L
.49332 .50735 L
.49438 .50736 L
.49552 .50736 L
.49675 .50736 L
.49789 .50737 L
.49859 .50737 L
.49925 .50737 L
.50049 .50737 L
.50163 .50737 L
.50286 .50736 L
.50401 .50736 L
.50508 .50736 L
.50754 .50735 L
.51014 .50733 L
.51268 .50732 L
.51504 .50729 L
.5204 .50723 L
.5293 .50709 L
.53882 .50688 L
.54906 .50659 L
.56016 .5062 L
.58032 .50528 L
.60019 .50413 L
.62123 .50263 L
.65912 .49923 L
.69946 .49463 L
.73829 .48927 L
.77956 .4826 L
Mistroke
.81932 .47526 L
.85757 .4674 L
.89827 .4582 L
.93745 .44858 L
.97619 .43838 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36655 m
.04262 .36864 L
.06244 .37042 L
.08255 .37179 L
.09396 .37235 L
.09905 .37256 L
.10458 .37275 L
.11004 .3729 L
.11508 .37301 L
.11989 .37309 L
.12232 .37312 L
.12369 .37313 L
.125 .37314 L
.12615 .37315 L
.12741 .37316 L
.12855 .37316 L
.12962 .37316 L
.13088 .37316 L
.13202 .37316 L
.13334 .37316 L
.13459 .37316 L
.13568 .37315 L
.13684 .37315 L
.1389 .37313 L
.14113 .37311 L
.14357 .37308 L
.14881 .37299 L
.15378 .37287 L
.16308 .37258 L
.1731 .37215 L
.184 .37156 L
.20377 .37013 L
.22478 .36814 L
.26253 .3634 L
.30273 .3568 L
.34142 .34913 L
.38256 .33979 L
.42218 .3299 L
.46029 .31982 L
.50085 .30878 L
.5399 .29817 L
.5814 .28721 L
.62138 .2773 L
.65985 .26863 L
.70076 .2606 L
.74017 .25425 L
.77805 .24959 L
.7975 .2478 L
.81839 .24634 L
.82852 .24581 L
Mistroke
.83387 .24557 L
.83957 .24536 L
.84504 .24519 L
.85 .24507 L
.85239 .24502 L
.85498 .24498 L
.85744 .24494 L
.85967 .24492 L
.86205 .24489 L
.86336 .24489 L
.8646 .24488 L
.86575 .24487 L
.86681 .24487 L
.86797 .24487 L
.8692 .24487 L
.87044 .24487 L
.87113 .24487 L
.87177 .24487 L
.87294 .24488 L
.87417 .24489 L
.87679 .24491 L
.87965 .24494 L
.88242 .24498 L
.88493 .24502 L
.89057 .24515 L
.90073 .24547 L
.91073 .2459 L
.91995 .24639 L
.94076 .24787 L
.95764 .24942 L
.97619 .25148 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .3148 m
.03279 .31489 L
.04262 .31497 L
.04758 .315 L
.0503 .31501 L
.05288 .31502 L
.05528 .31503 L
.05655 .31503 L
.05789 .31503 L
.05902 .31504 L
.06026 .31504 L
.06139 .31504 L
.06244 .31504 L
.0631 .31504 L
.06379 .31504 L
.06504 .31504 L
.06581 .31504 L
.06653 .31504 L
.06788 .31504 L
.06917 .31503 L
.07036 .31503 L
.07305 .31502 L
.07529 .31502 L
.07776 .31501 L
.08274 .31498 L
.08819 .31494 L
.09404 .31489 L
.10458 .31478 L
.11475 .31463 L
.12582 .31444 L
.14594 .31401 L
.18672 .31282 L
.22599 .31136 L
.26374 .30979 L
.30394 .30806 L
.34263 .30646 L
.38377 .30498 L
.4043 .30437 L
.42339 .30389 L
.44182 .30352 L
.45206 .30335 L
.4615 .30322 L
.47175 .30312 L
.47714 .30308 L
.48285 .30304 L
.48524 .30303 L
.48781 .30302 L
.49003 .30301 L
.49244 .303 L
.49391 .303 L
Mistroke
.49527 .303 L
.49658 .303 L
.4973 .303 L
.49796 .303 L
.49921 .303 L
.49991 .303 L
.50056 .303 L
.50175 .303 L
.503 .303 L
.50423 .303 L
.50556 .303 L
.50797 .30301 L
.51033 .30301 L
.5125 .30302 L
.51744 .30304 L
.52268 .30308 L
.5314 .30315 L
.54102 .30326 L
.56041 .30355 L
.58128 .304 L
.62247 .30519 L
.66215 .30665 L
.70031 .30824 L
.74092 .30999 L
.78002 .3116 L
.82157 .31309 L
.84241 .31371 L
.8616 .31418 L
.88033 .31455 L
.88988 .3147 L
.90012 .31483 L
.90539 .31489 L
.91038 .31493 L
.91524 .31497 L
.91974 .31499 L
.92399 .31501 L
.92616 .31502 L
.92851 .31503 L
.92973 .31503 L
.93085 .31503 L
.93199 .31504 L
.93305 .31504 L
.93421 .31504 L
.93549 .31504 L
.93673 .31504 L
.93743 .31504 L
.93806 .31504 L
.9392 .31504 L
.94026 .31504 L
.94143 .31504 L
Mistroke
.94268 .31503 L
.94524 .31503 L
.94757 .31502 L
.95207 .315 L
.95635 .31498 L
.96584 .31491 L
.97619 .3148 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .3092 m
.02846 .3092 L
.03279 .3092 L
.03527 .3092 L
.03754 .3092 L
.03879 .3092 L
.03945 .3092 L
.04015 .3092 L
.04143 .3092 L
.04262 .3092 L
.04384 .3092 L
.04496 .3092 L
.04626 .3092 L
.04749 .3092 L
.04862 .3092 L
.04967 .3092 L
.05205 .3092 L
.05469 .3092 L
.05708 .3092 L
.06244 .3092 L
.06787 .30919 L
.07287 .30919 L
.08414 .30918 L
.10458 .30916 L
.1234 .30914 L
.14407 .30911 L
.18449 .30904 L
.2234 .30897 L
.24321 .30893 L
.26476 .3089 L
.2837 .30887 L
.29448 .30886 L
.30461 .30885 L
.31492 .30884 L
.32438 .30884 L
.32931 .30884 L
.33449 .30884 L
.33719 .30884 L
.3397 .30883 L
.34111 .30883 L
.34245 .30883 L
.34319 .30883 L
.34399 .30883 L
.34471 .30883 L
.34539 .30883 L
.34662 .30883 L
.34775 .30883 L
.34896 .30883 L
.35028 .30883 L
.35143 .30883 L
Mistroke
.35265 .30883 L
.35485 .30883 L
.35767 .30883 L
.36032 .30884 L
.36526 .30884 L
.37054 .30884 L
.37538 .30884 L
.38631 .30885 L
.40517 .30887 L
.42585 .30889 L
.46632 .30895 L
.50528 .30903 L
.5467 .3091 L
.56743 .30913 L
.5866 .30916 L
.60522 .30918 L
.61462 .30919 L
.61967 .30919 L
.62498 .30919 L
.62981 .3092 L
.6351 .3092 L
.63742 .3092 L
.6399 .3092 L
.64222 .3092 L
.64436 .3092 L
.64565 .3092 L
.64707 .3092 L
.64849 .3092 L
.64927 .3092 L
.64999 .3092 L
.65068 .3092 L
.65133 .3092 L
.65256 .3092 L
.65387 .3092 L
.65461 .3092 L
.6553 .3092 L
.65648 .3092 L
.65759 .3092 L
.66012 .3092 L
.66258 .3092 L
.66523 .3092 L
.67018 .3092 L
.67479 .3092 L
.68525 .30919 L
.69544 .30918 L
.70634 .30917 L
.72766 .30915 L
.74781 .30912 L
.78624 .30905 L
.82713 .30897 L
Mistroke
.8665 .30891 L
.88627 .30888 L
.90435 .30886 L
.91364 .30885 L
.92378 .30884 L
.92933 .30884 L
.93448 .30884 L
.93941 .30884 L
.94196 .30884 L
.94466 .30884 L
.9466 .30884 L
.94872 .30883 L
.95066 .30883 L
.95246 .30883 L
.95356 .30883 L
.95459 .30883 L
.95552 .30883 L
.95654 .30883 L
.95763 .30883 L
.9588 .30883 L
.9598 .30883 L
.9609 .30883 L
.96186 .30883 L
.96288 .30883 L
.9647 .30883 L
.96879 .30884 L
.97232 .30884 L
.97619 .30884 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .4346 m
.06244 .44448 L
.10458 .4545 L
.14415 .46314 L
.18221 .4707 L
.22272 .47792 L
.26171 .48401 L
.30316 .48953 L
.34309 .49389 L
.3815 .49718 L
.40095 .49851 L
.42237 .49969 L
.44268 .50055 L
.45178 .50085 L
.46172 .50112 L
.4671 .50124 L
.4721 .50134 L
.47727 .50142 L
.48196 .50148 L
.48658 .50152 L
.4887 .50154 L
.49093 .50156 L
.49332 .50157 L
.49438 .50157 L
.49552 .50157 L
.49675 .50158 L
.49789 .50158 L
.49859 .50158 L
.49925 .50158 L
.50049 .50158 L
.50163 .50158 L
.50286 .50158 L
.50401 .50158 L
.50508 .50157 L
.50754 .50156 L
.51014 .50155 L
.51268 .50153 L
.51504 .50151 L
.5204 .50145 L
.5293 .50131 L
.53882 .50111 L
.54906 .50082 L
.56016 .50044 L
.58032 .49956 L
.60019 .49843 L
.62123 .49698 L
.65912 .49368 L
.69946 .48921 L
.73829 .48401 L
.77956 .47754 L
Mistroke
.81932 .47041 L
.85757 .46278 L
.89827 .45385 L
.93745 .44451 L
.97619 .4346 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .35782 m
.04262 .35959 L
.06244 .3611 L
.08255 .36226 L
.09396 .36274 L
.09905 .36291 L
.10458 .36308 L
.11004 .3632 L
.11508 .3633 L
.11989 .36336 L
.12232 .36339 L
.12369 .3634 L
.125 .36341 L
.12615 .36341 L
.12741 .36342 L
.12855 .36342 L
.12962 .36343 L
.13088 .36343 L
.13202 .36343 L
.13334 .36343 L
.13459 .36342 L
.13568 .36342 L
.13684 .36341 L
.1389 .3634 L
.14113 .36338 L
.14357 .36335 L
.14881 .36328 L
.15378 .36318 L
.16308 .36293 L
.1731 .36257 L
.184 .36206 L
.20377 .36085 L
.22478 .35917 L
.26253 .35514 L
.30273 .34955 L
.34142 .34304 L
.38256 .33512 L
.42218 .32673 L
.46029 .31818 L
.50085 .30882 L
.5399 .29981 L
.5814 .29052 L
.62138 .28212 L
.65985 .27476 L
.70076 .26795 L
.74017 .26256 L
.77805 .25861 L
.7975 .25709 L
.81839 .25585 L
.82852 .2554 L
Mistroke
.83387 .2552 L
.83957 .25502 L
.84504 .25488 L
.85 .25478 L
.85239 .25474 L
.85498 .2547 L
.85744 .25467 L
.85967 .25465 L
.86205 .25463 L
.86336 .25462 L
.8646 .25461 L
.86575 .25461 L
.86681 .25461 L
.86797 .25461 L
.8692 .25461 L
.87044 .25461 L
.87113 .25461 L
.87177 .25461 L
.87294 .25462 L
.87417 .25462 L
.87679 .25464 L
.87965 .25467 L
.88242 .2547 L
.88493 .25474 L
.89057 .25484 L
.90073 .25511 L
.91073 .25548 L
.91995 .2559 L
.94076 .25715 L
.95764 .25847 L
.97619 .26021 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31263 m
.03279 .31269 L
.04262 .31274 L
.04758 .31276 L
.0503 .31277 L
.05288 .31277 L
.05528 .31278 L
.05655 .31278 L
.05789 .31278 L
.05902 .31278 L
.06026 .31278 L
.06139 .31278 L
.06244 .31278 L
.0631 .31278 L
.06379 .31278 L
.06504 .31278 L
.06581 .31278 L
.06653 .31278 L
.06788 .31278 L
.06917 .31278 L
.07036 .31278 L
.07305 .31277 L
.07529 .31277 L
.07776 .31276 L
.08274 .31275 L
.08819 .31272 L
.09404 .31269 L
.10458 .31262 L
.11475 .31253 L
.12582 .31241 L
.14594 .31214 L
.18672 .31139 L
.22599 .31048 L
.26374 .3095 L
.30394 .30842 L
.34263 .30742 L
.38377 .30649 L
.4043 .30611 L
.42339 .30581 L
.44182 .30558 L
.45206 .30547 L
.4615 .30539 L
.47175 .30533 L
.47714 .3053 L
.48285 .30528 L
.48524 .30527 L
.48781 .30527 L
.49003 .30526 L
.49244 .30526 L
.49391 .30525 L
Mistroke
.49527 .30525 L
.49658 .30525 L
.4973 .30525 L
.49796 .30525 L
.49921 .30525 L
.49991 .30525 L
.50056 .30525 L
.50175 .30525 L
.503 .30525 L
.50423 .30525 L
.50556 .30525 L
.50797 .30526 L
.51033 .30526 L
.5125 .30527 L
.51744 .30528 L
.52268 .3053 L
.5314 .30535 L
.54102 .30541 L
.56041 .3056 L
.58128 .30588 L
.62247 .30662 L
.66215 .30754 L
.70031 .30853 L
.74092 .30963 L
.78002 .31063 L
.82157 .31156 L
.84241 .31195 L
.8616 .31225 L
.88033 .31248 L
.88988 .31257 L
.90012 .31265 L
.90539 .31269 L
.91038 .31272 L
.91524 .31274 L
.91974 .31275 L
.92399 .31277 L
.92616 .31277 L
.92851 .31278 L
.92973 .31278 L
.93085 .31278 L
.93199 .31278 L
.93305 .31278 L
.93421 .31278 L
.93549 .31278 L
.93673 .31278 L
.93743 .31278 L
.93806 .31278 L
.9392 .31278 L
.94026 .31278 L
.94143 .31278 L
Mistroke
.94268 .31278 L
.94524 .31278 L
.94757 .31277 L
.95207 .31276 L
.95635 .31275 L
.96584 .3127 L
.97619 .31263 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30909 m
.02846 .30909 L
.03279 .30909 L
.03527 .30909 L
.03754 .30909 L
.03879 .30909 L
.03945 .30909 L
.04015 .30909 L
.04143 .30909 L
.04262 .30909 L
.04384 .30909 L
.04496 .30909 L
.04626 .30909 L
.04749 .30909 L
.04862 .30909 L
.04967 .30909 L
.05205 .30909 L
.05469 .30909 L
.05708 .30909 L
.06244 .30909 L
.06787 .30908 L
.07287 .30908 L
.08414 .30908 L
.10458 .30907 L
.1234 .30906 L
.14407 .30905 L
.18449 .30902 L
.2234 .309 L
.24321 .30898 L
.26476 .30897 L
.2837 .30896 L
.29448 .30896 L
.30461 .30895 L
.31492 .30895 L
.32438 .30895 L
.32931 .30895 L
.33449 .30895 L
.33719 .30895 L
.3397 .30895 L
.34111 .30895 L
.34245 .30895 L
.34319 .30895 L
.34399 .30895 L
.34471 .30895 L
.34539 .30895 L
.34662 .30895 L
.34775 .30895 L
.34896 .30895 L
.35028 .30895 L
.35143 .30895 L
Mistroke
.35265 .30895 L
.35485 .30895 L
.35767 .30895 L
.36032 .30895 L
.36526 .30895 L
.37054 .30895 L
.37538 .30895 L
.38631 .30895 L
.40517 .30896 L
.42585 .30897 L
.46632 .30899 L
.50528 .30902 L
.5467 .30905 L
.56743 .30906 L
.5866 .30907 L
.60522 .30908 L
.61462 .30908 L
.61967 .30908 L
.62498 .30908 L
.62981 .30908 L
.6351 .30909 L
.63742 .30909 L
.6399 .30909 L
.64222 .30909 L
.64436 .30909 L
.64565 .30909 L
.64707 .30909 L
.64849 .30909 L
.64927 .30909 L
.64999 .30909 L
.65068 .30909 L
.65133 .30909 L
.65256 .30909 L
.65387 .30909 L
.65461 .30909 L
.6553 .30909 L
.65648 .30909 L
.65759 .30909 L
.66012 .30909 L
.66258 .30909 L
.66523 .30909 L
.67018 .30909 L
.67479 .30908 L
.68525 .30908 L
.69544 .30908 L
.70634 .30908 L
.72766 .30907 L
.74781 .30906 L
.78624 .30903 L
.82713 .309 L
Mistroke
.8665 .30898 L
.88627 .30896 L
.90435 .30896 L
.91364 .30895 L
.92378 .30895 L
.92933 .30895 L
.93448 .30895 L
.93941 .30895 L
.94196 .30895 L
.94466 .30895 L
.9466 .30895 L
.94872 .30895 L
.95066 .30895 L
.95246 .30895 L
.95356 .30895 L
.95459 .30895 L
.95552 .30895 L
.95654 .30895 L
.95763 .30895 L
.9588 .30895 L
.9598 .30895 L
.9609 .30895 L
.96186 .30895 L
.96288 .30895 L
.9647 .30895 L
.96879 .30895 L
.97232 .30895 L
.97619 .30895 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .43094 m
.06244 .44053 L
.10458 .45025 L
.14415 .45864 L
.18221 .46599 L
.22272 .47299 L
.26171 .4789 L
.30316 .48426 L
.34309 .4885 L
.3815 .4917 L
.40095 .49298 L
.42237 .49413 L
.44268 .49496 L
.45178 .49525 L
.46172 .49552 L
.4671 .49563 L
.4721 .49573 L
.47727 .49581 L
.48196 .49586 L
.48658 .49591 L
.4887 .49592 L
.49093 .49594 L
.49332 .49595 L
.49438 .49595 L
.49552 .49596 L
.49675 .49596 L
.49789 .49596 L
.49859 .49596 L
.49925 .49596 L
.50049 .49596 L
.50163 .49596 L
.50286 .49596 L
.50401 .49596 L
.50508 .49596 L
.50754 .49595 L
.51014 .49593 L
.51268 .49591 L
.51504 .49589 L
.5204 .49584 L
.5293 .4957 L
.53882 .4955 L
.54906 .49523 L
.56016 .49486 L
.58032 .494 L
.60019 .49291 L
.62123 .4915 L
.65912 .48829 L
.69946 .48396 L
.73829 .4789 L
.77956 .47262 L
Mistroke
.81932 .46571 L
.85757 .45829 L
.89827 .44962 L
.93745 .44055 L
.97619 .43094 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .35041 m
.04262 .35191 L
.06244 .3532 L
.08255 .35418 L
.09396 .35459 L
.09905 .35473 L
.10458 .35487 L
.11004 .35498 L
.11508 .35506 L
.11989 .35511 L
.12232 .35513 L
.12369 .35514 L
.125 .35515 L
.12615 .35516 L
.12741 .35516 L
.12855 .35517 L
.12962 .35517 L
.13088 .35517 L
.13202 .35517 L
.13334 .35517 L
.13459 .35516 L
.13568 .35516 L
.13684 .35516 L
.1389 .35514 L
.14113 .35513 L
.14357 .35511 L
.14881 .35504 L
.15378 .35496 L
.16308 .35475 L
.1731 .35444 L
.184 .35401 L
.20377 .35299 L
.22478 .35156 L
.26253 .34814 L
.30273 .3434 L
.34142 .33788 L
.38256 .33116 L
.42218 .32404 L
.46029 .31679 L
.50085 .30885 L
.5399 .30121 L
.5814 .29333 L
.62138 .2862 L
.65985 .27996 L
.70076 .27418 L
.74017 .26961 L
.77805 .26626 L
.7975 .26497 L
.81839 .26392 L
.82852 .26354 L
Mistroke
.83387 .26337 L
.83957 .26322 L
.84504 .2631 L
.85 .26301 L
.85239 .26298 L
.85498 .26294 L
.85744 .26292 L
.85967 .2629 L
.86205 .26288 L
.86336 .26288 L
.8646 .26287 L
.86575 .26287 L
.86681 .26287 L
.86797 .26287 L
.8692 .26287 L
.87044 .26287 L
.87113 .26287 L
.87177 .26287 L
.87294 .26287 L
.87417 .26288 L
.87679 .26289 L
.87965 .26292 L
.88242 .26294 L
.88493 .26298 L
.89057 .26307 L
.90073 .26329 L
.91073 .2636 L
.91995 .26396 L
.94076 .26502 L
.95764 .26614 L
.97619 .26762 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31128 m
.03279 .31132 L
.04262 .31135 L
.04758 .31136 L
.0503 .31136 L
.05288 .31137 L
.05528 .31137 L
.05655 .31137 L
.05789 .31137 L
.05902 .31137 L
.06026 .31137 L
.06139 .31137 L
.06244 .31137 L
.0631 .31137 L
.06379 .31137 L
.06504 .31137 L
.06581 .31137 L
.06653 .31137 L
.06788 .31137 L
.06917 .31137 L
.07036 .31137 L
.07305 .31137 L
.07529 .31136 L
.07776 .31136 L
.08274 .31135 L
.08819 .31133 L
.09404 .31131 L
.10458 .31127 L
.11475 .31121 L
.12582 .31114 L
.14594 .31097 L
.18672 .3105 L
.22599 .30993 L
.26374 .30932 L
.30394 .30864 L
.34263 .30802 L
.38377 .30744 L
.4043 .3072 L
.42339 .30701 L
.44182 .30687 L
.45206 .3068 L
.4615 .30675 L
.47175 .30671 L
.47714 .30669 L
.48285 .30668 L
.48524 .30668 L
.48781 .30667 L
.49003 .30667 L
.49244 .30667 L
.49391 .30666 L
Mistroke
.49527 .30666 L
.49658 .30666 L
.4973 .30666 L
.49796 .30666 L
.49921 .30666 L
.49991 .30666 L
.50056 .30666 L
.50175 .30666 L
.503 .30666 L
.50423 .30666 L
.50556 .30666 L
.50797 .30667 L
.51033 .30667 L
.5125 .30667 L
.51744 .30668 L
.52268 .30669 L
.5314 .30672 L
.54102 .30676 L
.56041 .30688 L
.58128 .30705 L
.62247 .30752 L
.66215 .30809 L
.70031 .30871 L
.74092 .3094 L
.78002 .31003 L
.82157 .31061 L
.84241 .31085 L
.8616 .31104 L
.88033 .31118 L
.88988 .31124 L
.90012 .31129 L
.90539 .31131 L
.91038 .31133 L
.91524 .31134 L
.91974 .31135 L
.92399 .31136 L
.92616 .31137 L
.92851 .31137 L
.92973 .31137 L
.93085 .31137 L
.93199 .31137 L
.93305 .31137 L
.93421 .31137 L
.93549 .31137 L
.93673 .31137 L
.93743 .31137 L
.93806 .31137 L
.9392 .31137 L
.94026 .31137 L
.94143 .31137 L
Mistroke
.94268 .31137 L
.94524 .31137 L
.94757 .31136 L
.95207 .31136 L
.95635 .31135 L
.96584 .31132 L
.97619 .31128 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30904 m
.02846 .30904 L
.03279 .30904 L
.03527 .30904 L
.03754 .30904 L
.03879 .30904 L
.03945 .30904 L
.04015 .30904 L
.04143 .30904 L
.04262 .30904 L
.04384 .30904 L
.04496 .30904 L
.04626 .30904 L
.04749 .30904 L
.04862 .30904 L
.04967 .30904 L
.05205 .30904 L
.05469 .30904 L
.05708 .30904 L
.06244 .30904 L
.06787 .30904 L
.07287 .30904 L
.08414 .30904 L
.10458 .30904 L
.1234 .30903 L
.14407 .30903 L
.18449 .30902 L
.2234 .30901 L
.24321 .309 L
.26476 .309 L
.2837 .309 L
.29448 .30899 L
.30461 .30899 L
.31492 .30899 L
.32438 .30899 L
.32931 .30899 L
.33449 .30899 L
.33719 .30899 L
.3397 .30899 L
.34111 .30899 L
.34245 .30899 L
.34319 .30899 L
.34399 .30899 L
.34471 .30899 L
.34539 .30899 L
.34662 .30899 L
.34775 .30899 L
.34896 .30899 L
.35028 .30899 L
.35143 .30899 L
Mistroke
.35265 .30899 L
.35485 .30899 L
.35767 .30899 L
.36032 .30899 L
.36526 .30899 L
.37054 .30899 L
.37538 .30899 L
.38631 .30899 L
.40517 .30899 L
.42585 .309 L
.46632 .30901 L
.50528 .30902 L
.5467 .30903 L
.56743 .30903 L
.5866 .30904 L
.60522 .30904 L
.61462 .30904 L
.61967 .30904 L
.62498 .30904 L
.62981 .30904 L
.6351 .30904 L
.63742 .30904 L
.6399 .30904 L
.64222 .30904 L
.64436 .30904 L
.64565 .30904 L
.64707 .30904 L
.64849 .30904 L
.64927 .30904 L
.64999 .30904 L
.65068 .30904 L
.65133 .30904 L
.65256 .30904 L
.65387 .30904 L
.65461 .30904 L
.6553 .30904 L
.65648 .30904 L
.65759 .30904 L
.66012 .30904 L
.66258 .30904 L
.66523 .30904 L
.67018 .30904 L
.67479 .30904 L
.68525 .30904 L
.69544 .30904 L
.70634 .30904 L
.72766 .30904 L
.74781 .30903 L
.78624 .30902 L
.82713 .30901 L
Mistroke
.8665 .309 L
.88627 .309 L
.90435 .30899 L
.91364 .30899 L
.92378 .30899 L
.92933 .30899 L
.93448 .30899 L
.93941 .30899 L
.94196 .30899 L
.94466 .30899 L
.9466 .30899 L
.94872 .30899 L
.95066 .30899 L
.95246 .30899 L
.95356 .30899 L
.95459 .30899 L
.95552 .30899 L
.95654 .30899 L
.95763 .30899 L
.9588 .30899 L
.9598 .30899 L
.9609 .30899 L
.96186 .30899 L
.96288 .30899 L
.9647 .30899 L
.96879 .30899 L
.97232 .30899 L
.97619 .30899 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .42738 m
.06244 .43669 L
.10458 .44613 L
.14415 .45428 L
.18221 .46141 L
.22272 .46821 L
.26171 .47395 L
.30316 .47915 L
.34309 .48326 L
.3815 .48637 L
.40095 .48761 L
.42237 .48873 L
.44268 .48954 L
.45178 .48982 L
.46172 .49008 L
.4671 .49019 L
.4721 .49028 L
.47727 .49036 L
.48196 .49041 L
.48658 .49046 L
.4887 .49047 L
.49093 .49049 L
.49332 .4905 L
.49438 .4905 L
.49552 .4905 L
.49675 .49051 L
.49789 .49051 L
.49859 .49051 L
.49925 .49051 L
.50049 .49051 L
.50163 .49051 L
.50286 .49051 L
.50401 .4905 L
.50508 .4905 L
.50754 .49049 L
.51014 .49048 L
.51268 .49046 L
.51504 .49044 L
.5204 .49039 L
.5293 .49026 L
.53882 .49006 L
.54906 .4898 L
.56016 .48944 L
.58032 .4886 L
.60019 .48754 L
.62123 .48617 L
.65912 .48306 L
.69946 .47885 L
.73829 .47395 L
.77956 .46785 L
Mistroke
.81932 .46113 L
.85757 .45394 L
.89827 .44552 L
.93745 .43672 L
.97619 .42738 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .34413 m
.04262 .3454 L
.06244 .34649 L
.08255 .34732 L
.09396 .34767 L
.09905 .34779 L
.10458 .34791 L
.11004 .348 L
.11508 .34807 L
.11989 .34812 L
.12232 .34813 L
.12369 .34814 L
.125 .34815 L
.12615 .34815 L
.12741 .34816 L
.12855 .34816 L
.12962 .34816 L
.13088 .34816 L
.13202 .34816 L
.13334 .34816 L
.13459 .34816 L
.13568 .34816 L
.13684 .34815 L
.1389 .34814 L
.14113 .34813 L
.14357 .34811 L
.14881 .34805 L
.15378 .34798 L
.16308 .3478 L
.1731 .34754 L
.184 .34718 L
.20377 .34631 L
.22478 .3451 L
.26253 .3422 L
.30273 .33818 L
.34142 .3335 L
.38256 .3278 L
.42218 .32176 L
.46029 .31561 L
.50085 .30887 L
.5399 .30239 L
.5814 .29571 L
.62138 .28966 L
.65985 .28437 L
.70076 .27947 L
.74017 .2756 L
.77805 .27275 L
.7975 .27166 L
.81839 .27077 L
.82852 .27044 L
Mistroke
.83387 .2703 L
.83957 .27017 L
.84504 .27007 L
.85 .27 L
.85239 .26997 L
.85498 .26994 L
.85744 .26992 L
.85967 .2699 L
.86205 .26989 L
.86336 .26988 L
.8646 .26988 L
.86575 .26987 L
.86681 .26987 L
.86797 .26987 L
.8692 .26987 L
.87044 .26987 L
.87113 .26987 L
.87177 .26987 L
.87294 .26988 L
.87417 .26988 L
.87679 .26989 L
.87965 .26991 L
.88242 .26994 L
.88493 .26996 L
.89057 .27004 L
.90073 .27024 L
.91073 .2705 L
.91995 .2708 L
.94076 .2717 L
.95764 .27265 L
.97619 .27391 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31043 m
.03279 .31045 L
.04262 .31047 L
.04758 .31048 L
.0503 .31048 L
.05288 .31049 L
.05528 .31049 L
.05655 .31049 L
.05789 .31049 L
.05902 .31049 L
.06026 .31049 L
.06139 .31049 L
.06244 .31049 L
.0631 .31049 L
.06379 .31049 L
.06504 .31049 L
.06581 .31049 L
.06653 .31049 L
.06788 .31049 L
.06917 .31049 L
.07036 .31049 L
.07305 .31049 L
.07529 .31048 L
.07776 .31048 L
.08274 .31048 L
.08819 .31047 L
.09404 .31045 L
.10458 .31043 L
.11475 .31039 L
.12582 .31034 L
.14594 .31024 L
.18672 .30995 L
.22599 .30959 L
.26374 .30921 L
.30394 .30878 L
.34263 .30839 L
.38377 .30803 L
.4043 .30788 L
.42339 .30776 L
.44182 .30767 L
.45206 .30763 L
.4615 .3076 L
.47175 .30757 L
.47714 .30756 L
.48285 .30756 L
.48524 .30755 L
.48781 .30755 L
.49003 .30755 L
.49244 .30755 L
.49391 .30755 L
Mistroke
.49527 .30755 L
.49658 .30754 L
.4973 .30754 L
.49796 .30754 L
.49921 .30754 L
.49991 .30754 L
.50056 .30754 L
.50175 .30754 L
.503 .30754 L
.50423 .30754 L
.50556 .30755 L
.50797 .30755 L
.51033 .30755 L
.5125 .30755 L
.51744 .30756 L
.52268 .30756 L
.5314 .30758 L
.54102 .30761 L
.56041 .30768 L
.58128 .30779 L
.62247 .30808 L
.66215 .30844 L
.70031 .30883 L
.74092 .30926 L
.78002 .30965 L
.82157 .31001 L
.84241 .31016 L
.8616 .31028 L
.88033 .31037 L
.88988 .31041 L
.90012 .31044 L
.90539 .31045 L
.91038 .31046 L
.91524 .31047 L
.91974 .31048 L
.92399 .31048 L
.92616 .31049 L
.92851 .31049 L
.92973 .31049 L
.93085 .31049 L
.93199 .31049 L
.93305 .31049 L
.93421 .31049 L
.93549 .31049 L
.93673 .31049 L
.93743 .31049 L
.93806 .31049 L
.9392 .31049 L
.94026 .31049 L
.94143 .31049 L
Mistroke
.94268 .31049 L
.94524 .31049 L
.94757 .31049 L
.95207 .31048 L
.95635 .31048 L
.96584 .31046 L
.97619 .31043 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30903 m
.02846 .30903 L
.03279 .30903 L
.03527 .30903 L
.03754 .30903 L
.03879 .30903 L
.03945 .30903 L
.04015 .30903 L
.04143 .30903 L
.04262 .30903 L
.04384 .30903 L
.04496 .30903 L
.04626 .30903 L
.04749 .30903 L
.04862 .30903 L
.04967 .30903 L
.05205 .30903 L
.05469 .30903 L
.05708 .30903 L
.06244 .30903 L
.06787 .30903 L
.07287 .30903 L
.08414 .30903 L
.10458 .30903 L
.1234 .30902 L
.14407 .30902 L
.18449 .30902 L
.2234 .30901 L
.24321 .30901 L
.26476 .30901 L
.2837 .30901 L
.29448 .30901 L
.30461 .30901 L
.31492 .30901 L
.32438 .30901 L
.32931 .30901 L
.33449 .30901 L
.33719 .30901 L
.3397 .30901 L
.34111 .30901 L
.34245 .30901 L
.34319 .30901 L
.34399 .30901 L
.34471 .30901 L
.34539 .30901 L
.34662 .30901 L
.34775 .30901 L
.34896 .30901 L
.35028 .30901 L
.35143 .30901 L
Mistroke
.35265 .30901 L
.35485 .30901 L
.35767 .30901 L
.36032 .30901 L
.36526 .30901 L
.37054 .30901 L
.37538 .30901 L
.38631 .30901 L
.40517 .30901 L
.42585 .30901 L
.46632 .30901 L
.50528 .30902 L
.5467 .30902 L
.56743 .30902 L
.5866 .30902 L
.60522 .30903 L
.61462 .30903 L
.61967 .30903 L
.62498 .30903 L
.62981 .30903 L
.6351 .30903 L
.63742 .30903 L
.6399 .30903 L
.64222 .30903 L
.64436 .30903 L
.64565 .30903 L
.64707 .30903 L
.64849 .30903 L
.64927 .30903 L
.64999 .30903 L
.65068 .30903 L
.65133 .30903 L
.65256 .30903 L
.65387 .30903 L
.65461 .30903 L
.6553 .30903 L
.65648 .30903 L
.65759 .30903 L
.66012 .30903 L
.66258 .30903 L
.66523 .30903 L
.67018 .30903 L
.67479 .30903 L
.68525 .30903 L
.69544 .30903 L
.70634 .30903 L
.72766 .30902 L
.74781 .30902 L
.78624 .30902 L
.82713 .30901 L
Mistroke
.8665 .30901 L
.88627 .30901 L
.90435 .30901 L
.91364 .30901 L
.92378 .30901 L
.92933 .30901 L
.93448 .30901 L
.93941 .30901 L
.94196 .30901 L
.94466 .30901 L
.9466 .30901 L
.94872 .30901 L
.95066 .30901 L
.95246 .30901 L
.95356 .30901 L
.95459 .30901 L
.95552 .30901 L
.95654 .30901 L
.95763 .30901 L
.9588 .30901 L
.9598 .30901 L
.9609 .30901 L
.96186 .30901 L
.96288 .30901 L
.9647 .30901 L
.96879 .30901 L
.97232 .30901 L
.97619 .30901 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .42393 m
.06244 .43297 L
.10458 .44213 L
.14415 .45004 L
.18221 .45696 L
.22272 .46356 L
.26171 .46914 L
.30316 .47419 L
.34309 .47818 L
.3815 .48119 L
.40095 .4824 L
.42237 .48348 L
.44268 .48427 L
.45178 .48455 L
.46172 .48479 L
.4671 .4849 L
.4721 .48499 L
.47727 .48507 L
.48196 .48512 L
.48658 .48516 L
.4887 .48518 L
.49093 .48519 L
.49332 .4852 L
.49438 .48521 L
.49552 .48521 L
.49675 .48521 L
.49789 .48521 L
.49859 .48521 L
.49925 .48521 L
.50049 .48521 L
.50163 .48521 L
.50286 .48521 L
.50401 .48521 L
.50508 .48521 L
.50754 .4852 L
.51014 .48519 L
.51268 .48517 L
.51504 .48515 L
.5204 .4851 L
.5293 .48497 L
.53882 .48478 L
.54906 .48452 L
.56016 .48417 L
.58032 .48336 L
.60019 .48234 L
.62123 .48101 L
.65912 .47798 L
.69946 .4739 L
.73829 .46914 L
.77956 .46321 L
Mistroke
.81932 .4567 L
.85757 .44971 L
.89827 .44154 L
.93745 .43299 L
.97619 .42393 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .3388 m
.04262 .33988 L
.06244 .3408 L
.08255 .34151 L
.09396 .3418 L
.09905 .34191 L
.10458 .34201 L
.11004 .34208 L
.11508 .34214 L
.11989 .34218 L
.12232 .3422 L
.12369 .3422 L
.125 .34221 L
.12615 .34221 L
.12741 .34222 L
.12855 .34222 L
.12962 .34222 L
.13088 .34222 L
.13202 .34222 L
.13334 .34222 L
.13459 .34222 L
.13568 .34221 L
.13684 .34221 L
.1389 .3422 L
.14113 .34219 L
.14357 .34218 L
.14881 .34213 L
.15378 .34207 L
.16308 .34192 L
.1731 .3417 L
.184 .34139 L
.20377 .34065 L
.22478 .33962 L
.26253 .33717 L
.30273 .33375 L
.34142 .32978 L
.38256 .32495 L
.42218 .31982 L
.46029 .31461 L
.50085 .3089 L
.5399 .3034 L
.5814 .29773 L
.62138 .2926 L
.65985 .28811 L
.70076 .28396 L
.74017 .28067 L
.77805 .27826 L
.7975 .27733 L
.81839 .27657 L
.82852 .2763 L
Mistroke
.83387 .27618 L
.83957 .27607 L
.84504 .27598 L
.85 .27592 L
.85239 .27589 L
.85498 .27587 L
.85744 .27585 L
.85967 .27584 L
.86205 .27583 L
.86336 .27582 L
.8646 .27582 L
.86575 .27582 L
.86681 .27581 L
.86797 .27581 L
.8692 .27581 L
.87044 .27581 L
.87113 .27582 L
.87177 .27582 L
.87294 .27582 L
.87417 .27582 L
.87679 .27583 L
.87965 .27585 L
.88242 .27587 L
.88493 .27589 L
.89057 .27596 L
.90073 .27612 L
.91073 .27634 L
.91995 .2766 L
.94076 .27737 L
.95764 .27817 L
.97619 .27923 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .3099 m
.03279 .30992 L
.04262 .30993 L
.04758 .30993 L
.0503 .30993 L
.05288 .30994 L
.05528 .30994 L
.05655 .30994 L
.05789 .30994 L
.05902 .30994 L
.06026 .30994 L
.06139 .30994 L
.06244 .30994 L
.0631 .30994 L
.06379 .30994 L
.06504 .30994 L
.06581 .30994 L
.06653 .30994 L
.06788 .30994 L
.06917 .30994 L
.07036 .30994 L
.07305 .30994 L
.07529 .30993 L
.07776 .30993 L
.08274 .30993 L
.08819 .30992 L
.09404 .30992 L
.10458 .3099 L
.11475 .30988 L
.12582 .30985 L
.14594 .30978 L
.18672 .3096 L
.22599 .30938 L
.26374 .30914 L
.30394 .30887 L
.34263 .30863 L
.38377 .3084 L
.4043 .30831 L
.42339 .30823 L
.44182 .30818 L
.45206 .30815 L
.4615 .30813 L
.47175 .30811 L
.47714 .30811 L
.48285 .3081 L
.48524 .3081 L
.48781 .3081 L
.49003 .3081 L
.49244 .3081 L
.49391 .3081 L
Mistroke
.49527 .3081 L
.49658 .3081 L
.4973 .3081 L
.49796 .3081 L
.49921 .3081 L
.49991 .3081 L
.50056 .3081 L
.50175 .3081 L
.503 .3081 L
.50423 .3081 L
.50556 .3081 L
.50797 .3081 L
.51033 .3081 L
.5125 .3081 L
.51744 .3081 L
.52268 .30811 L
.5314 .30812 L
.54102 .30814 L
.56041 .30818 L
.58128 .30825 L
.62247 .30843 L
.66215 .30865 L
.70031 .3089 L
.74092 .30917 L
.78002 .30941 L
.82157 .30964 L
.84241 .30973 L
.8616 .30981 L
.88033 .30986 L
.88988 .30989 L
.90012 .30991 L
.90539 .30991 L
.91038 .30992 L
.91524 .30993 L
.91974 .30993 L
.92399 .30993 L
.92616 .30994 L
.92851 .30994 L
.92973 .30994 L
.93085 .30994 L
.93199 .30994 L
.93305 .30994 L
.93421 .30994 L
.93549 .30994 L
.93673 .30994 L
.93743 .30994 L
.93806 .30994 L
.9392 .30994 L
.94026 .30994 L
.94143 .30994 L
Mistroke
.94268 .30994 L
.94524 .30994 L
.94757 .30994 L
.95207 .30993 L
.95635 .30993 L
.96584 .30992 L
.97619 .3099 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03527 .30902 L
.03754 .30902 L
.03879 .30902 L
.03945 .30902 L
.04015 .30902 L
.04143 .30902 L
.04262 .30902 L
.04384 .30902 L
.04496 .30902 L
.04626 .30902 L
.04749 .30902 L
.04862 .30902 L
.04967 .30902 L
.05205 .30902 L
.05469 .30902 L
.05708 .30902 L
.06244 .30902 L
.06787 .30902 L
.07287 .30902 L
.08414 .30902 L
.10458 .30902 L
.1234 .30902 L
.14407 .30902 L
.18449 .30902 L
.2234 .30902 L
.24321 .30902 L
.26476 .30901 L
.2837 .30901 L
.29448 .30901 L
.30461 .30901 L
.31492 .30901 L
.32438 .30901 L
.32931 .30901 L
.33449 .30901 L
.33719 .30901 L
.3397 .30901 L
.34111 .30901 L
.34245 .30901 L
.34319 .30901 L
.34399 .30901 L
.34471 .30901 L
.34539 .30901 L
.34662 .30901 L
.34775 .30901 L
.34896 .30901 L
.35028 .30901 L
.35143 .30901 L
Mistroke
.35265 .30901 L
.35485 .30901 L
.35767 .30901 L
.36032 .30901 L
.36526 .30901 L
.37054 .30901 L
.37538 .30901 L
.38631 .30901 L
.40517 .30901 L
.42585 .30901 L
.46632 .30902 L
.50528 .30902 L
.5467 .30902 L
.56743 .30902 L
.5866 .30902 L
.60522 .30902 L
.61462 .30902 L
.61967 .30902 L
.62498 .30902 L
.62981 .30902 L
.6351 .30902 L
.63742 .30902 L
.6399 .30902 L
.64222 .30902 L
.64436 .30902 L
.64565 .30902 L
.64707 .30902 L
.64849 .30902 L
.64927 .30902 L
.64999 .30902 L
.65068 .30902 L
.65133 .30902 L
.65256 .30902 L
.65387 .30902 L
.65461 .30902 L
.6553 .30902 L
.65648 .30902 L
.65759 .30902 L
.66012 .30902 L
.66258 .30902 L
.66523 .30902 L
.67018 .30902 L
.67479 .30902 L
.68525 .30902 L
.69544 .30902 L
.70634 .30902 L
.72766 .30902 L
.74781 .30902 L
.78624 .30902 L
.82713 .30902 L
Mistroke
.8665 .30901 L
.88627 .30901 L
.90435 .30901 L
.91364 .30901 L
.92378 .30901 L
.92933 .30901 L
.93448 .30901 L
.93941 .30901 L
.94196 .30901 L
.94466 .30901 L
.9466 .30901 L
.94872 .30901 L
.95066 .30901 L
.95246 .30901 L
.95356 .30901 L
.95459 .30901 L
.95552 .30901 L
.95654 .30901 L
.95763 .30901 L
.9588 .30901 L
.9598 .30901 L
.9609 .30901 L
.96186 .30901 L
.96288 .30901 L
.9647 .30901 L
.96879 .30901 L
.97232 .30901 L
.97619 .30901 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .42058 m
.06244 .42935 L
.10458 .43825 L
.14415 .44592 L
.18221 .45265 L
.22272 .45905 L
.26171 .46447 L
.30316 .46937 L
.34309 .47325 L
.3815 .47617 L
.40095 .47734 L
.42237 .47839 L
.44268 .47916 L
.45178 .47943 L
.46172 .47967 L
.4671 .47977 L
.4721 .47986 L
.47727 .47993 L
.48196 .47998 L
.48658 .48002 L
.4887 .48004 L
.49093 .48005 L
.49332 .48006 L
.49438 .48007 L
.49552 .48007 L
.49675 .48007 L
.49789 .48007 L
.49859 .48007 L
.49925 .48007 L
.50049 .48007 L
.50163 .48007 L
.50286 .48007 L
.50401 .48007 L
.50508 .48007 L
.50754 .48006 L
.51014 .48005 L
.51268 .48003 L
.51504 .48001 L
.5204 .47996 L
.5293 .47983 L
.53882 .47965 L
.54906 .4794 L
.56016 .47907 L
.58032 .47828 L
.60019 .47728 L
.62123 .47599 L
.65912 .47305 L
.69946 .46909 L
.73829 .46447 L
.77956 .45872 L
Mistroke
.81932 .45239 L
.85757 .4456 L
.89827 .43767 L
.93745 .42937 L
.97619 .42058 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .33428 m
.04262 .33519 L
.06244 .33598 L
.08255 .33658 L
.09396 .33682 L
.09905 .33691 L
.10458 .337 L
.11004 .33706 L
.11508 .33711 L
.11989 .33715 L
.12232 .33716 L
.12369 .33717 L
.125 .33717 L
.12615 .33717 L
.12741 .33718 L
.12855 .33718 L
.12962 .33718 L
.13088 .33718 L
.13202 .33718 L
.13334 .33718 L
.13459 .33718 L
.13568 .33718 L
.13684 .33717 L
.1389 .33717 L
.14113 .33716 L
.14357 .33714 L
.14881 .3371 L
.15378 .33705 L
.16308 .33692 L
.1731 .33673 L
.184 .33647 L
.20377 .33585 L
.22478 .33498 L
.26253 .33289 L
.30273 .33 L
.34142 .32663 L
.38256 .32253 L
.42218 .31818 L
.46029 .31376 L
.50085 .30891 L
.5399 .30425 L
.5814 .29945 L
.62138 .29509 L
.65985 .29129 L
.70076 .28776 L
.74017 .28497 L
.77805 .28293 L
.7975 .28214 L
.81839 .2815 L
.82852 .28127 L
Mistroke
.83387 .28116 L
.83957 .28107 L
.84504 .281 L
.85 .28094 L
.85239 .28092 L
.85498 .2809 L
.85744 .28089 L
.85967 .28087 L
.86205 .28086 L
.86336 .28086 L
.8646 .28086 L
.86575 .28086 L
.86681 .28085 L
.86797 .28085 L
.8692 .28085 L
.87044 .28085 L
.87113 .28086 L
.87177 .28086 L
.87294 .28086 L
.87417 .28086 L
.87679 .28087 L
.87965 .28088 L
.88242 .2809 L
.88493 .28092 L
.89057 .28098 L
.90073 .28112 L
.91073 .2813 L
.91995 .28152 L
.94076 .28217 L
.95764 .28285 L
.97619 .28376 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30957 m
.03279 .30958 L
.04262 .30959 L
.04758 .30959 L
.0503 .30959 L
.05288 .30959 L
.05528 .30959 L
.05655 .30959 L
.05789 .30959 L
.05902 .30959 L
.06026 .30959 L
.06139 .30959 L
.06244 .30959 L
.0631 .30959 L
.06379 .30959 L
.06504 .30959 L
.06581 .30959 L
.06653 .30959 L
.06788 .30959 L
.06917 .30959 L
.07036 .30959 L
.07305 .30959 L
.07529 .30959 L
.07776 .30959 L
.08274 .30959 L
.08819 .30958 L
.09404 .30958 L
.10458 .30957 L
.11475 .30955 L
.12582 .30954 L
.14594 .30949 L
.18672 .30938 L
.22599 .30924 L
.26374 .30909 L
.30394 .30892 L
.34263 .30877 L
.38377 .30863 L
.4043 .30857 L
.42339 .30853 L
.44182 .30849 L
.45206 .30847 L
.4615 .30846 L
.47175 .30845 L
.47714 .30845 L
.48285 .30845 L
.48524 .30844 L
.48781 .30844 L
.49003 .30844 L
.49244 .30844 L
.49391 .30844 L
Mistroke
.49527 .30844 L
.49658 .30844 L
.4973 .30844 L
.49796 .30844 L
.49921 .30844 L
.49991 .30844 L
.50056 .30844 L
.50175 .30844 L
.503 .30844 L
.50423 .30844 L
.50556 .30844 L
.50797 .30844 L
.51033 .30844 L
.5125 .30844 L
.51744 .30845 L
.52268 .30845 L
.5314 .30846 L
.54102 .30847 L
.56041 .30849 L
.58128 .30854 L
.62247 .30865 L
.66215 .30879 L
.70031 .30894 L
.74092 .30911 L
.78002 .30926 L
.82157 .30941 L
.84241 .30947 L
.8616 .30951 L
.88033 .30955 L
.88988 .30956 L
.90012 .30957 L
.90539 .30958 L
.91038 .30958 L
.91524 .30959 L
.91974 .30959 L
.92399 .30959 L
.92616 .30959 L
.92851 .30959 L
.92973 .30959 L
.93085 .30959 L
.93199 .30959 L
.93305 .30959 L
.93421 .30959 L
.93549 .30959 L
.93673 .30959 L
.93743 .30959 L
.93806 .30959 L
.9392 .30959 L
.94026 .30959 L
.94143 .30959 L
Mistroke
.94268 .30959 L
.94524 .30959 L
.94757 .30959 L
.95207 .30959 L
.95635 .30959 L
.96584 .30958 L
.97619 .30957 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03527 .30902 L
.03754 .30902 L
.03879 .30902 L
.03945 .30902 L
.04015 .30902 L
.04143 .30902 L
.04262 .30902 L
.04384 .30902 L
.04496 .30902 L
.04626 .30902 L
.04749 .30902 L
.04862 .30902 L
.04967 .30902 L
.05205 .30902 L
.05469 .30902 L
.05708 .30902 L
.06244 .30902 L
.06787 .30902 L
.07287 .30902 L
.08414 .30902 L
.10458 .30902 L
.1234 .30902 L
.14407 .30902 L
.18449 .30902 L
.2234 .30902 L
.24321 .30902 L
.26476 .30902 L
.2837 .30902 L
.29448 .30902 L
.30461 .30902 L
.31492 .30902 L
.32438 .30902 L
.32931 .30902 L
.33449 .30902 L
.33719 .30902 L
.3397 .30902 L
.34111 .30902 L
.34245 .30902 L
.34319 .30902 L
.34399 .30902 L
.34471 .30902 L
.34539 .30902 L
.34662 .30902 L
.34775 .30902 L
.34896 .30902 L
.35028 .30902 L
.35143 .30902 L
Mistroke
.35265 .30902 L
.35485 .30902 L
.35767 .30902 L
.36032 .30902 L
.36526 .30902 L
.37054 .30902 L
.37538 .30902 L
.38631 .30902 L
.40517 .30902 L
.42585 .30902 L
.46632 .30902 L
.50528 .30902 L
.5467 .30902 L
.56743 .30902 L
.5866 .30902 L
.60522 .30902 L
.61462 .30902 L
.61967 .30902 L
.62498 .30902 L
.62981 .30902 L
.6351 .30902 L
.63742 .30902 L
.6399 .30902 L
.64222 .30902 L
.64436 .30902 L
.64565 .30902 L
.64707 .30902 L
.64849 .30902 L
.64927 .30902 L
.64999 .30902 L
.65068 .30902 L
.65133 .30902 L
.65256 .30902 L
.65387 .30902 L
.65461 .30902 L
.6553 .30902 L
.65648 .30902 L
.65759 .30902 L
.66012 .30902 L
.66258 .30902 L
.66523 .30902 L
.67018 .30902 L
.67479 .30902 L
.68525 .30902 L
.69544 .30902 L
.70634 .30902 L
.72766 .30902 L
.74781 .30902 L
.78624 .30902 L
.82713 .30902 L
Mistroke
.8665 .30902 L
.88627 .30902 L
.90435 .30902 L
.91364 .30902 L
.92378 .30902 L
.92933 .30902 L
.93448 .30902 L
.93941 .30902 L
.94196 .30902 L
.94466 .30902 L
.9466 .30902 L
.94872 .30902 L
.95066 .30902 L
.95246 .30902 L
.95356 .30902 L
.95459 .30902 L
.95552 .30902 L
.95654 .30902 L
.95763 .30902 L
.9588 .30902 L
.9598 .30902 L
.9609 .30902 L
.96186 .30902 L
.96288 .30902 L
.9647 .30902 L
.96879 .30902 L
.97232 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .41732 m
.06244 .42584 L
.10458 .43448 L
.14415 .44193 L
.18221 .44846 L
.22272 .45468 L
.26171 .45993 L
.30316 .46469 L
.34309 .46846 L
.3815 .47129 L
.40095 .47243 L
.42237 .47345 L
.44268 .47419 L
.45178 .47445 L
.46172 .47469 L
.4671 .47479 L
.4721 .47487 L
.47727 .47494 L
.48196 .475 L
.48658 .47504 L
.4887 .47505 L
.49093 .47506 L
.49332 .47507 L
.49438 .47508 L
.49552 .47508 L
.49675 .47508 L
.49789 .47508 L
.49859 .47508 L
.49925 .47508 L
.50049 .47508 L
.50163 .47508 L
.50286 .47508 L
.50401 .47508 L
.50508 .47508 L
.50754 .47507 L
.51014 .47506 L
.51268 .47504 L
.51504 .47502 L
.5204 .47497 L
.5293 .47485 L
.53882 .47468 L
.54906 .47443 L
.56016 .4741 L
.58032 .47334 L
.60019 .47237 L
.62123 .47112 L
.65912 .46827 L
.69946 .46442 L
.73829 .45993 L
.77956 .45435 L
Mistroke
.81932 .44821 L
.85757 .44162 L
.89827 .43392 L
.93745 .42586 L
.97619 .41732 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .33044 m
.04262 .33122 L
.06244 .33188 L
.08255 .33239 L
.09396 .3326 L
.09905 .33268 L
.10458 .33275 L
.11004 .33281 L
.11508 .33285 L
.11989 .33288 L
.12232 .33289 L
.12369 .33289 L
.125 .3329 L
.12615 .3329 L
.12741 .3329 L
.12855 .3329 L
.12962 .3329 L
.13088 .33291 L
.13202 .33291 L
.13334 .3329 L
.13459 .3329 L
.13568 .3329 L
.13684 .3329 L
.1389 .33289 L
.14113 .33288 L
.14357 .33287 L
.14881 .33284 L
.15378 .3328 L
.16308 .33269 L
.1731 .33253 L
.184 .33231 L
.20377 .33178 L
.22478 .33104 L
.26253 .32927 L
.30273 .32681 L
.34142 .32396 L
.38256 .32048 L
.42218 .31679 L
.46029 .31304 L
.50085 .30893 L
.5399 .30498 L
.5814 .3009 L
.62138 .29721 L
.65985 .29398 L
.70076 .29099 L
.74017 .28862 L
.77805 .28689 L
.7975 .28622 L
.81839 .28568 L
.82852 .28548 L
Mistroke
.83387 .28539 L
.83957 .28531 L
.84504 .28525 L
.85 .2852 L
.85239 .28519 L
.85498 .28517 L
.85744 .28516 L
.85967 .28515 L
.86205 .28514 L
.86336 .28513 L
.8646 .28513 L
.86575 .28513 L
.86681 .28513 L
.86797 .28513 L
.8692 .28513 L
.87044 .28513 L
.87113 .28513 L
.87177 .28513 L
.87294 .28513 L
.87417 .28514 L
.87679 .28514 L
.87965 .28515 L
.88242 .28517 L
.88493 .28519 L
.89057 .28523 L
.90073 .28535 L
.91073 .28551 L
.91995 .2857 L
.94076 .28625 L
.95764 .28682 L
.97619 .28759 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30936 m
.03279 .30937 L
.04262 .30937 L
.04758 .30937 L
.0503 .30938 L
.05288 .30938 L
.05528 .30938 L
.05655 .30938 L
.05789 .30938 L
.05902 .30938 L
.06026 .30938 L
.06139 .30938 L
.06244 .30938 L
.0631 .30938 L
.06379 .30938 L
.06504 .30938 L
.06581 .30938 L
.06653 .30938 L
.06788 .30938 L
.06917 .30938 L
.07036 .30938 L
.07305 .30938 L
.07529 .30938 L
.07776 .30938 L
.08274 .30937 L
.08819 .30937 L
.09404 .30937 L
.10458 .30936 L
.11475 .30935 L
.12582 .30934 L
.14594 .30932 L
.18672 .30924 L
.22599 .30916 L
.26374 .30906 L
.30394 .30896 L
.34263 .30886 L
.38377 .30878 L
.4043 .30874 L
.42339 .30871 L
.44182 .30869 L
.45206 .30868 L
.4615 .30867 L
.47175 .30866 L
.47714 .30866 L
.48285 .30866 L
.48524 .30866 L
.48781 .30866 L
.49003 .30866 L
.49244 .30866 L
.49391 .30866 L
Mistroke
.49527 .30866 L
.49658 .30866 L
.4973 .30866 L
.49796 .30866 L
.49921 .30866 L
.49991 .30866 L
.50056 .30866 L
.50175 .30866 L
.503 .30866 L
.50423 .30866 L
.50556 .30866 L
.50797 .30866 L
.51033 .30866 L
.5125 .30866 L
.51744 .30866 L
.52268 .30866 L
.5314 .30867 L
.54102 .30867 L
.56041 .30869 L
.58128 .30872 L
.62247 .30879 L
.66215 .30888 L
.70031 .30897 L
.74092 .30908 L
.78002 .30917 L
.82157 .30926 L
.84241 .3093 L
.8616 .30933 L
.88033 .30935 L
.88988 .30936 L
.90012 .30936 L
.90539 .30937 L
.91038 .30937 L
.91524 .30937 L
.91974 .30937 L
.92399 .30938 L
.92616 .30938 L
.92851 .30938 L
.92973 .30938 L
.93085 .30938 L
.93199 .30938 L
.93305 .30938 L
.93421 .30938 L
.93549 .30938 L
.93673 .30938 L
.93743 .30938 L
.93806 .30938 L
.9392 .30938 L
.94026 .30938 L
.94143 .30938 L
Mistroke
.94268 .30938 L
.94524 .30938 L
.94757 .30938 L
.95207 .30938 L
.95635 .30937 L
.96584 .30937 L
.97619 .30936 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03527 .30902 L
.03754 .30902 L
.03879 .30902 L
.03945 .30902 L
.04015 .30902 L
.04143 .30902 L
.04262 .30902 L
.04384 .30902 L
.04496 .30902 L
.04626 .30902 L
.04749 .30902 L
.04862 .30902 L
.04967 .30902 L
.05205 .30902 L
.05469 .30902 L
.05708 .30902 L
.06244 .30902 L
.06787 .30902 L
.07287 .30902 L
.08414 .30902 L
.10458 .30902 L
.1234 .30902 L
.14407 .30902 L
.18449 .30902 L
.2234 .30902 L
.24321 .30902 L
.26476 .30902 L
.2837 .30902 L
.29448 .30902 L
.30461 .30902 L
.31492 .30902 L
.32438 .30902 L
.32931 .30902 L
.33449 .30902 L
.33719 .30902 L
.3397 .30902 L
.34111 .30902 L
.34245 .30902 L
.34319 .30902 L
.34399 .30902 L
.34471 .30902 L
.34539 .30902 L
.34662 .30902 L
.34775 .30902 L
.34896 .30902 L
.35028 .30902 L
.35143 .30902 L
Mistroke
.35265 .30902 L
.35485 .30902 L
.35767 .30902 L
.36032 .30902 L
.36526 .30902 L
.37054 .30902 L
.37538 .30902 L
.38631 .30902 L
.40517 .30902 L
.42585 .30902 L
.46632 .30902 L
.50528 .30902 L
.5467 .30902 L
.56743 .30902 L
.5866 .30902 L
.60522 .30902 L
.61462 .30902 L
.61967 .30902 L
.62498 .30902 L
.62981 .30902 L
.6351 .30902 L
.63742 .30902 L
.6399 .30902 L
.64222 .30902 L
.64436 .30902 L
.64565 .30902 L
.64707 .30902 L
.64849 .30902 L
.64927 .30902 L
.64999 .30902 L
.65068 .30902 L
.65133 .30902 L
.65256 .30902 L
.65387 .30902 L
.65461 .30902 L
.6553 .30902 L
.65648 .30902 L
.65759 .30902 L
.66012 .30902 L
.66258 .30902 L
.66523 .30902 L
.67018 .30902 L
.67479 .30902 L
.68525 .30902 L
.69544 .30902 L
.70634 .30902 L
.72766 .30902 L
.74781 .30902 L
.78624 .30902 L
.82713 .30902 L
Mistroke
.8665 .30902 L
.88627 .30902 L
.90435 .30902 L
.91364 .30902 L
.92378 .30902 L
.92933 .30902 L
.93448 .30902 L
.93941 .30902 L
.94196 .30902 L
.94466 .30902 L
.9466 .30902 L
.94872 .30902 L
.95066 .30902 L
.95246 .30902 L
.95356 .30902 L
.95459 .30902 L
.95552 .30902 L
.95654 .30902 L
.95763 .30902 L
.9588 .30902 L
.9598 .30902 L
.9609 .30902 L
.96186 .30902 L
.96288 .30902 L
.9647 .30902 L
.96879 .30902 L
.97232 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .41416 m
.06244 .42243 L
.10458 .43082 L
.14415 .43805 L
.18221 .44439 L
.22272 .45043 L
.26171 .45553 L
.30316 .46015 L
.34309 .4638 L
.3815 .46656 L
.40095 .46766 L
.42237 .46866 L
.44268 .46938 L
.45178 .46963 L
.46172 .46985 L
.4671 .46995 L
.4721 .47003 L
.47727 .4701 L
.48196 .47015 L
.48658 .47019 L
.4887 .47021 L
.49093 .47022 L
.49332 .47023 L
.49438 .47023 L
.49552 .47023 L
.49675 .47024 L
.49789 .47024 L
.49859 .47024 L
.49925 .47024 L
.50049 .47024 L
.50163 .47024 L
.50286 .47024 L
.50401 .47024 L
.50508 .47023 L
.50754 .47022 L
.51014 .47021 L
.51268 .4702 L
.51504 .47018 L
.5204 .47013 L
.5293 .47001 L
.53882 .46984 L
.54906 .46961 L
.56016 .46929 L
.58032 .46855 L
.60019 .46761 L
.62123 .46639 L
.65912 .46362 L
.69946 .45988 L
.73829 .45553 L
.77956 .45011 L
Mistroke
.81932 .44415 L
.85757 .43775 L
.89827 .43027 L
.93745 .42245 L
.97619 .41416 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .32719 m
.04262 .32785 L
.06244 .32841 L
.08255 .32884 L
.09396 .32902 L
.09905 .32909 L
.10458 .32915 L
.11004 .3292 L
.11508 .32923 L
.11989 .32926 L
.12232 .32926 L
.12369 .32927 L
.125 .32927 L
.12615 .32927 L
.12741 .32928 L
.12855 .32928 L
.12962 .32928 L
.13088 .32928 L
.13202 .32928 L
.13334 .32928 L
.13459 .32928 L
.13568 .32928 L
.13684 .32927 L
.1389 .32927 L
.14113 .32926 L
.14357 .32925 L
.14881 .32922 L
.15378 .32919 L
.16308 .32909 L
.1731 .32896 L
.184 .32877 L
.20377 .32832 L
.22478 .32769 L
.26253 .32619 L
.30273 .32411 L
.34142 .32169 L
.38256 .31874 L
.42218 .31561 L
.46029 .31243 L
.50085 .30894 L
.5399 .30559 L
.5814 .30213 L
.62138 .299 L
.65985 .29626 L
.70076 .29372 L
.74017 .29172 L
.77805 .29025 L
.7975 .28968 L
.81839 .28922 L
.82852 .28905 L
Mistroke
.83387 .28898 L
.83957 .28891 L
.84504 .28886 L
.85 .28882 L
.85239 .2888 L
.85498 .28879 L
.85744 .28878 L
.85967 .28877 L
.86205 .28876 L
.86336 .28876 L
.8646 .28876 L
.86575 .28876 L
.86681 .28876 L
.86797 .28876 L
.8692 .28875 L
.87044 .28876 L
.87113 .28876 L
.87177 .28876 L
.87294 .28876 L
.87417 .28876 L
.87679 .28877 L
.87965 .28878 L
.88242 .28879 L
.88493 .2888 L
.89057 .28884 L
.90073 .28894 L
.91073 .28908 L
.91995 .28924 L
.94076 .2897 L
.95764 .29019 L
.97619 .29084 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30923 m
.03279 .30924 L
.04262 .30924 L
.04758 .30924 L
.0503 .30924 L
.05288 .30924 L
.05528 .30924 L
.05655 .30924 L
.05789 .30924 L
.05902 .30924 L
.06026 .30924 L
.06139 .30924 L
.06244 .30924 L
.0631 .30924 L
.06379 .30924 L
.06504 .30924 L
.06581 .30924 L
.06653 .30924 L
.06788 .30924 L
.06917 .30924 L
.07036 .30924 L
.07305 .30924 L
.07529 .30924 L
.07776 .30924 L
.08274 .30924 L
.08819 .30924 L
.09404 .30924 L
.10458 .30923 L
.11475 .30923 L
.12582 .30922 L
.14594 .3092 L
.18672 .30916 L
.22599 .3091 L
.26374 .30905 L
.30394 .30898 L
.34263 .30892 L
.38377 .30887 L
.4043 .30884 L
.42339 .30883 L
.44182 .30881 L
.45206 .3088 L
.4615 .3088 L
.47175 .3088 L
.47714 .30879 L
.48285 .30879 L
.48524 .30879 L
.48781 .30879 L
.49003 .30879 L
.49244 .30879 L
.49391 .30879 L
Mistroke
.49527 .30879 L
.49658 .30879 L
.4973 .30879 L
.49796 .30879 L
.49921 .30879 L
.49991 .30879 L
.50056 .30879 L
.50175 .30879 L
.503 .30879 L
.50423 .30879 L
.50556 .30879 L
.50797 .30879 L
.51033 .30879 L
.5125 .30879 L
.51744 .30879 L
.52268 .30879 L
.5314 .3088 L
.54102 .3088 L
.56041 .30881 L
.58128 .30883 L
.62247 .30887 L
.66215 .30893 L
.70031 .30899 L
.74092 .30905 L
.78002 .30911 L
.82157 .30917 L
.84241 .30919 L
.8616 .30921 L
.88033 .30922 L
.88988 .30923 L
.90012 .30923 L
.90539 .30924 L
.91038 .30924 L
.91524 .30924 L
.91974 .30924 L
.92399 .30924 L
.92616 .30924 L
.92851 .30924 L
.92973 .30924 L
.93085 .30924 L
.93199 .30924 L
.93305 .30924 L
.93421 .30924 L
.93549 .30924 L
.93673 .30924 L
.93743 .30924 L
.93806 .30924 L
.9392 .30924 L
.94026 .30924 L
.94143 .30924 L
Mistroke
.94268 .30924 L
.94524 .30924 L
.94757 .30924 L
.95207 .30924 L
.95635 .30924 L
.96584 .30924 L
.97619 .30923 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03527 .30902 L
.03754 .30902 L
.03879 .30902 L
.03945 .30902 L
.04015 .30902 L
.04143 .30902 L
.04262 .30902 L
.04384 .30902 L
.04496 .30902 L
.04626 .30902 L
.04749 .30902 L
.04862 .30902 L
.04967 .30902 L
.05205 .30902 L
.05469 .30902 L
.05708 .30902 L
.06244 .30902 L
.06787 .30902 L
.07287 .30902 L
.08414 .30902 L
.10458 .30902 L
.1234 .30902 L
.14407 .30902 L
.18449 .30902 L
.2234 .30902 L
.24321 .30902 L
.26476 .30902 L
.2837 .30902 L
.29448 .30902 L
.30461 .30902 L
.31492 .30902 L
.32438 .30902 L
.32931 .30902 L
.33449 .30902 L
.33719 .30902 L
.3397 .30902 L
.34111 .30902 L
.34245 .30902 L
.34319 .30902 L
.34399 .30902 L
.34471 .30902 L
.34539 .30902 L
.34662 .30902 L
.34775 .30902 L
.34896 .30902 L
.35028 .30902 L
.35143 .30902 L
Mistroke
.35265 .30902 L
.35485 .30902 L
.35767 .30902 L
.36032 .30902 L
.36526 .30902 L
.37054 .30902 L
.37538 .30902 L
.38631 .30902 L
.40517 .30902 L
.42585 .30902 L
.46632 .30902 L
.50528 .30902 L
.5467 .30902 L
.56743 .30902 L
.5866 .30902 L
.60522 .30902 L
.61462 .30902 L
.61967 .30902 L
.62498 .30902 L
.62981 .30902 L
.6351 .30902 L
.63742 .30902 L
.6399 .30902 L
.64222 .30902 L
.64436 .30902 L
.64565 .30902 L
.64707 .30902 L
.64849 .30902 L
.64927 .30902 L
.64999 .30902 L
.65068 .30902 L
.65133 .30902 L
.65256 .30902 L
.65387 .30902 L
.65461 .30902 L
.6553 .30902 L
.65648 .30902 L
.65759 .30902 L
.66012 .30902 L
.66258 .30902 L
.66523 .30902 L
.67018 .30902 L
.67479 .30902 L
.68525 .30902 L
.69544 .30902 L
.70634 .30902 L
.72766 .30902 L
.74781 .30902 L
.78624 .30902 L
.82713 .30902 L
Mistroke
.8665 .30902 L
.88627 .30902 L
.90435 .30902 L
.91364 .30902 L
.92378 .30902 L
.92933 .30902 L
.93448 .30902 L
.93941 .30902 L
.94196 .30902 L
.94466 .30902 L
.9466 .30902 L
.94872 .30902 L
.95066 .30902 L
.95246 .30902 L
.95356 .30902 L
.95459 .30902 L
.95552 .30902 L
.95654 .30902 L
.95763 .30902 L
.9588 .30902 L
.9598 .30902 L
.9609 .30902 L
.96186 .30902 L
.96288 .30902 L
.9647 .30902 L
.96879 .30902 L
.97232 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .4111 m
.06244 .41912 L
.10458 .42726 L
.14415 .43429 L
.18221 .44044 L
.22272 .4463 L
.26171 .45125 L
.30316 .45574 L
.34309 .45929 L
.3815 .46196 L
.40095 .46304 L
.42237 .464 L
.44268 .4647 L
.45178 .46494 L
.46172 .46516 L
.4671 .46526 L
.4721 .46534 L
.47727 .4654 L
.48196 .46545 L
.48658 .46549 L
.4887 .4655 L
.49093 .46552 L
.49332 .46552 L
.49438 .46553 L
.49552 .46553 L
.49675 .46553 L
.49789 .46554 L
.49859 .46554 L
.49925 .46554 L
.50049 .46554 L
.50163 .46554 L
.50286 .46553 L
.50401 .46553 L
.50508 .46553 L
.50754 .46552 L
.51014 .46551 L
.51268 .4655 L
.51504 .46548 L
.5204 .46543 L
.5293 .46532 L
.53882 .46515 L
.54906 .46492 L
.56016 .46461 L
.58032 .46389 L
.60019 .46298 L
.62123 .4618 L
.65912 .45911 L
.69946 .45548 L
.73829 .45125 L
.77956 .44599 L
Mistroke
.81932 .4402 L
.85757 .434 L
.89827 .42674 L
.93745 .41914 L
.97619 .4111 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .32443 m
.04262 .32499 L
.06244 .32547 L
.08255 .32583 L
.09396 .32599 L
.09905 .32604 L
.10458 .32609 L
.11004 .32613 L
.11508 .32616 L
.11989 .32618 L
.12232 .32619 L
.12369 .32619 L
.125 .3262 L
.12615 .3262 L
.12741 .3262 L
.12855 .3262 L
.12962 .3262 L
.13088 .3262 L
.13202 .3262 L
.13334 .3262 L
.13459 .3262 L
.13568 .3262 L
.13684 .3262 L
.1389 .32619 L
.14113 .32619 L
.14357 .32618 L
.14881 .32616 L
.15378 .32612 L
.16308 .32605 L
.1731 .32593 L
.184 .32577 L
.20377 .32539 L
.22478 .32486 L
.26253 .32359 L
.30273 .32182 L
.34142 .31976 L
.38256 .31726 L
.42218 .31461 L
.46029 .31191 L
.50085 .30895 L
.5399 .30611 L
.5814 .30318 L
.62138 .30052 L
.65985 .2982 L
.70076 .29604 L
.74017 .29434 L
.77805 .2931 L
.7975 .29262 L
.81839 .29222 L
.82852 .29208 L
Mistroke
.83387 .29202 L
.83957 .29196 L
.84504 .29192 L
.85 .29189 L
.85239 .29187 L
.85498 .29186 L
.85744 .29185 L
.85967 .29184 L
.86205 .29184 L
.86336 .29184 L
.8646 .29183 L
.86575 .29183 L
.86681 .29183 L
.86797 .29183 L
.8692 .29183 L
.87044 .29183 L
.87113 .29183 L
.87177 .29183 L
.87294 .29183 L
.87417 .29184 L
.87679 .29184 L
.87965 .29185 L
.88242 .29186 L
.88493 .29187 L
.89057 .29191 L
.90073 .29199 L
.91073 .29211 L
.91995 .29224 L
.94076 .29263 L
.95764 .29305 L
.97619 .2936 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30915 m
.03279 .30915 L
.04262 .30916 L
.04758 .30916 L
.0503 .30916 L
.05288 .30916 L
.05528 .30916 L
.05655 .30916 L
.05789 .30916 L
.05902 .30916 L
.06026 .30916 L
.06139 .30916 L
.06244 .30916 L
.0631 .30916 L
.06379 .30916 L
.06504 .30916 L
.06581 .30916 L
.06653 .30916 L
.06788 .30916 L
.06917 .30916 L
.07036 .30916 L
.07305 .30916 L
.07529 .30916 L
.07776 .30916 L
.08274 .30916 L
.08819 .30916 L
.09404 .30915 L
.10458 .30915 L
.11475 .30915 L
.12582 .30914 L
.14594 .30913 L
.18672 .30911 L
.22599 .30907 L
.26374 .30904 L
.30394 .30899 L
.34263 .30896 L
.38377 .30892 L
.4043 .30891 L
.42339 .3089 L
.44182 .30889 L
.45206 .30888 L
.4615 .30888 L
.47175 .30888 L
.47714 .30888 L
.48285 .30888 L
.48524 .30888 L
.48781 .30888 L
.49003 .30888 L
.49244 .30888 L
.49391 .30888 L
Mistroke
.49527 .30888 L
.49658 .30888 L
.4973 .30888 L
.49796 .30888 L
.49921 .30888 L
.49991 .30888 L
.50056 .30888 L
.50175 .30888 L
.503 .30888 L
.50423 .30888 L
.50556 .30888 L
.50797 .30888 L
.51033 .30888 L
.5125 .30888 L
.51744 .30888 L
.52268 .30888 L
.5314 .30888 L
.54102 .30888 L
.56041 .30889 L
.58128 .3089 L
.62247 .30893 L
.66215 .30896 L
.70031 .309 L
.74092 .30904 L
.78002 .30908 L
.82157 .30911 L
.84241 .30913 L
.8616 .30914 L
.88033 .30915 L
.88988 .30915 L
.90012 .30915 L
.90539 .30915 L
.91038 .30916 L
.91524 .30916 L
.91974 .30916 L
.92399 .30916 L
.92616 .30916 L
.92851 .30916 L
.92973 .30916 L
.93085 .30916 L
.93199 .30916 L
.93305 .30916 L
.93421 .30916 L
.93549 .30916 L
.93673 .30916 L
.93743 .30916 L
.93806 .30916 L
.9392 .30916 L
.94026 .30916 L
.94143 .30916 L
Mistroke
.94268 .30916 L
.94524 .30916 L
.94757 .30916 L
.95207 .30916 L
.95635 .30916 L
.96584 .30915 L
.97619 .30915 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03527 .30902 L
.03754 .30902 L
.03879 .30902 L
.03945 .30902 L
.04015 .30902 L
.04143 .30902 L
.04262 .30902 L
.04384 .30902 L
.04496 .30902 L
.04626 .30902 L
.04749 .30902 L
.04862 .30902 L
.04967 .30902 L
.05205 .30902 L
.05469 .30902 L
.05708 .30902 L
.06244 .30902 L
.06787 .30902 L
.07287 .30902 L
.08414 .30902 L
.10458 .30902 L
.1234 .30902 L
.14407 .30902 L
.18449 .30902 L
.2234 .30902 L
.24321 .30902 L
.26476 .30902 L
.2837 .30902 L
.29448 .30902 L
.30461 .30902 L
.31492 .30902 L
.32438 .30902 L
.32931 .30902 L
.33449 .30902 L
.33719 .30902 L
.3397 .30902 L
.34111 .30902 L
.34245 .30902 L
.34319 .30902 L
.34399 .30902 L
.34471 .30902 L
.34539 .30902 L
.34662 .30902 L
.34775 .30902 L
.34896 .30902 L
.35028 .30902 L
.35143 .30902 L
Mistroke
.35265 .30902 L
.35485 .30902 L
.35767 .30902 L
.36032 .30902 L
.36526 .30902 L
.37054 .30902 L
.37538 .30902 L
.38631 .30902 L
.40517 .30902 L
.42585 .30902 L
.46632 .30902 L
.50528 .30902 L
.5467 .30902 L
.56743 .30902 L
.5866 .30902 L
.60522 .30902 L
.61462 .30902 L
.61967 .30902 L
.62498 .30902 L
.62981 .30902 L
.6351 .30902 L
.63742 .30902 L
.6399 .30902 L
.64222 .30902 L
.64436 .30902 L
.64565 .30902 L
.64707 .30902 L
.64849 .30902 L
.64927 .30902 L
.64999 .30902 L
.65068 .30902 L
.65133 .30902 L
.65256 .30902 L
.65387 .30902 L
.65461 .30902 L
.6553 .30902 L
.65648 .30902 L
.65759 .30902 L
.66012 .30902 L
.66258 .30902 L
.66523 .30902 L
.67018 .30902 L
.67479 .30902 L
.68525 .30902 L
.69544 .30902 L
.70634 .30902 L
.72766 .30902 L
.74781 .30902 L
.78624 .30902 L
.82713 .30902 L
Mistroke
.8665 .30902 L
.88627 .30902 L
.90435 .30902 L
.91364 .30902 L
.92378 .30902 L
.92933 .30902 L
.93448 .30902 L
.93941 .30902 L
.94196 .30902 L
.94466 .30902 L
.9466 .30902 L
.94872 .30902 L
.95066 .30902 L
.95246 .30902 L
.95356 .30902 L
.95459 .30902 L
.95552 .30902 L
.95654 .30902 L
.95763 .30902 L
.9588 .30902 L
.9598 .30902 L
.9609 .30902 L
.96186 .30902 L
.96288 .30902 L
.9647 .30902 L
.96879 .30902 L
.97232 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .40812 m
.06244 .41591 L
.10458 .42381 L
.14415 .43063 L
.18221 .4366 L
.22272 .4423 L
.26171 .4471 L
.30316 .45146 L
.34309 .4549 L
.3815 .4575 L
.40095 .45854 L
.42237 .45948 L
.44268 .46016 L
.45178 .46039 L
.46172 .46061 L
.4671 .4607 L
.4721 .46078 L
.47727 .46084 L
.48196 .46089 L
.48658 .46093 L
.4887 .46094 L
.49093 .46095 L
.49332 .46096 L
.49438 .46096 L
.49552 .46097 L
.49675 .46097 L
.49789 .46097 L
.49859 .46097 L
.49925 .46097 L
.50049 .46097 L
.50163 .46097 L
.50286 .46097 L
.50401 .46097 L
.50508 .46096 L
.50754 .46096 L
.51014 .46094 L
.51268 .46093 L
.51504 .46091 L
.5204 .46087 L
.5293 .46076 L
.53882 .4606 L
.54906 .46037 L
.56016 .46007 L
.58032 .45937 L
.60019 .45849 L
.62123 .45734 L
.65912 .45473 L
.69946 .45121 L
.73829 .4471 L
.77956 .442 L
Mistroke
.81932 .43638 L
.85757 .43035 L
.89827 .4233 L
.93745 .41593 L
.97619 .40812 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .32209 m
.04262 .32257 L
.06244 .32297 L
.08255 .32328 L
.09396 .32341 L
.09905 .32346 L
.10458 .3235 L
.11004 .32353 L
.11508 .32356 L
.11989 .32358 L
.12232 .32358 L
.12369 .32359 L
.125 .32359 L
.12615 .32359 L
.12741 .32359 L
.12855 .32359 L
.12962 .32359 L
.13088 .32359 L
.13202 .32359 L
.13334 .32359 L
.13459 .32359 L
.13568 .32359 L
.13684 .32359 L
.1389 .32359 L
.14113 .32358 L
.14357 .32357 L
.14881 .32355 L
.15378 .32353 L
.16308 .32346 L
.1731 .32336 L
.184 .32323 L
.20377 .32291 L
.22478 .32245 L
.26253 .32138 L
.30273 .31988 L
.34142 .31813 L
.38256 .31601 L
.42218 .31376 L
.46029 .31147 L
.50085 .30896 L
.5399 .30655 L
.5814 .30406 L
.62138 .30181 L
.65985 .29984 L
.70076 .29801 L
.74017 .29657 L
.77805 .29551 L
.7975 .2951 L
.81839 .29477 L
.82852 .29465 L
Mistroke
.83387 .2946 L
.83957 .29455 L
.84504 .29451 L
.85 .29449 L
.85239 .29447 L
.85498 .29446 L
.85744 .29446 L
.85967 .29445 L
.86205 .29445 L
.86336 .29444 L
.8646 .29444 L
.86575 .29444 L
.86681 .29444 L
.86797 .29444 L
.8692 .29444 L
.87044 .29444 L
.87113 .29444 L
.87177 .29444 L
.87294 .29444 L
.87417 .29444 L
.87679 .29445 L
.87965 .29446 L
.88242 .29446 L
.88493 .29447 L
.89057 .2945 L
.90073 .29457 L
.91073 .29467 L
.91995 .29479 L
.94076 .29512 L
.95764 .29547 L
.97619 .29594 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .3091 m
.03279 .3091 L
.04262 .3091 L
.04758 .3091 L
.0503 .3091 L
.05288 .3091 L
.05528 .3091 L
.05655 .30911 L
.05789 .30911 L
.05902 .30911 L
.06026 .30911 L
.06139 .30911 L
.06244 .30911 L
.0631 .30911 L
.06379 .30911 L
.06504 .30911 L
.06581 .30911 L
.06653 .30911 L
.06788 .30911 L
.06917 .30911 L
.07036 .3091 L
.07305 .3091 L
.07529 .3091 L
.07776 .3091 L
.08274 .3091 L
.08819 .3091 L
.09404 .3091 L
.10458 .3091 L
.11475 .3091 L
.12582 .3091 L
.14594 .30909 L
.18672 .30907 L
.22599 .30905 L
.26374 .30903 L
.30394 .309 L
.34263 .30898 L
.38377 .30896 L
.4043 .30895 L
.42339 .30894 L
.44182 .30894 L
.45206 .30893 L
.4615 .30893 L
.47175 .30893 L
.47714 .30893 L
.48285 .30893 L
.48524 .30893 L
.48781 .30893 L
.49003 .30893 L
.49244 .30893 L
.49391 .30893 L
Mistroke
.49527 .30893 L
.49658 .30893 L
.4973 .30893 L
.49796 .30893 L
.49921 .30893 L
.49991 .30893 L
.50056 .30893 L
.50175 .30893 L
.503 .30893 L
.50423 .30893 L
.50556 .30893 L
.50797 .30893 L
.51033 .30893 L
.5125 .30893 L
.51744 .30893 L
.52268 .30893 L
.5314 .30893 L
.54102 .30893 L
.56041 .30894 L
.58128 .30894 L
.62247 .30896 L
.66215 .30898 L
.70031 .30901 L
.74092 .30903 L
.78002 .30905 L
.82157 .30908 L
.84241 .30909 L
.8616 .30909 L
.88033 .3091 L
.88988 .3091 L
.90012 .3091 L
.90539 .3091 L
.91038 .3091 L
.91524 .3091 L
.91974 .3091 L
.92399 .3091 L
.92616 .3091 L
.92851 .3091 L
.92973 .3091 L
.93085 .30911 L
.93199 .30911 L
.93305 .30911 L
.93421 .30911 L
.93549 .30911 L
.93673 .30911 L
.93743 .30911 L
.93806 .30911 L
.9392 .30911 L
.94026 .30911 L
.94143 .30911 L
Mistroke
.94268 .30911 L
.94524 .3091 L
.94757 .3091 L
.95207 .3091 L
.95635 .3091 L
.96584 .3091 L
.97619 .3091 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03527 .30902 L
.03754 .30902 L
.03879 .30902 L
.03945 .30902 L
.04015 .30902 L
.04143 .30902 L
.04262 .30902 L
.04384 .30902 L
.04496 .30902 L
.04626 .30902 L
.04749 .30902 L
.04862 .30902 L
.04967 .30902 L
.05205 .30902 L
.05469 .30902 L
.05708 .30902 L
.06244 .30902 L
.06787 .30902 L
.07287 .30902 L
.08414 .30902 L
.10458 .30902 L
.1234 .30902 L
.14407 .30902 L
.18449 .30902 L
.2234 .30902 L
.24321 .30902 L
.26476 .30902 L
.2837 .30902 L
.29448 .30902 L
.30461 .30902 L
.31492 .30902 L
.32438 .30902 L
.32931 .30902 L
.33449 .30902 L
.33719 .30902 L
.3397 .30902 L
.34111 .30902 L
.34245 .30902 L
.34319 .30902 L
.34399 .30902 L
.34471 .30902 L
.34539 .30902 L
.34662 .30902 L
.34775 .30902 L
.34896 .30902 L
.35028 .30902 L
.35143 .30902 L
Mistroke
.35265 .30902 L
.35485 .30902 L
.35767 .30902 L
.36032 .30902 L
.36526 .30902 L
.37054 .30902 L
.37538 .30902 L
.38631 .30902 L
.40517 .30902 L
.42585 .30902 L
.46632 .30902 L
.50528 .30902 L
.5467 .30902 L
.56743 .30902 L
.5866 .30902 L
.60522 .30902 L
.61462 .30902 L
.61967 .30902 L
.62498 .30902 L
.62981 .30902 L
.6351 .30902 L
.63742 .30902 L
.6399 .30902 L
.64222 .30902 L
.64436 .30902 L
.64565 .30902 L
.64707 .30902 L
.64849 .30902 L
.64927 .30902 L
.64999 .30902 L
.65068 .30902 L
.65133 .30902 L
.65256 .30902 L
.65387 .30902 L
.65461 .30902 L
.6553 .30902 L
.65648 .30902 L
.65759 .30902 L
.66012 .30902 L
.66258 .30902 L
.66523 .30902 L
.67018 .30902 L
.67479 .30902 L
.68525 .30902 L
.69544 .30902 L
.70634 .30902 L
.72766 .30902 L
.74781 .30902 L
.78624 .30902 L
.82713 .30902 L
Mistroke
.8665 .30902 L
.88627 .30902 L
.90435 .30902 L
.91364 .30902 L
.92378 .30902 L
.92933 .30902 L
.93448 .30902 L
.93941 .30902 L
.94196 .30902 L
.94466 .30902 L
.9466 .30902 L
.94872 .30902 L
.95066 .30902 L
.95246 .30902 L
.95356 .30902 L
.95459 .30902 L
.95552 .30902 L
.95654 .30902 L
.95763 .30902 L
.9588 .30902 L
.9598 .30902 L
.9609 .30902 L
.96186 .30902 L
.96288 .30902 L
.9647 .30902 L
.96879 .30902 L
.97232 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .40523 m
.06244 .41279 L
.10458 .42047 L
.14415 .42709 L
.18221 .43288 L
.22272 .43841 L
.26171 .44308 L
.30316 .44731 L
.34309 .45065 L
.3815 .45317 L
.40095 .45418 L
.42237 .45509 L
.44268 .45575 L
.45178 .45598 L
.46172 .45618 L
.4671 .45628 L
.4721 .45635 L
.47727 .45641 L
.48196 .45646 L
.48658 .45649 L
.4887 .45651 L
.49093 .45652 L
.49332 .45653 L
.49438 .45653 L
.49552 .45653 L
.49675 .45653 L
.49789 .45654 L
.49859 .45654 L
.49925 .45654 L
.50049 .45654 L
.50163 .45654 L
.50286 .45654 L
.50401 .45653 L
.50508 .45653 L
.50754 .45652 L
.51014 .45651 L
.51268 .4565 L
.51504 .45648 L
.5204 .45644 L
.5293 .45633 L
.53882 .45617 L
.54906 .45596 L
.56016 .45567 L
.58032 .45499 L
.60019 .45413 L
.62123 .45301 L
.65912 .45048 L
.69946 .44706 L
.73829 .44308 L
.77956 .43812 L
Mistroke
.81932 .43266 L
.85757 .42681 L
.89827 .41997 L
.93745 .41281 L
.97619 .40523 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .32011 m
.04262 .32051 L
.06244 .32085 L
.08255 .32112 L
.09396 .32123 L
.09905 .32127 L
.10458 .3213 L
.11004 .32133 L
.11508 .32135 L
.11989 .32137 L
.12232 .32137 L
.12369 .32138 L
.125 .32138 L
.12615 .32138 L
.12741 .32138 L
.12855 .32138 L
.12962 .32138 L
.13088 .32138 L
.13202 .32138 L
.13334 .32138 L
.13459 .32138 L
.13568 .32138 L
.13684 .32138 L
.1389 .32138 L
.14113 .32137 L
.14357 .32136 L
.14881 .32135 L
.15378 .32133 L
.16308 .32127 L
.1731 .32119 L
.184 .32107 L
.20377 .3208 L
.22478 .32041 L
.26253 .3195 L
.30273 .31823 L
.34142 .31675 L
.38256 .31495 L
.42218 .31304 L
.46029 .3111 L
.50085 .30897 L
.5399 .30693 L
.5814 .30481 L
.62138 .3029 L
.65985 .30123 L
.70076 .29968 L
.74017 .29846 L
.77805 .29756 L
.7975 .29722 L
.81839 .29694 L
.82852 .29683 L
Mistroke
.83387 .29679 L
.83957 .29675 L
.84504 .29671 L
.85 .29669 L
.85239 .29668 L
.85498 .29667 L
.85744 .29667 L
.85967 .29666 L
.86205 .29666 L
.86336 .29666 L
.8646 .29665 L
.86575 .29665 L
.86681 .29665 L
.86797 .29665 L
.8692 .29665 L
.87044 .29665 L
.87113 .29665 L
.87177 .29665 L
.87294 .29665 L
.87417 .29666 L
.87679 .29666 L
.87965 .29667 L
.88242 .29667 L
.88493 .29668 L
.89057 .29671 L
.90073 .29677 L
.91073 .29685 L
.91995 .29695 L
.94076 .29723 L
.95764 .29753 L
.97619 .29793 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30907 m
.03279 .30907 L
.04262 .30907 L
.04758 .30907 L
.0503 .30907 L
.05288 .30907 L
.05528 .30907 L
.05655 .30907 L
.05789 .30907 L
.05902 .30907 L
.06026 .30907 L
.06139 .30907 L
.06244 .30907 L
.0631 .30907 L
.06379 .30907 L
.06504 .30907 L
.06581 .30907 L
.06653 .30907 L
.06788 .30907 L
.06917 .30907 L
.07036 .30907 L
.07305 .30907 L
.07529 .30907 L
.07776 .30907 L
.08274 .30907 L
.08819 .30907 L
.09404 .30907 L
.10458 .30907 L
.11475 .30907 L
.12582 .30907 L
.14594 .30906 L
.18672 .30905 L
.22599 .30904 L
.26374 .30902 L
.30394 .30901 L
.34263 .30899 L
.38377 .30898 L
.4043 .30897 L
.42339 .30897 L
.44182 .30897 L
.45206 .30897 L
.4615 .30896 L
.47175 .30896 L
.47714 .30896 L
.48285 .30896 L
.48524 .30896 L
.48781 .30896 L
.49003 .30896 L
.49244 .30896 L
.49391 .30896 L
Mistroke
.49527 .30896 L
.49658 .30896 L
.4973 .30896 L
.49796 .30896 L
.49921 .30896 L
.49991 .30896 L
.50056 .30896 L
.50175 .30896 L
.503 .30896 L
.50423 .30896 L
.50556 .30896 L
.50797 .30896 L
.51033 .30896 L
.5125 .30896 L
.51744 .30896 L
.52268 .30896 L
.5314 .30896 L
.54102 .30896 L
.56041 .30897 L
.58128 .30897 L
.62247 .30898 L
.66215 .309 L
.70031 .30901 L
.74092 .30903 L
.78002 .30904 L
.82157 .30905 L
.84241 .30906 L
.8616 .30906 L
.88033 .30907 L
.88988 .30907 L
.90012 .30907 L
.90539 .30907 L
.91038 .30907 L
.91524 .30907 L
.91974 .30907 L
.92399 .30907 L
.92616 .30907 L
.92851 .30907 L
.92973 .30907 L
.93085 .30907 L
.93199 .30907 L
.93305 .30907 L
.93421 .30907 L
.93549 .30907 L
.93673 .30907 L
.93743 .30907 L
.93806 .30907 L
.9392 .30907 L
.94026 .30907 L
.94143 .30907 L
Mistroke
.94268 .30907 L
.94524 .30907 L
.94757 .30907 L
.95207 .30907 L
.95635 .30907 L
.96584 .30907 L
.97619 .30907 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03527 .30902 L
.03754 .30902 L
.03879 .30902 L
.03945 .30902 L
.04015 .30902 L
.04143 .30902 L
.04262 .30902 L
.04384 .30902 L
.04496 .30902 L
.04626 .30902 L
.04749 .30902 L
.04862 .30902 L
.04967 .30902 L
.05205 .30902 L
.05469 .30902 L
.05708 .30902 L
.06244 .30902 L
.06787 .30902 L
.07287 .30902 L
.08414 .30902 L
.10458 .30902 L
.1234 .30902 L
.14407 .30902 L
.18449 .30902 L
.2234 .30902 L
.24321 .30902 L
.26476 .30902 L
.2837 .30902 L
.29448 .30902 L
.30461 .30902 L
.31492 .30902 L
.32438 .30902 L
.32931 .30902 L
.33449 .30902 L
.33719 .30902 L
.3397 .30902 L
.34111 .30902 L
.34245 .30902 L
.34319 .30902 L
.34399 .30902 L
.34471 .30902 L
.34539 .30902 L
.34662 .30902 L
.34775 .30902 L
.34896 .30902 L
.35028 .30902 L
.35143 .30902 L
Mistroke
.35265 .30902 L
.35485 .30902 L
.35767 .30902 L
.36032 .30902 L
.36526 .30902 L
.37054 .30902 L
.37538 .30902 L
.38631 .30902 L
.40517 .30902 L
.42585 .30902 L
.46632 .30902 L
.50528 .30902 L
.5467 .30902 L
.56743 .30902 L
.5866 .30902 L
.60522 .30902 L
.61462 .30902 L
.61967 .30902 L
.62498 .30902 L
.62981 .30902 L
.6351 .30902 L
.63742 .30902 L
.6399 .30902 L
.64222 .30902 L
.64436 .30902 L
.64565 .30902 L
.64707 .30902 L
.64849 .30902 L
.64927 .30902 L
.64999 .30902 L
.65068 .30902 L
.65133 .30902 L
.65256 .30902 L
.65387 .30902 L
.65461 .30902 L
.6553 .30902 L
.65648 .30902 L
.65759 .30902 L
.66012 .30902 L
.66258 .30902 L
.66523 .30902 L
.67018 .30902 L
.67479 .30902 L
.68525 .30902 L
.69544 .30902 L
.70634 .30902 L
.72766 .30902 L
.74781 .30902 L
.78624 .30902 L
.82713 .30902 L
Mistroke
.8665 .30902 L
.88627 .30902 L
.90435 .30902 L
.91364 .30902 L
.92378 .30902 L
.92933 .30902 L
.93448 .30902 L
.93941 .30902 L
.94196 .30902 L
.94466 .30902 L
.9466 .30902 L
.94872 .30902 L
.95066 .30902 L
.95246 .30902 L
.95356 .30902 L
.95459 .30902 L
.95552 .30902 L
.95654 .30902 L
.95763 .30902 L
.9588 .30902 L
.9598 .30902 L
.9609 .30902 L
.96186 .30902 L
.96288 .30902 L
.9647 .30902 L
.96879 .30902 L
.97232 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .40242 m
.06244 .40977 L
.10458 .41721 L
.14415 .42364 L
.18221 .42927 L
.22272 .43463 L
.26171 .43917 L
.30316 .44327 L
.34309 .44652 L
.3815 .44896 L
.40095 .44995 L
.42237 .45083 L
.44268 .45147 L
.45178 .45169 L
.46172 .45189 L
.4671 .45198 L
.4721 .45205 L
.47727 .45211 L
.48196 .45216 L
.48658 .45219 L
.4887 .4522 L
.49093 .45221 L
.49332 .45222 L
.49438 .45223 L
.49552 .45223 L
.49675 .45223 L
.49789 .45223 L
.49859 .45223 L
.49925 .45223 L
.50049 .45223 L
.50163 .45223 L
.50286 .45223 L
.50401 .45223 L
.50508 .45223 L
.50754 .45222 L
.51014 .45221 L
.51268 .4522 L
.51504 .45218 L
.5204 .45214 L
.5293 .45203 L
.53882 .45188 L
.54906 .45167 L
.56016 .45139 L
.58032 .45073 L
.60019 .44989 L
.62123 .44881 L
.65912 .44636 L
.69946 .44303 L
.73829 .43917 L
.77956 .43435 L
Mistroke
.81932 .42905 L
.85757 .42337 L
.89827 .41673 L
.93745 .40979 L
.97619 .40242 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31842 m
.04262 .31877 L
.06244 .31906 L
.08255 .31928 L
.09396 .31937 L
.09905 .31941 L
.10458 .31944 L
.11004 .31946 L
.11508 .31948 L
.11989 .31949 L
.12232 .3195 L
.12369 .3195 L
.125 .3195 L
.12615 .3195 L
.12741 .3195 L
.12855 .3195 L
.12962 .3195 L
.13088 .3195 L
.13202 .3195 L
.13334 .3195 L
.13459 .3195 L
.13568 .3195 L
.13684 .3195 L
.1389 .3195 L
.14113 .3195 L
.14357 .31949 L
.14881 .31948 L
.15378 .31946 L
.16308 .31941 L
.1731 .31934 L
.184 .31924 L
.20377 .31901 L
.22478 .31868 L
.26253 .31791 L
.30273 .31683 L
.34142 .31558 L
.38256 .31405 L
.42218 .31243 L
.46029 .31078 L
.50085 .30898 L
.5399 .30724 L
.5814 .30545 L
.62138 .30383 L
.65985 .30241 L
.70076 .3011 L
.74017 .30006 L
.77805 .2993 L
.7975 .29901 L
.81839 .29877 L
.82852 .29868 L
Mistroke
.83387 .29864 L
.83957 .29861 L
.84504 .29858 L
.85 .29856 L
.85239 .29855 L
.85498 .29855 L
.85744 .29854 L
.85967 .29854 L
.86205 .29853 L
.86336 .29853 L
.8646 .29853 L
.86575 .29853 L
.86681 .29853 L
.86797 .29853 L
.8692 .29853 L
.87044 .29853 L
.87113 .29853 L
.87177 .29853 L
.87294 .29853 L
.87417 .29853 L
.87679 .29854 L
.87965 .29854 L
.88242 .29855 L
.88493 .29855 L
.89057 .29857 L
.90073 .29863 L
.91073 .2987 L
.91995 .29878 L
.94076 .29902 L
.95764 .29927 L
.97619 .29961 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30905 m
.03279 .30905 L
.04262 .30905 L
.04758 .30905 L
.0503 .30905 L
.05288 .30905 L
.05528 .30905 L
.05655 .30905 L
.05789 .30905 L
.05902 .30905 L
.06026 .30905 L
.06139 .30905 L
.06244 .30905 L
.0631 .30905 L
.06379 .30905 L
.06504 .30905 L
.06581 .30905 L
.06653 .30905 L
.06788 .30905 L
.06917 .30905 L
.07036 .30905 L
.07305 .30905 L
.07529 .30905 L
.07776 .30905 L
.08274 .30905 L
.08819 .30905 L
.09404 .30905 L
.10458 .30905 L
.11475 .30905 L
.12582 .30905 L
.14594 .30905 L
.18672 .30904 L
.22599 .30903 L
.26374 .30902 L
.30394 .30901 L
.34263 .309 L
.38377 .30899 L
.4043 .30899 L
.42339 .30899 L
.44182 .30899 L
.45206 .30898 L
.4615 .30898 L
.47175 .30898 L
.47714 .30898 L
.48285 .30898 L
.48524 .30898 L
.48781 .30898 L
.49003 .30898 L
.49244 .30898 L
.49391 .30898 L
Mistroke
.49527 .30898 L
.49658 .30898 L
.4973 .30898 L
.49796 .30898 L
.49921 .30898 L
.49991 .30898 L
.50056 .30898 L
.50175 .30898 L
.503 .30898 L
.50423 .30898 L
.50556 .30898 L
.50797 .30898 L
.51033 .30898 L
.5125 .30898 L
.51744 .30898 L
.52268 .30898 L
.5314 .30898 L
.54102 .30898 L
.56041 .30899 L
.58128 .30899 L
.62247 .309 L
.66215 .309 L
.70031 .30901 L
.74092 .30902 L
.78002 .30903 L
.82157 .30904 L
.84241 .30904 L
.8616 .30905 L
.88033 .30905 L
.88988 .30905 L
.90012 .30905 L
.90539 .30905 L
.91038 .30905 L
.91524 .30905 L
.91974 .30905 L
.92399 .30905 L
.92616 .30905 L
.92851 .30905 L
.92973 .30905 L
.93085 .30905 L
.93199 .30905 L
.93305 .30905 L
.93421 .30905 L
.93549 .30905 L
.93673 .30905 L
.93743 .30905 L
.93806 .30905 L
.9392 .30905 L
.94026 .30905 L
.94143 .30905 L
Mistroke
.94268 .30905 L
.94524 .30905 L
.94757 .30905 L
.95207 .30905 L
.95635 .30905 L
.96584 .30905 L
.97619 .30905 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03527 .30902 L
.03754 .30902 L
.03879 .30902 L
.03945 .30902 L
.04015 .30902 L
.04143 .30902 L
.04262 .30902 L
.04384 .30902 L
.04496 .30902 L
.04626 .30902 L
.04749 .30902 L
.04862 .30902 L
.04967 .30902 L
.05205 .30902 L
.05469 .30902 L
.05708 .30902 L
.06244 .30902 L
.06787 .30902 L
.07287 .30902 L
.08414 .30902 L
.10458 .30902 L
.1234 .30902 L
.14407 .30902 L
.18449 .30902 L
.2234 .30902 L
.24321 .30902 L
.26476 .30902 L
.2837 .30902 L
.29448 .30902 L
.30461 .30902 L
.31492 .30902 L
.32438 .30902 L
.32931 .30902 L
.33449 .30902 L
.33719 .30902 L
.3397 .30902 L
.34111 .30902 L
.34245 .30902 L
.34319 .30902 L
.34399 .30902 L
.34471 .30902 L
.34539 .30902 L
.34662 .30902 L
.34775 .30902 L
.34896 .30902 L
.35028 .30902 L
.35143 .30902 L
Mistroke
.35265 .30902 L
.35485 .30902 L
.35767 .30902 L
.36032 .30902 L
.36526 .30902 L
.37054 .30902 L
.37538 .30902 L
.38631 .30902 L
.40517 .30902 L
.42585 .30902 L
.46632 .30902 L
.50528 .30902 L
.5467 .30902 L
.56743 .30902 L
.5866 .30902 L
.60522 .30902 L
.61462 .30902 L
.61967 .30902 L
.62498 .30902 L
.62981 .30902 L
.6351 .30902 L
.63742 .30902 L
.6399 .30902 L
.64222 .30902 L
.64436 .30902 L
.64565 .30902 L
.64707 .30902 L
.64849 .30902 L
.64927 .30902 L
.64999 .30902 L
.65068 .30902 L
.65133 .30902 L
.65256 .30902 L
.65387 .30902 L
.65461 .30902 L
.6553 .30902 L
.65648 .30902 L
.65759 .30902 L
.66012 .30902 L
.66258 .30902 L
.66523 .30902 L
.67018 .30902 L
.67479 .30902 L
.68525 .30902 L
.69544 .30902 L
.70634 .30902 L
.72766 .30902 L
.74781 .30902 L
.78624 .30902 L
.82713 .30902 L
Mistroke
.8665 .30902 L
.88627 .30902 L
.90435 .30902 L
.91364 .30902 L
.92378 .30902 L
.92933 .30902 L
.93448 .30902 L
.93941 .30902 L
.94196 .30902 L
.94466 .30902 L
.9466 .30902 L
.94872 .30902 L
.95066 .30902 L
.95246 .30902 L
.95356 .30902 L
.95459 .30902 L
.95552 .30902 L
.95654 .30902 L
.95763 .30902 L
.9588 .30902 L
.9598 .30902 L
.9609 .30902 L
.96186 .30902 L
.96288 .30902 L
.9647 .30902 L
.96879 .30902 L
.97232 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .3997 m
.06244 .40683 L
.10458 .41406 L
.14415 .4203 L
.18221 .42576 L
.22272 .43097 L
.26171 .43537 L
.30316 .43936 L
.34309 .44251 L
.3815 .44488 L
.40095 .44584 L
.42237 .44669 L
.44268 .44731 L
.45178 .44753 L
.46172 .44772 L
.4671 .44781 L
.4721 .44788 L
.47727 .44794 L
.48196 .44798 L
.48658 .44801 L
.4887 .44803 L
.49093 .44804 L
.49332 .44805 L
.49438 .44805 L
.49552 .44805 L
.49675 .44805 L
.49789 .44805 L
.49859 .44806 L
.49925 .44806 L
.50049 .44806 L
.50163 .44805 L
.50286 .44805 L
.50401 .44805 L
.50508 .44805 L
.50754 .44804 L
.51014 .44803 L
.51268 .44802 L
.51504 .448 L
.5204 .44796 L
.5293 .44786 L
.53882 .44771 L
.54906 .44751 L
.56016 .44723 L
.58032 .44659 L
.60019 .44578 L
.62123 .44473 L
.65912 .44235 L
.69946 .43912 L
.73829 .43537 L
.77956 .43069 L
Mistroke
.81932 .42555 L
.85757 .42004 L
.89827 .41359 L
.93745 .40685 L
.97619 .3997 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .317 m
.04262 .31729 L
.06244 .31753 L
.08255 .31772 L
.09396 .3178 L
.09905 .31783 L
.10458 .31786 L
.11004 .31788 L
.11508 .31789 L
.11989 .3179 L
.12232 .31791 L
.12369 .31791 L
.125 .31791 L
.12615 .31791 L
.12741 .31791 L
.12855 .31791 L
.12962 .31791 L
.13088 .31791 L
.13202 .31791 L
.13334 .31791 L
.13459 .31791 L
.13568 .31791 L
.13684 .31791 L
.1389 .31791 L
.14113 .31791 L
.14357 .3179 L
.14881 .31789 L
.15378 .31787 L
.16308 .31783 L
.1731 .31777 L
.184 .31769 L
.20377 .31749 L
.22478 .31722 L
.26253 .31656 L
.30273 .31564 L
.34142 .31458 L
.38256 .31328 L
.42218 .31191 L
.46029 .31051 L
.50085 .30898 L
.5399 .30751 L
.5814 .30599 L
.62138 .30462 L
.65985 .30342 L
.70076 .3023 L
.74017 .30142 L
.77805 .30078 L
.7975 .30053 L
.81839 .30032 L
.82852 .30025 L
Mistroke
.83387 .30022 L
.83957 .30019 L
.84504 .30017 L
.85 .30015 L
.85239 .30014 L
.85498 .30014 L
.85744 .30013 L
.85967 .30013 L
.86205 .30012 L
.86336 .30012 L
.8646 .30012 L
.86575 .30012 L
.86681 .30012 L
.86797 .30012 L
.8692 .30012 L
.87044 .30012 L
.87113 .30012 L
.87177 .30012 L
.87294 .30012 L
.87417 .30012 L
.87679 .30013 L
.87965 .30013 L
.88242 .30014 L
.88493 .30014 L
.89057 .30016 L
.90073 .3002 L
.91073 .30026 L
.91995 .30033 L
.94076 .30054 L
.95764 .30075 L
.97619 .30104 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30904 m
.03279 .30904 L
.04262 .30904 L
.04758 .30904 L
.0503 .30904 L
.05288 .30904 L
.05528 .30904 L
.05655 .30904 L
.05789 .30904 L
.05902 .30904 L
.06026 .30904 L
.06139 .30904 L
.06244 .30904 L
.0631 .30904 L
.06379 .30904 L
.06504 .30904 L
.06581 .30904 L
.06653 .30904 L
.06788 .30904 L
.06917 .30904 L
.07036 .30904 L
.07305 .30904 L
.07529 .30904 L
.07776 .30904 L
.08274 .30904 L
.08819 .30904 L
.09404 .30904 L
.10458 .30904 L
.11475 .30904 L
.12582 .30904 L
.14594 .30903 L
.18672 .30903 L
.22599 .30903 L
.26374 .30902 L
.30394 .30901 L
.34263 .30901 L
.38377 .309 L
.4043 .309 L
.42339 .309 L
.44182 .309 L
.45206 .309 L
.4615 .309 L
.47175 .309 L
.47714 .309 L
.48285 .309 L
.48524 .309 L
.48781 .309 L
.49003 .309 L
.49244 .309 L
.49391 .309 L
Mistroke
.49527 .309 L
.49658 .309 L
.4973 .309 L
.49796 .309 L
.49921 .309 L
.49991 .309 L
.50056 .309 L
.50175 .309 L
.503 .309 L
.50423 .309 L
.50556 .309 L
.50797 .309 L
.51033 .309 L
.5125 .309 L
.51744 .309 L
.52268 .309 L
.5314 .309 L
.54102 .309 L
.56041 .309 L
.58128 .309 L
.62247 .309 L
.66215 .30901 L
.70031 .30901 L
.74092 .30902 L
.78002 .30903 L
.82157 .30903 L
.84241 .30903 L
.8616 .30904 L
.88033 .30904 L
.88988 .30904 L
.90012 .30904 L
.90539 .30904 L
.91038 .30904 L
.91524 .30904 L
.91974 .30904 L
.92399 .30904 L
.92616 .30904 L
.92851 .30904 L
.92973 .30904 L
.93085 .30904 L
.93199 .30904 L
.93305 .30904 L
.93421 .30904 L
.93549 .30904 L
.93673 .30904 L
.93743 .30904 L
.93806 .30904 L
.9392 .30904 L
.94026 .30904 L
.94143 .30904 L
Mistroke
.94268 .30904 L
.94524 .30904 L
.94757 .30904 L
.95207 .30904 L
.95635 .30904 L
.96584 .30904 L
.97619 .30904 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03527 .30902 L
.03754 .30902 L
.03879 .30902 L
.03945 .30902 L
.04015 .30902 L
.04143 .30902 L
.04262 .30902 L
.04384 .30902 L
.04496 .30902 L
.04626 .30902 L
.04749 .30902 L
.04862 .30902 L
.04967 .30902 L
.05205 .30902 L
.05469 .30902 L
.05708 .30902 L
.06244 .30902 L
.06787 .30902 L
.07287 .30902 L
.08414 .30902 L
.10458 .30902 L
.1234 .30902 L
.14407 .30902 L
.18449 .30902 L
.2234 .30902 L
.24321 .30902 L
.26476 .30902 L
.2837 .30902 L
.29448 .30902 L
.30461 .30902 L
.31492 .30902 L
.32438 .30902 L
.32931 .30902 L
.33449 .30902 L
.33719 .30902 L
.3397 .30902 L
.34111 .30902 L
.34245 .30902 L
.34319 .30902 L
.34399 .30902 L
.34471 .30902 L
.34539 .30902 L
.34662 .30902 L
.34775 .30902 L
.34896 .30902 L
.35028 .30902 L
.35143 .30902 L
Mistroke
.35265 .30902 L
.35485 .30902 L
.35767 .30902 L
.36032 .30902 L
.36526 .30902 L
.37054 .30902 L
.37538 .30902 L
.38631 .30902 L
.40517 .30902 L
.42585 .30902 L
.46632 .30902 L
.50528 .30902 L
.5467 .30902 L
.56743 .30902 L
.5866 .30902 L
.60522 .30902 L
.61462 .30902 L
.61967 .30902 L
.62498 .30902 L
.62981 .30902 L
.6351 .30902 L
.63742 .30902 L
.6399 .30902 L
.64222 .30902 L
.64436 .30902 L
.64565 .30902 L
.64707 .30902 L
.64849 .30902 L
.64927 .30902 L
.64999 .30902 L
.65068 .30902 L
.65133 .30902 L
.65256 .30902 L
.65387 .30902 L
.65461 .30902 L
.6553 .30902 L
.65648 .30902 L
.65759 .30902 L
.66012 .30902 L
.66258 .30902 L
.66523 .30902 L
.67018 .30902 L
.67479 .30902 L
.68525 .30902 L
.69544 .30902 L
.70634 .30902 L
.72766 .30902 L
.74781 .30902 L
.78624 .30902 L
.82713 .30902 L
Mistroke
.8665 .30902 L
.88627 .30902 L
.90435 .30902 L
.91364 .30902 L
.92378 .30902 L
.92933 .30902 L
.93448 .30902 L
.93941 .30902 L
.94196 .30902 L
.94466 .30902 L
.9466 .30902 L
.94872 .30902 L
.95066 .30902 L
.95246 .30902 L
.95356 .30902 L
.95459 .30902 L
.95552 .30902 L
.95654 .30902 L
.95763 .30902 L
.9588 .30902 L
.9598 .30902 L
.9609 .30902 L
.96186 .30902 L
.96288 .30902 L
.9647 .30902 L
.96879 .30902 L
.97232 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .39705 m
.06244 .40397 L
.10458 .41099 L
.14415 .41705 L
.18221 .42236 L
.22272 .42741 L
.26171 .43168 L
.30316 .43555 L
.34309 .43861 L
.3815 .44092 L
.40095 .44184 L
.42237 .44267 L
.44268 .44328 L
.45178 .44349 L
.46172 .44368 L
.4671 .44376 L
.4721 .44383 L
.47727 .44389 L
.48196 .44393 L
.48658 .44396 L
.4887 .44397 L
.49093 .44398 L
.49332 .44399 L
.49438 .44399 L
.49552 .44399 L
.49675 .444 L
.49789 .444 L
.49859 .444 L
.49925 .444 L
.50049 .444 L
.50163 .444 L
.50286 .444 L
.50401 .444 L
.50508 .44399 L
.50754 .44399 L
.51014 .44398 L
.51268 .44396 L
.51504 .44395 L
.5204 .44391 L
.5293 .44381 L
.53882 .44367 L
.54906 .44347 L
.56016 .4432 L
.58032 .44258 L
.60019 .44179 L
.62123 .44077 L
.65912 .43846 L
.69946 .43533 L
.73829 .43168 L
.77956 .42714 L
Mistroke
.81932 .42215 L
.85757 .4168 L
.89827 .41054 L
.93745 .40399 L
.97619 .39705 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31578 m
.04262 .31603 L
.06244 .31624 L
.08255 .3164 L
.09396 .31647 L
.09905 .31649 L
.10458 .31651 L
.11004 .31653 L
.11508 .31654 L
.11989 .31655 L
.12232 .31656 L
.12369 .31656 L
.125 .31656 L
.12615 .31656 L
.12741 .31656 L
.12855 .31656 L
.12962 .31656 L
.13088 .31656 L
.13202 .31656 L
.13334 .31656 L
.13459 .31656 L
.13568 .31656 L
.13684 .31656 L
.1389 .31656 L
.14113 .31656 L
.14357 .31655 L
.14881 .31654 L
.15378 .31653 L
.16308 .31649 L
.1731 .31644 L
.184 .31637 L
.20377 .31621 L
.22478 .31597 L
.26253 .31541 L
.30273 .31464 L
.34142 .31374 L
.38256 .31264 L
.42218 .31147 L
.46029 .31029 L
.50085 .30899 L
.5399 .30774 L
.5814 .30645 L
.62138 .30529 L
.65985 .30427 L
.70076 .30332 L
.74017 .30257 L
.77805 .30203 L
.7975 .30182 L
.81839 .30164 L
.82852 .30158 L
Mistroke
.83387 .30155 L
.83957 .30153 L
.84504 .30151 L
.85 .3015 L
.85239 .30149 L
.85498 .30148 L
.85744 .30148 L
.85967 .30148 L
.86205 .30147 L
.86336 .30147 L
.8646 .30147 L
.86575 .30147 L
.86681 .30147 L
.86797 .30147 L
.8692 .30147 L
.87044 .30147 L
.87113 .30147 L
.87177 .30147 L
.87294 .30147 L
.87417 .30147 L
.87679 .30148 L
.87965 .30148 L
.88242 .30148 L
.88493 .30149 L
.89057 .3015 L
.90073 .30154 L
.91073 .30159 L
.91995 .30165 L
.94076 .30182 L
.95764 .30201 L
.97619 .30225 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30903 m
.03279 .30903 L
.04262 .30903 L
.04758 .30903 L
.0503 .30903 L
.05288 .30903 L
.05528 .30903 L
.05655 .30903 L
.05789 .30903 L
.05902 .30903 L
.06026 .30903 L
.06139 .30903 L
.06244 .30903 L
.0631 .30903 L
.06379 .30903 L
.06504 .30903 L
.06581 .30903 L
.06653 .30903 L
.06788 .30903 L
.06917 .30903 L
.07036 .30903 L
.07305 .30903 L
.07529 .30903 L
.07776 .30903 L
.08274 .30903 L
.08819 .30903 L
.09404 .30903 L
.10458 .30903 L
.11475 .30903 L
.12582 .30903 L
.14594 .30903 L
.18672 .30903 L
.22599 .30902 L
.26374 .30902 L
.30394 .30901 L
.34263 .30901 L
.38377 .30901 L
.4043 .30901 L
.42339 .30901 L
.44182 .309 L
.45206 .309 L
.4615 .309 L
.47175 .309 L
.47714 .309 L
.48285 .309 L
.48524 .309 L
.48781 .309 L
.49003 .309 L
.49244 .309 L
.49391 .309 L
Mistroke
.49527 .309 L
.49658 .309 L
.4973 .309 L
.49796 .309 L
.49921 .309 L
.49991 .309 L
.50056 .309 L
.50175 .309 L
.503 .309 L
.50423 .309 L
.50556 .309 L
.50797 .309 L
.51033 .309 L
.5125 .309 L
.51744 .309 L
.52268 .309 L
.5314 .309 L
.54102 .309 L
.56041 .309 L
.58128 .30901 L
.62247 .30901 L
.66215 .30901 L
.70031 .30902 L
.74092 .30902 L
.78002 .30902 L
.82157 .30903 L
.84241 .30903 L
.8616 .30903 L
.88033 .30903 L
.88988 .30903 L
.90012 .30903 L
.90539 .30903 L
.91038 .30903 L
.91524 .30903 L
.91974 .30903 L
.92399 .30903 L
.92616 .30903 L
.92851 .30903 L
.92973 .30903 L
.93085 .30903 L
.93199 .30903 L
.93305 .30903 L
.93421 .30903 L
.93549 .30903 L
.93673 .30903 L
.93743 .30903 L
.93806 .30903 L
.9392 .30903 L
.94026 .30903 L
.94143 .30903 L
Mistroke
.94268 .30903 L
.94524 .30903 L
.94757 .30903 L
.95207 .30903 L
.95635 .30903 L
.96584 .30903 L
.97619 .30903 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03527 .30902 L
.03754 .30902 L
.03879 .30902 L
.03945 .30902 L
.04015 .30902 L
.04143 .30902 L
.04262 .30902 L
.04384 .30902 L
.04496 .30902 L
.04626 .30902 L
.04749 .30902 L
.04862 .30902 L
.04967 .30902 L
.05205 .30902 L
.05469 .30902 L
.05708 .30902 L
.06244 .30902 L
.06787 .30902 L
.07287 .30902 L
.08414 .30902 L
.10458 .30902 L
.1234 .30902 L
.14407 .30902 L
.18449 .30902 L
.2234 .30902 L
.24321 .30902 L
.26476 .30902 L
.2837 .30902 L
.29448 .30902 L
.30461 .30902 L
.31492 .30902 L
.32438 .30902 L
.32931 .30902 L
.33449 .30902 L
.33719 .30902 L
.3397 .30902 L
.34111 .30902 L
.34245 .30902 L
.34319 .30902 L
.34399 .30902 L
.34471 .30902 L
.34539 .30902 L
.34662 .30902 L
.34775 .30902 L
.34896 .30902 L
.35028 .30902 L
.35143 .30902 L
Mistroke
.35265 .30902 L
.35485 .30902 L
.35767 .30902 L
.36032 .30902 L
.36526 .30902 L
.37054 .30902 L
.37538 .30902 L
.38631 .30902 L
.40517 .30902 L
.42585 .30902 L
.46632 .30902 L
.50528 .30902 L
.5467 .30902 L
.56743 .30902 L
.5866 .30902 L
.60522 .30902 L
.61462 .30902 L
.61967 .30902 L
.62498 .30902 L
.62981 .30902 L
.6351 .30902 L
.63742 .30902 L
.6399 .30902 L
.64222 .30902 L
.64436 .30902 L
.64565 .30902 L
.64707 .30902 L
.64849 .30902 L
.64927 .30902 L
.64999 .30902 L
.65068 .30902 L
.65133 .30902 L
.65256 .30902 L
.65387 .30902 L
.65461 .30902 L
.6553 .30902 L
.65648 .30902 L
.65759 .30902 L
.66012 .30902 L
.66258 .30902 L
.66523 .30902 L
.67018 .30902 L
.67479 .30902 L
.68525 .30902 L
.69544 .30902 L
.70634 .30902 L
.72766 .30902 L
.74781 .30902 L
.78624 .30902 L
.82713 .30902 L
Mistroke
.8665 .30902 L
.88627 .30902 L
.90435 .30902 L
.91364 .30902 L
.92378 .30902 L
.92933 .30902 L
.93448 .30902 L
.93941 .30902 L
.94196 .30902 L
.94466 .30902 L
.9466 .30902 L
.94872 .30902 L
.95066 .30902 L
.95246 .30902 L
.95356 .30902 L
.95459 .30902 L
.95552 .30902 L
.95654 .30902 L
.95763 .30902 L
.9588 .30902 L
.9598 .30902 L
.9609 .30902 L
.96186 .30902 L
.96288 .30902 L
.9647 .30902 L
.96879 .30902 L
.97232 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .39448 m
.06244 .4012 L
.10458 .40802 L
.14415 .4139 L
.18221 .41905 L
.22272 .42396 L
.26171 .4281 L
.30316 .43186 L
.34309 .43483 L
.3815 .43707 L
.40095 .43797 L
.42237 .43877 L
.44268 .43936 L
.45178 .43956 L
.46172 .43975 L
.4671 .43983 L
.4721 .4399 L
.47727 .43995 L
.48196 .43999 L
.48658 .44002 L
.4887 .44003 L
.49093 .44004 L
.49332 .44005 L
.49438 .44005 L
.49552 .44006 L
.49675 .44006 L
.49789 .44006 L
.49859 .44006 L
.49925 .44006 L
.50049 .44006 L
.50163 .44006 L
.50286 .44006 L
.50401 .44006 L
.50508 .44006 L
.50754 .44005 L
.51014 .44004 L
.51268 .44003 L
.51504 .44001 L
.5204 .43997 L
.5293 .43988 L
.53882 .43974 L
.54906 .43955 L
.56016 .43929 L
.58032 .43868 L
.60019 .43792 L
.62123 .43693 L
.65912 .43468 L
.69946 .43164 L
.73829 .4281 L
.77956 .4237 L
Mistroke
.81932 .41885 L
.85757 .41365 L
.89827 .40758 L
.93745 .40122 L
.97619 .39448 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.154508 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31476 m
.04262 .31497 L
.06244 .31514 L
.08255 .31528 L
.09396 .31534 L
.09905 .31536 L
.10458 .31538 L
.11004 .31539 L
.11508 .3154 L
.11989 .31541 L
.12232 .31541 L
.12369 .31541 L
.125 .31541 L
.12615 .31542 L
.12741 .31542 L
.12855 .31542 L
.12962 .31542 L
.13088 .31542 L
.13202 .31542 L
.13334 .31542 L
.13459 .31542 L
.13568 .31542 L
.13684 .31542 L
.1389 .31541 L
.14113 .31541 L
.14357 .31541 L
.14881 .3154 L
.15378 .31539 L
.16308 .31536 L
.1731 .31532 L
.184 .31526 L
.20377 .31511 L
.22478 .31492 L
.26253 .31444 L
.30273 .31378 L
.34142 .31302 L
.38256 .31209 L
.42218 .3111 L
.46029 .31009 L
.50085 .30899 L
.5399 .30793 L
.5814 .30684 L
.62138 .30585 L
.65985 .30499 L
.70076 .30419 L
.74017 .30355 L
.77805 .30309 L
.7975 .30291 L
.81839 .30276 L
.82852 .30271 L
Mistroke
.83387 .30269 L
.83957 .30267 L
.84504 .30265 L
.85 .30264 L
.85239 .30263 L
.85498 .30263 L
.85744 .30262 L
.85967 .30262 L
.86205 .30262 L
.86336 .30262 L
.8646 .30262 L
.86575 .30262 L
.86681 .30262 L
.86797 .30262 L
.8692 .30262 L
.87044 .30262 L
.87113 .30262 L
.87177 .30262 L
.87294 .30262 L
.87417 .30262 L
.87679 .30262 L
.87965 .30262 L
.88242 .30263 L
.88493 .30263 L
.89057 .30264 L
.90073 .30268 L
.91073 .30272 L
.91995 .30277 L
.94076 .30292 L
.95764 .30307 L
.97619 .30328 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{522.062, 322.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 651.562}, {402.312, 0}} -> {0, 0, 0, 0}, {{15.75, \
311}, {392.688, 210.25}} -> {0, -2, 0, 0}, {{340.5, 635.75}, {392.688, \
210.25}} -> {-1, -2, 0, 0}, {{15.75, 311}, {192, 9.5625}} -> {0, -7, 0, 0}, \
{{340.5, 635.75}, {192, 9.5625}} -> {-1, -7, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell["\<\
Because of the symmetry of the boundary conditions, the modes are \
either symmetric or antisymmetric about the center of the slab. These modes \
are a cross between insulating and fixed-temperature conditions: there is a \
small heat flux out of the slab faces that depends linearly on the \
temperature of the faces.  In the long-time limit, the temperature throughout \
the slab is zero in the absence of a heat  source.\
\>", "Text"],

Cell["\<\
\tWe can still form a general superposition of these different \
solutions in order to satisfy the initial conditions:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`T(x, 
          t) = \[Sum]\+n\( 
                A\_\(\(n\)\(\ \)\)\) \(\[ExponentialE]\^\(\(\[Lambda]\_n\) \
\(t\)\(\ \)\)\) \(\(\[Psi]\_n\)(x)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->{"i:42", "(3.1.76)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(x)\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th eigenmode, with corresponding eigenvalue ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          FormBox["\[Lambda]",
            "TraditionalForm"], "n"], TraditionalForm]]],
  ". However, the eigenmodes are now complicated linear combinations of \
trigonometric functions, with wavenumbers that are no longer evenly spaced \
multiples of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]/L\)]],
  ". This is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " a trigonometric Fourier series. How do we go about finding the constants \
",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " in this case?"
}], "Text"],

Cell["\<\
\tSurprisingly, the eigenmodes are still orthogonal with  respect \
to one another:\
\>", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%L\(\( \[Psi]\_m\)(
              x)\) \(\(\[Psi]\_n\)(x)\) \[DifferentialD]x = 0\)]],
  "  if ",
  Cell[BoxData[
      \(TraditionalForm\`n \[NotEqual] \ m\)]],
  "."
}], "Text",
  CellTags->"i:41"],

Cell["One can check this numerically:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[
      Table[NIntegrate[\[Psi][n, x] \[Psi][m, x], {x, 0, L}], {n, 1, 4}, {m, 
          1, 4}]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.17"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.851033904574666`", \(-5.783287453098307`*^-9\), 
              "1.480914569793046`*^-9", \(-9.099820547152186`*^-10\)},
            {\(-5.783287453098307`*^-9\), "0.74296268507732`", 
              "4.252997320638996`*^-10", "8.840959041245267`*^-11"},
            {"1.480914569793046`*^-9", "4.252997320638996`*^-10", 
              "0.5852161716509435`", \(-4.0393697154500474`*^-10\)},
            {\(-9.099820547152186`*^-10\), 
              "8.840959041245267`*^-11", \(-4.0393697154500474`*^-10\), 
              "0.5414261499199934`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
The off-diagonal elements in this table of integrals are nearly \
zero, indicating orthogonality of the eigenmodes within the precision of the \
numerical integration. \
\>", "Text"],

Cell[TextData[{
  "\tSince the modes are orthogonal, they can ",
  "still be used",
  " to determine the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A\_n'\) \(s\)\(\ \)\)\)]],
  " by matching to the initial conditions. At ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t = 0\)\(,\)\)\)]],
  " Eq. ",
  ButtonBox["(3.1.76)",
    ButtonData:>"(3.1.76)",
    ButtonStyle->"Hyperlink"],
  " implies"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 
          0)\  = \(\[Sum]\+n A\_n\ \(\(\[Psi]\_n\)(x)\) = \(T\_o\)(x)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Multiplying both sides by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_m\)(x)\)]],
  ", and integrating over ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+n A\_n\ \(\[Integral]\_0\%L\(\( \[Psi]\_m\)(
                  x)\) \(\(\[Psi]\_n\)(
                  x)\) \[DifferentialD]x\) = \[Integral]\_0\%L\(\( \
\[Psi]\_m\)(x)\) \(\(T\_o\)(x)\) \[DifferentialD]x\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Orthogonality implies that each term in the sum vanishes except for the ",
  Cell[BoxData[
      \(TraditionalForm\`n = m\)]],
  " term, so we find that only the ",
  Cell[BoxData[
      \(TraditionalForm\`n = m\)]],
  " term survives, leaving a single equation for ",
  Cell[BoxData[
      \(TraditionalForm\`A\_m\)]],
  ":  ",
  Cell[BoxData[
      \(TraditionalForm\`A\_m\ \(\[Integral]\_0\%L\(\( \[Psi]\_m\^2\)(
                x)\) \[DifferentialD]x\) = \[Integral]\_0\%L\(\( \[Psi]\_m\)(
              x)\) \(\(T\_o\)(x)\) \[DifferentialD]x\)]],
  ", which yields"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`A\_m = \[Integral]\_0\%L\(\( \[Psi]\_m\)(
              x)\) \(\(T\_o\)(
              x)\) \[DifferentialD]x/\(\[Integral]\_0\%L\(\( \[Psi]\_m\^2\)(
                    x)\) \[DifferentialD]x\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.77)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(3.1.77)",
    ButtonData:>"(3.1.77)",
    ButtonStyle->"Hyperlink"],
  " provides the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_m\)]],
  " for every value of ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ". When used in Eq. ",
  ButtonBox["(3.1.76)",
    ButtonData:>"(3.1.76)",
    ButtonStyle->"Hyperlink"],
  ", it yields the required solution ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " for any given initial temperature ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_o\)(x)\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Summary", "Section",
  CellTags->"c:22"],

Cell["\<\
In this subsection we found solutions to the heat equation using \
the method of separation of variables, the same approach as we employed when \
solving the wave equation. Just as for the wave equation, the approach only \
worked if we could find an equilibrium solution to the problem that took care \
of source terms and inhomogeneous boundary conditions. Then the deviation \
from equilibrium was  expanded as a series consisting of orthogonal \
eigenmodes with time-dependent amplitudes.\
\>", "Text"],

Cell["\<\
\tThis was all completely analogous to the wave equation solution. \
However, we allowed for more general boundary conditions such as can often \
occur in heat equation problems. Along with the Dirichlet conditions familiar \
from the wave equation, we also considered von Neumann and mixed conditions. \
These new boundary conditions brought with them several surprises.\
\>", \
"Text"],

Cell[TextData[{
  "\tFirst, we found that with static von Neumann boundary conditions, an \
equilibrium solution for the temperature is not possible unless the \
temperature gradients at the edge of the system satisfy an energy \
conservation condition, Eq. ",
  ButtonBox["(3.1.51)",
    ButtonData:>"(3.1.51)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tSecond, we found that in the case of mixed boundary conditions the \
eigenmodes used in our series solution for ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["T",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " were not simple trigonometric Fourier modes. Surprisingly, however, the \
modes still formed an orthogonal set, which could be used to find a solution \
just as in a Fourier series expansion. We will discover the reason for this \
amazing \"coincidence\" in Chapter ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 3.1", "Subsubtitle",
  CellTags->"c:23"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " A mass ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " hangs at the lower end of a vertical string, in equilibrium under the \
force of gravity ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  ". The string has constant mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " per unit length. The mass is at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ", and the string is attached to the ceiling at ",
  Cell[BoxData[
      \(TraditionalForm\`z = L\)]],
  ".  Find the tension ",
  Cell[BoxData[
      \(TraditionalForm\`T(z)\)]],
  " in the string as a function of height ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " . "
}], "Text",
  CellTags->"i:47"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " A thin rod of height ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is balanced vertically on its end at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ". The rod has a nonuniform cross section. It is cylindrical, but has a \
radius that varies with height ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`r = \ z/10\)]],
  ". (That is, the rod is  a cone, balanced on its tip). The mass density of \
the material making up the cone is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalM]", "=", 
          FormBox[
            RowBox[{"1000", " ", 
              RowBox[{"kg", "/", 
                FormBox[
                  SuperscriptBox[
                    StyleBox["m",
                      FontSlant->"Plain"], "3"],
                  "TraditionalForm"]}]}],
            "TraditionalForm"]}], TraditionalForm]]],
  ". Find the tension force in the rod vs. ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " (more aptly called compression force in this instance) due to gravity ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(g\)\(\ \)\)\)]],
  "."
}], "Text",
  CellTags->"i:46"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " The following futuristic concept has been proposed for attaining orbit \
around a planetary body such as the earth: a very massive satellite, placed \
in geosynchronous orbit above the equator, lowers a thick rope (called a ",
  StyleBox["tether",
    FontSlant->"Italic"],
  ") all the way down to the ground. The mass of the satellite is assumed \
here for simplicity to be much larger than that of the tether. Astronauts, \
equipment, etc., simply ride an elevator up the tether until they are in \
space. Due the huge tension forces in the tether, only fantastically strong \
materials can be used in the design, such as futuristic materials made of \
carbon nanotubes.  Here, we will calculate the tension forces in the tether . \
[See also the article in the ",
  ButtonBox["July-August 1997 issue of American Scientist",
    ButtonData:>{
      URL[ "http://www.sigmaxi.org/amsci/articles/97articles/strength.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  " on properties and uses of carbon nanotubes. The cover of this issue is \
reproduced in Fig. ",
  ButtonBox["3.6",
    ButtonData:>"Fig. 3.6",
    ButtonStyle->"Hyperlink"],
  ". (It depicts an open-ended tether design). Also, you may want to check \
out Sir Arthur Clarke's science fiction novel, ",
  StyleBox[ButtonBox["The Fountains of Paradise",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[".",
    FontSlant->"Italic"],
  ")"
}], "Text",
  CellTags->"i:45"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.33219 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00326158 0.0317189 0.00326158 [
[ 0 0 0 0 ]
[ 1 1.33219 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33219 L
0 1.33219 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .03172 translate
.95238 1.26875 scale
876 string
292 389 8 [292 0 0 389 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
97C597C5C5C5C5C597C5C597B6B6B69797975F5F5F979797FFC5C5EFC5C52C2C2C490000
00002C00002C00002C2C2C2C2C2C2C2C2C2C858585737373E1E1E12C2C2C0000002C0000
4900000000002C2C2C490000002C0097C5C5C5EFEFFFEFC5C59797B6B6B6C59797C5EFC5
FFEFC5FFEFEFEFC5C5FFFFC52C2C2C2C2C2C00002C00002C49000000002C005F5F5F5F5F
5F975FFFEFC52C2C2C002C002C2C2C00002C002C005F9797C5C5C5C5EFEF4949495F5F5F
C5C597EFC5C5B6B6B6C5C5EFC5C5EF002C002C00002C2C2C002C002C2C2C7373732C2C2C
9797979797972C2C2C00002C979797EFEFC52C2C2C002C005F9797C5C5C500002C2C0000
49000097C5975FC5C59797975F5F002C2C2C5F5F5F2C2C2C5F5F5F7373735F9797005F5F
5F5F5FC5EFC55F5F00002C002C2C2CA7A7A797975F5F975F4949492C2C2C000000000000
2C00002C00002C2C2CA7A7A797975FC5C5975F5F5F002C0000000000000000002C2C2C2C
002C00000000002C00002C002C2C2C858585C5C5C5EFEFC52C2C2C4949492C2C2C5F5F5F
C5C55FC5975F975F5FC5C597FFFFEF5F5F5F5F975F002C00002C00002C00002C00002C00
2C2C2C0000002C2C2C0000498585855F975F494949FFEFEFFFFFC55F5F5F494949494949
97C597FCFCFCB6B6B600002C00002C2C2C2C00002C5F5F5FFFFFEF2C2C2C00002C2C2C2C
000049979797A7A7A75F5F5FC5C5972C2C2C97975FC5C5C500000000002C5F975F97975F
7373734949495F979797C5C55F5F00858585002C00002C002C2C2C2C2C2CEFEFEFE1E1E1
5F5F00005F5F85858597C5C5FFFFEF5F97975F975F2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2CB6B6B697975FC5C597C5EFC5FFFFEFFCFCFCE1E1E1E1E1E1E1E1E15F5F002C2C2C
5F5F5F9797975F975F494949494949737373C5C5C5E1E1E1EFC5C573737300002C2C2C2C
002C000000002C2C2C00002C2C2C2CFFEFEFFFFFFF2C2C2C2C2C2C0000002C0000002C00
0049005F975FB6B6B6C5C597002C004949494949490000005F975F2C2C2C494949737373
979797002C002C2C2C9797975F97975F9797A7A7A72C2C2C2C2C2C005F5FC5C5C5005F00
2C2C2C2C2C2CC5EFEFE1E1E197C597C5C5EFEFFFC52C2C2C2C2C2C2C2C2CEFEFC5005F5F
002C00002C00D4D4D4C5FFC5858585005F00EFC5C5C5EFC5D4D4D4C5EFC5EFEFEF737373
2C2C2C2C2C2C5F005F5F5F97
B6B6B65F005F2C2C2C00000000002C2C2C2C4900002C2C2CA7A7A7B6B6B62C2C2C00002C
2C2C2C2C2C2C2C2C2C2C2C2C00002C5F975F494949FFEFEFC55F972C2C2C490000002C00
2C00002C000000002C2C2C2C00004997979797C5C5FFEFEFFFEFC5EFEFC5C5C5C5975F5F
2C2C2C858585C5EFEFC5EFC52C2C2C2C2C2C2C2C2C2C00002C2C2C000000737373975F5F
EFEFEF975F5F0000002C2C2C002C002C0000000000005F5F97C5C5EFEFC5E1E1E1E1E1E1
D4D4D4FCFCFCFFEFC5FFFFEFC5C5C5002C00002C002C2C2C00002C2C2C2C97975F5F97C5
B6B6B62C2C2C002C00002C00737373C5EFC54949490000005F97C5C5EFC5002C00000000
2C2C2CA7A7A72C2C2C2C2C2CB6B6B64949495F975F4949495F5F5F005F5F2C2C2C002C00
005F5FA7A7A7FFEFEF5F5F00000000002C00A7A7A7C5C5977373734949492C2C2C2C2C2C
002C00002C002C2C2C2C2C2C979797C5C597C5975F5F975F002C00002C002C2C2C002C00
002C000000002C2C2C002C00002C00737373EFEFC5C5C597EFEFC5B6B6B6A7A7A7C5975F
7373735F5F5F5F5F5FA7A7A7C5C597FFFFC52C2C2C737373002C000000002C0000002C00
2C2C2C5F5F5F7373737373732C2C2C5F5F5FD4D4D4FFEFC5EFEFC5EFC5C5EFEFC5EFFFEF
A7A7A72C2C2C00002C2C2C2C00002C2C2C2C2C2C2CFFFFEFC597972C2C2C00002C494949
A7A7A75F975F975F5F5F5F5F2C2C2C2C2C2C97C597A7A7A72C000000002C002C005F9797
97979797C55F979797B6B6B62C2C2C005F5F97975F002C00002C002C2C2C2C2C2CEFEFEF
B6B6B6FFFFEFEFFFC5FFEFEFFFEFFF2C2C2C5F975F979797002C00002C002C0000490000
00002C979797FFEFC5FFFFEFFFEFEFC5C5C5979797979797494949737373858585FFC5C5
97C5975F5F5F2C2C2C2C2C2CA7A7A7FFEFC5B6B6B62C2C2C2C00002C00002C0000490000
0000000000000000002C2C2C494949C5C5C5FFFFEF005F5F0000495F5F5F005F5F737373
9797979797972C2C2C0000492C2C2C2C2C2C005F002C2C2C4949495F9797B6B6B6004900
A7A7A72C2C2C00004997C5C5B6B6B65F97978585854949492C2C2C2C2C2CD4D4D4494949
0000492C2C2CEFFFFFD4D4D4E1E1E1EFEFEF97975F5F5F0000002C494949EFC5C55F5F5F
0000492C2C2C5F5F97D4D4D4B6B6B6737373E1E1E197975F494949FCFCFCFFEFEF737373
2C2C2C002C002C2C2C5F5F5F
2C2C2C00002C00002C00002C00002C4900002C2C2C00002CEFC5C5EFEFC57373732C2C2C
2C2C2C00002C005F5F4949495F5F5F975F5F97C5C5FFC5EF2C2C2C00002C00002C002C00
002C00002C002C2C2C2C2C2C7373735F5F5FC5C5C5EFC5C58585852C2C2C49000000002C
2C2C2C005F5FB6B6B6C5C5972C2C2C2C2C2C49000000002C2C2C2C2C2C2C5F5F5F5FC597
E1E1E12C2C2C2C00002C2C2C002C002C2C2C2C2C2C737373494949C5EFEFC5C5EF494949
2C2C2C2C2C2C005F5F97C5C5D4D4D42C2C2C2C2C2C2C2C2C002C005F979700002C97C5C5
A7A7A7002C002C2C2C2C2C2C005F5F97C5C5EFC5975F5F5FC5C5C5C5EFEF2C2C2C00002C
490000C5C5C5490000002C005F5F5F97C5974949494949492C2C2C002C00002C002C2C2C
00002C5F975FA7A7A7B6B6B6C5EF972C2C2C00002C00002CA7A7A7A7A7A75F5F00494949
0049002C2C2C00002C00002C2C2C2CA7A7A7C5C597975F007373735F5F00005F5F5F5F5F
002C002C2C2C00002C2C2C2C494949B6B6B6B6B6B6EFC5C52C000000002C00002C00002C
002C0000000000002C00002CA7A7A7B6B6B6FFEFC54949497373735F5F00002C00737373
5F9797858585007300979797FFEFC5FFEFC5EFC5C52C2C2CE1E1E1FFEFC5A7A7A7002C00
00002C00002C2C2C2C002C00002C00004900B6B6B6FFEFEF2C2C2C002C00979797C5EFC5
C59797002C0097C55F2C0000494949002C008585855F5F5F2C2C2C002C00002C005F5F5F
B6B6B6E1E1E1C5EFFFEFEFEFE1E1E197C55F494949A7A7A72C2C2C2C2C2C2C2C2C2C2C2C
EFEFEFEFC5C5B6B6B6B6B6B6975F97FFFFEF5F5F5F7373737373732C000000002C000000
0000002C2C2CE1E1E15F005F2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C0000002C2C2C
00002CEFC5EFFFEFFFB6B6B67373732C2C2C00002C2C2C2C002C0000000000002C00002C
002C0000002C5F5F5F7373735FC597EFEFEFC5EFEFC5C5C59797C55FC5C597C5C597975F
C5C5978585852C2C2C2C2C2C2C000000002C5F975F494949A7A7A7858585002C002C2C2C
5F97972C2C2C490000B6B6B62C2C2C005F5F97C5974949492C2C2C2C2C2CEFEFEF737373
8585855F5F5F97975F00002C2C2C2C975F5FC5FFC55F975F00002C2C2C2C49494997C597
737373000049D4D4D4A7A7A7A7A7A7C5FFEFEFEFC5494949002C00004900FFFFFF5FC597
97975F2C2C2C2C2C2C5F5F5F
2C2C2C0000000000002C2C2C00002C2C2C2C00002C2C2C2C97C5C5D4D4D45F5F5F5F9797
5F5F5F8585857373737373732C2C2C5F5F5FE1E1E14949492C2C2C2C2C2C2C2C2C490000
002C002C2C2C2C2C2C005F5F5F5F5F5FC597EFEFC52C2C2C4900002C2C2C00002C2C2C2C
2C2C2C002C005F9797FFFFEF2C2C2C4900002C2C2C005F5F8585855F5F5F005F5FFFEFEF
494949000000002C00002C00002C002C2C2C002C005F975F97C5C5EFEFEF2C2C2C00002C
2C2C2C2C2C2C2C2C2C5FC5C5E1E1E12C2C2C002C00002C00002C00737373005F5FC5C5C5
002C0049000000002C002C0000490073737397975FA7A7A773737397C5C5B6B6B6002C00
00002CB6B6B65F00004900002C2C2C5F979797C5C5858585005F002C2C2C490000494949
5F5F5F005F5F737373A7A7A75F5F5FE1E1E1C5C55F4900002C0000494949A7A7A7C5C597
2C2C2C5F975F5F5F5F5F5F002C2C2C2C2C2CB6B6B6EFEFC5C5C5972C2C2C00002C494949
5F5F5F5F5F5F737373494949979797FFEFC5EFC5C500002C002C002C00002C000000002C
0000002C00002C2C2C2C2C2C490000494949B6B6B6FFFFEF97975F2C2C2C8585855F5F5F
494949A7A7A7FFFFEFC5C5C52C2C2C2C0000002C00494949C5C5C5FFEFEF00002C002C00
2C0000002C002C2C2C2C2C2C2C2C2CA7A7A7FCFCFC00002C2C2C2C5F9797FFFFEF2C2C2C
2C2C2C97C59797975F002C002C2C2C5F5F5FA7A7A74949499797972C0000002C0000002C
737373C5C5EFB6B6B697C5C597C5C5D4D4D497975F5F5F5F97975F002C00002C002C2C2C
FFEFC5C5C55F2C2C2C002C002C2C2C494949C5C5C597C55F5F5F5F5F975F002C0000002C
000000494949D4D4D49797975F5F002C00000000000000000000000000000000002C2C2C
00002CC5C5C5C5C5C57373735F97972C2C2C2C2C2C005F5F004900005F00005F5F2C2C2C
2C2C2CA7A7A7D4D4D4FFFFEFD4D4D45F5F5F5F5F5F2C2C2C2C2C2C5F005FB6B6B6C5C5C5
2C2C2C2C2C2C49494900002C002C005F97972C2C2C97C5972C2C2C979797494949494949
A7A7A75F97975F97975F975F0000492C0000C5EFC55F975F2C2C2C004900EFFFFFC5EFEF
5F975FD4D4D47373732C2C2C2C2C2C00002CC5EFEF7373732C2C2C002C002C2C2CC5EFEF
97C5975F975FE1E1E14949492C2C2CA7A7A7FFEFEF5F97972C2C2C2C2C2CA7A7A7C5EFC5
7373732C2C2C2C2C2C5F5F5F
002C002C00002C2C2C2C00002C2C2C0000002C00000000005F5F5F97C597EF9797494949
4949495F0000005F5F7373735F9797FFEFFFE1E1E12C2C2C00002C2C2C2C2C2C2C000000
490000002C00002C005F5F5F000049EFEFEFC597972C2C2C00002C00002C0000002C0000
2C2C2C2C2C2C494949FFEFEFC597975F97977373735F5F00C5C5C5FFEFEFFFFFEFE1E1E1
2C2C2C002C00002C00002C002C2C2C002C007373732C2C2CEFC5C5C597972C2C2C2C0000
002C000000002C2C2C5F97C5FFEFEFC597970000002C2C2C737373494949FCFCFCC5C5C5
2C2C2C002C002C2C2C002C00002C004949495FC5C52C2C2C2C2C2C5F9797C5C5C5004900
00000097C5EF9797972C2C2C2C2C2C97975F975F5F005F5F97975F49494900002C005F5F
5F5F5F2C2C2C005F5F5F9797B6B6B6B6B6B6858585C5C5C5C5C5C57373735F5F5F737373
9797975F5F5F5F5F002C2C2C5F5F5F4949495F5F97EFC5C5B6B6B6C5C5C5B6B6B6C5EFC5
EFC597C5C5C5C5C5975F5F5FE1E1E1EFC5C54949495F5F00002C002C2C2C000000000000
2C000000002C2C2C2C002C002C00000000002C2C2CB6B6B6D4D4D4C5C597FFEFC5FFEFC5
EFC5C597975F00002C2C2C2C002C00002C00000000979797EFEFC52C2C2C002C00002C00
2C0000002C00002C00002C005F5F5FFFEFEF5F5F5F494949979797C5C5C5002C0000002C
00002C97C5970000002C2C2C2C2C2C97C5975F5F5F5F97978585852C00000000002C2C2C
858585D4D4D44949490000002C2C2CB6B6B6C5EFC5005F5F5F5F5F5F975F2C00002C2C2C
97C5C5EFC5C5002C000000002C0000002C002C2C2CC5C5C55F5F00000049494949494949
2C2C2C000000E1E1E1EFEFC57373732C2C2C000000000000000000000000000000000000
2C00005F9797FFFFFFC5C5C58585852C00004949495F5F5F005F5F4949495F5F5F494949
EFEFEFFCFCFCD4D4D42C2C2C2C2C2C002C00002C002C2C2C000000C5EFC5B6B6B6005F5F
2C2C2C2C2C2C00002C2C2C2C2C2C2C5F5F5F2C2C2C97C5972C2C2C97C5972C2C2C2C2C2C
C5C5C54949498585855F97972C2C2C2C2C2CEFFFEF5F5F5F979797A7A7A7C5FFEF2C2C2C
858585C5EFEF4949495F5F5F002C002C2C2C494949C5C5975F975F00002C494949EFEFEF
EFEFC5C5EFFFEFFFEF5F5F5F2C2C2C2C0000C5FFFF7373737373732C2C2C002C00C5EFEF
5F97975F975F2C2C2C5F5F5F
2C2C2C2C2C2C00002C2C0000002C002C2C2C2C2C2C2C2C2C2C2C2CC59797FFFFEFEFEFC5
FFFFEFEFFFEFFFEFEFFFEFC5EFEFEFFFEFEF2C2C2C2C2C2C2C0000002C00002C002C2C2C
00002C2C00005F979749494997EFC5C5C5C52C2C2C2C2C2C002C002C2C2C2C00002C2C2C
2C2C2C2C000000002CFFFFEFFFC5C5EFFFC5FFFFEFFFFFFFFFFFC5A7A7A7FFFFEFD4D4D4
2C2C2C00002C2C2C2C2C2C2C2C2C2C2C00002C2C2CA7A7A7FCFCFC2C2C2C002C00000000
49000049000000002C005F5FC5EFFFD4D4D497975FC5C597EFC5C5FFFFFFC5EFC5EFC5C5
002C002C2C2C002C00002C005F5F5F2C2C2CA7A7A700002C002C00005F5FC5C5C5979797
5F9797C5C5C5C5C5972C000000002C97975F494949002C00C5C5C52C2C2C2C2C2C004900
2C2C2C002C002C2C2C494949858585C5C5C5C5975F005F5F737373A7A7A7C59797C5C5C5
B6B6B6B6B6B6D4D4D4C5EFC5C5C597737373EFEFC5E1E1E15F5F5F0000000000002C0000
5F5F5F737373858585737373C59797E1E1E14949495F5F5F2C2C2C2C00000000002C0000
00002C002C00002C002C0000002C000000005F5F5FC5C5C5EFC5C5C5C597A7A7A72C2C2C
2C2C2C2C2C2C00002C00002C2C0000000000005F00C5C5C5FFFFEF2C2C2C2C2C2C002C00
2C2C2C0049007373735F5F5FC5EFEFFCFCFCEFEFC597C597FFFFEF2C2C2C2C2C2C002C00
9797975F5F002C2C2C4949492C2C2C49000000002C97975F5F5F5F5F5F00002C00005F5F
97C597C5C5EF975F002C00002C2C2C2C2C2C494949C5EFC52C2C2C5F5F5F5F5F5FA7A7A7
B6B6B6FFEFC50000002C000000000049000000002C2C2C2CB6B6B697C55F004900737373
5F5F5F5F975FA7A7A7EFEFFF5F5F5F737373002C00000000490000000000000000004900
005F5F5F9797FCFCFCFFFFFFEFEFC5EFEFC5C5C5C5D4D4D4C5C5C5E1E1E1FFFFEFE1E1E1
EFEFEF2C2C2C00002C002C002C2C2C002C0000490097C597C5EFC5C5C597005F5F2C2C2C
2C2C2C2C2C2C00002C5F975F5F97972C2C2C005F5F5F975F002C005F97975F97975F97C5
97975F2C2C2C975F975F975F002C002C2C2CEFFFEFD4D4D45F975FE1E1E1005F5F000000
2C2C2C49494997C5975F5F5F002C00002C002C0000C5979797C597858585005F00EFEFFF
004900A7A7A7FFFFEF8585852C2C2C004900D4D4D4C5C5975F975F2C2C2C002C00C55F97
E1E1E15F5F97005F5F5F5F5F
2C2C2C2C00002C2C2C002C002C2C2C002C002C2C2C2C2C2C5F5F5F979797FFFFEFE1E1E1
E1E1E1EFC5C59797975F5F5FFFFFEFEFFFEF5F00002C2C2C00000000002C2C2C2C2C2C2C
00002C005F5F494949005F5FC5C5C5975F5F002C00002C002C2C2C00002C002C002C2C2C
00002C000000494949C5EFC5FFEFEFFCFCFCC5979749494900002CA7A7A7FCFCFCB6B6B6
2C2C2C00002C002C00002C002C2C2C5F5F5F005F00E1E1E1850000490000002C00490000
002C000000000000005F5F5F97C5C5FFFFFFFFFFEFFFEFC5FFFFEF979797FFFFEFEFFFEF
2C2C2C2C00002C2C2C00002C737373005F5FA7A7A700002C00002C2C2C2C97C5C55F97C5
85858597C5C5C5C5C52C2C2C2C2C2C5F5F5F97975F002C00005F979797972C2C2C97C55F
002C002C2C2C4949495F5F97005F5F979797EFEF974949492C2C2C0000005F5F5FC5C5C5
97975F0000495F5F5F5F5F5F979797B6B6B6A7A7A7EFEFC54949495F5F5F00002C2C0000
002C00490000002C0000002C00002CA7A7A7EFC5C55F5F5F5F975F000000002C00002C00
00002C002C00002C0000000000002C494949A7A7A7EFEFC5A7A7A72C2C2C000000000000
490000002C002C2C2C00002C002C004949495F5F5FFFEFEF975F5F00002C00002C2C0000
7373737373735F5F5FB6B6B6975F97000049FFEFEFD4D4D4002C00002C00002C005F9797
85858500002C2C2C2C5F5F5F737373000000002C005F5F5F97C5978585850000002C2C2C
858585C5C5C5A7A7A7002C002C2C2C2C0000002C00B6B6B6C5EFC5B6B6B697C5C5C5C5C5
97C5C5FFFFEF2C2C2C005F002C2C2C002C0000002C2C00005F5F5FFFEFC5EFC5C5D4D4D4
FFEFEFE1E1E1FFEFEFC5EFC5C5C597002C005F5F5F5F5F5F00002C002C005F5F5F5F9797
C5EFC5FFFFFFFFEFEF49494900002C2C2C2C00000000002C2C2C2C2C2C2CFFEFEFFFEFC5
2C2C2C002C00002C002C2C2C5F975FC5EFC5EFC5C58585852C2C2C49494949494900002C
00002C2C2C2C7373732C2C2C97975F2C2C2C9797972C2C2C5F9797B6B6B65F5F5F97C5C5
5F5F5F2C2C2C5F5F5F5F9797004900004900D4D4D4005F5F858585EFEFEF5F5F5F2C2C2C
2C2C2C2C2C2CE1E1E15F5F5F005F5F000000002C00E1E1E1D4D4D4C5FFEF979797C5C5C5
2C2C2C2C2C2CC5EFEF5F97972C2C2C2C2C2C5F5F5FE1E1E17373735F5F5F00002C004900
E1E1E1EFEFC597C5975F5F5F
2C2C2C00002C002C002C2C2C00000000000000002C005F5F5F5F5FB6B6B6FFEFEF005F5F
2C2C2C2C2C2C00002C2C2C2C5F9797A7A7A7EFC5C52C2C2C2C000000002C002C0000002C
5F5F5F737373002C00EFFFEFEFC5C52C2C2C2C2C2C2C2C2C002C00490000002C00002C00
00002C2C2C2C5F5F5FFFEFEF975F5F2C2C2C2C2C2C2C2C2C00002C5F975FE1E1E1C5C5C5
5F5F5F2C2C2C5F5F5F7373735F975F5F5F5FC5EFC5FFFFEF2C2C2C002C002C2C2C000000
00002C0000005F5F5F494949E1E1E1C597972C2C2C2C2C2C2C2C2C005F97C5EFEFFFEFEF
2C2C2C002C002C00004949495F5F5FC5C5C55F005F2C2C2C2C2C2C2C2C2C9797975F975F
5F97C55F97C5C5C5C52C2C2C0000005F9797C5975F002C002C2C2C7373735F5F5F97C597
5F5F5F00004900005F005F5F2C2C2C4949495F9797FFFFC5975F002C2C2C2C2C2C002C00
A7A7A75F00000000002C0000002C002C2C2C737373B6B6B6C5C5972C2C2C49494900002C
002C0000002C002C00002C00490000002C002C2C2CC5C5C55F5F5F4949495F975F5F5F5F
5F5F5F5F5F5F5F5F5F5F975F5F5F5F979797E1E1E1A7A7A700002C2C0000002C002C0000
002C0000000000002C49494973737300490097975FEFEFEF0000494949497373735F5F5F
5F9797C5C5C59797970000002C2C2CFFFFEFFFEFEF00000000002C002C00A7A7A7C5C597
5F97004949495F975F2C2C2CC5C5972C2C2C0000002C000097C5978585855F975F737373
A7A7A7E1E1E197979700002C2C2C2C002C0000002C2C2C2CC5EFEFE1E1E1EFEFC5FFEFC5
E1E1E1EFEFC50049005F5F005F5F5F00002C00002C00002C005F5FFCFCFC0000002C0000
0000002C0000000000737373C5C5C5C5C5C55F975F002C005F5F5F5F975FB6B6B6FFFFFF
9797972C2C2C2C2C2C002C000000002C2C2C2C000000002C2C2C2C2C2C2C5F5F5FC5FFC5
EFFFEFFFEFEFA7A7A7B6B6B6A7A7A7979797C5C5C54949494949492C2C2C002C002C2C2C
5F5F5F0073002C2C2C2C2C2C00002C2C2C2CA7A7A75F975FB6B6B60049002C2C2CC5EFC5
5F5F5F2C2C2C5F5F9797C5C5005F5F5F97C57373732C2C2C2C2C2CFFEFEF005F5F2C2C2C
2C2C2C2C2C2C979797C5EFC55F5F5F5F5F5F000049C5C5C52C2C2C004900C5C5EF5F975F
002C0000490049494997C5975F975F2C2C2C2C2C2CEFEFFFB6B6B65F975F005F002C2C2C
E1E1E12C2C2C7373735F5F5F
2C00002C000000002C002C002C2C2C2C2C2C5F975F5F5F5F97C597E1E1E12C2C2C2C2C2C
2C2C2C002C002C2C2C2C2C2C00002C975F5FEFEFEF0049002C2C2C002C00004900737373
975F5F737373E1E1E1B6B6B62C2C2C2C2C2C00002C2C2C2C002C002C000000002C002C00
2C00005F5F5F004900EFEFC52C2C2C002C002C2C2C2C2C2C2C2C2C005F5FC5EFEFFFFFEF
9797978585857373735F975FB6B6B6FFEFFFFFFFEF975F5F00002C00002C2C2C2C00002C
2C00000000005F5F5F97C597FFEFC5002C00002C000000002C2C2C5F5F5F97C5C5FFFFFF
002C0000002C00490073737300002CC5C5C52C2C2C002C002C2C2C2C2C2C5F5F5F5FC5C5
494949494949C5C5EF97C55F00002C5F9797C5C5972C2C2C002C00005F5F5F9797494949
5F975F5F5F5F002C002C2C2C2C2C2C4949495F5F5F97975FC5C5C5EFEFC5490000002C00
2C0000C5C5975F97002C2C2C002C00000000002C00737373A7A7A7C5C5974949495F5F00
002C00000000002C002C0000002C002C00002C2C2C494949E1E1E1C5C55F5F5F00004900
002C004900002C2C2C5F5F005F5F5FFFFFEFB6B6B69797977373732C000000002C002C00
5F005F7373738585854949495F975FC5C5C5EFEFC5FFEFEFFFEFC5A7A7A797975FC5C597
2C2C2C000000000000000000005F00FCFCFC2C2C2C002C002C2C2C979797EFEFEF979797
97975FC5C5974949492C2C2C7373732C2C2C002C00002C00000000C5C59797C597C5C5C5
A7A7A7FFEFEF5F9797858585002C00002C00002C00000000B6B6B6EFC5C55F975F002C00
494949B6B6B6EFEF97005F5F5F5F5F5F5F00002C0000002C494949EFFFEF002C00000000
00002C00002C2C2C2C2C2C2C2C000000002C490000A7A7A7B6B6B6EFEFEF7373735F5F5F
00002C00000000000000002C4900002C0000002C0000002C5F5F5F5F9797C5C5C5C5C5C5
B6B6B67373735F5F5F494949EFC5C5A7A7A74949492C2C2C00002C2C2C2C2C2C2C5F5F5F
7373735F5F5F2C2C2C5FC5975F5F00005F5FB6B6B600490097C597494949002C00A7A7A7
005F5F004900B6B6B65F9797A7A7A7C5EFEF4949492C2C2C2C2C2C975F5FC5FFC55F5F5F
2C2C2C002C00005F5FEFFFEFC5EFC5005F5FEFFFEF005F5F2C2C2C2C2C2C5F5F5FC5EFC5
5F975F2C2C2C2C2C2CC5EFEF975F972C2C2C2C2C2CD4D4D4EFEFEFC5EFC5B6B6B6C5EFC5
E1E1E12C2C2C4949495F5F5F
0000002C000000002C2C2C2C2C0000005F5F5F5F5F5FC597EFC5C55F5F5F00002C000000
00002C2C000000002C00000000002CA7A7A7E1E1E1EFC5C55F5F5F5F97977373735F5F5F
EFEFC5EFFFEFFFEFFFC597972C2C2C00002C002C00002C002C2C2C2C2C2C00002C2C2C2C
005F5F494949E1E1E1C597972C2C2C002C002C00002C000000002C2C2C2C979797FCFCFC
C5C5C5FFEFC5FFFFEFFFEFEFC5C5C5975F5FFFFFC58585852C2C2C2C0000002C002C2C2C
00002C737373494949FFEFC52C2C2C00002C00002C2C000000002C2C2C2CC5C5EFFCFCFC
5F5F5FA7A7A797C5C597C5C5A7A7A7D4D4D4002C002C000000002C490000000000B6B6B6
2C2C2C2C2C2C97C5C55F5F97737373B6B6B6D4D4D4004900000000A7A7A75F5F002C2C2C
A7A7A72C2C2C5F5F002C2C2C5F97975F9797494949737373A7A7A7858585B6B6B6EFEF97
2C0000002C00A7A7A7FFFFEFC5C55F2C2C2C00002C00002C005F5F97C597C5C55F494949
5F5F5F5F0000005F002C0000002C00002C00002C00737373FFFFEFEFC597C5C597C5C597
97C597A7A7A7B6B6B6A7A7A7C5EFC5B6B6B6EFC5C55F5F00490000858585494949737373
5F975F004900A7A7A7C5C5C5A7A7A74949492C2C2CEFC5C5FFFFC5FFEFC54949492C2C2C
0000000000002C2C2C2C2C2CFFEFEFB6B6B62C2C2C2C2C2C97975FC5EFC500002C2C2C2C
97975F975F5F002C007373735F5F5FA7A7A7490000002C0000002CC5C5C5C5C5C5858585
B6B6B6B6B6B64949495F5F5FA7A7A7002C00002C00002C00FCFCFCEFC597C5C597002C00
002C00490000858585C5C5974900002C2C2C2C2C2C002C002C2C2CFFFFEF0000002C0000
00002C00002C4900002C2C2C002C002C2C2C002C00002C005F5F5FFFEFEFFFFFC5737373
7373732C2C2C2C2C2C00002C002C00002C002C2C2C5F975FB6B6B6C5EFEF8585852C2C2C
2C2C2C2C2C2C002C00C5EFC5A7A7A74949490000492C2C2C002C004949495F975F494949
494949979797005F5FA7A7A79797975F97970049002C2C2CA7A7A74949492C2C2C97C5C5
8585855F5F5FB6B6B65F5F5F2C2C2C9797975F975F5F5F5F2C2C2C2C2C2CC5EFEF5F9797
5F975F00002C5F005FC5C5972C2C2CC5C5C5E1E1E15F975F00002C2C2C2C2C2C2CE1E1E1
85858500002C2C2C2C5F5F5FC5FFEF5F5F5F494949EFFFEFEFEFC5002C00C5C5C5C5FFEF
E1E1E17373732C2C2C5F5F5F
490000002C002C2C2C2C2C2C00002C5F5F5F5F975FE1E1E1A7A7A72C2C2C002C0000002C
0000002C000000002C2C2C2C2C2C2C494949979797E1E1E15F5F5F494949C5EFC5FFEFEF
C5C597494949FFEFEFC5C5972C2C2C2C2C2C2C2C2C490000002C00002C002C00002C2C2C
73737397C5C5FFEFC52C2C2C2C2C2C2C0000002C002C00000000005F97975F975FFCFCFC
C597975F5F5F2C2C2C002C002C00005F5F5FFFC5EFC597972C2C2C00002C2C2C2C00002C
00002C494949C5C5C5C597972C2C2C49000000002C2C000000002C2C2C2C5F5F97FFEFFF
FFFFFFFFFFEFEFFFEFE1E1E1EFFFEFEFEF97002C002C000000002C005F5F5F5F97979797
2C2C2C49000049494997C597C597975F9797C5EFEF5F5F0000002C005F5FC5975F000000
00002C97975F002C00494949494949494949002C002C2C2C979797A7A7A7737373737373
FFEFC5C5C5975F5F5F97975F97975F2C2C2C97975F7373732C2C2C5F9797979797EFEF97
975F5F4949494949494949492C2C2C5F005FC5C597EFEFC597975F002C00002C00002C00
2C2C2C2C00000000002C2C2C2C2C2C494949EFC5C5C5C597C5C5972C2C2C002C005F975F
B6B6B6A7A7A78585852C2C2C00002C2C2C2C2C2C2C5F9797FFEFC500002C00002C00002C
000000000000000049858585FFFFEFC5EFC5979797858585FFFFEF000000000000737373
C5C5972C2C2C2C2C2C5F0000A7A7A7979797002C00002C00002C00C5C5C5975F5F5F975F
49000097975FB6B6B60049005F5F5F5F97975F5F5F494949EFC5EFC5C597979797002C00
2C2C2C002C002C2C2C858585B6B6B6005F5F5F9797858585979797D4D4D40049002C2C2C
2C2C2C00002C00002C002C002C00002C2C2C002C00002C002C2C2CFFFFEFFFFFEF737373
5F5F5F5F5F5F5F5F5F5F975F5F97977373735F9797EFEFEFD4D4D42C2C2C2C2C2C002C00
2C2C2C5F975FC5C5979797970000492C2C2C000000002C005F975F2C2C2C2C2C2C494949
00002C5F5F5F5F97975F5F5F2C2C2CA7A7A72C2C2C2C2C2C97C597005F5F0049005F9797
9797975FC59797C597737373000049000049EFC5C55F5F97002C002C2C2C49494997C5C5
5F97975F975FC5C5EF2C2C2C002C00000000C5EFC57373730049002C2C2C002C00EFC5EF
5F5F5F005F5F002C00494949EFEFFFFCFCFC97C5C5FCFCFC97975F002C00002C002C2C2C
858585C5EFC55F97975F5F5F
005F5F4949494949495F5F5F494949494949E1E1E1EFC5C52C2C2C002C002C2C2C2C2C2C
002C002C2C2C2C2C2C00002C00002C5F5F5F97C5C5FFFFC5FFFFEFEFEFEFD4D4D42C2C2C
2C2C2C2C2C2CC5C5C5B6B6B62C2C2C2C2C2C002C0000002C002C002C00002C2C2C005F5F
5F5F5FA7A7A7FFEFC52C2C2C00002C002C00002C0000002C002C005F97975F5F5FC59797
2C2C2C00002C00002C2C2C2C002C00005F5FFFEFFFEFC5C52C2C2C2C2C2C00002C000000
494949494949EFC5C5002C0000002C0000000000002C000000002C5F5F5F97C597FFFFFF
2C2C2C00002C002C005FC5C597C5C5FFFFEF00002C2C00002C2C2C7373735F97C52C2C2C
2C2C2C002C00002C009797979797972C2C2C5F97C5B6B6B62C2C2C494949B6B6B6002C00
002C0097C5974949495F5F5F2C2C2C2C2C2C494949494949494949979797EFC5972C0000
7373735F5F5F5F975FFCFCFCC5C5975F5F5F975F5F97975F5F5F00979797C5C597975F5F
4949495F5F5F858585A7A7A7C5C5C5EFEFC5EFEFC5EFEFC5975F5F5F5F5F4949492C2C2C
2C2C2C0000000000002C2C2C00002C002C002C2C2CC5EFC5C5C597C5C59797C597B6B6B6
4949492C2C2C49000000002C002C00002C005F975FEFFFC5490000002C00000000000000
4949498585855F9797B6B6B6858585D4D4D4FFFFEFE1E1E100002C0000002C2C2CC5C597
5F5F00002C002C2C2C2C2C2C5F5F5F5F5F5F5F975F2C0000000000A7A7A7C59797858585
0000002C2C2C490000C5C5C5002C00005F000049002C2C2CE1E1E1EFC5C5A7A7A7000000
002C00002C002C2C2C2C0000B6B6B6B6B6B6EFC597D4D4D4C5C5C5C5EFEF9797C5737373
7373734949490000492C2C2C2C2C2C00002C0049005F5F5F494949FCFCFCFFEFEFFFEFEF
EFC5C5B6B6B6EFFFEFEFEFC5FFFFEFEFC5EFB6B6B65F5F5F000000002C00004900C5C55F
EFEF97C5C5972C2C2C4949492C2C2C002C004949494949492C2C2C5F975F2C2C2C858585
494949B6B6B68585852C2C2C002C00B6B6B64949492C2C2C8585855F5F5F7373735F9797
2C2C2C2C2C2CC5EFEF005F5F4949492C2C2CB6B6B65F975F8585852C2C2C002C0097975F
B6B6B6C5EFC5C5EFEF7373732C2C2C2C2C2C975F975F979773737300002C2C2C2C494949
C5EF979797972C2C2C2C2C2CD4D4D42C2C2CC59797EFFFEF97C5975F5F5F2C00002C2C2C
002C00C59797C5EFC55F5F5F
4949492C2C2C2C2C2C494949975F5FEFC5EFE1E1E12C2C2C002C002C00002C2C2C2C2C2C
0000002C00002C2C2C2C2C2C5F5F5F5F5F5F5F975FFFEFEFEFEFC52C2C2C2C2C2C2C2C2C
00002C2C2C2CA7A7A7E1E1E1A7A7A75F975F73737397975F7373735F975F737373494949
97C597EFEFEF2C2C2C002C00002C00002C002C2C2C2C2C2C5F9797858585C5EFC52C2C2C
2C2C2C2C2C2C2C2C2C002C002C2C2C494949EFEFEFEFC5C52C2C2C5F5F5F5F975F5F975F
97975FEFEFEF73000000002C0000000000002C2C2C002C000049005F5F5FEFEFC5979797
00002C490000002C005F5F9797C5C5FFFFFF490000002C000000002C2C2CB6B6B6002C00
002C00002C002C2C2C9797C52C2C2C00002C4949495F5F5F2C2C2C005F5FB6B6B6002C00
002C005F97975F5F5F5F979797975F5F5F004949492C2C2C002C002C2C2C858585C5C55F
002C00002C002C2C2C737373EFFFEF2C2C2C2C2C2C002C005F5F5F737373B6B6B6FFEFC5
2C2C2C4949492C000000002C2C0000000000000000002C00EFC5C597975F4949492C2C2C
002C002C0000002C00002C00002C00002C005FC55F494949EFC5C5B6B6B6002C00490000
00002C000000000000002C00004900737373EFEFC58585852C2C2C002C0049494997975F
97975F9797978585852C2C2C2C2C2CEFFFEFFFEFEF00002C2C2C2C002C00C5C597C59797
00002C494949002C00002C002C2C2CC5C597C5C5C549494900002C97C5C5EFFFC597C597
002C0000002C2C2C2C737373E1E1E1D4D4D4C5C5C5EFEFEFEFEFFFEFC5C59797972C0000
00000049000000002C2C0000858585EFEFEF7373734949495F5F5F858585A7A7A7B6B6B6
5F5F004949497373735F975F7373738585855F5F0097C597FFFFEFE1E1E15F5F5F494949
2C2C2C4949494900005F5F00C5C5C5C5EFC55F5F5F005F5F5F975FB6B6B6C5EF97B6B6B6
5F5F002C00002C2C2C2C2C2C2C2C2C002C005F975F858585002C000000492C2C2C5F9797
5F97974949494949494949492C2C2C97C59749494900975F979797A7A7A75F97975F5F5F
2C2C2C2C2C2C975F9797C5977373732C2C2C004900D4D4D4C5EFC55F975FC5C5C52C2C2C
2C2C2C2C2C2CE1E1E12C2C2C00975F2C2C2C494949EFFFEF7373734949492C2C2C2C2C2C
EFFFFFC5EFC55F97975F5F00EFEFEF00002C2C2C2C494949EFEFFF97C5975F975F000000
2C2C2C2C2C2C494949005F5F
C5C597C5C5C5E1E1E1EFEFC5E1E1E1FFEFC52C2C2C002C00490000002C002C2C2C2C2C2C
2C2C2C002C002C2C2C2C2C2C5F975F5F5F00E1E1E1C597974949492C2C2C002C002C0000
00002C2C2C2C979797E1E1E1B6B6B65F5F5F5F5F5F4949494949495F5F5F97975FC5C597
FFEFEFEFEFC52C2C2C002C004900002C2C2C0000002C2C2C85858500975F975F5F2C2C2C
002C00002C00490000002C0000002C005F5FC5EFEFFFEFC55F975F979797C5C5C5FFFFC5
FFFFEFEFEFEF2C2C2C2C2C2C2C2C2C000000490000002C0073737397C597EFC5C55F0000
00002C2C2C2C002C00005F5F5F5F97FFFFFF002C005F975F5F5F5FEFEFC5C5C5C52C2C2C
000000002C004949499797C52C2C2C2C2C2C002C00C5975F975F5FB6B6B6C5EFEF5F5F00
2C2C2CA7A7A72C2C2C0049005F97970049002C2C2C005F5F0049002C2C2C2C2C2CA7A7A7
97975F2C000000002C000000737373C5C5972C2C2C0000000000000000002C2C2CB6B6B6
9797004949494949492C2C2C0000002C000000002C2C0000002C00A7A7A7C5C5975F5F5F
975F005F5F5F5F5F5F97975F7373737373735F5F5FC5C5C5EFEFC5494949002C00002C00
2C2C2C0000000049005F975F5F5F5F2C2C2CFFFFFF2C2C2C4949497373735F975F494949
97979700000000002C002C005F5F5FFFEFEF00002C2C2C2C002C00FFFFEF97C597C5C597
97975F2C2C2C8585852C2C2C2C2C2C49494997975F5F975FB6B6B6E1E1E1FFEFC5A7A7A7
00002C002C00002C002C2C2CEFC5EFB6B6B6B6B6B6B6B6B6C5EFEFFFEFC55F5F975F975F
490000002C00002C002C0000494949FFFFEF00002C002C00002C00002C002C0000737373
97979797975F5F975F5F975FEFFFC5C5EFC5FFEFEFEFC5C55F5F5F002C002C2C2C2C2C2C
2C2C2C00002C2C2C2C005F5FFCFCFCD4D4D4B6B6B69797978585855F5F5F737373A7A7A7
97C5972C2C2C2C2C2C2C2C2C005F5F7373734949495F975F2C2C2C494949005F5F979797
5F5F5F005F5F0000494949494949495F97977373735F97978585852C2C2C5F5F5F5F9797
005F002C2C2C2C2C2CC5EFFF5F5F5F97C597494949EFEFC52C2C2CD4D4D4C5EFC597975F
002C002C2C2CA7A7A7C5EF977373732C2C2C2C2C2C2C2C2CC5EFC5858585494949000049
EFC5972C2C2C737373D4D4D4E1E1E15F975F2C2C2C002C002C2C2C97979797C5975F975F
4949492C2C2C000049494949
C597978585855F5F5F2C2C2CB6B6B6D4D4D42C2C2C2C2C2C0000002C2C2C002C00002C00
2C2C2C00002C002C007373735F5F5F97975FEFC5C52C2C2C00002C2C2C2C4900002C2C2C
2C2C2C2C2C2C5F5F5F97C5C5FFFFEFFFEFEFEFFFEFEFFFC5FCFCFCEFC5C5B6B6B6B6B6B6
FCFCFCFFEFEF2C2C2C2C2C2C002C000000000049005F97975F5F5FD4D4D42C2C2C002C00
0000002C2C2C2C2C2C2C00002C00007373735F9797C5EFEFEFEFEFEFFFEFA7A7A72C2C2C
2C2C2CC5EFC55F000000002C2C00002C000000002C005F00494949C5EFC52C2C2C2C2C2C
2C0000002C00002C00002C005F5F5FFFFFFFFFEFEFFFFFEFFFEFEFFFFFFFFFEFEF002C00
0000000000005F5F5FA7A7A72C2C2C0000002C2C2C97975F97EFC59797979797C5B6B6B6
002C0097C5C52C2C2C00000000005FC597975F975F2C2C2C5F5F5F5F5F974949492C2C2C
B6B6B6C5C597C5C55F002C002C2C2C858585C5C55F00002C00000049000000002C5F5F5F
97C597C5C55F5F5F004949494949492C2C2C00000000002C49000000002C979797C5C55F
97975F97975F97C55F975F5F97975FC5C597EFEFC5FFEFEF2C2C2C97975F002C00004900
5F5F5F5F975F4949495F5F5FEFFFC5E1E1E1FFFFEFFCFCFCC5C597737373B6B6B62C2C2C
00002C00002C0000002C0000EFFFC55F5F5F2C2C2C000049FCFCFC7373735F5F5FC5975F
2C2C2C2C2C2C97975F2C2C2C2C2C2C00002CC5C597A7A7A7979797EFEFC5FFFFEF2C2C2C
97975F002C00002C00002C00EFEFFF73737300002C002C00B6B6B6EFC5C5C5975F5F005F
5F975F00002C002C0000002C2C2C2CFFFFC5737373002C002C2C2C0000002C0000002C00
2C0000002C00E1E1E1EFEFC5C5C5C57373732C2C2C002C00000000004900004900494949
2C2C2C005F5FFCFCFCEFFFEFC5EFEF5F5F5F5F5F5F2C2C2C2C2C2C2C2C2CA7A7A797975F
2C2C2C2C2C2C975F974949495F5F5F9797972C2C2C5F975F005F5FA7A7A77373735F5F5F
4949492C2C2C494949737373979797A7A7A7A7A7A797C5C55F5F002C2C2C2C2C2CB6B6B6
7373730000002C2C2CC5EFEFD4D4D45F9797A7A7A797975F0000002C2C2CB6B6B6005F5F
4949492C2C2C2C2C2CC5C5975F975F5F5F5F002C002C2C2CB6B6B6EFEFEF97C597C5C5EF
2C2C2C49494900002C0000002C2C2C97C5975F975F2C2C2C00002C2C2C2C858585C5C597
97C5975F5F5F5F975F005F5F
2C2C2C00002C002C002C2C2C737373E1E1E12C2C2C00002C002C002C2C2C002C002C0000
0000005F5F5F7373734949495F975FB6B6B6C597972C2C2C2C2C2C2C2C2C2C2C2C2C0000
2C00000000005F5F5F737373FFEFC54949492C2C2C2C2C2C00002C002C0000002C5F975F
C5C5C5FFEFEF5F00002C2C2C5F975F5F975F5F9797737373A7A7A7EFC5C5002C00000000
4900002C0000002C000000002C2C2C97975F5F9797C5979700002C00002C2C2C2C2C2C2C
00002CEFC5C5975F5F2C2C2C002C00002C002C2C2C5F5F97A7A7A7C597972C2C2C2C2C2C
0000002C2C2C490000000000979797FCFCFC8585852C2C2C2C2C2C5F97C5EFFFEF2C2C2C
00000000002C5F5F5FA7A7A749000000002C2C00005F97979797972C2C2C2C2C2C97C5C5
49494997C5975F00002C2C2C002C005F97975F9797C5C5972C2C2C2C2C2C002C002C2C2C
2C2C2C5F5F5F979797C5C597EFC59700002C858585E1E1E1C5975F005F00002C002C2C2C
737373A7A7A7EFC5970049004949495F5F005F975F7373735F5F5F4949495F975FFFFFEF
FFEFC55F5F5F49000000002C002C002C2C2C979797A7A7A7FFFFC55F5F5F0049005F5F5F
49494997975FFFFFEF975F5F2C2C2C002C00005F5FEFEFC5EFEFEF5F000000002C00002C
2C0000000000000049979797EFC5C52C2C2C005F00FFFFFF2C2C2C00002CC5C5975F5F5F
2C2C2C00000097975F97C5972C2C2C00002C97979749494997975F494949FFEFEFFFFFC5
005F5F979797002C0000002CE1E1E197975F2C2C2C2C2C2C2C2C2C85858597979797975F
494949737373005F5F005F5F494949EFFFEF979797002C00002C002C2C2C000000490000
00002C00002C000049FFEFEFC5C5975F5F5F5F5F5F5F975F5F5F5F5F5F5F5F5F5F5F5F00
EFEFC5FCFCFCD4D4D49797972C2C2C2C2C2C2C2C2C0049009797975F5F5F494949494949
2C00002C2C2C7373738585852C2C2C7373730049005FC5C54949495F97974949492C2C2C
0049005F975F005F5F7373735F97975F975F000049B6B6B6494949002C002C2C2C979797
5F975F5F5F5F2C2C2CC5EFEF2C2C2CB6B6B6C5EFEF858585002C002C2C2C2C2C2CC5EFC5
5F975F0049002C2C2C2C2C2CC5C5C55F97975F5F5F2C0000FCFCFC2C2C2C494949C5C5C5
EFEFC57373735F5F5F002C002C2C2C00002CC5C59785858500490000002C002C005F5F5F
C5EFEFB6B6B6C5C5EF494949
2C000000002C2C0000000000494949FFEFC5002C002C2C2C2C00000049005F5F5F858585
737373737373494949004900D4D4D4EFC5C52C2C2C4900002C2C2C00002C2C000000002C
0000005F5F5F737373A7A7A7C597972C2C2C00002C00002C2C2C2C002C002C2C2C2C2C2C
E1E1E1FFEFEFEFC5974949495F5F5F5F5F5FC5C597EFEFC5FFEFEFC5975F2C2C2C2C2C2C
002C00002C002C2C2C002C005F975F494949FFEFEF2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
002C00C5EFC5A7A7A75F975F7373737373735F5F00B6B6B6FFFFEF2C2C2C2C2C2C2C0000
2C0000002C002C2C2C5F5F5F97C597FFEFC52C2C2C002C002C2C2C5F9797C5C5EF2C0000
00000000002C5F9797B6B6B62C2C2C00002C0049005FC5C549494900000000002C979797
97979797C5C5C5C597002C00000000A7A7A74949498585855F5F5F000000005F5F5F975F
4900005F97972C2C2C8585855F9797A7A7A7EFC5C55F97979797975F9797B6B6B6737373
2C2C2CC5C5C5C5C597EFC5C5EFC5C5EFC5C5FFFFC5EFEFC5C5C55FC5C597FFFFEFFFEFEF
005F5F2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C979797E1E1E1C5C5C5D4D4D4
A7A7A72C2C2C2C2C2C2C2C2C2C2C2C2C2C2C858585FFFFC52C2C2C2C2C2C002C002C2C2C
4949497373735F5F5FD4D4D497975F97C597FCFCFC5F0000002C00494949C5C5972C2C2C
0049009797979797972C2C2C97975F2C2C2C97975F97C5977373732C000000002CFFFFEF
FFFFC52C2C2C2C2C2C494949FFFFEF858585490000002C000000000000002C2C2CEFC5C5
C5C55F4949495F5F5F5F9797B6B6B6EFEFFF97C5C58585854949492C2C2C002C0000002C
002C00004900737373E1E1E1FFFFFFE1E1E1FFC5C5FFEFEFFCFCFCEFFFEFFFEFEFC59797
C5C5C5EFEFC52C2C2C0000002C2C2C005F5FC5C597C5C5974949494949492C2C2C2C2C2C
00002C5F5F009797975FC5972C2C2C5F975F005F5F737373005F5F49494900002C5F5F5F
4949495F97975FC59797C5C59797975F5F5F004900494949005F5F2C2C2C2C2C2C494949
C5EFEF97C597737373C5C5C52C2C2C004900975F975FC5975F5F5F2C2C2C2C2C2C858585
97C5977373730049000049002C2C2CEFFFEFC5EFC55F9797EFFFC54949490000002C2C2C
2C2C2CA7A7A797C5975F9797002C00002C002C2C2C737373C5C597C5EFEF97EFEF97C5C5
C5EFEF5F97974949495F5F5F
002C0000000000002C0000002C2C2CEFEFEFC55F5F0049005F975F5F975F5F5F5F5F5F5F
2C0000979797C5C5C5EFEFC5FFEFFFFFEFEF4949492C2C2C2C2C2C2C2C2C2C2C2C002C00
005F5F737373494949EFC5C52C2C2C2C00002C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C
A7A7A7FFEFEFEFFFEFC5C597C5EFC5EFFFC5FFEFC5C59797B6B6B6EFEFC5002C002C2C2C
002C00490000002C008585852C2C2C97C5C5975F5F2C2C2C2C2C2C002C002C2C2C002C00
00002C97C5C5C5C5C5B6B6B6FFEFEFFFEFEFFFFFEFFCFCFCFFFFEF002C002C2C2C00002C
2C2C2C490000005F5F2C2C2CC5C5C5494949002C00002C002C00005F97C5C5EFEF97975F
73737397C597E1E1E1C5975F002C002C0000005F5FB6B6B6002C0000002C2C2C2C858585
A7A7A75F9797C5EFC5975F0000002C979797002C000049005F97975F975F00002C2C2C2C
4949492C2C2C97975F002C002C2C2C737373979797EFEFC5FFEFC50000495F975F5F975F
979797FFEFFFC5975F494949002C00002C002C2C2C2C2C2C97975FEFC5C5EFC5C5EFEF97
494949494949002C002C2C2C2C2C2C2C2C2C2C2C2C5F5F5FC5EFC5EFFFEF4949492C2C2C
0000002C2C2C002C0000002C5F5F5F5F975FEFEFEF4949492C2C2C2C2C2C5F5F5F494949
5F5F5FB6B6B6B6B6B65F5F5FFFEFEFEFC5C500002C00000000002CC5C59700002C004900
49494997975F002C0097975FA7A7A700002C005F5F97975F49494900002C00002C494949
FFFFFFFFEF97004900494949FFEFC597975F5F5F5F2C00000000002C00002C0000000000
E1E1E1C5EFFFEFEFEFC5EFEF97C5C52C2C2CD4D4D4C5EFC54949495F5F5F5F975F494949
2C2C2C5F975FEFEFFFEFEFEFA7A7A72C2C2C2C2C2C4900002C00004900002C2C2C002C00
5F975FFFFFC5979797A7A7A75F975F5F975F5F975F5F5F5F2C2C2C002C002C2C2C494949
4949494949492C2C2C97C5972C2C2C5F97975F975F2C2C2C2C2C2C005F5F2C2C2C5F975F
0097975F97975F9797494949C597975F5F004949492C2C2CB6B6B65F5F5F2C000000002C
97C55F979797B6B6B697975F005F5F2C2C2C2C2C2CA7A7A75FC5975F5F5F0049002C2C2C
C5C5C597C5C57373734949492C2C2C5F975F2C2C2CD4D4D4EFEFEF97C5C5005F5F004900
00002C002C0097979797C5975F5F5F2C2C2C49494900975FC5FFC59797C5737373494949
2C2C2C5F9797A7A7A75F5F5F
002C002C2C2C2C2C2C4949495F5F5FE1E1E1EFC5C55F5F5F4949492C2C2C975F5FB6B6B6
9797977373732C2C2C2C2C2CB6B6B6FFEFEF2C2C2C2C2C2C2C2C2C002C0000002C494949
7373735F5F5FE1E1E149494900002C2C2C2C2C2C2C2C2C2C00002C2C2C2C00002C5F5F97
C5EFC5EFC5C5EFEFC5B6B6B6975F5F2C2C2C002C00002C00FFEFC5EFFFFF002C002C2C2C
002C00002C002C00008585855F975FFFEFC52C2C2C2C0000002C00002C0000002C2C2C2C
979797005F5FE1E1E1C5C5C59797977373732C2C2C000049FFEFFF2C2C2C2C2C2C2C2C2C
00002C2C2C2C5F975F97C597FFEFFF2C2C2C000000002C002C2C2C005F97C5EFEFFFFFEF
FFFFEFEFEFC5EFEFEFFFEFC52C2C2C2C2C2C737373B6B6B6002C002C2C2C0000005F5F5F
73737300002CD4D4D49797C5002C00C5C5970000002C2C2C979797858585C5975F2C2C2C
2C2C2C5F975F000049C5C5972C2C2C00002C0000495F975FB6B6B65F5F00002C00000000
2C2C2C858585D4D4D42C2C2C5F5F5F002C00002C002C2C2C0000002C00002C2C2CB6B6B6
E1E1E14949495F975F5F975F5F5F5F5F975F5F975FC5EFEFE1E1E197975F2C2C2C2C2C2C
2C2C2C2C2C2C5F5F977373735F5F00C5C597EFEFC5EFEFC5C5C59797975F97C59797C5C5
49494900002C2C2C2C979797FFFFEF0000002C2C2C2C2C2CC5C5C597C55F5F975F5F975F
002C0097975F0000005F5F5F5F005F5F5F0097C5C5EFFFC52C2C2C5F975F002C00002C00
5F5F5FFFFFEFFFFFEFFFFFEFFFFFFFEFC5975F975F2C2C2C002C0000000000002C00002C
002C00E1E1E1494949002C00002C00002C002C2C2C002C00A7A7A7E1E1E1C5EFC5A7A7A7
C5EFC5FFFFFF4949492C2C2C00002C00002C000000002C00002C00002C005F5F5FEFFFEF
C5EFEF7373732C2C2C2C2C2CC5C597B6B6B65F5F5F2C2C2C002C004949492C2C2C97C55F
4949494949492C2C2C97975F5F5F5F494949005F5F2C2C2C49494997975F4949495F9797
9797C59797C55F5F5F00002C2C2C2CC5C597494949494949858585B6B6B6C5EFC597C5C5
5F975F2C2C2C494949E1E1E1858585005F5F2C2C2C2C2C2CA7A7A77373735F975F2C2C2C
000049EFFFEFB6B6B6EFEFC5C5EFFF5F975F2C2C2C002C002C2C2C97979797C5975F975F
2C2C2C2C2C2C00002CC5EFEF97C5C5C5C5EF9797C5979797979797A7A7A7005F5F490000
002C002C2C2C4949495F5F5F
002C00005F5F5F97975F5F5F5F5F5FEFEFEFEFEFEFC5EFEFFCFCFCEFC5C55F5F5F2C2C2C
4900002C2C2C2C2C2C2C2C2C494949FFC5C5B6B6B6005F5F5F97975F9797737373494949
5F975FFFEFC5EFC5C52C2C2C002C002C2C2C002C002C2C2C00002C0049007373735F5F5F
FFC5C5A7A7A7004900002C002C2C2C2C2C2C2C2C2C2C2C2CB6B6B6C5EFEF49494997975F
8585855F975F8585855F975FEFFFEF49494900002C00002C2C000000002C2C2C2C005F5F
5F5F5FC5EFC52C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2CC5EFFF5F5F002C2C2C002C00
002C00005F5F737373EFEFEF5F5F5F2C0000002C00002C00000049737373FCFCFCFFC5C5
2C2C2C2C2C2C97C5C5EFEFC52C2C2C002C00858585B6B6B6002C0000002C2C2C2C5F5F5F
5F00004900005FC5C5A7A7A72C2C2CC5EFC52C00002C2C2C9797975F5F5F5F97975F5F5F
4949494949492C2C2C004900C59797979797002C0000002C005F5F97C59797975F2C2C2C
002C002C2C2C5F5F5FEFC5C52C2C2C494949002C00002C0000002C00000000002C2C2C2C
979797E1E1E1EFEFC5C5C5C5C5C597B6B6B6E1E1E1EFEFEFC5C5975F5F5F858585494949
7373734949492C2C2CA7A7A7C5C5C597975F002C00C5C5C5FFFFEFA7A7A7002C00002C00
2C2C2C00002C2C2C2CE1E1E100002C002C00D4D4D4FFFFEF5F5F5F5F005F5F975F2C2C2C
002C005F5F5F002C0000000097C55F97C5C597C5C5B6B6B6EFC5C58585858585852C2C2C
2C2C2CD4D4D4C59797494949FCFCFCFFEFC597975F5F975F5F5F5F2C00002C2C2C2C2C2C
2C2C2CC5EFEFC5C55F002C002C2C2C2C2C2C002C0000002C002C002C0000002C00EFEFEF
FFFFFF5F5F5F00002C2C2C2C2C2C2C005F00494949005F5F5F9797C5EFC5C5EFEFA7A7A7
002C00002C00A7A7A7C5C5974949492C2C2C2C2C2C002C00002C009797975F975F5F0000
4949495F975F5F9797494949737373005F5F494949494949005F5F5F9797979797A7A7A7
2C2C2C0049005F975F005F002C2C2C2C2C2C7373732C2C2C97C597494949494949A7A7A7
0000004949492C2C2C49494997C5975F97972C2C2C2C2C2C004900C5EFEF97EFC55F9797
494949C5EFC52C2C2C2C2C2C2C2C2CC5EFC58585852C2C2C2C2C2C2C2C2C5F5F5FEFC5C5
C5EFC597C5C597C5C5D4D4D497C597004900002C002C2C2C2C2C2C494949858585858585
005F5F0073005F5F5F5F5F5F
5F5F5F5F5F5F494949C5C5C5EFFFEFEFFFEFFFEFC5EFC5C52C2C2C002C002C2C2C2C2C2C
2C2C2C2C2C2C002C002C2C2C007300EFEFEFB6B6B6C5C5C5A7A7A7C5C597E1E1E1FFEFEF
FFEFEFEFFFEF4949492C2C2C00002C2C00002C2C2C00002C002C005F5F5F5F975FC5EFC5
B6B6B62C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C5F9797C5C5C5005F5F5F5F5F
2C2C2C5F5F5FC5EFC5EFEFC5E1E1E12C2C2C2C2C2C0000002C2C2C2C2C2C2C2C2C5F5F5F
97C597D4D4D4002C002C2C2C2C2C2C2C2C2C2C2C2C002C0097C5C5975F5F5F975F5F975F
737373858585FCFCFCC597972C2C2C00002C00002C00002C005F975F9797FFFFEF2C2C2C
002C002C2C2C5FC597FFEFC55F9797C5EFC5FFFFFFE1E1E12C2C2C00002C002C0097C5C5
002C00002C002C2C2C97C597A7A7A7B6B6B62C2C2C002C0097975F2C2C2C005F5F5F975F
2C2C2C2C2C2C2C2C2C4949495F5F00858585C5C59797975F2C2C2C49494997C55F979797
B6B6B65F975F0000005F5F5FEFC5C55F5F5F2C2C2C00002C002C002C2C2C2C000000002C
004900C5C5C5E1E1E1975F5F5F5F5F4949492C2C2C494949EFEFC5E1E1E15F5F5F5F975F
C5C597C5C597A7A7A7490000002C002C2C2C5F9797FFEFC5A7A7A72C000000002C2C2C2C
2C2C2C5F9797D4D4D4494949002C00FFFFFFEFC5C5002C00002C005F97974949492C2C2C
2C2C2C97975F494949002C00A7A7A797C5C55F5F5F00002CB6B6B6C5C5975F97975F975F
002C00B6B6B65F5F5F2C2C2C5F5F5FA7A7A7FFEFC597975F5F975F5F975F002C00002C00
5F9797D4D4D4D4D4D42C2C2C2C2C2C00002C2C2C2C002C00002C00002C00002C005F5F5F
FFFFFF005F5F5F5F5F5F5F5F005F005F5F5F979797FFEFC5C5C5EFC5C5C500002C002C00
5F5F5FA7A7A79797974949492C2C2C2C2C2C2C2C2C9797974949497373734949495F5F5F
2C2C2C97C597737373494949494949494949005F5F5F975F5FC597A7A7A75F5F5F5F975F
4949492C2C2C9797975F5F5F2C2C2C2C2C2C97C5975FC5979797975F5F5F2C2C2C004900
C5EF975F5F5F2C2C2C2C2C2C9797975FC597737373005F5F4949495F975F002C00858585
E1E1E1C5C5975F5F5F2C000000002C002C00C5EFC55F97975F975F0049002C2C2C979797
A7A7A7A7A7A7737373494949A7A7A75F975F5F975F2C2C2C2C2C2C2C2C2C005F5F005F5F
97975F5F97975F5F5F5F5F5F
5F5F5F858585EFC5C5EFEFEFE1E1E1A7A7A72C2C2C2C2C2C00002C00002C2C2C2C002C00
490000002C002C2C2C7373735F0000E1E1E1FCFCFCFFEFEFFFEFEFEFC5C52C2C2C002C00
EFEFEFEFEFEF2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C4949495F5F5FC5C5C5C5C5C5
2C2C2C00002C2C2C2C2C2C2C2C2C2C00002C2C2C2C002C00C5C5C5EFC5EFEFFFFFFCFCFC
E1E1E1D4D4D4975F5FC5EFEFEFFFEF2C2C2C2C2C2C49000000002C2C2C2C73737300975F
FFEFEF4949492C000000002C2C2C2C2C2C2C002C0073737397C5C5C5FFC5C5EFEFC5EFEF
FCFCFCFCFCFCFFEFEFEFC5C52C2C2C00002C00002C005F5F5F975F97C5C5C59797002C00
2C0000000000494949FCFCFCFFFFEFA7A7A75F5F5FEFC5EF2C2C2C00000000002CB6B6B6
000000002C00000000C5C597B6B6B65F979797975F494949C5EF972C2C2C2C2C2C737373
97C5C54949492C2C2C2C2C2C2C2C2C975F5F002C00A7A7A797C597A7A7A74949492C2C2C
737373737373979797C5C597D4D4D4C5C5975F5F002C2C2C5F5F5F4949495F5F5F494949
737373FFFFC52C2C2C0000002C2C2C002C0000002C00002C00002C2C2C2CFFFFC55F5F5F
00002C002C00002C0000002C2C2C2C73737397C597C5C5C500002C2C2C2C494949737373
494949B6B6B6D4D4D4C5C597FCFCFC5F5F5F00002C002C000073005F975F2C2C2C494949
00002C979797737373002C005F5F5FC5EFC55F5F5F002C002C2C2CFFFFEF9797972C2C2C
494949E1E1E15F5F00002C0000002C2C2C2C2C2C2CB6B6B697975F5F975F2C2C2C2C2C2C
49494997C5C5B6B6B6C5C5C57373735F5F5F000000002C002C2C2C005F5F979797B6B6B6
C5C5C5C5C5C5A7A7A7858585975F5F737373737373C5C5C57373735F9797979797858585
85858597975F2C2C2C2C2C2C2C2C2C2C2C2C97975F7373735F5F5F005F5F4949495F9797
5F5F5F4949497373732C2C2C494949494949494949858585A7A7A75F975F00002C494949
5F5F5F0049004949495F975F005F5F5F5F5F5F97975F5F5FB6B6B6494949494949494949
B6B6B600975F7373732C2C2C2C2C2CC5EFEFEFFFC55FC597B6B6B62C2C2C00002C2C2C2C
2C00005F5F5F97C5975F979700490000002C2C2C2CEFC5C5C5C5EFE1E1E1C5EFEFC5C5C5
C5C5C5005F5F0000494949492C2C2C2C2C2C4949495F975F5F000049494997C5975F5F5F
0049005F975F494949494949
C5C597EFEFC5D4D4D4EFEFEF5F97972C2C2C2C2C2C002C002C2C2C2C2C2C002C002C0000
2C2C2C2C2C2CA7A7A7005F5FFFEFEFEFC5C5EFC5C52C2C2C2C2C2C00002C00002C00002C
97C5C5E1E1E1975F5F7373735F5F5F5F975F5F5F5F5F975FB6B6B6C5EFC5FFEFC5494949
2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2CA7A7A7C5C597EFC5C59797972C2C2C
49000000002C00002C5F5FC5EFC5FF2C2C2C2C2C2C00490073737385858597975FC5C5EF
C5C5C52C2C2C2C00002C2C2C00002C00002C5F975F979797C5FFEF9797977373732C2C2C
2C2C2C2C2C2C5F5F97FFFFFF2C2C2C2C2C2C2C2C2C7373735F9797FFFFEF2C2C2C2C0000
002C00002C005F9797FFEFEF49494900002C5F005FC5EFEFC5975F4949495F975FC5EFC5
494949002C0000002CA7A7A72C2C2C005F5FA7A7A7B6B6B6C5C5C5490000002C005F975F
005F5F5F5F00002C002C2C2C2C2C2C005F5F5F5F5F002C002C2C2C2C2C2CA7A7A72C2C2C
2C0000002C005F5F5F5F979797C5C59797C597975F858585A7A7A7B6B6B6C5C5C5B6B6B6
D4D4D4C5975F5F975F2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2CA7A7A7979797000000
0000000000002C2C2C2C2C2C737373A7A7A7FFFFEF2C2C2C2C2C2C8585855F5F5FC5EFC5
C5C5C52C2C2C5F5F5FFFFFEF2C2C2C00002C2C2C2C005F0097C5972C2C2C4949495F5F5F
0000002C2C2C5F5F5F5F5F5F2C2C2CB6B6B65F5F5F002C00000000979797EFC5C5494949
000049EFEFEF5F5F5F2C2C2C2C2C2C00002C00002C2C2C2CB6B6B6FFEFC5858585858585
97C597EFEFEFEFC5C5E1E1E1EFFFC57373737373735F5F5F858585A7A7A7FCFCFCB6B6B6
4949490000000000000000002C2C2C00490097C5C5E1E1E1737373494949004900C5C55F
9797974949492C2C2C0000005F975F4949492C2C2C005F5F494949005F5F005F5F5FC597
5F975F2C2C2C97975F4949492C2C2C5FC5975F97975F97972C2C2C979797494949494949
5F975F494949005F5F4949498585855F97975F5F004949494949498585857373732C2C2C
2C2C2CD4D4D45F97975F9797005F5FC5C5C52C2C2C2C2C2CB6B6B6C5EFC5737373494949
002C002C2C2C002C0097C597B6B6B6005F5F5F975F858585EFFFEF5F97972C2C2C2C2C2C
2C2C2C2C2C2C5F5F5F005F5F4949492C2C2C5F975F5F975F97975F2C2C2C9797C5A7A7A7
85858549494900002C005F5F
00002C2C2C2CC5C5C5E1E1E15F97975F5F5F5F5F5F4949492C2C2C2C2C2C002C002C2C2C
5F97975F975F97EFC5EFC5C5C5C5C5975F5F2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C
5F9797EFFFEFEFEFC5C5EFC5C5C5C5C5C5C5C5C5C5C5C5C5B6B6B6E1E1E12C2C2C2C2C2C
2C2C2C002C000000002C2C2C0049005F5F5FB6B6B65F97975F5F5F2C2C2C2C2C2C490000
2C2C2C2C2C2C2C2C2C5F005FE1E1E149494985858573737385858597979797C5C5FCFCFC
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C4949495F979797EFC5975F5F2C2C2C2C2C2C000000
00002C0000005F5F97E1E1E17373735F5F5F858585E1E1E1FFEFFF4949490000002C0000
002C00005F5F97C5C5FFEFEF0000002C0000002C0097C5C5C5C59797975FB6B6B6E1E1E1
2C2C2C00002C002C0097C5C5002C00002C00A7A7A7A7A7A75F97975F5F5F2C2C2C5F975F
2C2C2C00975F5F5F5F00002C4949492C2C2C4949495F975F97975F4900002C2C2CA7A7A7
97975F2C2C2C002C002C2C2C490000B6B6B67373735F975F00002C2C2C2C002C002C2C2C
2C2C2CD4D4D4C5C5978585855F5F5F7373738585855F5F5FC5C5C5EFEFC58585855F975F
2C2C2C4949499797975F5F5F979797C5C597FFEFEFFFFFEF97C597B6B6B6C5C5C5490000
00002C2C2C2CC5FFEFC597972C2C2C49494997C5C597C5975F975F5F5F5F002C00C5C5EF
2C2C2C002C007373735FC55F97C5C5C5C5C52C2C2C5F5F5F2C000000002CE1E1E1FFEFFF
FCFCFCFFEFFF97975F5F9797002C0000002C00002C000000000000FFFFC5E1E1E15F5F5F
5F5F5F002C00002C00002C002C2C2C2C2C2C979797FFFFEFFFEFEFEFEFFF2C000000002C
00002C00002C002C005F5F5F000049E1E1E1E1E1E149494900002C2C2C2CC5C5C52C2C2C
494949002C002C2C2C97975F2C2C2C494949005F5F5F5F5F4949495F97977373735F5F5F
494949494949737373494949005F5F5F97974949495F975F4949494949492C2C2C005F5F
7373735F97975F5F975F5F5F5F5F5F2C2C2C5F975F5F5F5F494949005F5F97C5975F975F
2C2C2CC5C5C5B6B6B6C5C5C55F97C597C55F005F5F00002C002C002C2C2CA7A7A7858585
5F5F5F2C2C2C002C005F0000E1E1E1A7A7A7A7A7A7C5C597C59797005F5F004900494949
2C2C2C4949492C2C2C2C2C2C9797972C2C2C5F97977373735F5F5F9797972C2C2C737373
975F5F002C005F5F5F5F5F5F
A7A7A75F5F5F97C5C5FFEFC5975F005F5F5F7373735F5F5F5F5F5F5F5F5F7373735F5F5F
979797FFEFEFB6B6B68585852C2C2C0000492C2C2C2C2C2C00002C000000005F97737373
97C5C5EFEFEFFFEFEF979797494949002C002C2C2C2C2C2C97C5C5C5C5C55F5F002C2C2C
2C2C2C2C2C2C002C002C2C2C737373858585B6B6B65F5F0000002C00002C2C2C2C00002C
4900002C2C2C002C00737373E1E1E1975F5F97C597C5EFC5D4D4D4C5C5C5B6B6B6FFEFEF
002C000000002C2C2C00002C2C2C2C9797975F975F8585854900002C2C2C2C2C2C00002C
002C002C2C2CC5C5C5C5EFEFEFFFEFFFFFFFFFEFEFFCFCFCFFFFEF2C2C2C002C002C2C2C
4900005F97C5FFEFEF5F5F00002C0000002C002C005F5F97C5C597737373005F97C5EFEF
2C2C2C490000005F5FC5C5C5002C00490000A7A7A72C2C2C005F5F97C597494949C5EFEF
2C00004949494949494949494949495F5F004949495F5F5F4949495F975F97975F494949
5F975FC5C5970049002C2C2C2C2C2C5F005FD4D4D42C2C2C2C2C2C0000002C2C2C2C0000
002C00494949A7A7A7C5C5C5EFC5C5B6B6B6EFC5C5C5C5C5E1E1E1EFEFEFEFFFEF737373
4949492C2C2C97975FC5C5C59797972C2C2C494949B6B6B6EFEFC57373732C0000002C00
000049858585EFFFEF004900B6B6B6E1E1E14949494949497373734949492C2C2CA7A7A7
5F975F2C000000002C97C5C52C2C2C975F5FEFC5C55F5F5F5F5F5F00002C5F9797C5EFFF
858585858585FCFCFC5F5F5F7373732C2C2C00002C000000000000737373EFFFEF004900
000000002C0000000000002C00002C00002C2C2C2CB6B6B6EFC5C500002C4949495F5F5F
5F975F5F975F494949C5EFC5E1E1E1B6B6B62C2C2C2C2C2C858585C5979700002C2C2C2C
2C2C2C2C2C2C002C004949494949494949495F5F5F5F975F5F97975F5F5F5F5F5F5F5F5F
005F5F494949005F5F5F97975F97975F975F2C2C2C7373734949494949495F9797737373
5F9797494949737373A7A7A74949492C2C2C2C2C2C9797974949492C2C2C97005FE1E1E1
737373A7A7A7005F5F4949492C2C2CA7A7A75F97975F975F2C2C2C2C2C2C2C2C2CD4D4D4
C5EFEF97EFC597C5C597C5C5C5EFFF2C2C2C2C2C2C2C2C2C2C2C2C4949495F5F5F5F5F5F
005F5F5FC59797C5977373732C2C2C5F97972C2C2C97975F5F5F5F2C2C2C5F5F9797C597
005F5F97C597A7A7A7494949
97C5C5C5C5C5C5C5C5C5EFC5D4D4D4EFEFC5C5EFC5E1E1E1EFEFEFFFFFEFEFEFEFEFEFEF
A7A7A75F5F5F2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C0049005F9797494949D4D4D4
D4D4D45F5F5F2C2C2C00002C2C00002C2C2C2C2C2C494949D4D4D4FCFCFC7373735F975F
737373737373737373979797EFEFEFEFEFFF2C2C2C2C2C2C00002C002C0000002C00002C
2C2C2C0049005F9797979797C5C5C5EFEFC5C5C5C5975F5F2C2C2C2C0000979797EFEFFF
0049000000000000002C2C2C97975F5F5F5FEFC5C52C2C2C2C2C2C2C2C2C00002C00002C
0000495F5F5FC5EFEFD4D4D42C2C2C2C2C2C2C2C2C002C00FCFCFC004900007300737373
5FC5C5FCFCFCFFC5C5002C00002C002C0000005F5FEFEFC5C597972C2C2C2C2C2CE1E1E1
494949002C00A7A7A7C5C5C5002C00002C0097C5C5002C002C2C2C97C597A7A7A7737373
4949494949494949495F5F5F97C5974900002C2C2C4949495F5F5F002C00002C005F975F
5F5F5F5F5F5FC5C5C5D4D4D4A7A7A700002C737373EFEFEF97C59797C5979797975F975F
5F5F5F979797EFEFEFEFC5C52C2C2C00002C2C000000000000002C49000097975FB6B6B6
B6B6B6D4D4D4975F5F002C002C2C2C2C2C2C979797E1E1E100002C2C2C2C2C2C2C5F5F5F
858585EFEFEFC5EFC5FFFFEFE1E1E10000000000002C2C2C5F5F5F2C2C2C002C00979797
5F97C52C2C2C00002C97C5C5005F002C2C2CA7A7A7B6B6B65F5F5F2C00002C2C2CC5C5EF
5F97972C2C2C00002CC5C59797975F5F5F5F5F5F5F0000002C2C2C00002CEFEFEF97C5C5
002C002C2C2C2C2C2C00002C2C2C2C2C2C2C5F9797B6B6B6C5C5C5C5C5C5FFEFC5EFC5C5
97C5C5A7A7A7C5C5C54949495F005F005F00737373737373494949A7A7A72C2C2C00002C
0000495F5F5F49494949494900975F005F5F5F97975F5F5F4949495F5F5F2C2C2C494949
4949499797978585855F5F5F4949495F975F494949494949737373005F5F5F9797494949
975F5F5F5F5F4949494949497373734949494949495F005F97C5C50049005F5F5F005F5F
979797C5C5C57373734949492C2C2C2C2C2C002C0097C5975F97972C2C2C2C2C2C9797C5
9797C59797975F5F5F2C2C2C49494949494949494900002C2C2C2C0049005FC597C5C5C5
975F5F005F5FA7A7A75F5F5F5F975F002C00737373B6B6B62C2C2C0000495FC5975F97C5
9797972C2C2C00002C005F5F
2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C00002C4949495F5F5F5F9797EFC5C5EFC5C5
9797975F5F5F5F5F5F005F974949495F5F5F49494900975F8585855F5F5FE1E1E1E1E1E1
5F5F0049000000002C00002C2C2C2C00002C2C2C2C5F9797D4D4D4FFEFEFA7A7A7C5C5C5
C5C5C5C5C5C5C5C5C5D4D4D4EFEFFFFCFCFC2C2C2C002C00002C0000000000002C00002C
5F5F5F97975FA7A7A7C5C5C55F5F5F00002C2C2C2C002C002C2C2C2C2C2C5F9797E1E1E1
73737373737397C597A7A7A7FCFCFCEFFFEF5F5F0000002C0000002C2C2C2C2C2C2C2C2C
5F5F5F5FC597C5EFEF5F5F5F00002C2C2C2C2C2C2C2C2C2CFFFFEF7373738585859797C5
C5C5C5FFEFEF2C2C2C2C2C2C00002C2C2C2C5F9797FFEFC5002C0000002C002C00E1E1E1
5F5F5FA7A7A7D4D4D4A7A7A72C2C2C2C2C2C97C5C52C2C2C00002C979797002C002C2C2C
49494997C597002C00005F5F49494997C55F2C2C2C2C2C2C4949495F5F5F2C2C2C2C2C2C
85858597975F002C002C2C2C858585C5C5C5D4D4D4EFEFC52C2C2C858585B6B6B6EFEFC5
B6B6B6FFEFEF8585855F97972C2C2C2C2C2C002C000000002C2C2C2C2C2C002C00494949
FFEFEF4949492C2C2C000000005F5F858585C5EFC55F5F5F494949005F5F5F975F494949
EFFFEFA7A7A7A7A7A7FCFCFC2C2C2C2C2C2C002C0097C5972C2C2C00490097975F858585
9797975F5F5F2C0000C5EFEF97C5972C2C2C00002CA7A7A7C5C5972C2C2C002C00C5EFEF
5F979700002C00000000002C737373C5C5975F5F5F5F9797979797979797B6B6B6EFFFC5
5F5F004949497373735F5F5F5F005FC5C5C5FCFCFCFFEFEF2C2C2C00000000002C002C00
494949C5FFFF97C5C597C5C597979797975F979797C5C59749494900002C002C002C2C2C
5F5F5F494949494949005F5F5F5F5F5F97975F97975F5F5F2C2C2C4949492C2C2C737373
7373737373732C2C2C858585005F5F494949005F5F49494973737385858597C5C55F5F5F
4949498585854949494949494949495F975F2C2C2C4949495F5F5F979797A7A7A7000049
2C2C2C494949B6B6B65F97975F975F2C2C2C2C2C2C2C2C2CE1E1E1C5EFC597C5C5C5C5EF
5F975F4949492C2C2C2C2C2C2C2C2C004900005F005F97978585857373738585852C2C2C
8585852C2C2C005F5F5F5F5F002C007373735F97972C2C2C73737397C59785858597975F
494949002C004900005F5F5F
2C2C2C2C2C2C2C2C2C0000002C2C2C2C2C2C005F5F5F9797B6B6B697C5C5E1E1E1EFEFEF
D4D4D4E1E1E1D4D4D4C5EFC5C5EFC5C5C5C5EFC5C5D4D4D4E1E1E1EFEFEFD4D4D45F9797
2C2C2C002C002C2C2C2C00002C2C2C5F975F5F97C55F5F5FC5C5C5E1E1E1B6B6B6A7A7A7
2C2C2C2C2C2C2C2C2C2C2C2CFFEFFFFCFCFC002C002C2C2C002C002C00000000495F975F
858585B6B6B6C5C5C52C2C2C2C2C2C2C2C2C0000000000002C2C2C00002C97C5C5FFEFEF
B6B6B6EFC5C5EFC5C5D4D4D4A7A7A7FFFFEFFFC5C500000000000000002C2C2C2C2C2C2C
737373C5C5FFC597972C2C2C00002C002C002C2C2C2C2C2CFFFFEFFFFFEFFFFFEFFCFCFC
E1E1E1EF975F2C2C2C00002C002C005F9797FFEFC5C597972C2C2C2C2C2C004900EFEFC5
FFFFC5858585C5C5C54949490000005F5F5F858585002C002C2C2C5FC5C52C2C2C002C00
A7A7A75FC5C52C2C2C5F975F4949494949494949492C2C2C2C2C2C2C2C2C4949495F5F00
00490073737397C5972C2C2C2C2C2C002C00A7A7A797975F979797004900002C002C2C2C
2C2C2C979797C5EFC5EFEFC55F975F5FC55F5F5F5F8585855F975F5F5F5F5F5F5FE1E1E1
97975F5F975F494949737373494949C5EFC5FFFFEF5F97008585855F975FC5EFC5A7A7A7
00002C005F5FC5EFEF00002C2C2C2C004900B6B6B67373735F975F2C2C2CA7A7A700002C
97975F97C5C55FC5C5C5C5C5FCFCFC2C2C2C002C002C2C2CB6B6B6FFEFC597975FC5EFEF
5F5F5F2C2C2C0000002C2C2C00002C979797FFEFC5D4D4D4C5C5C55F5F5F5F0000494949
A7A7A7B6B6B6C5C597C5C597FFFFFFFFFFFF4949490000002C2C2C002C00002C00002C00
97C5C5EFEFEF2C2C2C2C2C2C00002CA7A7A7C597972C2C2C00002C2C2C2C494949005F5F
4949495F5F5F494949005F5F7373735F5F5F5F5F5F5F97974949495F975F8585855F9797
4949495F975F4949494949495F975F005F5F005F5F737373005F5F494949494949737373
494949005F5F5F97974949492C2C2C97C55F8585855F97975F5F5F2C2C2C2C2C2CB6B6B6
00975F002C002C2C2C494949D4D4D4A7A7A75F979797C5C5C5EFEF5F97972C2C2C2C2C2C
2C2C2C2C2C2C5F5F5F49494949494900002C5F97978585859797975F975F7373735F5F5F
2C2C2C2C2C2C005F5F2C2C2C2C2C2C8585850049005FC597975F5F2C2C2C4949495F975F
73737300002C2C2C2C494949
2C2C2C2C2C2C5F5F5F5F5F5FB6B6B697C5C5C5C5C5C5EFC5FFEFC5B6B6B62C2C2C2C2C2C
2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C005F5F5F5F5F979797C5C5C5FFEFEFD4D4D4
97C5C58585855F97975F979797C5C597975FEFFFEFE1E1E1975F5F2C2C2C49000000002C
00002C2C2C2C2C2C2C005F5FEFEFEFFFFFFF979797858585858585979797A7A7A7FFEFC5
C5C5C5EFEFC52C2C2C2C00002C2C2C2C000000002C2C2C2C4949492C2C2CA7A7A7A7A7A7
002C00490000002C002C2C2C2C2C2CC5C5C5FFC5C5002C002C000000002C004900858585
E1E1E19797972C2C2C002C002C2C2C002C00005F5FC5EFC5C5EFFF7373732C2C2C2C0000
000049FFFFEF5F97975FC5C5A7A7A7737373FFFFFF2C2C2C2C2C2C2C0000979797FFEFFF
2C2C2C00002CE1E1E15F5F5F002C005F9797975F5F002C002C2C2C5F97C52C00002C2C2C
002C004949495F5F0097975F2C2C2C002C004949499797004949492C2C2C004900005F00
A7A7A75F9797B6B6B6C5C59785858500002C2C2C2C494949C5C55F5F5F5F002C00002C00
2C2C2C00002C000000C5C597B6B6B6EFFFC5C5EFC5EFEFC5EFEFC5D4D4D4D4D4D4EFC5C5
EFEFC5979797858585B6B6B6A7A7A75F0000494949FFFFEFE1E1E1C5C5C5002C002C2C2C
002C00C5EFC52C2C2C2C00005F9797B6B6B6A7A7A75F5F5F494949002C00858585494949
2C2C2CB6B6B6A7A7A72C2C2C5F9797EFC597002C00000000005F5FB6B6B6B6B6B6A7A7A7
C5C5975F975F00002C2C2C2C002C00000000E1E1E1C5EFEF2C2C2C00002C2C2C2C002C00
2C2C2C2C2C2C004900FFFFEF975F5F2C2C2C4949494949495F975F5F5F975F9797C5C5C5
FFEFEF2C2C2C002C005F5F5FC5C5974949492C2C2C00002C004900005F5F494949494949
5F5F5F00975F5F97974949495F5F5F2C2C2C4949497373734949495F97975F97975F975F
4949492C2C2C0049004949495F5F5F5F5F5F5F5F5F2C2C2C4949492C2C2C494949494949
4949494949498585855F97975F5F5F97C5972C2C2C2C2C2CA7A7A75F975F2C2C2C494949
5F5F97D4D4D4C5EFC597C597D4D4D45F5F975F97975F97974949492C2C2C5F5F005F5F5F
7373735F5F5F005F005F975F005F5F005F5F5F975F2C2C2C0000497373737373732C2C2C
0000495F5F5F5F975F4949495F979797C5C55F97C55F975F2C2C2C002C0097C5975F975F
2C2C2C2C2C2C4949495F5F5F
2C000000002C0000002C2C2C00002C494949005F5F4949490000492C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C0000492C2C2C97975F9797975F9797858585D4D4D4EFEFEFD4D4D4
EFEFC5D4D4D4C5C5C5B6B6B6C5C5C5E1E1E1FFEFC50049002C2C2C2C2C2C2C2C2C00002C
00002C5F5F5F5F9797737373FCFCFCFFEFEFEFFFEFEFFFEFE1E1E1B6B6B65F5F5F5F5F5F
FFEFEFFFFFEF2C2C2C00002C2C00002C000000002C002C002C2C2CB6B6B69797972C2C2C
2C0000002C002C00002C000000002C97C5EFEFEFC597975F5F5F5F5F5F5F5F975FFFEFEF
D4D4D42C2C2C2C00002C00000000005F5F5FA7A7A7C5EFEF49494900002C2C00002C2C2C
00002CFFFFEF97975FFFEFEFFFFFEFFFFFFFC597972C2C2C2C2C2C5F9797B6B6B6EFC597
2C2C2C2C2C2CFFEFEF5F5F0097C597C5EFC5C5975F2C2C2C005F5F975F5F00002C5F9797
2C2C2C00002C979797A7A7A75F5F5F2C2C2C5F5F5F5F975F2C00002C2C2C002C005F5F5F
4949492C2C2CC5C597494949A7A7A7B6B6B697975F494949979797EFEF975F975F737373
5F975F5F5F5F4949495F5F5FEFEFC5975F5F2C2C2C2C000000002C2C2C2C2C2C2C2C2C2C
B6B6B6E1E1E1B6B6B649494900002C00002C004900EFEFEFC597974949492C2C2C5F5F5F
EFFFEFEFFFEFEFFFC5C5C5C5E1E1E10000004949495F5F002C2C2C5F000097C597A7A7A7
002C0097C59797C5C50000002C2C2C97C5C5737373002C00494949EFFFC52C2C2C2C2C2C
979797A7A7A75F5F5F0000005F5F00005F5F858585EFEFC5B6B6B65F975F5F5F5F5F5F00
2C2C2C4949495F5F5FE1E1E1C5C5C597C59797C59797C597A7A7A7C5EFEFE1E1E1C5C597
00002C97975F5F975F2C2C2C2C2C2C2C2C2C2C2C2C494949005F002C2C2C005F5F5F5F5F
5F5F007373735F5F5F494949005F5F2C2C2C4949497373735F97975F975F4949495F5F00
005F5F005F5F5F5F5F5F975F5F9797494949005F5F5F975F2C2C2C494949494949005F5F
8585855F9797C5C5C52C2C2C494949A7A7A72C2C2C2C2C2C2C2C2C858585B6B6B65F975F
2C2C2CA7A7A7005F5F005F5F7373738585855F5F00005F5F2C2C2C2C2C2C002C0097975F
0049005F97975F97978585855F5F5F7373732C2C2C00002C73737397975F002C002C2C2C
5F975F97975F00002C9797972C2C2C00002CA7A7A75F5F5F00002C2C2C2CC5C597737373
2C2C2C2C2C2CA7A7A75F5F5F
2C2C2C0000000000002C2C2C4900002C00002C00002C2C2C5F9797737373005F975F5F97
5F97975F979797C5C597C5C5B6B6B6C5C5EFC5EFEFC5EFFFC5EFEFA7A7A77373732C2C2C
2C2C2C7373735F5F5F737373858585EFEFC5EFEFC55F975F7373735F5F5F5F5F5F005F5F
5F97C55F5F5F5F5F5FEFEFEFFFC5C52C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C494949
FFEFEFFFC5C52C2C2C2C2C2C5F5F005F5F5F5F975F5F975FD4D4D4975F5F2C2C2C00002C
2C2C2C490000002C004949495F5F5FEFEFC5EFFFFFEFEFEFD4D4D4D4D4D4C5EFC5D4D4D4
975F002C2C2C2C0000002C0000004997C5C5C5FFEF2C2C2C2C2C2C002C0000002C004900
494949FCFCFCD4D4D4858585000049FFFFEF2C2C2C002C005F97975F975FFFFFEF2C2C2C
00002C494949C5C5C5FFFFC597975F5F5F5FEFC5C5C5EFC5C5EFC549494900002CA7A7A7
002C00002C0097975F5F5F5FA7A7A70049005F5F5F2C2C2C7373732C2C2C005F5F494949
5F975F2C2C2C49494997C55F49494949494997975FC5C597C5EFC5C5EFC5C5EFC5B6B6B6
C5EFC5EFEFC5C5EFC5EFEFC5FCFCFC8585852C2C2C00002C2C2C2C2C2C2C002C002C2C2C
5F5F97FFFFC52C2C2C2C2C2C0049005F5F5FC5C5C5A7A7A700002C494949C5EFC5E1E1E1
494949494949FFFFEF5F5F5F4949492C2C2C7373735F5F5F2C2C2CC5975F490000979797
B6B6B6C5C5C5A7A7A72C2C2C2C2C2C494949979797494949005F5FC5EFC52C2C2C2C2C2C
2C2C2C5F5F5FA7A7A75F9797737373A7A7A7D4D4D4FCFCFCE1E1E1B6B6B697C59797C55F
5F975FC5C5C5FFEFEFC5C5C5EFC5C5A7A7A75F5F5F002C00E1E1E197C5EFA7A7A7A7A7A7
85858573737397975F2C2C2C00002C2C2C2C5F975F4949494949495F5F5F005F5F5F5F97
737373494949005F5F2C2C2C7373732C2C2C5F97974949494949494949495F5F5F2C2C2C
5F5F5F494949737373494949005F5F5F975F2C2C2C4949495F5F5F5F5F975F97975F9797
005F5F2C2C2C5F5F5F5FC55F00002C2C2C2CA7A7A797C597005F5F2C2C2C00005F2C2C2C
858585B6B6B6A7A7A79797974949494949492C2C2C2C2C2C5F5F5F5F975F5F975F97C597
5F5F5F8585852C2C2C4949498585852C2C2C2C2C2C5F5F5F5F975F002C005F5F5FA7A7A7
5F975F5FC55FC5C5977373732C2C2C2C2C2CC5C5977373732C2C2C4949499797975F975F
000049494949EFC5C55F5F5F
00002C000000490000000000002C00002C002C2C2C2C2C2C2C2C2C002C002C2C2C494949
4949495F5F5F8585855F5F975F5F5F5F5F5F005F5F4949492C2C2C00002C2C2C2C2C2C2C
00002C005F5F2C2C2C5F5F5FA7A7A7D4D4D4EFEFC5B6B6B6C5C5C5979797A7A7A7A7A7A7
97975FEFEFEFEFEFC52C2C2C002C002C2C2C00002C00002C00002C00002C000000005F5F
D4D4D4EFEFC5979797B6B6B6C5C597E1E1E1FFFFEFFFEFC5C5EFC52C2C2C002C00000000
2C00002C2C2C005F5F5F975F97979797C5C54949492C2C2C2C2C2C2C2C2C000049C5C5C5
EFC55F2C000000002C49494997C597EFEFEF5F5F5F002C002C2C2C002C00000000858585
EFFFC597975F2C2C2C2C2C2C2C2C2CC5FFFF97975FA7A7A75F975FEFEF97C5975F2C2C2C
2C2C2C5F9797FFFFFF2C2C2C002C002C2C2CD4D4D45F9797B6B6B62C2C2C2C2C2C5FC597
2C2C2C2C2C2C858585000000A7A7A7005F005F975F2C2C2C5F5F5F5F5F5F2C2C2C494949
2C2C2C5F5F005F5F00005F5F97C5972C2C2C2C2C2C2C2C2C494949C5C5C597975F002C00
002C002C2C2C2C2C2C2C2C2CA7A7A7C5EF975F5F5F5F97978585855F975F858585979797
FFEFC57373734949495F5F5F97975F5F5F00D4D4D4E1E1E1EFEFEFEFEFC5494949005F5F
49494997C597C59797494949A7A7A797975F5F975F005F5F97975F97C5C5002C005F9797
A7A7A7858585A7A7A75F975F000000002C00C5EFEFB6B6B697C5C5C5EFEF5F5F002C2C2C
002C0000002C005F00C5C597E1E1E14949494949492C2C2C002C002C2C2C2C2C2C2C2C2C
FFEFFF49494900002C2C2C2C00002C2C2C2C2C2C2C2C2C2C97C5C59797972C2C2C2C0000
97C55F97975F2C2C2C002C00002C002C2C2C5F5F00494949005F5F005F5F5F5F97858585
5F5F5F002C007373732C2C2C8585858585855F975F5F5F5F4949492C2C2C5F975F5F5F5F
5F97977373737373734949492C2C2C4949495F5F007373735F97975F9797A7A7A72C2C2C
5F5F5F5F975F2C2C2C4949497373735F5F5F2C2C2C000049979797858585B6B6B697C5C5
5F5F5F2C2C2C005F5F2C2C2C00490073737300002C5F975F97C597C59797737373494949
97975F002C00002C0097975F5F975F0049005FC59773737397C5972C2C2C9797972C2C2C
2C2C2CA7A7A7A7A7A75F975F2C2C2CB6B6B65F5F5F2C2C2C002C00A7A7A75F975F494949
2C2C2CC5C5C5B6B6B6494949
0000002C000000002C002C005F005F002C002C2C2C2C2C2C002C00002C00002C00002C00
0000002C000000002C2C2C2C4949495F5F5F005F5F8585857373735F9797979797A7A7A7
97C5C5C5EFC5C5C5C5C5EFC5E1E1E1D4D4D4858585979797B6B6B6EFEFC5D4D4D4C5EFC5
C5C5C5D4D4D45F5F5F4949494949492C2C2C2C2C2C2C2C2C002C005F00005F97975F5F5F
EFEFEFD4D4D48585859797975F5F5F5F5F5F002C002C2C2CC5C5EF005F004949492C2C2C
2C2C2C4949495F975FC5EFC5B6B6B62C2C2C002C002C0000002C00002C000000005F9797
EFC5977373735F975FA7A7A7FFEFEFFFFFEF2C2C2C2C2C2C2C2C2C0049005F975FD4D4D4
D4D4D42C2C2C2C2C2C2C2C2C5F5F5FC5EFFFFFEFC5FFFFC5FFEFFFFFFFEF975F00005F5F
5F5F5FD4D4D4B6B6B62C2C2C2C00002C2C2CC5C5C52C2C2C97C5975F975F97EFC5979797
2C2C2C005F5F737373002C005F5F5F97C597C5C5972C2C2C4949494949495F975F2C2C2C
4949492C2C2C5F5F5F5F97975F5F0097C5975F975F2C2C2C494949737373C5C5C55F5F00
0073002C2C2C002C002C000000002CE1E1E1EFFFC5EFEFC5EFEFC5EFC5C5C5C5C5C5C5C5
EFFFEFC5EFC58585855F5F00A7A7A72C2C2C494949FCFCFC5F5F5F002C002C2C2C494949
A7A7A7B6B6B600002CD4D4D4A7A7A75F975F5F5F5F2C2C2CC5C5970049005F975F5F975F
A7A7A72C2C2C2C2C2C97975F5F975F002C00C5EFEFC5C59700002C97979797C5C52C2C2C
2C000000002C002C00B6B6B6C5C5C55F975F2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000
D4D4D4C5C55F5F975F85858585858597C597C5EFC5EFEFEF975F5F2C2C2CA7A7A7C5C5C5
5F5F5F2C2C2C00002C2C2C2C005F5F4949495F5F5F4949495F975F5F9797494949494949
5F5F5F00005FA7A7A75F97975F97975F5F5F5F975F2C2C2C5F5F5F2C2C2C5F5F5F737373
5F5F5F005F5F00002C737373494949005F5F8585855F9797A7A7A7004900005F5F979797
005F5F2C2C2C97975F4949492C2C2C5F5F5F85858597975F97C5C55F97970049002C2C2C
2C2C2C4949497373732C2C2C002C000049005F5F5F5F5F5F00004997975F004900A7A7A7
4949492C2C2C97C597004900A7A7A7A7A7A75F5F5F2C2C2C2C2C2CC5C5C5858585000000
004900A7A7A75F5F5F49000000002CC5C5C57373732C2C2C49494997C5975F5F005F5F5F
D4D4D4C5975F494949005F5F
2C000000002C2C000000002C490000002C00490000002C000000002C2C2C00002C2C0000
00000000002C00002C2C2C2C2C2C2C2C2C2C00002C00002C2C2C2C2C2C2C2C2C2C737373
737373737373005F5F4949492C2C2C2C2C2C2C2C2C2C00002C2C2C737373B6B6B6C5C5EF
EFEFEFE1E1E1EFEFC5C5EFC5B6B6B6A7A7A7A7A7A7A7A7A7B6B6B6A7A7A7C5C5C5E1E1E1
494949002C0000000000002C2C2C2C2C2C2C2C2C2C2C2C2CC5EFC58585855F5F5F5F975F
5F5F5F5F9797A7A7A7B6B6B6002C000000002C2C2C2C2C2C0000002C2C2C5F5F5FC5EFC5
E1E1E1E1E1E1C5EFEFB6B6B6494949FCFCFC494949494949005F00737373C5EFC5C5C5C5
2C2C2C002C00002C00005F5F5F975FE1E1E1A7A7A75F5F5F2C2C2CA7A7A7C5C5975F5F5F
97C55FE1E1E14949492C2C2C2C2C2CC5EFEF5F5F002C2C2CB6B6B697C59797C5C5C5C5C5
5F5F5F5F97972C2C2C00002C97C597490000A7A7A75F975F5F975F4949495F5F5F5F5F00
2C2C2C2C2C2C5F5F5F4949497373737373735FC597C5C59797C55F5F975F97C5C5C5EFC5
B6B6B6A7A7A79797975F975FC5C5C5EFEFEF2C2C2C00002C00002C00002C2C2C2C002C00
2C2C2C005F5FEFEFC5002C002C2C2C00002C5F005FFFEFC5005F00002C002C2C2C5FC55F
EFEFC5737373D4D4D4C597975F5F5F4949494949490000007373732C000097C5C5A7A7A7
97C597490000002C00C5C5C59797974949495F9797C5EFEF2C2C2C00002C002C0097C5C5
97C5977373735F9797A7A7A7C5EFC55F975F5F5F5F97975F97975F00975F97C597B6B6B6
D4D4D4FFFFFFC5C5C5C5C5C5C5EFEFB6B6B6858585494949C5EFC5C5C5C549494900002C
2C2C2C2C2C2C004900494949005F5F4949494949495F975F5F9797494949494949494949
5F975F5F97975F97975F5F5F5F975F4949494949494949494949495F97975F5F5F494949
494949005F5F494949005F005F97975F97978585854949494949499797972C2C2C2C2C2C
A7A7A74949494949495F975F4949495F975F5F97974949492C2C2C2C2C2C5F975F494949
000000002C005F5F5F5F5F5F97975F97C597005F002C2C2C5F975F00002C9797C55F5F5F
97C5C59797974949492C2C2C9797975F5F5F2C2C2C2C2C2C2C2C2CC5C5975F5F00004900
5F975FC5C5975F97972C2C2C005F0097C597005F002C2C2CC5C597B6B6B65F975FC5EFC5
C5C5974949494900005F5F5F
00002C000000002C002C000000002C002C00002C000000002C2C2C002C0049000000002C
0000000000000000000000002C2C2C00002C2C000000002C2C2C2C2C2C2C2C2C2C2C0000
00002C2C2C2C4949499797975F5F975F975F5FC597B6B6B6C5C5EFE1E1E1B6B6B65F5F5F
2C2C2C2C2C2C2C2C2CC59797EFEFEFE1E1E1EFEFEFE1E1E1C5EFEFE1E1E12C2C2C2C2C2C
2C2C2C0000002C2C2C2C2C2C0000495F97975F9797C5EFC5D4D4D4C5EFEFC5EFFFC5EFEF
FFFFEFFFFFEF4949492C2C2C2C2C2C00002C2C2C2C002C00002C005F975FC5C5C5A7A7A7
00002C2C000000002C00002C005F5FEFEFEF97975F979797A7A7A7FFFFEFFFFFFF2C2C2C
002C002C2C2C4949495F9797E1E1E1EFC5C52C2C2C2C2C2C2C2C2CC5EFEFFFFFEFFFEFEF
C5C597C5C5C52C2C2C2C2C2C858585D4D4D42C2C2C494949B6B6B62C2C2C005F5FD4D4D4
5FC597C5C5C54949490000009797972C2C2C5F975F5F5F00B6B6B6494949005F00494949
2C2C2C2C2C2C4949495F975F49494997975F4949492C2C2CA7A7A7A7A7A797C597D4D4D4
737373975F5F979797A7A7A7B6B6B6C5C5C58585855F975F2C2C2C2C00002C2C2C490000
5F5F5FEFFFC50000002C2C2C2C2C2C97C597C5C5C55F5F5F2C2C2C5F9797C5C597737373
975F97EFEFC549494949494997975F4949494949492C2C2C5F5F5F004900979797979797
979797C5C5972C2C2C000000C5EFC5858585979797A7A7A7A7A7A7002C0000002C002C00
C5C5C5C5EFEFD4D4D4A7A7A7005F5F979797B6B6B697C5C597C5C5C5EFFF97C5C5737373
4949492C2C2C002C0000002C2C2C2CB6B6B6B6B6B69797975F5F5F00000049000000002C
00002C2C2C2C2C2C2C49494900005F97975F5F5F5F5F5F5F49494900975F5F5F5F5F5F5F
5F97974949497373734949495F5F5F005F5F4949495F97977373734949494949495F5F5F
2C2C2C005F008585855F5F5F7373732C2C2C5F975F2C2C2C2C2C2C494949A7A7A7737373
4949492C2C2C2C2C2C97975F97975F4949494949494949495F5F5F5F5F5F5F5F5F5F975F
490000A7A7A77373732C2C2C0049005F975F2C2C2C9797975F975F5F5F975F975F2C2C2C
9797977373732C2C2C002C00C5C5C58585852C2C2C002C00A7A7A75F5F5F2C2C2C2C2C2C
B6B6B6979797005F00494949D4D4D4B6B6B62C2C2CC5C5C5C5C597004900E1E1E1A7A7A7
5F5F5F2C2C2C4900005F5F5F
2C2C2C002C0000000000000000002C2C00000000002C00002C2C2C002C00002C002C0000
2C00000000000000002C000000002C0000002C0000002C00002C002C2C2C2C2C2C2C2C2C
2C2C2C002C00002C0000002C2C2C2C4949495F5F5F7373735F5F5F005F002C2C2C2C2C2C
4949492C2C2C4949492C2C2C2C2C2C5F5F5FA7A7A797C5C5C5C5C5B6B6B6C5C5C597975F
5F975F49494997C5975F9797A7A7A7C5EFC5C5EFEFB6B6B65F5F5F005F5F2C2C2C494949
5F5F5FD4D4D4EFC5972C00002C2C2C005F00005F5F5F5F005F5F5FC5EFC5B6B6B62C2C2C
00002C0000000000009797975F9797C5EFEFC5FFEFC5FFEFC5EFEFD4D4D4FFFFEF2C0000
8585855F97975F9797EFEFC5B6B6B62C2C2C2C2C2C002C00C5C5C5E1E1E14949492C2C2C
00002CFFC5C55F5F5F97975FEFEFC55F5F5F2C2C2CB6B6B6C5C5C52C2C2C2C2C2CC5EFC5
4949495F97975F5F5F4949495F975F0000009797974949497373735F5F5F5F5F5F494949
5F5F5F2C2C2C494949005F5F5F975F49494997975F5F5F000049002C2C2C000049C5C597
2C2C2C2C2C2C2C2C2C002C0000490000002CFFEFC5C5FFC597C5978585855F5F5F737373
FFEFEF97C597858585737373C5C597A7A7A7979797C5C5C5C5EFC5B6B6B6494949494949
D4D4D45F5F5F005F5FEFEFC55F5F5F2C2C2C002C005F5F5F2C2C2CA7A7A7A7A7A7737373
00002CA7A7A7979797002C009797975F975F0000002C000097C597858585002C002C0000
002C00B6B6B697C597002C002C00002C2C2C002C002C2C2CFFEFEF0049002C2C2C2C2C2C
00002C2C2C2C2C2C2C97975FEFEFC5C597972C2C2C002C00975F5F49494900005F005F00
7373732C2C2C5F5F00494949494949494949005F5F5F5F5F005F5F4949495F97975F9797
4949495F5F5F4949494949494949497373735F97974949494949495F5F5F4949495F005F
8585855F97975F5F004949495F975F49494949494997975F005F5F005F5F5F9797737373
8585859797975F5F5F2C2C2C002C005F5F002C2C2C4949495F5F5F97975F5F97975F975F
4949495F975F5F5F002C2C2CA7A7A72C2C2C5F5F5F494949494949A7A7A72C2C2C004900
C5C5975F5F5F004900494949C5C5974949492C2C2C000049C5C5977373730049005FC5C5
A7A7A75F5F5F5F975F97C597494949D4D4D4D4D4D4C5C5974949492C2C2CC5C5C55F975F
5F975F2C2C2C2C2C2C494949
000000000000000000000000002C00002C00000000002C0000002C002C00002C0000002C
2C2C2C002C000000002C2C2C002C002C0000002C002C000000002C00002C2C00002C2C2C
002C000000000000000000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C5F97979797C5
97C5978585855F979797C5C5C5C5C5C5C5C597C5C5C5EFEFC5EFC5A7A7A75F9797A7A7A7
A7A7A79797975F975F97C597979797858585002C00002C002C2C2C2C2C2C2C2C2C2C2C2C
00002C002C00B6B6B6C5C597C5C597EFC5C5A7A7A7A7A7A7C5EFC5C5EFC52C2C2C2C2C2C
2C2C2C494949A7A7A797C5C5C5EFC55F5F5F0049002C2C2C2C2C2C2C2C2CC5EFFF97975F
EFEFC5EFEFC5FCFCFCC5C5EF2C2C2C002C0000002C97C5C5EFFFEF5F5F5F002C002C2C2C
C5EFC5EFEFEFE1E1E1E1E1E1B6B6B649494997C55FC5C5C55F5F00494949004900A7A7A7
2C2C2C2C2C2C5F9797A7A7A7C5C5972C2C2C5F97974949495F5F5F5F975F8585852C2C2C
4949495F5F5F002C004949492C2C2C5F005F4949495F975F97C55F0049002C2C2C5F5F5F
C5EFC55F975F7373735F5F5F5F5F5F005F5FC5EFEFB6B6B697975F2C2C2C002C00000000
494949B6B6B6C5C597494949002C0000002C000049EFFFC5975F5F4949495F5F5FA7A7A7
5F9797A7A7A7C5C5C52C2C2C97975F005F002C2C2C8585855F5F00737373B6B6B697EFC5
5F975F2C2C2C979797004900494949C5C5C5002C000000002C2C2C97C597A7A7A797C597
B6B6B697C5C5C5EFC597975F7373732C2C2C2C2C2C00000097C5C5C5EFEFB6B6B65FC597
A7A7A75FC597C5C597C5EF972C2C2C002C00C5C597979797C5EFFFB6B6B6A7A7A7979797
5FC59797C5C549494900002C005F5F5F5F5FC5975F00002C005F5F5F97978585855F975F
494949494949005F5F5F97975F97977373734949495F975F5F5F00494949737373979797
4949494949495F5F5F4949492C2C2C5F5F5F5F5F5F5F5F5F737373005F5F5F975F5F9797
5F5F5F4949492C2C2C005F005F5F004949495F975F5F975F005F005F975F2C2C2C494949
494949979797005F5F5F975F5F975F9797974949492C2C2C5F97975F5F5F2C2C2C737373
5F975F494949494949B6B6B6C5C5974949495F975F97C59797C597005F5FA7A7A75F5F5F
2C2C2CC5EFC5C5C5972C2C2C4949495F5F5FC5C5C55F5F5F2C2C2C2C2C2CEFC5C5737373
5F5F5F2C000000002C005F5F
2C2C2C2C00002C2C2C00000000002C002C00000000002C00000000002C002C2C2C002C00
002C00000000490000002C002C000000002C2C2C2C2C2C2C2C0000002C00002C00490000
002C002C000000002C2C2C2C2C2C2C2C2C2C00002C2C2C2C00002C2C00002C2C2C2C2C2C
2C2C2C5F5F5F8585857373735F5F975F5F5F4949492C2C2C4900000000492C2C2C002C00
97C597975F00975F5FEFEF97C5EF97EFC597EFC5C597C59797C597C5EFC5B6B6B6B6B6B6
A7A7A7EFEFC5C5979797975F737373A7A7A7EFC5C54949492C0000B6B6B6975F0097975F
5F975FA7A7A797C5C50049002C2C2C2C2C2C2C2C2C2C2C2C5F5F005F9797C5EFEFC5FFEF
C5C5C5858585A7A7A7975F004949492C00005F5F5FC5FFEF2C2C2C2C2C2C2C2C2C737373
EFFFEF2C2C2C2C2C2C5F5F97FFFFEFEFEFC5EFEFC597C5C52C2C2C2C2C2C97C5C5494949
2C2C2C4949494949492C2C2CB6B6B65F970097975F2C2C2C5F5F5F4949495F975F5F975F
004900005F5F5F5F5F2C2C2C0049005F5F002C2C2C5F975F5F005F979797B6B6B6A7A7A7
97C5C597C59797C5C5C5C5C5D4D4D4C5EFC5A7A7A74949492C2C2C2C2C2C2C2C2C494949
979797D4D4D42C2C2C00002C2C2C2C2C2C2C494949C5C597005F5F5F9797C5C5C55F5F5F
C5EFC55F5F5F4949495F975F5F5F5F5F5F5F49494997979797C5972C2C2C5F9797494949
97C5C52C2C2C2C2C2C97979797C597A7A7A75F5F5F49000000002C002C0049494997C5C5
5F5F9700002C49494997C597A7A7A7C5EFC597C597FFFFEFD4D4D45F5F5F2C2C2C494949
2C2C2C004900C5C597C5C597A7A7A749494985858500002C2C2C2C5F975FFFEFC5494949
00002C2C2C2C858585A7A7A7A7A7A7B6B6B6B6B6B6C5EFC52C2C2C9797975F9797737373
4949495F5F5F5F97975F975F005F5F5F5F5F005F5F2C2C2C7373735F9797494949005F5F
5F975F2C2C2C2C2C2C5F975F5F5F5F7373737373737373735F97975F5F5F5F5F5F5F975F
005F5F0049002C0000737373005F005F975F2C2C2C2C2C2C4949492C2C2CB6B6B6004900
7373732C2C2C97C55F2C2C2C4949495F975F0049002C2C2C5FC55F2C2C2C002C00B6B6B6
C5C597004900C5C5972C2C2C005F0097C59797975F4949495F5F5FC5C5C5A7A7A72C2C2C
494949C5C5C55F97975F975F2C2C2C494949C5C5C57373732C2C2C2C2C2CEFEFC5979797
005F5F2C2C2C00002C494949
002C00002C000000002C2C2C00002C00002C00000000002C00000000002C490000000000
2C0000000000002C00002C002C000000002C002C002C2C2C2C2C2C2C2C2C002C00002C00
2C2C2C002C00002C002C0000000000000000000000490000002C00002C002C2C2C00002C
00002C2C2C2C002C002C2C2C00002C5F5F5F005F5F494949005F5F005F5F97975F5F5F5F
A7A7A7C5EFC5EFC5C52C2C2C005F5F737373C5C5C5EFEFC5D4D4D4B6B6B6C5C5C5858585
4949492C2C2C5F005FA7A7A7C5EFC5A7A7A7C5EFC597975F2C2C2CB6B6B6B6B6B6B6B6B6
97C5978585852C2C2C2C2C2C00002C002C005F5F00858585B6B6B6C5FFEF85858500002C
2C2C2C002C005F9797E1E1E1C5EFEFC5EFEFD4D4D48585852C2C2C2C2C2C5F5F5FEFFFFF
49494900002C000000C5C5C5B6B6B62C2C2CFFC5EFEFC5972C2C2C9797979797972C2C2C
2C2C2CA7A7A72C2C2C002C00A7A7A773737397C5C54949495F5F5F4949494949495F5F5F
97975F2C2C2C4949490049002C2C2C2C2C2C5F975F49494997C5970049000049005F5F97
C5EFEF97975F002C0000002C002C002C2C2C979797B6B6B68585857373735F5F5FC5EFC5
C5EFEF4949494949490049005F9797EFFFEFEFEFEFC5EFC5D4D4D4A7A7A72C2C2C5F97C5
494949494949A7A7A79797974949492C2C2C49494997C597002C009797975F97972C2C2C
2C2C2CB6B6B62C2C2C005F5FC5C5972C2C2C97C5979797975F5F00002C000000005F9797
B6B6B6000000002C002C2C2C00002C002C005F9797FFFFEF004900004900005F5F004900
494949C5C5974949490049005FC5972C2C2C97975F97C597C5EFC5E1E1E15F9797A7A7A7
C5C5C5A7A7A7EFEFEFC5EFEF5F975F00002C2C2C2C737373C5C5972C2C2C5F97975F5F5F
5F5F5F4949495F975F5F97974949494949495F975F5F97977373730049007373732C2C2C
2C2C2C4949495F97975F97975F5F5F4949495F97975F5F5F7373732C2C2C005F5F5F975F
5F5F005F5F5F4949499797975F5F5F4949492C2C2C5FC55F2C2C2C5F9797494949979797
4949495F97974949492C2C2C8585855F5F5F000049A7A7A797C5974949495F5F5F2C2C2C
49494997C597005F5F2C2C2C49494997975F5F5F5F002C00005F5FC597C54949492C2C2C
2C2C2CA7A7A79797975F5F5F2C2C2C5F5F5FEFC5C55F5F5F2C2C2C2C2C2CEFEFC5979797
7373732C2C2C00005F494949
002C0000002C2C2C2C002C002C000000002C2C0000002C0000002C002C00002C002C0000
2C0000002C002C0000002C002C00002C2C2C2C2C2C2C2C2C2C2C2C002C002C0000490000
002C002C2C2C002C00000000002C002C00002C000000002C2C2C2C002C00490000002C00
002C000000002C2C2C00002C2C2C2C2C2C2C00002C2C00002C2C2CA7A7A7858585EFEFC5
EFEFC52C2C2C2C2C2C2C2C2C494949A7A7A7C5EFC5C5EFC5C5EFC5EFEFC5D4D4D4EFEFC5
D4D4D4C5C5C5D4D4D4A7A7A77373735F5F5F5F9797C5C5C5EFEFC5A7A7A72C2C2C2C2C2C
975F0000975FA7A7A797975FA7A7A797EFC5B6B6B6D4D4D45F5F5F2C2C2C2C2C2C00002C
004900979797C5C5C55F5F5F2C2C2C00002CC5EFEF002C000049005F9797EFFFFF5F5F5F
2C2C2C2C2C2CC5EFC5A7A7A72C2C2C000000C5C5EFEFEFC5A7A7A7B6B6B6EFC597494949
5F9797B6B6B6494949005F0097975F2C2C2CA7A7A75F9797A7A7A72C2C2C5F975F2C2C2C
5FC5978585855F5F00005F5F2C2C2C2C2C2C4949495F5F5F49494997975F5F5F5F2C2C2C
005F5FB6B6B6C5C5975F975F5F975F5F5F5F005F5F5F975FC5EFEFC5C5C5B6B6B6A7A7A7
C5EFC597C5C5C5EFEFB6B6B67373732C2C2C004900737373EFC5C52C2C2CA7A7A7B6B6B6
A7A7A7C5C5C54949495F975F2C2C2C2C2C2C5F5F5F2C2C2C2C2C2CA7A7A797C59797975F
2C2C2C8585855FC5975F9797A7A7A72C00002C2C2C5F5F5FA7A7A7C5EFC5C5C5EFD4D4D4
C5C5C55F975F9797975F975F5F5F5F97C5C597C5C5C5EFFF5FC5C5A7A7A7C5EFC5C5C597
002C00000049979797A7A7A75F5F00979797B6B6B697C5975F5F5F97C59797975F97C597
B6B6B697C5972C2C2C00002C979797C5C5C500975F494949C5C5C55F5F5F5F975F97C597
5F5F5F4949495F5F974949498585855F97975F97974949492C2C2C494949494949005F5F
5F975F5F97975F5F5F5F5F5F5F97975F5F5F4949490000490049002C2C2C494949A7A7A7
97975F8585854949490049002C2C2C2C2C2C5FC55F494949005F5F5F975F5F975F5F5F5F
4949495F975F2C2C2C2C2C2C5F9797494949005F00B6B6B65F975FA7A7A797C5975F5F5F
494949B6B6B65F975F00002C2C2C2C737373737373002C002C2C2CB6B6B6737373000000
2C2C2CA7A7A7979797494949002C005F5F5FC5C5C55F975F494949000049EFEFC5B6B6B6
7373735F975FC5EFC55F5F5F
00002C00002C002C000000002C00000000002C000000002C00002C0000002C0000002C00
0000000000000000002C000000002C002C002C2C2C2C2C2C2C2C2C002C0000002C2C2C2C
002C00002C002C2C2C737373490000002C0000000000002C2C2C2C002C00002C00002C00
2C2C2C2C00002C2C2C00002C2C2C2C00002C2C000000002C2C2C2CC5C5C5C5C5975F5F5F
0049002C2C2C5F9797C5C5C5D4D4D49797972C2C2C2C2C2C2C2C2C00490097975FC5EFC5
C5EFC5EFEFC5C5C5C5C5C597C5C597A7A7A7EFC597D4D4D4C5C5C55FC597A7A7A7E1E1E1
C5C5975F5F5FB6B6B6975F5F005F5F5F9797C5EFC52C2C2C2C2C2C2C2C2C2C2C2C858585
97C5978585852C2C2C2C2C2C002C005F9797C5EFEFC5EFEFC5EFEFE1E1E1C5C597002C00
2C2C2CEFEFFFA7A7A72C2C2C0000495F975FC5C5C54949492C2C2CB6B6B6EFC597979797
97C5C5A7A7A75F5F5F5F5F5F5F5F002C2C2CC5C5972C2C2C97C5C55F975F494949002C00
2C2C2C5F97975F5F5F2C2C2C494949002C004949492C2C2C5F5F005F975F005F00A7A7A7
97C597005F5F97C5C597C5C597C5C597C5C5C5EFEFC5EFEF9797975F5F5F4949495F5F5F
494949C5EFC58585852C2C2C2C2C2C2C2C2C737373C5C5C52C2C2C5F975FB6B6B6EFEFC5
C597974949495F5F5F97975F4949494949498585852C2C2C97C55F9797972C2C2C5F5F5F
97975F2C2C2C5F5F5F737373858585A7A7A72C2C2C0000002C2C2CA7A7A75F97972C2C2C
2C2C2C2C2C2C494949B6B6B6C5EFC54949490000492C2C2C002C00002C005F5F00C5C597
494949737373858585A7A7A7D4D4D49797975F5F5F5F5F5F5F975F5F975F979797E1E1E1
5F5F005F5F5FEFEFC5004900005F5F5F9797979797858585C5EFC55F5F004949495F5F5F
005F5F5F975F5F5F5F5F97978585855F5F5F4949495F5F5F494949005F5FA7A7A75F9797
7373730097978585854949492C2C2C2C2C2C0049005F975F002C005F9797A7A7A7979797
00002C4949490049005F975F0000495F975F5F975F5F975F2C2C2C00002C5F975F494949
8585854949492C2C2C7373735FC59749494997C597494949494949A7A7A79797972C2C2C
002C00C5C5EF8585852C2C2C2C2C2C8585857373732C2C2C2C2C2CB6B6B65F5F97004900
2C2C2CA7A7A7979797005F5F494949C5C5C5EFC5C5B6B6B6000049C5C5C55F5F00EFC5C5
C5EFC5C5C5C55F5F5F494949
002C002C00000000002C2C2C00002C00000000002C002C002C000000002C490000002C00
002C000000000000000000002C2C2C2C2C2C002C000000002C000000000000000000002C
00002C002C002C2C2CA7A7A700002C002C002C00000000002C0000002C002C2C2C2C2C2C
00002C5F9797002C002C00002C000000002C00002C2C2C2C5F5F5FD4D4D4D4D4D4EFEFC5
EFEFC5B6B6B6C5C5C5002C002C00002C2C2C2C00002C2C2CB6B6B6E1E1E1B6B6B6002C00
2C2C2C2C2C2CEFEFEFE1E1E197975F2C2C2C2C2C2C4949492C2C2C5F5F005F5F5F97C55F
5F975FC5C5975F5F5FB6B6B65F5F5FC5C5EFC597972C2C2C2C2C2C979797B6B6B6C5C5C5
5F005F2C2C2C2C2C2C005F5FC5EFEFC5EFEF5F5F0000002C2C2C2CEFFFFFC5EFC5E1E1E1
C5EFC5A7A7A72C2C2C2C2C2C5F5F5FC5EFEF5F5F5F2C2C2C2C2C2C97C5C5B6B6B6737373
C5C5C5B6B6B62C2C2C737373494949005F5F7373735F005F97C5C597C5C597C5972C2C2C
002C002C2C2C5F97975F97974949495F5F002C2C2C2C2C2C2C2C2C2C2C2C737373005F00
2C2C2C979797B6B6B697C5972C2C2C00002C00002C004900A7A7A7E1E1E1C5C5C5A7A7A7
97C5C5A7A7A7C5C597005F5F97C597C5EFEFC5C5C5D4D4D4C5C5C55F5F5FA7A7A7C5C5C5
494949C5C5C52C2C2C5F5F5F4949494949495F975F5F5F5FA7A7A75F5F5F49494900002C
7373734949498585852C2C2C004900000000A7A7A75F5F005F975F97C5C597C5C55F975F
2C2C2C2C2C2C4949495FC597C5EFEFB6B6B6C5C597C5C597C5C59797975F2C2C2C005F5F
D4D4D42C2C2CC5C597EFEFC597979797C55F5F975F0073008585850049002C2C2C002C00
97C5975F975F5F5F00D4D4D4C5C5C5D4D4D45F5F002C2C2C5F5F97E1E1E12C2C2C005F5F
5F5F5F5F97977373735F97974949494949495F975F005F5F5F97979797975F975F5F9797
5F5F5F4949492C2C2C4949492C2C2C5F97975F975F97C5972C2C2C2C2C2C9797972C2C2C
5F975F2C2C2C8585857373737373734949497373735F5F5F2C2C2C737373737373004900
9797975F5F5F005F5F9797975F5F5F7373735F97974949492C2C2CA7A7A700975F2C2C2C
002C00B6B6B65F975F2C2C2C0049005F975F5F5F5F0000002C2C2CC597C55FC5972C2C2C
2C2C2CB6B6B6D4D4D4005F5F494949D4D4D4979797E1E1E1EFC5EFC5C5972C2C2C97975F
C5EFC5EFEFC5005F5F5F5F5F
2C0000002C000000000000002C2C2C002C0000000000002C2C00002C2C2C002C002C0000
0000004900000000000000002C2C2C002C002C2C2C2C2C2C002C00002C000000002C2C2C
2C2C2C2C2C2C000000002C00490000002C00002C002C00002C0000002C00002C0000002C
2C2C2C2C2C2C2C000000000000000000000000002C005F5F5F5F5FEFEFC54949492C2C2C
2C2C2C002C00EFEFC5C5EFC5EFFFC5EFFFC5D4D4D4B6B6B64949492C2C2C2C2C2C858585
EFEFC5C5EFC5975F5F2C2C2C2C2C2C5F5F5FEFEFC54949492C2C2C7373730049002C2C2C
5F5F00B6B6B6C5C59797975F85858597975F2C2C2C979797EFEFC5858585C5C5EF2C2C2C
2C2C2C2C2C2CA7A7A7C5EFEF5F5F5F00000000002C002C0097C5C5B6B6B6B6B6B69797C5
E1E1E15F5F5F5F5F0097C55FE1E1E17373732C2C2C2C2C2C005F5FC5EFC54949492C2C2C
97C5C5FFEFC5C5C5C597C5C52C2C2C5F5F5F4949494949499797972C2C2CB6B6B65F975F
2C2C2C005F004949497373737373732C2C2C5F975F002C000049004949495F5F0097975F
5F975F4949492C2C2C858585B6B6B6A7A7A797C5C597C5C5D4D4D44949494949492C2C2C
5F5F5F000049EFEFC58585852C2C2C2C2C2C005F5FC5C5C5494949494949C5EFC5C5EFC5
B6B6B6005F5F737373005F002C2C2C4949495F975F5F9797979797005F5F97C597004900
002C005FC597737373B6B6B62C2C2C00002C00002C858585B6B6B6737373737373B6B6B6
9797975F979797C5C597C5C549494900490049494900490097C5975F5F008585855FC597
2C00005F5F5F975F5F737373C5C5975F5F5F97C597C5EFC500002C2C2C2C5F5F5F000049
002C0097C55F858585C5EFEF2C2C2C2C2C2CC5C5C52C0000002C00979797E1E1E1EFFFC5
C5EFEF49000097C55F4949495F97975F97975F97975F5F975F97975F5F5F005F5F2C2C2C
2C2C2C2C2C2C005F5F5F5F5F8585852C2C2C7373732C2C2C2C2C2C979797005F005F9797
5F5F5F7373734949494949495F975F2C2C2C737373494949494949A7A7A7A7A7A7979797
8585855F97975F9797494949005F5F5F5F5F8585855F5F5F002C007373735F5F5F494949
2C2C2CEFEFC54949492C2C2C2C2C2CA7A7A75F5F5F2C2C2C2C2C2C979797EFEFC52C2C2C
005F97EFEFC5B6B6B6B6B6B6E1E1E15F5F00494949A7A7A7EFC5C54949492C2C2C2C2C2C
975F975F975F7373735F5F5F
0000002C2C2C00002C2C0000002C00002C002C000000002C002C002C000000002C002C00
2C000000002C49000000002C2C2C2C2C2C2C000000490000002C000000000000002C2C2C
00000000002C2C2C2C002C002C2C2C2C2C2C002C0000002C49000000002C2C2C2C2C2C2C
2C00004900004900002C2C2C2C2C2C2C2C2C005F5F5F5F5FEFC5C54949492C2C2C2C2C2C
00002C97975FC5EFC5858585494949005F00C5979749494997975FC5C5C5E1E1E1A7A7A7
2C2C2C2C2C2C2C2C2C004900C5C597A7A7A75F5F5F5F975FC59797C5C5978585855F975F
5F5F5F4949495F5F5FD4D4D4FFEFC5FFFFEFFCFCFC5F5F002C2C2CFFEFC5B6B6B6EFEFC5
97C597C5EFC5C5EFEF2C2C2C002C0000002C005F5FC5EFEF2C2C2C00002C2C2C2C979797
C5EFC5975F97737373B6B6B6FCFCFC2C2C2C002C00002C00C5FFEF5F5F5F2C2C2C2C2C2C
C5EFEFA7A7A7002C00A7A7A7A7A7A7EFC5C52C2C2C4949495F5F5F2C2C2CA7A7A75F9797
5F975F2C2C2C2C2C2C4949495F9797494949005F5F5F5F002C2C2C2C2C2C494949005F5F
5F5F00737373A7A7A7C5C5C55F5F5F2C2C2C2C2C2C49494997C5EFC5EFEFA7A7A797C597
97C5C5C5C5C55F5F5F0049004949495F9797D4D4D4005F5FC5C5C5EFC5C5005F5FC5EFC5
4949495F975F5F975F5F5F5F2C2C2C5F975F002C0097C5975F5F5F5F5F5F494949979797
00002C5F9797A7A7A72C2C2C979797C5C59797975FA7A7A7C5C5C55FC5974949492C2C2C
5F5F005FC597C5EFEF97C59797C5C5858585C5C597858585005F00C5EFC5005F5F97C5C5
C597972C2C2C49494997C59797C597B6B6B65F975F2C2C2CA7A7A72C2C2C004900A7A7A7
97C59797C5970000002C2C2CB6B6B6494949004900D4D4D497C597E1E1E1975F5F002C00
5F5F5FC5C597005F5FA7A7A75F5F975F5F5F5F975F4949492C2C2C2C2C2C2C2C2C000000
2C2C2C00002C00002C97975F4949495F97974949495F5F5F858585005F5F7373732C2C2C
5F975F4949492C2C2C97975F4949490049008585855F5F00A7A7A70049005F5F0097C597
005F5F494949A7A7A75F97972C2C2C4949495F5F5F5F5F5F2C2C2C5F005F5F975F5F5F5F
2C2C2C979797C5EFC5005F5F2C2C2CC5EFC55F975F4949495F5F97C5EFC59797975F9797
EFEFC52C2C2C00005F97C5C5A7A7A74949492C2C2C2C2C2C97C5975F5F5F002C00002C00
5F5F5F97C5975F9797494949
2C000000002C2C0000002C0000002C000000002C00000000002C0000002C00002C002C00
0000002C000000002C2C2C2C00002C2C000000002C00002C2C2C2C002C002C2C2C2C2C2C
2C2C2C00002C002C00002C00002C002C2C2C00000000002C4900002C0000002C00002C00
002C00002C00002C002C2C2C002C005F5F5F5F5F5FEFEFC52C2C2C2C2C2C002C002C2C2C
858585A7A7A72C2C2C2C2C2C5F975FEFEFC5B6B6B6C5C5C59797975F5F00C5C5EF005F00
5F5F5FC5C597C5EFC57373732C2C2C002C00002C0000002C97C5977373735F5F5F5F5F5F
EFEFC52C2C2C000000490000005F5FD4D4D42C2C2CC5C5C5C5C59797C5C5EFEFC597C55F
005F5FC59797FFFFEF5F5F5F5F975FC5C597A7A7A72C2C2C2C2C2C494949C5FFEF979797
2C2C2C00002C002C00005F97FFFFFF5F975F979700D4D4D4C5C5C52C2C2C2C2C2C5F9797
8585852C2C2C494949D4D4D42C2C2CC5C5C597979797975F2C2C2C4949495F5F5F5F5F5F
97979797C5C54900002C2C2C4949495F9797005F005F5F5F000000494949005F005F5F5F
4949495F975F004900494949B6B6B65FC597005F5F494949005F5F5F97C5C5C5C55F5F97
737373A7A7A7B6B6B697C5C5C5EFC5494949004900A7A7A72C2C2C005F5FB6B6B6737373
C5C5C549494997975F4949492C2C2C97C5C52C2C2C5F5F5F5F5F5FA7A7A72C2C2C979797
5F979797C5C5A7A7A74949492C2C2C7373734949494949495F5F5FB6B6B6B6B6B697C5C5
97C5C55F97C55F5F5F2C2C2C2C2C2C002C0097C5975F5F5F5F975F2C2C2C5F97C55F5F5F
5F5F5F5F5F00979797737373C5C597000000002C009797975F5F5F5F975F737373C5C5C5
00000000000097C55F2C2C2C5F9797C5C5C5C5EFC5B6B6B6494949D4D4D42C2C2C000000
002C00FFEFC5002C002C2C2C975F975F5F5F2C2C2C2C2C2C2C2C2C005F0049494900002C
97975F4949495F975F0097975F97975F5F5F97975F5F5F5F2C2C2C5F5F5F49494900002C
5F975F2C2C2C2C2C2C7373732C2C2C5F97975F975F858585C5C5975F5F5F494949A7A7A7
5F5F5F002C0097C5975F975F2C2C2C4949495F97975F5F5F2C2C2C2C2C2CC5C597005F5F
494949C5C5EF97975FC5EFC55F5F9797975F005F5FA7A7A7B6B6B6005F5F494949D4D4D4
7373732C2C2C2C2C2CB6B6B65F9797494949002C000000009797977373732C2C2C2C2C2C
2C2C2C97C5975F97975F5F5F
2C00002C00002C2C2C00002C0000004949490000000000002C2C2C0000000000002C2C2C
000000002C002C2C2C002C002C000000002C002C00000000000000002C00002C002C2C2C
2C2C2C002C002C2C2C002C002C2C2C979797002C002C000000002C4900002C2C2C00002C
000000490000490000002C00975F5F979797C5EFC5002C002C2C2C2C2C2C5F5F5F979797
A7A7A72C2C2C2C2C2CA7A7A7C5C5C54949490000492C2C2C00002CC5EFC5B6B6B6A7A7A7
A7A7A7D4D4D44949495F5F0049494997C597EFEFC5975F5F2C0000494949979797979797
494949858585A7A7A7C597975F5F5FA7A7A72C2C2C2C2C2C2C2C2CC5EFC52C2C2C2C2C2C
C5EFEFEFFFEFC5C5C5EFEFC5C5C597B6B6B6975F5F5F5F00B6B6B6B6B6B62C2C2C2C2C2C
2C2C2C002C00A7A7A7C5C5EFA7A7A72C2C2C494949C5C5C5C5EFEF002C005F5F5FB6B6B6
2C2C2C002C00C5EFC549494900002CA7A7A75F975FB6B6B62C2C2C5F5F5F002C00494949
5F5F5F49494997975F4949494949492C2C2C5F9797005F5F494949002C002C2C2C2C2C2C
005F004949494949498585855FC5C5A7A7A77373735F979797C5C597C5C55F975F737373
737373494949B6B6B65F5F5F2C2C2C494949C5EFC5494949494949979797B6B6B6EFEFC5
4949495F5F00494949005F5F494949002C005F975F005F5F4949495F97975F5F5F2C2C2C
5F979700002C2C0000EFEFC5494949494949C5C597737373005F5F002C002C2C2CB6B6B6
B6B6B65F975F5F975F5F975F9797975F5F5F005F5F73737397975F7373735FC5EF97C5C5
97975F5F975F2C2C2C5F975F2C2C2C5F5F5F97975FC5C597002C008585850000492C2C2C
9797C52C2C2C737373979797979797494949000049C5EFC54900005F5F9797C55F2C2C2C
2C2C2CFCFCFC2C2C2C4949492C2C2C2C2C2C002C000049002C2C2C8585852C2C2C5F5F5F
005F5F5F975F005F5F858585002C004949495F5F5F2C2C2C4949497373732C2C2C005F5F
5F9797004900858585A7A7A78585859797977373737373735F975F005F5F49494997C597
005F5F2C2C2CB6B6B65F97972C2C2C5F5F5FA7A7A7005F5F49494997C5C5C5EFC55F5F5F
005F97D4D4D44949495F5F5FD4D4D4005F5F2C2C2C2C2C2CC5C5975F5F5F002C00979797
5F97972C2C2C004900B6B6B6A7A7A7005F5F2C2C2C2C2C2CB6B6B67373732C2C2C2C2C2C
00002CD4D4D4858585494949
2C00000000002C00002C2C2C002C002C000000000000000000000000002C0000002C0000
00002C2C2C2C002C002C2C2C2C2C2C002C0000002C2C000000000000000000002C00002C
2C2C2C00002C2C0000002C00002C000000002C00002C000049000000002C002C002C0000
002C00858585C5C597D4D4D4C5C5C5C5C5C5E1E1E1000000494949C5EFC5C5C5C52C2C2C
2C2C2C2C2C2C979797B6B6B60000492C2C2C000049494949C5EFC54949492C2C2C2C2C2C
B6B6B6EFC5C5A7A7A7858585D4D4D45F5F5F2C2C2C5F975FC5C5C5494949002C00002C00
5F5F5FC5C5975F5F5F8585855F9797EFC597C5975F4949492C2C2C737373EFC5C52C2C2C
000049D4D4D45F5F5F5F5F5FC5C5C5E1E1E1C5C597494949009797C5C59797C55F5F975F
494949C5EFEFB6B6B64949492C2C2C2C2C2C2C2C2CB6B6B6C5EFFFEFFFEFC5EFEFC5FFEF
2C2C2CB6B6B62C2C2C2C2C2CC5C5C55F5F5F005F5F97C5C5B6B6B65F9797005F5F5F975F
494949494949005F5F9797975F5F5F005F002C2C2C8585854949495F975F002C00494949
4949495F5F5F5F975F4949495F5F5FB6B6B67373732C2C2C2C2C2C2C2C2CD4D4D4B6B6B6
979797979797B6B6B6979797C5EFC5B6B6B697C5C597C59797C5C549494997C5C55F5F5F
5F975F5F97972C2C2C2C2C2C0049002C2C2C2C2C2C5F975F5F97972C2C2C97C5C55F975F
C5C5C5A7A7A700002C494949C5C5C5C5C5C5858585737373A7A7A7A7A7A797C5C5979797
5F5F5F2C2C2C000049005F005F975F7373735F5F5F85858573737397C59797C5C5494949
97975F00004997975F002C0097975F8585854949492C2C2C4949492C2C2C9797972C2C2C
2C2C2CB6B6B6C5C597002C005F5F5F2C2C2C2C2C2CB6B6B62C2C2C005F5FE1E1E197C55F
9797975F5F002C2C2C2C2C2C002C00002C0000490000002C5F5F5F5F5F975F5F5F5F5F5F
5F975F2C2C2C4949495F5F5F005F5F4949495F5F5F4949498585855F5F5F2C2C2C5F97C5
9797975F5F5F97C5C55F5F5F9797975F975F2C2C2C5F97975F5F5F5F5F5F2C2C2C97C55F
005F5F2C2C2CB6B6B65F975F4949495FC5975F97975F975F494949EFEFC52C2C2CB6B6B6
C5C5972C2C2C494949002C00C5C5C55F5F5F2C2C2C00002CC5EFC55F975F2C2C2C494949
9797974949492C2C2C975F97B6B6B65F5F5F4949492C2C2CC5EFC55F5F5F005F972C2C2C
2C2C2CEFEFC55F9797005F5F
002C0000002C4949492C2C2C2C000000002C00005F0000002C00002C000000002C002C00
002C00002C0000002C002C00002C002C2C2C2C2C2C002C00002C002C00002C00002C2C2C
00002C2C2C2C0000002C00002C2C2C2C2C2C2C2C2C00002C000000002C000000002C0000
737373D4D4D449494900002C2C2C2CD4D4D4EFEFEFC5C5C5C5EFC5EFEFC5C59797004900
494949C5EFC5EFC5C52C2C2C2C2C2C2C2C2C97C597C5EFC52C2C2C2C2C2C002C00EFEFC5
A7A7A7002C002C2C2C5F9797B6B6B697975FA7A7A7B6B6B697975FC5C597EFC5C5858585
002C002C2C2C5F5F00B6B6B64949495F5F5F8585852C0000005F5F4949495F979797975F
4949495F5F97C5C5C5490000494949C5EFEF2C2C2C97C5C55F9797D4D4D45F5F5F005F5F
D4D4D45F97974949492C2C2C2C2C2C490000C5EFEF5F5F5F2C2C2C2C2C2C5F9797C5FFFF
C5EFEFC5EFC55F5F0097C5979797972C2C2C005F5F737373494949005F5F9797975F975F
2C2C2C4949494949495FC5975F97975F5F5F2C2C2C2C2C2C5F97974949498585852C2C2C
005F004949498585855F5F5F5F5F5F5F9797C5C59785858597979797EFC597C5C52C2C2C
2C2C2C4949495FC597C5C59749494949494997C5C5494949494949005F5F5F5F5FB6B6B6
5F5F5F975F5F4949492C2C2C002C005F97000049005F5F5F5F9797005F5F2C2C2C737373
A7A7A797C5C597C597005F5F5FC597494949005F5F4949492C2C2C494949C5C597005F5F
4949497373735F5F002C2C2C2C2C2C5F975F00975F4949492C2C2C49000097C5C5979797
5F975F97C597C5C5975F5F00858585002C007373732C2C2C5F5F5F5F5F5F979797494949
A7A7A700002C97975F2C2C2C002C0097C5972C2C2C00005FA7A7A79797C5A7A7A7005F5F
FCFCFC002C00002C0000002C002C00A7A7A7979797005F5F005F5F5F975F004900005F5F
97975F4949495F975F494949005F5F7373738585855FC5977373735F97975F97C5737373
49494997C5C573737300490097C5974949492C2C2C858585494949494949005F5F97C597
5F5F5F5F5F5FB6B6B6B6B6B65F5F5FA7A7A75F5F5FB6B6B6C5EFC5494949494949A7A7A7
A7A7A75F975F2C2C2C2C2C2CE1E1E15F5F5F2C2C2C2C2C2CC5EFC55F97972C2C2C2C2C2C
B6B6B65F5F5F0049005F5F5FC5EFC55F975F5F5F97005F5FEFFFEF97C5C58585855F5F5F
5F5F97C5C5C5C5C5C55F5F5F
2C00002C2C2C0000002C0000002C0000002C00002C002C002C0000002C00490000002C00
2C0000002C002C2C2C2C2C2C0000002C00002C2C2C002C00002C00000000490000002C00
2C000000002C00002C002C002C2C2C2C000000002C2C00000000000000002C0000009797
C5C5C597975F2C2C2C002C00000000737373A7A7A78585852C2C2C494949C5EFC5C5EFC5
C5C5C5737373D4D4D42C2C2C979797EFEFC5C5C5972C2C2C2C2C2C004900B6B6B6494949
002C0000004997975FA7A7A700002C002C00C5C597A7A7A7494949C5C5C5C5C55F97975F
EFEF97C5C5972C2C2C005F005F9797A7A7A75F975F002C0000002C2C2C2C494949D4D4D4
00002C49494997C5C5C597977373735F979797975F004900979797C5975FC5C5C5858585
97C597979797C5C59797C597C5EFC5B6B6B6002C0000002C00002CC5EFC5B6B6B62C2C2C
2C2C2CD4D4D4C5C5EFA7A7A72C2C2C005F00858585494949494949A7A7A7494949005F5F
5F975F5F5F002C2C2C4949498585855F97975F5F5F2C2C2C4949495F5F5F4949495F5F00
2C2C2C494949005F005F975F5F5F5F2C2C2C97C5975FC5974949492C2C2C005F5FC5C5C5
979797737373B6B6B67373735FC597C5EFC5A7A7A75F5F5F97C5C597C5C597C5C55F5F5F
4949495F975F4949492C2C2C5F5F002C2C2C4949495F979749494997C5C5A7A7A797C597
4949492C2C2CA7A7A7B6B6B697C5C55F5F5F73737373737397C597B6B6B65F5F97494949
494949494949005F5F5F5F5F97C597B6B6B6C5C597002C007373732C2C2C5FC5EF97C55F
2C2C2C0000494949495F5F5F0049009797975F5F0097975FA7A7A72C2C2C979797004900
5F5F5F00002C002C0097975F2C000097C59797C597EFFFEF2C2C2CC5EFC52C2C2C004900
D4D4D4002C0000002CB6B6B6005F5F5F5F5F5F5F5F4949494949495F975F494949494949
5F975F2C2C2C5F97975FC5975F97975F975F8585855F9797005F5F494949A7A7A7494949
2C2C2CB6B6B64949492C2C2CA7A7A7494949494949C5C5975F975F005F5F97C597979797
5F975FC5C5C549494973737397C5975F975F000049494949B6B6B65F975F2C2C2C5F9797
B6B6B67373732C2C2C2C2C2CC5C5C55F5F5F2C2C2C2C2C2CB6B6B6858585005F5F2C2C2C
B6B6B65F975F5F9797C5C5C5EFEFC5EFFFEF5F9797858585EFFFC5C5C59797C5C55F5F5F
E1E1E15F97975F5F5F5F5F5F
00002C2C00002C00002C00002C2C2C000000002C002C2C2C000000000000002C002C0000
002C00002C00002C002C2C2C2C2C2C000000494949002C00002C002C2C2C002C00002C00
2C000000002C00002C00002C2C000000002C0000002C000000002C002C000000495F975F
C597972C2C2C002C0000002C979797B6B6B62C2C2C2C2C2C2C2C2C004900D4D4D42C2C2C
0000002C2C2CC5C5C5B6B6B68585855F5F5FC5975F004900B6B6B6C5C5972C2C2C2C2C2C
002C008585859797972C2C2C004900C5C597C5C5972C2C2C494949C597972C2C2C494949
EFC597C5C59797975F97975F2C2C2C494949A7A7A7FFC5C5002C00494949494949B6B6B6
C5EFC52C2C2C5F5F5FB6B6B62C2C2C005F5F97C5C5005F5F494949737373002C005F9797
B6B6B6979797C5C5C597975FC5C5C5B6B6B65F975FB6B6B6C5EFC500002C2C2C2C000049
B6B6B6004900000049C5EFC5FFFFEFC5C5EF2C2C2C002C005F97C55F5F5F005F5F979797
4949495F97975F5F5F4949494949492C2C2C5F5F5F005F5F2C2C2C4949495F5F5F5F5F5F
5F5F5F2C2C2C4949494949497373730049005FC597A7A7A75F5F5F5F975FA7A7A75F5F5F
5F00004949495FC59785858573737349494997C5C55F979749494997C5975F975F5F975F
97975F494949494949005F5F97C55F494949494949005F5F005F5F5F97972C2C2C2C2C2C
97C5C55FC597004900979797494949005F5F494949009797B6B6B65F5F5F005F5F005F5F
4949494949495F975F2C2C2C97979700002C97975F2C2C2CC5C5975FC5C5858585494949
97C55F2C2C2C979797005F5F5F975F979797002C0097975F49494900002C2C2C2C5F975F
2C2C2C97C5972C000085858597975F97975F2C2C2C97975F2C2C2CA7A7A700002C2C2C2C
C5C5C500002C8585854949497373734949490049002C2C2C005F005F5F5F4949495F9797
5F97975F975F5F5F5F494949737373494949737373494949005F5F2C2C2C858585005F5F
005F5F97C59749494949494997C55F8585855F979785858597C5979797977373735F5F5F
5F5F5F979797005F5F2C2C2CB6B6B67373732C2C2C5F5F5FB6B6B65F5F5F2C2C2C5F5F97
B6B6B65F5F974949492C2C2CA7A7A75F975F004900494949737373C5C5C55F5F5F005F97
EFFFC5C5EFC5A7A7A7FCFCFC858585EFEFC5E1E1E1E1E1E1A7A7A7494949A7A7A7FFEFFF
C5C5C5737373494949494949
2C000000002C002C0000000000000000002C0000002C2C2C00002C00000000002C000000
002C002C2C2C49000000002C002C000000007373732C2C2C002C0000002C2C00002C2C2C
002C002C2C2C2C2C2C002C002C2C2C005F5F494949002C002C2C2C2C00005F5F5FEFEFC5
2C2C2C2C2C2C2C2C2C0049005F975F2C2C2C2C2C2C002C00002C0097975F2C2C2C002C00
2C2C2C5F975FC5C5C5002C0000002C005F5FC5C5C5C5C5975F5F5FC5EF972C2C2C97C55F
B6B6B6C597972C2C2C002C00EFC5C5C5975F2C2C2C2C2C2CC5C5972C2C2C5F5F5FC5C597
2C2C2C002C00C5C5975F975F005F5F4949492C2C2CB6B6B6FFEFC5975F5F00002C97C5C5
A7A7A7C5975F2C2C2C5F9797B6B6B60049002C2C2CC5EFC52C2C2C49494997C5975F5F5F
00002CC5C55F2C2C2C5F5F97A7A7A7C5C5975F5F5F5F5F5FB6B6B6005F00C5C597B6B6B6
000000A7A7A7C5C5974900002C2C2CC5C5C5494949A7A7A797975F4949495FC5C5494949
5F975F2C2C2C5F97975F5F5F2C2C2C005F002C2C2C5F5F5F5F975F4949492C2C2C494949
5F97972C2C2C4949494949495F5F5F5F5F5F4949495F5F5F97C5977373734949495F975F
97C5978585859797975FC59797979797C5975F975F5FC597979797A7A7A75F5F5F005F5F
5F5F5F005F5F2C2C2C2C2C2C2C2C2C0049007373735F5F0097C5C597C5C597C597494949
2C2C2C858585B6B6B65F5F5F7373738585855FC59797C5975F5F5F494949004900494949
2C2C2C2C2C2C2C2C2C97C59797975F49494949494900975FB6B6B6C5C59700490097975F
5F5F00C5975FC5C59749494997C55F97975F2C2C2C9797972C2C2CC597972C2C2CA7A7A7
5F975F002C0097979700002C002C005F5F5F00002C97975F2C2C2C9797972C2C2C2C2C2C
C5C5C55F5F007373732C2C2C97975F0049005F5F5F4949495F97975F97975F97975F975F
005F5F97975F4949495F5F00979797005F5F7373734949494949495F5F5F5F975F494949
005F5F97C5975F975F737373858585A7A7A79797975F5F5F494949A7A7A75F5F5F494949
7373735F5F5F5F5F5F2C2C2CB6B6B65F975F2C2C2C005F5FC5C5C55F975F2C2C2C5F97C5
97C5975F5F5F4949492C2C2CC5C5C5E1E1E15F97975F5F00C5C5C5B6B6B697C597EFEFEF
737373737373C5EFC5C5EFC54949492C2C2CC59797D4D4D45F5F5F490000002C00C59797
B6B6B65F975F494949005F5F
2C00000000000000002C0000002C002C0000000000002C000000002C0000002C00000000
0000002C2C2C2C000000002C00002C00002C49000000002C490000000000000000000000
00000000002C002C00000000002C00002C0000002C2C2C2C2C2C2C2C0000D4D4D4975F5F
2C2C2C2C2C2C2C2C2C975F00C597970000002C2C2C0000005F5F5FA7A7A72C2C2C2C2C2C
494949C5EFC52C2C2C2C2C2C002C009797975F5F00000000002C00B6B6B6A7A7A7494949
C5C5975F975FC5C597EFEFC5494949002C00737373EFC5972C2C2C979797C5C5972C2C2C
005F00C5C5972C2C2C494949A7A7A72C2C2CA7A7A797975FA7A7A7E1E1E1FFEFC5FFEFC5
979797C5EFC597975FEFEFC55F975FC5C597004900A7A7A797975F2C2C2C5F5F5F5F5F00
00002C005F5F4949492C2C2C5F979700490097975F97C5975F975F2C2C2C97C5C597C5C5
C5FFEF858585494949494949C5C5974949495FC5975F5F978585859797975F5F5F005F5F
004900005F5F4949495F5F5F5F5F5F4949494949494949495F975F5F5F5F494949737373
5F5F5F5F97970049002C2C2C2C2C2C5F975F4949495F975F5FC5975F5F5F4949495F9797
9797975F975FA7A7A75FC5975F5F5F5FC5C5858585005F5F97C597A7A7A75F9797004900
5F5F5F49494900002C002C005F5F5F4949494949499797975FC5C52C2C2C2C2C2C97C597
5F975F97C59797975F2C2C2C4949490000005F5F5F5F975F005F5F005F5F005F00494949
005F5F9797975F975F002C000049005F9797005F5F5F5F5F00002CEFEFC5C5979797C597
4949495F5F0097975F2C2C2C97975F002C005F975F005F5F97C55F5F5F5F97C5972C2C2C
97975F0000002C2C2C002C00002C0097975F2C2C2C97975F2C2C2CB6B6B6B6B6B697C5C5
C5C597C5C5C5B6B6B62C2C2C5F97975F5F5F5F975F5F979773737349494997975F5F5F5F
4949495F975F5F5F004949495F975F494949494949494949005F5F5F9797A7A7A7737373
5F97978585859797979797975F5F5F5F5F5F7373735F5F5F494949A7A7A74949492C2C2C
5F5F5F005F5F4949492C2C2C979797005F5F2C2C2C2C2C2CB6B6B65F975F004900A7A7A7
C5C5C585858597975F5F97C5B6B6B6737373C5EFC5B6B6B6B6B6B6005F5FFFC5C5B6B6B6
4949492C2C2CA7A7A75F975F4949492C2C2C00002CE1E1E15F5F5F5F5F000000002C2C2C
EFC5C55F975F8585855F5F5F
2C00000000002C0000002C002C000000002C002C002C2C2C0000000000000000002C0000
00000000002C0000005F5F5F002C002C2C2C002C0000002C00002C2C00000000002C0000
2C00002C2C2C002C00002C00002C0000000000002C00002C2C2C2C2C2C2CC5C5C5D4D4D4
2C2C2C004900858585B6B6B62C2C2C2C2C2C2C2C2C00002CB6B6B62C2C2C2C2C2C2C2C2C
97C597975F5F00002C002C005F5F5FC5C5972C2C2C2C2C2C97C597C5C59749494900002C
B6B6B6975F5F2C2C2CC5C597C5C597C5C597C5C5972C2C2C979797C5C5972C2C2C5F5F00
B6B6B62C2C2CA7A7A7C5975F00000097C5972C2C2C004900858585A7A7A7FFFFEFFFEFC5
2C2C2C2C0000B6B6B6EFC5C5004900979797C5C5C5B6B6B6B6B6B6C5C55F00002C97C597
C5C5972C2C2C494949494949002C00A7A7A700002C5F975F2C2C2C97C55F97975F97975F
A7A7A797C5979797974949495F5F00A7A7A75F5F979797972C2C2C5F975FC5EFC55F975F
5F975F2C2C2C5F975F494949005F5F5F97972C2C2C2C2C2C0049005F5F5F5F975F2C2C2C
005F5F005F5F5F9797494949005F5F4949495F5F5F005F5F005F0097C597A7A7A797C597
97C597005F5F00975F97C5C5005F5F8585858585854949495F9797737373005F5F5F5F5F
5F5F5F4949494949495F5F005F975F5F975F5F5F5FA7A7A79797974949490049002C2C2C
5FC5977373737373735F975FA7A7A79797974949495F5F5F5F5F5F2C2C2C005F5F5F5F5F
5F97975F5F5F2C2C2C005F005F975F737373A7A7A700002C2C2C2CEFFFEF5F5F5F2C2C2C
2C2C2CC597972C2C2C5F5F5F5F975F858585002C0097975F00002C975F5F9797972C2C2C
7373732C2C2C002C002C2C2C494949C5C597737373C5C59797C5C5EFEFC5A7A7A7C5C597
2C2C2CC5C5C5494949979797004900005F5F5F5F5F004900A7A7A74949495F5F5F5F5F5F
4949495F975F4949494949495F975F5F5F5F5F975F8585855F97975F97975F975F858585
737373494949494949A7A7A75F5F5F2C2C2C97C597005F5F2C2C2C5F5F975F975F494949
5F5F5F5F975F4949492C2C2C7373735F9797494949005F5FC5EFC597C5975F5F5FC5EFC5
97975FC5C5C5858585C5EFEF5F5F5F2C2C2C975F5FC5C5C54949494949497373735FC597
2C2C2C2C2C2C2C2C2CC5EFC55F5F5F2C00002C2C2C975F9797C597005F5F2C2C2C000000
A7A7A797C597737373494949
00002C2C000000002C002C002C00002C00002C2C2C002C0000000000002C2C2C2C000000
2C00000000002C2C2C2C2C2C2C0000002C000000002C2C2C2C2C2C002C00002C00002C00
2C000000002C2C2C2C002C002C2C2C002C00002C002C2C2C2C2C2C2C2C2C2C2C2CC5C5C5
5F5F5FEFEFC5EFC5C5C5EFC5C5975F2C2C2CA7A7A7C5C5C5C5C5972C2C2C002C00C5C597
E1E1E12C2C2C2C2C2C004900C5C5972C2C2C002C002C2C2CB6B6B62C2C2C00002CA7A7A7
975F5F002C005F975FC5C597002C002C0000C5C597A7A7A7C5C597005F5F97975FA7A7A7
2C2C2C97C55F7373732C2C2CA7A7A72C2C2C2C2C2C9797972C2C2C97975F002C00737373
5F5F00002C002C2C2CD4D4D42C2C2C00002C97C5C597C597002C00C5C5C5C5EFC5A7A7A7
5F5F975FC5972C2C2C979797002C002C2C2C2C2C2C005F5F5F5F5F2C2C2C0073002C2C2C
4949495F975F002C005F5F5F5F979797C5979797975F975F858585737373005F5F494949
C5EFC597C5974949494949490073004949495F5F974949492C2C2C0049005F5F5F007300
2C2C2C00975F5F5F5F737373002C004949494949495F97974949495F97975FC5C55FC597
5F97974949494949495F97978585855F5F5F7373734949494949497373732C2C2C494949
4949492C2C2C4949492C2C2C494949005F5F5FC5975FC5C500000073737397EFC597C5C5
97C5C597C5974949495F5F9797979797C55F5F5F5F5F5F5F005F5F4949495F5F5F5F5F5F
5F975F2C2C2C5F5F5F5F979797C59700002C0049004900002C2C2CEFEFEF002C0097975F
5F975F97C55F9797972C2C2C49494997975F0000498585854949495F5F005F975F2C2C2C
7373732C2C2C979797C59797975F5F2C2C2C975F5F494949B6B6B62C2C2C005F5F97975F
2C2C2CB6B6B649494997C5975F5F5F005F5F4949494949495FC597005F5F7373735F5F5F
5F5F5F5F975F8585855F975F8585855F975F7373735F5F5F5F9797858585494949494949
8585852C2C2C2C2C2CA7A7A77373732C2C2C9797975F975F4949495F5F5F5F975F5F5F5F
49494997C5975F5F0049494997979797C5975F975FB6B6B6858585B6B6B697C5C5858585
5F5F5F2C2C2CA7A7A797975F5F5F5F2C2C2C002C00B6B6B65F975F2C2C2C2C2C2CC5C5C5
4949492C2C2C2C0000D4D4D45F975F4949492C2C2C00002CEFEFC57373732C2C2C2C2C2C
494949FFEFC57373735F5F5F
000000002C00002C000000002C0000002C000000002C00002C00002C000000002C000000
2C00002C00002C2C2C00002C00002C0000002C2C2C002C000000002C2C2C002C00002C00
2C0000000000002C00002C000000002C00002C2C2C2C2C2C2C2C2C2C2C2C002C00858585
C5EFC5A7A7A72C2C2CC5EFC5D4D4D4C5EFC5C5C5C55F9797C5EFC5858585C5EFC5B6B6B6
C5C5972C2C2C00000097975F5F5F5F2C2C2C2C2C2C97C5974949492C2C2C004900C5C597
0049002C2C2CB6B6B65F5F5F2C2C2C97975FC5C597002C00A7A7A7858585005F5FC5C597
97C55F5F975FC5975FC5C5972C2C2C5F5F00858585005F009797972C2C2C2C2C2C979797
B6B6B6002C00494949A7A7A7975F005F5F5F005F5F979700002C00494949C5EFC5494949
002C0073737397EFC5737373C5C597005F005F975F2C2C2C5F5F002C2C2C5F5F5F494949
4949492C2C2C4949495F5F5F97C55F494949A7A7A773737397975F97C5975F9797A7A7A7
494949B6B6B69797978585854949492C2C2C005F5F737373005F5F494949494949737373
4949494949495F5F5F00975F7373732C2C2C494949494949005F5F5F97975F975F004900
4949495FC5975F975F5F5F5FC5C5974949495FC5975F975F0049005F975F4949495F5F00
49494900490000002C979797005F5F5FC5975FC5C5737373A7A7A74949495F5F0097C5C5
2C2C2C494949005F5F9797974949494949492C2C2C0049004949495F5F000049002C2C2C
2C2C2C4949495F97975F5F005F5F5F00002C2C2C2C5F5F002C2C2CFCFCFCA7A7A75F005F
002C0097975F97975F2C00005F5F5F5F975F2C2C2C5F975F5F5F5F5F975F85858597975F
A7A7A7975F5F2C2C2CA7A7A72C2C2C002C002C0000005F5F979797000000005F5F2C2C2C
5F5F5FB6B6B64949495F97974949494949495F975F2C2C2C9797977373735F979797975F
97979797975F4949498585855F9797005F5F5FC5974949497373735F97974949492C2C2C
5F97972C2C2C2C2C2C8585855F975F2C2C2C5F5F5F5F975F5F5F5F5F5F5F97C597494949
B6B6B697979797979700975FA7A7A7975F97C5C5C5C5EFC55F5F5F4949492C2C2C97C597
5F975F2C2C2C494949C5C5975F5F5F00002C2C2C2CB6B6B65F5F5F49494900002CA7A7A7
5F97972C2C2C002C00737373B6B6B67373734949492C2C2CC597C59797975F5F5F004900
2C2C2CEFEFEFC5EFC55F5F5F
0000000000000000002C000000002C2C000000000000000000000000002C0000002C0000
00002C002C00000000000000002C002C2C2C00002C002C002C0000002C00002C00000000
00002C000000002C0000002C2C2C2C002C002C2C2C002C00002C0000002C2C2C2C5F5F00
975F5F2C2C2C2C2C2C5F5F5FEFC5C52C2C2C2C2C2C2C2C2CC5EFC5C5C597494949000049
C5EFC55F5F00B6B6B6C5EF972C2C2C2C2C2C5F975FD4D4D42C2C2C2C2C2CC5C5972C2C2C
2C2C2C5F975F975F5F002C0097C597B6B6B62C2C2C5F5F5FA7A7A72C2C2C97C597A7A7A7
2C2C2CC5C5972C2C2CC5C597C5C55FC5C5972C2C2C975F5F2C2C2C97975F2C2C2C975F5F
A7A7A72C00000000005F9797C5EFC5002C005F5F5FC5EFC5002C002C2C2C5F97975F0000
5F5F5F2C2C2CB6B6B62C2C2C002C00B6B6B6005F5FEFFF9797975F5F975F4949495F5F00
4949492C2C2C4949490049004949492C2C2C5F975F2C2C2C73737397C5C5C5EFEF97C5C5
7373735F9797737373B6B6B697975F5F975F494949005F005F975F5F975F5F5F5F005F5F
5F5F5F4949495F5F5F5F5F5F005F5F005F5F0049004949495F5F5F5F5F5F858585005F5F
4949495F975F5FC5978585857373735F975F5F97975F975F5F5F5F5F5F5F5F975F005F00
4949492C2C2C5F975F8585855F97975F97975F979797C59749494997C5C5A7A7A7979797
97C59700975F97C5975F97978585855F975F005F5F494949005F008585855F975F5F975F
9797978585852C2C2C5F0000000000975F5F2C2C2C97C59785858597C5C52C2C2CA7A7A7
494949A7A7A797975F00000097C55F5F5F5F5F97974949497373734949492C2C2C97975F
2C2C2CC597972C2C2CC5C59700000000002C2C2C2C7373735F5F00002C00B6B6B6C5EFC5
B6B6B697975F4949497373737373739797975FC59797C5975F979797979797C5C5005F5F
8585855F975F2C2C2C5F5F5F5F975F2C2C2C5F9797005F5F2C2C2C5F97975F5F5F005F00
9797974949494949498585855F975F5F5F5F97975F8585855F975F97C597737373979797
C5EFC55F5F5F85858597C59797C5974949495F5F5FA7A7A75F5F5F002C002C2C2CEFEFC5
4949490049002C2C2CB6B6B67373732C2C2C2C2C2C73737397C5975F5F5F2C2C2C5F5F5F
C5EFC57373732C2C2C5F5F5FC5EFC55F97975F5F5F005F5F494949EFEFC55FC597737373
5F975FC597C5EFEFC55F5F5F
2C2C2C002C0000000000002C00002C00002C0000002C000000000000002C2C0000490000
0000002C2C2C002C002C2C2C00002C2C2C2C2C00005F5F5F0000000000002C0000000000
00002C2C0000002C00490000002C00002C002C00000000002C000000002C005F5F858585
2C2C2C2C2C2C002C00494949B6B6B62C2C2C2C2C2C002C00C5C5C52C2C2C002C002C2C2C
97C597C5EFC5494949005F5F97975FC5EF97C5975FEFC5C5494949B6B6B6B6B6B62C2C2C
2C2C2CC5C597004900494949C5C5972C2C2C000000C5C5972C2C2C737373C5C5972C2C2C
5F975F2C2C2C5F97978585852C2C2CC5C5975F5F5F5F970097C5972C2C2C97975F2C2C2C
97975F2C00002C00005F5F5FB6B6B6002C00002C0097EFC50000492C2C2C5F5F5FC5C5C5
2C2C2C00002C5F975F5F5F002C2C2CA7A7A72C2C2C494949975F5F005F5FA7A7A75F9797
0049004949492C2C2C5F5F000049000000005F5F004949497373735FC5975F5F5F97C5C5
B6B6B6979797A7A7A75F9797737373B6B6B65F975F5F5F5F4949495F5F005F975F494949
5F5F00005F5F4949495F5F5F5F5F5F5F5F5F494949494949005F5F5F975F5F5F5F5F975F
005F004949495F97978585855F975F5F975F5F979700975F9797975F5F005F5F5F5F5F00
2C2C2C4900009797975F975F5F979797979797C59749494997C5975F9797A7A7A7494949
5F5F5F5F9797005F5F5F5F5F5F5F5F4949492C2C2C2C2C2C5F975F5F5F5F5F5F5F979797
5F5F5F97975F002C0097975F2C2C2CC5C597005F5FA7A7A72C2C2CFCFCFC2C2C2C97C5C5
97979749494997975F5F975F2C2C2C4949494949490049004949498585852C2C2C97C597
004900C5975F005F5F97979700490097C597C5C5972C2C2CC5EFC5858585000049FFFFC5
2C2C2CA7A7A7A7A7A75FC5975F97975F97977373737373735F5F5F4949495F9797494949
2C2C2C5F97972C2C2C2C2C2C5FC5975F5F5F7373735F5F5F494949858585494949005F5F
97C5975F975F73737397C5979797978585857373734949499797975F975F737373494949
979797494949005F5F4949498585855F5F5F2C2C2C8585855F97975F5F5F2C2C2C979797
97C5975F5F5F2C2C2C5F5F5F5FC5974949492C2C2C2C2C2CB6B6B6858585005F5F005F5F
C5EFC55F97975F975F5F5F5FEFEFC5E1E1E197C597979797979797B6B6B6E1E1E197FFC5
97C597C5C5C55F9797005F5F
2C0000002C002C000000002C00002C00002C0000000000002C000000002C000000000000
2C2C2C2C000000002C002C00490000002C000000000000000000000000002C2C2C2C0000
00002C00002C2C0000002C002C2C2C002C0000002C2C0000490000002C005F5F5F97EFC5
2C2C2C00002C2C2C2C2C2C2C975F5F2C2C2C00002C005F5FC5C5C52C2C2C002C002C2C2C
97C5972C2C2C2C2C2C494949C5C5974949492C2C2C5FC597A7A7A72C2C2CB6B6B697975F
EFC597C5C5C597975FEFC597975F00490000C5C597494949000049C5C597494949004900
975F5F2C2C2C97975F00002CC5C5972C2C2C97C5972C2C2C9797975F5F5F4949495F5F5F
494949C5EFC52C2C2C494949C5EFEF5F5F00002C005F975FC5EFC52C2C2C494949C5EFEF
2C2C2C002C005F5F5FC5C5970000005F5F5F2C2C2C49494997C55F2C2C2C005F5F002C00
C5EFC57373734949495F5F5F2C2C2C5F5F002C2C2C494949005F004949492C2C2C737373
00005F5F975FB6B6B6005F5F5F5F975F975FA7A7A79797975F5F5F005F5F4949495F975F
5F5F5F2C2C2C005F5F5F5F5F4949497373735F975F4949495F5F5F005F005F5F5F494949
4949494949495F5F5F97979749494900975F4949497373735F9797005F005F5F5F494949
004900002C005F97C57373735FC5975F97C5005F5FA7A7A7005F5F7373735F5F5F5F5F5F
8585855F975F5F975F5F5F5F4949494949494949495F975F5F5F5F5F975F5F975F975F5F
00002C5F5F5F2C2C2C97975F5F975F97C5C5858585EFC5C52C2C2C9797974949495F005F
5F975F0049002C2C2C4949495F5F0000004997C597005F002C2C2C97C5975F5F5F5F975F
97975F85858585858549494997975F004900737373005F5FC5C597002C0097C5C55F5F00
2C2C2C7373735F5F5F5F97975F5F5F005F5F7373732C2C2C9797972C2C2C8585855F975F
4949497373735F5F5F4949495F975F4949495F975F858585737373979797979797979797
979797858585979797737373005F5F5F975F494949005F5F2C2C2C5FC5977373732C2C2C
7373738585855F5F5F2C2C2C97975F5F5F5F4949492C2C2CB6B6B65F975F4949492C2C2C
B6B6B69797977373732C2C2CC5C5C5005F5F4949492C2C2CD4D4D497C5C55F5F5F00975F
9797975F5F97A7A7A75F9797C5EFC5005F5F979797B6B6B6E1E1E15FC55F2C2C2C494949
C5C597C5C5C55F975F5F5F5F
002C00002C002C00002C000000002C000000002C00002C002C2C2C000000000000000000
2C2C2C2C00002C2C2C0000000000002C2C2C2C00002C000049000000002C00002C00002C
2C000000002C0000002C2C2C0000004949492C00002C2C2C002C002C2C2C5F5F5FC5EFC5
002C0000002C2C2C2C5F975F5F00004900002C2C2C5F975FD4D4D42C2C2C4900005F975F
C5C5C52C2C2C00002C858585C5975F002C002C2C2CC5C59700490000002CA7A7A7C59797
2C2C2CB6B6B6C5C597494949B6B6B6C5C5C597975F975F5F858585C597972C2C2C97C597
2C2C2C97C5972C2C2C97975F2C2C2C007300494949005F5F2C2C2C5F5F5F494949494949
97C5C5EFC5C5C5C5972C2C2CC5C597C5EFC5004900005F5FEFEFC55F00000049005F9797
5F5F0000002C5F5F5FC5C5C5002C00005F5F002C00005F5F97C5C5002C00005F5F5F5F00
97C5972C2C2C97C59700002CA7A7A72C2C2C004900005F5F4949494949495F5F5F494949
00002C9797975F5F5F005F5F5F97975F5F5F5FC5975F5F5FA7A7A75F5F5F5F975F005F5F
5F5F5F5F975F2C2C2C005F5F5F5F5F5F5F5F005F5F737373005F005F5F5F494949005F00
494949005F5F5F97975F975F5F5F5F5F5F5F85858500975FA7A7A75F5F5F7373735F5F5F
2C2C2C5F97975F9797005F5F005F975F5F5F00975F2C2C2C5FC5974949497373735F9797
5F979700975F4949494949494949494900002C2C2C005F5F2C2C2C5F97972C2C2C737373
2C2C2C2C2C2C005F5F9797975F5F5FEFC5C52C2C2C5F9797002C00979797B6B6B697C5C5
737373975F5F5F975F2C2C2C5F979797975F5F975F4949497373730049002C2C2C737373
002C007373732C2C2C975F5F4949498585852C2C2CB6B6B62C2C2C737373C5C5C5000049
4949495F975F494949005F5F7373734949497373734949495F97974949497373735F9797
2C2C2C5F975F5F975F5F975F9797975F979797C5979797975F97975F97975F5F5F979797
5F5F5F005F5F494949005F5F494949005F5F5F97975F5F5F2C2C2C5F5F5F7373735F5F5F
2C2C2C5F97975F975F49494949494985858500975F2C2C2C2C2C2CB6B6B67373732C2C2C
975F97975F5F97C5975F975FC5C5C5C5FFEF00975F858585C597C55F5F5FC5EFC5009797
9797975F97975F5F5F979797B6B6B65F5F5F5F5F5F494949D4D4D497C5975F5F5F2C2C2C
002C00979797B6B6B6494949
002C002C0000002C000000000000002C00002C2C2C2C00000000000000000000002C0000
002C00002C004900000000002C00002C2C2C2C2C2C00002C00000000002C2C2C2C00002C
2C00000000002C2C2C2C2C2C00002C002C0000002C2C2C2C0000002C2C2C494949C5C5C5
2C2C2C00002C2C0000B6B6B62C2C2C002C002C2C2C97979797975F2C2C2C2C2C2C858585
C5975F002C0000002C97C55F2C2C2C002C005F5F5FA7A7A7002C00002C00C5EFC52C2C2C
2C2C2CB6B6B62C2C2C004900A7A7A70049002C2C2CC5C5972C2C2C97975FA7A7A797975F
B6B6B6975F5F5F5F5F975F5F000000C59797002C004949495F975F2C2C2C5F5F5F494949
FFFFEF2C2C2CEFC5C5EFC5C5C55F5F494949C5C5C52C2C2CB6B6B6C5EFC52C2C2C5FC597
B6B6B65F5F00494949C5C5C52C2C2C002C00C5975F2C2C2CB6B6B62C2C2C005F5F97C597
0000492C2C2C4949492C2C2C002C004949495F97974949495FC55F005F005F5F5F2C2C2C
005F00005F004949495F5F5F5F5F5F5F9797A7A7A79797975F5F5FA7A7A75FC597494949
4949495F5F5F5F975F4949495F975F5F5F5F005F5F5F5F5F5F5F5F2C2C2C4949495F975F
0000497373735F5F5F7373735F975F5F5F5F494949005F5F5F97975F5F5F005F5F2C2C2C
5F975F5F97975F5F97737373A7A7A7005F5F005F5F5F97978585855F975F2C2C2C737373
005F5F005F002C2C2C4949490049004949490049004949497373730000002C2C2C5F5F5F
005F5F5F97975F5F5F97C597000000C5C5C5002C00004900EFC5C597C5C52C2C2C737373
C5EFC52C2C2C4949495F5F5F7373732C2C2C979797005F004949498585852C2C2C5F5F5F
7373732C2C2C5F975F00490097975F4949495F975FC5C5C597C5C5C5C5C52C2C2C2C2C2C
7373737373735F5F5F005F5F5F5F5F005F5F5FC5975F5F5F9797978585855F9797979797
5F97975F97978585859797975F5F5F5F5F5F979797005F5F5F9797005F5F494949494949
5F975F005F5F2C2C2C5F5F5F5F5F5F4949498585855F975F5F5F5F0049005F9797737373
005F5F975F5F7373735F5F5F5F5F5FB6B6B6A7A7A75F975F2C2C2CC5C597C5C5975F9797
C5C5C52C2C2C2C2C2CA7A7A7D4D4D42C2C2C97979797EFC5C5EFC55F5F5F5F5F5F979797
97C5C55F9797494949494949B6B6B697C5977373732C0000494949B6B6B65FC5975F5F5F
2C2C2C002C009797975F5F5F
002C002C2C2C00002C002C002C000000002C0000000000002C000049000000002C490000
002C0000002C002C002C2C2C002C002C00000000002C00000000000000002C2C2C00002C
00002C00002C00002C2C2C2C2C00002C2C2C00002C2C2C2C00002CC5C597EFEFC5C5C597
2C2C2C002C005F975FD4D4D40049002C2C2C0000499797972C2C2C2C2C2C2C2C2C5F9797
2C2C2C2C2C2C2C2C2CC5C5C52C2C2C2C2C2CC5C5974949492C2C2C2C2C2CD4D4D42C2C2C
2C2C2CB6B6B62C2C2C2C2C2C975F5F2C2C2C97C5972C2C2C5F5F5F975F5F00002CC5C597
004900A7A7A7002C0000004997975F97975F5F975F002C004949492C2C2C2C2C2C975F5F
E1E1E100002C002C00FFEFC549000000002CB6B6B6C5C597975F5F5F5F5FEFEFC5EFEF97
002C00C5C5C5C5C55F97C59797975F00002CEFEFC52C0000A7A7A72C2C2C2C2C2CC5C597
2C2C2C5F5F0000002C5F5F0000002C97C597002C002C2C2CA7A7A74949495F5F5F5F975F
2C2C2C2C2C2C5F5F5F5F5F5F2C2C2C4949495F975F5F5F5F979797737373005F5F97C5C5
5F97975F5F5F4949495F975F49494900005F5F5F005F5F5F0097975F5F5F4949492C2C2C
979797005F005F97975F975F5F975F4949495F5F5F5F5F5F5F975F005F5F494949002C00
5F5F5F005F5F5F5F5F8585852C2C2C4949495F975F97C597005F5F494949494949005F5F
005F5F4949494949492C2C2C4949492C2C2C8585855F975F4949492C2C2C5F5F5F5F9797
5F5F5F97C5970049004949492C2C2C2C2C2C97975F005F97005F5FE1E1E12C2C2C2C2C2C
979797C5C597A7A7A700002C5F5F5F5F97972C2C2C9797975F975F004900979797737373
5F975F9797978585855F5F5F2C2C2CB6B6B6005F00EFEFC5737373C5C5C5EFEFEF2C2C2C
5F5F5F49494997C59700975F5F97974949498585855F97975F97975F97975F97975F975F
7373735F5F5F4949495F5F5F005F5F4949495F975F5F5F5F4949495FC5975F5F5F494949
737373494949005F5F5F975F5F975F5F5F5F4949495F975F5F9797005F5F4949495F9797
5F975F005F5FB6B6B69797975F9797A7A7A7005F5F737373D4D4D4C5C5C54949492C2C2C
B6B6B65F975F5F5F5F4949494949495F9797494949494949979797C5C5C55F97972C2C2C
5F5F5F97C5975F5F5F2C2C2C494949B6B6B697C5975F5F5F2C2C2C494949C5C5C55F9797
0000732C2C2C0000495F5F5F
00002C002C002C2C2C002C002C2C2C002C000000002C2C2C2C2C2C00002C00002C00002C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C0000002C00002C00002C0000002C
00002C002C0000002C9797972C2C2C00002C2C0000005F00975F5FEFEFC597C597C5EFC5
97975FB6B6B6EFC5C5E1E1E1EFEFC52C2C2CC5EFC5EFEFC5C5975F004900005F5FC5C597
2C2C2C2C2C2C5F5F5F9797972C2C2C2C2C2CA7A7A72C2C2C004900A7A7A7C59797002C00
2C2C2CC5C5C5002C00C5C5972C2C2C002C00A7A7A7002C0097C5972C0000004900A7A7A7
490000975F5F2C2C2C2C2C2C2C2C2C975F5F00004900975F002C0097975F2C2C2C494949
FFFFC52C0000002C00EFC5C55F0000002C00494949E1E1E1002C00000000979797002C00
2C2C2C494949C5C5975F5F5FB6B6B6C5C59797C5C5C5C597C5C5C5C5C5C5005F00B6B6B6
2C2C2CC5EF9700002CC5C5972C2C2C5F979700004949494997979700002CC5EFC55F975F
2C2C2C5FC5974949492C2C2C0049002C2C2C0049002C2C2C5F5F5F005F5F5F97975F5F5F
5F975FA7A7A75F5F5F005F5F5F97975F5F5F005F5F5F5F5F5F5F5F5F5F972C2C2C494949
4949495F975F005F5F005F005F979700005F5F5F5F5F5F5F5F5F5F5F975F4949492C2C2C
7373735F5F5F5F5F5F5FC5C55F97975F9797A7A7A7005F5F2C2C2C5F5F5F005F975F5F5F
4949494949492C2C2C5F5F005F5F5F5F975F4949495F5F5F2C2C2C7373735F97975F5F5F
002C002C2C2C002C00494949A7A7A75F5F972C2C2CA7A7A75F975F2C2C2C979797490000
49000085858597C5C597C5C54949499797975F5F5F5F5F5F9797974900009797972C2C2C
975F5F005F5F5F5F5F2C2C2CA7A7A72C2C2CE1E1E100490097C5C5E1E1E12C2C2C005F5F
5F97975F97978585855F97975F5F975F97975F97974949495F5F5F4949494949495F5F5F
4949495F9797005F5F4949495F97974949494949495F975F5F5F5F737373005F5F494949
5F9797005F5F4949498585855F97975F9797005F5F97C59797979797979700979797C597
737373979797A7A7A74949495F5F975F97975F5F5F49494949494997C5C55F5F5F494949
2C2C2C7373735F97975F5F5F2C2C2CA7A7A77373730000492C2C2C5F5F5F97C5C55F9797
4949495F5F5F97EFC55F975F2C2C2C2C2C2CD4D4D45FC55F4949492C2C2C2C2C2CC5EFEF
B6B6B65F975F7373735F5F5F
2C00002C00000000002C2C2C2C00002C00002C0000002C002C2C2C002C000000002C2C2C
002C002C2C2C2C2C2C2C2C2C00002C00002C2C2C2C00002C2C2C2C00002C2C0000004900
2C0000000000002C00002C00002C00002C00002C00A7A7A7C5C5C54949492C2C2CB6B6B6
C5EFC5C5C5C52C2C2C5F5F5FC5EFEFD4D4D48585855F5F5FC5EFC5979797A7A7A7B6B6B6
5F5F00005F00C5C55F975F5F00002C97C597C5C5972C2C2C004900A7A7A7975F5F2C2C2C
97C597C55F5F2C2C2CB6B6B62C2C2C004900A7A7A7002C005F975F2C2C2C5F5F5F494949
00002C00002C4949492C2C2C0000002C2C2C97975F5F5F5F494949004900005F5F005F5F
EFFFEF0000002C2C2CB6B6B6004900002C005F5F5FC5EFC52C2C2C2C000097C5972C2C2C
00002C005F5FA7A7A7002C0085858597975F2C2C2C97C5C54949495F5F5FB6B6B6005F5F
B6B6B65FC5C597C5C5B6B6B6C5C597A7A7A70049005F5F00002C002C2C2C5F5F97490000
2C2C2C5F5F5F2C2C2CA7A7A75F97974949492C2C2C4949495F5F5F0049004949495F5F97
2C2C2C8585857373735F975F4949497373735F5F5F5F5F5F5F5F5F7373735F5F5F2C2C2C
4949494949495F5F5F97C5977373735F5F5F5F5F97005F5F4949495F5F5F2C2C2C005F00
5F5F5F5F5F5F5F97974949495F975F5F97974949495F5F5F5F97975F5F5F5F5F5F005F5F
00005F005F002C2C2C005F00005F5F4949490000490049005F97975F5F5F73737300002C
C5C5972C2C2C5FC5975F97975F5F5F9797975F5F5F2C2C2C5F5F5F2C2C2C2C2C2CE1E1E1
97EFC5C5EFEF4949492C2C2C5F97C500975F4949495F5F5F005F5F979797737373858585
5F5F5F979797A7A7A7C5C59797C597C5EFC5EFFFEFC5EFC5C5C5C52C2C2C00005F009797
5F97975F5F5F005F5F5F5F5F5F5F5F005F5F5F5F5F5F5F5F494949005F5F4949495F5F5F
4949495F5F5F5F5F5F4949495F975F9797975F5F5F97C597737373005F975F9797979797
979797858585A7A7A7A7A7A75F97979797975FC597A7A7A7005F5F5F5F5F9797975F9797
5F975F5F5F5F8585854949494949494949495FC5975F5F5F002C00000049B6B6B6737373
2C2C2C2C2C2CB6B6B65F975F5F5F5F2C2C2CB6B6B65F5F5F4949494949497373735F975F
005F5F2C2C2C4900005FC5975F97970049002C2C2CEFFFEF5F975F5F97975F5F5FC5EFEF
975F5FC5EFEFC5EFC55F5F5F
002C000000000000002C2C2C00002C000000002C0000002C00002C00002C4900002C0000
002C002C2C2C2C2C2C002C00002C002C2C2C002C004900002C00005F5F5F2C2C2C00002C
002C00002C00002C002C000000002C490000002C005F5F00C59797002C002C2C2C2C2C2C
C5C5C5002C002C2C2C2C2C2C5F5F5FC5C5C52C2C2C2C2C2C979797C5C5972C2C2C494949
B6B6B697C597002C00C5C597B6B6B6975F5F5F9797C5975FC5C59797975FC5C597979797
C5C5975F5F00A7A7A7C5C59700490097C59797975F2C0000975F002C2C2C8585852C2C2C
8585852C2C2C97975F2C2C2C5F5F002C2C2C2C2C2C005F002C2C2C5F975F2C2C2C004900
B6B6B62C00002C0000A7A7A72C2C2C002C005F5F5FC5EFC5002C0000002C9797972C2C2C
0000005F5F5F5F5F5F2C0000005F5F975F5F002C005F97972C2C2C00000097975F2C2C2C
C597972C2C2CC5C5C5002C00A7A7A7A7A7A7B6B6B697C5C597C5C5B6B6B6494949004900
5F975F2C2C2C5F5F5F9797972C2C2C4949495F97975F975F4949495F5F5F005F5F494949
0049005F5F5F7373735F9797737373005F5F005F5F5F5F5F737373005F5F5F5F97494949
494949005F009797977373734949495F5F005F5F5F00975F005F5F5F5F5F002C00494949
5F5F5F5F97975FC5C55F97975F97C5005F5F7373735F5F975F5F5F5F5F5F4949492C2C2C
2C2C2C4949490049005F5F5F00002C2C2C2C4949495F97972C2C2C5F5F5F2C2C2C494949
005F5F97C59797C5C59797972C2C2C2C2C2C494949005F00005F5F5F979797C5C5D4D4D4
2C2C2C2C2C2CFFEFC500002C002C005FC5C55F5F005F975F5F5F5F2C2C2C5F97975F5F5F
5FC5974949495FC597005F00B6B6B6C597972C2C2C2C2C2C2C2C2C494949005F5F5F5F5F
5F5F5F00975F5F5F5F494949005F5F5F5F5F005F5F5F5F5F005F975F97975F975F5F9797
5F97975F97979797979797975F97975F97975F97978585855F97975F97975F5F5F5F975F
005F974949494949495F9797494949005F5F5F5F5F8585855F5F5F5F5F5F005F5F737373
5F975F494949005F5FA7A7A74949492C2C2C494949B6B6B65F97974949492C2C2CB6B6B6
737373005F5F002C00C5C5C597C5975F975F005F5FC5C5975F97975F9797005F5F97C597
97C5975F975F5F97975F005F97C5C55F979797979797975F494949C5C5C597C5C5B6B6B6
2C2C2C2C2C2C5F5F97005F5F
2C2C2C00002C0000002C2C2C2C2C2C2C2C2C002C002C2C2C002C00002C00002C00000000
0000002C00002C2C2C2C2C2C2C2C2C00002C2C0000002C000000002C00002C2C2C000000
002C002C000000002C002C0000002C2C0000002C005F5F5FC55F5F2C2C2C2C2C2C002C00
97C5972C2C2C2C2C2C2C2C2C5F975FC5C5C500002C00002C5F5F5FC597972C2C2C002C00
975F5F2C2C2C2C2C2C97C597975F002C2C2C2C2C2CC5C5975F5F00002C00A7A7A7975F5F
2C0000A7A7A797979797C59797C597737373A7A7A7C59797979797005F5F979797002C00
97975F494949737373002C0097975F2C2C2C2C2C2C97975F2C2C2C5F5F5F5F975F005F5F
A7A7A7002C0000002CA7A7A75F5F002C2C2C5F5F5FEFEFC5002C00002C00979797002C00
2C00005F5F5F97975F0000002C2C2C975F5F00002C5F5F5F002C0000002C97C55F002C00
5F975F2C00005F97972C2C2C002C00002C005F5F5F002C007373732C2C2C5FC59797975F
5F5F5F5F5F5F97975F2C2C2C2C2C2C5F975FA7A7A75F975F4949495F5F5F5F5F5F5F5F00
2C2C2C005F002C2C2C7373734949495F975F5F5F5F5F5F5F5F5F5F005F5F5F5F5F5F975F
494949494949005F5F005F5F5F5F5F005F5F5F5F005F97975F975F005F5F2C2C2C5F975F
005F5F5F97975F5F5F5FC5975F97975F975F2C2C2C737373005F5F494949494949004900
494949005F5F5F975F494949005F5F5F975F4949490049002C2C2C5F975F2C2C2C979797
97979749494997C5C52C2C2C737373002C00002C00C5C5C573737397C55F2C2C2C2C2C2C
C5C5C55F975F2C2C2CB6B6B673737397C5C597C5C5A7A7A75F5F005F5F5F5F975F97975F
5F975F97975FC5C5C55F5F5F0049002C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C000000
4949495F5F5F7373735F5F5F5F5F977373735F975F5F97975F97975F5F5F5F975F494949
4949495F975F5F5F5F005F5F5F97974949495F5F5F5F975F5F5F5F005F5F5F5F5F5F5F5F
737373005F5F002C00494949A7A7A7005F5F4949492C2C2C9797975F975F494949494949
7373735F975F005F5F5F97979797C5B6B6B6005F5F9797975F5F5FA7A7A7A7A7A7D4D4D4
5F5F97B6B6B697C5C597C5C597979797C5C597C5C55FC5C5A7A7A7A7A7A75F97975F9797
5F5F977373738585855F005F2C2C2C4949495F5F5F4949492C2C2C2C2C2C4949495F5F5F
0049002C2C2C0000495F5F5F
00002C2C000000000000002C2C00002C0000002C002C2C2C2C0000002C002C00002C2C2C
2C000000002C2C2C2C002C002C2C2C00002C2C2C2C2C2C2C002C0000002C00002C2C0000
002C00002C002C2C2C002C00002C0000002C2C2C2C5F0000C597972C0000002C002C2C2C
B6B6B62C2C2C2C2C2C2C2C2C737373EFEFC5002C0000002C5F5F5FC5C5972C2C2C000000
7373732C2C2C2C2C2C5F975F975F5F002C002C2C2C5F9797002C002C2C2CA7A7A72C2C2C
00002CC59797002C002C2C2CC5C5972C2C2C97C5974949498585859797975F975F97975F
5F975F005F5F5F5F5F005F004949495F975F2C2C2C5F5F00002C00002C007373735F9700
979797002C002C2C2CA7A7A7979700002C00494949EFEFC5490000002C00858585002C00
00002C494949A7A7A7002C005F5F5F9797002C2C2C4949495F00002C2C2C858585002C00
5F5F5F002C00005F5F2C000000002C4900002C2C2C00000097975F002C005F5F00494949
2C2C2C97975F002C004949495F5F0097975F5F975F2C2C2C490000002C00004900737373
5F5F004949490049000049005F97975F97975F97975F5F5F4949495F975F494949005F97
7373735F5F0049494997975F5F97974949495F5F5FA7A7A75F5F5F4949494949495F5F5F
5F5F975F5F5F5F5F5FA7A7A75F975F49494985858500975F5F975F2C2C2C2C2C2C494949
005F5F2C2C2C2C2C2C5F975F494949002C004949492C2C2C5F975F4949499797975F9797
2C2C2CC5C5972C2C2C858585494949B6B6B697C5975F00002C2C2C5F5F978585855F5F00
000000C5C597C5C5C5B6B6B6C5EFC55F975F2C2C2C2C2C2C7373738585852C2C2C00002C
002C00494949858585C5EFC5EFFFFFC5C5C5979797E1E1E197C5C5C5EFC5E1E1E1FFFFFF
9797972C2C2C2C2C2C494949005F5F2C2C2C494949005F5F2C2C2C005F5F005F5F5F975F
5F5F5F005F5F5F975F5F5F5F4949495F975F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F005F5F
4949495F975F5F97974949495F5F975F97975F975F005F002C2C2C97C5C5C5C5C55FC5C5
5F97975F9797A7A7A7A7A7A75FC5C55F97979797C5B6B6B65F97975F97975F97975F97C5
A7A7A78585858585859797975F97974949494949495F5F5F005F5F494949005F5F5F5F5F
005F5F4949494949495F5F5F4949492C2C2C2C2C2C5F5F5F5F5F5F2C2C2C2C2C2C5F005F
5F5F5F4949494949495F5F5F
002C0000000000000000002C0000000000002C2C2C002C0000002C00002C002C0000002C
2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C00002C2C2C2C00002C2C2C2C002C00002C00
2C00000000000000000000000000002C2C2C00002C5F5F00975F5F2C2C2C00002C00002C
B6B6B60049002C2C2C000000494949C5C597002C00000000005F5F975F5F2C2C2C002C00
975F5F2C2C2C4900005F9797975F00002C002C00005F975F00490000002C97C5972C2C2C
2C2C2CC597972C2C2C00002CC5C5974949495F975F2C2C2C2C2C2C9797975F5F0097975F
5F975F5F5F005F975F2C2C2C7373735F5F5F5F975F5F5F5F97975F004900002C005F5F5F
A7A7A72C0000004900E1E1E1C5975F002C005F975FB6B6B600002C002C005F97975F5F00
00002C5F5F00C5C5972C2C2C494949C5975F002C00494949975F5F002C00979797002C00
000049975F000000495F5F5F00002C5F5F00005F5F2C00009797970000005F5F0000002C
2C2C2C5F975F002C0000002C000000858585000049858585002C005F975F005F00494949
5F5F5F5F5F5F0049000049005F5F5F5F5F5F5F975F5F97977373735F5F5F5F5F5F5F5F5F
0097972C2C2C2C2C2C5F5F5F7373735F975F5F5F5FA7A7A75F975F494949005F5F005F5F
85858500975F5F975F5F5F97005F5F7373735F5F5F5F5F5F5F5F002C2C2C2C2C2C005F00
5F5F002C2C2C5F9797005F004949495F5F000049005F97975FC5975F5F5F4949492C2C2C
2C2C2C002C0097EFC5A7A7A7A7A7A7005F5F2C2C2C8585852C0000000049A7A7A7005F5F
5F5F5FB6B6B649494900002C2C2C2C5F97975F97972C2C2C00002C0049005F975F979797
737373C5C5C55F5F5F2C2C2C002C002C2C2C2C2C2C5F5F5F858585C5C59700002CA7A7A7
002C00975F97C5EFC500002C5F5F004949492C2C2C97C5970049007373735F5F5F494949
5F975F00005F5F9797858585005F5F5F97975F97977373735FC5975F97979797975F97C5
5F97C55F97C597C5C5A7A7A7A7A7A7979797A7A7A75F5F5F5F5F5F5F975F005F5F2C2C2C
005F5F737373005F5F4949490049002C2C2C5F5F5F2C2C2C2C2C2C5F5F5F5F5F5F494949
5F5F5F5F5F5F5F5F5F005F5F8585855F5F5F5F5F5F005F5F7373735F975F2C2C2C005F5F
4949495F5F5F494949494949005F5F5F5F5F005F5F005F5F7373735F975F2C2C2C004900
4900005F5F5F5F5F5F5F5F5F
002C0000002C2C00000000000000002C00002C2C2C00002C0000002C0000002C0000002C
002C002C2C2C002C00002C002C2C2C00002C00002C2C2C2C00002C00002C2C2C2C2C2C2C
002C002C00002C000000000000000000002C00002C494949975F5F2C00002C2C2C000049
C5C5C52C2C2C00002C2C2C2C5F5F5FC5975F2C2C2C2C2C2C5F5F5F975F5F2C2C2C2C2C2C
97979700002C002C005F975F975F5F2C2C2C002C005F97972C2C2C2C2C2C5F975F490000
002C00C597972C2C2C002C00A7A7A72C2C2C5F975F490000004900975F5F0049005F975F
005F5F5F5F002C2C2C002C002C2C2C5F5F004949495F5F5F00000073737397975F494949
D4D4D42C2C2C5F5F5FE1E1E1A7A7A797975FB6B6B6B6B6B6C5C5975F975FC5C5C5B6B6B6
5F5F00C5C5C5C5C5C55F5F00C5C597B6B6B6000000979797C5979700000097C597000000
5F975F5F975F49494997C55F5F975F49494997975F2C00005F5F5F002C0097C55F002C00
002C002C2C2C002C005F5F002C2C2C00004900002C975F5F5F975F737373005F5F97975F
0049005F5F00737373494949005F5F5F5F5F5F5F5F5F97975F97970097975F97975F5F5F
005F5F4949492C2C2C5F5F5F005F5F5F975F5F5F5F8585854949494949495F975F5F5F97
5F5F5F5F5F5F5FC5C5005F5F5F97975F5F5F4949492C2C2C002C002C2C2C005F00494949
5F5F5F4949494949494949497373734949495F975F9797974949492C0000494949000049
737373A7A7A72C2C2C858585494949005F5F5F5F5F005F5F9797977373739797975F5F5F
002C0000002C00002C5F97972C2C2C0049005F975F5F5F5F979797494949002C00004900
C5EFC55F970097975F5F5F5F97975F5F975FC5C59700975F97C5975F5F5FA7A7A7005F5F
4949495F975F5F5F5FD4D4D40000495F5F5F5F5F5F5FC597979797979797A7A7A7A7A7A7
A7A7A7A7A7A797979797C5C55F97C5979797A7A7A75F5F5F5F5F5F7373734949495F5F5F
5F5F5F5F5F5F5F5F5F4949492C2C2C5F5F5F005F002C2C2C2C2C2C4949494949495F5F5F
4949494949495F5F5F737373005F5F5F5F5F005F5F5F5F5F007300005F5F4949495F5F5F
4949494949495F5F5F4949492C2C2C5F5F5F5F5F004949495F5F5F5F5F5F5F5F5F5F5F5F
7373735F5F5F4949495F5F5F5F5F5F005F5F4949494949494949495F975F00002C2C2C2C
494949002C00858585005F5F
2C0000002C0000002C2C000000002C00002C00000097C5C52C2C2C2C000000002C00002C
2C00002C00000000002C000000002C2C0000000000002C00002C00002C002C2C2C00002C
2C2C2C00002C2C00002C00000000002C2C2C002C00494949C5C5C52C2C2C2C2C2C2C2C2C
EFEFC5C5975F2C2C2C2C2C2C5F975FEFEFC500002C5F5F0097C5C5C5C5C5002C00002C00
97975F5F5F00002C00494949C5975F2C2C2C00002C5F975F2C2C2C2C2C2C5F975F2C2C2C
2C2C2C97C55F2C2C2C2C2C2C97C597002C00005F5F4949492C2C2C97975F0049005F975F
005F005F00002C2C2C2C2C2C2C2C2C5F5F005F5F5F4949492C2C2C5F5F5F975F5F5F5F5F
004900EFEFC5FFEFEF494949EFEFEFC5C5C5975F5F97C55FB6B6B6EFEFC5979797737373
EFEFC55F5F5FD4D4D4B6B6B6B6B6B6B6B6B6979797A7A7A7B6B6B65F5F00B6B6B65F9797
A7A7A75F5F9797C5975F979797C5975FC597C5C5C55F975FC5C597A7A7A797979700002C
5F5F5F2C2C2C5F5F00A7A7A7000000002C00002C005F5F5F5F5F000049002C2C2C005F00
5F5F005F97002C2C2C4949495F975F005F5F005F5F4949495F9797A7A7A75F975F5F5F5F
4949495F975F4949492C2C2C5F5F5F7373735F5F5F005F5F4949492C2C2C5F5F5F5F975F
5F975F5F97975F97975F97975F5F5F5F5F005F5F002C2C2C2C2C2C5F5F005F975F5F5F5F
4949494949495F5F5F5F97975F5F5F5F97975F975F5F5F5F2C2C2C5FC5974949492C2C2C
975F5F2C2C2C2C2C2C5F975FA7A7A7B6B6B67373737373739797975F5F5F2C2C2C002C00
005F5F5F5F5F5F975F5F5F5F7373732C2C2C5F5F5FEFC5C5B6B6B6A7A7A7D4D4D4C5C597
97975F5F5F5F00004997C55F49494997C59700490097C55F5F000097975FA7A7A75F9700
7373735F975F00002C494949C5EF970000005F975F494949494949005F005F5F5F494949
005F5F5F5F00005F5F4949494949494949494949495F5F5F4949495F5F5F494949494949
737373494949005F5F5F5F5F005F5F4949495F5F5F005F5F494949494949005F5F494949
005F5F494949005F5F494949005F5F005F5F2C2C2C2C2C2C2C2C2C7373735F5F5F737373
7373735F975F7373737373735F5F5F5F975F5F5F5F5F975F5F5F5F5F5F5F4949492C2C2C
5F5F5F5F975F97975F7373735F975F2C2C2C5F975F49494949494997975F2C2C2C858585
5F5F5F2C2C2C00002C494949
000000000000002C002C00000000002C2C2C0000000000004900002C2C2C002C002C2C2C
2C0000002C00002C0000002C0000002C2C2C2C2C2C2C0000002C00002C002C2C2C2C2C2C
00002C490000002C000000002C0000002C002C2C2C5F9797C5C5C5EFFFC597975FC5EFC5
858585C5EFC5EFC5C52C2C2CEFC5C5737373B6B6B6975F5FE1E1E1A7A7A7C5C5972C2C2C
C5C59797C597975F5F979797C5C597C5C55F002C00979797C5C55F002C005F97975F975F
2C2C2C8585850049004949499797972C2C2C5F5F5F494949004900975F5F2C2C2C5FC597
2C2C2C5F5F002C2C2C5F5F00005F5F002C0097975F5F975F00000049494997975F494949
2C0000FFC5C5002C002C2C2CEFC5C59797972C00005F975FC5C5C55F00002C2C2C5F5F5F
EFC5972C2C2C979797EFEFC52C2C2C5F5F5FB6B6B62C2C2C002C009797972C2C2C5F9797
2C2C2C005F5F5F5F5F00002C7373732C2C2C4949495F9797494949A7A7A7005F5FB6B6B6
97C5C597C5C5A7A7A75F97C597C5975F97975FC5978585855F97975F975F5F5F5F5F5F00
2C2C2C0049004949494949492C2C2C7373732C2C2C4949490000492C2C2C5F97975F9797
00975F5F5F5F5F5F5F2C2C2C005F5F7373735F975F5F5F5F5F5F5F494949737373494949
005F5F5F97975F97975F975F5F5F5F2C2C2C2C2C2C2C2C2C005F005F975F2C2C2C005F00
5F5F000049005F5F5F7373735F5F5F5F975F5F5F5F2C2C2CA7A7A77373732C2C2C5F5F5F
005F5F005F005F979797975F7373735F975F005F5F5F5F5F005F0073737397975FC5C597
7373735F975F97975F005F009797977373734949492C0000A7A7A72C2C2C737373494949
5F975F9797977373732C2C2C97C597002C005F5F5F2C2C2C4949495F005F0049005F5F5F
5F5F5F5F5F5F97C55F00002C5F9797C5C55F2C000097975F2C2C2C2C2C2C2C2C2C2C2C2C
4949494949492C2C2C4949494949492C2C2C4949494949495F5F5F494949004900494949
4949495F5F5F5F5F005F5F5F2C2C2C2C2C2C005F5F4949495F5F5F5F5F5F4949495F5F5F
494949494949494949005F5F4949494949495F5F5F4949495F5F005F975F2C2C2C2C2C2C
5F5F5F4949494949495F5F5F494949494949494949005F5F494949737373004900737373
2C2C2C004900979797494949004900A7A7A72C2C2C2C2C2CA7A7A72C2C2C8585852C2C2C
2C2C2C2C00005F9797494949
2C0000002C002C2C2C00002C2C2C2C2C00002C2C2C002C00002C002C2C2C00002C2C2C2C
00002C000000002C002C2C2C2C0000002C00002C00002C002C2C2C2C2C2C00002C00002C
2C2C2C00002C002C00002C002C2C2C2C2C2C2C2C2C2C2C2C5F9797B6B6B6C5EF97C5C597
2C2C2C2C2C2CC5C597C5C5C5B6B6B62C2C2C49000097C5C5B6B6B62C2C2C5F5F5FC5C597
97975F5F5F5F5F5F5FC5C5972C2C2C494949C5975FA7A7A75F5F5FC5975FA7A7A797975F
97975F97C59797975F97975F97975F97C55F5F975F5F5F5F97975F5F5F5F5F00005F975F
00490097975F4949495F975F5F5F5F2C2C2C5F975F5F975F4900004900005F5F5F004900
007300FFEFEF2C2C2C494949B6B6B60000000000005F9700EFC5C5002C00002C005F5F5F
C5975F2C2C2C5F5F5FC5975F002C002C2C2C2C2C2C002C00000000975F5F00000097C597
00002C2C2C2C2C2C2C0000002C2C2C002C00002C005F979700002C979797002C00494949
5F5F5F0049009797974949492C2C2C97975F002C002C2C2C4949495F5F5F97975F2C2C2C
005F5F5F5F5F5F5F005F5F002C2C2C005F005F97974949495F5F5F7373735F9797009797
5F975F005F975F97972C2C2C5F5F5F7373735F9797005F5F005F004949495F5F0000975F
8585857373735F5F5F5F5F5F494949005F002C2C2C5F5F00005F5F4949495F975F5F5F00
5F5F5F8585855F975F5F975F5F975F005F005F975F5F5F5FA7A7A74949495F975F494949
5F5F5F737373005F5F494949005F5F4949495F975F97975F5F975F005F5F5F5F5F5F5F5F
004900C59797494949975F5F002C0097975F2C2C2CC5C597494949002C002C2C2C000049
4900007373734949494949495F975F85858597975F97C597858585B6B6B6858585A7A7A7
5F975F97C5972C2C2CC5C597002C00C5EFC5B6B6B65F975F4949492C2C2C4949492C2C2C
5F5F5F5F5F5F005F5F005F5F494949005F5F005F5F005F5F5F5F5F5F5F5F005F5F5F5F5F
005F5F005F5F494949494949494949494949494949494949005F5F5F975F005F5F494949
5F5F5F5F975F00975F005F5F7373735F5F5F00975F5F975F4949494949495F975F5F5F5F
2C2C2C5FC55F2C2C2C4949495F975F0049002C2C2C9797972C2C2C005F5F7373732C2C2C
5FC5974949495F5F5F7373735F975F97C55FA7A7A797C5974949495F979797C59797C597
2C2C2C97C59797C597005F5F
2C000000002C002C002C00000000002C2C2C0000002C2C2C2C2C2C00002C2C2C2C2C2C2C
2C2C2C2C000000002C00002C00002C2C2C2C2C2C2C2C2C2C2C2C2C0000002C000000002C
2C00002C0000002C0000002C2C2C2C002C002C000000002C00002C5F97975F5F5FC5C5C5
002C002C000000002C5F5F5FC5EFC52C2C2C002C00005F5F97975F2C2C2C00002C97C597
5F5F002C000000002CC5C5972C2C2C002C00494949C59797000000494949C5C5972C2C2C
49494997C5972C2C2C9797972C2C2C5F5F5F97975F2C2C2C97975F4949495F975F2C2C2C
5F5F5F002C005F5F5F2C2C2C97975F5F5F5F4949495F5F002C2C2C5F5F005F5F5F2C2C2C
737373C55F5F00000097975FC597972C2C2C00002C975F5F975F5F0000002C2C2C5F5F5F
5F00000000005F5F00975F5F002C00002C002C000000002C0049005F5F002C00005F9797
2C2C2C2C2C2C2C0000002C005F5F00000000002C005F5F5F00002C5FC5970049005F5F00
8585852C2C2C5F975F2C2C2C5F5F005F5F5F0049002C2C2C2C2C2C5F5F005F5F00494949
5F5F004949495F5F5F5F975F5F5F5F494949002C005F975F5F5F5F4949492C2C2C97C597
5F97975F97977373734949495F5F5F5F975F5F5F5F5F975F005F5F5F975F4949495F9797
737373737373005F5F5F5F5F4949494949494949495F5F004949495F975F005F5F5F9797
5F975F4949492C2C2C005F5F97C5975F5F5F2C2C2C4949490049005F97975F5F5F5F5F5F
005F5F2C2C2C5F5F5F5F5F5F2C2C2C2C2C2C4949495F5F5F2C2C2C49494997C5972C2C2C
5FC55F0000495F5F00005F00858585005F5FA7A7A7494949A7A7A75F5F5F2C2C2C979797
8585852C00005F5F00005F00002C00005F002C00002C2C2C73737300002CC5C5972C2C2C
8585852C2C2C9797972C2C2CA7A7A7C5EFC52C2C2C975F97C5C5972C2C2C2C2C2C004900
4949495F5F002C2C2C4949495F5F005F5F5F4949497373730000495F5F5F4949492C2C2C
7373735F5F5F4949495F975F5F5F5F7373730000495F975F4949492C2C2C5F975F490000
975F5F2C2C2C858585002C0000975F4949490049002C00009797972C2C2C2C2C2C979797
975F5F5F5F5F5F975F2C2C2C2C2C2C5F975F5F975F0049009797975F5F00002C00979797
2C2C2C490000979797494949005F5F5F975F0049005FC5C55FC5C597975F2C2C2C5FC5C5
97975F004900737373494949
9797972C2C2C002C000000000000002C2C2C2C2C2C000000002C000000002C2C2C00002C
0000000000002C2C2C4900002C2C2C4900002C2C2C002C00002C00002C002C2C2C2C2C2C
2C2C2C0000000000002C0000002C00002C00002C002C2C2C2C2C2C2C2C2C737373A7A7A7
2C2C2C00002C00002C5F5F00EFC5C52C2C2C0000002C2C2C8585852C2C2C00002C005F00
C5C55F002C0000000097C597975F00002C002C0000C59797002C002C2C2C97975F2C2C2C
49000097975F2C2C2C8585852C2C2C2C2C2C5F975F2C2C2C5F975F2C2C2C2C2C2C494949
5F5F5F5F5F005F975F2C2C2C5F975F005F00002C005F00005F5F002C2C2C494949494949
979797004900000000C5C55F975F00002C0000490097975F2C2C2C000000002C00975F5F
2C2C2C2C2C2C5F97002C2C2C2C2C2C5F5F5F2C2C2C002C0000005F5F5F00002C0097C5C5
2C2C2C00975FC5C597005F5F97975F7373730049005F97972C2C2C97C5C50000495F9797
5F97975F5F5FA7A7A74949495F97975F97975F975F7373735F5F5F5F5F5F5F5F5F5F5F5F
4949495F975F2C2C2C005F004900004949498585855F5F5F5F5F5F005F002C2C2C5F975F
7373739797975F5F5F5F5F5F4949498585855F9797494949005F5F5F5F00737373737373
5F97975F5F5F494949004900005F005F5F5F4949492C2C2C005F5F5F9797858585005F5F
5F5F005F5F5F4949494949495F5F00005F5F5F975F5F5F005F5F5F5F5F5F005F5F5F975F
5F975F4949492C2C2C7373734949495F5F5F4949494949495F975F5F975F97975F5F975F
97975F9797975F975F5F5F5F2C2C2C5F000000002CA7A7A75F5F5F8585855F5F5F2C2C2C
C5C597858585A7A7A79797975F9700A7A7A70000495F5F5F2C2C2C4949492C2C2C002C00
2C2C2C2C2C2C2C2C2CEFC5972C2C2C8585852C2C2C2C2C2CE1E1E1005F5F7373735F5F5F
5F5F5F5F5F5F5F97974949495F975F4949495F975F7373735F5F5F005F5F737373979797
005F5F2C2C2C8585854949495F97975F5F5F7373735F5F5F7373735F5F5F005F5F5F5F5F
5F5F5F4949490049005F975F2C2C2C005F5F5F97975F5F5F4949495F975F7373732C2C2C
2C2C2C494949004900494949005F5F4949492C2C2C5F975F005F002C2C2C5F97972C2C2C
005F5FA7A7A72C2C2C2C2C2C97975F2C2C2C005F00C5C5975F975F2C2C2C005F5F97C597
7373732C2C2CB6B6B6005F5F
000000002C000000000000002C00002C2C2C2C2C2C000000490000000000490000002C00
0000000000002C2C2C2C0000002C00000000000000002C00490000002C002C2C2C2C2C2C
00002C002C002C0000000000002C002C2C2C2C00002C2C2C2C2C2C00002C0000495F975F
2C2C2C2C2C2C0000005F5F5F97C5C52C2C2C2C2C2C00002C97C59749494900002C002C00
97C597002C00000000005F5FC5975F2C2C2C002C00A7A7A7002C000000005F97975F5F00
2C2C2C7373732C2C2C2C2C2C97975F2C2C2C97975F2C2C2C5F975F5F00000049005F975F
2C2C2C97975F2C2C2C2C2C2C0049002C2C2C5F5F005F5F000049004949495F5F5F5F0000
EFC5C52C2C2C494949B6B6B6002C0049494997975F97C5975F5F000049005F975FEFEFC5
2C2C2C5F5F5FB6B6B697975F494949A7A7A797C59700975FB6B6B697C5975F9797A7A7A7
97C597A7A7A75F5F97858585A7A7A75FC5974949495FC5C5005F5F5FC5975F9797005F5F
73737397C5975F5F5F97975F4949492C2C2C5F5F007373735F5F5F5F5F5F5F5F00004900
2C2C2C97975F5F5F5F5F975F5F5F5F2C2C2C494949005F5F7373735F97975F5F005F975F
9797975F97975F97975F5F5F5F5F005FC5979797974949495F975F4949495F975F979797
005F5F5F5F002C2C2C4900004949495F5F5F5F5F5F7373737373735F5F5F5F5F5F5F975F
5F975F005F005F5F005F975F5FC5977373735F5F5F2C2C2C5F5F5F4949495F975F5F5F00
5F5F5F5F5F005F5F5F5F975F4949495F975F5F5F5F5F975F49494900002C004900494949
5F975F002C0097975F2C2C2C5F975F490000002C00C5979797975F4949490000002C0000
C5C5972C2C2C2C2C2C5F5F00000000494949858585975F5F5F5F0097975F5F5F5FA7A7A7
2C2C2CC5C55F2C2C2C005F5F5F5F5F004900C59797002C0000002C5F5F5F2C2C2C2C0000
2C2C2C5F975F5F975F494949005F5F4949495F5F5F4949495F975F5F5F5F5F97975F5F5F
8585855F5F5F5FC5975F97975F975F5F97975F5F5F5FC5977373735F97975F97975F9797
5F9797005F5F5F97978585855F97977373739797979797979797975F97977373735F9797
97C597005F5F005F5F5F9797737373005F5F0097975F975F494949005F5F5F5F5F494949
5FC5C5975F5F2C000097C55F2C2C2C000049C5C5C55F5F5F00002C2C2C2CEFEFC5737373
2C2C2CA7A7A78585855F5F5F
0000002C000000002C000000002C002C2C2C2C2C2C002C00002C002C0000002C00002C00
0000002C000000002C002C002C000000002C2C2C2C2C2C2C2C2C2C00002C00002C000000
2C0000002C00002C00002C00002C002C2C2C00002C0000002C2C2C2C2C2C00002C5F5F5F
2C2C2C002C002C00005F5F5F8585852C2C2C2C2C2C002C005F97974900002C2C2C2C2C2C
C5C5970000492C2C2C002C00C5C5972C2C2C002C0097975F00002C00002C5F5F0097975F
2C2C2C49494997975F49000097975F2C2C2C9797972C2C2C49494997975F2C2C2C5F975F
002C0097975F49494997975F4949495F5F005F5F5F4949492C2C2C5F5F5FA7A7A7A7A7A7
FFFFEF00002C5F5F5FA7A7A75F5F5F5FC597C5C5C5C5EFC597C597C5C597A7A7A797C5C5
97C55F97C5C549494997C5C5A7A7A773737397C597B6B6B649494997C5C5975F5F00002C
7373732C2C2C5FC5972C2C2C5F5F5F49494997C5C5002C0097C5C52C2C2C5F5F5F5F975F
2C2C2C9797972C2C2C2C2C2C4949492C2C2C5F5F005F975F494949002C0000002C005F5F
4949495F0000002C002C2C2C5F5F004949495F975F5F5F5F5F5F5F005F5F005F5F494949
5F5F97005F975FC5975F5F5F4949495F5F5F97975F005F5F5F5F0000975F979797005F5F
5F0000005F002C2C2C4949495F975F009797979797975F5F5F5F5F005F5F005F005F5F5F
2C2C2C5F5F5F2C2C2C2C2C2C4949495F5F5F2C2C2C5F975F00975F5F5F5F7373735F5F5F
5F975F5F5F5F5F5F5F4949492C2C2C4949492C2C2C494949005F002C2C2C5F5F5F002C00
4949492C00004949492C2C2CC5C597002C00C597C5000049002C00C5975F4949492C2C2C
97C55F002C0000490097975F2C2C2C975F5F002C0000002C97975F002C002C0000000000
7373732C2C2C737373A7A7A749494997C59797C59797C597B6B6B64900002C2C2C494949
97975F4949495F5F5F005F5F5F5F5F00975F5F5F5F5F975F5F5F5F5F5F5F5F5F5F494949
7373734949495F975F4949495F975F4949495F5F974949497373735F975F005F5FA7A7A7
005F00858585494949005F5F5F97975F5F5F97C5977373732C2C2C97C5C597C5C55F5F5F
B6B6B697C5C597C5975F5F5F97C55FC5EFC5E1E1E149494997C5C5C5C5C585858597C5EF
EFEFC55F5F5FC5FFFF5F5F5F005F5FE1E1E1B6B6B65F5F00002C0097C5C5FFFFEF5F5F5F
002C00C5FFC55F97975F5F5F
00002C0000002C00000000002C2C2C4900002C00002C000000002C00002C000000002C00
00002C00002C00002C2C2C2C2C2C2C002C002C2C2C002C002C2C2C2C2C2C000000490000
00002C002C002C2C2C002C002C2C2C2C00008585852C2C2C002C00002C0000002C975F5F
97975F002C002C2C2C2C2C2C494949C5975F2C2C2C2C2C2C5F5F5FB6B6B62C2C2C2C2C2C
494949C5C5972C2C2C2C2C2C737373C597002C0000494949C5975F2C000000002C979797
97975F2C000097975F004900858585975F00005F5F9797975F5F5F858585975F002C2C2C
5F5F0000002C49494949494900490097975F002C002C2C2C5F5F5F97C597E1E1E1C5C5C5
C5C5C5494949B6B6B6C5C5C5B6B6B6C597972C2C2CB6B6B6B6B6B6494949002C0097975F
B6B6B600002C002C00B6B6B6975F5F2C2C2C5FC597490000002C0097C5975F0000002C00
5F5F002C000097975F002C005FC59700002C975F5F002C00A7A7A75F9797000000979797
005F5F2C2C2C2C2C2C002C0097C5974949492C2C2C97979797C59797C597A7A7A7737373
97975F4949495F975F7373735F975F005F975F975F5F5F5F5F975F005F5F5F975F5F5F5F
005F005F97975FC5975F5F5F5F5F5F5F975F5F5F5F5F975F005F005F975F5F5F5F5F5F00
2C2C2C2C2C2C005F5F005F5F5F97975F5F5F5F5F5F5F975F005F5F5F5F5F494949005F00
4949494949495F5F5F0049004949495F5F5F5F5F5F5F975F5F975F00975F494949005F00
4949495F5F002C2C2C2C2C2C4949492C2C2C0049004949495F5F5F004900494949005F5F
2C2C2C85858549494997C597EFC5C55FC5C5E1E1E18585852C00002C2C2C975F5F5F005F
002C0097975F97975F9797972C2C2C97975F2C2C2C2C00005F5F5F2C2C2C002C002C2C2C
2C2C2C2C00002C2C2C97975F2C2C2C002C005F97002C2C2CC5C5C5494949005F5F5F5F5F
5F5F5F7373735F5F5F5F975F4949499797975F5F5F5F975F5F5F975F97975F97975F9797
5F5F5F5F979700975F5F975F737373005F5F5F97975F975F97975F5F5F5F494949005F5F
4949495F5F5F2C2C2C5F5F5F5F5F5F000049858585737373002C00A7A7A75F5F5F2C2C2C
C5C5975F975F5F5F5F5F5F5FC5C5C55F5F5FA7A7A7B6B6B65F5F5F494949C5C5C55F5F5F
B6B6B6D4D4D497975F5FC5C5C5EFC5C5C5C597C5C55FC597EFEFC5B6B6B6C5EFC5A7A7A7
C5C5C5C5EFC5A7A7A7005F5F
0000002C000000002C00000000002C002C002C000000002C0000000000002C000000002C
2C00002C000000002C002C002C2C2C2C2C2C2C2C2C00002C2C2C2C00002C2C0000002C00
002C00002C002C2C2C002C002C2C2C00002C2C2C2C002C000000000000002C2C2C5F5F5F
C5C59797975F2C2C2C2C2C2C005F5F97C5C5B6B6B65F975F005F00C5C5C597C5972C2C2C
2C0000C5C597C5C597975F0097C55FA7A7A7C5C5975F5F0097C597B6B6B65F5F00A7A7A7
494949C5C55F4949495F975F5F5F5F73737397975F97975F5F975F5F975F002C005F975F
2C2C2C5F975F5F5F005F5F5F5F975F5F975F5F5F5F5F0000A7A7A7C5C5EFC59797002C00
B6B6B6B6B6B62C2C2C979797C5C5972C2C2C000000979797975F00002C00000000A7A7A7
4949494900002C2C2C9797972C2C2C2C2C2C97C597002C00004900B6B6B6002C002C2C2C
00002C2C2C2C4949490049005FC597002C005F5F00002C005F975F5F975F5F5F5F2C2C2C
A7A7A700975F97C5C55FC5C55F97977373735F5F5F5F5F5F5F975F5F5F5F5F975F5F975F
5F5F5F7373737373735F5F5F00975F5F5F5F7373735F97975F97975F975F005F5F5F975F
4949495F5F5F5F97975F5F5F737373737373005F5F2C2C2C5F5F5FA7A7A797975F004900
4949494949495F9797A7A7A75F975F8585855F5F5F5F5F5F494949004900005F00494949
2C2C2C005F004949497373735F5F5F5F5F5F4949495F5F5F5F5F5F5F5F5F494949005F5F
005F5F00975F5F975F5F97975F975F5F975F5F5F975F975F7373737373735F975F005F5F
5F5F5F2C2C2C97C5974949495F5F972C2C2C2C2C2C5F5F005F5F5F002C002C2C2C5F975F
2C2C2C4949492C2C2C2C2C2C9797972C2C2C97975F979797858585494949002C005F5F5F
2C2C2C2C2C2C2C2C2CB6B6B600002C002C005F5F002C2C2CB6B6B6002C005F5F5F5F975F
5F5F975F97975F97978585855FC5975F97975F97975F97975F97975F97977373735F9797
5F97978585858585855F97975F975F97979785858597975F97C5975F975F97C597737373
97C597494949005F5F5FC5975F5F5F5F975F5F975F0049007373735F97975F5F00494949
9797975F5F5F0049009797977373734949498585855F5F5F5F5F00005F5F97975F494949
B6B6B6005F00005F5FB6B6B65F5F5F494949D4D4D4C5C5C52C2C2C2C2C2CC5C5C5EFEFC5
979797C5EFC5B6B6B65F5F5F
0000002C2C2C0000002C0000000000002C0000002C0000002C0000002C0049000000002C
0000000000002C2C2C2C2C2C002C00002C002C2C2C2C2C2C2C2C2C00002C00002C2C2C2C
00002C00002C4900004900000000000000002C2C2C2C2C2C0000000000002C2C2C5F5F5F
EFC5C597C597C5EFC55F5F00C5C5974949495F5F5FB6B6B697C5C50049005F5F5FC5C597
C5C597975F00002C005F5F5FA7A7A75F00002C2C2C979797C5975F2C2C2CA7A7A7975F5F
2C2C2C2C2C2C5F975F0049008585855F5F007373735F5F5F2C2C2C97C55F002C002C2C2C
2C2C2C2C2C2C97975F4949495F5F5F7373732C2C2C00490097975FC55F5F00002C494949
C5C5C52C2C2C002C00A7A7A75F0000002C002C2C2CB6B6B6002C0000002C2C2C2C97975F
00002C00002C494949C5C597002C00005F5FA7A7A72C2C2C5F5F5F8585852C2C2CB6B6B6
2C2C2C5F975F5F5F005FC5C597C5C55FC59797C5C55F97975F9797B6B6B6979797A7A7A7
5F97975F97975F5F5F5F5F5F858585A7A7A79797975F975F5F975F005F004949495F975F
8585858585855F97975F97975F97975F97975F97975F975F4949498585855F975F494949
5F5F005F975F8585855F97975F5F5F97979773737397975F8585855F5F5F494949494949
5F975F5F97975F5F5F5F5F5F5F5F5F494949000049005F005F5F00004900004900005F00
5F5F5F5F5F5F5F975F5F5F5F5F5F5F8585858585855F97975F97975F5F5F5F5F5F00975F
4949495F5F5F5F5F005F5F5F4949494949494949495F5F5F2C2C2C2C2C2C4949492C2C2C
5F5F5F2C2C2C97975F2C2C2C7373732C2C2C002C005F5F00002C0097975F5FC55F5F5F5F
49494900490097975F2C2C2C9797002C2C2C5F5F00002C004949495F5F5F9797972C2C2C
5F975F2C2C2C004900B6B6B62C2C2C00490097975F002C009797972C2C2C5F975F2C2C2C
494949005F5F5F5F5F5F5F5F5F5F5F4949494949494949495F975F5F5F5F5F5F5F5F975F
5F5F977373735F975F5F5F5F9797975F97975F975F5F97978585855F975F8585855F9797
A7A7A75FC597979797A7A7A75F5F5FA7A7A75F5F5F5F979797C597737373494949979797
7373735F5F5F5F5F5F97C5975F975F2C2C2C979797737373004900A7A7A7737373002C00
A7A7A7737373002C0097975F5F975F004900D4D4D48585852C2C2C002C00C5C5C5737373
2C2C2CC59797C5EFC55F5F5F
2C2C2C2C00002C00000000002C00002C2C2C2C00000000002C0000002C00002C0000002C
0000002C2C2C00002C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C00002C00002C002C00
2C2C2C00002C00002C00002C00000000000000000049000000002C002C00002C00E1E1E1
4949492C2C2C2C2C2CC5C5C5C5C5C54949492C2C2C2C2C2C97C597C597972C2C2C00002C
97C59797975F2C2C2C2C2C2C97975FC59797002C0000002C97979749494900002CA7A7A7
5F5F5F2C2C2C5F975F4949492C2C2C5F975F005F005F5F5F5F5F5F0049005F975F494949
5F5F5F002C0000002C5F5F002C2C2C4949495F975F5F5F5FEFEFC52C2C2C2C2C2CC5C55F
979797000000494949B6B6B62C2C2C002C005F975FB6B6B600002C2C2C2C5F975FA7A7A7
002C000000005F5F5F5F5F5F2C2C2C97979797975F490000C5EFC50049005F975FB6B6B6
5F975F85858597C5C5737373A7A7A75F5F5FB6B6B6002C004949499797975F97972C2C2C
5F5F5F5F5F5F5F97975F97975F5F5F005F5F5F5F5F2C2C2C5F975F5F979797C5975F9797
5F975F5F5F5F005F5F5F975F5F5F5F5F97975F5F5F5F97975FC5C5005F5F5F975F00975F
5F5F5F5F979797C5C55F97975F5F5F7373735F975F73737397975F0049004949495F9797
7373735F97005F5F5F4949495F5F5F4949492C2C2C2C2C2C5F5F5F5F5F5F5F5F5F5F5F5F
7373735F975F5F5F5F5F5F5F5F975F005F5F5F5F004949492C2C2C005F5F2C2C2C494949
005F00004900005F5F49494900002C005F002C2C2C7373730049002C2C2C005F5F00002C
C5C59700002CC5C5972C2C2C5F5F5F00002C004900C5C5C55F5F002C2C2C975F5F002C00
2C2C2C5F975F4949494949497373730049002C2C2C0000492C00002C00002C2C2C002C00
975F5F5F5F5F97975F494949B6B6B697975F737373002C0097C59797C597004900005F5F
5F5F5F005F5F5F5F5F5F5F5F5F5F5F5F975F5F5F5F00975F5F5F5F494949005F5F005F5F
494949005F5F5F5F5F005F5F5F5F5F5F5F5F5F97977373737373735F5F5F00975FA7A7A7
5F975F9797975F97975F975FA7A7A7A7A7A7B6B6B65F9797A7A7A75F97975F97975FC597
5F975F5F975F97C5975F5F5F5F5F5F5F9797A7A7A75F5F5F49494997C5975F5F5F737373
5F97970049005F5F5F5F97972C2C2C5F5F97C5C5975F5F5F2C2C2C2C0000C597975F975F
004900979797858585494949
0000000000002C2C2C002C0000002C002C00000000000000000000000000000000000000
2C0000002C002C00002C2C2C00002C00002C00002C0000002C2C2C00002C2C2C2C2C2C2C
002C00002C00002C002C0000002C002C2C2C2C2C2C2C2C2C00002C00002C2C2C2CC5C5C5
975F5F2C2C2C2C2C2C2C2C2C5FC5C597975F2C2C2C002C00005F5FC5EFC5975F5F2C2C2C
2C2C2CA7A7A7975F5F002C002C2C2C975F5F5F5F5F2C2C2C4900009797972C2C2C2C2C2C
5F97974949492C2C2C5F975F494949002C005F975F002C005F975F005F002C2C2C5F975F
2C2C2C5F975F2C2C2C5F975F2C2C2C2C2C2C494949C5C5C52C2C2C00002C5F9797C5C5C5
4900000000009797975F5F0000002C002C005F97974900000000002C2C2C5F975F5F5F00
002C005F975FB6B6B6C5C597C5C597975F5F97C597B6B6B65F5F5F97C5972C2C2C005F5F
5F5F5F005F5F5F5F00005F5F97975F979797002C00858585B6B6B6858585A7A7A75F975F
5F5F5F2C2C2C2C2C2C49494900975F9797977373735F975F5F5F5F4949492C2C2C000000
002C002C0000002C00000000002C000000000000005F975F5F5F5F5F97975F97975F5F5F
5F975F5F5F5F97C5C597979785858573737373737397975F2C2C2C005F5F5F97975F975F
005F5F5F5F5F5F5F002C2C2C0049005F5F5F5F5F5F4949495F5F5F5F5F5F5F5F5F494949
00975F7373735F975F5F975F5F975F5F97975FC5975FC5975F97975FC5975F97975F9797
5F97975F97975F97975F97978585855F5F5F5F975F5F97974949494949497373735F5F5F
97C5975F5F5F979797494949C5C5C52C2C2C5F97C5C5C5975F975F5F5F5F2C2C2C5F975F
002C005F975F2C2C2C2C2C2C5F5F5F4949495F5F00737373002C002C2C2C2C2C2C2C2C2C
49494900002C5F975F2C2C2C2C2C2C494949002C00C5C5C5A7A7A7B6B6B6B6B6B65F975F
005F5F5F975F5F975F7373737373738585855F5F5F5F5F5F5F5F5F4949495F5F5F5F975F
005F5F005F5F7373735F5F5F5F5F97005F5F5F97975F975F5F975F7373734949495F5F5F
4949495F97975F97974949490097975F975F5F9797858585005F5FB6B6B69797C55F9797
97C597B6B6B6A7A7A75FC5C55FC597C5C597C5EFC597C5C5C5C5C597C597005F5FC5EFC5
7373732C2C2CA7A7A75F97972C2C2CC5FFC58585854949492C2C2C00004997C597494949
2C2C2CEFC5C55F97975F5F5F
2C00002C00002C00002C0000002C002C00000000002C00000000002C00002C0000000000
0000002C2C2C2C2C2C002C000000002C000000002C0000000000002C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C0000002C0000002C2C2C2C2C2C2C0000002C00002C00005F5F5F5F5F5F
C5C5FF002C002C2C2C2C2C2C005F5F97C5C55F5F5F2C2C2C2C00002C2C2C979797004900
002C002C2C2CC5C597002C002C2C2C2C2C2CA7A7A7975F5F00002C005F5FA7A7A7490000
00000097C5972C2C2C002C005F97975F5F5F2C2C2C5F975F2C2C2C97975F5F975F007300
5F975F2C2C2C5F975F737373975F5F5F5F5F975F5FC597970000002C2C2CB6B6B62C2C2C
00002C5F5F5FB6B6B60000490000005F5F5FC5C5C52C2C2C005F5F97C597B6B6B6C5C5C5
A7A7A78585852C2C2CB6B6B62C2C2C000000C5C59700002CC5EFC5002C00002C00979797
5F5F5F5F5F5F005F5FA7A7A72C2C2C494949A7A7A75F5F005F5F5F494949494949737373
5F5F5F737373005F5F5F97974949494949492C2C2C0000000000002C00000000002C0000
00002C2C0000002C000000000000000000002C2C2C2C00002C2C2C5F5F979797C55F975F
005F5F0049009797975F9797737373737373975F5F2C2C2C5F975F5F975F5F5F5F5F5F5F
5F5F00002C00005F5F005F5F4949495F5F5F5F5F5F5F5F5F5F97975F5F977373735F9797
5F97975F975F4949495F5F5F005F5F5F5F005F5F004949495F5F5F4949498585855F5F5F
005F5F97C5974949492C2C2C005F5F2C2C2C00002C2C2C2CB6B6B6858585494949494949
004900A7A7A749494997C59749494997979797C5C5005F5F5F5F5F494949737373494949
4949492C2C2C85858500490097975F000049975F5F2C2C2C97975F5F5F0097975F979797
002C002C2C2C2C2C2C2C0000494949002C00002C00C5C59700002C2C2C2CB6B6B65F9797
7373735F97975F97975F97975F97975F97978585855F97975F97978585855F975F5F9797
005F5F5F97975F5F5F5F5F5F5F975F005F5F5F5F5F494949737373737373005F5F737373
005F5F5F97975F975F4949495F9797005F5F8585858585850000495F97975F5F5F5F9797
979797858585005F5FA7A7A7979797494949B6B6B65F975F737373E1E1E1B6B6B6A7A7A7
B6B6B6A7A7A7C5C5C5A7A7A75F9797B6B6B6C5EFC55F975F2C2C2C85858597C597737373
2C2C2CC5EFC5858585494949
2C0000002C002C00002C0000005F5FC55F5F002C00000000000000002C0000002C000000
0000002C2C2C002C00002C002C000000002C00002C002C002C2C2C2C00002C2C2C2C2C2C
00002C2C2C2C00002C002C0000002C2C2C2C2C2C2C00002C002C002C2C2C2C2C2C5F5F5F
2C2C2CC5EFEF0049002C2C2C2C2C2C5F5F5FB6B6B62C2C2C2C2C2C2C2C2C494949C5C597
002C002C2C2C858585B6B6B62C00002C2C2C002C00A7A7A75F5F5F002C0097975FA7A7A7
97975F5F5F0097975F73737385858585858597975F5F975F5F975F97C55F005F0097975F
97975F5F5F5F97C55F002C002C2C2C5F5F00EFEFFF2C2C2C2C2C2C5F975F979797000000
002C005F5F5FB6B6B62C2C2C005F5F97C5975F5F5FB6B6B6B6B6B64949492C0000A7A7A7
4949492C2C2CB6B6B65F5F5F2C2C2C97C5C500002C97C597494949005F5F858585004900
97979700002C9797975F97975F5F5F5F5F5F005F5F5F97975F97975F975F5F5F5F494949
2C2C2C2C2C2C2C0000002C00000000002C000000002C0000000000002C0000002C000000
002C00000000000000000000000000002C00000000002C0000002C5F5F5F5F97975F9797
5F975F2C2C2C737373979797005F5F8585852C2C2C005F005F97977373735F5F5F2C2C2C
5F5F5F005F5F4949495F5F005F5F5F5F5F5F4949494949495F5F5F005F975F97975F9797
5F97975F5F9700975F979797858585A7A7A75FC597979797979797A7A7A75F97C5494949
2C00005F5F970049005F5F002C2C2C0049002C2C2C00002CC5C597002C00490000002C00
00002C5F5F5F2C2C2CA7A7A72C2C2C97975F5F5F5F9797972C2C2C2C2C2C2C0000494949
2C2C2C5F5F5F5F5F004949494949492C2C2C2C2C2C00002C5F5F002C2C2C858585002C00
A7A7A7975F5F97975F002C00979797494949004900A7A7A72C2C2C490000EFEFC5494949
494949005F5F5F975F005F5F5F5F5F5F5F5F7373737373735F9797005F5F5F97975F9797
5F97975F97975FC5975F97975F97975F975F5F9797005F9797979700975F7373735F5F5F
005F5F5F97975F5F5F005F5F005F974949495F97975F5F5F2C2C2C9797975F5F5F5F5F5F
9797975F5F5F2C2C2C979797737373494949B6B6B6737373005F5FC5C5C55F975F494949
C5C5C5979797975F5FD4D4D4B6B6B6737373D4D4D4B6B6B6C5EFC5EFC5C5C5EFC55F975F
5F9797C5C5979797975F5F5F
002C002C00002C00000000002C2C2C2C2C2C2C2C2C0000002C2C2C2C2C2C00002C000000
2C0000002C002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C002C004900002C2C2C002C00
00002C00002C00002C2C000000002C2C2C2C00002C0000002C2C2C002C00000000002C00
5F5F5F5F5F5FC5C5C50049002C2C2C2C2C2C5F9797C5C5C52C2C2C2C2C2C2C2C2CA7A7A7
A7A7A797C5975F975F97C597C5C597B6B6B6A7A7A7A7A7A7737373A7A7A7A7A7A72C2C2C
2C2C2C5F975F4949494949499797974949490000495F975F4949492C2C2C5F975F494949
00004997975F2C00005F975F2C2C2CB6B6B6EFEFEF5F975F97FFC5C5EFC55F5F00002C00
5F9797B6B6B6C5C597C5C5C5A7A7A72C2C2C5F975FC5C5C52C2C2C00490097C597A7A7A7
00490097C5975F5F5F00002CA7A7A74949497373735F5F5F002C00A7A7A7494949979797
5F975F5F5F5F5F975F0049005F975F5F975F5F975F4949494949492C2C2C00002C000000
00002C002C00000000002C002C00000000002C0000002C00000000000000000000000000
000000000000000000002C0000002C00000000000000002C00000000002C5F9797A7A7A7
5F975F2C2C2C5F9797A7A7A7979797737373005F005F97975F5F5F4949492C2C2C494949
5F5F5F5F975F005F5F7373735F97975F975F00975F5F5F5F005F5F00975F5F5F5F005F5F
5F5F5F5F975F494949005F5F4949494949495F5F5F005F5F000049005F5F494949737373
5F97975FC5975F9797B6B6B600979797C5C55F97975F979797C5C55F5F5F5F975F494949
5F975F0000492C2C2C494949002C00A7A7A75F5F5F5F979797975F5F5F5F5F5F5F2C2C2C
7373732C2C2C5F5F5F0000495F5F009797972C2C2C7373732C2C2C002C005F0000004900
9797972C2C2C5F5F5F975F5F2C2C2CB6B6B6E1E1E1B6B6B62C0000C5C5C5FFEFC5494949
5F5F5F5F5F5F4949494949495F5F5F4949498585855F5F5F00979700975F009797737373
5F97975F5F5F5F9797005F5F5F975F8585855F97978585855F97979797975FC5C55F9797
5F979797C5975F5F5F5FC597737373005F5F979797005F5F0000495F975F5F5F5F5F5F5F
97975F5F975F005F5F5F975F858585494949979797494949494949B6B6B65F975F2C2C2C
97C597858585494949B6B6B68585855F5F5FA7A7A7E1E1E197C597737373C5C5C5C5EFC5
EFEFC5E1E1E19797975F5F5F
002C00002C0000000000000000002C0000002C00005F9797C59797002C00002C00002C00
2C00002C000000002C2C2C2C2C2C2C002C00002C0000002C00000000002C2C0000002C00
002C002C00002C0000000000002C002C0000002C00002C00490000000000000000000000
2C2C2C5F5F5F005F5FC5C5C597975F5F5F002C2C2CC5EFC5C5EFC5C5FFEF858585B6B6B6
005F5F858585B6B6B6B6B6B6004900002C005F5F5FA7A7A72C2C2C2C2C2C2C2C2C97C597
49494949494997975F7373734900005F975F97975F005F5F5F975F5F975F2C2C2C005F00
5F97002C2C2C5F975F5F5F00004900B6B6B6C5C5C5B6B6B6494949B6B6B6A7A7A7C5C5C5
B6B6B65F975FEFC5C5494949002C00007300C5C5C5002C002C2C2CC5EFC59797972C2C2C
B6B6B6737373002C005F975F494949005F005F5F0049494997C5C54949495F5F005F5F5F
2C2C2C737373005F5F5F5F5F5F5F5F002C00002C0000002C000000000000000000000000
002C002C0000000000000000002C002C0000002C002C0000000000000000002C002C0000
2C0000000000002C002C0000000000000000002C002C000000000000002C5F9797979797
5F975F4949498585855F975F7373730049005F97975F5F5F4949490049004949495F9797
5F5F5F00975F5F97975F975F737373005F5F5F5F5F4949494949495F975F5F5F5F494949
5F975F5F5F5F97C5975F975F5F97975F97975F975F5F5F5F4949495F97970097975F9797
5F5F5F7373730097975F5F5F5FC5C55F5F5F97C5975F9797979797A7A7A75F97975F97C5
5F97975F9797979797A7A7A75F9797005F5F49494997975F494949005F0097975F97975F
0000495F5F5F0049005F5F5F2C2C2C004900975F5F4949492C2C2C9797972C2C2C2C2C2C
5F00002C2C2CC597972C2C2C2C2C2C8585850000002C2C2CC5EFC5B6B6B65F97975F9797
5F5F5F5F97975F975F5F5F5F5F5F5F5F5F5F5F97975F5F5F7373737373735F5F5F5F5F5F
005F5F4949495F5F97005F5F005F5F5F97975F97977373735F5F5F97C597979797979797
5F9797A7A7A797C5C597C5C597C5975F97975F97975F5F5F5F5F5F7373735F5F00858585
5F975F00975F8585858585855F5F5F5F5F00858585494949005F5FC5EFC55F5F5F494949
A7A7A7494949494949FFEFC57373732C2C2C2C2C2CC5EFC597975F002C00A7A7A7C5C597
97C597C59797C5EFC5005F5F
2C2C2C00000000002C2C00002C000000000000002C002C002C00002C2C2C2C2C2C00002C
2C0000002C00002C002C2C2C002C002C2C2C2C2C2C00002C000000000000002C00737373
2C2C2C00002C000000000000000000002C00490000002C002C2C2C0000002C00002C2C2C
002C002C2C2C858585FFEFEFEFEFEFC5EFC5C5C5C5C5C5C55F5F5F2C2C2C5F5F0097C597
A7A7A70049002C2C2C97979797C55F005F5F2C2C2C5F5F0097C5974949492C2C2C2C2C2C
7373739797972C2C2C002C009797974900002C2C2C5F5F5F97975F0049009797972C2C2C
002C0097C597002C002C2C2C5F5F5FC5C5C5737373002C002C2C2CC5C5C5C5C5C597C597
005F00C5C5C52C2C2C00002C97C597B6B6B600002C004900B6B6B6858585002C00C5C5C5
97975F5FC597A7A7A7005F5FB6B6B62C2C2C97C5C5494949A7A7A77373737373732C2C2C
002C0000002C2C0000002C0000002C0000000000002C000000002C000000000000000000
2C000000002C002C00000000002C002C0000002C00000000002C00000000002C00000000
0000000000002C0000002C0000002C0000002C00000000002C2C2C0000002C2C2C009797
9797972C2C2CA7A7A77373732C2C2C8585855F97972C2C2C5F5F002C2C2C5F5F5F737373
5F5F5F5F5F5F2C2C2C2C2C2C5F5F004949495F5F5F5F5F5F5F5F5F5F5F5F005F5F2C2C2C
002C002C2C2C2C2C2C004900004900004900005F002C2C2C5F5F5F005F5F5F5F00005F00
979797005F5F00004997C5C54949495FC597005F974949495FC5C54949495F5F5F005F5F
494949005F5F005F5F5FC5C5494949B6B6B65F5F0000490097975F004900737373494949
4949492C2C2C97975F2C2C2C2C2C2C97975F2C2C2C979797000000004900005F5F979797
2C2C2C2C2C2C5F5F5F00002C004900975F5F002C002C2C2CC5C59700002C000049494949
5F5F5F5F5F5F7373735F979797C5975F97975F97975F5F5F5F97975F5F5F737373005F5F
005F5F005F975F975F005F5F5F5F5F005F5F005F5F5F5F5F005F5F8585855F5F5F5F9797
737373858585A7A7A75F979797C5C5B6B6B6B6B6B6A7A7A797C5C5B6B6B65F9797A7A7A7
97C59797C597B6B6B697975F737373A7A7A797C5975F5F5F858585A7A7A75F5F5F5F5F97
9797972C2C2C2C2C2CFFFFC54949492C2C2C5F5F5FEFEFC54949492C2C2CA7A7A7979797
5F5F00002C00C5EFC55F5F5F
2C00002C2C2C002C00002C0000000000002C000000002C00002C002C000000002C2C2C2C
0000002C2C2C002C000000002C2C2C00002C2C00002C2C2C2C2C2C2C2C2C0000002C0000
002C00002C0000002C00002C2C2C2C49000000002C00000000002C002C00002C00002C00
002C000000004949495F5F5F5F5F5F979797C5C5C5C5C5C5C5C5C54949492C2C2C2C2C2C
5F975FC5C5972C2C2C2C2C2C002C00C5C5975F5F5F2C2C2C2C2C2C737373C597972C2C2C
2C2C2C2C2C2C97975F494949005F5F5F975F97975F2C2C2C494949A7A7A797C59797975F
5F5F5F8585854949495F5F00A7A7A7494949005F5F004900B6B6B6C5C5C5494949005F5F
B6B6B6002C0000490097C5C5B6B6B6004900737373C5EFC597975FA7A7A7A7A7A700975F
8585850000495FC59797979700975F97C5C585858500002C0000000000002C000000002C
0000000000000000000000000000002C00002C000000002C000000000000000000000000
000000000000000000000000000000000000002C00000000002C0000000000002C002C00
000000002C000000000000002C0000000000000000002C0000000000000000002C5F9797
97979749494997C59797975F5F5F5F7373732C2C2C5F5F5F5F5F5F737373002C00494949
5F5F5F005F5F4949495F5F00005F000049002C2C2C2C2C2C4949492C2C2C4949495F5F00
5F975F5F5F5F4949495F5F004949495FC5977373738585855F975F5F5F00005F5F494949
5F5F5F5F5F5F4949497373735F975F5F975F5F5F005F5F5F005F5F00490097975F2C2C2C
979797002C002C2C2C005F5F5F5F5F5F9797C5C5977373738585855F5F5F2C2C2C2C2C2C
97975F2C2C2C97975F5F5F5F97975F002C008585852C2C2C2C2C2C97975F2C2C2C494949
A7A7A75F5F5F2C2C2C0049009797972C2C2C2C2C2CB6B6B65F5F002C2C2C494949494949
00975F005F5F5F975F005F5F5F5F5F5F5F5F7373735F97975F97975F97975F97975F5F97
5F975F7373737373735F5F5F5F5F5F5F975F005F5F5F975F005F5F005F5F7373735F5F97
5F5F975F97975FC5975F5F5F5F97975F97975F5F5FB6B6B65F5F9797979797C59797C5C5
C5C597B6B6B6A7A7A7B6B6B65FC5C5B6B6B6C5EFC5A7A7A7C5EFC5C5C597005F5FB6B6B6
9797975F5F5F494949C5EFC54949492C2C2C5F5F97C5C597002C002C2C2CC5EFC597975F
2C2C2C2C2C2CEFC5C55F5F5F
002C002C000000002C000000000000000000000000002C00002C00002C0000002C2C2C2C
2C2C2C2C2C2C2C2C2C00002C002C0000002C2C0000002C002C2C2C2C0000002C00002C00
002C0000002C00002C002C002C0000002C0000002C00002C00002C000000000000000000
000000002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C73737397C5C5C5C5C5975F5F2C2C2C
2C2C2C49494997C5974949492C2C2C2C2C2C97C59797C5972C2C2C2C00002C2C2CB6B6B6
C5C59797979797975FC5C5975F5F5F73737373737397975F5F5F5F737373C5975F97975F
002C007373735F5F00A7A7A72C2C2C2C2C2C494949B6B6B68585852C2C2C737373B6B6B6
002C00A7A7A7B6B6B685858597C597C5C5C597C597C5EFC5858585005F5F97C5C5494949
5F5F5F97979749494900002C2C2C2C002C000000000000002C2C2C000000000000000000
2C2C2C000000002C0000000000002C002C0000002C002C002C00000000002C0000002C00
0000002C2C2C2C2C2C0000000000000000000000000000002C0000000000002C00000000
2C2C2C000000000000002C0000000000002C2C000000000000002C000000002C005F9797
5F97975F97975F975F4949495F975F00002C5F975F5F975F2C2C2C5F5F5F4949495F5F00
4949495F5F5F4949494949495F975F005F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F2C2C2C
2C2C2C5F975F4949495F5F5F5F5F5F005F5F8585857373735F5F5F005F5F2C2C2C494949
5F5F5F979797979797B6B6B697975F9797975F5F5F5F975F4949494949495F5F5F5F5F5F
5F5F5F2C2C2C975F5F002C00B6B6B62C2C2CEFC5EF00002C2C2C2C2C2C2C005F5F5F5F5F
494949975F5F2C2C2C737373975F5F5F5F00005F5F0049009797972C2C2C002C005F5F5F
0000002C2C2CC5975F2C2C2CB6B6B6005F5F97C597C5C5C500002C5F97979797975FC597
5F5F5F005F5F737373737373737373737373005F5F5F975F5F5F5F5F97975F9797858585
9797975F97975F97975F97975F975F7373735F975F5F975F5F5F5F5F5F5F5F5F975F5F5F
5F5F5F5F975F5F97975F5F5F4949495F97972C2C2C9797977373735F97975F975F494949
97C59797C597858585979797A7A7A75F9797C5C5C5C5C597494949C5C5C5B6B6B6C5C5C5
EFEFC57373735F5F97C5EFC55F5F5F2C2C2CB6B6B65FC5972C2C2C2C2C2CD4D4D4858585
2C2C2C000049C5EF97005F5F
000000002C002C0000000000002C0000000000002C00002C0000002C0000002C002C0000
002C000000002C2C2C002C0000002C2C2C2C2C2C2C00002C00002C0000002C0000002C00
0000000000000000002C0000002C00002C002C2C2C2C2C2C2C00002C00002C2C2C2C2C2C
2C2C2C00002C00002C002C002C000000002C2C2C2C2C2C2C737373A7A7A7C5EFC5975F5F
2C2C2C2C2C2C004900C5C59797975F2C2C2C737373A7A7A797C59797C55F97C597C5C597
97C597737373000049858585C5C59797975F002C00002C005F5F5FC5C597975F5F002C00
5F979797C5975F5F5F002C002C2C2CC5EFC5C5C5C52C2C2C002C005F5F5FC5EFC5004900
97C5C55FC5C597C5C597C5C54949495F5F5F5F5F004949495F97975F9797000049000000
2C2C2C00002C000000002C002C0000002C0000002C002C00000000002C002C0000002C00
0000000000002C2C2C0000000000000000002C0000000000000000002C0000000000002C
2C000000000073737300000000002C002C00000000000000002C0000002C000000000000
2C0000002C00002C0000002C2C0000002C00000000002C000000002C2C2C00002C5F97C5
97975F5F5F5F5F5F5FA7A7A7002C00A7A7A7005F005F5F004949495F5F004949495F5F00
5F5F00005F005F5F00005F5F5F975F5F975F4949494949495F5F5F5F975F5F9797494949
5F9797005F5F7373730000005F5F5F2C2C2C5F5F5F005F5F5F5F5F8585858585855F975F
5F975F5F5F5F494949494949005F005F5F5F975F5F737373C5C5975F5F002C2C2C002C00
5F975F5F5F000049004949492C00005F5F5F494949EFEFC597975F97975F4949495F5F5F
97C55F5F975F97975F2C2C2C002C00C597972C2C2C2C0000005F005F975FC597972C2C2C
2C2C2C97975F2C2C2C000049D4D4D45F5F5F2C2C2CC5C59700002C5F5F5F5F97975F9797
5F979797C5979797975F5F5F5F5F977373735F97975F975F005F5F5F5F5F5F5F5F5F5F5F
5F975F00975F5F97975F97975F97979797978585857373735F5F5F7373735F5F5F5F9797
7373737373735FC5975F97972C2C2C5F9797005F5F9797975F5F5F494949005F972C2C2C
97C5977373734949495F9797979797737373A7A7A7979797979797979797B6B6B6A7A7A7
C5C5C5B6B6B6C5EFC5FFFFEFA7A7A75FC5C5FFFFEF5F9797737373B6B6B6C5EFC55F975F
2C2C2C979797C5C5975F5F5F
2C0000000000002C00002C002C00000000002C000000002C2C2C2C000000490000002C00
2C2C2C2C2C2C00002C002C00002C0000002C00002C00002C2C2C2C002C00000000000000
002C0000000000000000002C2C0000002C002C2C2C2C2C2C00002C2C2C2C00002C2C2C2C
2C2C2C2C2C2C2C0000002C002C2C2C00002C005F5FA7A7A72C2C2C5F5F5FA7A7A7C5C5C5
97975F97C55F97C59797C597C5C597C5C5975F5F5F004900858585C5C597C5C597005F00
2C2C2C2C2C2C97C597C5975F004900000049737373C5C597005F5FC5C5C5C5C5EFC5EFEF
B6B6B6B6B6B65F975F979797C5EFC5B6B6B6004900B6B6B6C5C5C5737373C5EFC52C2C2C
002C0097C5C52C2C2C005F5FA7A7A77373732C2C2C2C000000002C002C00000000000000
002C0000002C2C0000002C0000002C73737300000000000000002C00002C000000002C00
000000002C002C00000000000000002C000000000000000000002C002C00000000002C00
000000000000002C00000000000000000000000000000000000000002C00002C00002C00
002C000000002C2C2C000000002C002C000000002C0000002C2C2C0000000000005F9797
5F975FA7A7A75FC5C55F5F5FA7A7A7004900494949005F5F5F5F5F5F5F00005F5F494949
4949495F5F5F00975F5F5F5F5F5F0097975F7373735F975F5F975F5F975F2C2C2C5F5F5F
2C2C2C5F5F5F7373735F975F005F5F5F975F002C004949492C2C2C002C005F975F5F5F5F
005F5F5F9797A7A7A7A7A7A7005F5F5F975FA7A7A797979749494997C5C5A7A7A7B6B6B6
5F5F5F97975F85858597C5977373735F975F002C002C2C2CEFEFC58585855F5F5F005F5F
49494985858597975F97975F5F5F5F2C2C2C00002CC5C597002C002C2C2CC5C55F5F9797
97975F2C2C2C2C2C2C7373734949490000002C2C2CC5EFC54949494949494949492C2C2C
2C2C2C5F5F5F7373735F9797A7A7A75F97C58585855F97975F5F5F737373005F5F737373
5F5F5F5F5F97005F5F005F5F7373735F5F5F5F975F8585855FC5975F9797A7A7A7858585
5F975F5F9797A7A7A77373737373737373732C2C2CA7A7A75F5F5F494949858585494949
A7A7A75F975F2C2C2C975F975F975F494949A7A7A77373735F5F5F5F5F979797975F5F5F
85858597C5C597C5C5979797E1E1E1EFEFC5A7A7A7EFEFEFC5C5C5EFFFEFB6B6B697C597
5F975FA7A7A7C5C5975F5F5F
0000000000004900007373730000002C000000002C0000002C2C2C2C0000002C00002C00
2C0000002C002C00002C00002C2C2C002C00002C00000000490000002C002C2C2C2C2C2C
00002C002C002C00002C2C2C002C004900002C2C2C002C002C000000002C0000002C2C2C
2C2C2C2C2C2C002C002C00002C0000000000490000002C004900002C2C2C000049EFFFC5
A7A7A7002C002C2C2C2C2C2C49494997975FC5C597975F5F00002C2C2C2C2C000097975F
C5C59797975F2C00002C2C2CD4D4D42C2C2C5F5F5F97975F97975F7373735F975FB6B6B6
494949C5EFC5C5C5C55F5F5F009797C5EFC5C5C5C5002C00002C00A7A7A7004900005F5F
5FC597858585494949002C00000000002C0000000000002C002C00000000002C002C0000
002C00000000002C00002C0000002CC5C5970000002C0000002C000000002C0000000000
2C000000002C00000000000000002C002C00000000000000002C00002C000000002C0000
00000000002C0000000000000000002C0000002C00000000000000002C00002C002C2C2C
0000002C00000000002C0000000000002C00002C000000002C000000002C005F5F97C5C5
4949495F5F5F5F975F5F9797005F004949495F5F004949495F5F004949495F5F00005F5F
5F5F5F5F975F7373735F975F8585855F97974949492C2C2C5F5F5F5F5F5F5F975F5FC597
5F5F5F2C2C2C975F5F00002C4949495F5F5F5F97979797974949494949492C2C2C2C2C2C
5F5F5F002C002C2C2CB6B6B62C2C2C49494997975F858585858585002C00EFEFC55F5F5F
A7A7A7C5C5C55F97005F5F00A7A7A797975F49494997C597A7A7A7C5C59785858597975F
97975F4949499797975F975F975F5F975F5F975F5F002C002C2C2C97C55F2C2C2C2C2C2C
49494997C597C5EFC5EFEFC50000002C0000C5C5C5975F5F00002C00002C5F975F5F975F
49494985858500002C5F975F7373735F97975F9797A7A7A7A7A7A75F97975F97975F5F5F
5F975F4949495F5F5F4949495F5F5F5F975F7373735F975F5F5F5F5F5F5F5FC597979797
73737397979797C5975F97975F97978585855F9797A7A7A75F5F5F2C2C2C97C597494949
A7A7A77373732C2C2C9797975F975F2C2C2C9797C57373732C2C2CC597C5737373494949
737373A7A7A75F5F5F494949EFEFC5979797737373FCFCFCEFFFC5A7A7A7979797EFEFC5
B6B6B6FFFFC5B6B6B65F5F5F
002C002C00002C2C2C2C2C2C2C000000000000002C0000002C00002C0000002C002C0000
0000002C2C2C002C0000002C2C2C2C2C2C2C000000000000002C002C2C2C002C00002C00
002C002C2C2C2C2C2C2C0000002C00000000002C002C2C2C2C000000002C0000002C0000
002C00002C002C2C2C002C00490000000000000000002C002C2C2C002C004949495F9797
97C5C5A7A7A7B6B6B65F5F5F00002C2C2C2C2C2C2C979797C5EFC54949492C2C2C002C00
2C2C2C2C2C2CC5C59797975F737373A7A7A75F975F490000A7A7A7C597972C2C2C009797
97C5C5494949002C005F5F5F5FC5C52C2C2C002C0097C5C597C5C5737373494949002C00
2C000000002C2C00000000000000002C0000002C00000000002C0000000000002C2C0000
002C00000000000000002C002C0000002C00002C0000002C000000000000002C00000000
000000000000002C000000002C00000000002C0000000000000000000000000000002C00
000000000000000000000000000000000000000000002C002C0000000000000000000000
0000000000002C0000002C00000000000000002C00000000000000002C005F5F5FA7A7A7
5F97975F975F5F97975F975F4949495F5F5F005F5F005F5FA7A7A75F5F5F5F5F5F5F975F
5F97975F97975F97975F975F005F5F7373735F975F5F975F5F5F5F002C0000002CA7A7A7
5F5F5F97975F2C2C2CEFC5C52C2C2C97975F00002C97975F4949495F97975F97975F5F00
00002C494949C5EFEF2C2C2CC5EFC54949495F5F5F97975F490000A7A7A75F5F5F2C2C2C
49494900002C97C55FA7A7A72C2C2C2C2C2C5F975F85858597C5975F5F5F49494997975F
5F5F0097975F97975F737373975F5F5F5F5F4949495F975F2C2C2C2C2C2C005F00979797
4949492C2C2C5F5F5FC5EFC5C5EFC5C5C5C5FFC5C5002C00005F5F5F5F5F2C2C2C2C2C2C
002C002C2C2C5F5F5F737373005F00005F000049005F5F5F4949495F975F737373979797
5F97C55F97975FC5975F97975F975F5F975F7373735F975F5F975F5F975F5F975F5F5F5F
5F5F5F9797975F5F5F8585859797979797975F97975F97975F979773737397975F005F5F
979797858585005F005F5F5F97C5974949499797975F5F5F2C2C2CC597C5005F5F2C2C2C
85858597C5975F975F2C2C2CB6B6B65F5F5F494949FFEFEF975F5F005F5F2C2C2CD4D4D4
C59797858585C5C5C55F5F5F
2C0000002C002C2C2C00002C4900002C00002C0000002C0000002C2C0000002C002C2C2C
2C0000002C002C0000000000002C002C2C2C2C2C2C2C00000000002C00002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C00002C002C002C2C2C2C00002C2C2C2C0000490000002C00
00002C0000002C0000005F5F2C2C2C000000000000000000002C002C00002C2C2C5F5F5F
85858597C5975F975F5F5F5FB6B6B6EFC5C5A7A7A7B6B6B6D4D4D4EFEFC597975F737373
97975F5F5F5F5F975FC5C5C5D4D4D4EFC5C597C5C5C5C5972C2C2C490000858585737373
2C2C2C5F975F97C597A7A7A75F97972C2C2C00002C2C000049000000002C00002C2C0000
00002C2C0000000000002C002C2C2C000000000000000000000000002C00002C002C0000
00002C2C0000000000000000002C00000000002C002C0000002C00002C00000000002C00
2C0000000000002C00000000000000002C000000002C0000000000002C002C0000000000
2C0000002C002C2C2C000000000000000000000000000000000000000000000000002C00
2C00002C00000000000000002C00002C00002C00000000000000002C2C2C5F97975F5F00
5F5F5F2C2C2C7373735F5F5F5F5F5F5F5F5F7373735F5F00494949005F5F5F5F5F5F5F00
4949495F975F737373005F5F5F97974949492C2C2C2C2C2C5F975F5F97972C2C2C494949
005F002C2C2CA7A7A7494949C5C5C52C2C2C494949002C000000002C2C2C4949495F9797
5FC5975F975F5F9797C5EFC54949495F5F5F2C2C2C975F00002C00490000975F5FC5975F
97975F2C2C2C2C2C2C5F0000858585C5C597000049004900000000A7A7A75F975FA7A7A7
2C2C2C9797979797975F975F97975F97975F97975F4949495F975F8585854949495F5F00
002C0097C5C59797975F5F5F2C2C2C002C002C2C2C004900005F005F975F5F975F5F5F5F
5F5F5F5F975F5F5F005F5F004949492C2C2C4949494949494949494949495F975F494949
5F975F737373979797979797A7A7A797C5975F97975F97975F5F5F5F975F5F975F5F975F
5F5F5F5F97975F5F5F5F5F5FA7A7A75F5F5FA7A7A7737373A7A7A7979797A7A7A75F9797
9797975F975F5F5F5F5F5F5F97C59749494997975F5F5F5F2C2C2CC5C5C55F5F5F2C2C2C
A7A7A75F975F4949495F5F5F979797494949002C00EFC5C55F975F4949492C2C2CE1E1E1
5F5F5F002C009797975F5F5F
2C00002C2C2C000000002C0000002C000000002C00002C00002C000000002C0000002C00
000000490000000000490000002C002C2C2C2C2C2C002C002C000000002C002C002C2C2C
2C2C2C2C2C2C2C2C2C002C0000002C0000002C2C2C000000002C004900002C0000490000
002C00490000002C0000002C2C2C2C002C000000002C0000002C00002C002C0000490000
00002C2C0000737373A7A7A7737373005F97D4D4D4EFEFC5FFEFC5E1E1E1FFEFEFEFEFC5
A7A7A797975F97C5C5B6B6B697975F5F5F5F005F5F5F975F97C5C55F97975F5F5F2C2C2C
00002C002C0000002C0000002C2C2C00000000000000002C2C00000000002C2C2C000000
002C00000000002C00000000002C00002C002C000000002C000000000000000000002C00
002C00002C002C0000002C00000000000000000000000000000000002C0000000000002C
00000000002C002C00002C000000002C00000000000000000000002C00002C00002C0000
2C2C2C2C0000000000000000000000000000002C00000000002C00000000000000000000
000000000000002C002C00000000002C00002C0000002C002C0000004900979797005F5F
5F5F5F5F975F5F979700975F5F5F5F4949495F975F5F97978585859797975F9797858585
5F975F85858597975F2C2C2C5F5F5F9797979797972C2C2C002C00004900737373494949
5F97972C00005F5F00C5EFC5005F5F5F975F97C5972C0000A7A7A700002C005F5F2C2C2C
002C00B6B6B65F975F2C2C2C5F5F5F002C004949495F5F5F5F975F002C005F5F00002C00
49494985858597975FC5975F97975F002C005F5F5FA7A7A75F5F5F2C2C2C97C55F97C55F
97979797C597C5C59773737397975F97C5977373732C2C2C5F9797A7A7A75F5F5F5F5F5F
B6B6B62C2C2C5F975F005F5F005F5F005F5F5F975F5F975F5F975F8585855F975F97C55F
4949495F5F5F4949495F5F5F5F975F4949494949494949492C2C2C0000002C2C2C494949
7373735F5F5F5F975F5F5F5F7373735F5F5F5F975F5F979797C597B6B6B65F9797B6B6B6
5F5F5F5F975F5F975F5F975F737373005F5F7373735F975F4949498585855F975F979797
858585A7A7A797975F97C597979797737373A7A7A75FC5975F975FB6B6B67373732C2C2C
A7A7A7737373005F5F737373858585494949002C00C5C5C55F5F5F002C00494949FFEFC5
975F5F000000B6B6B65F5F5F
00002C002C0000000000002C002C000000000000002C00002C2C2C002C0000002C002C00
00002C0000002C0000002C00002C0000002C00002C4900000000002C000000002C490000
2C2C2C2C2C2C2C2C2C4900002C2C2C0000002C00002C2C2C00002C00002C002C00002C00
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C0000002C002C00002C2C2C00002C002C00
002C00002C002C2C2C002C002C2C2C85858500002C00002C2C000000002C490000C5C5C5
97C5C585858597979797979785858549494900002C2C0000000000000000002C0000002C
002C002C00000000000000002C2C2C2C000000000000002C0000002C00000000002C2C2C
0000000000000000002C000000002C000000000000002C002C0000002C000000002C0000
2C000000000000002C0000002C0000002C000000000000002C0000000000002C00000000
000000000000002C00000000000000002C00000000002C0000000000002C002C00002C00
000000002C000000000000000000000000000000002C0000000000000000002C00000000
0000002C2C2C2C00000000000000000000002C00000000000000005F975F97C5C55F5F5F
97975F5F5F5F5F97975F97975F5F5F5F97979797975FC597858585494949002C00494949
4949499797975F97975F97975F979797C5975F5F5FB6B6B65FC55F0049005F5F0097C597
5F97975F97972C2C2C97975F005F5F975F5F97C597979797B6B6B62C2C2CD4D4D4002C00
5F975F5F5F5F494949002C000049002C2C2C00490097975FC5C55F97975F5F5F5F002C00
0000004900002C2C2C979797004900005F5F97975F858585A7A7A7C5EFC54949492C2C2C
C5C5972C00005F975FB6B6B6B6B6B6C5C59797979797C59797C5972C2C2C737373A7A7A7
EFEFEF2C2C2C005F5F005F5F5F5F979797975F5F5F5F5F5F737373005F5F5F5F5F5F5F5F
5F5F5F4949495F975F5F975F5F5F5F005F5F5F5F5F00975F494949494949005F5F494949
2C2C2C002C004949495F5F5F5F5F5F2C2C2C73737349494973737349494985858597C597
B6B6B65FC5975F97975F5F5F5F5F5F5F975F5F5F5F858585005F5FA7A7A75F5F5F858585
5F975F5F5F5FC5C59773737385858597C59797975FA7A7A75F9797C5C5C58585855F5F5F
9797C55F975F5F975F97979797975F2C2C2C2C2C2CEFEFC55F5F5F2C0000494949C5C597
5F975F002C00EFC5C5494949
00002C002C002C00002C00000000000000002C00000000002C2C2C002C002C2C2C2C0000
002C002C2C2C2C0000002C002C00002C2C2C2C2C2C002C002C0000000000000000002C00
2C00002C2C2C2C2C2C49000000002C4900002C2C2C002C000000002C2C2C002C002C2C2C
2C2C2C002C0049000000002C2C2C2C002C002C2C2C0000000000000000002C0000490000
00002C002C00002C002C2C2C00002C00000000002C00002C2C2C2C00002C00002C00002C
2C2C2C000000002C00002C0000002C2C000000000000002C002C0000002C000000000000
2C000000002C002C00002C00000000000000002C00000000000000000000000000002C00
000000000000002C00002C00000000002C00002C002C000000002C00000000002C002C00
0000002C0000002C00000000002C000000002C2C2C00000000002C002C00000000002C00
0000000000000000000000002C0000000000002C000000002C2C2C0000002C0000000000
00002C2C00000000000000002C00000000002C0000000000000000002C00000000000000
000000002C00000000002C0000002C002C00002C00002C00000000005F5F5F975F5F975F
5F5F5F5F5F5F5F975F5F975F9797978585855F975F2C2C2C002C00002C002C0000000000
000000002C002C2C2C5F5F5F5F97975FC59797979797975F85858597C5C52C2C2CB6B6B6
73737397975F4949492C2C2C5F5F5F002C00C5EFC52C2C2CC5C5C597C5C55F5F5F2C2C2C
C5C597002C00C5975F5F00004949492C2C2C97975F5F5F0049494900002C2C2C2CC5975F
5F5F002C2C2C2C2C2C97975F97975F97C59797975F2C2C2C00002CC5EFC5C5C5C5B6B6B6
005F5F97975F2C2C2C2C2C2C2C2C2C0049002C2C2C2C2C2C004900A7A7A7858585494949
4949494949494949495F975F7373737373735F5F5F5F5F5F5F975F5F975F5F975F5F5F5F
4949495F5F5F5F5F5F5F5F5F5F5F5F4949495F5F5F4949495F975F5F5F5F4949495F5F5F
5F5F5F494949005F002C2C2C494949494949494949494949005F008585854949495F975F
4949498585858585858585855F9797B6B6B65F975F5F97975F5F007373735F975F5F5F5F
5F975F2C2C2C5F975F5F975F5F975FA7A7A75F975F737373B6B6B65F9797C597975FC597
C5C597A7A7A77373739797975F97975F5F00494949C5C5C55F5F5F002C0073737397975F
5F975F2C2C2CEFC5C55F5F5F
0000000000002C2C2C002C002C000000002C0000002C00002C2C2C2C000000002C2C0000
2C0000002C00002C000000002C000000002C2C0000002C00002C00002C00000000490000
002C0000002C002C00002C002C2C2C000000002C002C2C2C2C2C2C000000002C002C0000
2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C000000002C0049000000002C00002C
2C2C2C2C2C2C2C2C2C2C00002C2C2C00000000000000002C002C002C2C2C000000000000
000000000000002C00002C0000002C002C002C2C2C002C002C00000000000000002C0000
2C0000002C002C000000000000002C002C002C2C2C2C0000002C002C2C2C000000000000
002C00002C00000000000000000000000000002C0000002C0000002C00000000002C0000
2C000000000000000000002C00000000002C00000000002C000000000000000000000000
0000002C00000000002C2C2C0000002C00002C000000002C002C0000002C2C0000002C00
2C0000000000002C002C0000000000002C002C0000000000000000000000000000000000
000000000000000000002C000000000000002C000000002C4949495F97978585855F5F00
5F975F5F5F5F97C5C58585855F97972C2C2C002C0000000000000000000000000000002C
2C0000000000002C002C000000002C494949A7A7A797C5C55F979797979797C5C5A7A7A7
5F5F972C2C2C97C5C500975F97C5C52C2C2CC5C5972C2C2C005F5F000000B6B6B6B6B6B6
C5C59797975F002C0097975F49494997979797975F5F5F5F5F5F004949492C2C2C2C2C2C
975F5F97975F2C2C2C975F5F7373732C2C2C49494997979797975F9797972C2C2CC5C597
00004997975F2C2C2C5F5F5F00005F5F97975F97975F979797975F5F97975F9797005F5F
5F5F975F5F5F5F5F5F5F5F5F5F97975F5F5F5F975F5F5F5F5F975F5F5F5F5F5F5F5F5F5F
5F5F5F494949005F5F5F5F5F737373005F5F7373734949495F5F5F4949495F5F5F5F975F
5F975F005F5F5F5F5F494949005F5F005F00494949005F005F5F5F5F5F5F494949494949
2C2C2C4949495F975F49494997979749494997979797C55F97C59797C59797C597494949
5FC5975F975F4949498585855F975F5F975F7373735F5F5FA7A7A77373735F5F97B6B6B6
5F979797C5C597EFC5B6B6B697C5975F975FC5C5C5EFC5C5737373002C00C5C5C55FC597
5F5F002C2C2CEFEFC55F5F5F
0000002C00002C00000000000000002C2C2C2C00002C2C2C002C00000000000000000000
0000000000000000002C2C2C2C000000002C2C00000000002C0000002C002C2C2C002C00
00000000002C0000002C0000002C002C2C2C0000002C2C2C002C000000002C000000002C
002C000000002C000000002C002C002C2C2C2C2C2C2C2C2C0000002C00002C00002C2C2C
4949492C2C2C2C2C2C2C000000002C00000000000000002C2C2C2C002C00000000000000
0000002C00000000002C00000000000000002C0000002C00002C00002C002C0000000000
2C2C2C00002C002C000000002C0000000000002C000000002C00002C0000000000000000
000000002C0000002C000000002C00000000002C0000002C2C2C2C000000000000000000
0000002C0000000000002C0000000000002C2C0000000000002C002C2C2C002C00000000
00000000000000002C002C00000000002C0000002C002C0000000000000000002C000000
000000000000002C000000002C2C2C000000000000494949002C00002C00000000000000
002C000000002C000000002C00000000002C002C0000000000975F005F5F7373735F975F
737373A7A7A75F9797979797002C0000000000002C00002C00000000000000002C002C00
0000000000002C00000000000000002C00000000002C2C2CA7A7A79797975F97975F5F5F
979797002C00494949B6B6B68585855FC5975F975F2C0000D4D4D4002C00C5C5C5002C00
D4D4D4002C004949492C2C2C4949495F975F004900002C002C00005F975F5F5F5F000000
2C2C2C5F5F5F97975F97975F97975F2C2C2C5F5F005F005F5F5F5F5F5F5F2C0000C5C5C5
2C2C2CB6B6B62C2C2C005F5F005F5F7373735F975F5F975F005F5F5F5F5F005F5F5F9797
5F97975F5F5F5F5F5F5F97975F975F005F975F97977373735F975F7373735F975F5F5F5F
005F5F5F5F5F5F975F7373735F5F5F4949495F5F5F5F5F5F5F5F5F5F975F005F5F5F5F5F
5F5F5F5F975F5F5F5F5F5F5F5F5F5F4949495F5F5F5F5F5F4949494949492C2C2C494949
5F5F5F2C2C2C7373734949492C2C2C005F5F4949498585855F5F5F979797A7A7A797EFC5
97C5975FC5970049009797977373735F5F5F737373005F5F5F5F5F5F97975F5F5F737373
97C597005F5FC5C597858585C5C5C597C5C5C5EFC5FFEFEF97C5975F97C5E1E1E1C5C597
5F975F5F9797C5EFC55F5F5F
0000000000002C00002C2C2C2C2C2C2C00002C0000490000002C00002C00002C0000002C
2C00000000002C0000B6B6B6002C0049000000002C00002C00002C2C00002C2C2C002C00
2C000000002C002C002C0000002C00002C00002C00002C000000000000002C0000000000
002C0000002C494949002C002C00004949490000000000002C000000002C002C00000049
5F5F5F002C0000002C00002C00002C000000000000000000002C0000002C000000000000
00000000002C2C2C2C002C000000002C000000002C2C2C2C7373732C2C2C002C0000002C
002C00000000002C0000002C0000002C2C2C002C00000000002C00000000002C00000000
002C000000000000002C2C2C000000002C00000000002C0000002C2C0000002C00002C00
000000000000000000002C0000002C2C000000002C00000000002C0000000000002C0000
0000000000002C00000000002C2C2C2C0000000000000000000000000000002C00000000
2C2C2C002C00002C000000002C2C2C0000002C000000002C00002C002C000000002C2C2C
000000002C00000000002C00002C00002C00000000005F5F5F975F5F975F5F975F5F9797
A7A7A75F9797494949002C00000000000000000000002C000000000000002C0000000000
00000000002C000000002C00002C00000000002C002C00002C2C2CA7A7A75F9797005F5F
005F5F97C5C5004900C5C5972C2C2C5F9797A7A7A75FC5C597C5972C2C2C5F5F5F002C00
490000494949002C000049005F5F005F975F97975F97975F5F975F97975F97975F5F975F
2C2C2C494949C5975F004900975F5F2C00002C2C2C494949002C0097C597B6B6B6B6B6B6
2C2C2CB6B6B65F5F005F97975F97977373735F5F5F7373735F5F5F7373735F975F5F9797
5F5F5F5F97975F97975F9797005F5F5F5F5F5F5F5F5F97975F975F5F5F5F7373735F975F
5F5F5F5F5F5F005F5F5F975F5F97975F9797737373005F5F5F5F5F5F5F5F7373735F975F
5F975F4949495F5F5F5F975F5F5F005F5F5F5F975F4949494949495F5F5F5F5F5F494949
494949005F5F494949005F5F4949495F5F5F494949005F5F4949497373734949495F5F5F
5F975F97C59797C59797C59797C597494949A7A7A75F5F5F004900858585737373004900
9797977373737373735F975F5F5F5FB6B6B6A7A7A7A7A7A7EFEFC5B6B6B697C597EFEFC5
5FC5C5B6B6B6C5C5C55F5F5F
00002C2C000000002C00002C002C00002C00002C002C0000000000002C000000002C2C2C
2C000000002C2C00002C00002C000000002C2C0000000000002C00002C00002C00000000
0000000000000000002C2C2C002C002C2C2C2C2C2C00002C0000002C0000000000000000
002C00002C005F5F5F00002C00002C002C002C000000002C2C2C2C2C2C2C2C2C2C2C0000
002C00002C0000002C002C0000002C002C00002C00002C00000000002C0000002C000000
002C002C000000002C00000000002C000000000000002C00000000000000000000000000
2C000000002C00002C2C00000000005F5F5F2C00000000000000002C0000000000000000
000000000000000000000000002C00000000000000000000002C0000000000002C2C0000
0000000000002C2C2C00000000000000002C002C00000000002C00002C002C0000000000
2C0000002C00000000002C00002C00002C0000000000000000000000002C000000000000
000000002C0000000000002C002C000000002C0000002C000000000000002C0000000000
00002C0000000000000000000000000000000000005F975F5F975F5F979797C5C55F9797
5F979749494900002C0000000000002C000000002C0000002C2C2C002C00002C00000000
00000000000000002C00002C2C00002C0000002C002C000000002C2C0000979797979797
5F97975F5F5F97C597C5C5C52C2C2C4949495F97975F97975FC5C5C5C5C52C2C2C5F5F5F
0000005F5F5F5F5F005F5F5F2C2C2C5F5F5F4900005F975F002C0000000097975F2C0000
C5C55F2C00004900005F5F5F2C000097975FC5C55F002C00002C0097C5972C2C2CC5C597
C5C5C5B6B6B68585855F97979797978585857373738585857373735F975F5F5F5F5F5F5F
005F5F5F5F5F5F97975F97977373735F9797005F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F
5F5F5F737373737373005F5F5F5F5F5F5F5F00975F5F5F5F737373005F5F4949495F5F5F
5F5F5F5F5F5F005F5F4949495F5F5F005F5F5F5F5F005F5F7373735F5F5F005F5F005F5F
5F975F494949005F5F005F5F005F5F005F5F5F5F5F005F5F005F5F2C2C2C5F5F5F494949
737373494949A7A7A7979797A7A7A797C5C5C5EFC55F97974949494949495F5F97494949
5F975F5F97974949499797972C2C2C7373735F975F2C2C2C97C5C5A7A7A72C2C2CC5C597
C5C5975F975F5F5F97005F5F
0000002C2C2C2C000000002C002C00002C000000002C0000002C00002C00002C002C0000
002C002C000000002C002C00002C002C0000002C0000002C002C000000000000002C2C2C
002C002C000049000000002C49000000002C0000000000000000002C2C2C002C002C0000
490000002C002C2C2C00002C002C002C2C2C2C00000000002C00002C2C2C2C2C2C2C2C2C
002C00002C002C2C2C2C0000002C0000000000000000002C2C00002C2C2C0000002C2C2C
2C0000002C002C00002C0000000000002C002C00000000002C000000002C2C00002C0000
000000002C002C0000000000002C002C00000000002C00000000000000002C2C2C2C0000
002C00000000002C000000002C0000000000002C00000000000000000000000000002C00
002C0000002C0000002C000000002C2C0000002C0000000000002C0000000000002C0000
002C002C000000002C0000002C2C2C000000002C00000000002C0000000000002C002C00
00002C002C000000000000002C2C2C000000000000000000002C00000000000000000000
2C000000000000000000002C002C000000005F5F009797975F97975F9797A7A7A7979797
2C2C2C00002C002C00002C002C0000000000000000002C002C0000002C00000000002C00
00000000000000002C2C0000000000002C0000000000002C2C0000002C00000000000000
B6B6B6A7A7A773737397C5C5B6B6B62C2C2CA7A7A72C2C2CA7A7A75F975F5F975FC5975F
002C005F5F5F0000494949495F5F004900002C2C2C5F5F004949494900002C000097C597
002C005F5F00005F5F975F5F00490049494973737397975F2C2C2C97975F2C2C2CC5C55F
2C2C2C858585EFC5C5005F005F97975F97975F97977373735F975F9797975F975F5F5F5F
5F5F975F975F5F97977373735F9797005F975F975F7373735F5F5F7373735F5F5F5F5F5F
5F5F5F5F5F5F5F5F5F7373737373735F5F5F737373005F5F5F5F5F7373735F9797737373
005F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F005F5F5F975F5F975F5F5F5F
5F5F5F5F975F5F975F5F5F5F005F5F2C2C2C005F5F2C2C2C2C2C2C4949495F97972C2C2C
5F00004949494949497373735F5F5FA7A7A7005F5FC5C5C597C59797C5C597C5C55F5F5F
005F97A7A7A77373735F5F5F5F5F5F2C2C2C8585852C2C2C5F5F97C5C5972C2C2C005F5F
B6B6B65F5F002C2C2C494949
2C2C2C002C00002C0000002C002C000000002C00002C2C2C000000000000000000000000
0000002C00002C00000000002C00002C2C2C2C0000002C002C2C2C490000002C00002C00
2C2C2C002C0000002C2C2C2C00002C00000049000000002C2C2C2C2C2C2C002C0000002C
002C00002C002C2C2C00002C00002C00002C00002C2C000000002C002C00000000000000
2C2C2C002C00000000002C000000000000002C00000000000000002C2C2C2C0000000000
00002C002C002C00002C00000000002C000000002C000000000000002C000000002C0000
002C002C000000002C00000000000000002C0000002C00000000002C2C2C000000000000
2C2C2C000000000000000000000000000000000000002C00000000002C00002C002C2C2C
002C0000000000000000002C0000000000000000002C00002C00002C0000002C0000002C
000000000000002C00000000000000000000000000000000002C0000000000000000002C
2C00002C0000002C0000002C002C000000000000002C00000000002C0000000000000000
000000002C000000000000002C0000000000005F5F5F97975F979797C5C597C5C52C2C2C
0000000000000000002C00000000002C2C2C00000000000000002C00000000000000002C
000000002C000000000000000000002C2C2C2C00000000000000002C000000002C000000
2C00008585855F975F005F005F5F5FC5EFC5C5EFC52C2C2CB6B6B62C2C2CEFEFEF97C597
2C2C2C4949495F5F5F4949494949495F975F4949492C00005F5F5F5F00005F5F002C2C2C
5F5F5F0000002C2C2C97975F005F002C2C2C97975F002C0097975F5F9797005F5F97C55F
004900975F5F2C2C2CC5C5C5A7A7A75F975F5F5F5F7373735F975F5F5F5F5F9797737373
5F97975F5F5F5F975F5F5F975F5F5F737373005F5F5F5F975F975F5F97975F975F5F5F5F
5F5F5F005F977373735F5F5F005F5F5F975F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F737373
8585857373735F5F5F5F5F5F494949005F5F5F5F5F4949494949495F5F5F494949005F5F
00975F5F5F5F5F975F5F5F5F5F97975F97972C2C2C005F5F005F5F7373732C2C2C00005F
2C2C2C5F975F5F5F5F4949494949494949495F975F4949495F5F5F5FC59773737397C5EF
97C5C5C5C5EF97EFC55F5F5F5FC5972C2C2C8585854949492C2C2C8585850073002C2C2C
C5C5975F5F0000002C005F5F
2C2C2C0000002C000000002C00002C2C000000002C2C2C2C00002C000000000000002C00
00000000000000002C2C000000002C002C00002C00002C0000002C00002C2C2C2C2C2C2C
002C00490000002C00002C00002C00002C00002C002C2C2C2C2C2C2C2C2C0000002C0000
00002C2C2C2C2C2C2C002C0000000000002C2C2C2C2C00000000002C00002C00002C0000
002C000000002C2C2C00002C2C0000002C002C2C2C2C00002C2C2C00000000002C000000
0000002C2C2C2C000000002C0000000000002C2C2C00002C2C00000000002C2C2C2C2C2C
2C000000000000002C2C0000002C000000005F97C500002C000000000000000000002C00
0000000000002C000000002C00002C2C00000000002C0000002C0000002C0000002C0000
00002C000000002C00000000000000000000002C0000002C002C00002C00002C00000000
00002C2C0000002C002C0000002C0000002C0000002C000000000000000000002C2C0000
002C0000002C2C2C2C000000000000002C00002C0000002C002C00002C002C0000002C00
00002C002C000000002C000000002C5F5F5F5FC5975F979797C5EFC5C5C52C2C2C00002C
0000002C2C2C00000000000000000000000000000000002C000000000000000000000000
002C000000002C0000000000000000000000002C0000000000002C002C00000000002C00
975F5F00002C2C2C2CC5C5C597975FA7A7A7A7A7A7004900C5EFEF2C2C2CC55F5F5F5F5F
4949495F5F5F5F5F004949490049004949494949494949495F5F005F5F005F5F5F97975F
002C0097975F2C2C2C9797974949492C2C2C4949492C2C2C0000002C2C2C97975FC5C597
2C2C2C97975F490000EFEFC55F97975FC5C5A7A7A75F97975F5F5F5F5F5F5F5F5F5F9797
5F97979797975F5F5F7373735F5F5F5F5F5F5F5F5F005F5F5F5F5F5F5F975F975F5F5F5F
5F97975F975F5F5F5F5F5F5F5F5F977373735F5F5F005F5F5F5F5F5F5F5F5F97975F5F5F
4949495F97975F5F975F975F005F975F5F5F005F5F005F5F5F5F5F4949494949495F5F5F
005F5F5F5F5F5F5F5F7373735F5F5F5F5F5F5F97975F9797005F5F5F5F5F4949495F5F5F
5F5F5F2C2C2C0000494900005F5F5F5F5F5F494949494949494949737373494949494949
A7A7A7004900737373C5EFEFC5C5C55F97C59797975FC597004900A7A7A75F5F5F5F005F
A7A7A773737300002C5F5F5F
002C002C2C2C002C00000000000000002C000000002C000000002C002C002C00002C0000
00000000000000000000002C2C2C2C0000007373735F5F9700002C2C2C2C002C00000000
002C00002C00002C002C2C2C002C00002C0000002C00002C2C2C2C00002C00002C2C0000
00002C2C2C2C2C0000002C00002C00002C002C2C2C00002C00002C00002C2C2C2C00002C
0000000000000000002C0000002C0000002C0000002C00002C00002C00002C0000002C00
002C00002C0000002C00002C2C0000002C000000000000002C000000002C0000002C2C2C
002C002C2C2C0000002C00000000002C2C2C2C0000002C000000002C2C2C002C00000000
002C00002C0000002C0000002C00002C2C2C2C000000002C00002C002C002C000000002C
2C00002C2C2C00000000000000002C00000000002C0000002C0000002C00000000000000
2C0000000000000000002C00002C00002C0000002C2C0000002C002C0000002C00000000
2C0000002C002C000000000000002C0000002C00000000002C00000000002C000000002C
2C0000000000002C0000000000002C5F9797979797C5C5EFB6B6B6002C0000000000002C
000000000000000000002C00000000002C002C0000002C00000000000000000000002C00
00002C00000000002C00000000002C2C00000000000000002C0000000000000000002C00
00002C00002C0000002C2C2CB6B6B6494949005F5F97979797C5C5002C00975F5F004900
4949492C2C2C4949495F975F0000490049005F5F004900002C2C2C7373732C2C2C5F5F5F
8585852C2C2C5F5F002C0000494949002C005F5F005F975F2C2C2C5F97972C2C2CA7A7A7
A7A7A7C5EFC500002CEFFFEF5F5F97B6B6B697C5C597C5C5A7A7A78585855F5F5F5F5F5F
5F5F5F5F5F5F7373738585855F5F978585855F97975F5F975F5F5F5F5F5F5F5F97737373
7373735F975F005F5F7373735F975F5F5F5F5F97975F5F5F005F97005F5F7373735F5F5F
5F9797005F5F005F5F7373737373735F975F005F5F5F975F5F5F5F494949737373005F5F
2C2C2C5F5F5F5F5F5F005F5F005F5F7373735F5F5F5F5F975F975F5F5F5F5F5F5F5F975F
005F5F5F97975F5F000000490000495F5F5F2C2C2C4949495F5F5F494949494949494949
5F5F5F7373734949495F5F5F005F5F97C5C5C5EFC597C59797C55F9797975F97972C2C2C
9797975FC5975F5F5F494949
2C00002C2C2C002C002C2C2C2C0000002C000000000000000000002C00002C0000002C00
002C002C000000002C2C2C2C00002C2C00000000007373732C2C2C00002C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C002C002C0000002C0000002C2C00002C2C2C2C2C2C002C00
0000002C0000002C000000000000000000002C2C2C00002C0000000000002C2C2C000000
0000002C00000000002C0000002C0000002C2C00002C000000002C2C2C2C002C00002C00
002C002C2C2C2C0000002C00002C002C2C2C00002C0000002C000000002C00002C000000
002C0000002C2C0000002C005F975F002C00002C00002C0000002C0000002C00002C2C2C
2C00002C0000002C0000002C2C0000002C00002C0000002C002C007300005F5F97975F5F
4949492C2C2C002C00002C002C00000000002C0000000000002C00000000000000002C00
00002C002C0000002C002C002C0000002C002C0000000000000000000000002C0000002C
2C000000002C0000002C0000002C00002C00000000000000002C0000002C2C0000002C00
00002C002C00000000000000494949858585C5C5EFB6B6B6000000000000002C00002C00
00002C0000002C0000000000000000002C0000002C00002C0000000000002C2C2C002C00
0049000000000000002C0000000000000000002C00000000002C00000000000000000000
002C0000002C002C002C2C2C0000008585855F5F5F97975F2C2C2C97C5C5975F5F00002C
2C2C2C0000004949495F5F5F7373732C2C2C5F5F5F73737397975F00490097975F2C2C2C
5F975F9797974949492C2C2C5F5F5F002C0097975F4949492C2C2C97C597002C005F5F5F
490000A7A7A7B6B6B6C5975F97975FB6B6B65F97C597C5C55FC5C597C5C55FC5C55F9797
0097975F5F5F5F5F975F97975F97975F97975F975F737373005F5F7373735F5F5F5F975F
5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F7373735F5F5F5F5F5F5F5F5F7373735F5F5F5F5F5F
5F5F5F5F5F5F5F5F5F5F97975F5F5F5F5F5F737373005F5F005F5F5F5F5F5F9797494949
0049005F5F5F494949005F5F5F5F5F5F5F5F005F5F5F5F5F5F975F5F5F5F5F9797737373
4949497373735F5F975F979797975F4949494949494949492C2C2C2C2C2C2C2C2C494949
5F5F5F5F5F5F494949005F5F7373734949499797975F5F5FB6B6B697C5EFC5EFC597C5C5
97C5EFC5C5EF97C5C5005F5F
002C0000002C2C2C2C2C2C2C002C004900002C00002C00002C0000490000002C00002C00
000000000000002C0000000000002C2C00000000000000002C2C2C002C002C2C2C2C2C2C
002C00002C002C2C2C002C00002C002C2C2C002C002C2C2C5F5F972C2C2C002C00490000
002C002C2C2C2C2C2C2C00000000002C000000002C0000002C2C2C0000002C2C2C00002C
2C000000002C2C00002C00002C2C2C002C00002C00002C002C2C2C2C2C2C2C2C2C002C00
000000002C0000002C2C00002C2C2C002C0000002C2C0000002C002C0000002C002C0000
2C2C2C2C0000002C00002C00A7A7A700002C002C000000000000002C000000002C2C0000
002C002C0000002C000000002C00002C2C2C002C00002C000000007300005F5F979797C5
A7A7A7858585C59797975F5F49494900002C002C002C2C2C000000002C002C00002C0000
002C00002C00000000002C0000002C000000000000002C000000002C0000002C00000000
2C0000002C0000002C00000000002C000000002C002C0000002C0000000000002C2C0000
2C0000002C0000000000000085858597C5C55F9797494949002C00002C0000002C002C00
2C0000002C000000002C00002C00002C0000000000002C005F975F2C2C2C975F005F5F00
5F5F5F979797000000002C00000000000000000000000000000000000000000000000000
000000000000002C0000002C00000000000085858597979749494900002CEFFFC5737373
5F975F005F005F5F5F4949495F5F5F97C55F005F5F5F975F5F5F5F9797972C2C2C5F975F
49494900004973737397975F00002C2C2C2C002C00004900C5C5C59797972C2C2CD4D4D4
002C002C2C2C97975F2C2C2C2C2C2C97975FA7A7A797C5C5A7A7A75F97975F979797C5C5
5F97977373737373735F5F977373735F5F5F5F975F5F97975F5F5F5F97975F975F005F5F
5F5F5F494949005F5F5F5F5F7373735F975F5F975F737373005F5F5F97975F5F5F5F5F5F
005F5F5F5F5F5F5F5F5F5F5F005F5F5F5F5F5F5F5F005F5F737373005F5F858585005F5F
5F5F5F5F5F5F005F5F4949495F5F5F2C2C2C4949497373735F5F5F5F5F5F5F5F5F5F975F
7373738585857373735F5F5F5F5F5F5F975F9797C5005F5F494949494949005F5F2C2C2C
2C2C2C2C2C2C2C2C2C5F5F5F5F975F5F5F5F4949495F975F494949975F5F5F5F5F979797
97C5C55F97979797975F5F5F
2C00002C000000002C2C2C2C002C002C2C2C4900002C2C2C002C00002C00002C00002C00
0000000000000000002C00002C2C2C2C2C2C2C00000000002C2C2C2C2C2C2C2C2C2C0000
002C00002C00002C002C000000002C002C00002C002C2C2C00002C00002C2C2C2C000000
2C2C2C2C2C2C00002C00002C00002C00002C2C2C2C2C2C2C002C002C2C2C002C0000002C
00000000002C2C2C2C00002C2C2C2C2C00000000002C000000002C002C002C2C2C00002C
002C00002C002C2C2C0000002C2C2C002C002C000000002C002C00002C00002C00002C00
2C0000002C0000002C000000002C002C2C2C002C0000002C002C00000000000000002C00
00002C2C00002C2C2C2C000000002C002C000000002C00002C00008500009797C5975F97
9797C59797C5A7A7A7975FC5975FC59797C5975F977373732C2C2C2C0000002C00002C00
002C00002C00002C002C000000000000002C000000002C0000002C00002C0000002C0000
00002C000000000000000000002C00000000002C002C000000002C000000000000000000
000000002C00002C005F975F858585B6B6B6975F5F2C00000000002C0000000000000000
2C00000000002C00000000000000002C2C2C0000009797005F5F004900005F5F00A7A7A7
C59797730000002C00002C002C00002C00002C0000002C0000002C00000000002C000000
00000000002C000000000000000000002C002C2C2C5F5F5F97C5975F975F000000FFC5C5
7373735F5F004949492C2C2C5F5F005F5F5F5F975F2C2C2C5F975F5F5F5F8585852C2C2C
494949975F5F2C2C2C97975F5F5F00975F5F2C2C2C97979700000097C5C55F975FC5C597
00002C979797002C002C000000002C0000002C2C2C5F9797A7A7A7858585979797858585
5F5F975F97979797975F97975F975F5F5F5F5F5F5F5F5F975F5F5F5F975F5F5F5F5F975F
7373737373735F5F5F005F5F5F5F5F4949495F5F5F005F5F5F5F5F5F975F737373737373
005F5F5F5F5F5F5F5F4949494949495F5F5F2C2C2C5F5F5F494949494949737373858585
49494900975F4949495F975F005F5F4949495F5F5F5F5F5F2C2C2C4949495F5F5F005F5F
9797975F5F5F97975F8585855F5F5F8585855F975F5F979797C5975F97975F5F5F004900
490000005F5F4949495F5F5F5F5F5F0000495F5F5F5F5F5F2C2C2C494949494949494949
7373732C2C2C5F5F5F5F5F5F
00002C2C00002C00002C2C2C7373732C2C2C00002C49000000002C2C2C2C002C00002C00
00002C002C0000002C2C2C2C002C000000002C0000000000002C002C000000002C000000
2C2C2C002C002C2C2C0000002C2C2C2C2C2C2C2C2C2C2C2C00002C0000002C0000000000
2C2C2C00002C2C00002C2C2C00002C002C002C2C2C2C2C2C2C2C2C000000002C00002C00
2C0000002C0000002C2C2C2C002C00002C00002C002C000000002C2C2C2C49000000002C
2C000049000000002C2C00002C2C2C2C2C2C2C00002C0000002C00002C002C2C2C00002C
0000000000002C2C2C002C002C00000000002C000000000000002C000000000000002C00
2C000000000000000000000000000000002C002C00002C00000000C55F00C55F97A7A7A7
A7A7A79797C59797C5A7A7A7A7A7A79797C59797C59797C5A7A7A7A7A7A7979797737373
002C002C2C2C2C000000002C0000002C00000000002C00000000002C2C2C002C0000002C
00000000002C0000002C2C2C0000000000000000000000002C0000002C002C000000002C
0000002C0000005F5F979797C5C5C59797970000000000002C0000000000002C002C0000
0000002C0000002C00002C002C0000002C002C0000C59797C5C5C500002CC55F00975F5F
7300002C2C2C00002C002C002C0000002C000000000000002C000000002C002C002C0000
000000000000000000002C00000000002C002C2C2C000000494949C5C5C5494949C5C597
5F5F5F5F975F5F5F00858585005F5F5F975F5F975F5F975F00490097975F5F975F5F975F
4949492C2C2CC5C55F2C2C2C2C2C2C4949495F5F5F494949494949C5C5C52C2C2CD4D4D4
005F5FC5EFC500002C002C0000002C002C0000002C0000004949495FC597A7A7A7858585
8585855F975F5F5F5F8585859797978585855F9797005F5F5F975F5F5F5F5F975F5F5F5F
5F975F5F5F5F5F5F5F5F5F5F5F975F5F975F005F5F005F5F005F5F5F5F5F5F5F975F5F5F
5F9797005F5F7373735F5F5F5F5F5F5F5F5F2C2C2C5F5F5F4949492C2C2C005F5F5F5F5F
4949495F975F7373735F97975F97975F9797005F5F002C000049005F975F4949495F5F5F
5F5F5F005F5F5F9797494949002C00005F5F97975F4949495F5F5F4949495F5F5F005F5F
5F5F974949490049000049004949495F975F005F5F4949492C2C2C005F5F5F975F2C2C2C
2C2C2C8585854949495F5F5F
000000000000002C002C2C2C00002C2C2C2C002C00002C0000000000000049000000002C
2C2C2C002C002C2C2C00002C2C000000002C00002C002C0049000000002C002C00000000
0000000000002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C490000002C002C00002C0000
4900002C2C2C002C0000002C2C00002C2C2C002C00002C00000000000000000000002C00
002C00002C00002C00002C002C2C2C00002C0000000000002C2C2C2C2C2C002C002C2C2C
2C2C2C2C2C2C2C2C2C002C00000000002C00002C00002C00002C002C2C2C002C002C2C2C
002C00002C00002C002C0000002C002C00002C0000002C002C00000000000000002C0000
00002C000000002C00000000000000000000002C000000002C2C2C97005F9797C5979797
979797975FC59797C59797C5A7A7A79797C59797C59797C59797C59797C5C597C59797C5
9797C59797979797975F5F002C00002C00002C0000000000002C00000000002C002C0000
2C0000000000000000002C00002C000000002C000000000000002C00002C2C0000002C00
000000002C0097C59797C5C55F9797494949002C0000002C002C0000002C002C0000002C
002C002C000000002C000000002C00975F97EFC55FC55F00C5975F5F0000850000C55F00
0000000000000000000000000000000000002C0000002C000000002C0000000000002C00
00002C00000000000000002C000000002C00002C000000002C2C2C494949C5EFC5A7A7A7
5F5F005F5F5F2C2C2C00002C5F975F4949495F5F5F97975F97975F002C002C2C2C97975F
97975FA7A7A72C2C2C004900A7A7A70000008585852C2C2CB6B6B62C2C2C2C2C2CC5C5C5
A7A7A7D4D4D40000000000002C00000000002C00002C000000002C00002C5F5F5F5F9797
97C5C55F97977373737373735F97975F975F9797975F975F5F975F5F975F5F975F5F5F5F
005F5F5F5F5F7373735F975F7373735F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F737373
5F5F5F5F5F975F97975F5F5F4949495F5F5F005F5F5F5F5F2C2C2C005F5F5F5F5F2C2C2C
2C2C2C494949005F5F5F5F5F9797978585855F5F975F97975F97975F5F5F005F5F5F5F5F
4949497373735F5F5F2C2C2C49494997975F5F5F5F2C2C2C4949497373735F97975F5F5F
005F975F5F5F005F5F005F97494949494949005F004949494949495F5F5F494949494949
5F5F5F005F5F4900005F5F5F
490000002C002C2C2C4900002C2C2C2C0000002C002C00000000002C000000002C000000
2C00002C0000002C002C2C2C4900000000002C000000002C00002C00002C0000002C0000
0000002C00002C2C2C2C2C2C2C2C2C2C0000002C002C0000002C00002C0000002C002C00
002C00000000002C00002C002C2C2C002C000000000000000000002C0000000000000000
000000002C00002C00002C00000000002C0000002C2C0000000000002C002C2C2C00002C
2C00002C00000000002C00002C2C2C002C002C00002C00002C00002C000000002C00002C
0000002C00002C00000000000000002C0000000000002C000000000000002C2C2C00002C
00002C2C0000002C00002C0000000000002C002C0000000000002C9797C5B60000A7A7A7
A7A7A79797979797C59797C59797C5A7A7A79797C597C5C59797C59797C59797C59797C5
9797C5975FC59797C5C55F5F97975F9797974949492C2C2C002C0000002C00002C000000
00002C000000002C0000002C2C0000002C00002C002C0000002C0000002C002C002C0000
002C005F975F5FC59797C5C597C597002C00002C0000000000002C2C2C2C000000002C00
2C00000000005F5F5FEFC597C5975FC55F00C55F00002C002C2C2C490000975F0000002C
000000000000002C000000002C0000002C00000000002C0000000000002C000000000000
000000002C002C0000000000002C0000000000000000000000002C0000002C2C2CC5EFC5
C5C55F8585855F5F00005F005F5F5F5F5F5F002C002C2C2C2C2C2C97975F2C2C2C000049
2C2C2C97975F97975F5F5F5F2C2C2C494949B6B6B697975F975F5F002C00979797975F5F
000000B6B6B62C000000000000002C2C0000002C00002C002C000000002C2C2C2C2C2C2C
5F5F97A7A7A797C5C57373737373735F5F5F5F975F7373739797977373735F979700975F
7373737373735F5F5F975F5F005F5F5F975F5F5F5F7373737373735F5F5F5F5F5F5F5F5F
5F97975F5F5F005F5F8585858585855F97975F975F5F5F5F494949005F5F5F5F5F2C2C2C
005F5F4949492C2C2C005F5F5F5F5F5F5F5F9797977373735F5F5F5F9797C5C5975F9797
97C5975F975F4949494949495F5F5F5F5F5F2C2C2C2C2C2C005F5F5F9797494949494949
0097C55F97975F5F007373735F5F5F5F5F5F5F5F9797975F2C2C2C2C2C2C2C2C2C005F5F
2C2C2C4949495F5F5F5F5F5F
00002C2C2C2C4900002C00002C000000002C002C0000002C00002C002C00000000000000
2C2C2C00002C2C2C2C2C2C2C00002C2C000049000000002C00002C000000000000002C00
002C002C2C2C2C00002C00002C0000002C002C000000002C002C00000000002C00975F5F
000000000000000000000000000000000000000000000000002C002C0000002C002C0000
002C000000002C2C2C0000002C0000000000002C0000002C0000002C0000002C00002C00
2C000000002C0000000000000000002C2C2C49000000002C490000002C00002C002C2C2C
002C0000002C00002C2C000000000000002C000000002C0000002C2C00002C000000002C
2C2C2C2C2C2C002C00000000002C00000000002C002C2C2C5F5F005FC5C5C55F00975F97
A7A7A7C597C59797C5975F97C55F97975F979797C5A7A7A79797C59797C59797C59797C5
5F5FC59797979797C5979797975F979797979797C5A7A7A7A7A7A7975F5F2C2C2C002C00
002C00002C000000000000000000000000002C0000002C00002C002C0000000000002C00
005F005F979797C5EF5F97972C2C2C0000002C2C2C0000000000000000002C00002C2C2C
979797C59797C55F5FC5975F49000000002C002C00002C002C0000000000000000000000
00000000000000000000002C000000000000000000000000000000000000000000000000
002C00000000000000002C0000002C002C00002C000000000000000000000000002C2C2C
E1E1E1A7A7A797975F9797978585855F97975F975F5F5F005F5F0097975F73737397975F
49000000490097975F2C2C2C5F5F5F97975F2C2C2C002C0097C5975F5F5F97975F002C00
002C0085858597975F0000002C0000002C005F5F5F2C0000000000002C0000002C000000
2C2C2C2C2C2C5F9797A7A7A7A7A7A75F975F5F975F5F975F5F5F977373735F975F5F5F5F
5F975F5F975F7373737373737373735F975F737373858585005F5F5F97977373735F5F5F
4949495F5F5F5F5F5F737373005F5F7373735F97975F975F005F5F5F975F5F5F5F494949
5F975F494949005F5F5F5F5F2C2C2C494949005F5F49494900005F5F5F5F494949A7A7A7
C5C597B6B6B65F975F5FC5975FC5975F5F5F2C2C2C5F5F5F8585855F5F5F2C2C2C005F5F
5F975F5F5F5F5F5F005FC5C597975F4949495F979700975F4949495F5F5F5F9797494949
4949492C00004949495F5F5F
490000002C0000002C2C2C2C002C002C2C2C002C0049000000002C002C0000002C2C2C2C
002C00002C002C00002C2C2C2C2C2C00002C00002C2C2C2C00002C2C00002C00002C2C2C
2C00002C2C2C00002C2C0000002C002C2C2C2C2C2C2C2C2C00002C002C00002C002C2C2C
4900002C2C2C2C2C2C002C0049000000002C2C0000002C00002C00002C0000000000002C
000000002C00002C002C000000002C2C0000002C002C2C2C2C0000490000002C00002C00
00000000002C000000000000002C002C0000002C00002C0000002C002C00002C00002C00
00002C2C0000490000002C00002C002C0000002C0000002C2C00002C000000002C2C2C2C
2C0000002C002C00002C00002C00002C2C2C002C00000000490000C55F5F9797C59797C5
9797C5C55F97A7A7A7C55FC5A7A7A79797C59797C5A7A7A7979797979797975FC59797C5
A7A7A7C55F9797975FC55FC5975F975F97C5975FC5975FC5A7A7A79797C59797C5A7A7A7
975F5F002C0000002C2C00002C0000000000A7A7A797975F0049002C000000002C2C2C2C
A7A7A7A7A7A7979797C5975F00002C0000002C0000000000002C005F5F5FC59797C5975F
C55F00C5C59700002C2C000000002C2C2C2C2C0000002C0000000000002C0000002C2C2C
00000000002C002C002C000000002C00000000002C002C00000000000000002C00000000
00002C002C0000000000000000000000002C2C0000000000000000000000002C00000000
2C2C2CEFEFC549494949494997C59797975F00490097975F97975F97975F97975F5F5F5F
4949499797975F5F5F737373C5C59700002C2C2C2C97C597002C002C000000002C002C00
002C00FFEFEF0000002C2C2C002C002C2C2C0000000000002C00002C2C2C00000000002C
002C0000002C002C004900005F97975F9797A7A7A75F975F5F5F5F5F5F5F5F5F5F5F975F
5F97975F975F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F7373735F975F5F5F5F005F5F5F5F5F
5F5F5F005F5F5F5F5F4949494949495F975F4949495F97975F97978585855F5F5F005F5F
5F5F5F002C005F5F5F5F5F5F2C2C2C5F5F5F494949005F5F737373494949494949737373
494949858585B6B6B6A7A7A7B6B6B65F5F5F7373735F9797005F5F2C2C2C494949737373
4949492C2C2C4949495F975F2C2C2C4949495FC5EFC5C55F4949492C2C2C5FC5975F975F
5F975F5F9797A7A7A7005F5F
002C004900002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C002C0049000000002C
002C00002C002C2C2C2C2C2C002C002C2C2C00002C2C2C2C2C2C2C2C2C2C2C0000002C00
002C002C2C2C00002C002C002C0000002C00002C002C2C2C2C2C2C002C0000002C2C2C2C
002C000000002C2C2C2C2C2C002C002C2C2C00002C490000002C0000002C2C00002C0000
2C00002C00002C2C2C00002C2C00000000002C2C2C002C00002C00002C0000002C000000
0000000000002C2C2C0000002C000000002C2C000000002C002C002C2C2C2C0000002C00
2C2C2C002C00002C00002C00002C002C2C2C2C0000000000002C00002C0000002C000000
2C2C2C00000000002C2C0000000000000000490000000000850000975F97979797A7A7A7
9797C5A7A7A7C55F979797C59797C5A7A7A7C59797C55F97975F97975FC59797C5A7A7A7
975F97A7A7A7975F5F975FC5975FC59797C5975F97975FC59797C5A7A7A79797979797C5
A7A7A7002C002C00002C0000002C00850000FFC55FFFC500FFC55FFFEF00C5975F858585
97C597C5C5C5C5EFC5002C002C00002C00002C2C2C97C597A7A7A7C59700C5975F5F5F00
00002C00000000000000002C2C0000002C002C00000000002C0000000000000000000000
000000002C00000000000000000000002C000000002C000000002C0000002C2C2C000000
000000000000000000002C002C0000002C000000000000000000000000002C0000000000
0000002C2C2CFFEF979797975F5F5F5F975F5F5F5F97C597494949004900004900494949
002C002C2C2C494949B6B6B6A7A7A7737373C5C5972C2C2C000000004900005F5F5F9700
B6B6B62C2C2C2C2C2C00002C2C0000002C002C000000000000002C00002C00000000002C
0000000000002C00000000002C00005F5F5F8585855F97975FC5975F975F5F975F5F5F5F
5F975F8585855F975F8585857373735F5F5F5F5F5F5F975F5F5F5F5F5F5F7373735F5F5F
005F5F4949495F5F5F494949494949494949494949005F5F4949495F975F5F5F5F979797
5F5F5F005F5F5F5F5F494949005F5F4949492C2C2C2C2C2C5F975F2C2C2C4949495F5F5F
2C2C2C5F5F5F5F975F5F5F5F5F5F5FA7A7A7A7A7A7A7A7A75F975F005F5F9797975F975F
2C2C2C2C2C2C5F97975F5F5F2C2C2C5F5F5F97975F5F5F5F49494949494997C5975F5F5F
2C2C2C979797494949494949
2C0000002C002C00002C00002C2C2C2C2C2C2C2C2C002C002C00002C00002C2C2C2C2C2C
00002C2C2C2C2C2C2C002C002C2C2C2C2C2C002C0000002C2C2C2C2C2C2C00002C2C0000
2C2C2C002C00002C00002C000000002C0000002C0000002C002C00490000002C002C0000
2C00002C2C2C2C2C2C2C2C2C002C002C2C2C002C00002C0000002C00002C002C002C2C2C
2C0000002C002C2C2C2C2C2C0000002C00002C000000002C002C00002C002C2C2C000000
002C002C0000002C000000002C0000002C002C00002C000000002C002C00002C002C2C2C
002C00002C00002C002C000000002C2C0000002C00002C00002C000000002C2C2C2C0000
002C002C00002C0000000000002C00002C0000002C2C0000B6000097C5C5A7A7A79797C5
975FC5975FC59797C5A7A7A79797C597C5C5A7A7A79797C5C597C5C597C5975F97975F97
C55FC5A7A7A7C55F00A7A7A7979797975F97975FC5975F979797C5979797975F97975FC5
B6B6B697975F5F975F00002C00002C975F00FFC55FEF97005F5F00C55F00975F00737373
97C5EFC5C5C52C000000002C5F5F5FC5C597C5975F970000C5975F2C2C2C00002C00002C
002C002C00002C0000002C00000000000000000000002C00002C002C0000002C00002C00
00000000000000002C002C000000000000002C0000000000002C00000000000000000000
000000000000002C00000000000000002C0000000000002C002C0000000000002C2C0000
2C00000000002C0000D4D4D42C2C2C97C597858585A7A7A797C597975F5F2C2C2C494949
C5C5C5A7A7A72C2C2C2C2C2C2C00000000005F5F5F00002C002C00B6B6B6975F5F5F5F5F
5F5F5F2C2C2C002C002C000000000000002C2C0000002C002C000000000000000000002C
002C00002C000000002C0000002C0000002C002C007373735F97975F97975F97975F5F5F
5F975F5F5F5F5F5F5F5F975F8585855F975F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F00975F
7373735F5F5F5F97975F5F5F5F5F5F5F5F5F005F5F4949492C2C2C4949495F975F494949
5F97979797977373735F5F5F737373005F5F2C2C2C5F975F005F5F2C2C2C858585005F5F
494949005F5F5F5F5F4949494949495F975F005F5F5F5F5FB6B6B6B6B6B6A7A7A72C2C2C
005F5F5F5F5F7373732C2C2C494949A7A7A77373732C2C2C2C2C2C97C5975F5F5F2C2C2C
4949495FC5C597C5975F5F5F
2C2C2C002C002C2C2C2C000000002C2C2C2C2C2C2C4900002C2C2C002C002C2C2C000000
00002C2C2C2C2C2C2C490000002C0000002C00002C2C2C2C2C2C2C2C2C2C2C2C2C002C00
002C004900002C2C2C2C00002C00004900002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000
002C002C2C2C2C2C2C2C2C2C002C002C2C2C2C0000002C004900002C2C2C00002C2C0000
002C00002C00002C00002C002C2C2C2C2C2C002C002C2C2C002C00002C002C2C2C000000
2C000000002C2C000000002C00002C2C0000002C00002C00000000002C0000002C002C00
002C0000002C002C002C0000002C00000000002C002C0000000000002C002C0000002C00
002C000000002C00000000002C00002C00002C0000000000C55F9797C5EFC597C597C5C5
9797C597C5C5B6B6B69797C59797C5B6B6B69797C5A7A7A7C55FC597C5C59797C59797C5
9797C5A7A7A7A70000A7A7A7979797A7A7A79797C5975FC5975F97975F97975F979797C5
979797B6B6B6C55F97B6B6B6C5C597C55F00FF975FFFC55FC5975F97975FFF9700EFC597
C5C5C5C55F5FEF9700979797C597978500005F5F00002C000000002C00000000002C2C2C
00002C2C000000002C00000000002C000000002C00000000002C00000000000000000000
00000000000000002C000000002C002C0000000000000000000000000000000000000000
000000000000000000002C0000002C00000000000000000000002C000000000000000000
00002C2C0000002C00000000494949D4D4D4C5C5972C2C2C002C0097C597004900494949
979797C5EFC500002C0000005F5F5FC5C5C5EFC5C5C5C5C5C5C5C52C2C2C00002C00002C
002C002C00002C2C2C002C0000000000002C00000000000000000000002C000000000000
0000002C000000002C002C002C00002C0000002C002C00004949495F97C5A7A7A7979797
5F97975F975F5F5F5F5F5F5F5F5F5F9797978585855F975F5F5F5F5F5F5F4949495F5F5F
5F975F005F5F5F5F5F5F5F5F5F97975F5F5F4949495F5F5F2C2C2C494949005F5F494949
737373005F5F4949498585859797975F975F005F5F5F975F494949005F5F858585494949
4949499797972C2C2C2C2C2C5F97974949492C2C2C4949495F975F4949495F5F5F979797
979797B6B6B65F975F5F00005F975F737373005F002C2C2C005F9797975F2C2C2C2C2C2C
005F5F97975F5F5F5F5F5F5F
002C002C2C2C00002C2C2C2C00002C2C2C2C002C00002C002C2C2C2C2C2C002C002C0000
2C2C2C2C2C2C00002C0000002C2C2C00002C2C2C2C002C0000002C002C002C2C2C2C2C2C
2C2C2C002C002C2C2C00490000002C002C00002C00002C002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C002C002C2C2C2C2C2C2C2C2C005F5F005F5F002C002C2C2C002C00002C002C2C2C
2C2C2C002C002C00002C2C2C2C2C2C002C00002C002C2C2C2C2C2C000000002C002C2C2C
2C2C2C00002C00002C00002C002C0000002C2C0000002C000000002C2C2C2C0000002C00
0000002C2C2C2C2C2C002C002C2C2C2C00002C2C2C2C2C2C002C00000000002C00002C00
2C2C2C0000002C2C2C2C000000002C00002C002C00002C00C55F979797C597C5C59797C5
9797C59797C59797C59797C59797C597C5C59797C59797C59797C597C5C5C597C5A7A7A7
B6B6B6A7A7A7C55F00A7A7A7C55F97C55F97975FC5C597C5A7A7A7A7A7A7975F97975F5F
C5975FA7A7A7C5C55FA7A7A7C5C597C55F00FF9700EF9700FF9700EFC597EFC597FFC597
C5C55FEF975FFFC5975F5F005F000000002C2C2C2C000000000000002C0000002C002C00
002C00000000002C0000002C0000002C0000002C000000000000002C2C2C00000000002C
2C000000000000000000000000000000002C00000000002C00000000002C000000000000
002C00000000000000000000000000002C00000000000000002C00000000000000000000
00000000002C000000000000002C002C00005F5F5F2C2C2C5F5F5FB6B6B64949492C2C2C
2C2C2C2C2C2C97975FC5EFC52C2C2C2C2C2C000000A7A7A72C2C2C002C0000002C000000
00002C2C000000002C2C000000000000002C002C00002C0000000000002C000000000000
000000002C000000002C000000002C2C0000000000002C000000002C2C2C7373735F9797
A7A7A77373735F97975F5F5F005F975F5F5F5F975F8585855F97975F975F5F5F5F5F5F00
005F5F7373737373735F5F5F5F5F5F005F5F7373735F5F5F4949495F5F5F494949005F5F
5F975F0000494949495F9797005F5FA7A7A75F9797A7A7A74949495F975F005F5F005F00
49494997975F2C2C2C2C2C2CA7A7A74949492C2C2C9797975F5F5F002C00005F5FA7A7A7
5F975F5F5F5FA7A7A78585855F9797494949494949007300B6B6B6005F5F2C2C2C2C2C2C
A7A7A75F5F5F2C2C2C5F5F5F
002C002C00002C2C2C2C2C2C000000002C002C0000490000002C00002C002C0000002C00
4900002C2C2C2C0000002C0049000000002C4900002C2C2C002C00490000002C002C0000
2C2C2C002C00002C002C0000002C002C00002C2C2C002C002C2C2C002C004949492C2C2C
2C2C2C002C00002C002C2C2C4900002C2C2C4949492C2C2C002C0000002C2C2C2C002C00
2C2C2C2C2C2C2C00002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C0000002C0000002C
002C0000002C7373732C2C2C2C2C2C490000002C00002C002C0000000000000000490000
002C00002C00002C002C2C2C002C00000000002C00002C0000002C00002C2C2C2C2C0000
2C2C2C002C00002C002C00000000005F5F970000000000002C2C2C00002C000049A7A7A7
97C5C5C5C5C597C5EFB6B6B697C5C55F97C59797EF9797C59797C59797C59797C597C5C5
975FC597C5EFA700009797C5A7A7A79797C59797C59797C59797C5979797C55F97C59797
9797975F005F97975FC59797C5C597C5975FFF97005F5F00C55F00FFC597FFC55FFF9700
975F00C59700FFEF972C2C2C9797C59797C55F5F5F2C2C2C002C002C2C2C000000002C00
002C002C0000000000002C002C000000002C0000000000000000000000000000002C0000
0000000000002C2C2C2C0000002C00002C0000000000000000000000000000000000002C
000000002C0000000000000000000000000000000000000000002C000000002C0000002C
00000000000000000000002C000000002C00000000C59797A7A7A72C2C2C5F5F5F5F9797
7373735F5F5FB6B6B65F5F0000002C002C00737373C5EFC5490000000000002C00002C00
000000002C00002C0000000000002C000000002C002C0000002C0000002C000000002C00
2C00000000002C00000000000000002C0000002C002C00002C2C2C000000002C002C0000
5F97975FC5C597C5C55F97975F97975F975F5F5F5F5F97979797975F97979797975F5F5F
4949495F5F5F5F5F5F005F5F005F5F7373737373735F5F5F5F975F7373735F5F5F5F5F5F
5F5F5F494949005F5F4949494949495F97977373735F97975FC59785858597C55F494949
5F97974949492C2C2C7373737373732C2C2C2C2C2C7373732C2C2C2C2C2C979797494949
2C2C2C494949858585C5C59773737397C5975F975F97C5C5A7A7A7494949494949979797
975F5F4949492C2C2C5F5F5F
2C0000002C004900000000002C2C2C2C0000002C00002C002C2C2C002C002C2C2C002C00
2C2C2C2C2C2C002C002C2C2C2C2C2C00002C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C00002C2C2C2C00002C2C2C002C0049000049000000002C002C002C0000
002C00002C002C2C2C5F00002C2C2C2C2C2C2C2C2C2C2C2C00002C2C0000002C002C2C2C
002C002C2C2C2C2C2C2C2C2C2C2C2C00002C2C00002C2C2C002C00002C002C0000000000
002C002C2C2C00002C00002C002C00002C00002C00000000002C00000000000000002C00
002C00002C002C2C2C00002C2C2C2C002C002C2C2C00002C2C000000002C00002C002C00
2C0000000000002C002C2C2C0000002C2C2C000000000000002C00002C0000002C2C0000
002C002C2C2C0000002C2C2C0000495F5F979797C597C5C597C5EF9797C597C5EF9797C5
9797C597C5EFA7A7A7975F979797C5A7A7A79797C597C5C59797C59797C5975FC5C597C5
A70000A7A7A797975F494949C59797FFC55FFFC55FFFC597EFC55FFFC597FFC55FEF9700
7300002C2C2CFFEF5FC597979797C5B6B6B6A7A7A7975FC597C5C58585852C2C2C00002C
000000000000002C002C2C2C002C00000000002C00002C000000002C0000000000002C00
000000002C00000000000000000000000000000000000000000000002C00000000000000
00000000000000000000000000000000000000002C002C000000002C2C2C000000000000
0000002C0000000000000000000000002C0000002C2C000000002C2C00005F5F5F737373
858585975F5F5F00005F5F5FB6B6B6B6B6B65F5F5F2C2C2C002C0000002C0000002C2C2C
000000000000002C000000000000002C2C2C0000002C0000000000002C0000002C000000
00000000002C00002C00002C002C0000002C000000002C00000000000000002C0000002C
002C002C2C2C5F97975F97C5A7A7A79797978585855F5F5F5F97975F97975F5F5F979797
8585855F5F5F005F5F4949495F5F5F005F5F005F5F858585858585737373494949737373
5F5F5F4949495F5F5F494949005F5F5F975F494949005F5F979797979797B6B6B65F5F5F
8585855F5F5F5F5F5F97975F5F5F5F2C2C2C5F97974949492C2C2C000049737373494949
2C2C2C7373735F5F5F494949000049B6B6B6A7A7A7975F5FA7A7A75F5F5F5F9797A7A7A7
5F5F0000002C2C2C2C5F5F5F
002C002C0000002C002C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C002C00
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C4900002C2C2C2C00002C2C2C4900002C2C2C002C00002C00002C002C2C2C2C2C2C
002C00002C00002C002C2C2C2C2C2C2C2C2C4900002C2C2C2C2C2C4900002C2C2C2C2C2C
2C2C2C2C2C2C4900002C2C2C2C2C2C2C2C2C002C002C2C2C490000002C00002C002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000000000000000002C00002C0000002C002C2C2C
002C00002C002C2C2C002C000000002C00002C00002C00000000002C00002C0000002C00
0000002C2C2C00002C002C000000000000002C2C2C00002C0000002C2C2C000000002C00
002C002C2C2C2C2C2C0000492C2C2C00000000002C2C2C2C2C2C2C0000495F5F979797C5
C597C5979797975FC59797C55F97C59797EF9797C597C5C59797C59797C5B6B6B69797C5
A70000C5C597C5C597975F5FC5975FFFEF5FFFEF5FFFC500C55F00FFC55FC59700975F00
C500005F0000FFC55FC5C5979797C5A7A7A79797C59797C59797C5A7A7A797C5C5C5C5C5
C5975F5F5F002C2C2C000000002C0000000000002C00000000002C0000002C0000000000
2C000000002C002C00000000002C000000000000000000002C2C2C000000002C00000000
00002C000000000000002C000000002C2C2C0000002C0000002C002C000000002C000000
002C0000002C002C000000000000000000000000002C000000000000000000002C2C0000
002C0000002C00000000000000002C00002C0000002C2C2C000000000000000000000000
00002C00000000002C2C0000002C00000000000000002C0000002C2C0000002C00000000
0000000000000000000000000000002C00002C2C2C00000000002C000000000000000000
0000000000002C2C2C5F979797979797C5C5A7A7A75F97975F9797005F5F73737397975F
5F5F977373735F975F5F5F5F4949497373734949495F5F5F5F5F5F005F5F737373979797
737373005F5F5F9797494949494949005F5F4949495F97974949494949495F9797737373
B6B6B697C5977373735F975F005F5F4949498585855F5F5F2C2C2C005F5F4949492C2C2C
2C2C2C979797005F5F0049005F5F975F5F5F2C2C2C2C2C2C85858597C597975F5FB6B6B6
4949495F5F5FA7A7A75F5F5F
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0049004949492C2C2C2C2C2C0000492C2C2C
4949494949490049002C2C2C0049004949494949494949492C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C0049002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C2C2C2C2C0000
4900002C2C2C2C2C2C4900002C2C2C4949492C2C2C002C002C2C2C2C2C2C2C2C2C004900
002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C4900002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
00002C2C2C2C2C2C2C2C2C2C00002C2C2C2C0000002C2C2C002C00002C00002C00000000
00002C0000002C000000002C002C000000002C2C2C2C00002C000000002C0000002C2C2C
002C00002C00000000000000000000000000002C00002C00002C000000002C0000000000
2C00002C2C2C000000000000000000002C00002C002C2C2C00002C2C2C2C00002C000000
0000002C2C2C00002C4949495F5F9797C5C597C5EF97C5EF5F97C59797C59797C5C5C5EF
5F5F002C2C2C2C2C2C730000C55F5F850000C5975FFFEF97FFEF97FFEF5FFFC55F2C2C2C
5F0000C59700C5C597C5C55FA7A7A7C597C5C55FC5975FC5975FC5975FC5A7A7A7B6B6B6
C55F00A7A7A7A7A7A7A7A7A75F5F5F2C2C2C002C00002C00002C00000000000000000000
00002C0000002C00002C000000000000000000000000000000000000002C00002C000000
2C2C2C00000000000000000000000000000000002C00000000002C000000002C00000000
00002C002C000000002C00000000000000002C0000002C002C2C2C00002C2C0000000000
000000000000002C00000000002C000000002C2C2C002C000000000000000000002C2C2C
00000000000000000000002C000000002C000000002C0000002C0000002C2C000000002C
00002C2C0000000000000000002C0000002C00000000002C002C0000000000002C000000
000000000000002C0000000000002C97C5C59797975F97977373737373735F5F5F5F5F97
5F5F5F5F5F975F5F5F5F97975F5F97737373005F5F005F5F005F5F5F5F5F5F5F5F005F5F
5F5F5F5F97975F9797005F5F5F5F5F005F5F494949005F5F4949494949497373735F5F5F
5F5F5FA7A7A75F5F97C5C5C597C597737373737373005F5F005F5F979797005F5F002C00
5F9797A7A7A72C2C2C0049009797975F5F5F002C0049494997C5974949494949495F5F5F
5F9797A7A7A7B6B6B65F5F5F
005F5F494949005F5F5F5F5F005F5F005F5F5F5F5F005F5F005F5F005F5F005F5F005F5F
005F5F494949005F5F005F5F5F5F5F494949494949494949005F5F005F5F005F5F2C2C2C
4949492C2C2C4949492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0049002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C002C002C2C2C2C00002C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C002C00002C002C2C2C002C002C2C2C002C002C2C2C2C2C2C002C00
2C000000002C002C0000002C0000002C2C2C2C2C2C002C0000002C2C00002C00002C0000
2C2C2C002C002C00002C00002C2C2C2C2C2C2C2C2C00002C0000002C0000002C002C0000
002C00002C0000002C2C0000002C0000000000000000000000002C002C0000000000002C
00002C2C2C2C00002C2C0000002C000000002C2C2C00000000002C002C0000002C2C0000
002C000000002C2C2C0000002C2C2C00002C00002C2C2C2C005F5F975F9797C5C597C5EF
5F5F002C0000494949C55F5FC55F005F00005F0000970000C59797FFEF5FFFEF5FFFEF5F
FFEF5FFFEF97858585C55F5F97C5C5A7A7A79797C5975FC59797C5A7A7A79797C5975FC5
C5005FC597C5A7A7A7A7A7A79797C59797C5975F97A7A7A75F5F000000002C0000000000
0000000000000000000000000000000000000000002C2C2C00000000002C2C0000000000
0000002C00000000002C00002C00000000002C000000002C002C0000000000000000002C
000000000000002C002C0000000000002C000000000000000000002C0000002C0000002C
0000002C000000002C2C00002C00000000002C000000002C000000000000000000000000
00002C000000002C00000000000000002C000000000000000000002C0000002C00000000
002C000000002C2C2C002C000000000000000000000000000000002C00000000002C0000
002C00000000002C002C000000000000000073737397C5C597C5C5A7A7A75F9797979797
005F975F975F5F5F5F5F97977373739797975F5F5F5F975F005F5F5F5F5F5F5F5F494949
4949494949494949499797975F97975F975F5F5F974949495F5F004949495F5F5F494949
005F5F5F975F5F5F5F005F5FB6B6B65F9797A7A7A75F975F005F5F5F975F5F5F5F494949
858585005F5F2C2C2C5F5F5F9797972C2C2C0000497373734949492C2C2C5F5F5F97C5C5
5F5F5F5F5F5F975F975F5F5F
7373735F5F97005F975F97975F5F975F5F975F5F970097975F97975F5F97009797009797
005F97009797005F970097975F97975F97975F97975F9797005F5F005F97005F5F005F5F
4949495F5F975F5F5F494949005F5F005F5F005F5F4949490049004949492C2C2C2C2C2C
4949494949492C2C2C2C2C2C2C2C2C2C2C2C4949492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C002C00490000
00002C2C2C2C2C2C2C00002C2C2C2C2C2C2C4900002C2C2C2C0000002C00002C002C0000
002C002C2C2C490000002C002C2C2C002C00002C00000000000000002C002C000000002C
002C00002C002C00002C0000002C0000002C2C00002C0000002C00000000002C00002C00
0000002C0000000000002C002C2C2C0000000000000000002C00002C0000002C00000000
0000000000002C2C2C0000000000002C000000002C002C0000002C00002C2C00002C0000
002C000000005F5F00975F00B6000000002C494949B60000D40000975F00970000730000
730000975F5F2C0000975F5F9797C5A7A7A79797C5975FC5979797A7A7A7975F979797C5
C55F5F9797C5A7A7A79797C5A7A7A7C597C59797C59797C59797C5A7A7A700000000002C
2C0000000000000000002C00000000000000002C00000000000000000000000000000000
00002C002C0000000000000000000000000000002C00000000002C00000000002C002C00
00002C0000000000000000000000000000002C00000000002C000000002C2C0000000000
000000002C00000000000000002C0000002C000000002C0000000000002C002C00000000
002C00002C00002C0000002C2C000000000000002C00000000000000002C002C0000002C
00002C0000005F5F972C2C2C002C0000002C002C000000002C000000002C000000002C00
0000002C2C2C00002C00000000002C00002C2C00000000007373735F979797C5C5A7A7A7
7373735F97975F979773737300975F5F5F5F5F5F5F8585855F975F5F9797005F5F494949
005F5F005F5F4949495F5F5F5F5F5FA7A7A78585855F97974949495F5F5F5F5F5F2C2C2C
4949495F5F5F4949494949497373735F5F5F005F5F97C5975F9797B6B6B6005F5F005F5F
7373734949492C2C2C5F5F5F4949492C2C2C2C2C2CA7A7A74949492C2C2C005F5F97975F
2C2C2C4949495F5F5F5F5F5F
5F97975F97975F97975F97975F5F975F97C50097975F97975F5F975F97970097975F9797
5F97975F97975F97975F97C55F97975F97975F97975F9797009797009797009797009797
5F97975F97975F5F975F5F97005F975F5F5F5F5F5F5F975F5F5F5F5F5F5F005F5F005F5F
005F5F005F5F4949494949492C2C2C4949492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C002C005F00002C2C2C0049002C2C2C2C2C2C00002C2C2C2C2C2C2C
49000000002C49000000002C2C2C2C2C2C2C2C2C2C2C2C2C490000002C002C2C2C00002C
2C2C2C4900002C0000002C002C2C2C002C00002C000000002C2C2C0000000000002C0000
2C0000002C002C2C2C0000000000000000002C00002C00002C2C2C2C000000002C2C0000
2C00002C00002C2C2C00002C0000000000000000002C2C2C00000000002C000000000000
002C00000000002C0000002C2C0000002C0000002C2C00002C0000002C000000002C0000
002C0000000097975FC55F00C55F00C55F00C55F00C50000B60000B600009700005F0000
C55F002C2C2C002C00975F9797C5C59797C5A7A7A79797C59797C59797C59797C5975FC5
A7A7A7C597C5979797975FC59797C59797C5C597C5858585979797A7A7A72C0000000000
00000000002C000000000000000000000000000000000000000000000000002C00000000
000000000000002C0000000000002C002C00000000002C00002C002C000000000000002C
2C0000000000000000000000002C00002C00000000002C0000002C000000002C00002C00
00002C0000002C000000000000002C002C00002C0000000000002C2C0000000000000000
000000000000000000000000002C002C000000000000002C000000000000000000000000
000000002C000000002C2C2C2C000000002C000000002C0000002C0000000000002C2C2C
000000002C002C2C2C0000000000002C2C2C00490000002C002C000000005F97975F97C5
5FC5C55F97979797975F97977373735F5F5F5F975F7373735F5F5F9797975F9797737373
737373494949005F5F5F5F5F005F5F5F5F5F5F5F5F8585858585850097975F9797494949
494949494949004900494949979797494949005F5F7373737373735F5F975FC597737373
B6B6B6005F5F005F5F9797974949494949495F9797975F5F2C2C2C2C2C2CA7A7A72C2C2C
2C2C2C2C2C2C8585855F5F5F
5F5F975F97C55F97C55F97975F97975F97C55F97C55F97975F97975F97975F97C55F9797
5F97975F97C55F97975F97975F97975F97C55F97C55F97975F97975F97975F97975F97C5
5F97975F97975F97975F5F970097C50097970097975F97975F97975F97970097975F9797
5F5F5F005F970097975F5F5F5F5F5F005F5F4949494949494949490000494949492C2C2C
2C2C2C4949492C2C2C2C2C2C0049002C2C2C002C000000002C2C2C2C2C2C002C002C2C2C
2C2C2C002C0000002C490000002C00002C002C2C2C2C2C2C2C2C2C2C0000002C002C2C2C
2C2C2C002C002C2C2C002C002C00002C2C2C00002C490000000000002C00002C002C0000
0000002C2C2C00002C002C0000000000000000002C0000005F5F5F0000002C0000000000
002C002C0000000000002C000000002C2C2C0000000000002C2C2C002C00000000000000
2C2C2C00000000002C2C00000000000000002C0000000000002C0000000000002C00002C
00002C2C000000002C0000002C0000B6B6B6C5975FEF5F00C55F00C55F00850000970000
00002C0000000000005F5F97979797B6B6B697C5C59797C59797C59797C5979797979797
975F979797C5975FC5B6B6B6C55F97979797A7A7A7975F97A7A7A79797C5000000000000
00002C000000000000000000000000000000000000000000002C00000000000000000000
00000000002C000000000000000000000000002C0000002C00000000002C002C00000000
002C0000002C002C0000000000002C000000002C00000000000000000000000000002C00
2C00002C0000002C0000002C0000000000002C0000002C0000000000002C000000002C00
0000000000000000002C2C2C00000000002C0000000000000000000000002C2C2C000000
2C2C2C000000002C002C000000002C000000000000000000000000002C00000000000000
2C000000000000000000002C00002C00002C2C2C2C2C2C2C00000000002C002C002C2C2C
5F97975F5F975F97975F97975F97975F5F5F858585005F5F5F97975F5F5F8585855F9797
5F97975F5F5F005F5F4949494949495F5F5F4949495F975F7373737373738585855F5F5F
979797005F5F2C2C2C494949A7A7A72C2C2C005F5FA7A7A75F5F5F494949979797858585
5F97975F9797858585A7A7A7005F5F00975FA7A7A7494949002C00005F5F97C55F00002C
2C2C2C00002C97C5975F5F5F
5F97975F97C55F97C55F97C55F9797A7A7A75F97979797975F97975F97979797975F9797
5F97C59797975F97C55F97C55F97975F97975F97975F97C55F97C55F97975F97975F9797
5F97C55F97975F97975FC5C55F97975F97C55F97975F97975F97975F97975F97975F9797
5F97970097970097975F97975F97977373735F5F5F005F975F5F5F005F5F005F5F005F5F
5F5F5F005F002C2C2C2C2C2C2C2C2C4949492C2C2C2C2C2C2C2C2C4949490049002C2C2C
002C002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C4900002C2C2C490000002C00
2C2C2C2C2C2C002C002C0000002C00002C002C2C2C0000002C2C2C002C002C2C2C002C00
002C00002C0000002C0000002C00000000002C00002C0000000000002C002C00002C2C2C
00000000002C2C00000000005F5F5F2C00002C0000000000000000002C00000000002C00
0000002C0000000000002C00002C0000002C0000002C00002C0000002C00000000002C00
002C00002C00002C002C2C2CA7A7A7C5C5C5FFFFC5494949490000EF975F975F5F00002C
2C2C2C002C00002C00002C00002C002C2C2C975F975F97979797C59797C59797EFA7A7A7
975F9797C5EF9797C59797C59797C59797C5975FC5975FC59797979797C5000000000000
000000002C0000002C000000000000000000002C00000000000000000000002C00000000
00002C000000002C00002C00000000000000000000000000000000002C0000002C000000
0000000000000000000000002C0000000000000000002C00002C000000000000002C0000
00002C002C00002C0000002C0000000000002C0000002C0000002C005F5F000000000000
000000002C0000000000000000000000000000000000000000000000002C002C00000000
00002C2C00005F5F5F002C000000002C000000002C00002C0000000000002C0000000000
00002C0000002C2C2C000000000000002C000000000000002C000000002C2C2C2C000000
2C2C2CA7A7A75F97975F97975F97975F97979797974949495F5F975F97975F5F5F5F9797
8585855F5F5F7373735F5F974949495F5F5F005F5F5F975F5F5F5F494949494949979797
7373735FC5975F5F5F5F975F005F5F2C2C2C4949495F5F5F00002C005F5F9797975F5F5F
5F5F5FA7A7A75F97C55F5F975F97975F97977373734949492C2C2C9797975F5F002C0000
2C2C2CA7A7A75F975F5F5F5F
8585855F97C55F97C55F97975F97975F97C59797975F97C55F97975F97C55F9797A7A7A7
5F97C55F97C55F97979797975F97975F97975FC5C55F97975F97C55F97C55F97C55F97C5
5F97975F97975F97C55F97C55F979797C5975F97975F97975F97975FC5975F9797979797
5F97975F97C55F97975F97975F5F975F97975F9797009797009797009797005F5F005F97
005F5F5F5F97005F5F494949858585005F5F2C2C2C0049002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C4900002C2C2C002C002C2C2C0049005F5F000049002C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C00002C002C2C2C2C2C2C2C2C2C002C002C2C2C2C00000000002C2C2C
2C000000002C000000002C000000002C00002C000000002C000000000000002C00000000
000000002C00000000000000000000000000000000002C0000000000002C2C0000002C00
00000000002C2C0000002C00002C00002C002C0000000000000000000000000000000000
00002C002C0000002C49494997C5C5FFFFEF4949492C0000002C00FF975F002C00000000
000000000000002C002C0000000000002C00002C00002C0000000000002C494949979797
9797C59797C55F97C59797C55F97C5975FC59797C5975FC597C5EF97979700002C000000
002C00000000002C0000000000000000000000000000002C000000000000000000000000
0000000000002C0000002C00000000002C00000000000000000000000000002C00000000
0000002C00002C0000000000000000002C0000000000002C002C002C0000000000000000
00000000000000002C00000000002C002C000000000000000000002C2C2C000000002C00
000000000000002C002C000000002C00000000002C000000002C0000000000002C000000
002C002C2C2C2C000000002C00002C000000002C0000002C000000002C0000002C002C00
000000002C0000000000000000002C0000000000000000000000002C2C2C00002C002C00
002C0000002C2C2C2C5F97C55F97975F97979797977373739797975F975F5F5F5F5F5F5F
005F5F5F975F7373735F5F975F975F5F97974949495F5F5F494949005F5F494949494949
494949A7A7A75F97C55F97975F975F494949737373005F5F2C2C2C2C2C2C9797972C2C2C
00002C97C5975F5F5F2C2C2CA7A7A7858585A7A7A7005F5F5F975F97C5C52C2C2C000049
2C2C2CC5C5C57373735F5F5F
5F97975F9797979797A7A7A75F97C55F97975F97C55F97975F97975F97975F97C55F97C5
5F9797A7A7A79797975F97C5A7A7A75F97975F97C5A7A7A75F97C55FC5C55F97C55F97C5
5F97C597C5C5A7A7A75FC5C59797979797975F97975F97975FC5C55F97975F97975F9797
5F97C55F97975F97975F97C55F97975F97975F97975F97975F97970097975F9797009797
5F5F975F979700975F5F975F5F5F5F5F5F5F005F5F005F5F005F5F0049002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C4900002C2C2C
2C2C2C00002C2C2C2C2C2C2C2C2C2C2C000000002C2C2C2C000000002C002C2C2C2C2C2C
002C000000002C00002C2C2C2C00002C00002C00002C00002C0000000000000000002C00
0000002C000000000000002C00000000000000002C000000002C00000000000000002C00
00002C0000000000000000000000002C00002C2C2C002C00000000002C002C2C2C002C00
000000002C00002C00A7A7A797C5C5EFC59700002C00002C000000FF975F2C00002C0000
00000000000000000000002C2C0000002C0000000000000000000000002C000000000000
2C2C2C00002C5F5F979797C59797C59797C5975F979797C59797C55F9797002C00000000
000000002C00000000002C000000002C0000000000002C00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
002C00000000000000000000000000002C00000000002C00000000000000002C00000000
000000000000002C0000000000000000000000000000002C000000000000000000002C00
5F5F5F000000002C0000002C00000000000000000000002C00000000002C000000002C00
0000000000000000002C00002C2C2C00002C00002C00002C0000002C00002C0000002C00
00002C0000002C2C2C0000000000002C000000002C2C2C2C00002C0000002C0000000000
00002C000000000000002C007373735F97975F97975F97979797975F975F5F5F5F5F9797
4949495F5F5F4949495F97977373735F9797005F5F5F5F5F5F5F5F4949495F5F5F494949
005F5F7373735F975F2C2C2CA7A7A75F9797979797005F5F0000495F5F5F4949492C2C2C
5F5F5F5F5F5F2C2C2C2C2C2C7373732C2C2C5F5F5F97C597B6B6B6A7A7A75F5F5F494949
5F979797C597494949494949
97C5C5A7A7A7A7A7A79797975F97C59797975F97979797975F97975F97979797C55F97C5
9797975F97C55FC5C55F97C55F97C597C5C597C5C55F97C55F97C55F97975F97975FC5C5
5F97975F97979797975F97975F97C55F97C55F9797A7A7A75F97C5A7A7A79797975F9797
5F97975F97975F97979797975F97975F97975F97975F97975F97975F97975F97975F9797
5F97975F97975F97975F97975F97975F97975F97975F5F97005F5F005F5F005F5F5F5F5F
2C2C2C4949492C2C2C0000492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C494949
2C2C2C002C002C2C2C002C002C2C2C002C002C2C2C2C2C2C2C00002C2C2C49000000002C
002C002C2C2C002C002C00002C0000002C0049000000002C002C00002C00000000002C00
2C2C2C002C002C000000002C00000000000000000000000000002C0000002C000000002C
002C0000002C00000000000000002C000000002C002C0000000000000000002C002C0000
2C000000000085858597C5C5FFFFFF002C002C00002C2C2C2C2C2CEF975F002C0000002C
002C000000000000000000000000002C00002C0000002C002C2C2C2C2C2C00000000002C
2C2C2C00002C00002C2C2C2C2C2C2C2C2C2C9797979797C59797C55F979700002C002C00
000000000000000000000000000000000000000000000000000000000000000000002C00
000000000000000000000000000000000000000000000000002C00000000002C00000000
000000000000000000002C002C00000000002C000000002C000000002C00000000000000
002C0000000000000000000000000000002C000000002C00000000002C00000000002C00
00000000000000000000000000002C002C000000002C0000000000002C002C000000002C
000000002C002C2C2C000000002C000000002C2C2C002C00000000002C000000002C0000
00002C00000000000000000000002C00000000000000000000002C00000000002C000000
00000000000000000000000000002C000000A7A7A75F9797005F5F85858585858597C597
5F5F5F7373734949495F5F975F5F5F5F97977373737373735F9797005F5F005F5F005F5F
494949005F5F494949494949858585C597975F5F975F975F005F975F97975F975F2C2C2C
9797975F5F5F00490000005F5F5F5F2C2C2C5F5F5F737373737373005F5F97C597C5C5C5
D4D4D4A7A7A75F5F5F5F5F5F
5F97975F97C5A7A7A75F97C5A7A7A79797979797C55F97C55F9797A7A7A7A7A7A7A7A7A7
9797975F97975FC5C5A7A7A7A7A7A7A7A7A75F97C55F97C597C5C55F97C59797C597C5C5
97C5C55F97975F97975F97975FC5C55F5F97A7A7A7A7A7A7B6B6B6A7A7A7A7A7A75F9797
5F97975F97975F97975F9797979797A7A7A7A7A7A75F97C59797975F97975F97975F9797
5F97975F97975F97975F97975F97975F97975F97975F5F970097975F5F97009797005F5F
005F9700975F4949495F5F5F005F5F4949492C2C2C4949492C2C2C0049004900002C2C2C
2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C002C0000002C002C00004900002C002C2C2C
2C2C2C2C2C2C002C002C0000002C0000002C0000002C0000002C0000002C2C0000002C00
002C00002C00002C002C00002C2C2C2C0000002C002C0000002C000000002C0000000000
0000000000002C00002C000000002C002C0000002C002C00002C002C2C2C000000000000
00002C2C2C2CB6B6B6FFFFEFC5975F00002C002C00000000000000FF97000000002C0000
000000000000000000000000002C002C0000000000000000002C000000002C000000002C
002C0000000000002C00002C00000000002C00002C2C2C2C00002C002C0000000000002C
0000000000002C0000000000000000000000000000000000000000000000000000000000
002C00000000000000000000000000000000000000000000000000000000000000000000
000000002C00000000000000000000000000002C00002C00000000000000000000000000
00002C000000002C00000000000000002C000000000000000000002C0000000000000000
002C000000000000000000000000002C000000002C00000000002C000000000000002C00
0000000000000000002C00000000000000000000002C00002C2C2C002C0000002C2C0000
002C002C2C2C000000494949000000002C000000000000000000000000002C0000000000
00002C002C000000002C2C2C2C2C2C0000002C2C2C2C2C2C5FC5975F5F5F5F9797975F97
5F9797737373005F5F49494900975F5F5F5F5F979797979797C5978585857373735F5F5F
4949497373735F5F5F4949495F975F494949005F5F979797A7A7A7975F975F5F5F5F5F5F
5F975F5F5F5F2C2C2C5F5F5F2C2C2C0000004949495F5F5F2C2C2C2C2C2CA7A7A7979797
5F5F5FC5C5C55F97975F5F5F
5F97975F97975F97975F97975F97C5A7A7A7A7A7A75FC5C59797C5A7A7A7A7A7A7A7A7A7
979797A7A7A7A7A7A7979797A7A7A75FC5C55FC5C55FC5C55F97C5979797B6B6B65F9797
5F97975F97975F97975F97C5A7A7A7A7A7A797C5C597C5C55FC5C55F97975FC5975F9797
5F97975F97C55F97975F97975F97975F97C55F97975FC597A7A7A79797975F97C55F9797
5F97975F97975F97C55F97975F97975F97975F97C55F97975F97975F9797009797009797
009797005F9700975F737373005F97005F5F494949005F5F4900002C2C2C4949492C2C2C
2C2C2C004900002C000049002C2C2C002C00002C00002C002C2C2C00002C2C2C2C2C2C2C
2C2C2C002C00490000002C0049000000002C002C00002C002C00000000000000002C0000
002C00002C00000000002C00737373002C00002C00002C00002C00000000000000000000
00002C0000002C000000002C490000002C002C2C2C2C2C2C00002C2C2C2C2C2C2C00002C
002C00C5EFC5A7A7A7EFC597002C0000000000000000000000002CEF975F2C2C2C000000
002C002C00002C000000000000000000002C0000000000000000002C0000000000000000
000000000000000000000000000000002C0000002C00000000002C000000002C00000000
000000000000002C00000000000000000000000000000000000000000000000000000000
000000002C000000000000000000000000000000000000002C0000000000000000000000
000000000000000000002C00000000002C000000002C000000002C00000000002C00002C
002C0000002C00000000000000000000000000000000000000002C000000002C00000000
000000000000000000000000000000000000002C000000002C0000000000000000000000
000000002C0000000000002C00000000000000002C000000000000002C00000000002C00
002C002C2C2C002C00002C000000002C000000002C0000002C2C2C000000000000002C00
000000002C0000002C00000000002C002C000000002C00002C00005F5F5F5F97C55F9797
5F975F5F975F8585855F975F737373494949858585005F007373735F975F5F97975FC597
005F5F5F5F5F49494949494973737349494900005F8585855F5F5F005F5F97C5C5B6B6B6
B6B6B65F5F5F2C2C2C9797972C2C2C2C2C2C9797975F5F5F2C2C2C2C2C2C5F97975F5F00
490000B6B6B6B6B6B65F5F5F
5F97975F97C55F97C55F979797C5C597C5C597C5C55FC5C597C5C55FC5C597C5C59797C5
5F97C55FC5C55F97979797975F97C59797C597C5C55F97C55F97C55F97C55F97975F9797
0097975F979797C5C55FC5C597C5C5A7A7A75F97975F97C5A7A7A75F97C55F97975FC5C5
97979797C5975F97975F97975F97C55F97975FC5978585855F97975FC5C55FC5C5979797
5FC5C55F97C55FC5975F97975F97975F5F975F97975F5F975F97975F97C55F97975F9797
5F97975F97975F97975F97975F97975F97975F975F005F5F005F5F00005F2C2C2C002C00
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C0000
2C0000002C002C2C2C002C002C2C2C002C0000002C2C2C2C002C002C2C2C002C002C0000
2C0000002C0000002C0000002C0000002C002C2C2C000000002C002C2C2C2C2C2C2C0000
00000000002C002C00002C00002C002C2C2C002C00002C00002C00000000000000002C00
A7A7A7B6B6B6FFFFFF2C2C2C0000002C2C2C000000002C00002C00EFC5972C2C2C002C00
000000000000000000000000002C00000000002C0000002C002C00002C00000000002C00
000000002C000000000000002C2C2C000000000000000000000000000000000000000000
0000002C0000000000000000002C00000000002C00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000002C00000000000000
000000000000000000000000000000000000000000002C000000002C0000002C002C2C2C
00002C002C00000000000000000000000000002C00000000002C002C0000000000000000
00000000002C002C00000000000000002C00000000000000002C0000002C002C00000000
2C2C2C00000000002C002C00000000002C000000000000000000002C000000002C000000
00002C00002C000000000000002C0000002C002C000000000000000000002C2C2C000000
002C00000000000000000000000000000000002C00002C00002C00000000000000858585
5F9797A7A7A75F5F5F9797978585855F5F5F9797975F5F5F4949497373735F5F5F5FC597
8585855F97975F5F5F00975F7373735F5F5F2C2C2C97975F494949494949737373005F5F
5F975FA7A7A75F9797A7A7A75F5F005F5F5F9797975F5F002C2C2C0000495F975F2C2C2C
2C2C2C97975F979797494949
5FC5979797C55FC5C55F97C5A7A7A79797C5A7A7A797C5C55F97C5A7A7A797C5C597C597
A7A7A75F97975F9797A7A7A797C5C597C5C597C5C5A7A7A75F97C55F97975F9797009797
5F97975F9797A7A7A797C5C5A7A7A7979797A7A7A7A7A7A75F97975F97975F97975F9797
5F97970097975F97975F97975F97C5A7A7A7A7A7A75F9797A7A7A75F97975F97C55FC5C5
5F97979797975F97975F97975F97C55F97975F97975F97975F97979797975F97975F9797
5F97977373735F97C55F97975F97975F97975F9797005F5F00979700975F005F5F5F5F5F
005F5F494949002C00004900002C002C2C2C2C2C2C002C002C2C2C2C2C2C002C002C2C2C
2C2C2C2C2C2C002C002C0000002C000000002C2C2C2C0000490000002C0000002C002C00
0000002C00002C2C2C002C00002C002C00000000000000000000002C2C2C2C0000000000
2C0000002C002C00002C00002C0000002C002C2C2C2C0000002C00002C0000002C004900
97C5C5E1E1E1EFC5970000000000002C2C2C000000000000002C00C5975F002C0000002C
2C00002C00002C00000000002C000000000000002C0000002C0000000000000000000000
0000002C00000000002C0000002C00000000002C002C0000000000000000000000000000
000000002C0000000000000000000000000000000000000000002C000000000000000000
000000000000000000000000000000002C0000002C000000000000000000000000000000
000000000000000000000000002C002C00000000002C0000000000002C00000000000000
002C00000000002C000000002C2C2C0000000000000000002C0000002C00000000000000
000000002C00000000002C002C000000002C002C000000002C0000002C0000002C002C00
00002C000000002C0000000000000000000000002C0000002C2C2C2C0000002C00002C00
2C00000000002C00002C2C2C00002C2C0000002C0000000000002C000000000000000000
00000000002C0000002C00002C2C2C00002C0000002C2C2C0000002C2C2C0000002C0000
2C2C2C5F97975F5F5F005F5F5F97978585855F97975F9797005F005F97972C2C2C737373
9797975F5F5F9797979797978585855F5F5F49494997975F4949494949495F975F5F5F5F
5F5F5FB6B6B6979797A7A7A74949495F975F5F975F494949002C004949495F975F002C00
002C00A7A7A7737373005F5F
5F97975F97975F97975F97C5A7A7A7A7A7A75F9797A7A7A75F97975F97C55FC5C597C5C5
5F97C55F97C55F97C597C5C5B6B6B69797C597C5975F97970097975F97975F97975F9797
5F979797C5C597C5C55FC5C597C5C55F97975F97979797975F97975F97975F9797009797
0097975F97975F9797A7A7A75FC5C5A7A7A75F979797C5C5A7A7A75F97975F97975F9797
5F97975F97975F97979797975F979797C5975F97979797975F97C55F97C55F97975F9797
5F97975F97C55F97975F97975F97975F97975F97975F97975F97975F97970097975F5F5F
005F97005F5F5F5F5F4949492C2C2C4949492C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C
2C2C2C002C002C2C2C2C2C2C5F5F5F2C2C2C2C00002C2C2C00002C00002C2C0000002C00
002C00000000002C0000000000002C2C00002C0000002C00002C00000000000000000000
0000002C00002C00002C2C2C0000000000002C0000002C002C00002C2C2C002C00C5EFC5
C5C5C5FFEFC52C2C2C0000000000000000002C2C2C0000002C0000C5975F2C2C2C002C00
002C00000000002C000000000000000000002C0000002C0000000000002C002C00002C00
00002C002C002C000000002C002C0000000000000000000000002C000000000000000000
2C0000000000000000000000000000000000000000000000000000000000002C00000000
0000000000000000000000002C2C2C0000002C0000000000000000002C00002C00000000
2C2C2C0000002C00000000000000000000002C0000002C002C0000002C002C0000000000
0000000000002C00000000000000002C2C2C000000000000002C00000000000000002C00
0000002C00000000000000000000000000000000000000000000000000002C0000000000
002C002C2C2C00000000002C000000002C002C000000002C2C0000002C002C0000002C00
00002C2C0000002C0000002C0000002C000000002C0000002C00002C2C2C002C00000000
002C0000000000002C002C0000000000002C0000002C2C2C002C0000002C00000000002C
00002C0000004949495F97975F9797005F5F5F97979797977373735F97975F5F5F5F5F5F
8585852C2C2C73737300975FA7A7A75F975F5F5F5F97C5975F5F5F2C2C2C5F5F972C0000
4949495F9797494949005F5FA7A7A7979797A7A7A74949492C2C2C9797975F5F5F002C00
2C2C2CC5C5975F5F5F5F5F5F
5F5F5F8585855F97975F97C5979797A7A7A75F9797A7A7A75F97975F97C59797C55F97C5
97C5C597C5C5C5C5C597C5C597C5C597C5C5A7A7A75F97C55F97975F97975F97975F9797
A7A7A7A7A7A75FC5C59797975F97975F97975F97975F97C55F97975F97975FC5975F9797
5F97975F97C55F97979797979797C55FC5C55F97C5A7A7A7A7A7A75F97C55F97C55F9797
9797975F97975F97C55F97C58585859797979797975F97C55F97975F97975F97C55F97C5
5F97C55F97975F97975F97C55F5FC55F97C55F97975F97975F5F975F97975F5F975F9797
5F5F9700975F00975F0097975F5F5F494949005F5F2C2C2C002C00002C002C0000002C00
2C2C2C002C002C2C2C2C2C2C002C00002C002C2C2C2C2C2C002C002C0000002C00002C00
2C2C2C2C0000002C002C00002C0000002C00002C002C0000002C00002C000000002C0000
00002C2C2C2C2C2C2C0000000000002C2C2C00002C0000002C2C2C2C2C2C494949B6B6B6
FFFFFF4900002C2C2C2C2C2C0000000000002C2C2C002C00000000C5975F002C00002C00
00002C00000000002C0000002C2C2C000000000000002C00002C00000000000000000000
000000002C002C00002C0000002C002C00002C00000000000000002C0000C5C597002C00
000000000000002C00000000000000000000000000000000000000000000000000000000
000000002C000000002C2C2C000000000000000000000000000000000000000000000000
0000000000000000000000002C2C2C00000000002C000000002C0000002C000000000000
000000002C00000000002C000000000000002C2C2C00000000002C0000000000002C0000
000000002C002C000000000000000000000000000000000000002C000000000000000000
0000002C2C2C2C0000002C00002C002C000000002C2C000000002C002C00000000002C00
000000002C0000002C002C0000000000002C00002C00000000002C2C0000002C00000000
00002C000000002C0000000000002C0000002C0000002C000000002C2C2C002C0000002C
0000000000002C2C2C2C2C2C8585855F979797975F5F5F5F5F97977373735F975F494949
979797494949005F5F9797975F5F5F5F975F5F97979797975F5F5F4949495F9797002C00
4949495FC5974949495F5F5F97975F5F5F5F97979797C59797C5C5C5C5975F5F5F2C2C2C
002C00A7A7A75F5F5F5F5F5F
7373735F975F8585855F97C5A7A7A79797C5B6B6B6A7A7A75F97C59797C55F97C55F97C5
5F97C5B6B6B6B6B6B6B6B6B65F97975F97975F97975F97975F97975F97975F97970097C5
5FC5C59797975F97C55F97C50097C55F97C55F97C5A7A7A75F9797A7A7A75F97975F9797
5F97975FC5C5A7A7A75F97C55FC5C55F97C55F97C5A7A7A75F97C50097979797C55FC5C5
5FC5C597C5C55F97C5B6B6B697C5C59797C59797C5A7A7A7A7A7A75F97979797C55F97C5
5F97C59797975F5F975F97975F97975F97C55F97C55F97975F97C55F97C55F97975F9797
5F97975F97975F97975F979700975F005F5F005F5F005F5F2C2C2C005F5F2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C00002C5F975F002C0049000000002C002C002C0000002C002C0000
002C00000000000000002C00002C00002C000000000000002C2C2C2C000000000000002C
2C0000002C00002C002C00000000002C2C2C0000002C2C2C002C002C0000C5C5C5E1E1E1
975F002C2C2C002C0000000000000000002C2C000000000000000097975F2C00002C2C2C
002C00000000000000002C002C0000000000002C0000000000000000002C0000002C2C2C
00000000000000000000000000002C002C002C0000002C00000000002C00000000000000
00000000000000000000000000002C002C00000000002C00000000000000000000000000
000000000000002C00000000000000000000000000000000000000000000000000000000
000000002C00000000002C00000000000000002C00000000000000000000000000000000
00000000000000000000002C000000000000002C0000002C002C00002C00000000000000
00000000002C0000002C2C2C2C00000000000000000000000000002C0000002C00000000
0000002C00000000002C0000002C00002C0000002C002C0000000000000000002C000000
2C000000002C002C0000002C2C000000002C0000002C2C2C002C00000000000000002C00
0000000000000000000000000000002C00000000002C000000002C000000002C00000000
00000000000000002C2C0000002C002C2C2C5F97975F5F97005F5F5F97975F975F5F9797
8585855F5F5F494949979797005F5F9797975F975F9797975F9797858585858585494949
005F5F858585005F5F4949495F975F005F5F5F5F5FA7A7A75F5F5F5F5F5F9797975F5F5F
73737397C55F5F5F5F5F5F5F
5F5F5F5F5F5F7373735F979797C5C597C5C59797C59797C59797975F97C5A7A7A797C597
97C59797C5979797975F97975F97975FC5975F97975FC5975F97975F97975F97975F97C5
5F97979797979797975F97975F97975F97C55FC5C55F97975F97C55F97978585855F9797
5F9797A7A7A75F97975F97C55FC5C55F97975F97C55F97975F97975F97975F97C5A7A7A7
A7A7A7A7A7A75F97C597C5C597C5C5A7A7A75F97975F97C55F97C5A7A7A75F97C55FC5C5
5F9797A7A7A75F9797A7A7A7A7A7A7A7A7A75F97975F97978585855F97978585855F97C5
9797975F97975F97975F97975F97C50097975F5F97005F5F5F5F97005F5F005F5F494949
002C00002C002C2C2C002C00490000002C00000000002C000000000000002C00002C2C2C
002C00000000000000002C002C2C2C000000000000002C002C000000002C2C0000005F5F
002C00002C002C00000000000000002C00002C000000002C490000979797C5C5C5FFFFEF
2C2C2C2C2C2C2C2C2C0000002C0000000000000000000000000000005F5F00002C002C00
0000002C0000002C00000000002C00002C000000002C2C2C2C0000000000000000000000
000000000000002C00000000002C0000002C0000000000002C000000000000000000002C
0000000000002C2C2C000000000000000000002C0000000000002C000000000000000000
00002C000000000000000000000000000000002C00000000000000000000000000000000
000000000000000000000000000000000000000000000000002C00000000000000000000
000000002C0000000000000000000000000000002C002C0000000000002C000000000000
00000000000000002C000000000000002C0000000000000000000000000000000000002C
2C0000002C002C2C2C0000000000002C0000000000000000000000002C00000000000000
002C002C0000002C002C00000000002C000000000000000000002C00000000000000002C
00000000002C000000000000000000000000000000000000002C00000000000000000000
2C2C2C00002C00002C2C0000002C0000000000002C4949495F9797858585005F5F979797
5F5F5F5F979700730097C5977373735F5F5F7373735F5F5F97C5975FC597979797005F5F
49494997C5972C2C2C4949495F97972C2C2C4949498585855F5F5F4949499797975FC597
B6B6B697975F858585494949
4949495F5F5F858585858585B6B6B697C5C55F97C597C5C597C5C597C5C5A7A7A7A7A7A7
A7A7A797979797979797975F5F97975F975F73737397975F5F97975F9797979797858585
A7A7A7A7A7A75F97975FC5975FC597A7A7A797979797979797975F5F9797A7A7A79797C5
9797C55F97C55F97C55F9797A7A7A79797C55F97975F5F975F9797A7A7A75F97C597C5C5
5F97C597C5C59797C55FC5C55F97979797C55FC5C55F97975FC59797C5C55F97C55F97C5
A7A7A7A7A7A79797C55FC5C597C5C55F97975FC5C5A7A7A75F97C5A7A7A75F97C55F9797
5F97975F97C55F97C55F97C55F97975F9797005F975F97975F5F975F5F97005F975F5F97
005F5F4949492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C0000002C
002C000000002C0000002C00002C00002C002C00002C2C2C00000000002C0000002C0000
000000002C00002C00002C0000002C2C0000002C000000002C2C2CB6B6B6FFFFFF975F5F
2C2C2C002C002C2C2C2C0000000000002C002C2C2C2C2C2C00002C5F5F5F002C002C2C2C
002C00002C00000000000000000000002C002C2C2C2C000000002C000000002C00002C00
0000000000000000002C00000000002C00002C2C2C2C0000002C000000000000002C0000
000000000000000000000000000000000000000000000000002C00000000000000000000
00000000000000000000000000000000000000002C000000000000000000000000000000
0000000000002C00000000000000000000000000000000000000002C2C2C000000000000
00000000000000002C000000002C002C000000000000002C0000000000002C000000002C
000000000000000000000000002C00000000000000002C002C0000000000000000000000
0000002C2C2C0000000000002C0000002C00000000002C0000002C0000002C2C2C000000
000000000000000000002C0000002C0000000000002C000000002C000000000000000000
2C2C2C000000002C0000002C00000000000000002C49494900002C000000000000000000
0000002C0000002C00002C0000000000000000002C00002C2C2C2C5F5F5F5F97975F5F5F
0097975F5F5FA7A7A78585855F5F5F2C2C2C8585852C2C2C97C5975F5F5F5F975F5F9797
5F97975F97974949494949497373732C2C2C2C2C2CA7A7A75F5F5F002C0073737397975F
5F5F5F737373A7A7A75F5F5F
005F005F5F5FB6B6B65F979797C5C5A7A7A79797C59797C597C5EFB6B6B697C5C5A7A7A7
C5C597979797A7A7A78585855F975F5F975F5F975F5F975F5F975FA7A7A78585855FC597
A7A7A75F97975F97975F97975F97C55F97975FC59797C5975F97979797975F97C597C5C5
97C5C55FC5C55F97C55F97C55F97C55F97975F97C55F5F975F97C55F97C55F97C55F97C5
5F97979797C59797C597C5C5A7A7A75F97975F9797A7A7A75F97C55F97975FC5C55FC5C5
5F97C50097C5A7A7A75F97C55F97C55F97C5A7A7A79797979797979797975F97975F9797
5F97C59797975F97975F97975F97C59797975F97975F97975F97C55F97C55F97975F9797
00975F005F5F005F5F4949494949490049004900002C2C2C2C2C2C2C0000002C002C2C2C
2C2C2C0000002C2C2C002C00002C00002C002C00000000000000002C000000002C002C00
002C002C00000000002C000000002C000000002C002C2C2CC5C5C5C5C5EFFFEFC52C2C2C
002C000000002C000000002C2C00002C2C2C2C2C2C00000000002C5F005F002C00002C00
002C000000002C2C2C0000002C2C2C2C00000000002C0000002C00002C002C000000002C
2C00002C2C2C2C000000002C2C000000002C000000000000000000002C00000000002C00
002C00000000002C00000000002C000000000000002C0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000002C0000000000000000002C00000000000000000000002C000000000000000000
2C000000000000000000000000000000000000000000000000000000002C00002C000000
000000000000002C0000000000000000002C002C0000000000000000002C2C0000000000
000000000000002C0000000000000000000000000000002C00000000000000000000002C
0000000000000000002C00000000002C2C2C000000000000000000000000000000002C00
000000002C002C0000002C002C000000002C2C000000002C000000002C002C2C2C5FC597
5F9797005F5F5F97975F5F5F5FC5975F5F5F7373734949497373735F97975F0000A7A7A7
8585859797975F975F5F5F5F9797972C2C2C49494997C5975F5F5F2C2C2C5F9797737373
0049002C0000A7A7A7494949
A7A7A7005F5F5F5F5F5F5F5F97979797C5C597C5C5C5C5EFC5C5EF97C5C597C5C597C5C5
A7A7A7A7A7A797975F7373738585855F97977373738585855F97977373735F975FA7A7A7
5F97979797C55F97C59797975F97C55F979797979797C5979797975FC5C55F97C5A7A7A7
A7A7A75F97975F97975F97979797975F97C55F97C55FC5C55F97C5A7A7A7A7A7A797C5C5
5FC5C55FC5C55F9797A7A7A75F97975F97C597C5C597C5C55F97975FC5C55F97C55F97C5
9797975F97975F97C55F9797A7A7A797979797C5C55F97C5A7A7A75F97C597C5C5979797
9797C55F97C55F97C59797975F97C55F97C55F97C55F97C55F97975F97975F97970097C5
5F97975F5F5F5F9797494949005F5F4949494949494949492C2C2C002C002C00002C2C2C
2C2C2C002C002C2C2C002C00002C002C2C2C2C00002C00000000004900002C2C2C2C2C2C
2C00000000000000002C00002C2C2C002C00000000B6B6B6C5C5C5FFFFEF00002C002C00
002C002C2C2C2C2C2C000000490000002C0000002C0000002C000000002C002C00000000
2C2C2C002C00002C0000002C0000002C00002C0000002C004949490000000000002C0000
00002C000000000000002C000000000000000000000000002C00000000000000002C2C2C
00000000002C0000000000000000000000000000000000000000002C00002C0000000000
002C002C0000000000002C0000002C000000002C00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000002C
000000000000000000000000000000000000000000000000000000000000000000000000
002C00000000000000000000000000000000000000000000000000000000000000002C00
00000000000000000000000000002C2C0000000000002C00000000000000002C00000000
00000000002C2C0000000000002C00002C00000000000000000000002C0000002C000000
2C000000002C2C000000000000000000000000000000002C002C0000002C002C00002C00
000000000000002C0000002C002C0000002C2C00000000002C000000002C002C00000000
2C2C2C5F97975F975F5F5F5F494949B6B6B697C5C55F5F5F5F5F5F5F97974949495FC5C5
5F5F5F49494997C597A7A7A7A7A7A7005F5F00002C9797975F5F5F002C00975F97C5975F
5F975F002C004949495F5F5F
5F5F5F7373738585859797C597C5EFB6B6B697C5EFB6B6B697C5C5D4D4D4979797A7A7A7
A7A7A7B6B6B69797975F975F7373735F975F5F975F8585857373735F97975F97975F9797
97C5C5B6B6B68585858585855F97979797978585855F97975F97979797975F97975F97C5
979797A7A7A75F97C5A7A7A7A7A7A7C5C5EF5FC5C597C5C597C5C5A7A7A75F97C597C5C5
9797975F97C55F97C55FC5C59797975F9797A7A7A75F97975F97979797975F97C55F9797
5F97C55F97975F97C55F9797A7A7A75F97C55FC5C5A7A7A75F97975F9797A7A7A75F9797
9797C55F97975F97975F97979797975F97C55F97C59797975F97C55F97C55F97C55F97C5
5F5F975F97C55F5F977373735F5F5F5F5F5F4949494949492C2C2C2C2C2C2C2C2C2C2C2C
2C00002C2C2C49000000002C002C002C2C2C00002C002C00002C0000002C002C00002C00
2C2C2C490000000000002C00002C00002C0049494997C5EFFFFFFFC5975F2C2C2C002C00
2C00000000002C2C2C00002C002C000000000000002C0000002C002C2C2C002C00002C00
000000000000002C002C2C2C00000000002C002C00002C00002C00002C002C000000002C
2C0000002C00002C00002C0000000000002C002C00000000000000000000002C002C0000
000000000000002C000000000000000000000000002C2C2C2C00000000000000002C2C2C
000000002C00000000000000002C00000000000000000000000000000000002C00000000
00000000002C000000000000000000002C00000000000000000000000000000000000000
000000002C00000000002C00000000000000002C00000000000000000000000000000000
00000000000000000000000000000000000000000000002C0000000000000000002C0000
00002C0000002C0000002C0000000000000000002C000000002C000000002C0000000000
00002C00000000000000002C00000000002C0000000000002C00002C0000002C00000000
000000000000002C0000002C000000002C0000002C002C0000000000000000000000002C
000000000000000000002C0000002C002C0000000000000000002C2C0000002C002C2C2C
2C2C2C2C2C2C4949495F97C55F5F975FC5974949495FC597A7A7A75FC597005F5F737373
73737300490097C5C55F5F5FA7A7A77373730000499797975F975F002C0049494997C597
5F5F5F2C2C2C000049494949
8585859797975F979797C5C5B6B6B697C5C597C5C597C5C5B6B6B6A7A7A78585855F9797
8585858585857373737373735F5F5F5F975F737373A7A7A79797977373735F9797B6B6B6
9797C55F97978585855F97978585855F97975F97979797978585855F97975F97975F9797
9797977373735FC5C59797C55F97C55FC5C59797C5A7A7A797C5C55F97C5A7A7A7979797
5F97C55F97975F97979797975F97970097C55F97C55F97979797975F97C55F97C55F9797
5F97975F97C50097C55F9797979797A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A75F97C5
5FC5C55F97C55F97C5979797979797A7A7A7A7A7A75F97C55F97C5A7A7A75F97C55F97C5
5F97C55F97975F97C50097975F97975F97975F97975F5F5F005F5F2C2C2C002C002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C4900002C2C2C2C2C2C00002C2C2C2C4900000000002C0000
000000002C002C0000002C002C0000002C00C5C5C5EFFFEFFFEFC52C2C2C2C2C2C002C00
0000002C00002C00002C000000002C2C00002C00002C00002C00002C2C2C00002C002C00
00002C0000002C2C2C0000002C2C2C000000002C0000002C2C2C2C00000000002C00002C
0000002C00002C000000000000002C002C00002C0000000000002C0000000000002C0000
0000000000002C0000000000000000002C002C000000000000002C000000000000002C00
0000000000000000000000000000000000000000000000002C2C2C000000000000000000
000000000000000000000000000000000000000000000000000000000000000000002C00
00000000000000000000002C0000000000002C0000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000002C0000000000
000000000000002C0000000000000000002C002C000000000000002C2C2C0000002C0000
002C002C0000000000002C000000002C0000002C002C000000000000000000002C000000
2C2C2C0000002C2C2C0000000000000000000000000000000000002C2C2C002C00000000
002C000000002C2C2C0000000000000000000000002C0000002C00002C000000005F9797
2C2C2C002C002C2C2C2C2C2C9797975F979700975F737373005F5FA7A7A7494949858585
5F5F972C2C2C97C5C55F975F2C2C2C5F97975F97979797975F97972C2C2C5F5F5FA7A7A7
5F975F00002C2C2C2C005F5F
858585A7A7A7975F5F858585C5C5C5979797A7A7A797C5978585855F975F5F97975F975F
8585857373735F5F5F5F979700975F5F97975F97975F9797A7A7A75F5F977373735F9797
B6B6B65F975F7373738585855F5F5F7373735F975F5F97975F97977373735F97975F975F
979797009797009797A7A7A75F97975F97978585855F975F97C5C597C5EF97C5C55F97C5
A7A7A75F97979797975F97975F97975F97975F5F975F9797009797979797A7A7A75F9797
9797C59797C55F97C5A7A7A75F97C5A7A7A79797C55F9797979797A7A7A79797975F97C5
5F97979797975FC5C597C5C597C5C597C5C5A7A7A75FC5C55F97C55FC5C50097975F97C5
A7A7A75F97C55F97975F97975F97975F97975F97975F5F975F975F5F5F975F5F5F494949
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00002C002C00002C0000
2C0000002C00002C002C00002C0000005F97B6B6B6FFFFC52C2C2C0000002C000000002C
0000002C2C2C2C2C2C002C00002C0000002C00002C002C00002C00002C00002C00002C00
0000000000002C000000002C00002C2C000000002C00002C000000002C000000002C0000
002C002C00000000000000002C000000000000002C000000002C000000002C2C2C002C00
0000002C2C2C002C00002C00000000000000000000000000000000000000000000000000
0000002C0000002C00002C00000000002C00000000000000000000000000000000000000
00000000000000000000000000000000000000002C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
002C00000000000000000000000000000000000000000000002C0000000000002C000000
00002C00000000000000000000000000000000002C00000000000000000000000000002C
00000000002C2C0000002C0000002C000000002C0000002C002C00000000000000000000
000000002C00000000000000002C002C2C2C00002C000000002C00000000002C0000002C
2C00000000000000002C2C2C2C2C2C002C00002C00002C0000000000000000002C00002C
0000000000005F5F9797979700002C5F5F5F5F97975F979797C5C55F5F5FB6B6B6000049
5FC5974949495F5F5F8585852C2C2C9797975F9797737373A7A7A75F975F858585B6B6B6
5F5F5F2C2C2C002C00494949
979797B6B6B6C5C5C5A7A7A79797979797979797978585855F97977373735F97975F9797
5F975F73737373737373737397C5C57373735F97975F5F9797979797C5C5A7A7A797C5C5
97C5C58585855F97977373735F5F5F7373739797975F97975F5F975F97975F975F5F975F
5F97975F97975F97979797975F9797A7A7A7A7A7A75F97975F97C55F97975FC5C5A7A7A7
5F9797B6B6B65F97975F97C59797975F975F5F979797C5C5A7A7A79797975F979797C5C5
5F97C55F97C55F97975F9797A7A7A75F97C55F97C5A7A7A75F9797A7A7A75FC5C55FC5C5
97C5C55F97C5A7A7A75F97C55F97C55FC5C55F97C597C5C5A7A7A75F97C55F97C5A7A7A7
A7A7A75F97975F97978585855F97C55F97975F97975F97C55F97975F97975F9797005F5F
005F5F5F5F5F2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C002C004900002C2C2C2C2C2C
002C000000000000004900002C2C2C97C5C5FFFFFF975F5F2C2C2C002C002C00002C2C2C
2C2C2C2C2C2C00002C2C2C2C2C00002C2C2C2C0000490000002C0000000000000000002C
00002C2C000000002C00002C2C2C2C002C000000000000002C0000002C00002C002C0000
002C002C000000002C002C00000000002C00000000002C002C0000000000000000000000
0000000000002C0000000000000000000000000000000000002C00002C002C2C2C2C0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000002C000000002C00000000000000000000000000000000000000000000000000
000000002C00000000000000000000000000000000000000000000000000000000000000
0000000000002C000000002C000000000000000000000000002C00000000000000002C00
000000002C0000000000002C2C000000002C2C000000000000000000002C000000000000
0000002C2C2C00000000002C000000002C000000002C000000000000000000002C00002C
002C00000000002C002C00000000000000002C2C2C002C00002C0000002C000000000000
00000000000000002C000000002C0000002C002C004949495F97975F5F97005F97005F5F
4949495FC5975F5F5F5F975F2C2C2C005F975F975F5F5F5F005F5F97975FA7A7A7A7A7A7
9797975F975F2C00005F5F5F
858585A7A7A7979797A7A7A7B6B6B697975F5F5F5F4949497373735F5F5F858585858585
5F979797C5C55FC5C597C5C55F97978585855F97975F97975F5F5F5F9797A7A7A7979797
5F97978585855F5F5F5F975F5F5F5F5F5F5F97975F5F979700975F8585858585855F975F
97975F8585855F97977373739797979797975F97975F97C55F5F97A7A7A7C5C5C5A7A7A7
5F97C5C5C5C5A7A7A75F97C55F5F5F5F97975F97975F9797B6B6B65F97C59797C5A7A7A7
5F97C55F97975FC5C597C5C55F97C55FC5C59797975FC597A7A7A797C5C55F9797A7A7A7
5F97C5A7A7A79797975F97C55FC5C5A7A7A797C5C55F97C55F97C55FC5C5A7A7A7979797
A7A7A75FC5C55FC5C55F97975F97975F97975F97975F97975F5F975F97975F97975F5F97
005F97005F5F005F5F005F5F2C2C2C2C2C2C2C2C2C4949494900002C2C2C2C2C2C00002C
2C2C2C2C2C2C2C2C2C002C00C5C5C597C5EFFFEFC52C2C2C0000000000002C2C2C002C00
2C2C2C002C0000002C2C2C2C00002C2C2C2C002C00002C0000002C00002C2C00002C2C2C
000000002C002C00002C0000002C0000000000002C00000000002C00002C00002C000000
2C2C2C000000000000002C0000002C000000002C00000000000000000000000000000000
002C0000002C000000000000000000002C00000000000000000000000000000000000000
00002C000000002C00000000000000000000000000000000002C00000000000000000000
00002C00000000000000000000000000000000000000000000002C000000000000000000
000000000000000000000000000000000000000000000000000000000000000000002C00
000000000000000000002C00000000000000000000000000000000000000000000000000
000000000000000000000000000000002C0000000000000000000000000000000000002C
00000000000000002C000000000000002C000000002C2C2C000000000000000000002C00
002C0000000000002C0000002C0000002C000000000000002C2C2C00002C0000002C2C2C
2C2C2C00000000000000000000002C000000000000002C0073737373737300002C2C0000
0000002C00002C000000002C002C0000002C2C0000002C00002C004949490097975F9797
494949979797979797A7A7A75F5F5F0049007373735F975F2C2C2C97C5C55F5F5F494949
979797737373005F5F5F5F5F
A7A7A7979797A7A7A7C597975F975F4949494949495F5F5F5F9797858585A7A7A797C5C5
C5C5C5A7A7A797C5C597C5C5A7A7A75F97977373735F97978585855F5F5F5F5F5F737373
8585855F975F494949005F5F5F975F5F975F97975F0097975F97978585855F975F5F975F
7373735F975F8585855F9797A7A7A79797975F97C5858585858585A7A7A797C5C5B6B6B6
8585858585857373735F97978585855F97975F97975F97975F97975F979797C5C5009797
5F97C5858585A7A7A7A7A7A75FC5C55F97C5A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7
5FC5C55FC5C59797C55FC5C597C5C55FC5C5A7A7A75FC5C55F97975F97C5A7A7A7A7A7A7
A7A7A797C5C5858585A7A7A75F97C55F97979797975F97975F97975F97975F97975F9797
5F97975F5F5F5F5F5F5F5F5F005F5F2C2C2C0049002C2C2C002C004900002C2C2C2C2C2C
2C2C2C002C00002C00005F5FC5C5C5FCFCFC2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C002C0000002C979797000000490000002C00002C00000000000000000000000000
2C2C2C00002C2C2C2C002C002C2C2C002C0000002C002C002C000000002C2C2C2C000000
002C002C00000000002C0000002C00002C002C2C2C0000000000000000002C2C2C000000
002C00000000000000000000002C00000000000000000000000000000000000000002C00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000002C00000000000000000000000000
0000000000002C2C2C000000000000000000000000000000000000000000000000000000
00002C000000000000000000000000000000000000000000000000000000000000000000
000000000000002C002C000000002C000000000000000000000000000000000000002C00
00002C0000002C0000002C0000002C0000000000002C2C2C2C00002C000000002C00002C
2C000000002C000000000000002C002C2C2C00002C2C0000000000002C0000002C00002C
2C2C2C2C000000002C00000000000000002C2C000000002C000000002C002C000000002C
00002C000000002C002C2C2C002C0000002C000000002C000000000000002C2C2C5F9797
5F97977373735F5F5F494949A7A7A7494949975F977373732C2C2C5F5F975F5F5F494949
494949C5C5975F97975F5F5F
85858573737397975F97975F5F5F5F737373005F5F5F5F5F5F97975F979797C5C5B6B6B6
97C5C5A7A7A7975F5F737373A7A7A7A7A7A78585855F5F5F5F5F5F5F975F5F97005F5F5F
5F5F005F5F5F005F5F5F975F97975F5F97005F5F5F5F975F97975F5F975F5F5F5F737373
7373735F975F5F975F5F5F5F5F5F5F5F975F5F9797C5C5C597C5C5A7A7A75F97C5975F97
5FC5979797979797975F5F5FA7A7A7A7A7A75F97975F9797A7A7A797C5C55F97979797C5
9797975FC5975F97C59797C55FC5C59797C597C5C55F97975FC59797C5979797975F9797
5F97C55F97979797979797975F97C55F9797A7A7A79797979797975FC5C597C597A7A7A7
97C5C55FC5C597C5C5A7A7A75F97979797979797975F97975F97975F97975F97975F9797
5F97975F97977373735F5F5F5F5F5F005F5F4949490000492C2C2C2C2C2C2C2C2C2C2C2C
002C002C2C2C004900C5EFC5E1E1E1C5975F0000002C2C2C2C2C2C00000000002C2C2C2C
002C00000000002C002C2C2C2C2C2C2C2C2C00002C2C2C2C002C002C00000000002C0000
2C0000002C002C2C2C2C00002C0000002C00002C0097975F2C2C2C2C0000000000002C00
00000000002C00000000002C002C00002C00000000000000000000002C00002C00000000
2C2C2C000000000000000000000000000000000000000000000000002C002C0000000000
002C00000000002C0000002C000000000000002C00002C00000000000000000000000000
000000000000000000002C0000000000000000002C000000000000000000000000000000
002C00000000000000000000002C00000000000000000000000000000000000000000000
000000002C00000000000000000000000000000000000000000000002C0000000000002C
00000000000000000000000000000000002C000000002C000000000000002C0000000000
002C0000002C002C00000000000000000000002C0000000000002C000000002C00000000
2C0000000000000000000000000000002C0000000000000000002C2C000000002C000000
2C00000000002C2C2C2C00002C0000002C0000002C00000000000000002C000000000000
00002C2C00002C2C2C002C00002C00000000000000002C0000000000002C00002C002C00
005F5F5F97975F97C5005F5F5F5F5F00975F97C5C597C5C52C2C2C4949495F5F5F2C2C2C
002C009797C5C5C597005F5F
97975F5F5F5F9797005F5F5F5F975F5F975F005F5F0097975F97C5A7A7A79797C5B6B6B6
B6B6B69797975F97978585859797975F5F5F97975F5F5F5F5F5F5F5F5F5F5F5F5F5F975F
5F5F5F5F5F5F5F5F005F975F5F5F5F5F975F5F5F5F7373738585857373735F5F5F858585
5F975F5F975F5F975F005F5F7373735F97975F9797A7A7A75F9797A7A7A7A7A7A7A7A7A7
9797975F9797979797979797A7A7A79797979797975F9797A7A7A7A7A7A75FC5C55F9797
5FC5975F97975F97C55F9797A7A7A7A7A7A75F97C55FC5C55F97C55F97C5A7A7A7A7A7A7
5F9797A7A7A75F9797A7A7A75F979797C59797979797C5C5A7A7A797C5C5A7A7A7A7A7A7
B6B6B6B6B6B6A7A7A797C5C5A7A7A75F97975F979797C597979797A7A7A79797975F9797
5F97975F97975F9797737373737373005F5F00975F005F5F4949492C2C2C2C2C2C2C2C2C
002C002C2C2CC5EFEFD4D4D4FFFFEF2C2C2C002C0000002C2C2C2C2C2C2C2C2C2C002C00
002C0049000000002C2C2C2C002C0000002C002C002C2C2C002C002C000000002C00002C
00002C0000002C2C2C002C002C00000000002C00000000002C000000002C000000000000
2C00002C00002C00002C0000002C002C0000002C00002C0000000000002C00000000002C
0000000000002C0000002C002C0000000000000000000000000000000000002C00000000
00000000000000002C002C00002C0000000000000000000000002C000000000000000000
000000000000002C00000000000000002C00000000002C00000000000000000000000000
000000000000000000000000000000000000000000002C00000000000000000000000000
000000000000000000000000000000000000002C00000000000000000000000000000000
000000002C0000000000000000002C00000000000000002C000000000000002C00000000
00000000000000000000000000000000002C0000000000000000002C0000000000000000
0000002C0000002C002C2C2C000000000000000000000000002C00000000002C00000000
002C0000000000000000000000000000002C2C000000002C00002C00002C000000000000
2C0000000000002C00000000002C0000002C0000002C2C2C0000000000000000002C2C2C
2C2C2C2C2C2C5F5F5F5F97C5002C005F97975F5F5FA7A7A75F5F5F4949495F975F005F00
4900007373735F97975F5F5F
975F0097975F5F5F5F975F5F5F975F975F5F8585855F97979797C5A7A7A7C5C5C5B6B6B6
7373737373735F97977373739797979797974949495F5F5F005F5F5F5F5F5F5F5F5F5F5F
005F5F4949495F5F005F975F5F5F5F5F5F5F5F975F5F5F5F7373735F975F5F975F5F5F5F
5F975F5F975F5F5F5F73737397975F5F97C55F97975F975F5F9797A7A7A75F97C55F9797
A7A7A75F97C597979797C5C5858585A7A7A7979797A7A7A7979797A7A7A75F97975F97C5
A7A7A75F97C597C5C597C5C597C5C597C5C55FC5C59797975F9797A7A7A7A7A7A7009797
5F97975F97979797975F97975F9797979797A7A7A75F97975F97975FC5C55F97C5B6B6B6
5F97975F9797A7A7A797C5C55F97975F9797979797A7A7A75F97C5979797979797858585
5F97975F97975F5F97005F975F97C55F9797005F975F5F5F5F5F5F5F5F5F2C2C2C2C2C2C
2C2C2C494949C5C5C5EFEFEF5F5F5F2C2C2C002C002C2C2C002C002C2C2C00002C2C0000
002C002C2C2C002C0000002C002C002C000000002C49000000002C002C00002C0000002C
00002C002C00002C002C2C2C0000000000002C00002C2C2C002C00002C000000002C2C2C
0000002C2C2C0000002C0000000000002C0000002C0000002C0000000000000000002C00
000000002C000000002C0000000000000000000000002C00000000000000000000000000
000000000000002C0000002C000000000000000000002C002C0000000000002C00000000
00000000000000000000000000000000000000000000000097975F000000000000000000
00000000000000000000000000000000000000002C00000000000000002C002C002C0000
00000000000000000000002C000000000000000000000000000000000000000000000000
0000000000002C0000002C000000002C0000002C000000002C2C2C2C00000000002C2C2C
2C00000000002C0000000000002C002C0000000000002C0000000000000000002C2C2C2C
00000000002C002C00002C00000000002C00000000002C002C0000002C00000000000000
00000000000000000000000000002C2C0000002C0000002C002C002C2C2C000000000000
00000000002C000000002C0000000000002C00002C002C0000002C0000000000002C2C2C
0000002C000000002C2C2C2C5F5F975F5F97005F5F2C2C2CA7A7A797C5C5979797737373
2C2C2C005F5F9797975F5F5F
97975F975F5F9797978585855F9797A7A7A79797C5A7A7A7A7A7A7B6B6B6858585A7A7A7
5F97975F97979797975F97975F97977373735F975F5F5F5F5F5F5F005F5F5F5F5F5F975F
5F5F5F5F5F5F4949495F5F0097975F5F5F5F975F5F5F5F5F5F975F5F975F737373737373
5F975F7373735F975F97975F9797975F97978585855F979797C5C55F97C597C5C5858585
A7A7A75F97975F9797A7A7A75F97975F5F97979797979797979797979797A7A7A7A7A7A7
A7A7A7B6B6B697C5C5A7A7A7B6B6B69797C55F9797A7A7A79797975F97975F97C55F9797
97C5979797975FC5C55FC5C5858585A7A7A7A7A7A7979797A7A7A75F97975F97C55F9797
5F97979797975F97975F97975F97C55FC5C5979797A7A7A79797975F97975F97975F9797
5F97975F97975F97975F97975F97975F97970097975F97977373737373735F5F5F494949
2C2C2CE1E1E1FFEFEFC5C5972C2C2C2C2C2C2C0000490000490000002C002C2C2C00002C
000000002C00002C00002C00000000000000000000000000002C00002C002C2C2C000000
2C0000002C00002C000000002C0000002C000000002C2C2C002C00002C00002C002C0000
2C0000000000000000000000002C00000000000000002C00000000002C002C0000000000
000000000000000000002C000000000000000000002C00000000002C2C2C000000002C00
2C2C2C0000002C000000000000002C002C00000000000000000000000000000000000000
000000002C00000000002C00000000000000000000000000494949000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000002C00000000000000000000000000
000000000000002C002C0000000000002C0000000000002C00002C2C0000002C002C0000
002C00000000000000000000000000000000002C002C000000000000000000000000002C
2C2C2C002C000000002C2C2C00002C000000002C000000000000002C00002C0000002C00
00002C00000000002C2C2C2C002C0000000000002C0000002C2C2C00000000000000002C
000000000000002C00002C00000000000000000000002C00002C0000002C0000002C2C2C
0000000000002C00002C000000002C5F5F5F5F97974949494949495FC5975F5F5FB6B6B6
5F975F005F5FA7A7A75F5F5F
975F0097975F979797979797B6B6B6C5C5C5A7A7A7A7A7A7C59797975F005F975F5F975F
7373739797979797979797979797975F975F5F975F5F5F5F5F5F5F5F5F5F005F5F737373
5F5F5F5F975F5F5F005F5F5F5F975F5F5F5F5F975F5F975F5F975F5F975F5F975F5F975F
5F975F8585855F5F5F737373737373A7A7A79797975F9797A7A7A75FC5C5979797979797
A7A7A75F97975F97975F979797975F5F97975F97975F979797979785858597C5C5979797
5F97C55F9797B6B6B6A7A7A75FC5C55FC5C55FC5C597C5C5A7A7A7A7A7A75F9797A7A7A7
5F97C55F9797A7A7A75F97979797975F97975F97975F9797979797A7A7A79797975FC5C5
5F97979797979797975F97975FC5979797975F97975FC5C55F97975F97978585855F97C5
5F97975F97975F97C55F97975F97975F5F975F97975F5F977373735F5F5F5F5F5F005F5F
97C5C5C5C5EFFFEFC52C2C2C002C00002C002C2C2C002C00002C004900005F5F972C0000
2C00000000002C2C2C002C002C2C2C0000000000002C000000002C2C0000002C00000000
2C0000002C002C00002C000000002C00002C2C2C2C002C00000000002C0000002C000000
2C0000002C002C0000000000002C002C000000000000000000002C2C0000000000002C00
0000000000002C2C2C000000002C000000002C0000000000000000000000002C00000000
002C00000000000000002C002C0000000000002C00000000000000002C0000002C000000
000000000000002C0000002C000000000000000000000000494949000000000000000000
00000000000000002C00000000000000000000000000000000000000002C000000000000
000000000000000000000000000000000000002C00000000000000000000000000000000
000000000000000000002C002C000000002C00000000000000002C2C0000000000494949
0000002C2C2C000000000000002C002C000000002C000000000000000000000000002C00
000000000000002C000000002C000000002C00002C2C000000000000002C002C0000002C
000000000000000000000000000000002C000000000000005F5F5F00002C00002C2C0000
002C00002C000000002C000000000000002C0000000000002C2C2C000000002C00000000
002C0000000000002C00002C00002C00002C002C00494949005F5F5FC5C55F5F5F005F5F
97C597B6B6B64949495F5F5F
B6B6B6C5975F979797C5C5C5B6B6B6EFC5EFB6B6B6A7A7A7975F5F975F5F5F5F5F5F5F5F
737373A7A7A79797975F97975F975F5F975F5F5F5F5F975F5F5F5F5F5F5F4949495F5F5F
4949495F5F5F5F5F005F5F005F975F5F975F5F975F5F975F5F975F5F975F7373735F975F
7373735F975F5F975F7373737373735F5F5F5F975F5F97975F9797B6B6B6A7A7A7A7A7A7
9797975F97975F97975FC5C57373735F97977373735FC5C58585859797975F97C597C5C5
A7A7A797C597A7A7A75FC5C55F97C55F97C5A7A7A79797C55F97C5A7A7A75F97975F9797
97C5C55F97979797975F97979797975F9797A7A7A75F97975F97979797975F97C55F97C5
5F97975F97978585855F97975F9797A7A7A75F97975F97975F97975F97975F97975FC597
5F97979797975F97975F97975F97975F97975F97975F97975F97975F97975F5F5F737373
B6B6B6FFEFC55F5F5F2C2C2C2C0000002C00002C0000002C2C2C2C2C2C2C00002C2C2C2C
00002C4900002C0000002C002C2C2C0000002C000049000000002C2C00002C2C2C00002C
00002C00000000002C2C00002C00002C2C2C2C2C2C00002C000000002C002C00002C0000
2C0000002C00002C002C00000000002C0000000000002C0000000000002C0000002C0000
00002C002C002C0000000000000000000000002C00000000002C0000000000002C000000
00002C2C0000002C00000000000000000000000000000000000000000000002C00000000
0000002C0000000000000000000000000000000000000000494949000000000000000000
000000000000000000000000002C00000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000002C000000000000000000000000
0000000000000000000000004900002C0000000000002C00000000000000002C00494949
00000000002C000000000000000000000000000000002C00000000000000002C0000002C
0000000000000000002C0000002C00002C00002C0000002C00002C000000000000000000
00000000000000002C002C000000000000002C00002C00002C0000002C0000002C2C0000
002C0000002C2C2C2C00002C0000002C00000000002C2C2C0000002C000000002C000000
00002C0000002C000000002C000000002C00002C002C2C2C2C2C2C7373735F9797004900
975F975F5F5F002C005F5F5F
A7A7A7A7A7A7C597C5B6B6B6C5C5C5B6B6B6A7A7A797C5C55F975F975F00975F5F5F5F00
858585A7A7A75F975F5F5F5F005F5F5F5F5F5F5F5F5F5F0049494900975F5F5F5F5F5F5F
4949495F5F5F5F975F5F5F5F5F5F5F5F975F4949495F975F97975F737373975F5F5F975F
5F975F7373738585855F975F7373735F97977373735F97975F97975F97C597C5C597C5C5
5F97975F97975F97978585857373739797975F97977373735F97978585855F9797858585
5F97979797975F97975F97975FC5C597C5C597C5C55FC5C55F97979797975F97C5A7A7A7
5F97975F97975F97975F97C55F97975F97975F97975F97C55F97975F97C55F97975F9797
5F97C55F97975F97975F97975F97975F97C55F97975F97975F97975F97C55F9797737373
5F97975F97975F97975F97975F97979797975F97C59797979797975F97975F975FC5C5EF
E1E1E1E1E1E15F975F005F5F4949492C2C2C002C002C2C2C2C2C2C002C002C2C2C002C00
4900002C0000002C002C2C2C002C002C000000002C0000002C00002C000000002C2C0000
002C000000002C00002C0000002C000000000000002C0000002C002C0000000000000000
2C000000002C002C00002C0000002C0000000000000000002C2C2C0000002C2C2C2C0000
0000002C2C2C002C00000000002C002C2C2C00000000000000000000002C002C0000002C
002C00000000002C00000000000000000000002C00000000000000000000000000002C00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000002C00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000002C00000000000000002C000000000000000000002C2C2C000000000000
0000002C0000002C00000000000000002C0000002C0000000000002C2C2C2C0000000000
2C00000000002C2C2C0000002C2C2C2C2C2C002C0000002C000000000000000000000000
2C00002C0000002C00002C002C0000002C0000002C000049000000000000002C0000002C
00002C000000000000002C00002C0000002C00000000002C000000000000000000000000
0000000000000000000000002C0000002C002C00002C2C2C2C2C2C2C2C2C005F5F5F9797
00002C5F97C55F5F5F005F5F
C5C5C5C5C5C5C5C5C5C5C5C5B6B6B69797975F5F5F4949495F5F00494949975F00737373
97C597A7A7A78585855F975F5F5F5F005F5F73737300975F005F005F5F5F005F5F5F975F
005F5F5F5F5F7373735F5F5F5F5F00005F005F5F5F5F5F5F5F5F5F5F975F5F975F5F975F
975F5F5F5F5F7373735F5F5F5F975F5F5F5F5F975F00979797C5C55F9797979797A7A7A7
5F9797A7A7A75F97975F97975F5F975F97975F975F8585859797977373735F9797979797
5F97979797978585855F97C55F97C55F97C5A7A7A75F97975F97C5A7A7A75FC5C55F9797
5F97975F97975F97975F97975F97975F97975F97C55F97975F97975F97975F97975F9797
5F97975F97C55F97975F97975F5F975F5F5F5F97975F97975F5F975F97975F97975F9797
5F97975F97975F97979797975FC5C55F97C55F97C5A7A7A7A7A7A7A7A7A75F97C597C5C5
EFEFC55F5F97005F97005F5F005F5F005F5F2C2C2C4900002C2C2C2C2C2C002C00002C00
00002C4900002C000000002C002C00000000490000002C00002C00002C00002C002C0000
2C000000002C002C00002C002C0000002C0000002C002C002C2C2C002C0000002C000000
2C00002C2C2C2C0000002C00000000002C0000002C002C002C0000002C002C0000000000
2C000000000000002C00000000000000000000002C000000000000002C00000000002C00
000000002C000000002C000000002C0000000000002C2C2C00000000000000002C000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000002C2C2C00000000000000000000000000002C
000000000000000000000000000000000000000000000000000000000000000000000000
2C0000002C0000000000000000002C000000000000002C00000000000000000000000000
2C0000002C000000002C000000002C000000000000002C00002C0000000000002C002C00
00002C0000000000000000002C00000000002C2C2C00000000002C00002C002C00002C00
002C00000000002C00000000002C00002C0000002C5F5F5F000000000000002C002C0000
002C00002C0000002C2C0000002C0000002C002C00000000000000000000000000002C00
002C002C00000000002C00000000002C0000002C002C2C2C002C002C2C2C000000002C00
5F5F5F7373735F9797494949
97C5C5B6B6B6C5C5C5B6B6B6A7A7A7C5C5C5C5975F975F5F494949975F5F5F5F5F5F975F
97979797979797975F5F5F005F975F4949495F5F5F5F5F00494949002C002C2C2C5F5F5F
5F5F5F5F975F5F5F5F5F5F5F5F5F5F5F5F005F975F5F5F005F5F5F5F5F5F5F975F5F975F
5F975F7373737373735F975F5F975F5F975F5F9797737373B6B6B65F97975F97975F5F97
8585855F97978585855F9797737373A7A7A78585855F97C55F975F979797A7A7A75F9797
8585855F97975F97975F97975F979797C5C55FC5C5A7A7A75F9797A7A7A75F97975F9797
5F97979797975F97977373735F97977373735F5F5FA7A7A78585855F97975F97975F9797
005F975F97975F97970097975F97975F97975F975F5F97975F97975F97975F97975F9797
5F97975F97C55F97975F97975F97C55F97C55F97C597979797979797C5C5C5C5EFE1E1E1
5F97975F5F975F97975F979700975F00975F005F5F2C2C2C2C2C2C2C2C2C2C2C2C00002C
2C2C2C002C002C2C2C2C2C2C002C002C2C2C002C00002C002C2C2C002C000000002C0000
2C2C2C0000002C0000002C00002C00000000002C00002C00002C002C000000000000002C
000000002C00002C002C0000000000002C00000000000000000000002C002C2C2C2C0000
0000002C2C2C002C00000000002C002C0000000000002C00000000000000000000000000
00000000000000002C0000002C0000002C00000000002C0000000000002C000000000000
000000002C0000000000000000000000000000000000000000000000002C000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00002C002C00000000000000002C00000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000002C00000000000000002C002C00
0000000000009797972C2C2C002C00002C0000000000000000002C2C00000000002C0000
0000000000000000002C0000002C00002C000000000000002C2C2C2C2C2C2C2C2C002C00
2C2C2C002C00002C00000000002C002C2C2C002C00002C000000002C0000000000000000
0000002C000000000000002C00002C00002C000000002C0000002C002C0000002C2C0000
002C0000002C002C00000000000000002C0000000000000000002C000000000000000000
2C2C2C2C2C2C858585494949
97C5C597C5C5C5C5EFD4D4D4A7A7A7B6B6B6B6B6B65F005F975F00975F0097975F979797
A7A7A797975F5F5F0097975F4949495F97005F5F5F5F975F4949494949494949495F5F5F
5F5F5F5F5F5F0073005F5F5F005F5F5F5F5F5F5F00005F5F5F975F5F5F5F5F5F5F975F5F
5F975F5F975F5F975F5F975F5F5F5F5F5F5F5F5F5F5F97975F5F975F97C5A7A7A75F97C5
5F97975F97975F97975F97C5979797A7A7A75F97975F97975F97975F97975F9797979797
9797975F97975F97975FC5C55FC5C55F97C55F97977373735F97975F97C55F97C55F9797
5F97977373735F97975F9797009797005F975F5F977373735F97975F5F97005F975F97C5
5F97975F979700975F00975F5F5F5F5F9797005F5F0097970097975F97970097975F9797
5F97975F97975F9797A7A7A75F97C597C5C5A7A7A797C59797C5C5C5EFFFC5C5EFEFEFC5
5F97C59797975F97975F97975F97975F97975F9797005F5F4949490049002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C002C004900002C2C2C002C002C2C2C2C2C2C002C000000002C2C2C
002C00002C002C0000002C002C2C2C2C2C2C002C000000002C2C2C002C00002C002C0000
2C2C2C002C00002C0000002C000000000000000000000000000000000000000000002C00
00002C002C0000002C0000002C2C2C2C0000002C00000000000000000000002C00002C00
0000002C2C2C000000002C0000000000002C00002C00000000002C000000000000002C00
002C0000000000002C0000002C00000000000000000000002C2C2C000000000000000000
00000000000000000000002C000000002C0000000000000000000000002C000000000000
00000000000000002C00000000000000000000000000000000000000000000002C000000
000000000000000000000000002C0000000000002C000000000000002C00000000000000
000000002C00C597970000000000002C000000002C49494900002C002C0000002C002C00
00002C002C000000002C00002C0000002C000000002C00002C2C2C000000002C00000000
00000000002C002C00002C0000000000002C002C0000000000002C00002C000000000000
0000002C000000002C00002C0000000000002C000000000000002C000000002C00000000
2C00002C2C2C00000000002C002C0000000000002C0000002C2C2C0000000000002C0000
2C2C2C2C2C2C000000005F5F
9797C597C5C5C597C59797C5979797EF975F975F5FC597975F5F5F975F007300005F5F5F
5F975F5F5F5F73737397975F97975F5F5F005F975F5F5F5F4949495F5F002C2C2C5F5F00
2C2C2C494949005F00494949005F5F494949005F004949490073004949495F5F5F5F975F
5F5F5F5F975F5F975F5F5F5F005F5F5F5F5F5F5F5F005F5F5F97979797C597C5C5A7A7A7
5F97979797975F5F975F5FC585858597C597858585A7A7A78585855F5F975F9797A7A7A7
A7A7A79797979797C5A7A7A78585855F97975F97C5979797A7A7A75F97C55F97975F9797
00979700975F5F9797009797005F5F005F5F005F5F5F5F975F5F5F005F5F005F5F5F5F5F
5F97977373735F5F975F97975F5F5F5F979700975F5F9797005F975F97975F5F97009797
5F97975FC5975F9797979797A7A7A79797C597C5C5A7A7A75F97C5C5C5EFFFFFEF97C5C5
5F97979797975F97975F97975F97C55F97C55F97975F975F5F975F005F5F005F5F494949
002C004900002C2C2C4900002C2C2C002C00002C00490000002C004900002C00002C0000
2C00002C00002C00002C00002C2C2C002C002C2C2C00002C2C00000000002C000000002C
00002C002C002C2C2C2C00002C00000000000000002C00002C00002C2C2C00002C2C0000
0000000000000000002C2C2C000000002C00000000000000000000002C00000000002C00
0000000000002C2C2C0000002C2C2C000000000000002C00000000000000002C0000002C
000000000000000000002C00000000000000002C00000000000000000000000000002C00
000000000000000000000000000000000000000000000000002C00000000002C0000002C
000000000000002C00000000000000000000000000000000000000000000000000002C00
00000000002C000000000000000000002C002C0000002C000000002C0000000000002C00
00000000002C00000000000000002C00000000002C002C00000000002C00000000002C00
00000000000000000000002C00002C0000002C00000000002C2C2C2C2C2C2C2C2C00002C
2C0000002C002C2C2C0000000000002C2C2C0000002C2C2C2C0000002C00002C002C0000
2C2C2C002C002C2C2C002C00002C002C2C2C00002C2C2C2C002C00000000000000000000
00002C2C00000000002C00002C00000000002C2C2C000000002C00000000000000002C00
00000000002C00002C494949
D4D4D497C5C597C5C5B6B6B6B6B6B6C5975FEF975F975F00975F5F97975F7373735F5F00
97975F975F5F5F5F5F97975F5F5F5F9797005F5F005F5F5F5F5F5F005F5F005F5F5F5F00
005F5F0049004949495F5F5F005F5F5F5F5F5F5F004949495F5F005F975F5F5F5F5F975F
4949495F5F5F005F5F5F5F5F5F5F5F5F5F5F5F5F5F7373735F9797A7A7A75F97C55F97C5
5F97C55F97C55F97975F97975F9797975F9797C5C59797975F97977373735F5F5F5F975F
9797975F9797A7A7A7A7A7A75F9797979797A7A7A79797975F97C55F9797005F5F5F9797
5F9797005F5F005F9700975F5F5F5F005F5F00975F5F5F5F5F5F5F00975F005F5F5F5F5F
5F5F5F5F5F97858585005F5F5F5F5F5F5F5F5F5F97005F5F5F975F5F97975F9797009797
00975F5F97975F97975F97979797C5A7A7A79797975F9797EFFFEFFFEFEFA7A7A7979797
5F97C59797C55F97C55F97975F97975F97975F5F975F9797009797005F97005F5F005F00
490000002C00002C002C2C2C002C00002C002C2C2C2C000049000000002C2C000000002C
002C00002C002C2C2C002C00002C002C2C2C000000002C000000004900002C0000000000
2C00002C2C2C002C00490000002C000000000000000000002C00000000002C0000002C00
2C0000000000002C00002C00000000002C002C2C2C2C000000000000002C000000000000
00002C002C000000000000002C000000002C0000002C0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000002C00000000
002C0000000000000000000000000000000000000000000000000000000000002C002C00
0000002C0000000000004900494949000000000000000000000000000000002C00000000
00000000000000000000000000000000000000002C0000000000000000000000002C0000
00000000000000002C2C2C2C002C0000002C2C00000000002C00000000002C000000002C
000000002C000000002C000000002C00002C002C00002C002C000000002C2C000000002C
2C2C2C2C2C2C002C002C2C2C0000002C2C2C000000002C0000005F7373732C2C2C002C00
2C00000000000000000000002C0000002C00000000002C0000002C0000000000002C2C2C
2C2C2C00002C00002C002C0000002C000000000000002C002C0000000000002C00000000
000000002C0000002C494949
C5C5C597C5C597C5C5B6B6B69797C5975F5FC5975FC5975FC5975FC5C597979797975F5F
975F5F975F5F5F5F00975F5F858585975F5F5F5F005F5F5F5F5F004949495F5F5F005F5F
5F005F2C2C2C494949494949005F5F494949494949494949494949494949005F5F5F5F5F
4949495F5F5F5F5F5F5F5F5F5F5F5F00975F5F975F5F975F5F5F5F5F5F5F9797C55F97C5
979797A7A7A75F5F975F9797975F975F9797A7A7A75F97975F5F5F7373735F97975F9797
5F97975F97975F9797A7A7A75F97979797C5A7A7A75F5F975F5F975F9797009797005F97
737373005F97005F5F009797009797005F975F5F977373735F975F5F5F975F5F975F5F97
5F5F975F97975F5F5F005F5F005F975F9797005F5F5F975F7373737373735F975F005F97
5F97975F97C55FC5979797975F97C55F97979797C5EFEFEFC5C5C5C5979797C5C55FC5C5
A7A7A79797975F97975F97C55F97C55F97975F97975F97975F97970097975F97975F5F97
5F5F5F2C2C2C2C2C2C2C2C2C002C002C2C2C00002C2C0000002C00002C0000002C2C2C2C
000000002C0000002C002C00002C002C2C2C2C2C2C49000000002C00002C0000002C2C2C
2C2C2C2C2C2C002C002C0000002C002C000000002C0000002C2C2C002C00002C002C0000
2C0000002C002C2C2C00002C0000002C0000002C002C00002C000000000000002C000000
00002C00002C000000002C0000002C002C002C0000000000002C00002C00000000000000
00002C00000000002C0000000000000000000000002C2C2C000000002C0000002C000000
000000000000002C000000000000002C000000002C000000002C0000002C000000000000
2C000000002C00000000000000000000002C000000002C00000000000000000000000000
002C0000000000000000002C00000000000000000000002C000000000000000000002C00
00002C2C2C2C0000002C2C2C00000000000000000000002C000000002C0000002C00002C
2C2C2C2C000000002C2C2C2C00000000002C00002C0000000000000000000000002C0000
002C000000002C000000002C0000002C2C2C2C2C2C00000000000000000000002C2C2C2C
00002C00002C002C002C00002C2C2C2C0000002C002C00000000000000002C0000002C00
002C0000000000002C2C00000000000000000000002C000000002C000000002C00000000
00000000002C002C00005F5F
B6B6B69797C597C5C597C5C55F9797979797C55F5FEF5F00C55F5FC5C597A7A7A7C5975F
97975F975F5F5F5F005F5F5F4949495F5F5F5F5F00975F5F5F5F5F8585857373735F5F5F
5F5F5F005F00005F5F005F5F494949494949005F5F5F5F5F5F975F2C2C2C5F5F5F005F5F
5F5F5F5F5F5F5F5F004949494949495F975F5F5F5F5F5F977373735F97975F97975F9797
97C5C55F97C55F97975F5F975F97979797C5A7A7A79797975F5F975F97975F975F737373
7373735F97975F9797A7A7A75F97C59797978585857373737373735F5F977373735F5F5F
005F5F5F5F5F4949495F975F5F975F5F975F7373735F975F5F5F5F5F5F5F5F97975F9797
0097975F97975F9797005F5F5F5F5F5F975F5F9797005F5F005F5F5F5F5F009797737373
5F97975F97975F97975FC5C55F97C55F97C59797C5C5C5EFFFFFEF9797C597C5C5979797
9797C55F97C59797975F97975F97978585855F97975F97975F97975F5F975F9797009797
005F5F005F5F005F5F2C2C2C002C002C2C2C2C2C2C2C2C2C490000002C002C0000002C00
0000000000002C0000000000000000002C002C2C2C0000002C00000000000000002C2C2C
002C00002C00002C00002C0000002C0000002C0000002C00000000002C00000000000000
00002C002C002C000000002C00002C2C0000002C00002C00002C00002C00000000000000
002C0000000000000000000000000000000000000000002C2C0000000000000000000000
002C000000000000002C000000002C002C000000000000002C00000000002C0000002C00
002C00000000000000002C00000000000000000000002C002C2C2C002C000000002C0000
00002C2C0000000000000000000000000000002C00000000002C00000000000000000000
0000000000000000002C000000002C0000002C000000000000000000000000002C000000
2C000000002C000000000000005F5F2C2C2C2C2C2C00002C0000000000002C0000002C00
00002C00002C00002C2C2C2C0000002C00002C2C2C0000000000002C00002C0000002C00
000000002C00002C0000002C0000002C2C2C2C2C2C0000000000002C2C2C002C0000002C
00002C00002C002C002C2C2C000000002C0000002C00002C002C00002C00000000000000
00002C2C000000000000002C002C00002C00002C000000000000000000002C0000000000
002C0000000000002C494949
B6B6B697C5C55F97C5C5C5EF5F97975F5F5F975F00EF975FEF975FC5C5C5EFC5C5C5C597
975F5F97975F97975F4949495F5F5F5F5F5F5F5F005F5F5F4949495F5F5F97975F737373
005F5F5F5F00494949494949005F5F4949494949494949495F5F5F5F5F5F494949494949
5F5F5F5F5F5F005F5F0073004949495F5F5F7373735F5F5F5F97975F97975F97C5B6B6B6
97C5C58585855F97979797C55F97975F9797A7A7A75F97975F97977373730097C55F9797
5F97975F97975F975F5F97975F975F5F5F5F7373737373735F5F5F5F5F5F5F5F5F737373
5F975F5F5F5F5F5F5F7373735F975F5F975F5F975F5F5F5F5F5F5F5F5F5F737373737373
97975F5F5F5F5F975F5F975F5F5F5F00975F5F97977373737373737373735F975F5F9797
5F97C55F97C55F97C55F97C5A7A7A75F97C5C5EFEFFCFCFCA7A7A79797C55F97C5B6B6B6
A7A7A7A7A7A7A7A7A75F9797A7A7A75F97C55F97975F97975F97C55F97975F97975F9797
005F975F97975F5F5F005F5F2C2C2C2C2C2C00002C4900002C2C2C2C2C2C002C00002C00
2C00002C000000002C2C2C2C2C0000002C00002C002C2C2C00002C00002C2C0000002C00
00002C002C002C2C2C000000490000002C002C0000002C000000002C2C2C2C000000002C
000000000000002C002C2C2C00000000000000002C00002C002C0000002C0000002C2C2C
2C000000000000002C00000000000000002C0000002C000000000000000000002C002C00
00002C002C00000000000000002C0000000000000000002C000000000000000000000000
000000000000000000002C0000000000000000000000002C5F5F5F000000000000000000
000000000000002C0000000000000000000000002C00000000000000000000000000002C
000000000000002C002C000000000000002C002C00000000002C000000002C000000002C
000000000000002C0000000000000000002C00002C002C000000002C00002C2C2C002C00
002C00002C002C00000000002C2C2C00000000002C000000000000002C00002C00000000
2C2C2C2C2C2C2C000000002C000000002C0000002C000000002C0000002C000000000000
2C000000002C00000000002C00002C002C002C2C2C2C00002C0000002C000000002C0000
00002C00002C2C000000002C002C000000002C000000000000002C002C0000000000002C
0000002C0000000000005F5F
C5C5EFA7A7A797C5C597C5C50097975F5F5F494949C5975FEF975FEF975FEFC597FFC5C5
C5C597975F5F975F5F8585855F5F5F5F5F5F5F5F004949495F5F5F5F5F5F5F5F5F5F5F5F
5F5F5F49494900975F4949492C2C2C5F5F5F0000495F5F005F975F5F5F5F5F5F5F005F5F
00975F4949495F5F5F005F5F5F5F5F005F5F4949495F5F5F5F5F5F97C5C55F9797979797
97C5C59797979797979797C55F97C5A7A7A78585855F97975F97975F97975F97C5858585
8585855F97975F97979797978585859797975F975F5F5F5F5F975F5F975F5F975F5F5F5F
5F5F5F5F975F7373735F975F5F5F5F4949495F975F5F975F5F5F5F5F5F5F5F5F5F5F975F
9797005F5F5F7373735F97975F975F5F5F5F7373739797975F97975F97975F97975F5F5F
8585855F97975F97975F97C55F979797C5C5C5C5EFC5C5C597C5C597C5C597C5C5A7A7A7
9797C59797C59797C5A7A7A75F97C55F97975FC5C59797975F97979797C55F97975F9797
5F5F975F5F97005F975F5F5F4949492C2C2C2C2C2C002C002C2C2C2C2C2C490000002C00
2C2C2C2C2C2C002C0049000000002C2C0000002C002C2C2C2C00000000000000002C2C2C
2C000000002C0000002C0000002C0000002C002C00002C002C2C2C2C2C2C2C00002C0000
00002C002C002C2C2C00000000000000000000002C000000002C00002C00000000002C00
000000002C000000002C0000000000002C00002C000000000000002C2C2C0000002C2C2C
2C00000000000000000000000000000000000000004949492C2C2C2C000000000000002C
000000002C000000000000000000000000002C2C2C000000000000000000002C00000000
00000000002C000000000000002C0000002C0000002C2C2C000000000000000000000000
00002C002C000000000000000000000000000000002C00000000000000000000002C0000
002C0000000000002C2C00002C2C2C00000000002C2C000000002C00002C000000000000
002C00002C00002C00000000002C002C2C2C002C00000000002C002C0000002C0000002C
000000000000002C002C2C2C00000000000000002C2C0000002C0000002C00002C000000
0000000000000000000000000000002C2C2C00000000002C00002C002C002C2C2C002C00
2C000000000000002C0000000000002C0000000000000000000000002C00000000000000
000000002C00000000494949
B6B6B6A7A7A79797C5979797737373005F5F4949495F5F5FEF9797B6B6B6C5C597EFC5C5
EFC597C5975F97975F97975F7373735F5F5F5F5F5F5F5F5F5F5F5F5F5F005F5F5F005F5F
5F975F4949495F5F5F5F5F5F4949495F5F5F5F5F004949494949495F5F5F4949495F5F5F
5F5F00005F5F5F5F5F5F5F5F5F5F5F4949495F975F5F5F5F7373735F97C55F979797C5C5
B6B6B6A7A7A797C5C597C5C5A7A7A7A7A7A75F97C55F97C55F97975F5F975F97975F97C5
5F97C573737397975FA7A7A75F5F5F975F005F975F97975F5F5F5F975F5F5F5F5F5F975F
5F5F5F5F975F73737397975F5F975F5F975F5F975F5F975F5F5F5F5F5F5F005F5F737373
73737373737373737397979797C5978585855F975F5F5F5FA7A7A797C597737373737373
5FC5C55F97C55F97975F97975F9797E1E1E1FFFFEF97C5C55F97C55F97C5B6B6B697C5C5
5F97C55F97C5A7A7A7A7A7A75FC5C55FC5C55F97979797975F97975F97975F97C55F9797
5F97975F97C5005F977373735F975F5F5F5F4949492C2C2C2C2C2C2C2C2C2C2C2C002C00
2C2C2C2C2C2C002C00002C002C2C2C2C2C2C2C2C2C2C2C2C490000002C00002C002C0000
00002C002C002C2C2C00000000002C00000000002C000000490000002C0000002C002C00
000000002C002C2C2C2C2C2C4949492C0000000000000000002C002C2C2C00002C002C00
00000000000000000000002C0000000000002C2C2C2C000000002C0000002C2C2C000000
000000002C00000000000000002C00000000000000000000000000000000000000002C00
000000000000002C0000000000002C00000000002C00000000002C0000002C0000002C00
00002C0000000000002C000000002C00000000002C000000000000000000000000000000
000000000000000000002C00000000002C0000000000002C002C0000000000002C002C00
002C00002C00002C00002C000000002C0000002C000000000000000000000000002C0000
002C0000002C2C2C2C002C000000002C2C2C002C00000000002C0000002C000000000000
2C00002C0000002C002C2C2C00000000000000002C00002C002C00002C002C2C2C00002C
0000000000000000002C00002C2C2C002C0000002C0000002C2C2C2C2C2C000000000000
0000000000002C0000002C002C0000002C0000000000000000000000002C0000002C2C2C
000000002C00000000005F5F
5F979700979797C5C5005F97005F97005F5F5F97975F5F5FB6B6B6EFC5C5B6B6B6C5C597
C5C59797975F97975F97975F975F5F975F5F5F5F5F5F5F5F5F5F5F5F5F5F2C2C2C494949
5F975F5F5F5F494949494949494949494949005F5F5F5F5F5F5F5F5F5F5F5F975F5F975F
4949495F975F4949495F975F5F5F5F5F975F5F5F004949495F5F5F005F5F5F5F975F9797
97C5EF97C5C55F97C55F97C55F97C5A7A7A75F97975F97C55F97C55F9797A7A7A75F9797
9797C55F97977373735F975F4949495F975F97975F5F975F5F975F7373735F5F5F5F5F5F
5F975F5F970073737397975F97975F975F5F7373735F975F5F5F5F5FC5C59797975F9797
858585858585979797A7A7A78585857373735F975F97975F5F975F5F97975F975F5F5F97
9797979797977373735F9797FFFFEFC5EFEF5F97979797C55FC5C597C5C55F97C5979797
5F97C55FC5C55FC5C59797C5A7A7A797C5C5A7A7A7A7A7A7009797A7A7A75F9797A7A7A7
5F97975F97975F97977373735F97975F5F5F4949495F5F5F4900002C2C2C4900002C2C2C
2C2C2C002C0000002C002C002C2C2C002C002C2C2C002C00002C0000002C00002C000000
2C00000000000000000000002C00000000002C0000000000002C00002C002C0000002C00
2C0000002C00002C002C0000002C00002C00000000000000002C002C0000000000002C00
2C000000002C000000000000000000000000000000002C00002C00000000000000000000
00002C2C000000000000002C00000000002C002C00000000000000002C002C0000000000
00002C000000000000000000000000000000000000000000000000002C0000002C000000
2C00002C00000000000000000000000000000000000000002C2C2C000000000000000000
002C000000000000002C00002C00000000000000002C000000000000002C002C00000000
000000000000002C0000002C00000000002C2C000000002C2C00002C2C2C000000000000
00000000002C002C002C00002C2C2C002C0000002C0000000000000000000000002C2C2C
002C000000002C0000002C00002C002C00000000002C00002C2C2C000000000000000000
002C002C000000002C00000000002C00002C002C0000002C00002C00002C002C00000000
2C0000002C00002C000000002C2C2C2C2C2C002C00002C00002C000000002C000000002C
00000000002C000000494949
5F97975F9797A7A7A7005F5F005F5F5F975F5F97975F97C5A7A7A7C5C5C5C5979797975F
97975FEFC597C5975F97979797975F5F5F5F2C2C2C975F5F5F5F5F5F5F00494949494949
5F5F5F5F975F5F5F5F5F5F5F4949495F5F5F5F5F005F5F005F5F5F5F5F5F5F5F5F5F5F5F
5F5F5F2C2C2C5F5F5F5F5F004949495F5F5F5F975F005F5F5F5F5F5F5F5F5F97C5A7A7A7
5FC5975F97C55FC5C5A7A7A7A7A7A7A7A7A7979797858585A7A7A75F97C59797C597C5C5
737373005F5F5F975F5F975F5F975F5F975F8585855F5F5F494949975F5F5F5F5F858585
7373735F975F7373735F975F97975F5F975F5F975F85858597975FA7A7A75F9797858585
9797978585855F975F5F975F5F975F8585858585859797975F9797A7A7A797975F97975F
979797737373494949A7A7A7C5C5EFFFFFC55F97975FC5C55F97C55F97C597979797C5C5
A7A7A75F97C55F97C55F97C5A7A7A75F97C5A7A7A7979797A7A7A7A7A7A75F97C5A7A7A7
5F97975F97975F97C55F97975F97975F97975F5F97005F5F005F5F2C2C2C2C2C2C2C2C2C
2C2C2C002C002C00002C2C2C002C00002C0000002C00000000002C00000000000000002C
002C00002C002C0000002C00002C002C2C2C002C00000000002C00000000002C00002C00
2C2C2C2C00002C2C2C002C0000002C2C2C2C00002C0000002C0000000000002C002C2C2C
000000002C000000002C2C2C000000002C000000002C00000000000000002C2C2C2C2C2C
00000000000000000000000000000000000000000000002C0000000000002C2C2C000000
00000000000000002C002C0000002C0000000000000000000000000000000000002C0000
000000000000000000000000000000000000000000002C00000000002C00000000002C00
2C000000002C000000000000002C0000002C00000000002C00000000002C00000000002C
0000000000000000002C2C2C000000002C00002C0000000000000000002C002C002C0000
00000000002C000000002C002C2C2C00002C2C0000002C002C000000002C000000000000
00000000000000002C2C0000002C0000002C00000000002C002C00002C00002C00000000
2C000000002C00002C2C0000002C0000002C0000002C000000002C2C2C2C000000000000
002C000000002C2C2C2C000000002C0000000000002C2C2C002C0000002C000000000000
000000002C00000000494949
5F97C55F97975F97975F5F97005F975F97975F97975FC597A7A7A7A7A7A7B6B6B6C59797
C55F5FC5C597EF975FC5975F97975F4949495F5F5F2C000097975F975F5F2C2C2C494949
5F5F5F4949495F975F5F5F5F5F5F5F2C2C2C0073004949495F975F5F5F5F005F5F5F5F5F
5F975F5F5F005F5F005F5F5F5F5F005F5F004949495F5F5F5F5F00005F004949499797C5
5F97C55F97C5A7A7A7A7A7A75FC597A7A7A79797975F97C55FC5C5A7A7A79797975F5F5F
5F5F5F7373735F5F5F5F979797C5C5A7A7A79797975F975F5F5F0000975F5F5F5F5F9797
8585855F97979797979797979797978585855F5F5F5F975FA7A7A75F97975F97975F9797
5F97978585859797975F975F5F975F5F97975F975F5F9797979797A7A7A785858597975F
5F97005F5F005F5F5FEFEFEFFFFFEF5FC5C5A7A7A7A7A7A79797C5A7A7A7A7A7A7A7A7A7
97C5C55FC5C55F97C55F9797A7A7A7A7A7A7A7A7A7A7A7A75F97C55F97C5979797A7A7A7
9797975F97975F97C55F97975F97975F9797009797005F97737373005F5F4949492C2C2C
002C00002C002C0000002C00002C00002C00002C002C2C2C2C0000000000490000002C00
2C00002C0000002C00002C00002C002C2C2C2C2C2C0000000000002C0000002C00002C00
2C000000000000002C000000002C0000002C2C2C2C002C002C000000002C002C00002C00
0000002C000000002C0000000000002C2C2C00000000002C002C00000000000000000000
00002C0000000000002C0000000000000000002C000000002C2C2C0000005F97972C2C2C
00000000002C00000000002C00000000000000000000000000000000000000002C000000
2C000000000000000000002C2C0000000000000000000000002C002C000000002C000000
002C00000000002C0000000000000000002C2C00000000002C00000000000000002C0000
002C0000002C0000002C2C2C00002C0000002C2C2C2C000000002C2C0000002C00000000
00000000002C002C000000002C000000000000002C000000002C00000000002C00002C00
00002C00000000000000002C00002C2C00002C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C
00002C2C000000002C00002C2C000000002C002C0000000000002C0000002C0000000000
000000000000002C0000002C000000002C0000002C00000000000000002C002C00000000
00002C2C2C2C2C0000005F5F
C5C5C597C5C5B6B6B65F97970097975F97975F979797C5C597C5C5A7A7A7C59797C5975F
97975FC5975FEFC597C5C59797975F5F5F5F975F5F4949495F5F5F5F5F5F494949005F00
2C2C2C2C2C2C5F5F00494949494949005F5F5F5F00005F5F5F5F004949495F5F5F5F5F5F
5F975F5F5F5F5F5F009797005F5F5F5F5F5F5F5F5F0049005F5F5F494949005F97737373
5F9797A7A7A7A7A7A797C5C59797C55F97979797975F97979797975F9797A7A7A797975F
00975F5F975F7373735F9797979797979797A7A7A79797975F5F5F5F5F5F5F97975F97C5
8585858585855F9797979797737373A7A7A79797975F97C59797975F97975F97975F9797
737373858585975F5F97975F5F975F8585855F5F5F5F975F8585858585859797975F975F
5F975F5F5F5FFFFFFFC5EFEFC5C597A7A7A797C5C597C5C5A7A7A7A7A7A797C5C59797C5
97C5C55F97C55F97C55F9797A7A7A75FC5975F97975F97C55F97975F97C5A7A7A7A7A7A7
979797A7A7A75FC5970097C55F97975F97975F97978585855F97975F5F5F005F5F494949
002C00002C00002C002C2C2C2C2C2C2C2C2C000000002C0000002C2C2C2C00002C2C2C2C
002C002C2C2C2C00004900000000002C000000002C0000002C000000002C2C00002C0000
2C000000000000002C0000000000002C2C2C000000002C002C2C2C2C000000002C2C2C2C
002C0000002C002C00002C000000002C00000000002C0000000000000000000000000000
002C00000000002C0000002C00002C0000005F5F5F2C2C2C000000002C00000000000000
000000000000000000002C0000002C0000002C0000000000002C00000000000000000000
00002C000000000000000000000000002C0000000000000000000000002C000000002C00
000000002C0000002C000000000000002C0000000000002C0000000000002C0000000000
002C002C0000002C002C2C2C00002C00002C2C00002C2C2C2C000000002C002C00000000
2C00002C2C2C2C2C2C002C0000002C0000000000002C00002C2C2C000000000000002C00
000000002C0000000000002C0000000000000000000000002C2C2C002C002C00002C2C2C
2C2C2C2C0000002C0000002C000000000000000000000000002C00002C0000002C00002C
000000002C0000000000002C002C00002C002C0000000000002C0000002C0000002C2C2C
000000000000000000494949
C5C5C5C5C5C5B6B6B697C5C55F97C55F97C597C5C59797C5A7A7A797C597979797C5C597
C5975FC5975FC5975FC59797C5975F97975FA7A7A7975F5F494949975F5F975F5F5F5F00
005F004949495F5F005F5F005F5F00494949005F000049005F5F5F5F5F005F5F5F737373
5F5F5F5F97005F5F004949495F975F5F975F494949494949494949494949737373737373
A7A7A7A7A7A785858597C5C597C5C5A7A7A797C5C57373735F97975F9797A7A7A75F5F5F
7373735F975F5F9797A7A7A79797979797975F9797A7A7A75F5F5F979797A7A7A797C597
5FC597979797A7A7A797C5975F97978585855F97975F975F979797979797858585979797
A7A7A77373738585855F5F5F5F975F5F975F97975F5F975F5F5F5F7373735F975F5F5F5F
5F5F00C5EFEFB6B6B6FFFFEF5F5F5FA7A7A79797975F97979797C597C5EFB6B6B6C5C5C5
A7A7A797C5C597C5C5A7A7A7979797A7A7A7A7A7A79797979797975F97975F97C5979797
A7A7A7A7A7A7A7A7A75F97975F97C55F97975F97975F97975F97975F979700975F005F5F
005F5F0049002C2C2C2C2C2C002C00002C002C0000002C002C2C2C002C0000002C2C2C2C
2C2C2C2C2C2C2C000000002C002C002C2C2C002C00002C00002C002C2C2C00002C00002C
00002C2C000000002C2C000000002C002C00002C002C2C2C0000002C000000000000002C
00002C002C00002C0000002C000000002C0000002C002C00000000002C0000002C000000
00000000000000002C000000002C00000000000000002C000000002C00002C0000000000
00002C00000000000000002C002C00000000000000000000000000000000002C00000000
0000000000002C0000002C0000000000000000002C000000000000000000002C0000002C
00000000000000000000002C000000000000002C00002C00000000002C000000002C0000
2C0000002C00002C00002C00000000000000002C002C2C2C000000000000002C00000000
00002C002C000000000000002C000000000000000000002C002C0000000000002C000000
00002C2C2C2C002C000000002C2C2C0000002C000000000000002C002C00002C0000002C
00000000000000000000002C0000002C2C2C0000002C000000000000002C002C0000002C
2C2C2C000000000000000000000000000000002C00000000000000000000002C00000000
000000000000000000005F5F
C5C5C5B6B6B6C5C5C5B6B6B697C5C5C5C5C597C5C59797C5B6B6B6979797737373B6B6B6
C5975F858585C5975FC5C597C5975FC5975F97975F975F5F5F5F005F5F5F5F975F975F5F
5F5F000049005F5F005F5F004949494949494949495F5F004949495F5F5F5F97005F975F
5F5F005F5F005F975F5F5F005F5F005F975F5F5F5F4949494949495F5F5F5F97975F975F
97C5C59797975F97975F979797C5C5A7A7A7737373A7A7A75F975F5F5F5F979797979797
5F975F97975F9797978585855F5F5F5F9797B6B6B65F97975F975F5F979797C597979797
B6B6B6A7A7A79797975F97975F97975F5F5F5F975F8585858585855F975F979797979797
8585857373735F5F5FA7A7A77373735F975F5F97975F975F5F5F5F5F975F5F5F00494949
5F975FC5C5C5FFFFFF5F5F5FA7A7A79797975F975F97979797C5C5A7A7A7B6B6B697C5C5
B6B6B697C5C5A7A7A75F97C59797C55F97C55F97C55F97C55F97975FC5978585855F9797
979797979797A7A7A75FC5C55F97975F97C55F97975F97C55F97975F9797005F5F5F9797
005F5F4949492C2C2C2C2C2C2C2C2C2C2C2C00002C002C002C2C2C2C00002C2C2C2C2C2C
2C2C2C002C00002C00002C0000002C002C002C2C2C2C2C2C002C000000002C0000000000
0000000000002C0000000000000000002C00002C00002C00000000000000002C00002C00
00002C002C000000002C0000002C00002C0000000000000000000000000000002C2C0000
000000000000002C002C00002C00000000002C00002C000000002C000000002C00002C00
00000000000000000000000000000000000000000000000000002C0000002C0000000000
00000000000000000000002C002C00000000000000002C0000002C002C002C0000000000
00000000002C00000000002C0000002C2C2C00000000002C0000002C2C2C2C000000002C
002C00000000000000002C002C0000000000002C002C000000002C2C0000002C0000002C
00002C2C000000000000000000002C000000000000002C00000000002C002C0000002C00
002C00002C000000002C000000002C000000000000000000000000002C00002C00002C00
2C2C2C00002C002C0000000000000000002C002C00000000000000000000002C00000000
00002C00000000000000002C000000000000000000002C0000002C000000000000000000
0000002C2C2C2C2C2C494949
A7A7A797C5C5D4D4D497C5C5C5C5C5C5C5C5A7A7A7E1E1E1A7A7A75F97C55F5F5F5F97C5
C5975F97975F979797C5975FC5C55FC5975F97975F979700C5C5C54900005F5F5F5F975F
975F00494949494949494949005F004949492C2C2C4949495F5F5F5F5F005F5F5F5F5F5F
005F5F2C2C2C5F5F5F5F5F5F4949495F5F005F5F5F5F5F00494949005F00005F5F737373
5F5F5F5F5F5F858585737373005F5F737373A7A7A78585857373735F975F5F5F5F737373
5F5F5F5F97975F97975F5F5F5F97975F979797C5978585855F975F97975F97C597A7A7A7
B6B6B6979797A7A7A7A7A7A79797975F5F5F5F5F5F979797858585858585A7A7A7A7A7A7
A7A7A75F975F8585859797975FC5975F97975F975F5F975F5F5F5F97975F5F5F005F5F00
C5EFFFE1E1E197975F8585855F97C55F979797C5C597C5C5A7A7A79797C597C5C597C5C5
A7A7A7A7A7A79797C597C5C597C5C55FC5C5A7A7A75FC5975F9797A7A7A79797C5A7A7A7
A7A7A7A7A7A7A7A7A75F97C55F97975F97975F97C55F97979797978585855F97975F5F97
7373735F5F5F4949492C2C2C2C2C2C2C2C2C2C2C2C002C0000002C002C002C2C2C2C2C2C
002C002C2C2C002C00000000000000002C002C00002C2C2C2C2C2C2C2C2C002C00737373
000000002C000000002C2C2C2C00002C2C2C0000002C0000000000000000000000002C00
000000000000000000002C0000002C002C002C2C2C2C2C2C000000000000002C002C0000
002C00002C000000002C00002C0000002C00002C00000000002C0000002C2C0000000000
00000000002C00000000000000002C0000000000000000000000002C000000000000002C
00000000000000002C0000000000000000002C2C2C0000000000002C000000000000002C
000000002C0000002C002C000000000000002C2C2C000000000000000000002C00002C00
0000000000002C00000000002C2C2C2C0000002C00002C002C000000002C2C2C2C2C2C2C
00000000002C002C002C000000002C0000000000002C2C2C00000000002C00002C002C00
002C0000000000000000000000002C2C0000002C000000000000000000002C2C2C000000
2C2C2C002C002C2C2C0000002C2C2C00002C00002C00002C002C00002C0000002C000000
2C0000002C00002C00000000000000002C0000002C0000000000002C2C2C000000000000
00002C0000002C2C2C005F5F
5F97C59797C5C5C5EF9797C5B6B6B6C5C5C55F97C597C5C5B6B6B65F9797005F5FA7A7A7
5F975F97975F97975FC5979797975FC5975F97975FC5C5C57373734949492C2C2C975F5F
975F5F5F5F005F5F004949494949490049005F5F005F5F5F4949495F5F5F5F5F5F494949
5F975F4949494949494949495F5F5F494949494949005F002C2C2C5F5F5FA7A7A75F975F
979797B6B6B6737373B6B6B697C5C5737373A7A7A797C5C59797975F97979797975F5F5F
858585979797A7A7A79797975F975F5F97979797975F97975F975FB6B6B6A7A7A75F9797
A7A7A7979797A7A7A797979797C5975F975F97975FA7A7A7A7A7A7B6B6B6A7A7A7A7A7A7
A7A7A77373735F9797A7A7A79797979797975F975F5F5F5F5F5F5F5F5F5F5F5F005F9797
C5C5C5EFC5975F5F5F5F5F5F858585979797A7A7A7A7A7A79797C59797C5A7A7A75F97C5
97C5C59797C5A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A75F97975F97979797975F97C5
A7A7A7A7A7A7A7A7A7A7A7A75FC597A7A7A75F97979797979797975F97975F9797858585
0097970097975F5F5F005F5F2C2C2C2C2C2C002C00002C002C2C2C002C002C00002C2C2C
2C2C2C002C002C2C2C00002C2C0000002C0000002C2C2C2C2C2C2C2C000000002C2C2C2C
00002C0000000000002C2C2C002C002C0000002C00002C0000002C2C000000002C2C2C2C
0000000000002C2C2C2C000000000000000000002C2C2C2C002C002C000000002C2C0000
002C00002C002C000000002C0000000000002C2C2C000000000000000000002C0000002C
000000000000000000002C000000000000002C0000002C00000000000000000000000000
000000000000000000002C000000000000002C00000000000000000000002C2C2C002C00
000000000000000000000000002C002C00000000002C000000002C2C0000002C00000000
2C0000002C00002C0000002C000000002C002C2C2C2C2C2C00002C00002C00002C002C00
000000000000002C00002C002C2C2C0000000000002C2C2C00002C00002C002C00000000
00002C002C002C00002C2C2C2C2C2C2C0000002C0000000000000000000000002C002C00
00002C000000002C0000002C00002C002C002C2C2C2C0000002C002C0000002C002C0000
00002C000000000000000000000000000000002C00000000000000000000000000000000
2C0000000000002C00494949
5F97975F97C5B6B6B69797C5B6B6B697C5C597C5C5A7A7A75FC5C55F97975F975F5F5F97
00975F005F5F97975FA7A7A797975F858585C5C5975F5F005F5F5FB6B6B65F5F005F5F00
49494997975F5F5F5F5F975F5F5F5F5F5F005F5F00005F005F5F5F005F5F4949495F5F5F
5F5F5F5F5F5F5F5F5F4949495F975F4949495F5F004949494949495F9797B6B6B65F5F5F
5F5F5FB6B6B65F97975F975F975F5F9797975F97975FC5975F9797979797737373494949
5F5F975F9797979797A7A7A75F97979797975FC597979797A7A7A78585855F9797A7A7A7
85858597979797C5C597C5C5A7A7A75F975F5F975F737373A7A7A7A7A7A75F975F858585
A7A7A7975F5F5F5F5F97975F8585855F975F5F975F5F5F5F5F5F0097975F5F975FC5EFEF
FFFFFF0073005F975F5F5F5F5F5F5F9797978585855F97C5A7A7A7979797A7A7A7A7A7A7
5F97C59797979797C5A7A7A75FC5C5A7A7A75F97C55F97975FC5C55F97C55F9797A7A7A7
9797975F97C55F97C597C5C55F97C55F97C55F97979797975F97975F97975F97975F5F97
5F9797005F975F975F5F97974949492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C
2C2C2C002C002C2C2C002C00002C000000002C00002C2C2C002C002C2C2C002C0000002C
000000002C00002C00002C00002C0000002C2C2C2C002C0000000000002C0000002C0000
00002C490000002C00002C0000002C000000000000002C0000002C002C000000002C0000
2C2C2C0000002C2C2C000000002C002C2C2C002C002C00002C000000002C2C0000000000
002C00000000002C0000000000002C0000000000002C2C2C000000000000000000002C00
00002C002C0000000000002C2C00002C0000002C0000000000002C000000002C002C0000
0000002C00002C000000002C0000000000002C2C2C0000002C000000002C2C2C2C000000
0000002C000000002C0000002C00002C2C2C00000000002C00002C00002C00002C000000
000000000000000000002C002C2C2C2C00002C2C2C000000002C000000000000002C0000
2C0000002C00002C0000002C00002C2C00000000000000000000002C00002C2C2C00002C
00002C00000000002C00002C00002C0000002C00000000000000002C000000002C000000
002C00000000002C00000000000000000000000000000000002C000000002C2C2C2C0000
002C0000002C000000005F5F
5F97975F979797C5C597C5C5E1E1E1C5C5C5B6B6B6A7A7A75F97C5979797A7A7A7B6B6B6
5F975F5F5F5F737373C5975F979797858585C5975FEF975F97975F858585A7A7A75F0000
2C2C2C975F0097975F97975F975F5F005F005F5F5F4949494949494949495F5F5F494949
5F5F5F5F5F5F5F5F00005F5F5F5F5F4949494949497373735F5F5F5F5F975F5F00979797
005F5F97C5975F97975F5F00005F5F737373A7A7A7A7A7A797C5975F5F5F5F5F5F737373
5F9797494949005F5FA7A7A78585857373735F975F7373735F975F5F5F5F7373735F5F5F
A7A7A75F9797A7A7A7A7A7A7A7A7A77373735F97977373735F975F8585855F5F5F5F9797
A7A7A77373735F975F5F97975F97C58585854949495F5F005F975F5F975FC5C5EFC5C5C5
979700005F005F5F5F5F9797858585979797A7A7A797C5C597C5C597C5C59797C59797C5
A7A7A7A7A7A75F97C59797C55F97975F97C59797C55FC5C55FC597A7A7A79797C5A7A7A7
97979797979797C5C5979797A7A7A75F97975F97C55F97975F9797979797858585A7A7A7
5F5F975F97975F5F977373735F5F5F4949492C2C2C2C2C2C002C00002C002C2C2C2C2C2C
2C2C2C2C2C2C002C00002C002C00002C00002C2C2C2C2C2C2C2C2C00002C2C000000002C
2C2C2C002C002C000049000000002C002C002C2C2C2C00002C2C2C2C2C2C00002C000000
002C00002C0000000000002C0000000000000000000000000000002C2C2C002C00002C00
000000000000000000000000000000000000000000002C0000002C000000000000000000
00000000000000002C002C0000002C002C00000000002C002C2C2C00000000002C2C0000
0000002C0000000000000000002C0000002C002C000000002C00000000002C2C2C002C00
002C0000002C000000002C002C2C2C00002C002C002C2C2C00000000002C2C2C2C002C00
2C000000002C000000000000002C002C000000002C2C000000002C0000000000002C2C2C
00002C2C000000000000000000000000002C000000000000002C0000002C00000000002C
002C00002C002C00002C2C2C2C000000000000002C2C000049000000002C00002C00002C
002C002C2C2C2C2C2C2C2C2C00000000000000002C2C2C2C000000000000000000000000
002C00000000000000002C00000000002C00000000000000000000000000002C00000000
000000000000002C005F5F5F
5F97975F979797C5C5B6B6B697C5C5C5C5C5B6B6B6A7A7A7D4D4D4A7A7A75F97C5B6B6B6
5F97C55F975F8585855F979797975F97C597C5975FC5975FC5975F975F0097975F737373
2C2C2C494949975F5F5F975F975F5F975F002C2C2C5F5F002C2C2C5F5F5F5F5F00494949
5F975F7373735F975F5F5F5F7373734949494949497373737373735F975F5F5F5FA7A7A7
B6B6B6858585A7A7A7494949494949A7A7A7A7A7A75F97977373734949495F5F5FA7A7A7
A7A7A75F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F975F5F975F8585855F5F5F5F5F5F005F5F
5F975FA7A7A75FC5975FC5C55F97974949497373735F97975F97977373735F975F5F9797
9797977373737373735F979797979797975F97975F4949495F9700737373C5EFEFFFFFC5
5F5F5F7373735F97C55F9797858585737373A7A7A75F97C597C5C59797C5A7A7A79797C5
979797A7A7A7A7A7A75FC5C55F97C55F97C55FC5C55F9797A7A7A7A7A7A75FC5C55FC5C5
A7A7A75FC5975F97C5A7A7A75F97975FC5975F97C55F97975F97979797975F97975F9797
5F97975F97975F97975F97975F975F5F5F5F4949492C2C2C2C2C2C2C2C2C00002C002C00
2C2C2C2C2C2C2C2C2C002C00002C002C2C2C2C2C2C002C00002C00002C00002C00002C00
002C002C2C2C00002C00002C2C0000002C00002C00002C00002C002C000000002C2C0000
002C002C2C2C002C000000002C00004900002C000000002C2C00000000002C00002C0000
00002C0000002C2C2C2C00002C2C2C000000002C0000002C002C002C2C2C000000002C00
002C002C0000002C002C0000002C0000000000000000002C000000000000000000000000
2C2C2C002C00000000002C0000002C00002C2C2C2C002C000000000000002C2C2C000000
0000000000000000000000002C00002C2C2C002C002C00002C2C2C000049C5C597002C00
2C000000002C0000002C0000002C0000000000002C00002C002C002C2C2C2C0000002C00
00002C0000002C000000002C2C00000000002C0000000000000000002C00002C002C2C2C
2C0000490000002C002C000000002C00002C00002C00002C00002C2C2C2C00000000002C
2C2C2C2C000000002C002C002C2C2C2C2C2C00000000002C000000002C0000002C000000
2C2C2C00000000000000002C002C0000002C000000002C002C0000000000000000000000
0000002C00002C2C2C494949
5F97C5A7A7A797C5C5B6B6B6A7A7A797C5C597C5C5A7A7A7C5C5C597C5C55F97C59797C5
A7A7A75F97977373735F9797009797C5C597EF975FC5975FC5975F97975F97975F5F5F5F
9797972C2C2C975F0097975F5F5F5F9797002C2C2C494949005F005F5F00494949494949
5F5F5F5F975F5F5F5F5F5F5F4949494949495F00004949495F5F5F5F5F00494949858585
A7A7A75F975F5F975F5F5F5F5F5F5F5F5F5F5F979785858597C597A7A7A75F97975F9797
5F97977373735F5F5F5F5F5F5F5F5FA7A7A77373737373735F975F5F975F737373737373
5F975F5F97975F975F8585858585857373739797978585855F97975F97979797975F9797
5F97977373739797975F97975F979797975F5F97005F5F5F5F5F00FCFCFCEFFFEF975F5F
5F97979797975F9797A7A7A79797978585857373735F979797C5C5B6B6B65F97C55F97C5
A7A7A7979797A7A7A75F97C55F9797979797A7A7A797C5C5A7A7A7A7A7A7A7A7A75F97C5
97C5C5A7A7A75F9797A7A7A79797975F97975F9797A7A7A79797975F97975F9797A7A7A7
5F97975F97C55F97975F97975F5F977373735F5F5F494949494949002C002C2C2C002C00
2C2C2C00002C2C2C2C2C2C2C002C000000002C2C2C2C2C2C2C0000002C00002C00002C00
002C000000004900002C2C2C2C2C2C4900002C00002C000000002C002C002C0000000000
0000002C000000002C002C00002C00002C00002C002C2C2C0000000000002C2C2C002C00
0000002C000000002C002C0000000000002C00002C000000000000002C00000000002C00
2C000000002C00002C0000000000002C00000000000000000000002C2C2C000000000000
2C000000002C00002C2C2C2C2C000000002C00002C00002C00002C002C0000002C002C00
00002C2C00002C00002C000000002C002C00002C00002C00002C002C2C2C2C2C2C00002C
00002C0000002C0000002C0000002C2C000000000000002C002C00000000000000002C00
00002C002C00002C00000000000000000000002C000000000000000000000000002C0000
002C00002C002C00000000002C2C2C2C000000002C00002C00002C002C002C2C2C000000
002C0000002C00002C2C2C2C000000000000000000002C002C000000000000002C2C0000
00000000000000000000000000002C000000000000000000002C000000000000002C2C2C
0000000000002C0000005F5F
A7A7A797C5C5B6B6B697C5C59797C597C5C597C5C597C5C597C5C59797C55FC5C55FC5C5
97C5C5A7A7A75F97975FC597A7A7A7B6B6B6C5C597C59797975F5F730000C5975F494949
C5C597975F5F5F00007373735F975F5F5F004949495F5F5F5F5F004949495F5F00494949
4949494949495F5F5F7373735F5F5F5F5F00002C005F5F5F4949495F5F00005F5FB6B6B6
9797975F5F5F5F5F5F5F5F00494949005F5F8585858585855F5F5F8585855F9797979797
5FC5C55F5F5F005F5F4949495F5F5F5F5F97A7A7A79797975F5F974949495F97975FC597
5F5F5F97C5975F5F5F005F5F5F97979797975F97975F97975F9797A7A7A7979797A7A7A7
9797975F9797A7A7A75F975F7373735F975F005F5F494949C5C5C5C5EFEFFFEF975F9797
5F97975F97975F97977373735F5F5F97979797979797C5C55F97C59797C55F97C55FC5C5
9797C55F9797A7A7A7A7A7A7A7A7A7A7A7A75F97C55FC5C5A7A7A75F97C597C5C597C5C5
9797C5A7A7A7A7A7A75FC5C5A7A7A7A7A7A7A7A7A75F97C59797C58585855F97979797C5
9797979797975F97975F97975F97975F97975F5F5F7373734949492C2C2C002C002C2C2C
002C002C2C2C2C2C2C2C2C2C00002C5F5F00002C002C2C2C002C00002C0000002C2C2C2C
0000002C000000002C002C002C2C2C002C002C2C2C2C000049000000002C2C0000000000
000000002C000000002C2C2C2C0000002C00002C00002C00002C000000002C2C2C002C00
2C000000000000000000000000000000000000000000002C002C0000002C00002C002C00
002C002C0000002C000000002C2C2C2C00002C0000002C0000002C000000000000000000
00002C0000002C000000002C00000000002C00002C2C2C2C2C0000002C00000000000000
0000002C2C2C2C000000002C00002C2C0000002C000000002C2C2C737373002C002C2C2C
0000000000002C2C2C2C000000002C2C00002C00002C2C2C2C2C2C000000000000000000
00002C2C0000002C0000002C2C0000002C002C0000000000000000000000002C002C0000
002C00002C00002C0000002C002C0000002C00002C00000000002C002C002C2C2C2C2C2C
002C000000000000002C00000000000000002C2C2C00000000000000000000002C002C00
000000002C0000000000002C000000000000000000002C00000049000000494949002C00
2C00000000002C2C2C494949
5F97C5B6B6B697C5C55FC5C597C5C5B6B6B69797C5A7A7A797C5C55F97C55F97C55F9797
97C5C5A7A7A797C5975F97C55FC5C55FC5C5A7A7A7C5975FC5C55F975F5FC5975F5F5F5F
4949495F5F002C2C2C5F5F5F975F005F5F5F975F5F5F5F5F494949005F00494949005F5F
005F5F4949497373735F975F5F5F97005F5F4949492C2C2C4949492C2C2C4949495F9797
5F975F5F975F5F5F005F5F5F4949495F97975F5F5F5F5F975F975F5F5F5F5F5F5F979797
A7A7A7979797494949005F5F5F97979797C58585859797977373735F9797B6B6B6A7A7A7
5F975F97975F494949005F5F737373005F5F7373735F5F5F8585855F97975FC597A7A7A7
9797975F97975F979797975F5F5F5F5F5F00494949737373C5EFC5FFFFEF5F5F5F5F975F
5F975F5F975F5F5F000097975F97975F97C58585855FC5C55F97C5A7A7A75FC5C5A7A7A7
5FC5C597C5C597C5C55FC5C5A7A7A7B6B6B6A7A7A797C5C5A7A7A75F97C55F97C597C5C5
97C5C55F97C5A7A7A797C5C5A7A7A7A7A7A7979797A7A7A7A7A7A75FC5C55F97975F9797
A7A7A75F97975F97C55F5F979797975F97975F97975F97975F5F5F005F5F2C2C2C00002C
2C2C2C2C00000000002C2C2C0000000000002C000000002C00002C00002C2C2C2C2C2C2C
2C2C2C2C00000000002C2C2C00002C2C2C2C2C0000002C00002C00002C0000002C000000
000000000000002C00000000000000000000002C002C00000000002C2C2C2C2C2C2C2C2C
00002C00002C2C000000000000000000002C0000002C2C2C002C0000000000002C2C2C2C
002C00002C002C0000002C0000002C002C0000002C0000002C2C2C000000000000000000
0000002C000000002C0000002C0000000000002C002C00000000002C2C2C490000000000
0000002C0000002C00002C0000002C2C0000002C00000000002C002C0000002C00000000
000000002C00002C002C2C2C2C00002C000000002C002C00002C002C2C2C002C002C0000
00002C00002C5F0000002C002C000000000000002C2C0000002C00000000002C00000000
2C2C2C2C0000002C0000000000002C002C002C2C2C00000000002C002C002C2C2C002C00
002C000000002C000000002C2C2C2C002C0000000000000000002C00002C000000000000
2C000000002C000000000000000000000000002C00002C00975F5F00002C002C00002C00
00002C2C0000002C00494949
979797B6B6B6B6B6B65F979797C5C597C5C5A7A7A7C5EFC597C5C597C5C55F97C55FC597
5F9797A7A7A7A7A7A75F9797005F5FA7A7A75F9797979797C5979785858597975FC5975F
B6B6B6B6B6B65F5F005F5F004949495F5F5F4949495F5F5F5F975F5F975F494949494949
0049004949495F5F5F5F5F5F5F5F5F5F5F5F2C2C2C494949494949494949005F00494949
5F5F5F5F5F005F5F005F5F5F5F5F5F5F5F5F7373735F97975F97975F975F5F5F5F737373
5F9797979797494949005F5F5F5F5F8585855F5F5F7373738585859797975FC59797C597
9797975F5F00005F5F97C5975F5F5F5F975F5F975F737373A7A7A75F9797979797979797
9797975F97979797974949495F5F5F5F5F005F975FD4D4D4FFFFEF5F5F5F5F975F5F975F
5F5F5F5F5F5F5F975F858585858585A7A7A75FC5975F97C5A7A7A797C5C55F97C59797C5
9797C5A7A7A79797C55F97C55FC5C5A7A7A7A7A7A79797C5A7A7A797C5C597C5C55F97C5
5FC5C59797C5A7A7A79797C5A7A7A75F97C5A7A7A79797975FC5C55F97C55F97C55F9797
7373735F97975F97979797975F97975F97975F97975F97977373737373734949492C2C2C
2C2C2C2C2C2C2C2C2C2C0000002C000000002C00000000002C0000000000002C002C2C2C
49000000002C002C00002C00002C002C2C2C2C2C2C002C000000000000002C0000000000
490000002C000000000000000000000000002C2C2C002C002C0000000000002C00000000
2C2C2C00002C00002C2C00002C000000002C2C00005F0000002C0000002C2C0000002C00
2C2C2C002C002C00002C0000002C002C000000002C00000000002C0000002C000000002C
2C2C2C000000002C000000002C00002C0000002C0000002C002C002C0000002C002C2C2C
2C000000002C002C0000002C0000000000002C000000002C002C000000002C0000002C00
2C0000000000002C0000002C00002C2C000000002C002C000000002C00002C2C2C00002C
00002C00002C00002C00002C00002C0000000000002C0000002C0000002C002C002C0000
002C00002C002C0000002C0000002C00002C00002C00000000002C002C00000000000000
002C00002C002C2C2C00000000000000002C00002C00002C0000002C2C2C000000000000
00000000000000000000002C0000000000002C0000000000002C002C000000002C000000
000000000000002C00494949
9797C5A7A7A7B6B6B6A7A7A75FC59797C5C55F97C59797C597C5C5C5C5C55FC5C55F9797
5F97975F97975F975F5F97975F5F970097970097975F975F858585A7A7A797975F5F5F00
975F5FC5C5975F5F5F5F5F5F2C2C2C4949495F005F5F5F5F4949494949495F5F00494949
5F5F5F4949494949495F5F5F5F5F005F5F5F4949492C2C2C2C2C2C5F5F004949495F5F5F
5F5F005F5F5F5F5F005F97005F5F5F5F975F5F9797005F5F5F97975F5F5F5F5F5F5F5F5F
005F005F5F5F5F5F5F4949495F97975F97977373735F97975F975F5F9797B6B6B6A7A7A7
A7A7A79797975F97975F5F5F5F5F5F7373735F97975F5F005F5F5F5F5F5F85858597C5C5
979797A7A7A7A7A7A75F97975F5F0097975F5FC597EFEFC5C5975F4949495F5F5F494949
4949495F5F5F5F975F5F5F5F5F9797A7A7A79797979797979797C55FC5C597C5C597C5C5
97C5C5B6B6B65F97C55FC5C55F97C55F97C597C5C597C5C55F97C55F97C5A7A7A7A7A7A7
A7A7A7A7A7A797C5C597979797C5C5A7A7A7A7A7A7A7A7A75F97C5A7A7A75FC5C55F9797
5F97C55F97C55F97975F97975F97975F97975F97975F97977373735F5F5F5F5F5F005F5F
2C2C2C2C2C2C00002C2C00002C2C2C0000000000002C000000002C2C00002C00002C2C2C
2C2C2C2C00002C2C2C002C00002C0000002C2C2C2C002C000000000000000000002C0000
2C000000002C0000002C00002C0000002C002C2C2C2C2C2C00002C490000002C00002C00
2C2C2C2C000000002C0000000000002C00000000002C2C2C00000000002C000000002C00
000000002C00002C0000002C002C000000002C2C2C0000000000002C2C2C2C000000002C
2C0000002C00002C0000002C0000002C2C2C2C000000002C002C0000002C000000490000
0000000000002C2C2C2C2C2C00002C002C002C000000002C002C000000000000002C0000
002C00002C002C2C2C00002C00002C00002C00002C000000000000002C0000002C2C0000
00002C0000002C000000002C00002C00000000002C00002C2C000000002C2C2C2C002C00
000000002C002C00000000002C2C2C000000002C002C2C2C00000000002C000000000000
2C2C2C00002C002C000000000000002C0000000000002C002C000000002C000000000000
0000000000000000000000000000000000005F5F97000000000000002C00000000002C00
2C00000000000000005F5F5F
C5C5C55FC5C55F97C59797C55F97975F97975F97C55FC5C5E1E1E1C5C5C59797975F97C5
0097975F97975F97975F97975F5F975F97975F9797005F5F5F979797979797975FC5975F
5F5F00975F5F5F5F5F4949495F5F5F5F5F5F5F5F5F5F5F5F7373735F5F5F975F005F5F5F
005F005F5F5F5F5F5F4949494949495F5F5F4949495F5F004949494949495F5F5F494949
5F5F005F5F5F5F5F5F5F5F5F5F975F4949495F5F5F5F5F5F737373737373005F00494949
005F5F5F5F00494949005F5F49494949494997975F4949495F5F5F858585B6B6B6A7A7A7
5F9797A7A7A75F5F00005F5F5F5F5F5F97977373735F5F005F5F5F9797975F97975F9797
9797975F979797979797975F97975F858585EFEFC5FFFFC57373735F97975F97975F975F
9797975F5F5F5F975F8585859797C5A7A7A79797C5A7A7A7A7A7A7A7A7A7979797A7A7A7
97C5C55F97C5A7A7A7A7A7A75FC5C5A7A7A79797C5A7A7A797C5C55FC5C5A7A7A7A7A7A7
A7A7A7A7A7A75FC5C55FC5C55F97C55F97C55FC5C55FC5C55F9797A7A7A75F9797979797
5F97975F97975F97975F97C55F97C55F97975F97975F97970097975F97975F9797005F5F
005F5F005F5F2C2C2C2C2C2C2C2C2C490000002C000000002C000000002C002C002C2C2C
2C2C2C2C2C2C00002C49000000002C000000002C000000000000000000002C2C2C000000
0000002C00002C2C2C00002C2C2C2C002C002C2C2C002C00002C00002C00000000002C00
2C2C2C2C2C2C2C2C2C2C000000002C2C00000000000000002C2C2C2C00000000002C2C2C
2C2C2C000000000000002C0000002C00000000002C00002C2C000000000000002C2C0000
00002C002C0000002C002C00002C0000002C00002C002C002C2C2C2C2C2C002C00002C00
002C002C2C2C002C002C2C2C00002C0000000000002C0000002C0000000000000000002C
002C0000002C2C00000000002C2C2C00002C00002C00002C000000002C0000002C494949
00002C00000000000000002C002C0000002C00002C2C0000002C002C00002C2C2C2C2C2C
002C00002C000000002C0000002C002C2C2C00000000002C002C005F5F5F000000002C00
2C2C2C00002C00000000002C000000002C002C0000002C00002C00002C002C000000002C
002C000000002C2C2C000000002C0000002C2C000000002C002C00000000002C0000002C
000000000000002C00494949
B6B6B6A7A7A797C5C597C5C597C5C55F97C55F97C55F97C5D4D4D4D4D4D497C5C55F97C5
A7A7A75F97975F5F5F5F5F975F97C55F97970097975F5F5F5F5F5F494949979700979700
975F5F975F5F8585858585855F5F5F494949975F004949495F975F5F5F5F007300005F5F
4949494949495F5F005F5F5F5F5F005F5F5F5F5F5F2C2C2C2C2C2C2C2C2C2C2C2C494949
005F5F005F5F5F5F5F5F5F5F5F5F5F5F5F5F005F5F4949497373735F5F5F5F5F00494949
4949494949494949494949495F5F5F5F5F5F5F97975F5F5F5F975F5F5F5F979797979797
5F979797C5974949495F5F00005F5F5F5F004949495F5F005F5F005F5F5F5F5F5F979797
5F97C5979797A7A7A75FC59797975FD4D4D4EFFFC59797975F5F5F005F5F858585A7A7A7
5F97975F975F975F5F494949A7A7A7A7A7A797C5C5A7A7A7A7A7A7A7A7A7A7A7A797C5C5
5F97C59797C55F97C597C5C5979797A7A7A75FC5C55F97C55F97975F97C55F9797A7A7A7
5F97C5A7A7A7A7A7A75F97979797975F97975F97C55F97975F9797A7A7A75F97C55F97C5
5FC5975F9797A7A7A75F97C55F97C55FC5C55F97975F97977373735F97975F9797009797
005F5F005F5F2C2C2C2C2C2C2C00004900004900002C0000002C00000000002C002C2C2C
2C2C2C2C2C2C2C000000002C0000002C00000000002C00000000002C0000000000000000
2C2C2C2C0000002C00002C002C0000002C0000002C2C2C2C002C002C0000000000000000
002C002C0000002C0000002C2C0000002C000000002C0000002C00002C002C0000002C00
002C0000002C2C0000002C0000000000000000000000002C00000000000000002C2C2C2C
00002C2C0000002C0000002C2C00000000000000002C0000002C0000002C2C2C2C00002C
00002C2C0000002C0000002C0000002C00002C0000002C00002C00000000002C002C2C2C
2C000000002C2C000000000000002C002C002C2C2C2C2C2C002C002C2C2C2C2C2C00002C
0000000000002C000000002C2C2C2C49494900002C00002C0000002C2C2C2C2C2C002C00
002C00002C00002C002C2C2C002C002C2C2C00002C2C000000000000002C2C0000002C00
2C2C2C000000000000002C002C2C2C2C0000002C002C2C2C000000002C00002C002C0000
002C002C0000000000000000000000000000002C00002C00000000000000000000002C00
0000002C2C2C000000494949
B6B6B6A7A7A75F97C55FC5C597C5C55FC5975F9797C5C5EFB6B6B6C5EFEFC5C5EF9797C5
9797C5A7A7A75F97975F975F5F97975F5F975F97975F5F975F5F5F979797979700C55F5F
975F5F975F5F5F5F5F97975F975F5F5F5F005F5F5F5F5F004949495F5F5F4949492C2C2C
2C2C2C5F5F00494949494949005F004949495F5F5F4949494949492C2C2C005F5F494949
4949495F5F005F5F5F5F975F494949005F5F5F5F005F5F5F2C2C2C4949492C2C2C005F00
494949005F002C2C2C5F5F005F5F5F5F5F5F7373735F5F5F494949005F5F85858597975F
4949495F5F5F4949495F5F004949495F5F005F5F005F5F004949495F5F5F5F5F5F737373
5F97979797979797975F979797C5C5C5C5C5EFC5C59797975F975F5F5F5F5F97C55F9797
737373975F5F7373735F975F5F97975F97C5A7A7A797C5C5A7A7A75F97C59797C55F97C5
5FC5C5979797A7A7A79797975F97C59797975F97C55F9797A7A7A7B6B6B697C5C55F97C5
5F97975FC5C55FC5975F97C55F97979797C55F97C5A7A7A7A7A7A7A7A7A7979797A7A7A7
A7A7A7A7A7A79797975F97975F97C59797979797975F5F975F97970097975F9797005F97
005F975F5F5F5F5F5F494949002C00002C002C2C2C2C00004900002C00002C0000000000
002C0000000000002C00002C2C2C2C00002C2C2C2C002C000000002C00002C000000002C
2C2C2C00002C4900002C000000002C00002C0000002C2C2C002C002C2C2C2C0000A7A7A7
494949002C002C00002C0000002C00002C00002C0000002C2C2C2C00002C000000002C00
2C0000002C00002C0000002C00002C2C000000002C2C2C2C0000002C000000002C000000
2C000000002C0000002C0000000000002C002C000000002C2C2C2C2C000000002C000000
2C00002C0000002C000000002C0000002C00000000000000002C000000002C000000002C
2C2C2C002C002C000000002C00002C002C00002C00002C0000002C2C2C2C2C2C2C00002C
2C2C2C002C00002C002C2C2C002C00002C002C2C2C2C000000000000002C002C002C0000
002C00002C002C2C2C002C002C2C2C00002C2C2C2C0000000000002C2C2C2C2C2C002C00
00002C002C00002C0000002C00002C000000002C00002C002C2C2C002C0000002C002C00
00002C002C00000000002C0000002C00000000002C000000000000002C00000000002C00
002C00000000002C00005F5F
B6B6B6A7A7A797C5C50097C5C5C5C55F97975F9797C5C5C5C5EFEFC5C5EFC5C5C597C5C5
B6B6B65F97978585855F97975F97C57373735F5F5F5F5F5F5F5F5F005F975F975F975F5F
975F5FC55F5F975F5F5F975F5F5F005F5F5F5F5F004949495F5F5F5F5F5F5F975F97975F
5F5F000049005F5F005F5F5F2C2C2C2C2C2C4949495F5F00005F004949492C2C2C494949
4949495F5F5F4949495F5F5F5F5F004949495F5F004949494949495F5F005F5F00005F00
4949494949494949494949492C2C2C5F5F5F5F5F00005F000073005F5F97A7A7A75F5F00
5F5F005F5F004949494949492C2C2C0049002C2C2C4949492C2C2C0049005F5F5F5F9797
97975F5F9797858585979797FFEFEFFFFFEF97C597B6B6B6858585858585979797979797
5F975F5F5F5F5F97975F97977373735F97975F9797A7A7A7A7A7A79797C597C5C55FC5C5
9797C55FC5C5A7A7A797C5C59797979797979797C5A7A7A7A7A7A79797975F97C5979797
5F97C55F97975FC5975F97C55F97975F97975F97975F97975F97C55F97975F97C55F9797
5F97975F97975FC5975F97C5A7A7A79797975F97C55F97975F97975F97975F5F975F9797
0097975F97975F5F5F4949492C2C2C002C002C2C2C2C2C2C002C002C000000002C2C0000
2C000000000000002C2C2C2C2C00002C2C2C2C00002C0000000000000000000000000000
002C000000002C00002C2C2C2C2C2C002C0049000000002C2C2C2C00002C002C002C2C2C
002C00002C00002C00002C002C2C2C00000000002C002C00002C0000002C2C0000002C00
00002C00002C2C00000000002C2C2C00000000002C002C004900002C000000002C2C0000
0000002C2C2C2C0000002C00002C0000000000002C000000002C002C00002C000000002C
2C000000002C0000000000002C2C2C0000000000002C0000002C0000002C0000002C2C2C
002C00002C002C2C2C2C2C2C002C002C2C2C2C2C2C2C00002C2C2C2C2C2C00002C000000
002C0000002C49000000002C2C0000002C00002C000000000000002C2C2C000000000000
002C00002C0000000000000000000000002C002C000000000000002C2C2C002C00002C00
2C2C2C0000000000002C2C2C0000002C2C2C2C00000000000000000000002C000000002C
000000000000000000000000002C0000000000000000000000000000002C000000000000
002C0000000000002C494949
9797975F97C5C5C5EF5F97C5D4D4D45F97975F97C597C5C5E1E1E1C5C5C5C5C5EFB6B6B6
5F97977373738585855F5F975F97975F5F5F5F5F9700975F005F5F5F97975F9797975F5F
C5970097975F97975FC597979797975F5F5F4949495F5F005F5F005F5F5F97975F97975F
5F5F5F4949492C2C2C5F5F000073004949494949495F5F5F494949005F5F4949495F5F00
4949495F5F005F5F005F5F5F4949494949492C2C2C5F5F005F5F002C2C2C4949495F5F00
4949494949492C2C2C005F00494949494949005F005F5F5F5F5F5F5F5F5F494949494949
4949490049004949494949494949495F5F002C2C2C004900494949005F004949495F5F5F
5F975F5F975F5F5F00EFFFEFC5EFEFC5C597A7A7A7A7A7A7979797A7A7A75F975F5F9797
85858597975F5F975F5F975F5F975FA7A7A7858585979797B6B6B6A7A7A79797C55F97C5
5FC5C5979797A7A7A75F97C5A7A7A7A7A7A7B6B6B6A7A7A75F97C5A7A7A75F97C55FC597
5F97979797975F97975FC597A7A7A75F97C55F97975F97C55F97975F97975F97975F9797
5F97979797975F5F975F97975F97979797975F97975F97975F97C55F97975F97975F9797
5F97975F97978585855F5F5F005F5F2C2C2C002C00002C00002C004900002C2C2C2C0000
2C00002C00002C2C2C2C00002C000000002C000000002C002C2C2C000000000000000000
00002C2C2C2C002C0049000000002C002C00002C00002C0000002C00002C2C2C2C00002C
0000000000002C2C2C00002C2C00002C00002C2C2C002C00002C00002C00000000002C00
2C000000002C0000002C0000002C0000000000000000002C002C000000002C0000000000
0000002C00002C2C2C0000000000002C000000002C2C2C2C002C00002C002C000000002C
00002C0000002C00000000002C2C2C2C2C2C2C00002C2C2C2C2C2C0000002C00002C2C2C
0000005F979700002C002C00002C002C2C2C2C2C2C00002C2C2C2C2C2C2C00002C2C0000
2C000000002C00002C2C2C2C2C0000002C000000002C2C2C002C00002C002C0000000000
2C0000002C000000002C2C2C00002C00000000002C002C002C00000000000000002C0000
002C00002C0000002C2C2C2C0000002C0000002C00000000002C0000002C00002C2C0000
000000000000000000000000000000000000002C002C2C2C000000000000002C002C0000
00002C2C00002C0000494949
97C5C597979797C5C55F97979797C55F97975F9797C5C5EFE1E1E1D4D4D497C5C5C5C5EF
A7A7A75F5F975F5F5F5F5F975F97975F5F975F5F97005F5F005F975F5F9749494997975F
979797858585C5975F975F5FC5975F5F5F5F5F5F5F5F5F004949495F5F005F5F5F5F5F5F
5F5F5F4949492C2C2C0073004949495F5F5F5F5F5F005F5F005F005F5F5F5F5F5F5F5F5F
4949495F5F005F5F5F5F975F5F5F5F494949005F005F5F00005F002C2C2C005F005F5F00
002C004949494949492C2C2C4949492C2C2C005F005F5F005F5F5F4949497373735F5F5F
005F005F5F005F5F5F005F004949495F5F5F5F975F4949494949494949495F5F00494949
5F975F5F97005FC59797C5C5FFFFC55F97007373739797975FC597A7A7A75F979797C597
5F975F5F5F5F5F5F5F5F5F5F5F97977373735F975F979797A7A7A79797C5A7A7A75F97C5
A7A7A7A7A7A797C5C597C5C5A7A7A7A7A7A7B6B6B6A7A7A7B6B6B6A7A7A7A7A7A7979797
A7A7A75F97975F97975F97975F97979797975F97975F97975F97975F97978585855F9797
9797975F97979797975F97C59797975F97975F97975F97975F97975F97975F97975F9797
5F97977373737373735F5F975F5F5F005F5F2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C
000000002C00002C00002C000000002C2C2C2C0000002C00002C000000002C0000000000
000000002C002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C000000
002C000000002C2C2C00002C2C000000002C2C0000002C00002C00002C002C0000002C00
002C00002C002C000000002C00002C2C0000002C002C2C2C002C00002C0000002C00002C
2C0000002C002C000000002C2C00000000002C0000002C0000002C002C002C000000002C
2C2C2C2C2C2C0000000000002C2C2C00002C00002C2C000000002C000000002C00000000
0000002C2C2C002C002C2C2C002C000000000000002C000000002C2C2C2C2C2C2C000000
2C000000002C2C2C2C2C2C2C002C000000002C00002C2C2C00000000000000002C00002C
2C2C2C002C0000002C002C00002C002C000000002C002C0000000000000000002C2C2C2C
002C000000000000002C2C2C00002C00002C002C00000000002C00000000000000002C00
0000002C00002C0000002C000000002C000000002C002C00002C002C0000000000000000
00002C000000000000494949
A7A7A797C5C5B6B6B69797C55F97975F97975F97C597C5C5C5EFC5C5C5EFA7A7A797C5C5
5FC5C59797975F975F5F97975F5F5F5F5F5F5F5F97005F977373735F97975F9797A7A7A7
97975FC5975F97975FC5975F73737397975F5F00000049005F00002C2C2C975F00494949
5F5F5F5F5F5F975F5F2C2C2C494949494949494949005F5F494949005F5F005F5F5F5F5F
5F5F5F5F5F5F5F5F5F5F5F5F5F5F004949490049004949492C2C2C494949494949494949
4949492C2C2C0049004949492C2C2C2C2C2C4900000049005F975F5F5F5F5F5F005F5F5F
5F5F004949495F5F005F5F5F5F975F7373735F5F00494949494949005F005F5F5F5F5F5F
5F5F005F975FEFEFEFFFFFEF5F975F5F5F00858585979797B6B6B6A7A7A7C5C5C5979797
5F5F005F5F5F5F5F005F975F5F975F5F979797975FA7A7A7C5C5C5B6B6B65FC5C55F97C5
97C5C55F97C5A7A7A75F97C55FC5C5A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7979797A7A7A7
A7A7A75F97975F97979797975F97975F97975F97975F97975F97975F97975F97975F9797
5F97978585855F97975F97975F97975F97979797975F97C55F97975F97975F97975F9797
5F97975F97975F97970097975F97974949492C2C2C2C2C2C2C2C2C2C2C2C490000002C00
2C0000002C00002C00002C00002C002C0000002C002C2C2C000000000000000000000000
0000002C000000002C49000000002C2C0000002C0000002C2C0000002C00002C002C2C2C
002C002C2C2C002C002C000000000000000000002C2C00000000002C0000002C00002C00
00002C2C2C2C00000000000000002C002C002C2C2C2C00002C2C2C2C2C2C00002C00002C
002C00002C00002C0000002C00002C00000000000000000000002C002C0000002C00002C
002C00002C002C2C2C0000002C000000002C00002C00002C002C002C2C2C002C00000000
00000000002C4900004900000000000000002C000000002C00002C00002C2C0000000000
002C002C00002C2C2C2C2C2C0000002C0000002C0000002C00002C002C002C2C2C2C0000
00002C2C0000002C00002C00002C0000000000002C0000000000000000000000002C2C2C
2C2C2C0000002C000000002C0000002C2C2C0000002C0000002C002C2C2C490000002C00
002C000000000000002C2C2C2C2C2C000000002C0000002C000000002C000000002C0000
2C0000000000002C00494949
97C5C5C5C5EF97C5C5B6B6B65F97975F97C597C5EFB6B6B6C5C5EF9797C5A7A7A7B6B6B6
97C5C55FC5975F975F5F975F5F975F5F5F5F5F5F5F5F97977373735F97975F979797975F
97975FC5975FC5975F97975F975F5F975F005F5F000049004949495F5F5F5F97005F975F
5F5F5F97975F5F5F005F5F5F5F5F00005F002C2C2C4949494949495F5F5F5F5F5F5F5F00
5F5F5F5F975F5F5F005F5F005F5F000049002C2C2C4949495F5F002C2C2C494949005F5F
0049005F5F002C2C2C5F5F004949492C2C2C2C2C2C2C2C2C005F005F5F5F4949495F5F5F
005F004949495F5F5F5F5F5F005F5F2C2C2C005F004949495F5F5F5F5F5F5F5F5F494949
5F975FE1E1E1C5C5EFC597005F5F5F5F5F005F975F5F975F97979797C597A7A7A7B6B6B6
5F5F00737373005F5F5F5F5F5F9797858585A7A7A75F97C59797C59797C59797C55F97C5
9797C55F97C59797C597C5C5A7A7A797C5C5A7A7A7979797A7A7A7A7A7A7979797A7A7A7
9797975F97975F97975F97978585855F97975F97975F97975F97975F5F975F9797009797
5F97975F97975F97975F97975F9797A7A7A79797979797978585855F97975F97975F9797
5F97975F97975F97975F97975F979700975F494949002C002C2C2C002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C002C002C2C2C4900002C2C2C002C000000000000002C0000490000
2C00002C00002C2C2C002C000000002C000000002C002C00002C0000002C002C002C0000
00002C490000002C000000000000002C000000000000002C2C0000002C002C0000002C00
002C00002C002C00002C000000002C2C2C2C00002C2C000000002C2C2C2C0000002C2C2C
002C00002C000000002C2C2C002C002C00000000002C00002C2C2C002C00002C00490000
002C00002C0000002C2C2C2C002C004900002C00002C000000002C2C0000002C00002C00
0000004900002C2C2C002C0000000000000000002C2C00002C000000002C2C0000002C00
2C2C2C002C002C2C2C2C2C2C002C002C0000002C002C2C2C00000000002C002C002C2C2C
002C002C000000002C00002C002C0000000000002C0000000000000000002C00002C2C2C
0000002C000000002C2C000000002C2C2C2C00002C00002C002C002C2C2C002C00000000
0000002C0000002C000000000000000000000000002C0000000000000000000000000000
000000002C00000000005F5F
97C5C5D4D4D497C5C55F979797C5C597C5C597C5C5D4D4D4B6B6B697C5C5B6B6B697C5C5
5F979797C5C55F97975F97975F5F5F5F5F5F7373735F97975F979797C5C5979797C59797
97975FC5975FC5975FC5975FC59797C5975F975F5F4949495F5F5F5F5F5F5F5F5F5F5F5F
5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F005F00494949494949005F5F4949495F975F494949
5F5F005F975F2C2C2C5F5F005F975F5F5F000049002C2C2C005F002C2C2C494949004900
5F5F00005F00005F00494949005F000073004949492C2C2C4949494949495F5F00494949
5F5F00975F005F5F5F5F5F005F5F5F5F5F009797009797007373735F975F5F97005F975F
5F975F97C5EFFFEFC55F975F5F975F5F5F005F5F5F5F975F5F9797A7A7A797C5C55F975F
A7A7A79797977373735F97977373735F97975F9797A7A7A797C5C597C5C597C5C597C5C5
5FC5C55FC5C5A7A7A7979797A7A7A797979797979797975F73737397975F5F97975F9797
A7A7A79797975F97975F97975F97975F97975F97975F97975F97975F97975F97975F9797
5F97975F97975F97975F97978585855F97975F97979797979797975F97975F97975F9797
5F97975F97975F97975F97975F5F975F979700975F4949494949492C2C2C2C2C2C2C0000
002C0000002C5F97972C00002C2C2C00002C002C00002C0000000049000000002C00002C
2C2C2C2C2C2C00002C00002C0000000000002C2C2C002C000000002C2C2C000000000000
002C002C00002C2C2C00002C2C2C2C00002C002C00002C0000002C002C00002C002C2C2C
2C0000002C00002C0000002C0000002C2C2C2C000000002C00002C002C0000002C002C00
0000002C00002C000000002C002C000000002C0000002C002C2C2C002C00002C00002C00
2C00002C2C2C002C002C2C2C002C00002C002C0000002C0000002C2C2C2C002C00002C00
002C0000002C2C2C2C00002C00002C2C2C2C002C0000002C2C2C2C2C2C2C2C2C2C2C2C2C
00002C2C0000002C002C0000002C00002C00002C00002C0000002C2C2C2C002C00002C00
002C0000002C2C2C2C2C2C2C2C2C2C00002C0000000000002C00002C2C2C00002C00002C
002C00002C0000002C2C000000002C5F5F5F0000002C2C2C002C00002C00000000000000
000000000000002C00000000490000002C002C0000002C0000002C00002C2C2C2C2C2C2C
00002C000000000000494949
C5C5C5C5C5C55F97975F9797B6B6B6C5C5C5C5C5C5C5EFEFD4D4D497C5C5C5C5C5A7A7A7
5FC5C5A7A7A79797975F5F977373735F975F7373735F97975F979797C5C5737373005F5F
73737397975FB6B6B6EF975FC5975FC5975F97975F97975F5F975F4900005F5F005F5F00
5F975F975F5F97975F5F975F5F975F005F5F005F5F5F5F005F5F5F5F5F5F5F975F494949
5F975F5F5F5F2C2C2C5F5F5F4949495F5F005F5F004949494949495F5F004949495F5F00
4949492C2C2C005F002C2C2C4900004949494949494949494949495F5F005F5F005F5F5F
4949494949494949495F5F5F5F975F7373735F5F5F5F5F005F5F5F5F97005F5F005F975F
EFFFEFFFFFFF5F5F005F5F5F5F97005F975F97C5975F975F5F979797975FA7A7A7C5C597
A7A7A7A7A7A7005F5F5F97975F5F5F5F5F5FA7A7A7A7A7A797979797C5C597C5C597C5C5
5F97C55F97C5A7A7A79797975FC5C55F975F85858597975F7373737373735F97975F975F
8585855F97975F975F8585855F97975F97975F97977373735F97975F97975F9797005F97
5F97975F97975F97975F97975F97975F9797A7A7A75F97979797979797975F9797009797
5F97975F97975F97979797975F97975F9797737373005F5F4949492C2C2C2C2C2C2C0000
2C2C2C4900002C2C2C2C2C2C00002C000000000000002C002C2C2C002C002C2C2C2C2C2C
2C2C2C00002C0000002C2C2C2C00002C2C2C002C00002C00002C002C2C2C0000002C0000
2C2C2C002C002C2C2C002C000000000000002C2C2C00002C2C00002C0000002C00000000
002C00002C00002C002C2C2C002C002C0000002C002C00000000002C2C2C00002C000000
0000002C2C2C00002C49000000002C00002C002C00002C002C2C2C2C0000002C002C0000
00002C2C2C2C2C2C2C2C000000002C002C00002C00002C002C2C2C2C2C2C0000002C0000
00002C2C2C2C2C2C2C00002C002C004900002C2C2C2C2C2C2C2C2C2C2C2C002C00002C00
00000000002C2C0000002C00002C00002C00002C00002C002C00002C2C2C2C2C2C2C2C2C
002C002C2C2C2C2C2C000000002C00002C0000000000000000002C002C00002C002C2C2C
002C0000000000002C00002C00000000000000000000002C000000000000000000000000
00000000000000000000002C0000002C000000002C00002C002C00002C000000002C0000
0000005F5F002C0000494949
5F9797B6B6B697C5C5C5EFEFFFEFEFEFEFEFFFEFC5FFC5EFC5C5EF97C5C5C5C5EFA7A7A7
5F97975F979797C5C5A7A7A75F5F5F5F5F975F5F975F97975F979797C5C5005F5F5F5F5F
A7A7A7C5C55FC5C597EFC5C5C5975FC5975FC5C55F97975F8585855F5F004949495F5F00
7373735F5F005F5F5F975F5F5F975F97975F005F5F2C2C2C5F5F5F005F5F4949495F5F5F
5F5F005F5F00494949494949005F5F5F5F5F4949495F5F005F5F002C2C2C4949492C2C2C
005F004949492C2C2C2C2C2C2C2C2C005F5F005F00494949494949005F000049005F5F00
4949494949492C2C2C5F5F5F5F5F5F5F5F5F5F975F9797005F97005F97005F975FA7A7A7
97C5EFC5975F5F5F5F5F5F5F4949494949495F5F5F7373735FC59797979797975F737373
979797737373005F5F7373735F975F5F5F5F858585A7A7A797979797C5C5B6B6B69797C5
A7A7A797C5C5A7A7A7A7A7A7A7A7A7A7A7A78585855F5F5F7373735F5F5F5F9797737373
5F5F5F7373735F975F5F97979797975F97975F5F975F97975F97975F97975F97975F9797
5F97975F97975F97970097975F97975F97975F97975F97979797975F97975F97975F9797
5F97975F97975F97975F97975F97978585855F97975F5F5F5F975F005F5F002C002C2C2C
2C2C2C00002C002C002C2C2C0000002C00002C00000000000000002C2C2C002C00002C00
2C2C2C000000002C002C2C2C2C2C2C002C00002C00002C002C2C2C2C2C2C2C2C2C2C2C2C
00002C2C2C2C0000002C00000000002C2C2C2C00002C0000002C002C00004900002C0000
002C00000000002C002C2C2C2C2C2C002C002C000000002C2C00000000002C2C2C2C0000
2C2C2C00002C2C000000002C000000490000002C002C000000002C000000000000002C00
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C0000002C002C0000002C002C0000002C00
2C2C2C002C0000002C00002C49000000002C2C00002C00002C2C2C2C2C2C0000002C0000
2C000000002C002C002C2C2C2C2C2C002C002C0000002C00002C002C2C2C2C2C2C2C2C2C
2C2C2C00002C2C2C2C2C2C2C0000000000000000000000000000002C2C2C002C0000002C
002C002C0000000000000000002C00000000002C00494949002C0000002C000000000000
2C2C2C002C0000002C2C000000002C0000000000000000002C2C2C2C000000002C000000
00002C000000000000494949
5F97975F9797C5C5C5E1E1E1EFEFEFE1E1E1E1E1E1E1E1E1C5C5C55FC5C5B6B6B697C5C5
009797B6B6B65F979773737300975F009797005F5F5F975F737373A7A7A700975F5F9797
5FC59797C597B6B6B6EFC5C5EF9797C5975FC5975F97975F85858597970097975F5F5F5F
5F5F0097975F975F5F975F5F97975F5F975F005F5F004900005F004949492C2C2C494949
4949494949492C2C2C005F00494949494949494949005F000073004949492C2C2C005F00
4949494949494949492C2C2C005F002C2C2C005F005F5F002C2C2C2C2C2C494949005F00
5F5F5F494949005F005F975F5F5F5F5F5F005F975F5F975F97975F5F975F737373C5EFEF
FFFFEF7373735F5F005F5F5F5F5F00005F005F5F5F9797979797975F5F5F5F975F5F9797
005F5F7373735F97C5A7A7A77373738585855F97C59797979797C597C5C597C5C5B6B6B6
A7A7A7A7A7A7A7A7A7A7A7A7A7A7A78585858585855F97975F97975F975F5F979797975F
5F9700005F5F5F5F5F8585857373735F975F5F979700975F0097975F97975F97975F9797
5F5F975F97970097975F97975F97975F9797979797A7A7A7A7A7A7A7A7A75F97975F9797
8585855F97975F97975F97975F97979797975F97977373735F9797005F5F2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C002C002C00002C2C2C2C2C2C2C2C2C5F5F5F2C2C2C002C00002C00
002C00002C004900002C00000000002C2C2C002C002C2C2C2C2C2C2C2C2C002C0000002C
2C2C2C00002C002C00002C00002C002C2C2C002C00002C002C2C2C002C00002C002C0000
002C0000002C00002C00002C0000000000002C000000000000002C2C000049000000002C
2C2C2C0000002C2C2C2C2C2C002C00002C002C2C2C002C00002C00000000000000002C00
00000000002C00002C2C2C2C000000000000000000000000002C002C00000000002C0000
00002C2C2C2C00000000002C00002C002C00002C00002C00002C00002C00002C00002C00
2C2C2C2C2C2C2C2C2C2C2C2C4900002C0000002C004900002C000000002C2C2C2C2C2C2C
0000002C000000002C00002C000000000000000000002C002C00002C2C2C00002C002C00
002C00002C002C2C2C2C00002C2C2C2C2C2C2C2C2C002C00002C00002C00002C00000000
2C000000002C0000002C2C2C0000002C0000002C00494949002C000000000000002C0000
000000002C002C0000494949
5F97C5B6B6B6C5C5C5D4D4D497C5C5E1E1E1E1E1E1EFEFFF97C5EFC5C5C5C5C5EF97C5C5
5F97C5B6B6B60097970097977373735F5F5F4949495F5F5F5F5F5F97C5C5737373009797
B6B6B6C5C5C5EFC5C5EFC5C5EFC597EFC597C5975F975F5F97975F97975FC5975F5F5F5F
5F5F5F5F5F005F5F00975F00975F5F5F5F5F494949005F004949492C2C2C5F5F005F5F00
494949005F005F9700005F00494949494949494949005F5F4949494949492C2C2C005F5F
2C2C2C005F002C2C2C4949494949495F5F005F5F002C2C2C005F004949490000492C2C2C
5F5F004949495F5F005F5F005F5F5F4949495F5F5F5F5F005F97005F975FEFEFC5C5EFFF
97975F5F97005F5F005F975F5F975F5F5F005F5F5F005F5F97C597494949494949494949
5F97979797979797C597C5C59797975F9797C5C5C5A7A7A7A7A7A75F97C597C5C597C5C5
9797C55FC5C597C5C597C5C59797979797975F97975F97979797975F5F5F4949495F5F5F
7373737373735F5F5F73737373737397975F5F97975F975F0097975F97975F97975F975F
5F97970097975F9797005F970097975F97975F97C55F97979797979797975F97975F9797
5F97975F97975F97975F97C55F97975F97975F97975F97975F97975F975F005F5F494949
2C2C2C2C2C2C2C2C2C4900002C2C2C2C2C2C002C00002C00002C00000000490000002C00
002C0000002C002C002C00004900002C00002C2C2C2C2C2C2C2C2C00002C00002C2C2C2C
2C2C2C2C2C2C002C00002C00002C0000002C0000002C00002C2C2C000000002C002C0000
002C00002C00002C000000000000000000002C00000000002C000000002C00002C000000
000000002C00002C00002C00002C0000002C00002C0049002C00002C000000002C00002C
002C0000002C2C2C2C2C2C2C000000002C00000000000000002C000000002C2C2C2C0000
00002C002C002C00002C00002C2C2C002C00002C002C2C2C2C2C2C002C00000000000000
00000000000000002C00000000002C00002C2C000000002C000000000000002C002C2C2C
002C0000000000002C002C000000000000000000002C000000000000002C00002C002C00
2C0000000000002C00002C002C2C2C002C002C2C2C2C2C2C00002C000000000000000000
00000000002C002C00002C005F5F5F2C2C2C00002C002C00002C0000002C2C00002C0000
00002C2C0000002C00494949
979797C5EFFF97C5C59797C597C5C5D4D4D4E1E1E1E1E1E1C5EFC5C5C5C597C5C5B6B6B6
0097975F97975F9797009797005F5F5F5F5F5F5F5F5F97975F5F975F97970097975F97C5
C5C5C5C5C597C5975FEFC597C5C5C5EFC55FC5C59797975F5F5F5F975F5F979700975F5F
2C2C2C5F5F005F5F5F5F5F5F5F5F00737373005F002C2C2C4949494949495F5F00494949
494949005F005F5F00005F00494949494949494949005F5F494949005F004949492C2C2C
4949494949495F5F5F494949494949494949005F5F4949492C2C2C5F5F00494949494949
4949495F5F5F5F5F00005F5F5F5F5F7373735F5F5F5F5F5F5F975F5F9797C5C5EFC5C55F
975F5F5F975F5F97005F5F5F5F975F5F975F5F5F5F4949495F5F5F5F5F5F005F5F5F5F5F
5F97979797975F5F5F9797C597C5C597C5C5A7A7A797C5C5A7A7A797C5C59797C597C5C5
97C5C5A7A7A7B6B6B6A7A7A797C5977373738585857373735F975F005F5F5F975F5F5F00
4949495F975F5F975F5F5F5F5F5F5F5F5F5F5F975F858585005F975F975F5F97975F9797
5F975F0097975F97975F97975F97975F97975F97C5A7A7A79797979797975F97975F9797
5F97C5A7A7A75F97C55FC5975F97C59797C55F97975F5F975F97975F9797005F5F005F5F
0049002C2C2C002C00002C002C2C2C2C00002C0000002C0000002C00002C00002C2C2C2C
002C002C2C2C0000002C000000002C2C2C2C2C2C2C00002C2C2C2C00002C2C2C2C00002C
2C00002C2C2C002C00002C00002C00002C00002C00002C00002C002C00002C2C2C2C2C2C
2C0000000000002C00002C000000000000002C000000002C00000000000000002C2C0000
2C000000002C0000000000002C0000002C00002C00C5C5975F5F5F00002C000000000000
0000002C00002C2C2C00002C2C2C2C00002C2C00000000000000002C000000002C002C00
00002C002C00002C002C00002C2C2C2C2C2C00002C2C0000002C000000002C2C2C2C2C2C
002C00002C002C2C2C000000490000002C00490000002C00000000000000002C002C2C2C
00002C2C000000000000000000000000000000000000002C0000000000002C2C2C2C2C2C
002C00002C000000002C2C2C00002C2C0000002C002C2C2C2C2C2C0000002C000000002C
0000002C2C2C002C00002C0000002C00000000002C2C000000002C2C2C2C2C2C2C2C2C2C
000000000000002C00494949
97C5C5C5C5C55FC5C597C5C5D4D4D4C5C5C5C5EFEFE1E1E1C5C5EFB6B6B65FC5C55F9797
5F97979797C55F97975F97975F5F5F005F5F5F5F5F5F5F5F0097975F97975F9797B6B6B6
A7A7A7858585B6B6B6EFEFC5C5EFC5C5EFC5C5C597C5975FC5975F979797737373975F5F
4949495F0000975F5F0073005F5F5F5F5F00005F5F4949495F5F5F5F5F5F494949494949
005F004949495F5F5F005F00005F00494949005F002C2C2C5F5F004949492C2C2C004900
0049004949495F5F005F5F004949494949494949495F5F5F5F5F5F494949005F005F5F00
0049005F5F5F5F5F005F975F5F5F5F737373975F5F97975F97975FC5C5C5FFEFC55F975F
737373005F5F5F5F5F5F975F5F975F5F975F005F004949495F5F5F5F975F5F5F5F494949
5F5F5F5F97975F97C5979797A7A7A7A7A7A7858585A7A7A797C5C5979797C5C5C597C5C5
B6B6B697C5C59797975F97975F97975F975F5F97975F975F5F5F5F5F5F5F5F975F5F975F
5F5F5F5F975F5F975F73737397975F5F5F5F975F5F7373738585855F97975F97975F9797
5F97975F97975F97975F97975F97C55F97C597C5C55F97C5979797A7A7A75F97975F9797
5F9797A7A7A7979797A7A7A79797975F97C55F97978585855F97975F97975F97975F9797
005F5F2C2C2C002C00002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00
00000000002C2C0000002C0000002C2C00000000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
00002C2C00002C2C2C2C2C2C002C002C00002C00002C000000002C002C00002C002C2C2C
2C2C2C490000002C0000002C0000002C00002C2C2C2C000000002C000000000000002C00
002C000000002C00000000002C0000002C002C000000002C2C0000002C00000000000000
00002C49000000002C2C000000002C00002C002C002C00002C000000002C2C2C2C2C2C2C
00002C2C000000002C002C002C2C2C2C000000002C00002C2C2C2C2C2C2C002C002C2C2C
2C2C2C2C2C2C002C00002C00002C00002C00002C00002C00000000000000002C002C2C2C
00002C00002C2C2C2C2C000000000000000000000000002C0000000000002C2C2C2C2C2C
000000490000002C0000002C00002C2C0000002C002C2C2C00002C2C000000002C000000
2C00002C2C2C002C002C0000002C00002C002C2C2C002C002C2C2C00002C002C0000002C
0000002C2C2C002C00494949
5F97975FC5C5A7A7A7979797C5C5EFC5C5EFD4D4D4E1E1E197C5EF97C5C50097C59797C5
5F979797C5C55F97C58585855F5F5F5F5F5F5F5F5F5F975F005F5FA7A7A7A7A7A75F97C5
5F97C597975F97C5C597C5C5B6B6B6EFC5C5C5C597C5975FC5975F85858597975F737373
97975F97970097975FEFEFC55F975F5F975F494949494949005F5F005F5F494949494949
4949494949494949495F5F002C2C2C2C2C2C494949005F5F494949005F00004900004900
005F00494949005F004949494949495F5F5F4949492C2C2C2C2C2C494949494949004900
002C00005F005F5F005F5F5F5F975F5F975F5F975F5F5F5FC5EFC5C5EFEF5F5F5F5F5F5F
5F5F00005F5F5F5F5F5F975F5F5F5F5F5F004949494949495F5F005F5F5F5F5F5F858585
005F5F5F5F5F5F97979797C597975F5F5F5F9797975F97C597C5C597C5C597C5C5C5C5C5
97C5C5A7A7A79797975F97979797978585858585855F5F5F858585005F5F5F5F5F5F5F5F
5F975F97975F5F975F5F975F5F975F5F975F975F5F73737373737300975F005F5F5F9797
005F978585857373735F97975F97975F97975F97975F97975FC5C55F97C55F97975F9797
5F97C55F97C55FC5C55F97C55F97975FC5975F97975F97975F97975F97975F97975F9797
4949492C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00
2C00002C2C2C002C00002C0049000000002C00002C002C00002C002C2C2C00002C002C00
2C2C2C002C0000002C00002C2C0000000000000000002C000000002C2C2C2C2C2C2C0000
002C00002C0000002C002C002C2C2C2C2C2C00002C2C00002C2C2C00002C2C0000002C00
2C0000002C002C2C2C0000002C2C2C2C0000002C002C2C2C2C0000002C000000002C0000
00002C2C000000000000002C00002C2C2C2C00002C002C002C000000002C002C00002C00
002C0000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C0000000000002C0000002C00002C00002C0000002C2C2C2C
002C0000002C00002C00002C0000000000000000000000000000002C000000000000002C
2C2C2C0000002C2C2C00002C2C2C2C002C00002C0000000000002C2C2C2C2C00002C0000
00002C2C0000002C00002C000000002C2C2C002C00002C0000002C2C2C2C2C2C2C002C00
0000002C0000002C00494949
5F97C59797C5C5C5C55F97C597C5C5C5C5EFD4D4D4D4D4D497C5C597C5C50097C597C5C5
5F97975F9797A7A7A79797975F5F5F4949495F9797005F5F5F97C55F97975F9797979797
97C5C59797C5C5C5C5C5EFC5B6B6B6FFEFC5B6B6B6C5C5979797975F97975F5F5F858585
A7A7A75F5F005F5F00C5C5C5C5C5C55F5F00004900494949494949005F004949492C2C2C
005F00005F002C2C2C2C2C2C0049002C2C2C4949494949495F5F004949494949492C2C2C
2C2C2C4949492C2C2C494949494949007300494949005F005F5F00002C002C2C2C002C00
002C005F5F5F5F5F5F5F5F00494949005F5F005F00A7A7A7C5C5C5C5C5975F5F5F494949
5F5F5F005F00005F00005F5F5F5F000073004949495F5F5F5F5F5F5F975F5F5F5F5F975F
737373A7A7A7A7A7A797979773737373737397C5C55F97C59797C5A7A7A7C5C5C5C5C5C5
A7A7A7979797979797A7A7A7A7A7A79797975F97975F975F7373735F5F5F5F975F5F5F5F
5F975F7373735F5F5F5F975F5F5F5F7373737373735F5F5F5F975F7373735F97975F975F
5F97975F97975F97975F97975F97975F97C55F97C5A7A7A75F97975F97975F97975F9797
5F97C597C5C55F97C55FC5C55F97C5A7A7A7A7A7A75F97975F97975F97975F97975F9797
00975F5F5F5F2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C002C00002C00000000
2C00002C00002C2C2C002C00002C000000000000002C2C2C002C00002C0000002C2C2C2C
2C2C2C2C2C2C2C2C2C00002C00002C0000000000000000002C000000002C002C002C2C2C
2C00002C2C2C490000002C002C0000002C002C0000002C00002C002C2C2C002C002C2C2C
00002C2C2C2C00002C0000000000000000002C2C2C00002C2C000000000000000000002C
49000000002C00002C00002C490000002C00002C00002C0000002C00000000000000002C
0000002C00002C2C2C002C0000002C0000002C000000002C00002C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C0000002C000000002C000000002C00002C2C2C2C49000000002C2C2C2C
00002C00002C00002C00002C00002C2C2C2C00002C000000000000002C002C2C2C2C2C2C
2C2C2C00002C2C2C2C00002C2C2C2C2C2C2C002C002C00002C2C2C002C00002C002C2C2C
00000000000000002C0000002C0000002C002C2C2C2C0000002C00494949002C0000002C
2C000000002C2C0000494949
B6B6B69797C5B6B6B65F97C55F97C5C5C5C5C5C5C597C5EF0097C55F97C55F97975FC597
5F97C55F9797A7A7A7005F5F005F5F005F5F005F5F005F97005F97005F9700979797C5C5
C5C5C5B6B6B6B6B6B6C5C5C5FCFCFCFFC5C5C5C597C5C55FC59797C5975F97975F979797
975F00EF975FEFEFC5C5C5C5D4D4D45F5F005F975F4949494949495F5F5F5F5F5F5F5F00
5F5F5F4949495F5F002C2C2C2C2C2C4949490049002C2C2C005F00005F002C2C2C004900
4949492C2C2C4949494949495F5F5F494949494949005F005F5F002C2C2C2C2C2C490000
002C0097975F005F004949494949494949495F975F97C5C5FFC5C55F5F5F4949495F5F00
005F005F5F5F4949495F5F5F5F5F004949495F5F5F5F5F5F5F5F5F5F5F004949495F5F5F
5F975F5F5F5F737373A7A7A75F97975F5F5FA7A7A797979797C5C597C5C55F97975F97C5
5FC5C59797979797975F97979797975F97C597975F5F975F5F5F00005F5F005F5F5F975F
005F5F5F975F4949495F5F5F5F5F5F5F975F5F5F5F5F975F5F975F5F975F5F5F97009797
5F97970097975F97975F97975F97975F97975F97975F97975F97975F97975F97975F97C5
5F97C55F97C55FC5C55F9797A7A7A75F97C55F9797A7A7A75F97975F97975F97975F9797
7373737373734949492C2C2C2C2C2C002C00490000002C00002C00002C000000002C0000
2C2C2C2C2C2C002C00002C00490000002C00002C002C2C2C000000002C002C0000002C00
002C0000002C0000002C2C2C5F9797002C0000002C000000000000002C0000002C2C2C2C
002C002C0000002C000000002C2C2C0000002C000000002C0000000000002C2C2C2C2C2C
002C002C2C2C0000000000000000002C0000002C002C000000000000000000000000002C
00002C00002C00000000002C0000002C00002C2C2C002C002C2C2C0000002C00002C2C2C
00002C00002C2C2C2C2C000000002C0000000000002C2C2C2C2C2C2C2C2C2C2C2C00002C
2C0000002C0000000000000049000000002C00002C002C002C2C2C00002C2C2C2C00002C
2C2C2C00002C2C0000002C002C0000002C000000000000002C000000002C00002C00002C
00002C00002C00002C2C2C2C002C002C2C2C2C0000002C00000000002C00000000000000
2C000000000000000000000000002C2C2C2C2C2C2C002C0000002C2C0000002C002C0000
002C002C0000002C00494949
C5C5EF9797C597C5C55FC5C55F97C597C5C597C5C5C5C5C50097C55FC5C597C5C500C5C5
5F97975F97C55F979700975F005F5F494949005F5F00975F005F970097979797975F9797
A7A7A7A7A7A797C5EFE1E1E1EFEFEFB6B6B6C5C5C5EFC5C5C5C55FA7A7A7C5C59797C597
975F5FC5975FC5C5C5D4D4D4E1E1E15F5F5F975F5F005F5F0073005F5F5F5F5F005F975F
5F5F5F494949005F002C2C2C494949005F5F2C2C2C4949494949492C2C2C2C2C2C005F5F
0049002C2C2C2C2C2C2C2C2C005F002C2C2C494949494949005F5F4949492C2C2C2C2C2C
002C002C2C2C4949494949492C2C2C005F00B6B6B6EFFFEF5F5F5F005F5F5F5F5F494949
494949494949494949494949494949494949494949005F5F5F5F5F5F5F5F494949005F5F
005F5F494949494949005F5F5F97975F979785858597C5C597979797C5C55F97C55F97C5
5F97975F97979797C55FC5C55F979797C5C5979797737373005F5F5F975F5F975F5F975F
5F975F5F975F5F5F005F5F5F5F5F5F5F975F5F975F5F5F5F5F975F5F975F737373737373
5F9797005F975F97975F97975F97975F97975FC5C55F97975F97975F97970097975FC5C5
9797C55F97C55F97C55F97C597C597979797A7A7A75F97975F97975F97975F97975F9797
5F5F975F9797005F5F4949494949492C2C2C2C2C2C002C00002C002C2C2C0000002C0000
002C002C2C2C00002C002C00002C00002C002C2C2C002C000000002C2C2C00002C000000
0000002C2C2C2C2C2C2C000049494900002C2C2C2C00002C0000002C00002C0000002C00
2C2C2C2C0000002C00002C002C2C2C0000002C000000002C0000000000002C2C2C2C2C2C
2C2C2C2C0000002C0000002C00002C00002C2C000000002C0000000000000000002C0000
00002C2C2C2C2C00002C2C2C00002C002C00002C00002C00002C002C000000002C002C00
00002C002C002C2C2C2C2C2C00002C2C0000002C002C2C2C2C2C2C2C2C2C00002C490000
002C004900000000002C2C2C2C2C2C2C2C2C00002C2C2C2C002C002C2C2C00002C2C2C2C
2C2C2C0000000000002C2C2C2C2C2C2C2C2C00002C2C2C2C002C00002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C00002C2C00002C00000000000000002C0000
002C00002C002C2C2C49494900002C002C002C2C2C2C2C2C2C000000002C000000000000
0000002C2C2C2C0000494949
C5C5C597C5C597C5C55F97C55F97C59797C597C5C597C5C5A7A7A75F97C597C5C55F97C5
5F97C55F97975F97975F5F5F005F5F009797005F5F0097975F97970097975F979797C5C5
5F979797C5C5C5C5C5FFEFEFE1E1E1C5C5C5B6B6B6C5C597C5C597979797A7A7A797975F
97975FB6B6B6B6B6B69797979797975F975F975F5F5F5F5F5F5F5F5F975F005F5F97975F
4949494949490049004949490049005F5F00005F000049002C2C2C2C2C2C005F002C2C2C
494949005F5F494949005F00005F004949494949492C2C2C0049002C2C2C0049002C0000
005F00002C000049002C2C2C005F00005F5FC5C5C5C597004949494949492C2C2C004900
4949490049002C2C2C2C2C2C2C2C2C2C2C2C4949492C2C2C5F5F004949494949492C2C2C
494949494949005F5F5F975F737373A7A7A70097975F979797C5C5C5C5EF97C5C5858585
5F9797A7A7A7A7A7A79797979797979797977373737373734949495F5F005F5F5F5F5F5F
975F5F5F975F5F975F5F975F5F975F5F975F5F5F5F5F5F5F5F975F5F970097975F5F5F97
5F97975F97975F97975F97975F97975F97975F97975F97975F97970097975F9797979797
5FC5C55FC5C55F97C597C597A7A7A7A7A7A797C597A7A7A75F97975F97979797975F9797
5F97975F97970097975F5F5F00002C2C2C2C002C002C2C2C002C002C2C2C000000000000
002C002C2C2C000000002C00002C002C00002C2C2C002C002C000000002C0000002C0000
2C0000002C00002C002C000000002C000000000000000000000000002C00002C00002C00
002C0000002C000000000000000000002C00000000000000002C002C00002C2C2C490000
002C00002C0000002C2C0000000000002C0000002C00002C2C000000000000002C00002C
2C2C2C2C2C2C2C2C2C2C000000002C0000000000000000002C0000000000000000002C00
002C0000002C2C2C2C00002C00002C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00
00000000000000000000002C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C49000000002C
2C2C2C002C000000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C
2C2C2C85858500002C002C0000002C2C2C2C002C00002C002C000000002C000000000000
002C002C2C2C2C2C2C4949490000002C2C2C2C2C2C002C002C2C2C2C2C2C00002C000000
2C000049000000002C005F5F
C5C5C597C5C597C5C55F97C597C5C59797C55FC5C5C5C5EF5F97C55F97975F97970097C5
5F97975F97975F9797005F97009797009797005F975F97975F9797005F5F5F979797C5C5
5FC5C5C5C5EF97C5C5C5EFEF97C5EFD4D4D4FFEFC5C5C597C5C55F97979797975FC55F00
C597975F5F5F5F5F5F4949494949495F975F5F975F5F5F5F4949495F5F004949495F9700
005F5F4949495F5F002C2C2C2C2C2C005F004949492C2C2C2C2C2C4949490049005F5F00
0049005F5F002C2C2C2C2C2C005F00005F004949494949492C2C2C2C2C2C2C2C2C5F5F00
2C2C2C4949492C2C2C4949492C2C2CC5C5C5FFEFEF5F5F004949490000492C2C2C2C2C2C
4949494900004949492C2C2C494949494949494949494949005F00005F005F5F005F5F5F
4949494949494949495F5F5F9797977373735F97C5A7A7A7B6B6B6B6B6B6A7A7A75F9797
A7A7A7A7A7A7858585A7A7A7A7A7A75F97977373737373735F5F5F5F5F5F5F97005F975F
97975F5F5F004949495F975F4949495F5F5F5F5F5F5F5F5F5F975F5F975F5F5F5F5F9797
009797009797009797009797A7A7A75F97C55F97975F97975F97975F97975F97975FC5C5
5F97C55F97C55F97975F97C55FC5C55F97C5A7A7A7A7A7A75F97975F97C55F97975F97C5
5F97975F97975F5F975F5F5F4949490049002C2C2C002C002C0000002C002C0000002C00
002C002C2C2C000000002C00002C000000002C2C2C00002C00002C00002C2C2C2C2C0000
002C00000000002C002C2C2C2C2C2C00002C002C0000002C2C0000002C002C0000002C00
0000002C2C2C002C0000002C2C0000002C00002C002C00002C000000002C000000002C00
002C002C2C2C00002C00002C002C000000002C2C2C2C2C2C0000002C000000002C000000
0000002C2C2C2C2C2C00002C0000000000002C0000490000002C00002C00002C002C2C2C
00000049000000002C00002C000000002C00002C002C0000002C002C0000002C002C2C2C
000000002C000000002C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C00002C00002C002C00
002C004900002C000000002C2C2C2C2C2C2C00002C2C2C2C490000002C00002C00002C00
490000002C002C00002C2C2C00002C2C00002C0000002C0000002C0000002C00002C0000
2C000000002C00002C00002C2C00002C2C2C00002C00002C002C002C2C2C2C2C2C002C00
002C00002C0000002C494949
B6B6B69797C5C5C5EFA7A7A79797C55F97C597C5C5C5C5EF97C5C50097C55F9797009797
5F97975F97975F979700975F5F97975F97C55F97970097975F975F5F97975F979797C5C5
C5C5EFB6B6B6EFC5EFD4D4D497C5EFB6B6B6EFC5C5C5C597EFC59797975F975F00975F00
975F005F5F5FB6B6B65F5F004949495F5F5F2C2C2C5F5F5F4949494949494949495F975F
2C2C2C5F5F004949492C2C2C2C2C2C4949494949492C2C2C2C2C2C0000494949495F5F5F
5F5F5F5F5F5F4949494949494949492C2C2C005F5F4949492C2C2C2C2C2C494949002C00
2C2C2C002C000049002C2C2C97C5C5D4D4D45F5F5F0049002C2C2C005F002C2C2C2C2C2C
2C2C2C4949494900002C2C2C2C2C2C2C2C2C002C004949495F975F5F5F002C2C2C004900
494949737373975F5F5F9797005F5FA7A7A797C5C55F5F97A7A7A7858585858585858585
97979797979797C5C59797975F97975F97975F5F5F5F975F73737300975F494949494949
2C2C2C5F5F5F5F5F5F5F975F5F5F5F5F5F5F5F975F5F5F5F4949495F9700737373005F97
00975F005F970097975F97975F97975F97975F9797005F975F97975F97C59797975F9797
9797975FC5975FC59797C5C55F97C597C5C5A7A7A75F9797A7A7A75F975F5F9797858585
5F97975F97975F5F975F5F97005F5F4949492C2C2C2C2C2C0049002C00002C2C2C00002C
00002C000000000000000000000000002C002C2C2C002C002C2C2C00002C2C2C2C00002C
00002C2C0000002C00002C002C2C2C2C2C2C2C2C2C002C00002C002C00000000002C2C2C
2C2C2C2C2C2C2C0000002C0000002C2C0000002C00002C002C2C2C002C002C0000002C00
2C000000002C000000002C002C000000002C00002C2C2C2C000000002C002C2C2C002C00
2C000000002C00002C00000000000000002C00002C00000000002C2C2C2C002C00490000
2C2C2C00002C0000002C0000490000002C002C0000002C00002C00002C004900002C2C2C
49000000002C4900002C2C2C2C2C2C2C2C2C002C0000002C2C2C2C2C2C2C2C2C2C2C2C2C
975F5F5F97972C2C2C00002C490000002C0000000000002C0000002C00000000002C2C2C
00002C002C00002C00000000002C00002C002C2C2C2C000000002C002C0000002C00002C
2C00000000002C00002C2C2C2C2C2C002C002C000000000049000000002C490000002C00
2C00004900002C2C2C494949
C5C5EF97C5C597C5C597C5C597C5C5B6B6B697C5C5D4D4D49797C597C5C55F97C55F9797
97C5C597C5978585855F5F5FA7A7A75F97975F97975F5F975F5F97005F5F5F97C59797C5
97C5C5C5C5EFE1E1E1C5EFEFC5EFC5C5C5C5EFEFC5B6B6B6EFC59797979797975FA70000
975F00C55F00B6B6B697979797975F9797005F5F5F5F5F5F005F002C2C2C494949494949
2C2C2C5F5F005F5F005F5F5F494949005F5F5F5F5F005F5F5F5F00005F004949495F9700
5F5F5F5F5F002C2C2C0049005F5F004949495F5F005F5F005F5F002C2C2C002C00494949
2C2C2C002C002C2C2C005F5FC5C5C5EFC597005F5F5F5F004949495F5F002C2C2C2C2C2C
2C2C2C4949492C2C2C00002C2C2C2C2C2C2C2C2C2C005F5F5F5F5F7373737373735F5F00
5F5F005F975F5F5F5F8585859797C5B6B6B697C5C55F9797A7A7A75F5F975F97975F9797
5F97978585859797979797975F97975F975F5F97975F97975F97975F97975F5F5F494949
005F5F4949495F5F5F5F5F5F5F5F5F005F5F5F5F005F5F5F5F5F5F5F5F5F5F975F494949
005F5F5F5F5F5F97970097975FC5C55F97C55F97975F97975F97979797975F97975FC5C5
5F97C55F97975F979797979797C5C597C5C5979797A7A7A75F97C55F97975F97975F9797
5F97975F97975F97975F979700975F005F5F002C004949492C2C2C2C2C2C2C2C2C2C2C2C
00002C00000000000000000049000000002C00002C2C2C2C2C2C2C002C00002C002C2C2C
002C00000000490000002C00002C000000000000002C0000002C00002C002C2C2C002C00
2C0000002C00002C00002C00002C0000002C002C002C2C2C002C002C00002C0000002C00
00002C002C0000002C0000002C000000002C002C002C00002C2C2C002C0000002C000000
2C000000002C002C00000000000000000000002C002C2C2C2C2C2C00002C00002C00002C
2C2C2C00002C2C000000002C00002C2C2C2C2C2C2C002C00002C002C2C2C2C2C2C2C0000
0000002C2C2C00002C00002C2C2C2C2C2C2C2C2C2C00002C2C00002C2C2C00002C00002C
2C2C2C2C2C2C002C002C2C2C002C00002C002C00002C2C2C002C002C00000000002C2C2C
002C00002C00002C000000002C0000002C002C000000000000002C00002C00002C00002C
00000000002C002C002C00002C2C2C0000002C00000000000000002C2C2C002C002C2C2C
00002C2C2C2C2C2C2C5F005F
C5C5C597C5C597C5C597C5C5C5C5EFB6B6B697C5C5E1E1E1C5C5C5C5C5EF97C5C5009797
97C5C55F979797C5C55F97C50097975F979700975F0097975F9797005F5F5F97C5C5EFEF
C5EFEFD4D4D4D4D4D4EFEFC5C5C5EF97C5C5B6B6B6C59797EF9797C5975FC5975F975F5F
975F5FC5975FC5975F85858597975F5F5F5F5F975F5F975F4949492C2C2C4949492C2C2C
2C2C2C5F5F005F5F5F4949495F975F5F5F004949495F5F5F5F5F000049004949495F5F5F
5F5F5F007300005F004949494949495F5F00975F5F5F975F4949492C2C2C2C2C2C490000
2C2C2C2C2C2C494949C5C5C5B6B6B64949494949492C2C2C0000492C2C2C2C2C2C2C2C2C
4949492C2C2C4900000049004900002C2C2C2C2C2C005F000049002C2C2C2C2C2C5F5F5F
5F5F5F5F5F5F494949005F5F5F5F5F5F9797A7A7A75F97C55F979797C5C597C5C5A7A7A7
5F97975F9797737373A7A7A77373735F5F5F005F5F5F97975F97975F9797005F00005F00
494949005F5F005F005F5F007373735F5F5F5F5F5F00975F5F975F5F975F5F9700858585
5F975F5F97978585855F97975F9797A7A7A75F97975F97975F97975F97975F9797979797
5F97975F97C55F97975F97C5A7A7A7979797A7A7A7A7A7A79797975F97975F97975F9797
5F97975F97975F97975F5F975F97975F5F5F005F5F0049002C2C2C490000002C00002C00
0000000000002C2C2C000000002C002C2C2C002C002C2C2C002C002C2C2C2C2C2C002C00
2C000049000000002C002C000000002C00004900002C0000002C002C2C2C2C0000000000
002C002C2C2C002C002C2C2C2C2C2C00000049000000002C2C000000002C00002C002C00
2C2C2C002C0000002C0000002C000000002C000000002C0000002C2C2C2C00002C2C0000
00000000002C2C2C2C000000000000490000002C0000002C00002C00002C4900002C2C2C
2C2C2C00002C002C002C2C2C00002C00002C2C2C2C2C00002C2C2C4900002C2C2C002C00
2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C49000000002C2C2C2C
0000002C2C2C2C2C2C000000002C002C0000002C0000002C00002C00002C002C0000002C
0000002C2C2C002C002C0000002C002C0000002C00002C002C2C2C00002C00002C2C0000
002C002C2C2C2C0000002C00002C002C2C2C00002C00002C002C00490000002C002C2C2C
00002C00002C2C2C2C494949
C5C5C59797979797C597C5C597C5C5A7A7A7C5C5C5C5C5C5C5EFEFC5C5C5A7A7A7009797
A7A7A75F97975F97975F97970097975F97975F9797005F5F005F5F005F5F5F9797B6B6B6
C5C5EFB6B6B6C5C5C5C5C5C5C5C5C5C5C5C55FC5C5B6B6B6C5975FC5979797975F975F5F
C5975F5F5F5FC5975F975F5F2C2C2C97975F5F5F5F4949494949492C2C2C5F5F005F5F00
4949495F5F5F5F5F5F5F5F5F5F5F005F5F005F5F5F5F5F005F5F005F5F5F5F5F5F5F975F
5F5F5F5F5F005F5F5F5F5F00494949005F5F4949495F5F002C2C2C5F5F002C2C2C004900
005F002C2C2CC5C5C5C5C5EF9797004949494949490049002C2C2C4900002C2C2C2C2C2C
002C002C2C2C002C002C2C2C494949002C002C2C2C5F5F005F975F975F00494949737373
7373737373735F97975F5F5F5F97979797C5A7A7A7A7A7A7A7A7A79797C59797C5979797
8585855F97975F5F975F975F5F5F5F5F5F5F5F5F5F5F9797858585737373494949494949
5F5F5F005F5F5F5F5F5F975F5F975F5F5F005F5F5F5F5F005F975F4949494949495F5F5F
5F975F7373735F97975F97975F97979797975F979797C5C59797975F97C55F97975FC597
9797975F97975F97975F979797C597A7A7A7A7A7A79797975F9797737373858585858585
5F97975F97975F97C55F97975F97975F5F5F5F5F5F494949002C002C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C00000000002C002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C000000
002C0000002C000000002C00002C0000002C00002C0000000000002C000000002C2C0000
002C00002C002C2C2C2C2C2C2C2C2C2C2C2C00002C002C0000002C494949002C002C2C2C
2C2C2C2C2C2C0000002C00000000000000002C2C2C2C2C2C00000049000000002C2C0000
0000002C0000000000000000490000002C00002C00000000002C00490000000000002C00
2C2C2C002C0000002C000000002C002C2C2C2C2C2C0000002C000000002C00002C002C00
2C2C2C2C2C2C00002C2C2C2C2C2C2C00002C490000002C002C2C2C00002C2C2C2C2C2C2C
2C2C2C2C2C2C00002C000000002C0000000000002C002C00002C00002C002C2C2C2C2C2C
2C2C2C2C2C2C00002C2C2C2C2C2C2C000000000000002C0000002C000000000000000000
002C002C2C2C002C00002C002C2C2C002C000000002C0000002C00002C002C000000002C
2C2C2C2C2C2C2C2C2C494949
979797979797A7A7A7C5C5C597C5C597C5C5C5C5C5D4D4D45F97975F979700979700975F
0097975F97979797C55F97975F97975F975F97C5C5B6B6B6975F5F5F5F5F5F975F9797C5
B6B6B697C5EFD4D4D4C5EFEF97C5C597C5C5B6B6B697C597C59797EF975F97975F97975F
975F5F5F9700C5C55F975F5F5F5F5F975F5F5F5F5F005F5F005F5F494949494949494949
5F5F5F5F5F5F5F970097975F9797005F5F5F975F5F7373735F975F5F5F5F5F97005F975F
5F97005F5F5F4949495F5F5F5F5F005F5F5F5F5F00002C005F5F00007300494949490000
5F5F005F975FC5C5C5C5C5974949492C2C2C2C2C2C002C00004900002C00004900002C00
2C2C2C2C2C2C0049002C2C2C490000002C004949495F5F5F5F5F5F2C2C2C494949494949
4949498585855F5F5F5F9797A7A7A7B6B6B6B6B6B6A7A7A797C5C59797C597C5C5A7A7A7
9797978585855F5F5F7373735F5F5F5F5F5F5F975F5F5F5F7373735F5F5F4949495F5F00
4949494949495F5F005F5F5F4949495F5F5F5F5F00494949005F5F5F975F5F5F005F5F5F
97975F5F975F005F975F97975F97979797975F97C5A7A7A75F97975F97979797975F9797
9797975F97975F97C55F97975F97C5A7A7A7A7A7A7A7A7A75F97975F97975F9797979797
5F97979797975F97979797978585855F97975F97975F5F5F494949002C002C2C2C2C2C2C
494949005F00002C002C2C2C2C2C2C2C2C2C2C2C2C2C0000002C00002C002C2C2C000000
4900002C00002C00000000002C000000002C002C00002C00002C002C2C2C002C002C2C2C
0000002C00002C2C2C2C2C2C002C002C2C2C002C002C000000002C2C0000002C00000000
2C000000002C000000000000000000000000002C00002C002C2C2C00002C2C000000002C
2C00002C00002C0000000000002C002C2C2C002C002C00002C00002C2C2C2C0000002C00
002C00490000002C002C2C2C2C2C2C2C00002C2C2C002C00002C00002C0000002C002C00
00002C00002C00000000002C00002C2C2C2C0000002C2C2C2C2C2C2C2C2C002C00002C00
2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C002C000000002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000490000002C000000000000002C2C2C
2C2C2C002C002C2C2C002C0049000000002C2C0000002C00002C004900002C2C2C00002C
002C0000002C2C2C2C494949
5F9797A7A7A797C5C5C5C5C5A7A7A79797C5C5C5EFC5C5C55F97C50097975F9797009797
5F97975F97975FC59797979785858573737397C5C597C5C50097975F97975F9797C5C5C5
C5C5C5C5C5C597C5C5B6B6B6C5C5EF97C5C5C5EFEF97C597C5C55FC5975F97975FC59700
975F5F975F5F97975F97975F5F5F5F5F975F5F5F005F5F00494949494949494949494949
5F5F5F005F5F5F5F5F97975F97975F97975F5F975F5F975F5F5F5F5F975F5F975F5F5F00
005F5F5F5F005F5F004949492C2C2C5F5F00005F00005F000049002C2C2C494949004900
494949C5EFC5C5C5C50073000049004949494900000049004900002C2C2C2C2C2C002C00
2C2C2C004900005F00002C00004900005F002C2C2C2C2C2C002C004949495F5F00494949
4949494949495F97975F5F9797C5C5B6B6B6A7A7A75F5F5F5F97979797C5A7A7A797975F
4949495F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F975F4949495F5F5F005F5F494949005F00
005F005F5F005F5F0097975F5F5F5F5F5F5F5F5F5F5F5F005F97005F5F5F5F5F005F5F5F
97975F97975F5F97975F97975F97975F97975FC597A7A7A797C5979797975F9797858585
5F97975F97975F97975F97C55F97979797979797975F97975F97975F97975F97975F5F97
9797975F97975F97975F97975F97975F97975F97975F975F005F5F2C2C2C494949002C00
2C2C2C00002C002C002C0000002C00002C0000002C2C0000002C0000002C002C00002C00
00002C002C0000002C2C0000490000002C00002C000000000000002C00002C00002C2C2C
2C000000002C2C2C2C2C2C2C2C2C2C002C00002C0000000000002C0000000000002C0000
00002C0000000000002C2C2C2C2C2C002C00002C00002C002C2C2C00002C002C002C2C2C
2C00002C0000002C002C0000002C002C2C2C2C2C2C00002C2C2C2C00002C00002C2C2C2C
2C2C2C2C2C2C2C2C2C00002C00002C002C002C2C2C2C0000002C002C2C2C2C2C2C000000
2C2C2C2C2C2C2C000000002C2C2C2C2C2C2C490000002C0000002C2C2C2C2C2C2C2C2C2C
2C2C2C00002C4900002C2C2C00002C002C00000000002C0000002C2C2C2C2C2C2C002C00
00002C00002C2C2C2C002C00002C002C0000002C002C2C2C2C2C2C00002C00002C2C2C2C
2C2C2C2C2C2C00002C2C2C2C002C002C0000002C00002C002C2C2C002C004900002C2C2C
00002C002C002C2C2C494949
9797C597C5C5B6B6B6C5C5C55F97C597C5C597C5C55F97975F979797C5C5B6B6B65F9797
5F97975F97977373735F97975F979700975F5F97975F97970097975FC5C597C5C597C5C5
C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5B6B6B6979797C5C597C5975F97975FC5975FC55F5F
5F5F5F5F5F00737373975F5F5F5F5F5F5F5F4949495F5F00494949005F5F5F5F5F494949
5F5F5F5F5F5F5F5F5F5F975F97975F5F5F5F5F5F5F5F5F5F5F5F005F975F5F5F5F5F5F00
5F5F5F005F00494949004900004900002C005F5F005F5F5F5F97005F5F005F5F00004900
5F9797C5C5EF4949495F5F000049004900002C2C2C2C2C2C4949492C2C2C2C2C2C2C2C2C
002C00004900002C004949494949492C2C2C4949490049004949495F5F002C2C2C737373
5F5F5F97C5C55F97C5A7A7A7A7A7A78585855F5F5F7373737373735F97C55F9797737373
5F975F5F5F5F4949494949495F975F5F975F858585005F5F4949494949492C2C2C5F5F00
5F5F002C2C2C005F5F5F5F5F5F5F005F975F494949979700975F5F5F5F5F5F5F5F5F5F00
97975F5F975F5F975F00975F5F97977373735F97975F97975F97975F97975F97975F9797
5F97975F97975F5F975F9797A7A7A7A7A7A75F97C59797979797975F97975F97975F9797
5F97975F97C59797979797975F97978585855F5F975F975F5F5F5F2C2C2C2C2C2C2C2C2C
2C2C2C002C00002C000000002C2C2C002C002C2C2C2C0000002C00002C002C2C2C002C00
002C002C2C2C2C2C2C2C2C2C2C2C2C0000002C00004900002C2C2C002C00002C00002C00
002C00002C002C2C2C002C002C2C2C2C2C2C2C2C2C0000002C2C2C2C2C2C2C2C2C2C2C2C
0000002C00002C00002C2C2C0000000000002C0000002C0000002C2C2C2C00002C000000
2C00002C0000002C00000000002C00000000002C002C00002C2C2C002C002C000000002C
002C002C2C2C2C2C2C2C2C2C00002C00002C00002C00002C2C2C2C00002C4900002C2C2C
2C2C2C00002C002C000000002C000000002C2C2C2C002C002C2C2C002C0000002C2C2C2C
2C2C2C2C2C2C00002C2C2C2C2C2C2C002C000000000000000000000000002C2C2C2C2C2C
0000002C2C2C2C2C2C002C002C2C2C002C00002C002C2C2C00002C2C2C2C2C2C2C2C2C2C
002C0000002C000000002C002C2C2C00002C2C2C2C0000000000002C2C2C2C2C2C00002C
2C2C2C2C2C2C490000494949
97C5C5B6B6B6C5C5C5B6B6B65F9797D4D4D49797975F9797A7A7A7D4D4D45F97C55F9797
C5C5C55F975F5F9797005F9700975F00975F5F9797A7A7A7B6B6B6A7A7A75F9797A7A7A7
97C5C597C5C5C5C5C597C5C597C5C5858585009797C5C597C5C55F975F5FC55F00975F5F
5F5F5F5F5F005F5F5F5F97005F975F5F5F002C2C2C5F5F5F5F5F004949495F975F5F5F5F
5F975F4949495F5F5F5F975F5F970097975F5F5F5F5F975F975F5F5F5F5F5F5F5F005F5F
5F5F00004900494949494949005F002C2C2C005F005F5F5F5F5F00002C00004900494949
C5C5C5FFC5972C2C2C004900002C00004900002C00490000004900002C002C2C2C490000
002C002C2C2C2C2C2C494949494949004900002C004949495F00005F97972C2C2C494949
4949499797975F5F5F5F9797A7A7A75F5F5F5F5F5F97C5C59797975F97975F5F5F737373
5F975F5F5F5F4949495F5F5F5F975F5F5F5F7373735F5F004949492C2C2C2C2C2C494949
2C2C2C5F5F002C2C2C5F5F004949494949495F5F005F975F97975F975F00975F5F5F5F00
97970097975F5F975F0097975F97975F5F975F97979797970097979797975F97975F9797
5F97975F97975F97975F97975F97975F97975F97975F97975F97C55F9797737373009797
5F97975F97975F97975F97975F97975F97975F97975F97975F5F5F005F5F2C2C2C002C00
2C00002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C00002C2C2C2C
002C00002C002C2C2C2C2C2C00002C49000000002C2C2C2C002C00002C0000002C002C00
002C00002C002C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C00005FB6B6B6000000
000000002C00002C002C2C2C002C002C2C2C2C2C2C002C002C2C2C00002C000000002C00
002C00002C000000002C0000002C002C00002C2C2C2C2C2C2C2C2C2C2C2C002C0000002C
00002C2C00000000002C2C2C2C2C2C002C0049000000002C49000000002C2C2C2C2C2C2C
2C2C2C2C2C2C49000000002C00002C2C2C2C2C2C2C002C002C2C2C002C002C2C2C2C2C2C
2C2C2C00002C00002C002C002C2C2C002C002C000000002C2C2C2C0000002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C2C2C00002C002C0000002C2C000000002C
00002C2C2C2C2C00004900002C0000000000002C002C00002C2C2C2C2C2C2C2C2C2C2C2C
00002C2C2C2C2C2C2C494949
97C5C597C5C5B6B6B697979797C5C59797975F97975F975F97C5C5A7A7A75F97975FC5C5
A7A7A77373735F5F5FB6B6B6005F5F005F5F005F975F979797C5C55F97975F97975F97C5
97C5C5B6B6B6C5C5EF97C5C5A7A7A75F97975F9797A7A7A7C5975FC5975F7300005F5F00
494949005F5F5F5F5F5F5F5F5F5F5F5F5F004949495F5F005F5F00975F5F7373735F5F5F
5F5F5F5F975F5F975F005F5F5F975F5F5F5F5F975F5F5F5F005F5F5F975F5F5F5F494949
494949494949002C000049002C2C2C494949005F00005F000049004949492C2C2CB6B6B6
C5FFC54949494949494949492C2C2C2C2C2C002C00002C00002C002C2C2C2C2C2C2C2C2C
4949494949492C2C2C2C2C2C2C2C2C2C2C2C494949005F00005F008585854949492C2C2C
49494973737373737373737397C5C5A7A7A75F5F5F8585855F97C59797975F975F5F9797
5F5F5F7373735F975F5F97975F5F5F5F975F5F5F005F5F00494949004900002C00004900
005F002C2C2C002C004949495F5F00005F00005F005F5F5F5F975F5F970097975F5F5F00
5F97005F5F5F97975F5F97975F975F9797975F975F5F5F975F97975F97975F9797009797
5F5F978585855F5F975F97975F5F975F97979797975FC5C55F97975F97975F97975F9797
5F97975F97975F5F975F9797A7A7A75F97975F97977373735F9797005F5F4949492C2C2C
00490000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C
2C2C2C002C002C2C2C2C2C2C002C0000002C2C2C2C002C00002C002C2C2C2C2C2C2C2C2C
0000002C2C2C002C0000002C00002C00002C002C00000000002C00002C009797972C2C2C
0000000000002C2C2C002C002C00000000002C000000002C2C2C2C00002C002C002C2C2C
2C000000002C00000000000049000000002C002C002C0000002C002C2C2C2C2C2C00002C
2C00000000002C2C2C2C2C2C002C00490000002C002C2C2C00002C2C2C2C002C002C2C2C
2C2C2C2C2C2C2C2C2C0000002C2C2C2C2C2C2C2C2C00002C0000000000002C2C2C002C00
2C2C2C2C2C2C00002C4900002C0000002C002C2C2C00002C00002C002C002C2C2C002C00
2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C4900002C000000002C002C00002C00000000
2C000000002C00002C2C2C2C002C002C2C2C2C2C2C00002C2C2C2C2C2C2C002C00490000
00002C2C2C2C2C2C2C494949
5F97975F97C55F97C59797977373735F5F5F5F5F975F5F5F005F5F5F5F975F5F975F9797
9797975F5F5F8585855F975F9797978585855F5F5F5F5F97979797000073B6B6B697C5C5
97C5C5979797B6B6B65F5F5FA7A7A75F97975F5F9797975FC5975FC55F5F5F5F005F5F00
0049005F5F5F4949495F5F005F5F005F5F005F5F004949495F5F00494949494949494949
5F5F005F5F5F4949494949490073005F5F5F5F5F5F5F5F005F5F5F5F97005F5F5F005F5F
005F5F2C2C2C5F5F00494949494949005F5F4949490049002C2C2C005F005F5F5FC5C5C5
975F5F494949494949004900494949005F5F2C2C2C494949002C004949494949492C2C2C
4949494949492C2C2C005F002C2C2C494949005F5F4949492C2C2C5F5F5F8585855F975F
7373735F97975F97C5A7A7A79797975F5F5F494949A7A7A7979797A7A7A75F97975F5F5F
7373737373737373735F97975F5F5F5F5F5F5F5F5F5F5F005F5F004949492C2C2C005F00
004900494949004900005F00005F005F5F005F5F5F5F5F5F5F5F5F5F975F7373735F9700
5F5F005F5F008585855F97975F5F5F5F975F0097970097975F97975F97975F9797005F97
5F97975F97970097975F97970097979797975F97C55F97979797975F97C55F97975F5F97
5F97975F97979797975F97975F97975F97C55F97975F97975F979700975F494949494949
2C2C2C2C2C2C002C00002C002C2C2C2C2C2C2C2C2C00002C00002C2C0000002C00002C00
002C002C2C2C2C00002C2C2C2C2C2C00000000002C00000000000000002C002C00002C00
2C00002C000000002C00002C2C2C2C2C0000490000002C00002C00002C004949492C0000
002C002C0000002C0000002C2C2C2C002C00002C002C2C2C002C002C2C2C00000000002C
2C2C2C2C000000000000002C002C002C2C2C00002C00000000000000002C00002C2C2C2C
002C002C0000002C002C2C2C002C0000002C2C2C2C2C2C2C002C000000002C2C2C00002C
2C2C2C002C0000002C002C002C000000002C2C2C2C2C00002C00002C00004900002C2C2C
2C2C2C2C2C2C00002C2C2C2C2C2C2C002C00000000002C00002C002C2C2C002C002C2C2C
002C002C2C2C2C2C2C2C2C2C00002C2C2C2C00002C2C2C2C00002C490000002C00002C00
00002C0000002C2C2C2C0000002C00002C002C2C2C2C2C2C00002C002C00490000002C00
2C000000002C2C2C2C494949
5F97975F9797A7A7A797975F00975F5F5F5F0097975F97975F97C59797975F5F5F5FC5C5
8585855F5F5F7373735F5F5F4949494949495F5F975F97975F97975F5F5F8585859797C5
A7A7A797C5970097975F979797C5C5737373A7A7A7C5975FC5975FC5975F5F5F00494949
4949495F5F5F5F5F005F5F5F4949495F00004949495F5F5F494949005F5F005F5F494949
2C2C2C494949005F00005F5F4949494949495F5F00494949005F00005F004949495F975F
494949494949005F5F005F005F5F004949495F975F4949492C2C2C5F5F00EFFFEFC5C5C5
005F5F4949492C2C2C2C2C2C002C002C2C2C0049004949494949492C2C2C2C2C2C005F00
005F002C2C2C2C2C2C2C2C2C005F004949495F5F5F5F5F5F8585857373735F9797979797
7373739797975F975FA7A7A77373734949499797979797979797975F5F975F5F5F5F9797
85858597975F5F5F5F5F5F5F737373005F5F5F5F5F4949495F5F5F2C2C2C5F5F5F005F00
2C2C2C4949495F5F004949495F5F00494949494949005F00005F5F5F5F5F5F975F5F975F
5F9700975F5F97975F00975F0097975F5F975F975F5F97975F97975F97970097975F9797
5F5F97009797737373005F975F97975F979785858597975F5F97975FC5C55F97975F9797
5F975F5F97975F97975F97975F97975F97C55F97C55F97975F97975F5F975F9797005F5F
2C2C2C002C004900002C2C2C2C2C2C2C2C2C002C002C000000002C2C2C2C002C002C0000
2C2C2C2C2C2C00002C9797970000002C000000002C0000002C00002C0000002C002C2C2C
00000000002C4949492C00002C2C2C0000000000002C2C2C002C002C00002C2C2C002C00
2C2C2C2C2C2C002C00002C000000002C000000002C2C2C2C2C000000002C2C000000002C
2C2C2C002C002C000000002C2C2C2C2C2C2C00002C4900004900000000000000002C2C2C
002C00002C00000000002C00002C00000000002C002C2C2C2C00002C000000002C2C2C2C
0000002C0000002C002C00002C2C2C00002C2C000000002C2C2C2C2C2C2C2C2C2C002C00
2C2C2C2C2C2C2C2C2C002C002C0000002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C002C002C2C2C002C00
000000002C0000002C2C0000002C002C2C2C2C2C2C00002C2C2C2C2C2C2C002C002C0000
2C2C2C2C2C2C2C2C2C494949
5F5F5F5FC5C597C5C55F97975F5F975F5F97009797009797C5C5C57373735F5F5F979797
5F5F5F005F5F5F9797005F5F005F5F005F5F5FC5C57373735F5F5F5F5F975F979797C5C5
5F979797C5C5005F5F97C5C597C5C5005F5FA7A7A7C5975FC5975F975F5F5F5F5F5F5F00
4949495F5F5F975F000049005F5F5F4949494949495F5F5F4949495F5F5F005F002C2C2C
2C2C2C2C2C2C2C2C2C4949492C2C2C00490000002C004900005F002C2C2C005F00007300
5F5F00494949005F5F5F5F005F5F005F5F5F2C2C2C2C2C2C005F00EFEFC5C5C5C5494949
494949494949005F004949492C2C2C5F5F004949494949492C2C2C494949494949494949
4949492C2C2C4949494949494900004949492C2C2C2C2C2C4949495F5F5F005F5F5F5F5F
5F5F5F5F5F5F5F97975F9797005F5F005F97A7A7A7A7A7A7005F5F9797C55F97975F5F5F
5F5F5F5F5F5F005F5F4949495F5F5F8585855F975F4949492C2C2C494949737373494949
2C2C2C2C2C2C5F5F00005F5F4949492C2C2C0073005F975F005F5F5F975F975F0097975F
5F975F9797005F97970097977373735F5F5F7373735F97970097975F97975F97975F9797
5F97975F97975F97970097970097975F97975F97C55F97975F97975F97975F97C55F9797
5F97975F97975F97975F97975F97975F97975F97975F9797A7A7A75F97975F97975F5F5F
2C2C2C002C0000002C002C00002C002C2C2C0000000000002C2C2C002C00000000000000
2C2C2C00002C000000002C002C2C2C00002C00002C2C2C2C002C002C2C2C002C002C2C2C
2C2C2C002C002C2C2C002C002C2C2C2C0000002C002C2C2C2C2C2C00002C000000000000
4900002C00002C000000002C00002C2C2C2C00002C002C002C2C2C002C002C2C2C2C2C2C
00002C2C00004900002C2C2C2C2C2C00002C2C2C2C2C2C2C0000002C00002C0000002C00
2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C002C002C00002C2C2C2C2C2C2C2C2C002C00
2C2C2C2C2C2C00002C2C2C2C4900002C2C2C2C2C2C2C2C2C00002C00002C2C2C2C00002C
2C2C2C2C2C2C002C002C2C2C2C2C2C00002C2C2C2C00002C2C2C2C002C002C2C2C002C00
002C002C2C2C2C2C2C0000002C00002C2C2C002C002C2C2C2C2C2C00002C00002C000000
000000000000002C00002C0000002C002C0000002C0000002C2C2C002C002C2C2C2C2C2C
002C000000002C2C2C005F5F
5F5F979797C597975F5F5F975F5F975F5F5F005F97005F97737373005F5F5F97975F97C5
5F5F5F5F97975F5F5F5F5F5F5F5F5F005F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5FA7A7A7
5F5F97005F975F979797C5C57373735F5F5FC5C597C55F5F97970097975F5F5F5F005F00
5F5F00002C000000004949495F5F005F5F5F5F5F5F4949495F5F005F5F5F5F5F002C2C2C
0049002C2C2C005F004949492C2C2C2C2C2C0049002C2C2C2C2C2C494949005F002C2C2C
5F5F00494949005F5F4949495F5F000049002C2C2C2C2C2C5F5F97C5EFEFC5975F005F5F
494949005F00005F002C2C2C2C2C2C004900494949494949004900005F00002C002C2C2C
2C2C2C2C2C2C4949490049004949494949494949495F975F4949495F5F5F7373735F5F5F
5F9797858585A7A7A77373735F5F5F5F5F975F97975F97975F5F5F5F97975F5F5F5F975F
5F5F5F005F004949495F5F5F4949495F5F5F5F5F5F0049004949494949495F5F5F2C2C2C
0049002C2C2C494949002C00494949005F002C2C2C5F5F5F5F5F005F5F00975F5F975F5F
5F5F5F97975F7373735F97975F97975F97975F97975F97975F97975F97C55F97975F9797
5F97975F97975F5F975F97970097977373735F97977373735F97975F9797A7A7A75F9797
0097975F5F975F97975F97975FC5C55F97C55F97975F97975F97975F97C55F97975F5F97
4949492C2C2C2C2C2C4949492C2C2C2C2C2C002C00490000002C002C2C2C000000000000
2C2C2C0000000000002C0000002C002C2C2C2C000000002C490000002C00002C00002C00
00002C002C002C2C2C2C2C2C2C2C2C002C00002C002C2C2C2C2C2C2C2C2C000000000000
00002C2C0000002C002C2C2C00002C00002C2C000000002C2C2C2C2C2C2C2C2C2C002C00
2C2C2C002C0000002C002C00002C002C2C2C2C2C2C00002C490000002C002C2C2C00002C
2C2C2C002C0000002C2C2C2C2C2C2C4900002C2C2C002C000000002C2C2C00002C002C00
00002C002C002C0000002C00002C002C2C2C0000002C2C2C002C002C2C2C00002C2C2C2C
000000000000002C00002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C00002C2C2C2C2C2C00002C002C00002C0000002C2C2C2C2C0000002C00000000
2C0000002C000000002C2C2C2C2C2C2C2C2C2C2C2C49000000002C002C0000002C2C2C2C
002C002C00002C2C2C494949
5F5F5F9797C55F5F975F5F97005F97979797005F5F5F5F5F005F5F005F5F5F97975F5F5F
5F97975F5F5F5F5F5F005F5F5F5F5F005F5F4949495F5F5F5F5F5F5F97975F5F5F979797
5F5F975F5F5F8585855F5F97005F5F979797C5975F97975F97975F975F5F5F5F5F5F5F00
4949497373735F5F5F4949495F5F5F5F5F5F5F5F5F5F5F5F5F975F005F005F5F5F494949
0049002C2C2C4949494949492C00002C2C2C2C2C2C494949002C000049002C2C2C2C2C2C
494949494949005F5F005F5F5F5F00494949002C00004900D4D4D4EFC5972C2C2C2C2C2C
494949494949005F002C2C2C005F002C2C2C4949494949492C2C2C494949494949494949
2C2C2C4949494900002C2C2C2C2C2C4949494949494949495F5F5F5F5F5F494949494949
494949979797C597975FC5C55F97975F97979797975F5F975F5F97005F977373735F5F5F
494949858585005F004949494949492C2C2C005F5F005F5F2C2C2C5F5F5F5F5F5F494949
4949494949494949494949495F5F000049005F5F005F5F5F5F5F005F975F5F5F5F858585
5F5F5F9797975F975F5F97975F97975F97975F97975F97975FC5979797975F97975F9797
5F97975F97975F97975F97975F97975F5F975F97975F97970097975F97975F97975F9797
0097975F97975F97C59797975F97C55F97975F97975F97979797975F97975F97975F9797
5F97974949492C2C2C00002C002C00002C002C2C2C00002C490000002C002C2C2C2C2C2C
00002C0000002C000000002C2C00002C2C2C00002C00002C000000002C00002C0000002C
002C00002C002C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C002C002C2C2C00002C
2C00000000002C000000002C2C000000002C49000000002C49000000002C4900002C2C2C
2C2C2C2C2C2C00002C2C2C2C49000000002C2C2C2C002C00002C004900004900002C2C2C
2C2C2C2C0000490000002C002C000000002C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C002C000000002C2C2C2C2C2C2C2C2C0000002C2C2C2C2C2C
00002C0000000000000000002C2C2C002C004949492C2C2C4949492C2C2C2C2C2C002C00
2C2C2C000000002C002C2C2C00002C2C2C2C00002C000000000000002C00000000000000
2C2C2C0000000000002C00000000002C2C2C2C2C2C2C2C2C00002C2C2C2C2C0000002C00
2C2C2C002C002C2C2C494949
5F97975F975F5F975F5F5F97C597975F5F5F005F5F5F5F5F005F97005F5F5F9797009797
00975F005F5F005F5F005F5F5F5F5F5F5F5F5F5F5F005F5F005F5F5F5F5F5F979797C5C5
5F975F005F5F005F97005F5F979797C5C597C5975F97975F97975F5F5F005F5F5F5F5F00
5F5F5F5F975F5F5F5F5F975F5F5F5F5F5F5F5F975F5F5F5F005F5F5F5F00005F00005F00
2C2C2C4949494949492C2C2C2C2C2C005F004949494949494949490049000049005F5F5F
4949495F5F5F2C2C2C4949495F5F5F2C2C2C4949495F9797C5C5C52C2C2C2C2C2C005F00
2C2C2C2C2C2C4949494949492C2C2C2C2C2C2C2C2C005F00004900005F00005F002C2C2C
2C2C2C2C2C2C494949004900005F00005F5F7373734949499797977373735F97975F975F
737373737373858585A7A7A75F5F975F97979797974949495F97975F97974949495F9797
7373735F5F5F4949494949494949495F5F5F5F5F5F494949005F5F5F975F494949494949
4949490049002C2C2C494949494949005F005F5F5F5F5F004949495F5F5F4949495F5F5F
5F5F5F5F975F5F97975F97975F97975F97975F5F5F0097975F97C55F97C55FC597009797
0097975F97975F97975F97975F97970097975F97977373730097975F97C50097975F9797
5F97975F97975F97975F97C55F97C55F97C55F97C55F97975F97C55F97C55F97975F9797
5F9797005F5F4949492C2C2C002C00002C00002C004900002C2C2C002C00002C002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C49000000002C2C0000002C00490000002C00
5F5F5F2C2C2C000000490000002C00002C002C2C2C002C002C000000002C000000000000
2C2C2C2C2C2C002C002C2C2C2C00002C2C2C002C002C2C2C00002C2C2C2C2C2C2C00002C
002C002C2C2C00002C2C2C2C002C002C2C2C494949002C00002C0000002C2C2C2C00002C
2C2C2C002C002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C
000049737373002C002C2C2C4900002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C00002C2C2C2C2C2C2C00002C0049000000492C2C2C2C2C2C00002C2C2C2C
002C00002C004900000000492C2C2C002C000000000000000000002C0000002C00002C00
00002C002C00002C002C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C490000
002C00002C002C2C2C494949
737373005F5F005F5F5F5F975F5F5F5F5F5F5F5F5F4949495F5F5F5F97975F9797005F5F
5F5F5F00975F00975F005F5F5F5F5F5F5F5F5F5F5F005F5F5F5F97005F5F5F97975F9797
5F9797494949005F5F005F975F9797C5975FC5975FC597005F5F5F5F5F5F00490097975F
5F975F7373735F5F005F975F5F975F494949005F5F494949005F005F5F00007300494949
2C2C2C2C2C2C005F004949492C2C2C2C2C2C4949492C2C2C2C2C2C2C2C2C005F00494949
4949494949494949495F5F5F494949005F005F5F00C5C5C5C5975F2C2C2C005F002C2C2C
0049005F0000005F5F2C2C2C005F002C2C2C005F002C2C2C2C2C2C494949494949494949
5F5F004949492C2C2C4949494949492C2C2C4949492C2C2C5F5F5F005F5FA7A7A7979797
858585737373B6B6B6C5C5C597C5C597C5C55F97975F97975F5F975F97975F9797979797
005F978585855F975F5F5F5F4949494949494949495F5F00494949494949494949494949
4900000049002C2C2C4900004949492C2C2C5F5F00005F004949495F5F5F5F9700737373
9797970097975F975F5F5F5F5F5F5F0097975F97975F97975F9797A7A7A75F9797005F97
5F97975F97975F97975F97C55F5F970097975F97978585855F5F975F97975F97C55F9797
5F97975F97975F97975F97975F97975F97C55F97975F97C55F97C55F97C55F9797858585
5F9797005F5F005F5F2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C490000002C00
00002C2C0000002C00002C00490000490000002C00002C002C2C2C00002C5F5F5F2C2C2C
2C2C2C2C2C2C00002C73737300002C002C0000002C4900002C2C2C000000000000490000
00002C2C2C2C00002C2C2C2C2C0000002C000000002C000000002C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C00002C2C2C2C2C2C2C2C0000
2C00002C2C2C00002C002C002C2C2C2C2C2C00002C2C2C2C2C2C2C00002C2C2C2C2C2C2C
2C00002C2C2C2C2C2C00002C002C0000002C2C2C2C2C2C2C002C002C2C2C002C002C2C2C
0000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C2C2C0049002C2C2C2C2C2C
002C002C2C2C002C000049002C2C2C002C0000000000002C2C0000002C00000000002C00
2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C00002C2C2C
2C2C2C2C2C2C4949492C2C2C
005F97005F97005F5F5F5F5F005F5F005F5F005F5F005F5F5F97975F97975F5F5F005F5F
005F5F5F5F5F5F5F5F5F5F5F005F5F5F5F5F005F5F005F5F7373735F5F5F5F97975F5F97
494949005F5F005F5F5F979797975FC5975F97975F97975F5F5F5F4949495F975F5F975F
5F975F5F5F5F4949495F5F5F494949005F5F4949494949495F5F005F5F002C2C2C2C2C2C
4949494949494949492C2C2C0049004949492C2C2C494949494949494949494949494949
2C2C2C0049000073005F5F005F5F005F5F00B6B6B697C5C52C2C2C005F00005F5F2C2C2C
004900005F5F004900005F00494949004900005F002C2C2C0049004949494949492C2C2C
2C2C2C4949492C2C2C005F002C2C2C494949494949494949494949494949494949858585
5F979797C5C5C5C5C5A7A7A79797C55F97975F9797005F975F97975F97C5A7A7A75F975F
4949497373735F5F5F5F5F00002C005F5F004949492C2C2C005F5F494949494949494949
2C2C2C2C2C2C005F000049005F5F004949495F5F004949494949494949495F975F005F5F
7373735F5F5F5F979700975F5F97975F97970097975F97975F97975F97975F97C5A7A7A7
5FC5C55F97975F97979797970097970097977373735F97970097975F97975F97975FC5C5
8585855F97975F97975F97C55F97975F97C55F97C59797975F97C55F97975F97C55F9797
5F5F975F5F975F5F5F2C2C2C2C2C2C2C0000002C002C2C2C2C2C2C00002C00002C002C00
2C2C2C00002C2C2C2C49000000002C2C2C2C0000002C0000002C002C00002C2C2C2C2C2C
00002C49000000002C00002C002C002C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
00002C2C2C2C2C2C2C00000000000000002C490000002C0049000000002C2C2C2C2C2C2C
002C002C2C2C2C2C2C00002C00002C00002C2C2C2C00002C4900002C2C2C00002C2C2C2C
2C2C2C00002C002C0000002C4900002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C
2C2C2C002C002C2C2C2C2C2C000000002C002C2C2C002C000000002C2C2C002C0000002C
2C2C2C4900002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C
002C0000002C002C002C2C2C2C2C2C2C2C2C490000002C002C2C2C002C002C2C2C2C2C2C
2C2C2C002C00002C002C2C2C2C2C2C00002C002C00002C002C2C2C002C00002C00002C00
5F5F5F2C2C2C2C2C2C494949
5F975F005F5F005F5F5F5F5F005F5F005F5F005F5F005F5F005F5F5F5F5F5F975F5F5F5F
005F5F5F5F5F5F975F5F5F5F005F5F005F5F5F5F5F5F5F97005F5F5F97C55F97975F5F5F
5F5F5F5F005F979797C5C597C5C597975F5F494949C597005F5F5F4949495F5F005F5F00
5F975F5F975F5F975F5F975F5F5F5F5F5F5F494949005F005F5F5F5F5F5F4949492C2C2C
0049005F5F00494949005F004949492C2C2C2C2C2C005F5F494949494949494949494949
494949005F5F005F005F975F4949495F9797C5C5C55F5F004949494949492C2C2C494949
002C004949494949495F5F002C2C2C005F000049002C2C2C2C2C2C0049002C2C2C2C2C2C
5F5F002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C4949495F5F5F5F5F5F2C2C2C5F5F5F979797
5F9797A7A7A79797975F97979797C597C5C58585855F5F975FC5C597C5C5858585494949
005F5F5F5F5F5F5F5F4949492C2C2C002C004949495F5F002C2C2C002C00494949494949
5F5F004949494900005F5F00005F5F4949492C2C2C975F005F975F97975F5F975F5F975F
5F5F5F5F5F975F5F5F00975F0097975F97975F97975F97975F97975F97975F97975F97C5
5F97975F97C55F97C55F97975F97975F97C55F97975F97975F97975F97975F9797979797
5F97975F97975F97975F97C55F97975F97975F97975F97C55F97C55F97975F97C55F9797
5F97975F975F5F5F5F2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C00002C2C2C2C002C00
002C00002C0000002C2C2C2C0000000000004900002C00002C000000000000002C2C2C2C
00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C00002C
2C2C2C00002C002C002C0000002C002C0000002C00002C0000000000002C49000000002C
2C00002C2C2C2C2C2C00002C2C2C2C49000000002C2C2C2C2C2C2C00002C0000002C2C2C
00002C49000000002C2C2C2C0000002C2C2C0000002C00002C2C2C2C2C2C2C2C2C2C2C2C
002C002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C002C000000002C2C2C00002C2C2C2C
002C002C2C2C002C0000002C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
0000490049002C2C2C2C2C2C5F5F5F5F5F5F2C2C2C002C002C2C2C002C00002C002C2C2C
002C00002C00000000002C00002C002C2C2C002C002C00002C2C2C2C2C2C2C00002C0000
2C2C2C2C2C2C2C2C2C2C2C2C
005F5F005F5F005F5F5F5F5F005F5F005F5F49494900975F005F5F005F5F5F5F9700975F
005F5F00975F5F5F5F5F5F5F005F5F005F5F5F5F5F5F5F5F85858597C5C55F5F5F005F5F
0097975F9797C5C55FC5975F975F005F5F5F5F97004949495F975F5F5F005F5F5F5F975F
5F975F5F975F5F975F005F00494949002C005F5F00005F004949492C2C2C2C2C2C2C2C2C
4949494949494949494949495F5F5F5F5F004949492C2C2C005F5F005F5F2C2C2C5F5F00
5F5F5F5F5F5F0073005F5F005F5F5FC5C5C5B6B6B6005F000049002C2C2C005F002C2C2C
5F5F00494949004900005F5F494949005F005F5F00005F002C2C2C0049002C2C2C494949
2C2C2C4949492C2C2C2C2C2C4949492C2C2C002C00002C00494949494949737373A7A7A7
9797975F5F5F7373735F5F5F7373735F9797A7A7A75F9797B6B6B65F97C55F97975F5F5F
2C2C2C494949005F5F4949494949492C2C2C4949492C2C2C2C2C2C2C2C2C4949495F5F5F
4949494949492C2C2C5F5F5F737373494949005F005F97005F97005F5F5F5F5F5F5F975F
5F5F5F5F975F005F970097975F97975F97970097975F97970097975F97975F97C55F9797
5F97C55F97C597C5C55F97970097975F97975F97975F975F5F97975F97975F9797979797
5F97975F97975F97975F97975F97975F97C55F97975F97975F97C55F97975F97975F97C5
5F5F978585857373735F5F5F2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C00002C002C00
2C2C2C00002C2C2C2C2C2C2C00002C002C002C2C2C2C2C2C002C002C00002C2C2C002C00
2C00002C0000002C00002C0000002C2C2C2C2C2C2C00002C00002C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C00002C0000002C0000002C002C00002C2C2C2C2C2C2C2C2C2C2C2C490000
2C2C2C002C0049000049000000002C00002C00002C002C0000002C2C2C2C2C2C2C2C2C2C
2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C00002C00002C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C00002C2C00002C2C2C2C2C2C002C0000002C2C2C2C2C2C2C002C00
2C2C2C002C000000495F975F2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C00002C002C004949492C2C2C2C2C2C002C002C2C2C00002C0000002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C002C00002C002C2C2C
2C2C2C00002C2C2C2C494949
5F5F5F005F5F005F5F5F5F5F005F5F5F5F5F005F5F005F5F5F5F5F005F5F005F5F005F5F
005F5F005F5F5F5F5F5F5F5F494949005F5F5F5F5F5F5F5F9797975F9797005F5F0097C5
5F9797C5975FC5975F9797005F5F004949495F5F5F5F5F5F4949495F5F004949495F5F00
494949005F5F5F975F005F004949494949490073004949495F5F5F494949494949005F00
0049004949495F5F00005F5F494949004900494949494949005F004949490049005F5F5F
5F5F5F5F5F5F5F5F00005F00C5C5C5B6B6B64949490073004949492C2C2C2C2C2C2C2C2C
494949005F004949490000492C2C2C2C2C2C005F5F005F00494949004900002C005F5F00
4949494949490049002C2C2C2C2C2C0049002C2C2C2C2C2C005F00494949A7A7A7A7A7A7
85858597975F4949495F5F9773737397C5C55F5F5F85858597C5C55F97975F5F97494949
2C2C2C4949492C2C2C494949494949005F004949494949494949494949495F5F5F737373
5F5F5F4949492C2C2C5F5F5F5F5F5F2C2C2C5F5F005F975F5F5F005F975F5F5F5F5F5F5F
0097975F975F005F5F0097975F97975F97975F97975F97970097975F97975F5F975F9797
5F9797A7A7A75F9797A7A7A75F97975F97975F9797005F975F97975F97975F9797A7A7A7
5F97C55F97975F97975F97975F97975F97975F97975F97C55F97C55F97C55F5F975F5F97
5F97975F97975F97975F5F5F2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C00002C2C2C
2C2C2C2C2C2C2C2C2C002C002C2C2C002C0000002C2C000000002C00002C000000000000
2C000000000049000000002C2C2C2C00002C2C2C2C0000002C00002C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C00002C2C2C2C0000002C2C2C2C00002C2C2C002C002C2C2C2C2C2C00002C
002C00002C002C2C2C2C2C2C000000002C004900002C2C2C2C2C2C2C2C2C4900002C2C2C
00002C2C2C2C002C002C2C2C2C2C2C00002C00002C2C2C2C2C2C2C002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C0000002C2C2C00002C4900002C2C2C000000002C002C2C2C
00002C2C2C2C2C2C2C002C002C2C2C0000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00
2C2C2C00005F2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00005F005F970049002C2C2C494949
002C002C2C2C0000002C2C2C00002C2C2C2C2C2C2C002C0000002C2C2C2C002C00002C00
2C2C2C002C002C2C2C2C2C2C
5F5F5F005F5F005F5F005F5F005F5F005F5F005F5F005F5F005F5F00975F005F5F005F5F
005F5F00975F5F5F975F5F5F5F5F5F5F5F5F5F5F5F005F5F5F9797494949005F975FC597
97C55FC5975FC597005F5F005F5F005F5F5F975F5F2C2C2C4949495F5F5F4949495F5F5F
5F5F005F5F002C2C2C005F00494949005F5F5F5F00005F004949494949494949492C2C2C
0049002C2C2C494949494949494949005F004949494949492C2C2C4949494949495F5F5F
5F5F5F5F5F5F5F97005F9797D4D4D45F5F5F4949490049004949495F5F00005F00494949
005F002C2C2C2C2C2C002C002C2C2C5F5F002C2C2C2C2C2C005F5F2C2C2C5F5F002C2C2C
4949492C2C2C2C2C2C002C002C2C2C005F5F5F5F5F494949A7A7A75F5F5F5F975FA7A7A7
5F975F4949495F975FA7A7A7858585858585A7A7A75F97979797975F97975F975F494949
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C494949494949494949005F5F737373858585
5F5F5F4949494949495F5F5F5F5F5F005F005F5F5FC5975F5F5F005F5F5F5F97975F9797
005F5F5F975F7373735F97975F9797005F975F97975F97975F97970097975F9797005F97
0097975F9797A7A7A75F97C55F97C55F97979797975F97975F975F5F97975F9797979797
5F97975F97975F97975F97975F97C50097975F97975F97975F97975F9797A7A7A75F9797
5F97975F97975F97975F97974949492C2C2C2C2C2C002C002C2C2C2C00002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C0000002C2C2C2C2C2C002C002C2C2C00002C00002C2C2C2C
2C2C2C4900000000004900002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00
002C002C2C2C2C2C2C2C2C2C0000002C2C2C00002C002C002C2C2C2C2C2C2C2C2C00002C
2C2C2C2C2C2C2C2C2C2C2C2C2C000000002C2C2C2C4900002C2C2C2C2C2C00002C2C2C2C
2C2C2C2C000000002C2C2C2C0000002C2C2C2C2C2C9797C52C2C2C00002C2C2C2C2C2C2C
2C2C2C00002C2C2C2C2C2C2C00002C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C
002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C000049
2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C5F5F5F5F5F5F5F5F5F5F5F5F2C2C2C004900
2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C002C00
2C2C2C002C002C2C2C494949
005F5F005F5F005F5F5F5F5F005F5F005F5F5F979700979700975F005F5F005F5F005F5F
005F5F005F5F00975F005F5F5F5F5F494949005F5F005F5F5F5F5F4949495FC597C5975F
C5975F97975F975F005F5F5F4949495F5F5F4949495F5F004949495F975F5F5F005F5F5F
5F5F000073005F5F5F2C2C2C494949494949005F5F4949494949492C2C2C2C2C2C2C2C2C
4949494949495F5F004949492C2C2C002C00002C000049004949494949494949495F5F5F
005F5F0073005F5F5FE1E1E18585855F975F5F5F5F494949494949494949005F005F5F00
0049004949490073004949492C2C2C2C2C2C005F004949490049002C2C2C5F00002C2C2C
4900002C2C2C002C002C2C2C2C2C2C5F975F8585858585855F9797494949737373A7A7A7
C5975F97975F494949A7A7A7494949494949A7A7A7B6B6B62C2C2C7373735F5F5F494949
4949492C2C2C4949492C2C2C4949494949494949495F5F5F005F5F5F97979797975F5F5F
5F975F5F5F00494949494949975F5F9797005F5F004949494949495F5F5F7373735F9797
5F97975F97975F97975F97975F979700975F5F97970097975F97975F97975F9797009797
0097970097975F97975FC5C55FC5C59797975F97975F97975F97975F97975F97975F9797
5F97975F97975F97975F97970097975F97975F97975F97979797975F97975F9797979797
5F97975F97975F97977373737373735F5F5F0049002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C002C002C0000002C002C00000000000000002C2C2C2C2C2C00002C
2C2C2C2C2C2C4900000000002C000000002C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C
002C002C0000002C0000002C00002C49000000002C2C2C2C2C2C2C2C2C2C00002C2C2C2C
2C2C2C2C2C2C00002C00002C0000002C2C2C002C002C2C2C002C0000002C0000002C0000
00002C2C000000002C2C2C2C002C0000000000002C5F5F5F002C002C2C2C00002C2C2C2C
2C2C2C2C2C2C00002C2C2C2C2C0000002C0000002C2C2C2C2C2C2C2C2C2C00002C2C2C2C
2C2C2C2C2C2C2C2C2C00000000002C2C2C2C2C2C2C2C2C2C2C2C2C0000002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C002C000049002C2C2C975F5FEFC5C55F97C57373735F975F
005F5F2C2C2C0000492C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C002C002C2C2C
2C2C2C00002C2C2C2C00005F
005F5F5F5F5F005F5F5F5F5F005F5F005F5F494949009797005F5F005F5F00975F005F5F
005F5F005F5F73737300975F5F5F5F5F975F005F5F005F5F005F5F5FC597C5C59797975F
C5975F5F5F5F49494997975F5F5F0097975F97975F5F5F00005F5F494949005F005F5F5F
5F5F005F5F5F2C2C2C5F5F005F5F002C2C2C0049004949494949492C2C2C494949005F00
494949005F5F2C2C2C005F002C2C2C5F5F002C2C2C0049002C2C2C5F5F5F5F5F5F494949
494949494949D4D4D4B6B6B6005F5F5F5F002C2C2C5F5F00005F002C2C2C0049002C2C2C
004900005F00005F00005F00005F00005F00005F004949492C2C2C4949494949492C2C2C
2C2C2C0049002C2C2C2C2C2C5F5F005F5F00005F5F737373494949858585979797A7A7A7
005F5F5F5F5F494949A7A7A75F5F5F5F975F5F5F5F005F5F5F5F5F7373735F5F002C2C2C
2C2C2C005F005F5F002C2C2C005F5F5F5F00494949494949005F5F9797979797975F975F
5F5F5F5F975F0073005F97009797005F5F5F5F5F5F5F5F005F975F005F5F7373735F975F
7373735F5F5F005F970097975F97975F97977373735F97970097975F97975F97975F9797
0097970097975F97975F9797A7A7A79797979797975F9797005F970097978585855F9797
5F97975F97975F97975F97C55F97975F97970097975F97975FC5C55F97C55F97975F97C5
5F97975F97975F97975F97975F975F5F5F5F494949002C002C2C2C2C2C2C2C2C2C002C00
2C2C2C002C00002C00002C00002C002C000000002C00000049000000002C000000490000
2C2C2C002C002C2C2C002C00002C00002C00002C00002C002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C000000002C2C2C2C2C2C2C2C2C00002C2C2C2C002C0000002C490000
00002C4900002C2C2C0000000000002C2C2C002C002C2C2C4900002C2C2C2C2C2C002C00
2C0000002C00002C002C2C2C00002C2C2C2C00002C2C2C2C2C2C2C2C2C2C00002C002C00
00002C2C2C2C002C002C2C2C00002C002C00002C00002C002C2C2C2C2C2C2C2C2C002C00
00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0049002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C5F5F97858585494949C5EFC5
5F5F5F49494900005F2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C0000002C2C2C
005F5F5F5F5F5F975F5F5F5F00975F005F5F005F5F5F975F005F5F5F5F5F005F5F005F5F
5F5F5F5F5F5F5F5F5F005F975F5F5F5F5F5F5F5F5F005F5F5F975FC5C55FC59797C55F5F
975F5F5F5F5F5F975F9797005F5F5FC5C55F979700494949494949005F005F5F005F5F00
005F5F2C2C2C005F002C2C2C0049005F5F00494949005F00005F00005F004949495F5F5F
4949494949495F5F004949494949492C2C2C2C2C2C2C2C2C2C2C2C4949494949495F5F00
494949005F5FB6B6B6494949005F5F005F00005F005F5F005F5F002C2C2C005F002C2C2C
005F005F5F5F4949494949492C2C2C494949494949494949004900004900004900494949
004900002C000049000049004949494949494949495F5F00005F5F5F975F975F5F979797
005F5F5F975F4949495F5F5F5F5F5F9797979797978585855F5F5F4949495F5F5F5F5F5F
2C2C2C5F5F002C2C2C4949494949495F5F00494949005F005F5F005F97975F97975F5F5F
5F5F5F5F975F975F5F5F975F9797005F5F5F5F975F494949005F977373735F9797005F5F
5F5F5F005F9700975F5F97975F97975F97975F97975F97970097975F97975F97975F9797
5F9797005F975F97975F979797979797C597A7A7A75F97975F97975F97975F97975FC5C5
5FC5975F97975F97975F97975F97975F97975F97975F97975F97C5A7A7A7858585858585
5F97975F5F975F97975F97975F5F977373734949494949492C2C2C00002C002C002C2C2C
2C00002C2C2C002C002C0000002C00002C0000002C2C00002C2C2C002C002C0000000000
0000002C000000002C00002C00002C2C2C2C2C2C2C002C002C0000002C000000002C0000
49000000002C00002C0000002C0000002C002C2C2C00002C2C2C2C002C00490000002C00
00002C2C2C2C00002C2C2C2C2C2C2C2C0000002C00490000002C0000002C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C00002C0000002C2C2C2C2C2C2C2C2C00002C00002C00002C2C2C2C
002C002C2C2C2C2C2C2C2C2C2C000000002C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C00002C002C002C2C2C
002C002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C5F5F5F4949495F5F5F494949C5975F
9797972C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C00002C00002C002C00
2C2C2C4949492C2C2C494949
005F5F00975F5F5F5F5F5F5F005F5F005F5F005F975F5F5F00975F5F5F5F005F5F005F5F
005F5F5F5F5F5F975F5F5F5F005F5F5F5F5F00975F5F9797A7A7A7C5975FC5C55FC5975F
C5975F5F5F5F9797005F975FC5975F97975F5F5F5F4949495F5F00005F5F5F5F5F004900
2C2C2C5F5F004949494949492C2C2C5F5F5F4949494949492C2C2C2C2C2C4949495F5F00
005F004949494949492C2C2C5F5F002C2C2C494949005F004949494949494949495F5F00
5F975FE1E1E1C5C55F5F975F4949494949494949494949494949492C2C2C002C005F5F00
494949494949005F5F494949005F004949494949494949492C2C2C005F00005F002C2C2C
2C2C2C5F5F002C2C2C5F5F004949495F5F004949494949495F5F009797974949495F9797
4949498585855F5F5F2C2C2C737373979797005F00858585494949005F5F494949002C00
5F5F00494949005F004949494949494949494949495F5F004949495F975F5F975F494949
005F5F5F5F5F5F975F5F975F5F5F5F5F5F5F5F5F0000975F5F97975F975F005F975F5F5F
5F5F975F97975F5F975F97975F97970097975F97977373730097975F97975F97975F9797
5F97975F97975F97975F97975F979797C5979797979797977373735F97979797975F9797
5F97975F97975F97979797975F97975F97975F97975F97975F9797979797979797979797
5F97975F97975F5F975F97975F97978585855F5F5F2C2C2C2C2C2C002C002C2C2C2C2C2C
002C002C2C2C2C2C2C00002C49000000002C2C00002C2C2C00002C002C002C0000000000
002C002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C002C002C2C2C002C00
2C2C2C2C2C2C00002C2C000000002C2C2C2C2C2C2C2C0000002C002C2C2C00002C002C00
2C2C2C00002C2C2C2C2C2C2C002C002C0000490000002C002C2C2C002C002C2C2C2C2C2C
2C2C2C2C0000002C002C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C00002C2C2C2C490000
2C2C2C2C2C2C4900002C2C2C002C002C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C
002C000049002C2C2C2C2C2C002C002C2C2C002C004949492C2C2C005F5F005F5F494949
0000492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C00002C002C002C00002C2C2C
005F00000000002C0000005F
005F5F005F5F5F5F5F5F975F005F5F005F5F5F97975F5F5F5F975F5F5F5F005F5F005F5F
5F5F5F5F5F5F005F5F5F5F5F737373005F5F979797A7A7A7C5975FC5975FC5975F97975F
975F5F5F975F5F975FC5975F5F975F5F5F5F5F97005F5F5F5F5F00494949007300494949
005F5F2C2C2C0049002C2C2C004900005F5F494949494949004900004900005F005F975F
5F5F005F5F004949494949494949494949492C2C2C2C2C2C5F5F005F5F000049005F5F00
A7A7A797C5C55F5F5F2C2C2C4949492C2C2C5F5F5F2C2C2C005F5F2C2C2C494949002C00
004900005F5F4949494949492C2C2C005F5F494949005F5F005F004949495F5F002C2C2C
005F00002C00494949494949494949494949005F5F5F97975F5F5F5F975F737373737373
5F5F5F97C5975F5F5F494949005F5F8585855F5F5F4949494949492C2C2C5F5F005F5F00
5F5F004949495F5F005F5F5F4949495F5F004949495F975F5F975F5F975F5F975F494949
5F5F5F975F5F4949494949495F975F5F5F5F005F5F5F5F5F5F5F5F005F5F00979700975F
5F5F5F7373737373737373735F975F5F975F5F975F5F9797005F5F5F9797005F97737373
5F97975F97975F97970097975F97975F97C55F97979797975F97975F97975F97975FC597
9797970097975F97975F97975F97975F97975F97975F97975F97975F9797A7A7A75F9797
8585855F5F975F97979797975F5F975F97975F5F5F5F5F5F2C2C2C2C2C2C490000002C00
002C002C2C2C2C2C2C2C2C2C00002C0000002C00002C2C2C00002C002C00000000000000
2C2C2C2C2C2C2C2C2C002C0000002C000000002C0000002C2C0000002C00002C00002C00
2C2C2C2C2C2C2C2C2C002C0049000000002C00002C00002C2C2C2C2C00002C2C2C000000
2C00002C2C2C2C2C2C00002C00002C002C0000002C00002C002C00002C002C2C2C2C2C2C
2C2C2C2C2C2C002C002C2C2C0000002C2C2C002C002C2C2C002C002C2C2C2C2C2C2C2C2C
002C004900002C2C2C00002C002C002C2C2C2C2C2C002C0000002C002C0000002C000000
2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C4949490049002C2C2C00002C004900
0049002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C2C2C2C2C2C002C002C2C2C
2C2C2C00002C4949492C2C2C
005F5F005F5F00975F5F5F5F5F5F5F5F5F5F5F97975F5F5F005F5F5F5F5F005F5F005F5F
5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F9797A7A7A7C5C597C59797C5975F5F5F00737373
5F975F97975F97C55F975F5F005F5F494949979700494949005F004949495F5F5F494949
4949495F5F5F2C2C2C005F004949495F5F5F005F002C2C2C005F5F4949495F5F00494949
4949495F5F00005F000049002C2C2C005F002C2C2C004900005F5F0049005F5F00737373
C5C5C5C55F5F4949495F5F5F4949494949494949495F5F000049000049005F5F00005F00
4949492C2C2C494949005F5F4949495F5F000073002C2C2C005F00494949494949494949
2C2C2C005F002C2C2C5F5F002C2C2C2C2C2C5F5F5FB6B6B6005F009797974949495F5F5F
4949495F5F5F2C2C2C5F5F5F7373735F975F5F5F5F5F9797005F5F5F5F004949495F5F00
4949494949495F5F002C2C2C4949494949495F5F004949495F5F5F5F5F5F5F975F5F5F5F
5F5F5F5F975F5F5F5F00975F5F5F5F005F005F5F5F5F5F5F5F5F5F5F5F5F0097975F9797
5F5F977373737373735F97970097975F97975F979700975F5F97975F97975F97975F5F97
5F97975F979700975F5F97975F979797C597A7A7A75F97975F97975F5F975F979797C597
A7A7A75F97978585859797975F97C55F97975F97975F97975F97975FC5975F97C5A7A7A7
5F97975F97975F97975F97975F97975F97975F975F5F5F5F2C2C2C2C2C2C002C002C2C2C
2C2C2C002C002C2C2C2C2C2C00002C4900004900002C2C2C00002C00002C2C00002C2C2C
2C2C2C002C00002C002C2C2C000000002C002C2C2C000000000000002C00002C00490000
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00002C002C2C2C
002C002C2C2C002C004900002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C
2C000000002C002C000000002C2C2C00002C00002C2C2C2C002C002C2C2C2C2C2C2C2C2C
00002C002C002C2C2C2C2C2C2C2C2C00002C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C002C002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0049002C2C2C002C00
2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
0049002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C4900002C0000002C00
2C2C2C2C2C2C2C2C2C2C2C2C
005F5F005F5F005F5F5F5F5F005F5F005F975F9797005F5F005F5F5F5F5F5F5F5F005F5F
494949494949005F5F49494997975FC59797C5C597C5975FC55F5F975F5F5F5F5F97975F
5F975F97975F97975F5F5F5F5F5F00005F005F5F00494949494949494949005F5F494949
494949494949002C00005F004949495F5F5F2C2C2C494949494949494949005F00494949
494949494949007300005F5F494949494949005F000049002C2C2C4949495F5F5FE1E1E1
C5C5975F5F00494949494949005F5F4949492C2C2C2C2C2C4949492C2C2C4949492C2C2C
4949495F5F5F2C2C2C5F5F004949492C2C2C5F5F00005F00005F002C2C2C2C2C2C494949
2C2C2C002C000049000049005F5F00004900007300B6B6B649494997975F5F975F005F00
007300858585494949A7A7A78585855F5F005F975F5F5F004949494949492C2C2C2C2C2C
4949492C2C2C4949494949494949494949495F5F005F5F00005F5F5F975F5F975F5F975F
97975F8585855F5F5F7373735F5F5F73737300975F005F5F5F5F5F00975F005F5F009797
5F97975F5F5F7373735F97975F97970097975F975F5F975F5F975F5F975F00975F00975F
0097975F5F970097975F97975F97975F97975F97975F97975F97975F97975F97975F9797
97C5975F97975F97975F97975FC5975F97975F97975F97975F97975F9797A7A7A75F9797
A7A7A75F97978585855F97975F97975F97975F5F975F975F4949492C2C2C002C00002C00
2C2C2C2C2C2C2C2C2C2C2C2C000000002C000000002C00002C2C2C2C2C2C00002C2C2C2C
2C2C2C4900002C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C0000000000002C002C2C2C
0000002C2C2C2C2C2C002C00002C00002C002C2C2C2C2C2C002C002C2C2C000000490000
2C2C2C49000000002C2C2C2C2C2C2C0000002C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C
002C002C2C2C2C2C2C2C2C2C2C2C2C4949492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
002C002C2C2C002C002C00002C2C2C002C002C00002C2C2C00002C2C2C2C2C2C2C2C2C2C
002C00002C002C2C2C002C0000002C2C2C2C2C2C2C2C2C2C002C00002C002C2C2C2C2C2C
2C2C2C002C002C2C2C2C2C2C0049002C2C2C0000490000490049002C2C2C2C2C2C2C2C2C
0049002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
490000002C002C0000494949
005F5F005F5F00975F5F5F5F5F5F5F5F975F5F9797494949005F5F4949495F5F5F5F5F5F
5F5F5F494949005F5F97975FC5975FC59797C5975FC55F5F975F00737373C5975F5F5F5F
5F975F005F5F5F975F5F5F5F4949495F5F004949492C2C2C5F5F002C2C2C5F5F00005F00
4949492C2C2C5F5F002C2C2C5F5F5F007300494949005F005F5F5F5F5F00005F5F494949
2C2C2C4949492C2C2C005F004949494949492C2C2C494949005F5F005F0097C5C5C5C5C5
494949494949005F00007300005F002C2C2C005F002C2C2C2C2C2C5F5F002C2C2C005F00
4949494949492C2C2C005F002C2C2C2C2C2C005F002C2C2C0049002C2C2C002C002C2C2C
0049000049002C2C2C2C2C2C4949494949494949497373735F5F5F2C2C2C975F5F2C2C2C
2C2C2C8585855F5F5F9797979797975F5F5F975F5F005F5F5F5F5F2C2C2C2C2C2C494949
494949494949005F005F5F005F5F005F5F005F5F5F5F5F5F5F5F5F5F975F5F5F5F5F975F
73737373737397975F97975F5F975F005F97005F5F005F5F5F5F5F5F5F5F5F975F5F9797
8585855F97975F97975F5F977373735F975F00979700975F009797009797005F5F009797
5F97975F97975FC5975F97C55F97975F9797A7A7A75F97975F97975F97975F9797979797
9797975F97975F97975F97979797975F97975F97C55F97975F97979797975F9797979797
A7A7A75F97975F97975F5F975F97975F97975F97975F9797005F5F2C2C2C2C2C2C2C2C2C
2C2C2C002C00002C0000002C2C2C2C002C00002C00000000002C00002C0049000000002C
2C2C2C002C002C0000002C002C2C2C4900002C2C2C2C2C2C002C002C2C2C2C2C2C00002C
2C000049000000002C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C000000002C00002C002C00
2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C4900002C2C2C002C002C2C2C2C2C2C2C2C2C
00002C00002C00002C2C2C2C2C2C2C2C2C2C002C0000002C2C2C2C2C2C2C002C002C2C2C
2C2C2C2C2C2C0000002C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C002C0000002C000000
00002C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
00002C2C2C2C2C2C2C2C2C2C2C2C2C002C004949490000002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C00002C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C002C004900002C2C2C
2C2C2C2C2C2C002C002C2C2C
005F5F005F5F5F5F5F005F5F5F5F5F5F5F975F5F5F005F5F005F5F5F5F5F5F5F5F5F5F5F
5F5F5F49494997975FC5975FC5C55FC5975FC5975FB60000975F0097975F97975F97C597
97975F5F975F5F5F005F5F00005F5F5F5F5F0049002C2C2C5F5F5F5F5F5F494949494949
494949494949494949002C00005F002C2C2C4949494949494949490073004949495F5F00
005F5F494949005F005F5F005F5F5F4949494949494949494949495F9797C5C5EF5F5F5F
005F002C2C2C494949005F004949492C2C2C2C2C2C4949492C2C2C4949490049005F5F00
004900005F00005F002C2C2C4949492C2C2C2C2C2C4949492C2C2C005F004949492C2C2C
004900002C002C2C2C5F5F5F5F5F5F494949A7A7A75F5F5F4949495F975F5F5F5F5F5F00
0049005F5F5F4949494900002C2C2C494949005F5F5F5F5F4949494949494949492C2C2C
4949495F5F005F5F004949495F5F00494949007300005F5F5F5F5F73737385858597975F
8585858585855F97975F97975F975F5F975F005F97005F9700975F5F975F5F97975F9797
9797978585855F97975F97975F97975F9797005F975F5F5F00975F5F97975F97975F9797
5F97975F97975F97975F97975F97975F97C55F97975F97975F97975F97975F975F979797
5F97975F97975F97975F97975FC5975F97975F97975F97975F97975F97C55F97975F9797
979797A7A7A75F97975F97975F97975F97975F97975F5F9700975F2C2C2C2C2C2C00002C
2C2C2C2C2C2C2C2C2C00002C002C002C00000000002C2C2C00002C490000002C00490000
2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C490000002C00002C002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C00002C002C00002C2C2C4900002C2C2C
00002C2C2C2C00002C00002C2C00002C2C2C002C002C00004900002C2C2C2C2C2C2C2C2C
0000002C2C2C00002C002C00002C002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C00002C
2C2C2C002C000000002C2C2C00002C002C00002C002C2C2C2C000000002C2C2C2C002C00
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C0000002C2C2C
2C2C2C002C002C2C2C2C2C2C0049002C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C
002C002C2C2C2C2C2C002C002C2C2C2C2C2C002C002C2C2C2C2C2C002C00002C002C2C2C
00002C2C2C2C2C2C2C2C2C2C
005F97005F5F00975F5F975F5F5F5F7373735F975F5F5F5F5F5F5F005F5F005F5F005F5F
005F5F5F5F5F97975FC5C55FC5975FC5975F975F5F975F005F975F97975F7373735F5F5F
737373005F5F4949492C2C2C5F5F5F5F5F00002C000000492C2C2C2C2C2C5F5F00494949
494949004900494949494949005F5F494949005F00005F002C2C2C005F5F5F5F00005F5F
4949495F5F5F5F5F5F494949005F5F2C2C2C004900005F5F5F9700C5C5EFC5C597494949
005F004949492C2C2C494949005F5F5F5F00005F5F4949495F5F005F5F00494949494949
4949492C2C2C5F5F00005F002C2C2C004900494949494949005F002C2C2C2C2C2C007300
49494949494900490049494949494949494997975F005F00005F5F8585855F5F5F494949
2C2C2C494949858585494949005F5F4949492C2C2C2C2C2C005F5F5F5F5F005F5F494949
2C2C2C494949004900007300494949494949005F5F5F5F5F5F5F005F5F5F979797858585
5F9797009797009797005F9700975F5F5F5F5F5F5F005F5F5F975F5F97975F9797979797
5FC5C55F97975F9797979797737373009797737373005F5F005F5F5F5F975F97975F9797
5F97975F9797005F975FC597979797A7A7A797C5975F97970097975F97970097975F9797
5F97975F97975F97975F97975F97C55F97975F97975F97975F97975F97975F9797979797
97979797C5975F97C55F97975F97975F97975F97970097977373735F5F5F2C2C2C2C2C2C
002C0000002C002C002C00002C00002C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C002C00
2C00000000002C00002C2C2C2C2C2C4900002C2C2C00002C2C2C2C2C2C2C2C2C2C002C00
2C2C2C0000002C00002C2C2C002C0000002C000000002C000000002C00002C2C2C000000
2C2C2C0000002C2C2C2C000000002C2C2C2C00002C2C2C2C002C002C2C2C002C00002C00
0000002C2C2C002C00000000002C002C0000002C0000002C4900002C2C2C00002C000000
002C002C2C2C002C002C2C2C2C2C2C00002C002C002C2C2C2C2C2C00002C2C2C2C2C2C2C
2C2C2C002C0000002C2C2C2C002C002C2C2C002C002C2C2C002C000000002C2C2C002C00
2C2C2C2C2C2C2C2C2C002C0000002C4949490049002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C002C2C2C2C2C2C00002C002C0000002C00002C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C494949
005F5F5F5F5F005F97005F5F5F5F5F5F979700975F005F5F005F5F005F5F5F5F5F005F5F
005F5F97979797C55FC59797C5975FC55F00975F007373735F5F5F5F975F5F975F5F975F
5F5F5F4949494949492C2C2C2C2C2C2C2C2C002C00494949494949005F5F494949005F5F
2C2C2C005F004949495F5F5F5F5F5F4949495F5F5F4949495F5F00494949005F5F5F5F5F
4949494949494949495F5F5F5F5F002C2C2C2C2C2C2C2C2C97C5C5D4D4D4494949494949
494949494949494949494949005F5F494949005F5F2C2C2C494949494949494949005F5F
2C2C2C002C004949494949494949494949494949495F5F5F494949005F5F4949495F5F5F
7373735F5F5F005F00005F004949495F5F5F4949494949498585855F975F5F5F5F005F5F
005F97A7A7A7005F5F5F5F5F8585855F975F2C2C2C0049005F5F5F494949494949005F00
005F000000492C2C2C0073005F5F5F4949495F5F5F5F5F005F5F0097975F9797975F9797
5F97970097970097975F9797005F5F0097975F97975F5F5F5F97975F9797737373979797
A7A7A79797975F97975F97975F5F970097975F5F975F5F975F97975F97975F97975F9797
5F97C55F97970097975F97975F9797A7A7A79797975F97970097975F97975F97975F9797
5F97975F97975F97C55F97C55F97975F97975F97975F97975F97C55F97C55F97C55F97C5
5F97C55F97C55F97C55F97C55F97975F97977373738585855F97974949492C2C2C2C2C2C
2C2C2C002C002C2C2C2C2C2C0000002C2C2C2C0000000000000000002C002C2C2C002C00
2C2C2C00002C2C2C2C002C002C2C2C00002C4900002C2C2C2C2C2C2C00000000002C2C2C
002C00002C002C2C2C4900002C2C2C002C002C2C2C2C2C2C0000002C2C2C2C2C2C000000
00002C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C4900002C2C2C000000002C002C0000
2C2C2C002C002C2C2C2C2C2C00002C2C2C2C2C2C2C00002C2C2C2C00002C0000002C2C2C
0000002C2C2C2C2C2C00000000002C00002C00002C2C2C2C2C2C2C002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C002C002C2C2C2C2C2C
2C2C2C2C2C2C004900004900002C002C2C2C2C2C2C2C2C2C0049002C2C2C2C2C2C00002C
00002C2C2C2C2C2C2C2C2C2C2C2C2C002C0000002C2C2C2C002C002C2C2C2C00002C2C2C
00002C0000002C00002C2C2C
005F5F5F5F975F5F5F005F5F005F5F737373005F5F005F5F005F5F4949494949495F5F5F
005F5F5F975F979797C5979797975F975F005F5F007373735F5F5F97975F5F5F5F5F5F5F
005F5F4949490049000049002C2C2C0049002C2C2C2C2C2C4949494949492C2C2C5F5F00
2C2C2C0049004949495F5F5F494949005F005F5F5F494949005F00005F5F005F00005F5F
005F5F5F975F5F5F5F5F975F005F00005F00002C002C2C2CD4D4D44949494949492C2C2C
4949495F5F5F2C2C2C005F00005F00005F5F005F5F2C2C2C2C2C2C4949492C2C2C2C2C2C
494949005F004949495F5F00494949494949494949005F002C2C2C7373735F5F5F494949
5F5F5F494949005F005F5F000073004949494949495F979797975F005F5F7373735F5F5F
A7A7A797975F5F5F5F5F5F5F4949494949494949495F5F5F5F975F5F5F5F494949005F5F
2C2C2C4949494949495F5F5F4949495F5F005F975F5F5F5F5F5F5F97975F7373735F9797
5F97C55F97975F97975F5F970097975F97975F97975F97975F975F5F9797A7A7A7A7A7A7
5F97975F97C55F97975F97975F97975F979700979700975F5F97975F97975F97C55F9797
5F97975F97975F97C55FC5975F9797A7A7A75F97C55F97975F97975F9797A7A7A75F97C5
5F9797A7A7A75FC5C55F9797A7A7A75FC5C55F97C55F9797A7A7A75F97975F97C55F9797
5F97C5979797A7A7A79797979797975F97C55F97C55F97C55F5F975F5F5F005F5F2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C002C00002C00002C2C2C00002C00002C
2C00002C2C2C00002C2C2C2C002C002C2C2C00002C2C2C2C00002C2C2C2C2C00002C2C2C
2C2C2C2C2C2C000000002C002C0000002C0000002C00002C00002C002C002C2C2C490000
2C2C2C490000002C002C2C2C00002C2C2C2C002C002C2C2C2C2C2C00002C490000002C00
002C0049000000002C2C00002C2C2C2C2C2C2C2C2C002C002C2C2C00002C2C2C2C2C2C2C
2C0000002C00005F5F2C2C2C00002C0000002C2C2C2C2C2C2C2C2C2C2C2C00002C00002C
2C2C2C2C2C2C00002CA7A7A72C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C0000002C2C2C0049002C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C002C2C2C002C002C2C2C00002C002C002C2C2C00490000002C2C2C2C
2C2C2C2C00002C2C2C2C2C2C
5F5F5F005F5F5F5F5F005F5F5F5F97737373005F5F005F5F005F5F5F975F494949005F5F
005F5FA7A7A797C597EF975F5F5F5F5F5F5F5F5F005F5F5F5F5F5F5F5F5F737373005F5F
4949494949492C2C2C0049002C2C2C4949494949492C2C2C4949492C2C2C494949005F5F
2C2C2C005F5F005F5F005F00494949005F00494949005F5F000049494949005F5F005F00
5F5F00005F5F005F5F5F975F005F005F5F0049494997C5C5C597005F9700494949007300
4949490073005F5F00005F004949494949492C2C2C2C2C2C2C2C2C0049002C2C2C005F00
005F00004900005F004949494949495F5F0049494900005F4949495F5F5F005F5F5F5F5F
494949005F00005F00005F5F4949492C2C2C005F009797002C2C2C2C2C2C5F975F5FC597
5F5F97A7A7A75F5F5F5F5F5F5F5F5F494949005F5F5F975F005F5F4949494949492C2C2C
0049004949494949494949495F5F005F5F005F5F5F5F5F5F7373735F97978585855F9797
5F97975F97C50097975F97C55F97C5A7A7A75F97970097975F97C59797979797975F9797
5F5F975F97979797975F97975F97C55F97975F97970097970097975F97975F9797979797
5F97C55F97975F97979797975FC5C59797C55F5F975F97970097975F97975F9797009797
5F5F970097975F97975FC5975F97C5A7A7A75F97975F97975FC5C55F97C55F97C55F97C5
9797975F97975F9797A7A7A79797975F97975F97975F97975F9797005F5F4949492C2C2C
2C2C2C2C2C2C2C2C2C002C002C2C2C000000002C0000002C00002C00002C00000000002C
00002C2C2C2C2C2C2C2C2C2C2C00002C00002C2C2C2C2C2C002C00002C002C2C2C002C00
2C2C2C2C2C2C00002C4900002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C00002C
2C2C2C00002C0000002C2C2C00002C2C2C2C002C00002C00002C0000000000002C000000
2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C002C000000002C2C2C2C2C2C2C2C2C00002C
2C2C2C2C2C2C00002C2C2C2C00002C2C2C2C2C2C2C002C002C2C2C00002C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C5F5F5F002C002C2C2C002C002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C0000492C2C2C2C2C2C005F5F2C2C2C2C2C2C2C2C2C002C00
2C2C2C002C002C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C
002C002C2C2C2C2C2C2C2C2C
5F5F97005F5F005F5F005F5F7373735F5F5F5F5F5F005F5F005F5F005F5F005F5F005F5F
5F5F5F5F975F5F975FEF975F975F5F5F5F5F5F5F5F5F975F975F5F97975F737373494949
4949494949494949492C2C2C4949494949492C2C2C005F5F494949005F002C2C2C2C2C2C
005F002C2C2C5F5F00494949005F00494949494949005F00005F5F5F5F5F5F5F5F494949
5F5F004949495F5F5F005F002C2C2C4949495F5F97C5C5C5005F5F5F5F5F5F5F00005F00
4949495F5F004949494949490049002C2C2C2C2C2C4949494949492C2C2C2C2C2C5F5F00
005F004949495F5F002C2C2C2C2C2C49494997975F005F005F5F5F4949495F5F5F494949
494949005F00005F00005F5F5F975F005F004949494949495F5F5F494949858585B6B6B6
8585857373734949497373734949495F975F5F5F5F4949495F5F00005F00007300005F5F
005F5F5F5F5F494949494949005F000073005F5F5F5F975F5F5F5F8585858585855F9797
5F97C59797975F97C55F97C55F97979797C55F97970097975F9797009797005F975F9797
5F97975F5F97A7A7A7A7A7A7A7A7A75F97C55F97975F97975F5F97A7A7A79797975F9797
97C5975F97C55F97979797975F97C55F97975F97C55F97975F97975F5F975F97975F9797
5F97975F97975F97975F97975F97975F97C55F9797005F975F97979797979797975F9797
5F97979797975F97C55F9797979797A7A7A75F97975F97C55F97C55F5F975F5F5F2C2C2C
2C2C2C2C2C2C2C2C2C2C0000002C00002C000000002C2C2C2C2C2C2C00002C0000002C00
2C2C2C2C2C2C49000000000000002C2C2C2C2C2C2C2C2C2C4900002C2C2C2C2C2C002C00
2C0000002C000000002C2C2C2C2C2C00002C2C2C2C2C2C2C002C002C00002C2C2C000000
00002C2C2C2C00002C00002C002C002C2C2C2C2C2C2C2C2C2C2C2C00002C0000002C0000
2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C00002C00002C2C2C2C2C2C2C00002C2C2C2C
858585002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C002C00
2C2C2C2C2C2C002C002C2C2C00002C00002C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C
002C002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C002C0000002C002C002C2C2C2C2C2C00002C2C2C2C2C2C2C2C0000
002C0049000000002C2C2C2C
005F5F5F5F5F5F5F975F9797737373005F5F494949005F5F005F5F005F5F494949494949
005F5F5F975F5F975F97975F5F97005F975F5F975F5F5F5F975F5F5F5F5F494949494949
4949494949492C2C2C005F004949492C2C2C0049002C2C2C4949492C2C2C2C2C2C494949
2C2C2C4949495F5F00004900494949005F004949494949494949495F5F5F5F5F5F494949
4949495F5F00494949004900005F5F5F5F5FC5C5EF97975F5F5F5F0073005F975F494949
4949495F5F004949494949494949495F5F5F494949005F002C2C2C2C2C2C2C2C2C007300
2C2C2C494949005F002C2C2C005F004949494949495F5F004949492C2C2C5F5F00005F5F
5F5F005F5F004949495F97975F5F005F5F5FA7A7A7979797005F00005F00494949979797
A7A7A77373737373735F97977373735F5F5F0073005F975F5F975F005F005F5F5F5F5F5F
5F5F005F5F000049002C2C2C4949495F5F005F5F5F005F5F5F5F0097C597009797979797
5F9797A7A7A75F97C55FC5C55FC5C55F97C55F97975F97975F9797005F975F97975F9797
5F97975F97C5A7A7A75F97C55F97C55F97975F97975F97975F97C55F97C55F97C5979797
5FC597A7A7A75F97979797979797975F97C55F97970097975F5F979797975F9797737373
005F975F97975F97C55F97C55F97C55F97975F97970097975FC5C55F97975F97C55F97C5
5F97C5A7A7A75F97C55FC597A7A7A75F97975F97975F97975F97975F9797737373494949
2C2C2C2C2C2C2C00002C2C2C2C2C2C2C00000000002C2C2C2C2C2C0000002C2C2C002C00
2C2C2C00002C002C00002C008585852C2C2C00002C002C002C2C2C0000002C00002C2C2C
002C002C2C2C2C2C2C2C2C2C00002C002C002C2C2C002C0000002C002C00002C0000002C
2C0000002C002C2C2C2C2C2C49000000002C2C2C2C2C2C2C2C2C2C00002C2C000000002C
00002C002C002C2C2C002C002C2C2C2C2C2C0000002C2C2C2C2C2C2C2C2C002C00000000
2C2C2C002C0000002C2C2C2C2C2C2C2C2C2C2C2C2C00002C00002C002C002C2C2C2C2C2C
002C002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C
2C2C2C2C2C2C2C2C2C0000002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C00002C002C2C2C2C2C2C4949492C2C2C2C2C2C2C2C2C5F00002C2C2C
002C002C2C2C2C2C2C2C2C2C
7373735F5F5F5F5F5F005F5F005F5F005F5F005F5F494949005F5F4949495F975F005F5F
5F5F5F5F5F5F975F5F975F005F5F0049494997975F5F5F5FC597974949492C2C2C2C2C2C
4949495F5F5F4949494949495F5F004900002C2C2C4949492C2C2C494949494949494949
2C2C2C5F5F0000002C2C2C2C2C2C2C005F00494949494949005F005F5F00005F00494949
5F975F5F5F5F4949492C2C2C5F5F5F97C5C5C5C597494949007300005F00737373494949
2C2C2C005F00005F00005F000049004949495F5F00005F5F2C2C2C2C2C2C2C2C2C004900
005F5F494949005F004949494949494949492C2C2C5F5F5F5F975F5F975F858585494949
0097977373734949495F5F5F005F5F5F5F5F97979797975F4949494949495F5F5FC5C597
A7A7A77373734949490049002C2C2C5F5F004949494949495F5F002C2C2C005F5F5F5F5F
5F5F005F5F004949495F5F005F5F007373735F5F5F97975F5F5F5F0097975F97970097C5
5F9797979797A7A7A7A7A7A75FC5C55F97975F97975F97970097975F9797A7A7A797C5C5
A7A7A79797975F97C55F97975F97975FC5975F97C55F97975F9797979797A7A7A797C5C5
9797C59797C55F97975F97979797975F97975F97975F97975F97970097975F97975F9797
5F97975F97C55F97975FC5C5A7A7A75F97C55F97975F97975F97975F97975F97975F9797
A7A7A79797979797C55F97C55F97975F97C55F97975F97975F97975F97975F97975F975F
4949492C2C2C2C2C2C2C2C2C2C2C2C00002C2C0000002C004900002C2C2C002C002C0000
002C00002C00002C002C2C2C2C2C2C2C2C2C2C2C2C00002C2C00000000002C2C2C2C0000
00002C002C002C2C2C2C2C2C002C002C2C2C2C2C2C2C0000002C002C2C2C002C00002C00
00002C2C2C2C2C2C2C2C2C2C002C002C2C2C00002C2C2C2C002C002C2C2C002C002C2C2C
2C2C2C2C2C2C002C0000005F2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00000000002C00002C
00002C0000002C2C2C2C2C2C2C2C2C00000000002C002C0000002C2C2C2C00002C000000
2C2C2C2C2C2C00002C00002C2C2C2C2C2C2C2C2C2C0000002C2C2C002C002C2C2C002C00
2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00
2C2C2C002C0000002C2C2C2C2C2C2C2C2C2C000000002C002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C49000000002C2C2C2C
5F5F5F5F5F9700975F5F5F5F5F5F5F4949494949495F5F004949495F5F5F494949494949
5F5F5F73737397975F49494997975F5F5F5F5F975F97975F5F975F2C2C2C0049002C2C2C
2C2C2C5F5F5F5F5F00494949005F00494949005F000073002C2C2C2C2C2C4949492C2C2C
4949492C2C2C4949492C2C2C4949495F5F5F5F5F5F005F00494949005F004949495F5F5F
5F5F5F5F975F5F5F5F5F5F0073737397C5C54949495F5F5F4949494949494949495F5F5F
4949495F5F005F5F00005F00005F002C2C2C005F00494949005F005F5F00494949005F00
5F5F005F5F5F494949494949005F5F5F5F5F5F5F5F5F5F5F5F5F5F5F97975F97975F9797
5F5F5F5F5F5F0073005F5F5F5F97975F5F975F5F5F9797975F5F5F0000735F5F5F979797
5F975F4949495F5F5F7373735F5F5F005F005F5F5F5F5F5F5F5F00005F004949495F975F
5F5F5F5F5F007373735F5F00005F002C2C2C97975F85858500975F009797005F975F5F97
A7A7A75F97975FC5C55FC5C597C5C55F979797C5C55F97975F97C55F97975F9797A7A7A7
7373735F97975F97975F97975F97975F97978585855F97C55F97975F97979797979797C5
5F97C59797C55F97C55F97975F97975F97975F97975F97975F97975F97977373735F9797
A7A7A75F9797A7A7A75F97975F97975F97975F97975F97C55F97C55F97975F9797A7A7A7
A7A7A75F97C55F97C5979797979797979797A7A7A79797975F97C59797975F97975F5F5F
4949492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00000000000000002C00002C000000002C
00002C2C2C2C2C2C2C2C2C2C2C2C2C00002C0000002C00000000000000002C2C2C00002C
2C2C2C002C002C2C2C002C002C2C2C2C2C2C2C2C2C00002C00002C2C2C2C2C2C2C2C2C2C
2C2C2C00002C2C2C2C2C2C2C2C2C2C002C0049000000002C0000000000002C2C2C002C00
00002C00002CB6B6B6C5C5975F5F5F2C2C2C2C2C2C0000002C2C2C0000002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C002C002C2C2C0000002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C0000492C2C2C2C2C2C2C2C2C
00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
002C0000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C
005F975F975F5F5F97005F5F005F5F5F5F5F005F5F005F5F5F5F5F4949495F5F5F494949
737373C5C59797975F9797975F5F5F97975F5F975F5F5F5F4949494949492C2C2C494949
4949495F5F5F5F5F00494949005F00005F5F494949494949005F00494949005F002C2C2C
007300004900004900494949494949005F5F2C2C2C4949495F5F00005F00005F00494949
5F975F49494949494973737397C5EFC597005F975F0085005F5F5F5F975F2C2C2C5F9797
975F5F5F5F5F4949494949495F5F00005F00494949005F005F5F00005F5F004900494949
5F5F5F5F5F004949494949494949494949495F5F5F5F975F0073005F5F5F4949495F5F5F
8585859797975F5F5F5F5F5F5F5F5FA7A7A75F975FB6B6B65F97977373735F975F5F5F5F
494949494949737373005F5F5F5F00005F005F5F5F4949495F5F5F4949495F97005F5F5F
97975F494949975F5F5F5F5F5F5F005F5F5F97975F5F5F5F7373735F97975F97975F97C5
A7A7A75F97975F97975F9797A7A7A7A7A7A7A7A7A797C5C59797975F97975F979797975F
5F97975F5F975F97970097975F97975F97975F97C55F9797A7A7A797979797C5C55F9797
5F97975F97975F97975F97975F97978585855F97975F97975F97975F97975F5F97009797
5F9797A7A7A75F9797A7A7A75F97C55F97975F97975F97975F97975F97975F9797A7A7A7
5F97978585855FC5C5979797A7A7A79797979797975F97975F97975F97975F97975F5F97
4949492C2C2C2C2C2C2C2C2C2C2C2C002C002C000000002C2C2C2C002C002C0000002C00
5F97972C2C2C002C00490000002C002C2C2C002C0000002C2C2C2C2C2C2C00002C2C2C2C
2C2C2C490000002C00002C0000000000002C2C2C2C002C0000000000002C002C0000002C
002C002C2C2C2C2C2C2C2C2C00002C0000002C2C2C00002C002C000000000000002C0000
2C00004900000000002C2C2C2C2C2C0000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
002C000000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C0000002C2C2C2C
2C2C2C00002C2C2C2C2C2C2C00002C2C2C2C0049005F5F972C2C2C00002C002C002C2C2C
002C002C2C2C002C002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00002C002C2C2C2C2C2C00002C2C2C2C
00490000002C2C2C2C2C2C2C
005F5F005F5F979797005F5F005F5F005F5F005F5F005F5F005F5F4949494949495F5F5F
737373A7A7A797C597975F005F5F00C55F5F737373C5C55F5F5F5F5F5F002C2C2C494949
005F5F4949494949495F975F4949494949492C2C2C4949492C2C2C494949005F00494949
494949494949494949005F5F4949495F5F000073004949492C2C2C007300005F5F005F00
5F5F5F5F5F5F5F975FC5C5EFC5C5974949495F97005F5F5F005F5F005F5F005F00004900
7373734949492C2C2C2C2C2C4949490049004949495F5F002C2C2C4949495F5F005F5F00
5F5F5F4949494949495F5F00494949005F5F9797975F5F5F979797005F5F5F975FB6B6B6
A7A7A77373735F975F7373735F5F5F73737397975FA7A7A75F5F5F5F5F005F5F5F005F5F
4949492C2C2C2C2C2C005F5F005F5F005F5F494949005F5F005F5F005F5F005F005F5F00
7373735F97975F975F7373735F5F5F5F5F5F5F5F5F5F5F975F5F5F9797975F97975F9797
5F9797A7A7A75F9797A7A7A75F97975F97975F9797A7A7A70097975F97977373735F9797
5F979700975F005F975F97978585855F97975F97975F97975F97979797C55F97975F9797
5F97975F97975F97975F97978585855F97975F9797A7A7A75F97975F97975F975F009797
5F97975F97975F97C55FC5C55F97975F97975F97975F97975F97975F97975F9797979797
8585855F9797A7A7A7979797A7A7A797C597A7A7A75F97975F97975F97975F97975F9797
5F5F5F4949494949492C2C2C2C2C2C002C0000002C2C2C2C2C2C2C2C2C2C00002C002C00
2C00002C2C2C002C00002C00002C002C2C2C00002C2C00002C2C2C2C2C2C2C2C2C00002C
490000002C00002C0000002C2C2C2C00002C2C2C2C0000000000000000002C00002C2C2C
2C0000002C005F5F972C2C2C00002C2C000000002C2C2C2C00002C00000000000000002C
002C00002C00002C002C2C2C2C2C2C00000000002C002C002C2C2C2C2C2C2C2C2C002C00
00002C2C2C2C00002C002C002C2C2C002C002C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C002C0000002C2C2C2C0049000049004949492C2C2C2C2C2C00002C2C2C2C2C2C2C
002C002C2C2C2C2C2C002C002C2C2C2C2C2C0049002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C4949492C2C2C2C2C2C2C00002C2C2C
2C2C2C002C002C2C2C2C2C2C
005F5F005F5F5F5F5F5F5F5F005F5F005F5F005F5F005F5F5F5F5F4949495F5F5F005F5F
5F5F5FC5C55F5F5F5F5F5F005F5F00975F005F975F5F975F005F5F4949492C2C2C005F00
002C005F5F5F5F5F00494949005F00005F002C2C2C5F5F00494949005F002C2C2C005F00
005F002C2C2C2C2C2C5F5F5F494949494949005F5F2C2C2C2C2C2C007300494949005F5F
5F5F5F5F5F005F975F97C5C55F5F00004900005F5F5F5F00000049005F5F005F00004900
494949005F002C2C2C2C2C2C0049000049005F5F005F5F5F5F5F5F5F5F005F975F5F5F00
4949495F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F005F5F5F5F5F7373735F9797858585
9797975F97978585855F97975F9797979797858585858585B6B6B6737373494949C5C597
5F5F004949494949494949490049004949495F5F5F2C2C2C4949495F5F005F5F005F5F00
97975F975F5F5F5F975F975F737373005F5F005F5F00975F5F97975F9797979797979797
5FC597A7A7A7A7A7A7979797A7A7A79797C55F97975F97970097975F5F5F5F975F009797
005F5F5F5F5F5F97975F97975F97975F97975F97975F97975F9797A7A7A75F97975F9797
5F97979797975F97977373735F975F0097970097975F97975F97975F97975F9797009797
5F979797979797C5C55F97975F97970097970097975F97975F97975F97C55F97975F9797
979797A7A7A75F97C5A7A7A7A7A7A79797975F97975F97C55F97975F97C55F97975F9797
5F975F4949492C2C2C2C2C2C2C2C2C2C2C2C00002C4949492C2C2C2C2C2C2C2C2C2C2C2C
0000002C2C2C2C2C2C2C2C2C2C2C2C49000000002C002C004900002C2C2C2C2C2C2C2C2C
002C002C2C2C2C2C2C002C002C2C2C2C2C2C002C00002C00002C002C2C2C002C002C2C2C
002C002C2C2C2C2C2C2C2C2C2C2C2C002C002C0000002C00000000000000490000002C00
0000002C2C2C2C2C2C00002C00002C2C00002C00002C2C2C2C2C2C00002C002C002C2C2C
002C002C2C2C0000000000002C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C5F9797002C002C2C2C2C2C2C
00002C00002C2C2C2C2C2C2C2C2C2C00002C4949492C2C2C00002C002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C002C00490000
002C002C2C2C2C2C2C2C2C2C
005F5F005F5F5F97975F5F5F005F5F5F975F005F5F005F5F005F5F005F5F5F5F5F5F975F
5F975FC5C59797975F4949495F5F00975F5F97975F5F5F5F5F5F5F5F5F5F2C2C2C97C55F
005F5F4949492C2C2C002C00005F002C2C2C4949494949492C2C2C2C2C2C005F5F737373
005F002C0000005F002C2C2C4949495F5F005F5F5F494949004900005F00005F00005F00
5F97005F975FC5EFEF5F5F5F5F5F5F5F5F004949495F5F005F5F00005F00005F002C2C2C
005F005F975F494949494949005F005F5F005F5F00005F5F5F5F5F5F5F00494949005F00
4949495F5F5F5F5F5F5F5F5F5F5F5F737373737373494949737373737373494949979797
A7A7A7B6B6B6A7A7A75F5F5F979797858585737373B6B6B6A7A7A749494997975F97975F
2C2C2C5F5F005F5F002C2C2C2C2C2C5F5F5F4949495F5F5F4949495F5F005F5F00002C00
5F5F5F5F975F5F975F5F975F005F5F005F9700975F8585855F97975F97975F9797979797
9797975F97C59797979797975F97975F97975F97975F97970097977373735F975F00975F
00975F5F97977373737373735F97975F97975F97975F97979797979797975F9797979797
5F97975F97975F97975F5F975F97975F97975F97975F97975F97975F97975F9797009797
5F97975F97C50097C55F97978585859797975F97975FC5C55F97975F97978585855F9797
A7A7A75F97975F97C59797C5A7A7A7A7A7A75F97C55F97975F97C55F97C5979797858585
5F975F005F5F2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C002C004900002C2C2C2C2C2C
00002C2C2C2C2C2C2C5F5F5F0000002C2C2C2C2C2C00002C002C002C2C2C2C2C2C002C00
2C2C2C002C002C2C2C2C2C2C000049002C00002C00000000490000002C00002C002C2C2C
2C2C2C2C2C2C002C00002C000000002C2C2C002C002C0000000000002C00002C00000000
000000002C0000002C2C2C2C002C0000002C002C00002C000000002C2C2C2C2C2C2C2C2C
002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C
4949492C2C2C00002C002C002C2C2C2C2C2C5F5F972C2C2C2C2C2C0000002C2C2C2C2C2C
00002C2C2C2C002C002C2C2C2C2C2C002C005F5F5F2C2C2C002C002C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C490000002C00
2C2C2C2C2C2C2C2C2C2C2C2C
5F5F5F7373735F5F5F5F5F5F4949495F5F5F4949495F5F5F5F5F5F4949495F5F5F5F975F
A7A7A7C5975F975F5F4949499797005F975F494949005F00005F5F5F5F5F2C2C2C2C2C2C
4949492C2C2C4949495F5F000073002C2C2C5F975F5F005F5F5F002C2C2C5F975F494949
5F5F00005F5F5F5F5F005F5F4949494949490073005F5F004949490073004949495F9700
5F5F5F97C5C5B6B6B62C2C2C5F975F5F5F00007300005F005F5F5F5F975F005F00494949
4949495F5F5F494949494949005F5F4949490049002C2C2C5F5F5F5F5F00005F5F007300
4949495F5F5F5F5F5F5F5F5F737373A7A7A78585855F97975F97975F5F97858585737373
5F975F97C5C5B6B6B6A7A7A7737373A7A7A7A7A7A77373735F5F5F9797975F975F494949
0049004949490049004949495F5F5F5F5F5F005F5F4949490049005F5F005F5F005F5F00
975F5F5F5F5F005F97009797009797005F5F7373735F97975F97975F97975FC5C5A7A7A7
9797975F97975F97C59797975F97975F97975F97977373735F97975F97975F97975F5F5F
7373735F97975F5F5F5F97977373735F97977373735F97975F9797A7A7A75F97975F9797
5F97975F9797005F975F5F975F97975F97975F5F97005F970097975F97975F97975F9797
5F97979797975F97970097975F97975F97975F97975F97975F97975F97975F9797979797
9797975F97C55F97975F9797979797A7A7A79797975F97975F97975F97975F97975F97C5
5F97977373734949492C2C2C002C002C2C2C002C0000002C002C002C0000002C00490000
2C2C2C2C2C2C2C2C2C002C002C00002C00002C2C2C2C2C2C2C2C2C2C2C2C00002C00002C
490000002C00002C002C2C2C4900002C2C2C0000002C2C2C2C2C2C00002C2C2C2C2C0000
2C2C2C2C2C2C2C2C2C002C002C2C2C0000002C000000002C0000002C2C2C2C2C2C2C2C2C
0000000000000000002C2C2C2C0000002C0000002C2C2C2C2C2C2C2C2C2C2C2C2C00002C
2C2C2C2C2C2C00002C00002C002C0000002C2C2C2C2C2C2C00002C002C002C2C2C00002C
2C2C2C002C00002C002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C00002C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0049002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C
005F5F005F5F00975F005F5F005F5F00975F005F5F005F5F5F5F5F4949495F5F5F5F5F5F
C5979797975F975F005F5F005F5F005F975F004900005F005F5F5F5F5F00494949A7A7A7
5F9797737373005F5F494949737373A7A7A75F975F5F5F005F5F000085002C2C2C005F00
49494900490049494973737397975F2C2C2C5F5F005F5F5F4949492C2C2C005F5F5F5F5F
5F975FC5C5C5008500005F005F975F5F5F5F4949490073004949495F5F00494949858585
5F5F005F5F000049002C2C2C5F5F5F2C2C2C005F002C2C2C4949495F5F004949495F5F00
5F5F005F5F005F5F004949495F5F5F7373735F9797979797A7A7A7A7A7A7005F97A7A7A7
5F97977373739797975F9797A7A7A79797978585855F975F5F975F858585494949494949
4949495F5F004949495F5F005F5F00007300494949005F004949490049005F5F00494949
975F5F97975F5F975F009797494949005F5F5F97977373737373735F97975F97C55F9797
5F97975F97975F97975F97C55FC5975F97C55F97975F97975F979700975F737373737373
7373735F97970097975F97975F97975F97970097975F5F975F97975F97975F9797009797
5F97975F97975F979700975F5F5F975F97975F975F0097970097975F97970097975F9797
5F97975F97975F97975F97975F97975F97975F97975F97975F97975F97975F97975F9797
5F97975F97C55FC5C55F97C5A7A7A75F97975F97975F97975F97979797975F97975F97C5
5F97975F975F4949492C2C2C2C2C2C2C00002C2C2C002C00002C000000002C00002C0000
2C00002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C00002C2C2C2C002C00002C00490000
002C002C2C2C2C2C2C2C2C2C002C00002C002C2C2C002C0000002C2C2C2C2C2C2C00002C
2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C00002C2C2C2C0000002C2C2C2C2C2C000000
0000002C00000000004900002C0000002C0000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
00002C2C2C2C2C2C2C002C002C2C2C002C002C2C2C2C2C2C002C002C2C2C00002C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C2C2C2C002C00
002C00002C002C2C2C005F5F2C2C2C2C2C2C2C2C2C2C2C2C0049002C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C2C2C2C2C2C002C002C0000002C00
49000000002C2C2C2C2C2C2C
005F5F009797005F5F005F5F005F5F005F5F005F5F005F5F49494949494949494997975F
C5C55F5F5F005F5F005F5F005F975F5F975F2C2C2C005F5F5F5F004949495F5F5F979797
A7A7A797C5C55F5F5F5F5F00A7A7A797979700005F4949494949495F5F004949495F5F5F
97975F005F005F5F00494949005F5F97975F005F5F5F5F5F5F9797005F5F5F975F5F975F
C5C5EFC5C55F494949494949005F5F5F5F5F5F5F5F5F5F5F5F5F5F4949495F5F5F979797
737373005F00494949005F005F5F004949495F5F5F2C2C2C2C2C2C5F5F005F5F005F5F00
00975F5F5F005F005F5F975F7373735F5F5F7373735F97975F97975F97975F9797858585
A7A7A7A7A7A7B6B6B6B6B6B6C5C5C5B6B6B697C5975F5F5F975F5F5F5F5F737373005F00
005F002C2C2C4949494949495F5F005F5F005F5F00007300005F5F2C2C2C494949007300
5F5F5F494949975F5F494949005F5F005F975F97977373735F5F5F5F97975F97975F9797
5F97975F9797A7A7A7A7A7A75F9797A7A7A75F97970097975F975F0097975F975F737373
7373735F975F5F5F5F5F9797009797005F975F97975F97979797975F97975F97975F975F
00975F5F5F975F9797005F975F97975F979700975F5F975F0097975F97975F9797009797
5F97975F97975F97975F97975F97975F97975F97975F97975F97975F97975F97975F9797
5F97975F97975F97C59797975F97C55F9797A7A7A75F97975FC5975F97C55F9797979797
5F97C55F975F005F5F004900002C002C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C00002C
0000004900002C2C2C00002C2C2C2C4900000000002C2C2C2C00002C2C2C00002C2C2C2C
2C2C2C2C2C2C00002C00002C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C00002C2C2C
002C002C2C2C002C00490000002C002C2C2C4900002C00000000002C2C2C002C00002C00
00000000002C2C00002C2C2C00002C002C002C2C2C2C2C2C2C2C2C490000002C0000002C
2C2C2C2C2C2C00002C2C2C2C00002C2C2C2C00002C00002C00002C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C002C002C2C2C0000002C2C2C2C2C2C2C2C2C
004900002C002C2C2C2C2C2C2C2C2C000049002C002C2C2C0000494949492C2C2C004900
2C2C2C4949492C2C2C2C2C2C2C2C2C2C2C2C4949492C2C2C2C2C2C2C2C2C2C00002C2C2C
2C2C2C002C002C2C2C2C2C2C
5F975F5F5F5F5F5F5F5F5F5F005F5F005F5F005F5F005F5F5F5F5F005F5F5F5F5F97C597
C5C55F975F005F5F005F5F00975F5F5F5F005F5F005F5F5F5F5F005F9700494949A7A7A7
A7A7A7C5C597494949002C005F5F5F4949495F5F00494949737373494949005F00494949
5F5F5F49494997975F5F5F5F5F5F5F494949005F5F5F975F5F5F005F5F5F494949858585
B6B6B6494949975F5F005F00005F5F5F5F5F4949495F975F97975F4949495F5F005F5F00
7373737373735F97977373735F5F5F4949495F5F002C2C2C4949494949495F5F00494949
5F5F005F975F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F979797A7A7A7A7A7A7A7A7A7
B6B6B6B6B6B69797975F97975F97975F5F97A7A7A797975F5F5F5F5F5F5F737373005F00
005F5F2C2C2C2C2C2C4949495F5F005F5F005F5F5F5F5F00002C005F5F004949495F5F5F
5F5F005F5F005F975F005F5F7373737373735F97975FC5970097975F5F5F5F97975F9797
9797975F9797979797A7A7A75F97979797975F97975F979700975F005F5F5F975F5F975F
00975F5F97975F97975F5F975F97975FC5C55F97975F97979797979797977373735F9797
5F975F00975F005F5F00975F5F979797C5975F97975F97970097975F97975F97975F9797
5F97975F97975F97970097975F97975F97975F97978585855F97975F97975F97975F9797
A7A7A75F97C5979797A7A7A75F97C5A7A7A75F97975FC5C55F97975F97975F9797979797
5F979773737300975F2C2C2C2C2C2C2C2C2C002C002C0000002C002C2C2C2C00002C2C2C
2C2C2C2C2C2C002C00737373002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
000000002C00004900002C00490000002C002C2C2C2C2C2C2C2C2C002C00002C00000000
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00000000002C002C0000002C00
000000002C000000002C2C2C00002C00002C2C2C2C2C2C2C00002C2C2C2C002C002C2C2C
2C2C2C00002C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C00002C2C2C2C2C2C
002C00002C002C2C2C00002C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C002C2C2C0000494949492C2C2C2C2C2C0049000000492C2C2C000049
00002C2C2C2C2C2C2C2C2C2C2C00002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C
005F5F7373735F5F5F5F5F5F005F5F005F5F005F5F4949495F5F5F005F5F73737397C55F
B6B6B6975F5F975F5F5F5F5F9797000073005F5F00005F5F5F5F5F5F5F5F5F5F5F2C2C2C
A7A7A72C2C2C2C2C2C4949498585857373734949495F5F005F9797B6B6B69797C5C5C597
97979797975F737373A7A7A75F975F5F5F005F5F00494949005F5F007300858585C5C5C5
005F008585857373734949492C2C2C5F5F5F5F5F5F005F5F5F5F5F4949494949495F5F5F
5F5F005F5F5FA7A7A7858585005F5F4949492C2C2C494949494949005F5F5F5F005F5F00
4949494949494949494949495F5F5F5F5F5F979797979797A7A7A7A7A7A797C5C5A7A7A7
A7A7A7A7A7A75F9797494949494949737373737373A7A7A797975F9797975F975F979797
494949005F5F2C2C2C005F002C2C2C5F5F5F4949495F5F005F5F004949495F5F00494949
5F5F5F5F5F5F7373735F5F9797C5975F97975F97977373735F97970097975F5F5F5F9797
5F97C55FC5975F97975F97C59797975F97975F97975F975F5F5F5F5F975F5F9797009797
5F97978585859797970097975F97979797975F97979797970097975F97975F9797737373
5F975F5F97977373735F9797858585979797979797005F975F97975F97975F9797005F97
5F97975F97975F97975F97975F97975F97975F97975F97C55F97975F97975F97975F97C5
5F97C55F97C5A7A7A797C5C55F97C55F97975F97975F97C55F97979797975F9797979797
9797975F97975F5F97005F5F2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00490000
2C2C2C2C2C2C0000002C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C49000000002C000049
2C2C2C2C2C2C2C2C2C5F5F5F002C002C2C2C002C00002C0000002C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C0000002C2C2C2C002C0000002C002C0000000049000000002C2C2C2C
002C002C2C2C00000000002C000000002C002C2C2C2C2C2C2C2C2C002C002C2C2C000000
2C2C2C002C002C0000002C000000002C2C2C002C002C2C2C2C2C2C002C002C2C2C2C2C2C
00002C2C2C2C0000002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C4949492C2C2C2C2C2C0049002C2C2C2C2C2C
2C2C2C0000492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C
002C002C2C2C2C2C2C494949
5F5F5F5F5F5F5F5F5F005F5F005F5F005F97005F5F005F5F005F5F005F5F97C597EFC597
C5C59797975F5F97005F5F5F0073005F5F00494949005F5F005F5F5F5F5F4949495F5F5F
4949490073005F9797A7A7A7737373007300494949C5C5C5B6B6B68585858585855F975F
5F9797005F5F5F5F5F5F975F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F975FC5C5EF97975F
005F5F4949495F5F00979797005F5F5F5F5F005F5F97975F5F975F9797975F9797005F5F
A7A7A75F5F5F5F97975F9700005F5F5F5F5F005F004949495F5F5F5F5F5F5F5F5F494949
00975F5F5F5F979797005F5F5F5F5F5F5F5FA7A7A7B6B6B69797C5C597C59797C5C5C5C5
97C5C5979797858585005F5F5F5F5F5F5F005F5F5F8585859797977373735F975F494949
4949492C2C2C2C2C2C4949490049005F5F004949492C2C2C2C2C2C2C2C2C005F5F5F5F5F
4949495F975F9797975F9797A7A7A75F5F975F97975F5F5F005F97005F5F5F97975F97C5
97C5C5A7A7A79797C55FC597A7A7A7A7A7A75F9797005F5F5F97975F979700975FA7A7A7
9797979797975F97975FC5C597C5C59797979797975F97C5A7A7A7A7A7A75F97975F9797
5F975F005F97005F5F5F97979797975F97979797975F97975F97975F97970097975F9797
5F97975F97C55F97975F97975F97975F97975F97975F97975F97975F97C55F97C55F9797
9797979797C5A7A7A7A7A7A75F9797A7A7A75F97975F9797A7A7A75F97975FC5C5979797
9797975F5F975F9797005F5F2C2C2C2C2C2C00002C00002C002C0000002C2C2C2C000000
002C002C2C2C002C002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C002C002C2C2C002C00
2C2C2C2C2C2C0000002C2C2C2C2C2C00002C49000000002C2C2C2C002C002C2C2C00002C
2C2C2C00002C2C2C2C2C2C2C000000002C002C0000002C00490000000000000000002C00
002C002C2C2C2C00002C0000000000002C000000002C0000002C00000000000000002C00
002C00002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C00002C002C00
2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0049002C2C2C0000492C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C005F5F2C2C2C2C2C2C002C00490000002C00
2C2C2C002C002C2C2C2C2C2C
5F5F5F5F5F5F5F5F5F005F5F005F5F005F5F5F975F005F5F005F5F005F5F97975FC5C597
C5975F5F975F5F975F5F975F4949495F5F0049494900975F5F5F5F002C002C2C2C005F00
4949492C2C2C494949979797A7A7A75F5F5F4949492C2C2C8585855F97977373735F5F5F
5F5F5F4949495F5F5F5F975F9797975F975F5F5F5F5F975F5F5F5F5F9797C5EFC55F5F00
5F5F005F5F5F5F5F97A7A7A74949494949495F5F5F5F5F005F5F5F005F5F5F9700494949
9797975F5F5F5F9797858585B6B6B6858585494949005F5F5F975F5F5F5F4949495F5F5F
4949495F975F005F5F5F5F5F9797975F5F00005F9797979797979797C5C5B6B6B6A7A7A7
9797975F97975F5F5F494949494949005F5F5F5F5F7373739797975F975FA7A7A75F5F5F
5F5F004949492C2C2C2C2C2C005F005F5F004949494949492C2C2C005F005F5F5F494949
005F5F858585979797858585A7A7A77373735F5F5F5F5F5F5F5F5F5F97975F97975F97C5
A7A7A7A7A7A75FC5C597C5C55F97975F97975F97975F97970097975F97975F97975F9797
5F97975F97C55F97975F97C55F97C5A7A7A75F9797979797A7A7A7979797A7A7A7979797
0097970097975F97975F97975F97975F97C55F97975F97975F97978585855F9797009797
5F9797A7A7A70097975FC5975F5F975F97975F97C55F97975FC5C55F9797979797979797
A7A7A75FC5C5A7A7A75FC5C55FC5C55F97975F9797979797979797979797A7A7A75F9797
5F97C55F97975F97975F5F5F2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
00002C00002C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C4900002C2C2C00002C2C2C2C
2C2C2C0000002C2C2C2C2C2C2C2C2C2C2C2C002C0000002C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C0000002C2C2C2C00002C2C2C2C002C000000000000000000002C0000
2C2C2C00002C2C2C2C00002C2C2C2C2C2C2C00002C002C002C2C2C2C2C2C2C2C2C00002C
2C2C2C2C2C2C00002C2C2C2C0000002C2C2C2C2C2C002C002C2C2C2C00002C2C2C2C2C2C
00000000002C2C2C2C00002C2C2C2C2C2C2C0049002C2C2C2C2C2C2C2C2C002C002C2C2C
2C2C2C0049002C2C2C002C002C2C2C2C2C2C0049002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C0049002C2C2C2C2C2C2C2C2C5F005F5F5F002C2C2C2C2C2C2C2C2C002C002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C
5F5F5F5F5F5F5F5F5F005F5F005F5F005F5F5F5F5F005F5FC597975F5F5FC5C597EFC5C5
C597975F975F5F975F5F5F5F5F5F5F4949494949497373735F5F5F4949492C2C2C5F5F5F
4949495F5F005F5F5F97975FE1E1E197975F5F5F00494949494949858585005F5F2C2C2C
8585855F5F5F5F5F5F5F5F5F9797975F9797858585005F5F5F975F97C5C5005F5F007300
5F5F004949495F975F005F00005F5F005F5FA7A7A797975F4949495F5F5F005F5F737373
5F5F5F7373739797975F9797A7A7A797C55F5F5F5F494949975F5F5F5F5F5F9797858585
4949495F975F5F975F4949495F97975F5F5F737373A7A7A797C5C5B6B6B6A7A7A75F9797
5F97977373735F975F005F5F5F5F5F4949499797975F97975F975F5F5F004949495F5F00
2C2C2C2C2C2C490000005F005F5F004949494949494949492C2C2C4949495F975F5F975F
7373739797975F9797A7A7A75F9797737373005F5F00975F5F975F5F97975F5F979797C5
A7A7A7A7A7A7A7A7A79797C55F97975F97C59797975F9797005F979797975F9797858585
5FC5975F97975F97979797975F9797A7A7A75F97C5A7A7A7A7A7A75F9797A7A7A75F9797
005F975F97979797979797975F97975F97975F97975F9797009797005F975F9797009797
5F97975F97C55F97979797975F97C59797975F97C55F97975F97C55F97979797C5979797
A7A7A75F97979797979797975F97975FC5C55FC5975F9797A7A7A75F97975F97C597C5C5
5F97C55F97C55F97975F5F972C2C2C2C2C2C2C2C2C2C00002C2C2C002C00002C00490000
2C2C2C2C2C2C002C002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C00002C2C2C2C0000492C2C2C2C2C2C
2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C002C002C2C2C002C002C00002C00002C0000
002C002C2C2C00002C0000002C2C2C000000002C0000002C0000002C2C2C2C2C2C00002C
00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C0000492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C
5F5F5F005F5F005F5F5F5F5F005F5F5F97975F9797005F5F5F5F5F5F5F5FC59797C5975F
C5975F5F5F5F7373735F5F5F5F5F5F494949005F5F979797A7A7A75F5F5F5F979797975F
005F5F5F5F5F494949494949B6B6B65F5F97005F004949494949495F9797494949004900
5F5F5F97C5C5005F5F5F5F5F005F005F5F5F97C5C55F979797C5C5C5C5975F5F5F5F5F5F
737373005F5F2C2C2C5F5F00494949494949494949005F5F4949495F5F5F4949495F5F5F
5F975F5F5F5F5F975F858585A7A7A7A7A7A797979797975F5F5F00005F5F5F5F5F979797
5F5F5F5F975F8585857373735F97977373739797975F97979797C5C5C5C55F97975F9797
7373734949495F5F00005F5F4949495F9797979797A7A7A74949495F5F005F5F5F494949
4949492C2C2C2C2C2C5F5F004949494949494949492C2C2C005F005F5F5F5F975F975F5F
A7A7A75F97979797975F97975F97974949495F5F975F97975F97975F97C597979797C5C5
5F97C5A7A7A797C5C597C5C59797C597979797C5C5A7A7A75F97975F97975F97975F9797
0097975F97975F97975F97975F97975F97979797975F97C55F97975F97975F97975F5F5F
005F975F97975F97975F97975F97975F97975F97C55F97975F97975F5F975F97975F9797
5F97975F97975F97C55F97979797978585855F97C55F97C55FC5C55F97C55F97C55FC5C5
9797C5A7A7A75FC5975F97975F97C55FC5C55F97C55F97979797978585859797975F97C5
5F97975F97C55F9797737373005F5F2C2C2C2C2C2C2C2C2C00002C002C002C2C2C002C00
002C002C0000002C002C2C2C4900002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C002C0000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00
00002C2C2C2C2C2C2C2C2C2C2C0000490000002C002C2C2C2C2C2C00002C00002C000000
002C0049000000002C2C2C2C00002C2C0000000000002C00002C002C2C2C2C2C2C2C2C2C
00002C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C00002C002C00000000
2C2C2C002C002C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C
005F5F005F5F4949495F5F5F5F5F5F5F97975F97975F97975F97975F975FC5C597C5C55F
8585857373735F5F5F7373730073005F5F5F005F5F5F5F5FB6B6B65F5F5FB6B6B65F9797
979797A7A7A7858585737373B6B6B67373737373735F5F5F005F5F8585854949495F5F00
4949495F97C5C5975F5F975F5F975F5F5F5FC5C597858585D4D4D4A7A7A7A7A7A7B6B6B6
97975F9797975F5F004949497373735F97974949495F5F5F005F5F005F005F5F5F5F975F
8585858585855F5F000073005F5F5F858585A7A7A77373738585855F975F494949A7A7A7
97979700975F5F5F5F7373738585857373735F5F5F7373738585859797975F5F5FA7A7A7
9797974949495F5F5F4949495F97975F97979797970073004949495F5F004949492C2C2C
2C2C2C4949494949494949494949494949494949492C2C2C5F5F5F4949494949495F5F5F
494949737373005F975F975F5F5F5F5F5F5F5F97975F97C55FC5C55F97C55F97975FC5C5
97C5C55FC5C55FC5975FC5C59797979797C55F97C55F97975F97975F97975F97975F9797
5F5F975F97970097C55F97975F979797C5C5A7A7A7A7A7A75F979700975F5F97975F9797
0097970097970097975F5F970097975F97975F97975F97975F97975F97975F97975F97C5
5F97975FC5C55F5F975F97C50097C55F97C59797979797975FC5C55FC5C55F97C55F9797
5F9797A7A7A7A7A7A75F97975F97975F97978585855F97C55F97C5A7A7A797C5C55F9797
9797975F97975F97C55F5F97005F5F0000492C2C2C4900002C2C2C5F5F5F5F5F5F002C00
002C002C00002C000000002C2C2C2C00002C2C2C2C002C0000002C2C2C2C2C2C2C2C2C2C
2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C2C2C2C2C2C2C
00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C00002C2C2C2C2C2C002C002C2C2C
002C00002C002C000000002C002C0000002C002C004900002C2C2C00002C2C2C2C002C00
2C2C2C2C2C2C2C2C2C002C00002C002C2C2C00002C2C2C2C2C2C2C2C2C2C00002C2C2C2C
2C2C2C002C002C2C2C00002C2C2C2C2C2C2C2C2C2C0000492C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C7373732C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C
005F5F005F5F5F5F5F005F5F005F5F7373734949495F979773737300975FA7A7A797C55F
8585855F5F5F005F5F73737397975F4949495F5F5FA7A7A7C5C5C55F979797C5C5C5C5C5
B6B6B6979797A7A7A75F5F5F97C5C5C597975F97975F5F5F9797975F5F5F5F97975F5F5F
7373735F5F5F97C5C58585855F97C55F5F5F5F5F5FC5C5EFA7A7A75F97975FC5C5B6B6B6
97C5C597C5972C2C2C5F5F5F5F5F5F9797975F5F5F737373B6B6B6C5C5979797975F5F00
005F5F7373735F5F5F5F975F7373738585854949497373739797975F975F5F5F5F494949
5F5F974949494949494949495F97975F5F5F4949495F5F5F5F5F5F5F97974949495F5F5F
85858597C5C55F9797A7A7A77373737373738585854949497373735F5F002C2C2C004900
494949494949005F004949492C2C2C0073004949494949495F5F5F2C2C2C5F5F00494949
5F975F7373735F5F975F5F5F8585857373735F975F5F5F975F97975F97C5A7A7A7A7A7A7
5F97C5A7A7A79797C5A7A7A7A7A7A7A7A7A75F97C55F97975F97975F97970097975F9797
5F97975F97975F5F975F97975F97979797979797975F9797005F975F97975F5F975F9797
5F97970097C55F97970097975F97975F97975F97970097975F5F975F97975F97975F9797
9797C55F97975F97C55F97C55F97975F97C55F97C55F97C55F97C55FC5975F97975F9797
5F979797C5C55F97C50097975F97975F9797A7A7A75F9797A7A7A75FC5C55F9797A7A7A7
5F97C55F97C55F97970097975F5F5F4949492C2C2C2C2C2C002C002C2C2C4900002C2C2C
2C2C2C002C002C00002C2C2C00002C4949492C2C2C002C002C2C2C002C002C2C2C490000
2C2C2C00002C2C000000002C2C2C2C2C2C2C002C0000002C4949492C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C00002C000000490000002C00002C002C00002C2C2C002C00
002C002C2C2C00002C00002C00002C002C002C2C2C2C2C2C2C2C2C00002C2C2C2C2C0000
002C002C2C2C2C2C2C2C2C2C002C00002C00002C002C2C2C2C2C2C0000002C2C2C00002C
2C2C2C002C0000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0049002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C0000490000492C2C2C2C2C2C2C2C2C2C2C2C0000492C2C2C
2C2C2C005F5F00002C5F975F2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C002C00
2C2C2C2C2C2C4949492C2C2C
005F5F005F5F494949005F5F005F975F9797005F5F7373735F97975F9797979797979797
5F975F4949494949495F5F5F7373735F5F5F9797975F97C597C5C5E1E1E1C5C5C5B6B6B6
A7A7A7B6B6B6FFEFC5B6B6B6A7A7A7975F0097C5C5979797C5C5C54949498585855F975F
5F5F5F73737373737397C5C5C5EFC597979797C5EFB6B6B65FC5C5C5C5EFA7A7A7979797
A7A7A77373735F5F5F97975F5F975F7373739797C5C5C5975F5F5F5F97979797975F5F5F
4949495F5F005F5F5F5F5F5F8585854949497373739797C5A7A7A75F5F5F5F5F5F5F5F5F
5F5F5F494949005F5F005F008585855F5F005F5F5F7373735F5F5F5F5F5F5F5F5F979797
9797C59797C59797C5A7A7A7A7A7A75F97975F97C597979797975F0049005F5F002C2C2C
4949492C2C2C737373737373002C005F5F005F5F004949495F5F5F494949494949494949
5F5F007373735F5F5F5F5F97A7A7A75F97975F97975F97975F97C55F9797A7A7A75F97C5
5FC5C597C5C59797C5A7A7A7979797979797A7A7A75F97977373730097975F97975F5F97
5F97975F97975F97975F97975F979797979797C5C55F97970097975F97975F9797005F97
0097975F97975F97975F97975F97975F97975F9797009797009797005F975F97975F97C5
5F97C55F97C5A7A7A75F97C59797C55F97C55FC5975F97975F97975F97C55F97C55F9797
5F97975F9797A7A7A75F97975F97975F97C55F97C55F97C55FC5C55F97C5A7A7A75F97C5
5F97C55F97C55F97975F97975F5F97005F5F2C2C2C2C2C2C2C2C2C002C00002C002C2C2C
00002C2C2C2C00002C00002C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C0000002C0000002C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C00002C49000000002C4900002C2C2C002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C00002C00002C2C2C2C2C2C2C2C000000002C2C2C2C002C0000002C
002C002C2C2C2C2C2C00002C2C2C2C002C00002C002C2C2C2C2C2C2C2C2C5F97972C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C004900000049
2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C000049002C002C2C2C2C2C2C2C2C2C
2C2C2C0049002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C2C2C2C
002C002C2C2C4949492C2C2C
005F5F5F5F5F005F5F005F5F5F5F5F5F97C549494997979797C5C5979797A7A7A797C597
97975F4949495F5F5F5F5F5F5F5F5F5F975FB6B6B69797979797C5C5C5EFC5C5C5B6B6B6
C5C5EFB6B6B6C5C5EFB6B6B65FC5C5979797C5C5975F975FB6B6B64949497373735F975F
005F5FA7A7A75F975FA7A7A7A7A7A797979797C5EF5F97C55F97C5C5C5C59797C597C5C5
B6B6B6A7A7A75F5F5F494949B6B6B6A7A7A7A7A7A7005F5F494949858585005F00494949
5F975F4949492C2C2C5F5F5F9797975F97975F5F5FA7A7A7B6B6B6A7A7A7494949858585
5F5F5F5F5F5F5F5F5F4949499797975F5F005F975F5F5F5F7373734949495F5F5F5F5F00
5F5F00A7A7A7A7A7A77373739797975F97C59797978585855F975F7373735F5F5F494949
494949494949737373858585005F5F005F5F005F004949495F5F000073005F5F5F494949
5F5F5F5F5F5F005F97005F5FA7A7A75F5F5F005F5F5F9797A7A7A75F97C55F9797A7A7A7
A7A7A7A7A7A75FC5C55F97C5A7A7A75F97975F97C55F97970097975F97977373735F97C5
5F9797005F975F97975F97975F9797A7A7A75F97975F5F970097975F9797009797009797
5F97975F97C55F97C55F97975F97975F97C55F97975F97975F97975F97975F97975F9797
A7A7A79797975F97975F97C55F97C5A7A7A75F97C59797975F97975F97975F97975F97C5
5F9797A7A7A797C5C50097975F97975F97979797975F9797979797A7A7A7979797979797
9797975F97975F97C55F97975F5F97005F5F2C2C2C2C2C2C2C2C2C2C2C2C2C000000002C
2C2C2C2C2C2C00002C2C2C2C00002C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C
2C000000002C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C0000
2C2C2C00002C2C2C2C2C2C2C002C0000002C2C2C2C2C2C2C002C00002C002C2C2C2C2C2C
00002C2C2C2C2C2C2C00002C00002C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C002C00
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C2C2C002C0000002C002C002C2C2C
2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0049002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C0049002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
000049005F002C2C2C2C2C2C2C2C2C002C0000002C2C2C2C2C2C2C2C2C2C7373732C2C2C
4949492C2C2C4949492C2C2C
005F5F5F5F5F005F5F5F5F5F005F5F494949005F5F97C5C5D4D4D4C5C5C5A7A7A797C597
5F5F5F5F5F5F5F5F5F005F5F5F975F2C2C2C5F9797A7A7A7979797C5C5C5C5C5C5C5EFC5
B6B6B6E1E1E1A7A7A75F975FA7A7A797975FC5C5C5737373005F5F494949005F5FC59797
5F5F5F005F5F5F5F5F5F5F5F5F979797C5EF85858597979797C5C55F97C5B6B6B697C5C5
97C5C5C5C5C55F97975F9797B6B6B697975F494949005F5F5F5F5FA7A7A79797975F5F5F
975F5FB6B6B6A7A7A74949495F5F5F5F975F7373737373738585855F5F5F5F9797737373
97975F5F5F5F0073005F5F5F5F5F5F5F975F8585850073005F5F5F4900004949495F5F5F
005F5F5F5F5F5F5F5F737373A7A7A79797975F97975F97977373735F5F5F5F975F858585
5F975F5F5F5F858585A7A7A79797972C2C2C4949495F5F5F5F5F004949495F5F005F5F5F
5F97975F9797005F5F5F5F5F005F975F97979797975F97979797979797975F97C5B6B6B6
9797C5A7A7A75F97C5A7A7A7A7A7A70097975F97975F5F975F97975F97975F97975F9797
5F97975F97975F97975F97975F9797A7A7A79797975F97975F97975F9797009797009797
5F97C55F97979797975F97975F97975F97977373735F97975F97970097975F97975F9797
5F97975F97975F97C55FC5C55FC5C59797975F97C50097975F97975FC5975F97C55F9797
5F9797A7A7A75F97975F97970097979797979797975F97C5A7A7A79797975F97C55F97C5
5F97C55F97C55F97C55F97C55F97975F5F5F2C2C2C2C2C2C2C2C2C002C00002C002C0000
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C002C002C2C2C
2C2C2C00002C002C002C2C2C2C2C2C49000000002C2C2C2C002C002C2C2C2C2C2C002C00
2C2C2C2C00004900002C2C2C002C002C2C2C00002C2C2C2C2C2C2C00002C002C00002C00
002C002C2C2C00002C00002C002C002C2C2C002C002C2C2C2C2C2C0000002C2C2C2C2C2C
2C2C2C002C00002C002C2C2C002C002C2C2C2C2C2C2C2C2C000000002C00002C002C2C2C
2C2C2C2C2C2C00002C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0049002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C005F5F2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C
005F5F005F5F005F5F5F97C59797C55F97C597C5C5A7A7A7E1E1E1B6B6B6C5C597858585
5F5F005F5F005F5F5F005F5F5F5F5F4949495F5F5F97C5C55F97C59797C5A7A7A7C5C5C5
979797EFEFC58585855F5F5FC5C5C55F5F5FB6B6B6005F5F005F5F00975F737373C5C5C5
B6B6B6858585B6B6B65F975F97C5C5979797B6B6B65F979797C5C5C5C5C55F97C5A7A7A7
A7A7A7005F5FC5C5C597C5C5C5C5C597975F005F00C5C5C55F5F5F5F9797A7A7A75F9797
5F5F5F97C5C597979773737373737397975F5F5F5F858585005F97979797979797737373
5F5F5F005F008585854949495F5F5F0073005F5F5F0049004949495F5F5F737373494949
5F975F5F5F5F7373735F97977373735F97979797975F97975F5F5F97975F494949494949
5F5F00494949494949005F00494949005F5F5F5F5F5F5F005F5F5F5F97005F5F5F5F5F5F
C5C5975F9797005F5F005F5F005F5F8585857373735F97975F97975F97C55F9797A7A7A7
A7A7A79797C597C5C59797C55FC5C55F97975F5F975F97975F97975F97970097975F9797
5F97975F97975F9797979797A7A7A7A7A7A75F97970097975F97C55F5F975F9797858585
5F97975FC59797C5975F97975F97975F97970097975F97970097975F97975F97975F9797
5F97979797975F97975F97C55F97975F97975F97975F97975F97975F97975F97C55F97C5
A7A7A75F97975F97975F97975F97975F9797A7A7A7A7A7A7A7A7A79797C55FC5C59797C5
5F97975F97C59797975F97975F9797005F5F4949492C2C2C2C2C2C002C00002C002C0000
2C2C2C002C004900002C2C2C2C2C2C00002C002C0000002C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C002C002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C002C00
2C2C2C00002C2C2C2C00002C002C0000002C00002C00002C2C2C2C00002C0000002C0000
002C0000002C2C2C2C00002C2C2C2C2C2C2C002C002C2C2C2C2C2C2C00002C2C2C00002C
002C0000002C002C002C2C2C2C2C2C0000002C2C2C2C00002C2C2C002C0000002C000000
2C2C2C002C002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C494949
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C737373
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C4949492C2C2C494949
005F5F005F5F005F5F737373A7A7A7C5C5C597C5C597C5C5C5C5EFC5C5C5B6B6B697975F
5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F0049008585859797975F9797858585A7A7A7737373
9797977373735F975F5F5F5FB6B6B65F5F00979797737373737373737373858585737373
5F975FA7A7A75F5F5F5F975F97C5C5975F5F5F5F975F5F9797C5C5A7A7A7005F5F5F5F5F
5F975F5F5F5FB6B6B697C55F5F5F004949497373735F5F5F979797A7A7A77373735F5F5F
49494973737385858597975FD4D4D49797977373732C2C2C494949A7A7A7B6B6B6A7A7A7
4949497373738585855F5F5F005F5F5F975F5F5F5F8585854949494949495F9797494949
5F5F5F737373975F97A7A7A7A7A7A797C5C55F97977373735F5F979797975F975F005F5F
00490097975FA7A7A77373735F5F005F5F5F5F5F5F5F975F5F5F5F5F97005F5F5F494949
97975F005F5F005F5F005F5F5F975F7373735F97979797975F97979797975F97C597C5C5
97C5C5A7A7A7A7A7A7A7A7A7A7A7A70097975F97975F97975F9797009797009797005F97
9797975F97C55FC5C5A7A7A7A7A7A75F97C55F9797A7A7A75F97975F97975FC5975F97C5
5FC5975F97C55F97975F97975F97975F97975F97975F97975F97975F97977373735F9797
5FC5C55F97975F97975F97C55FC5970097C55F97975F97975F97C55F97975FC5C597C597
9797975F97975F97975F97975F97975F9797979797A7A7A7A7A7A79797975F97C5A7A7A7
A7A7A75F97975F97975F97975F97975F97974949492C2C2C002C002C2C2C4900002C2C2C
00002C00002C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C002C00002C0000002C2C2C2C
002C002C2C2C00002C00002C002C0000002C2C2C2C00002C000000002C002C2C2C2C0000
00002C2C2C2C2C2C2C002C0000002C0000002C2C2C00002C2C2C2C00002C2C2C2C2C2C2C
00002C2C2C2C00002C00002C00002C002C002C2C2C002C00002C00002C00002C002C2C2C
2C2C2C2C2C2C0000492C2C2C002C002C2C2C490000002C002C2C2C002C00002C002C2C2C
002C002C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C0049002C2C2C002C00
4949490049002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C494949494949
005F5F005F5F5F97979797C597C5C5C5C5EFA7A7A7B6B6B6E1E1E1A7A7A7C5C5C597C597
5F5F5F5F5F5F005F5F4949494949495F5F5F979797A7A7A75F97C5979797979797737373
A7A7A75F975F97975FA7A7A78585855F5F5F005F5F5F5F0049494997C5975F5F5F005F00
5F975F494949A7A7A7C5EFEF5F5F5F5F5F5F7373738585855F975F8585854949495F5F00
005F5FA7A7A79797975F975F5F5F5F7373735F975F5F97C5B6B6B68585855F5F5F005F5F
737373A7A7A74949495F5F5FA7A7A7B6B6B6C5975F5F975F5F975F009797B6B6B6B6B6B6
97975F5F5F5F00975F5F97975F5F5F0049005F5F005F5F5F5F9797A7A7A797C5C55F5F5F
5F5F5FA7A7A797C5C5B6B6B6B6B6B6B6B6B6A7A7A79797975F5F5F5F975F005F002C2C2C
2C2C2C5F5F5F979797979797A7A7A7979797737373975F5F5F975F4949495F975F5F5F00
5F5F5F005F5F00975F005F5F7373734949495F9797A7A7A75F97C5979797A7A7A797C5C5
9797C597C5C55FC5C59797C5A7A7A75F97975F97975F97975F97978585858585855F9797
A7A7A7979797979797979797A7A7A75FC5C55FC5C55F97C55F97975F97975F97C5A7A7A7
9797975F97979797975F97975F97975F97970097975F97975F97975F97975F9797009797
5F97C55F97975F97975F97970097975F97975F97975F97975F97975F97979797975F9797
5F97975F97975F97978585855F9797A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7
5F9797A7A7A75F5F975F97975F97970097974949492C2C2C00002C4900002C2C2C2C2C2C
00002C2C2C2C2C2C2C00002C2C2C2C0000002C2C2C00002C2C2C2C2C2C2C2C2C2C002C00
2C2C2C2C2C2C2C2C2C4900002C2C2C002C002C2C2C00002C2C00002C2C2C002C002C2C2C
2C2C2C2C2C2C2C00002C2C2C2C2C2C002C0000002C2C2C2C2C2C2C00002C0000002C2C2C
002C0000000049000000002C000000000000000000002C002C2C2C2C2C2C2C2C2C2C2C2C
49000000002C002C002C2C2C002C002C2C2C00002C002C002C2C2C2C2C2C2C0000000000
2C2C2C2C2C2C0000002C2C2C002C002C2C2C002C002C2C2C2C2C2C2C2C2C4949492C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C0000492C2C2C2C2C2C2C2C2C0000492C2C2C
2C2C2C2C2C2C2C2C2C005F5F2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C494949494949
005F5F5F97C5A7A7A7B6B6B6A7A7A7C5C5EFC5C5C5B6B6B697975FC5C5C5A7A7A7979797
975F5F5F5F5F5F5F5F5F5F00005F00005F5FA7A7A797C5C5C5C5C5858585C59797494949
97975F4949495F5F5FA7A7A75F975F5F5F005F5F5F2C2C2C5F5F5F97975F005F5F5F5F5F
8585855F979797975FC59797B6B6B6005F5F5F9797C5C5C597979797C5C5858585A7A7A7
A7A7A773737397C5C5A7A7A75F5F5FC5C597B6B6B6C5C5C5B6B6B6979797A7A7A75F97C5
E1E1E1C5C5C5B6B6B697975FA7A7A75F9797979797A7A7A7A7A7A7A7A7A75F975FA7A7A7
A7A7A77373737373738585855F975F5F5F5F5F5F5F5F5F5FB6B6B65F5F5F979797737373
97C5C59797C5C5C5C5B6B6B6B6B6B6B6B6B6979797494949005F004949495F5F5F2C2C2C
494949494949A7A7A7A7A7A7979797A7A7A7975F5F5F5F5F5F5F5F97975F975F5F5F975F
005F5F005F5F005F5F005F5F5F5F5F5F97975F97979797975F97975FC597B6B6B697C5C5
97C5C597C5C5A7A7A75FC5C5A7A7A75F975F5F97975F97975F97975F975F5F97975F9797
A7A7A7A7A7A7A7A7A79797C59797C597C5C5979797A7A7A7A7A7A79797C59797975F9797
5F97975F9797A7A7A7A7A7A75F97975F97975F975F5F97975F97975F979700975F5F9797
5F97975F97C55F97975F97975F97970097C55F97975F97975F9797979797A7A7A75F9797
5F97975F97975F97975F97975F97C55F97C55F9797A7A7A7B6B6B6979797A7A7A7A7A7A7
5F97C55F97C55F97C55F97975F97977373735F5F5F005F5F2C2C2C2C2C2C2C2C2C490000
2C2C2C00002C2C2C2C2C2C2C00002C2C2C2C2C2C2C002C002C2C2C2C2C2C00002C2C2C2C
002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C002C2C2C2C2C2C
2C0000490000002C00002C002C2C2C00002C002C004900002C2C2C00002C2C2C2C002C00
002C0049000000002C000000002C002C00002C2C2C2C2C2C0000002C2C2C00002C2C2C2C
002C002C2C2C2C2C2C2C2C2C00002C00002C2C2C2C00002C00002C2C2C2C2C00002C2C2C
00002C2C2C2C00002C002C0000002C004900002C002C2C2C494949002C002C2C2C004900
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000490049000049002C2C2C
0000490000492C2C2C002C002C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C494949
5F5F002C2C2C2C2C2C2C2C2C
5F979797C5C5A7A7A75F979797C5EFB6B6B6C5C5977373735F5F5FC5C5C5979797975F5F
5F5F5F5F5F5F4949495F5F5F4949494949495F5F005F9797B6B6B65F97974949492C2C2C
5F975F4949490049005F975F494949005F0097979785858597975F7373735F9797737373
5F5F5F5F5F5FC5EFEF97C5C5979797979797858585B6B6B69797979797975F5F5F737373
97975FA7A7A7979797A7A7A7A7A7A7C5C597B6B6B6B6B6B6A7A7A75F975FC5C5C5C5C5EF
B6B6B6979797B6B6B6D4D4D4C5C5C55F9797B6B6B6A7A7A75F9797B6B6B6A7A7A75F5F5F
A7A7A797C5975F97975F97979797978585857373734949495F5F5FB6B6B6A7A7A7C5C5C5
97C5C597C5C5C5C5C5B6B6B6C5C5C5B6B6B65F97977373738585855F975F005F5F97975F
2C2C2C5F5F005F5F5F5F5F5F5F5F5F979797C5975F5F5F00975F5F97975F97975F5F975F
005F5F5F5F5F5F979797C5977373735F97975F9797A7A7A75F97975F97C5A7A7A7A7A7A7
A7A7A7A7A7A7A7A7A7A7A7A75F97970097975F97975F97975F97975F97975F97975F9797
97C5975F9797A7A7A797C5C5A7A7A7A7A7A7A7A7A7A7A7A75F97C5A7A7A79797975F97C5
5F97975F97C59797979797975F979797C5975F97975F97975F97975F97975F97975F9797
9797975F97975F5F975F97975F97975F97975F97975F97975F97975F97975F9797979797
5F97975F97975F97975F9797A7A7A75FC5C55F9797A7A7A7A7A7A75F97C5979797A7A7A7
5F97C55F97C55F97979797975F97975F5F977373734949492C2C2C2C2C2C002C00000000
2C0000002C00002C004900002C2C2C00002C2C2C2C2C2C2C00002C00002C2C2C2C00002C
2C00002C2C2C4900002C2C2C2C2C2C00490000002C49000000002C002C002C2C2C002C00
002C00002C0049000000002C00002C2C2C2C49000000002C2C2C2C2C2C2C002C00000000
2C0000002C000000002C0000002C002C2C2C2C2C2C2C2C2C4900002C2C2C0000002C2C2C
002C00002C002C2C2C2C2C2C002C0000002C2C2C2C2C2C2C2C2C2C00002C2C2C2C00002C
002C002C2C2C002C002C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C0049002C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C004900004900
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C
2C2C2C2C2C2C4949495F5F5F
A7A7A79797975F97977373739797975F5F5F5F5F5F97979797C5C5C5C59797975F97975F
97975F5F5F5F5F5F5F5F5F5F5F5F5F2C2C2C4949494949495F975F4949495F5F00007300
4949495F5F5F5F5F004949497373735F5F5F8585855F5F002C2C2C494949858585494949
5F975F97C5C5C5C597C5C5C55F975FA7A7A75F9797A7A7A77373735F5F5FC5C5C5979797
9797975F9797A7A7A7A7A7A75F97C5979797B6B6B65F975FB6B6B6B6B6B6D4D4D4B6B6B6
5F979797C5C5C5C5C5C5C5C5A7A7A7B6B6B6A7A7A7737373004900A7A7A797975F005F00
4949498585855F97975F9797A7A7A7A7A7A75F9797858585737373737373B6B6B6A7A7A7
9797C5B6B6B6B6B6B6B6B6B697C5C5B6B6B6B6B6B69797977373735F5F5F5F975F5F975F
004900975F5F5F5F5F5F5F0097975F97975FA7A7A7B6B6B65F979700975F494949494949
005F5F005F5F005F5F005F5F005F5F5F5F975F97C5A7A7A75F97C55FC5C5A7A7A7979797
B6B6B6A7A7A7B6B6B697C597979797979797A7A7A75FC5975F97975F97978585855F9797
5F97975F97C5A7A7A7979797A7A7A7A7A7A7A7A7A75F97975FC59797C5975F97C5979797
979797A7A7A7A7A7A79797979797975F97975F97975F97975F97975F97975F97975F9797
5F97975F97975F97975F97975F97975F97975F97975FC5975FC5975F97C597979797C597
5F97975F97975F97975F9797A7A7A7A7A7A7A7A7A75F97C5A7A7A75FC5C59797C55F9797
5F97C55F97975F97C55F97975F5F970097970097974949492C2C2C002C002C2C2C2C2C2C
002C00002C002C2C2C002C00002C0000000049000000002C2C2C2C002C002C2C2C2C2C2C
2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C00002C00002C002C002C2C2C00002C2C2C2C
2C2C2C2C2C2C002C002C2C2C002C00490000002C002C0000002C00002C00000000000000
000000000000000000490000002C002C2C2C2C2C2C2C2C2C002C002C2C2C2C00002C2C2C
2C2C2C002C002C2C2C002C002C2C2C2C2C2C00000000002C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C002C00002C0000002C2C2C2C00000000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0049002C2C2C005F5F2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C002C004949492C2C2C
5F5F5F5F5F975F97975F5F5F5F97975F5F5F5F5F97979797C5C5C5B6B6B697975F97975F
979797C5C5975F5F5F494949005F5F004900005F00494949005F5F005F5F494949494949
4949492C2C2C4949495F975F97975F5F5F0097975F4949495F975F5F5F5FA7A7A7C5C5C5
5F9797B6B6B6B6B6B6B6B6B64949495F979797979797975FA7A7A7005F5F5F97975F9797
7373735F97977373735F5F5F5F5F5F5F5F5F5F5F5F5F5F00EFEFEFB6B6B6D4D4D4C5C5EF
C5C5C5C5C5C5B6B6B6B6B6B6005F5F9797978585855F975F5F5F5F979797A7A7A7C5C597
8585855F5F5F97975F8585855F5F97A7A7A7858585C5EFEF858585979797A7A7A7A7A7A7
C5C5C5C5C5C597C5C5B6B6B697C5C5B6B6B697979797975F5F5F5F5F975F4949495F5F00
5F5F5F5F97005F5F5F5F5F00975F5F737373A7A7A7A7A7A75F97978585855F5F5F005F5F
5F5F5F5F5F5F005F5F0097970097970097975FC597B6B6B65FC5C55F97C597C5C5A7A7A7
97C5C5A7A7A7A7A7A7A7A7A75FC5975FC5C55FC5C55F97975F97975F97975FC5C55F9797
9797975F97975FC5C597C5C55F979797C5C59797979797979797975F97C5A7A7A7A7A7A7
9797C59797979797975FC5975F97979797975F97975F97975F97975F97975F97975F9797
5FC5975F97975F97975F9797A7A7A75F97975FC5975F97975F9797A7A7A7A7A7A7A7A7A7
5F97975F97970097975F97C55FC59797C5C5A7A7A7A7A7A7A7A7A75F97975F97C59797C5
9797979797975F97C55F97975F97975F97975F9797005F5F49494900002C2C2C2C002C00
2C00002C2C2C2C2C2C2C2C2C00002C0000002C2C2C2C2C2C00002C002C002C00002C2C2C
2C2C2C2C2C2C005F5F5F5F002C2C2C002C002C00002C2C2C2C2C2C2C000049000000002C
4900002C2C2C002C00002C002C2C2C00002C000000002C00002C00002C000000002C0000
0000000000002C0000002C002C2C2C002C004900002C2C2C00002C002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00000000002C002C2C2C2C2C2C2C2C2C2C2C2C
002C00002C002C2C2C2C2C2C00002C2C2C2C002C002C2C2C00002C002C002C2C2C002C00
2C2C2C2C2C2C2C2C2C2C2C2C0049002C2C2C8585850049004949492C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00490000
2C2C2C2C2C2C0000492C2C2C
9797975F5F5F5F5F5F975F97A7A7A75F979797C5C597C5C5C5C5C5C5C5C5C5C5C597975F
97C597EFC55F9797005F975F5F5F5F0073004949495F5F5F4949492C2C2C0049005F5F00
2C2C2C494949005F005F5F005F975F494949005F004949495F5F5F5F975F97979797975F
C5C5C597C5C55F975FB6B6B65F5F005F5F5F8585854949495F5F9797C5C5C5C5C5B6B6B6
A7A7A797979797C5C573737397975FB6B6B6B6B6B6005F5FC5C5C5EFEFFFE1E1E1C5C5C5
D4D4D4B6B6B6B6B6B6B6B6B65F9797A7A7A79797975F5F5F7373735F5F00979797A7A7A7
97975F979797737373009797737373A7A7A7979797858585979797C5C5C5C5C5C5A7A7A7
A7A7A7B6B6B6A7A7A7A7A7A79797979797975F5F5F2C2C2C494949494949004900979700
5F5F5F5F5F005F5F5F975F5F7373737373738585855F97C55FC5975F975F5F5F5F5F5F5F
5F5F5F5F5F5F5F97975F97975F97975F9797A7A7A7979797A7A7A797C5C5979797A7A7A7
A7A7A797C5C5A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7979797A7A7A7A7A7A7A7A7A7
A7A7A75F97C5A7A7A7A7A7A7A7A7A797979797C5C5A7A7A7A7A7A7A7A7A7A7A7A7979797
97C5C597C5979797975F97977373739797975F97975F97978585855F97975F9797009797
5F9797A7A7A75F97979797975F97975F97975F97975F9797A7A7A75FC5C5979797979797
5F97975F97975F97C55FC5C5A7A7A75F97C5A7A7A75F97975F97C55F97C55F97975F9797
97979797C5978585855F97975F5F975F97970097975F5F5F2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C00002C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C
2C2C2C0000002C2C2C0000002C2C2C2C2C2C00002C00002C2C2C2C2C2C2C2C2C2C2C2C2C
00002C2C2C2C0000000000004900002C2C2C2C000000002C2C2C2C2C2C2C2C2C2C002C00
0000002C00002C2C2C2C2C2C00002C2C2C2C002C0000002C002C002C2C2C00002C00002C
002C002C00002C2C2C00002C2C2C2C2C2C2C2C2C2C002C0000002C2C2C2C00002C00002C
0000002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C49494900002C
0049002C2C2C2C2C2C4949492C2C2C5F5F5F4949490049002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C002C002C2C2C4949492C2C2C494949
0049000049005F5F002C2C2C
5F5F5F005F5F737373B6B6B69797977373735F9797C5C5C5C5C5C5C5C5C597C5975F975F
97975F975F5FC5975F5F5F5F5F975F4949495F5F5F494949005F002C2C2C4949495F5F5F
0049004900000085004949495F5F5F5F5F5FA7A7A7005F004949494949495F975FB6B6B6
5F5F5FC5C5C5C5C5C54949494949495F97975F5F5F494949A7A7A797C5C5C5C5EF97C5C5
97C597A7A7A7A7A7A7979797B6B6B6D4D4D4A7A7A7858585C5C5C5C5C5EFB6B6B6D4D4D4
C597C5A7A7A797C5C5D4D4D4B6B6B6B6B6B6D4D4D497975FC597975F5F5F5F5F5F5F975F
A7A7A797C5975F9797A7A7A7737373737373979797858585A7A7A79797C59797C5A7A7A7
B6B6B6B6B6B697C5C5B6B6B69797975F5F5F5F5F5F5F975F5F5F5F8585854949495F5F5F
5F970097975F975F5F97975F858585009797005F5F5F5F5F005F5F4949494949495F975F
005F5F00975F5F97975F97975FC5C5A7A7A75FC5C5A7A7A7B6B6B6A7A7A797C5C597C5C5
B6B6B6A7A7A7A7A7A7A7A7A7B6B6B6B6B6B6A7A7A7A7A7A7A7A7A75F97975FC5C5979797
97C5C5A7A7A7A7A7A7A7A7A7A7A7A797C5C597C5C597C5C5A7A7A797C5C5A7A7A75F9797
9797975F97975F97C55F97975F97C55F97C55F97975F97975F97975F97975F97975F9797
5F97975FC5C55F97979797975F97975FC5975F9797979797A7A7A75F97975F97975F9797
5F97979797975FC5C55F97C55F97979797979797975FC5C5A7A7A75F97975FC5C55F9797
5F97C5A7A7A75F97975F97975F97975F97975F5F97005F5F4949492C2C2C2C2C2C2C0000
00002C2C2C2C2C2C2C00002C2C000000002C002C002C2C2C2C2C2C002C002C2C2C2C2C2C
00002C2C2C2C2C2C2C000000002C002C2C2C2C2C2C000000490000002C002C000000002C
002C002C2C2C2C2C2C2C2C2C00002C002C0000002C002C002C2C2C0000004900002C2C2C
00000000002C2C2C2C2C2C2C00002C2C2C2C2C2C2C002C002C2C2C00002C2C2C2C2C2C2C
002C00002C002C2C2C00002C002C002C2C2C2C2C2C002C002C000000002C000000002C00
000000002C004900002C2C2C002C002C2C2C002C00002C002C2C2C005F5F2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C4949492C2C2C2C2C2C2C2C2C4949492C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C00002C
9797C55F97979797C597C5C5C5C5C597C5C585858597C5C5D4D4D4B6B6B697C5C55F975F
975F0097970097975F975F5F4949494949494949494949494949492C2C2C005F00494949
2C2C2C5F5F005F97004949495F5F5F5F5F5F5F975F5F97972C2C2C5F5F5F5F9797B6B6B6
B6B6B6B6B6B65F5F5F5F5F979797C5B6B6B69797975F975F97979797C5C5C5C5C5A7A7A7
5F5F5F5F9797B6B6B6D4D4D4979797B6B6B6C5C5C59797C5B6B6B697C5C5C5C5C5C5C5C5
5F97C55FC5C5D4D4D4D4D4D4EFC5C5C5C5C5FFEFC5A7A7A7B6B6B65F5F005F5F97737373
5F979785858597C5C5B6B6B69797978585857373735F97C5C5C5C59797C5B6B6B697C5C5
9797C5C5C5C5A7A7A75F9797A7A7A7A7A7A77373735F975F97975F979797A7A7A75F5F5F
5F5F5F97975FC5975FA7A7A797C5975F97975F5F5F005F5F5F5F5F005F5F005F5F5F5F5F
00975F5F9797005F975F9797A7A7A7A7A7A7979797A7A7A7A7A7A7A7A7A7A7A7A797C5C5
B6B6B69797C597C5C5B6B6B69797C5A7A7A75FC5C5A7A7A75FC5C55F97C5A7A7A797C5C5
97C5C55FC5C5A7A7A7A7A7A7A7A7A7A7A7A797C5C5A7A7A7A7A7A75F97C58585855F9797
9797975F979797C5975F97975F97975FC5C55F97C55F97979797979797975F9797A7A7A7
97C5C55F97975F97975F97975F97975F9797979797A7A7A75F97975F97975F9797979797
5F97975FC5C5A7A7A7A7A7A7A7A7A7A7A7A7A7A7A797C5C59797975FC5C55F97975F97C5
979797A7A7A75F97979797975F97978585855F97977373734949492C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C00002C002C2C2C2C00004900002C2C2C002C002C000000002C490000
2C2C2C00002C2C00002C00002C2C2C002C002C2C2C49000000002C2C2C2C00002C2C2C2C
49000000002C2C0000000000002C002C0000002C002C2C2C2C2C2C2C2C2C00002C002C00
2C00000000002C0000490000002C00002C00002C002C2C2C2C2C2C00002C002C00002C00
00002C2C2C2C002C00002C002C2C2C2C2C2C000000000000490000002C00000000000000
000000002C00002C00002C00002C002C000000002C00000000002C002C00002C002C2C2C
2C2C2C2C2C2C2C2C2C4949490049002C2C2C2C2C2C2C2C2C0000492C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C494949
2C2C2C2C2C2C002C002C2C2C
9797975F5F97C5C5C5A7A7A797C5C5C5C5C5C5C5C5C5C5C5D4D4D4C5C5C55F97975F9797
5F975F975F5F5F975F5F5F5F4949490073002C2C2C2C2C2C494949002C002C2C2C2C2C2C
2C2C2C0049002C2C2C0049002C2C2C5F5F007373735F5F007373735F975FB6B6B65F5F5F
858585858585737373C5C5C597C5EF5F975FB6B6B6737373C5C5C5B6B6B65F97C5737373
5F975F7373735F97C5A7A7A75F97975FC5C5B6B6B6B6B6B6B6B6B6A7A7A7B6B6B6C5C5EF
D4D4D4D4D4D4C5C5EFC5C5C5E1E1E1E1E1E1C5EFC5B6B6B6B6B6B64949495F975F737373
5F9797B6B6B697C5C5B6B6B6C5C5C5C5C5C597C5C55F97C597C5C5979797C5C5C5C5C5C5
A7A7A79797978585855F9797858585A7A7A797979797975F5F975F5F5F5F97979797C5C5
97975F979797C5C5C5C5C5C5B6B6B697C5C55F97975F97975F9797005F5F5F97975F9797
5F5F975F5F5F005F9700979797C5C597C5C55FC5C5A7A7A797C5C59797C597C5C5B6B6B6
A7A7A797C5C5B6B6B6A7A7A797C5C55FC5C5A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7
A7A7A7A7A7A75FC5C55FC5C597C5C597C5C597C5C5A7A7A7A7A7A75F97975F97975F97C5
A7A7A75F97C5A7A7A75F97975F97975F97975F97979797975F97975F97975FC5975F97C5
97979797C5C55F97975F97C5B6B6B6A7A7A7A7A7A75F97978585855F97C55F97C55F97C5
5F97975F9797979797B6B6B6A7A7A7A7A7A79797979797975FC5C55F97975F97C5A7A7A7
5FC5C5A7A7A7A7A7A75F97975F97975F9797005F975F5F974949492C2C2C2C2C2C2C2C2C
4900002C2C2C49000000002C00002C2C2C2C2C2C2C00002C002C0000002C2C2C2C002C00
2C000000002C2C2C2C002C00002C002C2C2C2C2C2C2C2C2C49000000002C00002C2C2C2C
002C00002C0000002C00002C2C2C2C002C00002C00002C002C2C2C00000000002C002C00
2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C002C00002C00
2C2C2C00002C002C002C2C2C002C004949494900002C2C2C2C0000002C00002C002C2C2C
2C2C2C2C2C2C2C2C2C002C002C2C2C002C002C0000002C00002C002C2C2C2C2C2C2C2C2C
002C002C2C2C2C00002C2C2C0000492C2C2C2C2C2C2C2C2C4949492C2C2C005F5F002C00
2C2C2C4949492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
494949494949494949494949
5F5F5F005F5F5F97C55F97C5C5C5EF97C5EFC5C5EFC5C5C5B6B6B697C5C55F97975F975F
5F97975F975F5F975FC5C5975F975F5F5F5F4949494949494949492C2C2C5F5F00005F00
0073002C2C2C2C2C2C002C002C2C2C005F005F5F00005F5F494949C5C5C55F5F5F2C2C2C
2C2C2C979797A7A7A7E1E1E1B6B6B65F97977373735F9797B6B6B6B6B6B69797C55F9797
858585737373C5C5EF97C5C597C5C5B6B6B6C5C5C5C5C5C597C5C59797975F5F97C5C5C5
C5EFC5D4D4D4C5C5C5D4D4D4E1E1E1E1E1E1E1E1E1D4D4D4C5C5C5A7A7A7A7A7A75F9797
A7A7A7B6B6B6B6B6B6C5C5C5B6B6B6C5C5C5C5EFEFA7A7A79797C597C5C5975F975F9797
A7A7A7A7A7A79797979797C5B6B6B6A7A7A7B6B6B6A7A7A7A7A7A77373735F9797858585
979797979797B6B6B6C5C5C5C5C5C5C5C5C59797979797975F97975F97975F9797737373
7373735F97975F97975F9797A7A7A7A7A7A75F9797A7A7A79797C5C5C5C5B6B6B6C5C5C5
B6B6B69797C597C5C59797C597C5C59797C597C5C597C5C597C5C5B6B6B6A7A7A797C5C5
97C5C5A7A7A75F97C5A7A7A7B6B6B6A7A7A7B6B6B697C5C55F97C5A7A7A7009797A7A7A7
A7A7A7A7A7A7A7A7A75F97975F97975F97C55F97975F97C55F97975F9797A7A7A75F97C5
97C5C59797C55F97C55F9797A7A7A7A7A7A75F97C55F97975F97975F97975F97975F9797
A7A7A7858585A7A7A75F97C597C5C5A7A7A797C597A7A7A75F97C55F9797A7A7A7979797
5F97C55F97C5979797975F975F97C55F5F975F97975F975F005F5F2C2C2C2C2C2C2C2C2C
2C00002C2C2C002C00002C0000002C4900002C2C2C2C2C2C0000000000002C2C2C2C2C2C
002C0000002C00002C2C00004900002C2C2C2C2C2C002C002C2C2C002C002C2C2C00002C
2C2C2C2C2C2C2C2C2C49000000002C2C2C2C00002C2C2C2C00002C2C000000002C490000
002C0000002C00002C2C2C2C002C002C2C2C2C2C2C00002C2C2C2C2C2C2C00002C2C2C2C
0000002C2C2C00002C2C2C2C2C2C2C00002C002C002C000000002C00002C2C00002C2C2C
00002C4900002C2C2C2C2C2C00000000002C2C2C2C2C00002C2C2C2C2C2C0000002C2C2C
002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C005F5F0049002C2C2C4949492C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C
494949494949494949494949
5F5F5F005F97B6B6B65F9797C5C5EFC5C5C5D4D4D4B6B6B6C5C5EF97C5C55F97C5B6B6B6
5F97975F975F5F975FA7A7A75F975F5F975F005F5F4949494949495F5F5F4949495F5F5F
005F005F5F5F2C2C2C4949494949495F5F004949495F97975F9797975F0049494997C597
5F5F5F5F9797C5C5C5D4D4D45F97C5005F5F005F5F5F5F975F975FB6B6B6B6B6B6B6B6B6
97C5C5C5C5C5B6B6B6C5C5C5C5C5C5B6B6B6B6B6B6D4D4D4A7A7A7C5C5EFC5C5EFC5C5EF
C5C5EFB6B6B6EFEFEFEFC5EFD4D4D4D4D4D4C5C5C5D4D4D4B6B6B6B6B6B6D4D4D4C5C5C5
EFC5C5C5C5C5B6B6B6C5C5C5C5C5EFC5C5EFD4D4D4C5C5C5C5C5EF97C5C597C5C59797C5
5FC5C55F9797C5C5C5B6B6B6B6B6B6C5C5C5C5C5C5C5C5C5B6B6B6C5C5C55F9797A7A7A7
A7A7A75F97975F97C59797C597C5C59797C55F97C55FC5C597C5C5A7A7A75F97975F97C5
5F9797A7A7A7A7A7A75FC5C5A7A7A7A7A7A797979797C5C5B6B6B6C5C5EFC5C5EF97C5C5
97C5C5B6B6B6B6B6B6B6B6B6B6B6B697C5C597C5C597C5C5B6B6B6B6B6B697C5C5B6B6B6
97C5C5A7A7A797C5C59797C59797C597C5C597C5C5B6B6B6B6B6B65F97975F97C5009797
5F97C59797975F97975F97975F97C55F9797979797A7A7A75F97975FC5C55F97975F9797
9797975F97C59797C5A7A7A75F97C55F97975FC5C55F97C55F97975F97975F97C55F97C5
979797979797A7A7A75FC5C59797C59797975F9797A7A7A75FC5C5A7A7A75F97C5A7A7A7
5FC5C55F9797A7A7A75F97C55F97975F97C55F97975F9797005F5F2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C00002C2C2C2C2C2C
0000002C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C00000000002C2C2C2C002C002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C000000005F002C2C2C2C2C2C00000000002C002C00
2C2C2C2C2C2C000000000000002C00002C00002C002C2C2C00002C4900002C2C2C2C2C2C
2C2C2C00002C4900002C2C2C2C2C2C2C2C2C00000000000000002C2C000000002C00002C
00002C002C002C2C2C002C00002C0000002C49000000002C002C0000002C2C2C2C002C00
00002C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C005F5F494949
49494900002C0049002C2C2C2C2C2C2C2C2C0049002C2C2C2C2C2C2C2C2C4949492C2C2C
4949494949494949492C2C2C
49494997C5975F97975F97C5C5EFEFC5C5EFC5C5EFA7A7A797C5C58585855F5F975F9797
97979797975F97975F979797C5975F5F5F5F4949495F5F004949494949494949495F9700
5F5F004949495F5F004949494949495F5F004949495F5F5FC5C5C5005F5F5F5F5FA7A7A7
4949495F9797C5C5EFB6B6B68585857373735F9797D4D4D4494949005F5FA7A7A79797C5
97C5C5C5C5C597C5C5B6B6B6A7A7A75F97975F9797737373C5C5C5B6B6B6C5C5C5C5C5C5
97C5C597C5C5C5C5EF97C5EFD4D4D4C5EFEFD4D4D4D4D4D4C5C5EFC5C5C5D4D4D4EFC5C5
C5C5C5C5C5C5B6B6B6C5C5C5C5C5C5C5C5C5D4D4D4B6B6B697C5C597C5C597C5EFC5C5C5
9797C5A7A7A797C5C5C5C5C5B6B6B6B6B6B6C5C5C5C5C5C5C5C5C5A7A7A7C5C5C5A7A7A7
9797975F97C55F97975F97979797C597C5C5B6B6B6B6B6B6C5C5C597C5C5A7A7A7979797
5F979797C5C597C5C597C5C59797C55F97975F97C5B6B6B6B6B6B6B6B6B6B6B6B6A7A7A7
B6B6B6B6B6B6C5C5C5B6B6B6B6B6B69797C597C5C597C5EF97C5C5C597C5B6B6B6B6B6B6
B6B6B697C5C5B6B6B6A7A7A7C597C597C5C5B6B6B6A7A7A75F97975F97975F97975F9797
5F97975F97C55F5F97009797A7A7A75F97C55F97C55FC5C55F97C55F97C55F97C55F9797
97C5975F9797A7A7A7A7A7A75F9797A7A7A75F97975F97975F97975F97C5A7A7A7A7A7A7
A7A7A7A7A7A797C5C5B6B6B65FC5C597C5C55F97C55FC5C55F97C59797975FC597979797
5F97C50097C55F97975F5F975F97C55F5F975F97975F97975F5F5F2C2C2C2C2C2C2C2C2C
2C2C2C00002C2C2C2C2C2C2C00002C00000000002C2C2C2C000000002C002C2C2C00002C
002C0000002C2C2C2C00002C49000000002C2C2C2C000000002C002C2C2C002C00002C00
2C2C2C00002C4900002C2C2C2C2C2C005F5F494949002C00000000000000002C0000002C
2C2C2C002C002C00000000002C000000002C00002C00002C00002C2C2C2C2C2C2C490000
2C2C2C00002C2C2C2C2C2C2C00002C2C2C2C2C2C2C000000000000002C002C2C2C000000
2C000000002C00002C00002C2C2C2C490000002C004900002C0000002C002C2C2C002C00
2C2C2C2C2C2C2C2C2C005F5F2C2C2C2C2C2C00004900002C2C2C2C0049002C2C2C004900
4949492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C4949492C2C2C494949
4949497373732C2C2C494949
005F5F005F5FA7A7A75FC5C5C5C5C5C5C5C5B6B6B6A7A7A75FC5C55F5F5F5F5F97979797
5F975FC5975F7373735F975FC5C59797975F5F5F5F005F005F5F000049005F5F0000005F
494949005F005F5F004949492C2C2C005F5F5F5F5FC5C5C5005F5F858585858585A7A7A7
005F00858585B6B6B6C5EFEF979797C5C5C5EFC5EFA7A7A77373735F5F5F4949495F5F5F
A7A7A797975FA7A7A7A7A7A79797975F97979797975F5F5F5F9797B6B6B6C5C5C597C5C5
B6B6B69797C5C5C5C59797C5B6B6B6B6B6B6C5C5C5D4D4D4C5C5C5C5C5C5C5C5C5D4D4D4
C5C5C5B6B6B697C5C5B6B6B6C5C5C597C5C59797C597C5EF97C5C5C5C5EFC5C5C5B6B6B6
5F9797A7A7A7A7A7A7A7A7A75F97C597C5C5C5C5C5D4D4D4D4D4D4C5C5EF97C5C5C5C5C5
A7A7A7A7A7A797C5C5C597C597C5C5B6B6B6C5C5C5C5C5C5C5C5C597C5C5A7A7A797C5C5
A7A7A7A7A7A7A7A7A7A7A7A79797975FC5C5A7A7A797C5C5C5C5C5C5C5EFC5C5C5C5C5C5
97C5C597C5C5B6B6B697C5C597C5C597C5C597C5C5B6B6B6B6B6B6B6B6B697C5C597C5C5
97C5C597C5C5B6B6B69797C597C5C597C5C597C5C59797975F97975F97975F97C55F97C5
5F97975F97975F97975F979797C5C5A7A7A79797979797975F97975F97C55F97975F97C5
5F97975F9797A7A7A7A7A7A7A7A7A75F97975F97975F97975F97975F97975F97C55FC5C5
9797975F97C55F9797A7A7A7A7A7A7A7A7A7979797979797A7A7A7A7A7A7A7A7A75F9797
5F97C55F97979797C55F97C55F97C55F97975F97975F5F977373732C2C2C2C2C2C2C2C2C
2C2C2C002C002C2C2C2C2C2C2C00002C2C2C002C00002C002C000000002C0000002C2C2C
00002C4900002C2C2C2C2C2C2C2C2C2C000000002C2C2C2C2C2C2C00002C2C2C2C002C00
2C000000002C002C002C00002C00002C2C2C5F5F00002C002C00002C000000000000002C
002C002C2C2C2C2C2C002C00002C0000002C000000000000002C002C2C2C2C2C2C2C2C2C
0000000000002C00002C0000002C00490000002C000000002C00002C2C2C002C00002C00
000000002C00000000002C0000000000002C2C2C2C002C00000000002C002C00002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C0049000000492C2C2C494949
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0049004949492C2C2C494949
4949492C2C2C2C2C2C494949
00975FB6B6B6005F9797C5EFC5C5EF97C5C597C5C5A7A7A7A7A7A75F979797C5C5979797
C5C55F5F5F5F5F975F5F9797C5C59797975F5F975F5F97004949494949495F5F00494949
4949495F97002C2C2C4949494949495F5F5F5F979797975F4949492C2C2C858585005F5F
4949499797C5737373C5C5C5858585B6B6B6C5C5C55F9797979797979797009797975F5F
5F5F5F5F975F5F5F5F97979797C5C5B6B6B68585855F5F5F5F975F5F97C5C5C5C5C5C5C5
B6B6B6C5C5EFC5C5C5C5C5C5C5C5C597C5C5D4D4D4EFEFEF97C5EFD4D4D4C5C5C5B6B6B6
B6B6B6D4D4D4D4D4D4B6B6B6C5C5C5A7A7A75FC5C5EFC5C5B6B6B65F97C5A7A7A7A7A7A7
B6B6B6B6B6B6D4D4D4D4D4D4A7A7A7979797C5C5C5C5C5C597C5C5B6B6B6C597C5A7A7A7
9797975F97C55F97C5C5C5C5C5C5C5D4D4D4C5C5C5C5C5C5B6B6B65F97C5A7A7A7A7A7A7
A7A7A79797975FC5979797975F97979797C5B6B6B6B6B6B6B6B6B6C597C5B6B6B6B6B6B6
C5C5C5C5C5C5C5C5C5C5C5C597C5C5B6B6B6B6B6B6B6B6B697C5C5B6B6B6B6B6B697C5C5
B6B6B697C5C597C5C5A7A7A797C5C597C5C597C5C5979797A7A7A75F97975F97C55FC597
9797979797975F97975F97975FC5C597C5C597C5C597C5C5A7A7A7A7A7A70097975FC5C5
9797975F97C5A7A7A75F97975F97975F97C58585855F97975F97975F97975F97975F97C5
A7A7A7A7A7A797C5C5A7A7A7A7A7A797C5C5A7A7A7A7A7A7A7A7A75F97C55F97C55F97C5
5F97975F97975F97975F97975F97C55F97975F97977373737373734949492C2C2C2C2C2C
4900002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C00002C2C2C00002C2C2C2C2C2C2C
2C2C2C002C004900002C2C2C00002C002C002C0000490000002C002C2C2C2C2C2C2C2C2C
00002C2C0000002C002C2C2C002C00002C005F5F5F00002C00002C2C2C2C2C0000002C00
2C2C2C002C00002C002C2C2C00002C00002C0000002C2C2C2C2C2C00002C002C00002C00
2C2C2C2C2C2C00002C002C00002C00002C002C2C2C002C002C2C2C2C2C2C2C2C2C002C00
2C00000000000000002C00002C000000002C000000002C002C2C2C00002C002C002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C004900
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C004900
4949492C2C2C2C2C2C2C2C2C
5F9797005F5F0097979797979797C5A7A7A79797C597C5C597C5C55FC5975F5F5F97C55F
97975F5F97005F975F5F5F5F979797C5C5975F975F2C2C2C4949495F5F5F5F5F5F494949
005F5F5F975F5F5F004949495F5F5F5F5F5FB6B6B65F5F00005F0000005F7373735F5F5F
005F5FC5C5C597C5C5B6B6B6A7A7A75F97975F9797B6B6B6975F5F005F005F5F97B6B6B6
4949494949494949499797C5005F5F5F5F5FA7A7A79797C55F9797A7A7A7C5C5EFC5C5C5
E1E1E1EFC5C5EFEFEFD4D4D4D4D4D4D4D4D4E1E1E1C5C5C597C5C5D4D4D4C5C5C597C5C5
B6B6B6C5C5C5C5C5C597C5C5C5C5C5D4D4D4B6B6B6E1E1E1C5C5C5C5C5C5EFEFEFEFEFC5
A7A7A7C5C5C5C5C5C5E1E1E1C5C5C5C5C5C5B6B6B697C5C5C5C5C5C5C5C597C5C55F97C5
5F97979797975FC5C597C5C5D4D4D4B6B6B6A7A7A7A7A7A7A7A7A797C5C55F97975F9797
A7A7A75F97975F9797A7A7A797C5C597C5C5C5C5C5B6B6B697C5C597C5C5B6B6B6C5C5C5
C5C5C5D4D4D497C5C5B6B6B697C5C597C5C5B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6
B6B6B6A7A7A7B6B6B697C5C597C5C5A7A7A75F97979797C55F97970097C55FC5C59797C5
5F97975F97975F9797A7A7A7A7A7A7A7A7A7A7A7A7A7A7A75F97C55FC5C55F97975F9797
5F97C55F97975F97C55F97C55F97C55F97975F97C55F97975FC5C5979797A7A7A75F97C5
5F97C5A7A7A797979797C5C597C5C5A7A7A7979797A7A7A75FC5C55F97C59797975F9797
A7A7A7979797A7A7A75F97C55F97975F97975F97975F97975F97974949492C2C2C2C2C2C
2C2C2C00002C002C002C2C2C00002C2C2C2C2C2C2C00002C2C00002C2C2C00002C2C2C2C
2C2C2C2C0000002C002C2C2C00002C2C000000002C2C2C2C2C2C2C002C002C2C2C2C2C2C
00000000002C00000000002C2C2C2C00002C2C2C2C2C2C2C00002C00002C000000000000
00002C2C2C2C2C2C2C2C2C2C0000000000002C2C2C2C2C2C2C2C2C002C002C00002C2C2C
2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C002C00002C0000002C00002C2C2C2C00002C
002C0000002C002C002C2C2C00002C000000002C0000002C00002C2C2C2C00002C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C97975F2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C4949492C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C
00975F5F97975F97C5E1E1E1B6B6B65F97975FC5C597C5C5A7A7A7979797A7A7A7C5975F
97975F5F5F005F975F5F975F5F5F5F97975F97975F5F5F5F494949494949494949005F00
005F5F4949495F5F00494949007300B6B6B6494949005F004949495F5F5F5F5F5FA7A7A7
494949B6B6B6B6B6B6A7A7A7979797494949A7A7A7C5C5EFB6B6B68585855F9797C5C5C5
7373735F5F5F4949494949495F5F5F2C2C2C5F5F5F5F5F5F97C5C5FFEFC5C5C5C5C5EFC5
EFC5C5D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4D4EFC5EFC5C5EFD4D4D4E1E1E1C5C5C5
C5C5C5C5C5C5B6B6B6A7A7A7858585A7A7A75FC5C5A7A7A7A7A7A797C5C5E1E1E197C5C5
B6B6B6B6B6B65FC5C5C5C5C5E1E1E1E1E1E1C5C5C5C5C5C5C5C5C5C5C5C5A7A7A7A7A7A7
A7A7A797C5C59797C5B6B6B697C5C597C5C55F9797A7A7A79797C5A7A7A7979797A7A7A7
5F97979797975F97C597C5C5C5C5C5C5C5C5C5C5C597C5C597C5C5C597C5B6B6B697C5C5
C5C5C5C5C5C5B6B6B6C5C5C597C5C5B6B6B697C5C5B6B6B697C5C597C5C59797C5B6B6B6
97C5C5B6B6B697C5C597C5C597C5C55F97C55FC5970097970097975F97975FC5C59797C5
5F97975F97975F97975F97975F97C55F97C59797975F979797C5C55F97975F9797A7A7A7
5F97975F97975F97975F97970097975F97975F97975F97979797975F97975F97C55F9797
A7A7A7979797A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A75F97C5A7A7A7A7A7A75F97C5
979797A7A7A79797975F97975F5F975F97975F5F975F5F970097974949492C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C002C002C2C2C2C00002C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C00002C00002C2C00002C2C2C2C2C2C2C2C2C2C2C2C002C002C000000000000002C
00002C0000000000002C2C2C00002C002C002C2C2C00002C4900002C0000002C00000000
2C2C2C2C2C2C2C2C2C00002C2C000000000000002C2C2C2C2C2C2C2C2C2C002C00002C00
00002C2C2C2C00002C00002C2C2C2C4900002C00002C2C2C00002C00002C00002C00002C
2C2C2C2C2C2C002C002C2C2C00002C00002C00002C0000002C0000002C002C2C2C000000
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C002C004900002C2C2C2C2C2C2C2C2C2C2C2C002C004949494949492C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C494949
5F97975F9797D4D4D4D4D4D45F97975F975F5F9797C5C5EFB6B6B65F97C597C597979797
5F975F5F97005F97005F975FC5C597975F5F5F975F4949495F5F004949492C2C2C5F5F00
4949495F5F5F005F005F5F5FC597C55F5F5F005F5F4949492C2C2C2C2C2C979797A7A7A7
494949A7A7A7A7A7A7A7A7A75F5F5F494949C5C5C5E1E1E1B6B6B697C5C5B6B6B6B6B6B6
A7A7A7A7A7A77373735F5F975F5F5FA7A7A75F9797B6B6B6D4D4D497C5C5B6B6B6C5EFEF
EFEFEFEFEFC5C5C5EFE1E1E1D4D4D4E1E1E1EFC5C5C5C5EFC5C5C5C5C5C5D4D4D497C5C5
97C5C5D4D4D4B6B6B697C5C55F97979797975F5F9797C5C5D4D4D4C5C5C5C5C5C5B6B6B6
B6B6B697C5C5B6B6B6B6B6B6A7A7A7D4D4D4C5C5C5E1E1E1D4D4D4D4D4D4C5C5C59797C5
97C5C5B6B6B697C5EFB6B6B6B6B6B6A7A7A75F97C597C5C5B6B6B6A7A7A7979797979797
A7A7A7979797B6B6B6C5C5C5D4D4D4B6B6B6C5C5C5B6B6B6B6B6B6B6B6B697C5EFC5C5C5
97C5C5C5C5EFC5C5EF97C5C597C5C597C5C5C5C5C5B6B6B6A7A7A7A7A7A797C5C5A7A7A7
B6B6B6A7A7A7A7A7A7A7A7A79797C5979797737373005F970097975F97C5A7A7A75F9797
5F97C55F97975F9797737373A7A7A7A7A7A797C5C55F9797A7A7A75F97970097975F9797
5F97975FC5C55F97975F97975F97975F97975F97975F97C55F97975F97C5A7A7A797C5C5
A7A7A7A7A7A7A7A7A797C5C597C5C55F97979797979797975F97C5A7A7A75F97C55F9797
9797975FC5C59797C55F97975F97975F5F975F97975F9797009797005F5F2C2C2C2C2C2C
2C2C2C2C2C2C002C002C2C2C002C002C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C0000000000002C00002C2C2C2C2C2C2C2C2C00002C490000002C0000002C490000
2C2C2C0000000000002C2C2C2C2C2C002C0000002C2C000000002C002C0000002C2C2C2C
002C000000002C2C2C00002C00000000000000002C000000002C00002C00000000000000
0000000000002C2C2C2C2C2C002C00002C00002C002C00002C2C2C00002C2C2C2C2C2C2C
00002C00000049000000002C2C2C2C2C000000002C2C000000002C000000000000000000
2C2C2C2C2C2C002C002C2C2C0000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C494949002C002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C
5F5F975F979797C5C55F97C55F9797005F5F009797C5C5C5B6B6B6009797858585A7A7A7
2C2C2C5F5F005F975F494949979797A7A7A797975F5F5F00004900494949005F00005F00
5F975F97975F7373735F5F5F5F5F5F5F5F005F5F002C2C2C0049004949494949492C2C2C
494949B6B6B6A7A7A75F5F5F5F5F00005F5F97C5C597C5C5A7A7A7A7A7A7C5C5C5C5EFC5
C5C5C597C5C59797C5C5EFC55F9797B6B6B6FFFFEFC5C5C5D4D4D4C5C5C5A7A7A7A7A7A7
97C5C5EFC5C5C5EFEFE1E1E1E1E1E1E1E1E1EFEFEFC5C5EF97C5C5C5C5EFD4D4D4A7A7A7
97C5C5A7A7A7C5C5C5858585979797C5C5C597C5C5C5C5C5A7A7A7C5C5C5C5C5C5C5C5C5
C5C5C5B6B6B6B6B6B697C5C597C5C5B6B6B6C5C5C5D4D4D4D4D4D4E1E1E1C5C5EFC5C5C5
C5EFEFC5C5C5C5C5EF97C5C597C5C597C5C5B6B6B6B6B6B6C597C5A7A7A797C5C5B6B6B6
B6B6B697C5C59797C5D4D4D4C5C5C5D4D4D4C5C5C5B6B6B6C5C5C5B6B6B6B6B6B6C5C5C5
C5C5C5C5C5C5C5C5C5C5C5C59797C5B6B6B697C5C5B6B6B6A7A7A797C5C597C5C5A7A7A7
97C5C5A7A7A797C5975FC597A7A7A75F5F975F97975F97975F97975F97975F97975F9797
5F97975F97975F5F975F9797A7A7A79797C597C5C55F9797A7A7A70097970097975FC597
0097C5A7A7A75F97978585850097975F97970097975F97975F97975F979797C5C55F97C5
5F97C55F979797C5C5A7A7A75FC5C55FC5C5A7A7A75FC5C55F97C55F97C55FC5C55F97C5
9797C55F97C59797975F97C55F97975F97975F97975F5F975F975F005F5F0049002C2C2C
002C002C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C000000
0000002C0000002C00002C002C2C2C002C00000000002C00002C002C2C2C2C2C2C00002C
002C002C00002C0000002C000000002C2C2C2C2C2C002C002C2C2C2C2C2C00002C002C00
002C002C2C2C2C2C2C2C000000002C2C000000002C002C002C2C2C002C002C2C2C2C2C2C
2C2C2C002C00002C002C2C2C2C2C2C00002C002C00002C002C2C2C00002C2C2C2C2C2C2C
00002C00002C00002C00002C2C2C2C002C000000002C2C2C2C2C2C0000002C2C2C002C00
00002C002C002C00002C2C2C2C2C2C002C002C2C2C002C0000002C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C002C002C2C2C2C00002C2C2C2C2C2C002C002C2C2C2C2C2C002C00
2C2C2C2C2C2C2C2C2C2C2C2C
5F97975F97C55F97975F97C500975F005F5F5FC5C55F979797C5C5009797005F5F97C597
C5975F5F5F005F5F005F5F00975F5FC5C597C5975F5F5F005F5F00005F005F5F00002C00
005F5F5F975F494949975F5F5F5F5F5F97005F5F002C2C2C494949005F00494949494949
5F975F858585B6B6B65F5F5F005F5F4949495F975F5F5F5F97975F5F979797C5C5C5C5C5
C5C5C597C5C5B6B6B697C5C597C5C5C5C5C5B6B6B6EFEFC5E1E1E1B6B6B69797975F97C5
A7A7A7A7A7A7E1E1E1C5C5C5C5C5C5EFEFEFC5C5C5C5EFEFA7A7A7C5C5C5B6B6B6979797
A7A7A75F5F5F73737397975F5F9797A7A7A75F979797979797C5C5B6B6B6C5C5C5B6B6B6
C5C5C5B6B6B6C5C5C5B6B6B6B6B6B6B6B6B697C5C5C5C5C5EFC5C5C5C5C5C597C597C5C5
9797C597C5C597C5EFB6B6B697C5C5A7A7A7B6B6B697C5C55FC5975F97C5A7A7A75F97C5
A7A7A7B6B6B6A7A7A7C5C5C5C5C5C5C5C5C5C5C5C5B6B6B6C5C5C5C5C5C5C5C5C5B6B6B6
B6B6B697C5C597C5C5C5C5C5B6B6B6B6B6B697C5C5B6B6B697C5C55F97C5A7A7A75F9797
A7A7A7979797A7A7A75F97C55F97975F97970097975F97C55F97970097975F9797A7A7A7
5F97975F5F975F97979797975FC5C597C5C597C5C55F97975F97975F97975F9797A7A7A7
9797975F97C59797975F97975F97975F97C55F97975F9797A7A7A7A7A7A7A7A7A7A7A7A7
A7A7A7A7A7A7A7A7A797C5C5A7A7A75F97C55FC597979797A7A7A7A7A7A7A7A7A75F97C5
5F97975F97975F97975F97975F97975F97975F97975F97975F5F97005F5F2C2C2C002C00
00002C00002C002C00490000002C002C2C2C2C2C2C00002C2C2C2C0000002C00002C0000
000000002C002C2C2C2C2C2C2C2C2C002C002C00002C2C2C002C002C2C2C00002C000000
00002C00002C002C004900002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00002C002C2C2C
00002C00002C2C2C2C00002C2C000000002C4900002C2C2C2C2C2C002C00002C00002C00
2C2C2C002C002C2C2C00002C2C00002C2C2C2C000000002C002C002C2C2C00002C000000
0000002C2C2C2C2C2C000000002C00002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C002C002C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C000000
2C2C2C2C2C2C002C0000002C00002C2C2C2C2C2C2C0049002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C000049
A7A7A75F97C597C5C597C5C50097970097975FC5C5005F5F00975F005F5F005F005F9797
A7A7A75F5F002C2C2C5F975F975F5FC5C597C5C5975F5F005F5F005F5F5F005F002C2C2C
005F005F975F5F5F5F5F5F5F4949495F975F5F97005F975F4949494949494949492C2C2C
5F975F5F5F5F9797975F5F5F858585B6B6B64949495F5F5F494949737373A7A7A7B6B6B6
EFC5C5B6B6B6C5C5C597C5C5D4D4D4C5C5C5C5C5C5EFC5C5B6B6B65F9797737373B6B6B6
EFC5C55F97C5C5C5C5A7A7A79797C5B6B6B6C5C5C59797975F97975F5F97858585737373
5F5F5F005F5F005F5F5F5F5F5F975F737373979797A7A7A7D4D4D4B6B6B6A7A7A75F9797
979797A7A7A7D4D4D4C5C5C5B6B6B6D4D4D4D4D4D4D4D4D4C5EFEFB6B6B697C5C5A7A7A7
B6B6B697C5C597C5C597C5C59797C59797C5A7A7A7A7A7A75F97975F97C58585855FC597
A7A7A7A7A7A7B6B6B6C5C5C5D4D4D4D4D4D4C5C5EFC5C5C5C5C5C5C5C5C5B6B6B6C5C5C5
C5C5C5C5C5C5B6B6B6C5C5C597C5C5C5C5C5B6B6B6B6B6B697C5C55F9797A7A7A75F9797
5FC597A7A7A75F97975F97970097975F97970097975F97975F97970097975F97975F97C5
5F97975F97970097975F97975F97C5A7A7A7A7A7A7009797A7A7A75F97975F9797979797
A7A7A75F97975F97975F97975F97975F97975F97975F9797858585979797A7A7A7A7A7A7
5F97C597C597A7A7A7A7A7A7A7A7A75F97C597979797C5C55F97C55F97C5A7A7A7A7A7A7
A7A7A75F97975F97975F97975F97975F97975F5F975F5F975F97975F5F5F2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C2C2C2C00002C2C2C002C00
002C002C0000002C002C2C2C2C2C2C2C2C2C002C00002C002C2C2C2C2C2C00002C2C0000
2C2C2C00002C00002C2C2C2C002C002C2C2C00002C000000002C002C2C2C2C0000002C00
2C2C2C2C2C2C00002C0000002C00002C2C2C2C2C2C00002C002C00000000002C002C2C2C
002C00002C002C2C2C2C00002C2C2C2C2C2C002C002C2C2C002C00002C002C0000002C00
002C002C2C2C2C2C2C00000000000000000000002C2C2C2C00002C2C000073000000002C
4949492C2C2C000000002C002C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C002C002C2C2C
2C2C2C00002C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
4900002C2C2C2C2C2CB6B6B6
E1E1E15F97C597C5C55F97975F97C5009797005F5F5F9797005F5F5F5F5F4949495F5F97
73737397975F5F5F5F5F5F5F4949495FC55FC5C597C5C55F5F5F005F5F0097975F5F975F
5F5F004949495F5F5F5F5F5F975F5F5F5F5F4949495F5F5F5F5F5F4949495F5F00005F5F
49494973737397975F5F5F5F97975F97979797975FB6B6B65F5F005F5F5F5F5F5FC59797
A7A7A797C5C597C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5C597C5C597979797A7A7A797C5C5
5F9797A7A7A7979797A7A7A79797975F9797B6B6B6C5C5C5A7A7A79797975F5F00494949
494949B6B6B65F5F5F494949494949C5C5C5A7A7A7C5C5EF5F97975F975F979797858585
9797975F9797979797C5C5C5B6B6B65FC5C5A7A7A7C5C5C5C5C5C5A7A7A797C5C55F97C5
5F9797A7A7A79797C597C597A7A7A7A7A7A7A7A7A75F9797A7A7A75F97975F97975F97C5
A7A7A7A7A7A7B6B6B6B6B6B6C5C5C5C5C5C5A7A7A7B6B6B6C5C5C5B6B6B6B6B6B6B6B6B6
A7A7A7C5C5C5B6B6B6C5C5C5B6B6B6B6B6B697C5C597C5C597C5C5979797A7A7A75FC5C5
A7A7A7979797A7A7A75F9797A7A7A75F5F970097975F97975F97970097975F9797009797
8585855F97975F97975F979797C5C597C5975F97975F97975F97970097977373735F9797
5F97975F97975F97975F97975F97975F97975F97C55FC597979797A7A7A79797C55FC5C5
97C5C55F9797A7A7A7A7A7A75F97C55F97C55FC5C55F97C55F97C59797975F97975F9797
5F97C55F97C55F97975F97975F97975F5F975F97975F5F970097975F5F974949492C2C2C
2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C
2C2C2C002C002C2C2C2C2C2C002C002C00002C0000002C002C2C2C002C000000002C2C2C
00002C0000002C2C2C002C00002C00002C002C2C2C2C0000002C00002C002C0000000000
2C2C2C00002C00002C2C2C2C002C0049494900002C00002C002C00002C002C2C2C002C00
2C2C2C2C2C2C00002C00002C2C2C2C002C00002C00002C00002C00002C00002C002C2C2C
2C2C2C2C2C2C00002C4900000000000000002C000000002C00002C00002C2C2C2C00002C
0000002C2C2C2C2C2C0000002C2C2C2C2C2C2C00002C2C2C00002C00002C2C2C2C2C2C2C
2C2C2C2C2C2C002C0000002C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00
002C002C2C2C00002C97975F
C5EFEFEFEFEFC5C5C597C5EF5F97C55F97C55F97975F5F5F7373737373734949495F9797
5FC597C5975F97975F97975F5F5F5F5F5F5FC5C5C5C5C55FC5975F97C5975F5F5F5F975F
5F97005F5F5F494949005F005F5F5F975F5F5F5F5F97975F5F5F00005F005F975F494949
5F5F5F9797979797975F975FC5C597979797B6B6B6858585737373A7A7A7A7A7A7979797
5F975FB6B6B6A7A7A7B6B6B6B6B6B6B6B6B6E1E1E1858585B6B6B6A7A7A75F5F5FA7A7A7
5F5F5F9797977373735F5F5FA7A7A7A7A7A7C5C5C5B6B6B6C5C5C5A7A7A7C5C5C55F975F
5F975F97C55F005F00B6B6B6C5C5C5C5C5C5EFC5C5C5C5C597975F5F5F5F5F9797979797
9797975F97979797979797979797975FC5C5009797B6B6B697C5C5A7A7A79797C55F9797
5F97970097975F97979797975F97975F9797009797005F975F97975F97975F97975F9797
9797975F9797A7A7A7979797A7A7A797C5C55F9797A7A7A797C5C5B6B6B697C5C597C5C5
97C5C5C5C5C5B6B6B6A7A7A797C5C597C5C5A7A7A79797C5A7A7A7A7A7A75F9797979797
5F9797A7A7A75F97975F97975F97C59797975F97975F97975F97970097975F9797009797
5F97979797975F97C597979797C5975F9797A7A7A75F97975F97975F97975F97975F9797
5F97975F97975F97975F97975F97975F97975FC5975F97C5A7A7A7A7A7A75FC5C55FC5C5
5F97C5979797A7A7A75F97975FC5C59797979797975F97979797C55F9797A7A7A7979797
5FC5C55FC5975F97975F97975F97975F97975F97975F97975F975F5F9797005F002C2C2C
002C002C2C2C002C00490000002C004900002C2C2C2C2C2C002C00002C002C2C2C2C2C2C
002C0049000000002C00002C002C00002C00002C00000000002C002C2C2C00002C000000
00002C2C2C2C2C00000000002C0000A7A7A72C2C2C00002C00002C2C2C2C2C2C2C000000
2C2C2C002C00002C000000002C000000002C00002C00002C00002C0000002C2C2C00002C
00000000002C0000002C00002C2C2C2C2C2C2C2C2C2C0000002C002C2C2C002C002C2C2C
00000000000000002C00002C0000000000000000002C2C2C2C2C2C00002C2C2C2C2C2C2C
002C0000002C2C2C2C2C00002C2C2C2C2C2C00002C2C2C2C002C002C2C2C00002C002C00
2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C4949492C2C2C2C2C2C2C2C2C002C00
2C2C2C2C2C2C00002C2C0000
D4D4D4B6B6B6C5C5C5A7A7A77373730097970097975F5F97B6B6B6A7A7A75F5F5F5F975F
5F9797979797C5975F97975F5F975F5F975F858585C5C597EFEFC5EFC5C55F975F5F5F5F
5F97002C2C2C005F5F494949005F004949490073005F975F5F5F5F5F5F00005F00494949
2C2C2C004900979797979797975F5F979797C5C5C58585854949495F5F5F5F9797979797
858585C5C5C59797975F9797C597975F97C5B6B6B69797975F5F5F4949494949492C2C2C
005F5FA7A7A77373735F975F97975F97C5C5C5C5C5A7A7A75F975F979797858585A7A7A7
97975F97975F494949494949005F5F5F5F5F5F979797C5C5858585005F5FA7A7A7A7A7A7
858585A7A7A7C5C5C59797C5C5C5C597979700975F5F97975F9797005F5F5F9797979797
0097970097975F97975F97975F97975F97975F97975F97975F97979797975F97975F9797
5F97970097975F97975F97975F97975F97C59797975F97C59797C597C5C597C5C5B6B6B6
97C5C5B6B6B6B6B6B697C5C5B6B6B6B6B6B6A7A7A797C5975F97975F97975F97975F9797
5F97975F97975F97979797975F97C55F9797A7A7A75F97975F97975F97975F9797009797
5F97975FC597A7A7A7A7A7A77373735FC5975F9797A7A7A75F97975F97978585855F9797
5F97975F97975F97978585855F97975F97979797975FC597A7A7A75FC5C5979797979797
979797A7A7A7A7A7A79797975F97C5A7A7A75FC5975F97C55F97C55F97C5A7A7A7979797
5F97975F97C55F97975F97975F5F975F5F970097975F97975F97977373734949492C2C2C
2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C002C00002C0000002C8585852C00002C00002C2C2C00002C490000002C002C0000
002C0000002C2C0000002C00002C009797974949492C2C2C2C2C2C00002C00002C2C0000
002C002C0000002C0000002C2C2C2C2C2C2C0000002C000000002C2C2C2C002C00002C00
00000000002C00000000000000002C00002C00002C00002C002C00002C00000000000000
002C0000000000002C00002C000000490000002C002C2C2C002C000000002C2C2C002C00
00002C4900002C2C2C002C002C2C2C00002C2C2C2C002C002C2C2C0000000000002C2C2C
002C002C2C2C2C2C2C002C00002C002C2C2C2C2C2C002C002C2C2C2C2C2C49000000002C
00002C00002C2C2C2C2C2C2C
EFC5C5EFEFC5D4D4D497C5C5B6B6B697C5C5C5EFEF009797A7A7A75F9797009797979797
5F97975F9797979797C5975F97975F5F975F5F5F5F979797C5C597D4D4D497975F97975F
97975F5F5F5F5F5F00494949494949494949005F0097975F5F975F5F975F5F5F5F5F5F5F
005F004949490073005F5F002C2C2C2C2C2C9797975F5F5F494949C5975F5F5F5F979797
5F5F5F49494997975F5F5F5F5F975F5F5F5F97975F5F5F5F4949495F5F00005F5FA7A7A7
C59797737373C5C55F5F5F5F5F5F5F4949495F9797005F004949495F5F5F97975FC5C55F
97C55F97975F5F5F5F97975F97975F97975F979797B6B6B6A7A7A75F5F5F975F00975F5F
5F979797975FC5C5C5B6B6B6B6B6B6C5C5C55F97C597979700975F5F975FB6B6B6A7A7A7
5F97975F97977373735F97975F97970097970097975F97977373735F97975F9797979797
5F97975F97978585855F97975F97975F97975FC597B6B6B6C5C5C5B6B6B6A7A7A75F97C5
B6B6B6B6B6B6B6B6B697C5C59797C5A7A7A7A7A7A75F97C55F97975F5F975F97975F9797
5F97975F9797979797A7A7A75F97975F97975F97975F97975FC5C59797975F9797009797
5F97C5979797A7A7A7A7A7A75F97975F97975F979797979700975F5F97975F97975FC597
5F97975F97975F97975F97975F97975F97C597C5C59797979797975F9797A7A7A75FC5C5
5F9797979797A7A7A75F97975F97979797975F97C59797975FC5C55F97C5A7A7A7A7A7A7
5F97C59797975F97975F97975F97975F97975F97975F97975F97975F5F5F005F5F490000
002C002C2C2C0000002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C2C2C2C
2C2C2C2C2C2C97979700002C2C2C2C2C2C2C002C00490000002C002C2C2C002C002C0000
00002C00002C002C000000004900002C2C2C2C2C2C002C00002C000000002C0000490000
002C002C2C2C2C2C2C002C002C2C2C2C2C2C002C0000000000002C2C2C2C000000000000
2C00002C0000000000000000000000002C0000002C002C00002C00002C00002C002C2C2C
00000000000000002C002C002C2C2C00002C2C00002C2C2C2C2C2C000000002C002C0000
002C0000002C000000002C004900002C2C2C2C2C2C002C000000002C2C2C00002C002C00
2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C
002C002C00002C2C2C00002C
EFEFC5E1E1E1EFC5C5B6B6B6D4D4D497C5C5A7A7A75F97975F97970097975F97975F5F5F
005F5F00975F5F979785858597975FB6B6B65F5F0097C597A7A7A7B6B6B6979797C5C597
737373A7A7A75F5F5F5F5F5F5F5F5F4949494949495F975F97975F5F975F9797005F5F5F
4949494949494949495F5F002C2C2C2C2C2C5F975F2C2C2C975F5F5F5F0097975F2C2C2C
5F5F007373735F975F5F5F0049494973737397975F7373735F5F5F4900005F975F5F5F5F
B6B6B697975FC597975F5F004949495F5F005F5F0049494997975FC5975F97975F97975F
97975F5F975F5F975F5F5F5F5F5F5F97979797975FA7A7A773737397975F5F5F5F5F9797
73737397975F5F97C597C5C5A7A7A7C5C5C5B6B6B6B6B6B6979797B6B6B6C5C5C5A7A7A7
0097975F97975F97975F975F0097970097975F97970097970097975F97975FC5C5979797
97C5C5A7A7A7A7A7A75F97975F97975F97975F97C5C5C5C5C5C5C5B6B6B6A7A7A75F9797
B6B6B69797C597C5C5A7A7A797C5C597C5C55F97975F97975F97975F975F5F975F00975F
8585855F97975F97979797975F97975F97C55F97979797975F9797A7A7A75F97975F9797
9797975F9797A7A7A7A7A7A75F97975F97979797975F97975F97975F975F5F97975F9797
5F97975F97975F97975F97975F97975F9797A7A7A75F97975F9797A7A7A7979797A7A7A7
5FC5C55F97975F97C55F97975F97975F97975F9797A7A7A75F97C55FC597A7A7A7A7A7A7
5F97C59797975F97975F97975F97975F5F975F97975F5F977373737373734949492C2C2C
2C2C2C2C2C2C2C00002C2C2C2C2C2C002C002C2C2C000000490000002C00000000490000
2C00002C000000002C00002C2C2C2C00002C49000000002C2C00000000000000002C0000
2C2C2C002C00000000000000002C0000002C00002C000000000000002C00000000000000
0000002C2C2C00000000000000002C00000000000000000000002C2C2C2C2C0000002C00
002C00000000002C0000000000000000002C2C00002C2C2C002C000000002C2C2C00002C
000000490000002C00002C000000000000002C000000002C0000002C2C2C002C002C2C2C
002C000000000000002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C0000
000000002C002C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C002C00002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C
C5C5C5E1E1E1C5C5C5B6B6B6C5C5C5A7A7A797C5C5B6B6B6A7A7A75F97C55F9797005F5F
00975F5F975F0097970097975F97979797979797975F975F979797C59797B6B6B6C5C597
C5C597C5C55FC5C5975F5F5F5F975F97975F5F5F0097975F5F5F5F5F975F97975F5F5F5F
494949494949005F5F4949495F5F002C2C2C975F5F5F5F5F5F5F5F975F5F5F975F5F5F5F
975F5F5F97979797977373735F5F5F4949494949495F5F005F5F5F5F5F5F5F5F5F494949
5F5F5F5F5F5F494949C5C5974949490049002C2C2C975F0097975FC5975F5F97005F5F5F
97975F9797005F5F0049494997975F737373858585B6B6B6858585737373009797009797
5F97975F97975F97975F97C5B6B6B6C5EFC59797C5B6B6B697C5C597C5C597C5C55F97C5
5FC5975F97975F97975F97975F97C55F97975FC5C55F9797A7A7A75F97C5A7A7A7A7A7A7
97C5C5A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7B6B6B6B6B6B6C5C5C597C5C55F97C55F97C5
B6B6B6B6B6B6A7A7A75F97C59797975FC5C59797975F97970097975F97975F975F5F5F5F
7373738585855F97975F97975F97975F97975F97979797975F97975F97975F9797009797
0097975F97C55F97978585855F97975F97975F97970097977373735F97975F97975F97C5
5F97975F97975F97975F97C55FC5C59797975F97975F9797A7A7A75FC5C5A7A7A7A7A7A7
5F97C55F97C55F97975F97975F97C55F97975F97C59797975FC5C55F97C5979797A7A7A7
9797975F97C55F97975F97977373735F97975F97975F97975F97978585854949492C2C2C
2C2C2C2C2C2C2C2C2C002C002C2C2C4900002C2C2C002C00002C002C00002C2C2C00002C
002C002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C002C00002C00002C0000002C
0000000000002C00002C00000000002C000000002C0000002C2C2C2C2C2C2C2C2C000000
0000002C2C2C0000000000000000002C00002C00002C000000002C00002C002C00002C00
2C2C2C0000002C2C2C2C2C2C00000000002C00002C00000000002C000000002C00002C00
2C2C2C2C2C2C0000002C00002C0000002C002C2C2C2C00002C2C2C002C00000000000000
00002C000000002C00000000002C0000000000002C2C2C2C00002C5F5F002C2C2C00002C
2C2C2C2C0000002C002C2C2C2C2C2C2C2C2C2C2C2C000049494949002C00000000490000
2C2C2C2C2C2C2C2C2C00002C
B6B6B697C5C59797C55FC5C5C5C5C55FC5C55F97975F9797009797005F9700975F5F5F5F
005F5F005F979797975F97975F5F975F975F85858585858597C55FA7A7A7B6B6B697975F
B6B6B6C5C55F97975F9797975F975F5F975F5F5F5F2C2C2C5F0000975F5F5F5F5F5F975F
5F5F5F4949494949492C2C2C5F5F5F494949494949975F5F494949002C00494949975F5F
002C002C2C2C5F5F5F4949494949494900005F5F5F5F5F00494949005F5F5F5F00494949
5F5F004949495F5F004949492C2C2C5F5F005F5F5F5F5F5F5F97005F5F007373735F5F5F
5F5F005F5F005F97005F5F5F97970097970097975FC5975FA7A7A75F9797009797009797
5F97975F97970097C55F97975F97979797C55F9797A7A7A75FC5975F97975F97C55F9797
5F97979797975F9797C5C5C5B6B6B65F97C5979797B6B6B697C5C55FC5C55F97C597C5C5
A7A7A7A7A7A7B6B6B697C5975FC5C55F9797A7A7A7A7A7A75F97979797979797C597C5C5
C5C5C5B6B6B697C597979797A7A7A7A7A7A79797975F975F00979700975F5F5F5F5F975F
5F975F5F97970097970097975F97975F5F975F97975F97975F97977373735F9797009797
0097975F97975F975F5F97975F97975F97975F97975F97975F97970097970097975F9797
A7A7A75F97C55F97975F97975F97975F97C55F97975F97975F9797A7A7A75F97C5A7A7A7
5F97C59797975F97979797975F9797A7A7A75FC597A7A7A75F97975FC5C5A7A7A75FC5C5
5F97979797975F97975F97975F97975F97975F97978585855F97975F5F5F5F5F5F2C2C2C
2C2C2C002C002C2C2C000000002C002C2C2C2C2C2C2C0000002C00002C002C2C2C00002C
2C2C2C002C002C2C2C2C2C2C2C2C2C002C002C2C2C002C0000002C2C2C2C00002C000000
002C000000002C2C2C002C0049000000002C2C2C2C2C2C2C2C2C2C2C2C2C00002C000000
2C2C2C00000000002C2C00000000002C00000000000000002C0000002C00002C00000000
00002C002C00000000002C002C000000000000000049000000002C002C00000000002C00
00002C00002C000000002C000000000000002C2C2C00002C000000002C002C000000002C
2C000000000000002C00002C0000002C00002C2C2C2C2C2C000000002C002C2C2C2C2C2C
002C00002C002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C00002C2C2C2C2C2C2C2C0000
002C002C2C2C002C00002C00
5FC5975F97975F97C55F9797A7A7A773737373737397979797C5C5A7A7A7A7A7A75FC5C5
C5C5C55F975F5F97975F5F5F5F5F5F5F5F97858585005F975F97975F9797A7A7A7A7A7A7
97979797975F97975F5F5F5F5F5F005F5F5F5F975F5F975F5F5F5F5F5F5F97975F5F975F
97975F494949494949005F00005F5F4949498500005F5F002C2C2C5F5F5F49494997975F
8585854949492C2C2C2C2C2C2C2C2C005F5F5F5F00494949005F5F494949494949494949
0049004949494949492C2C2C00975F5F5F5F5F5F5F5F5F005F5F004949495F5F5F5F5F00
0049005F5F004949495F5F005F5F005F5F5F97975F97975F5F97975F9797009797009797
5F97975F97C5A7A7A75F97C5979797A7A7A75F97975F97975F97975F97C55F97C55FC5C5
5F97C55FC5975F97C5A7A7A797C5C5A7A7A7A7A7A75F97C59797C55F97C55F9797A7A7A7
B6B6B6A7A7A75F97975F97975F97978585855F97978585855F9797B6B6B697C5C597C5C5
A7A7A7A7A7A797C5C5A7A7A7979797A7A7A75F97975F9797005F5F5F5F5F00975F005F5F
005F5F7373735F975F5F5F975F9797005F977373735F975F5F97975F97975F9797009797
009797005F970097975F97975F97975F97C58585855F5F97005F970097975F97975F9797
5F97975FC5975F97C59797C597C5C5979797A7A7A75F97C55F97C55FC5C55F97C5A7A7A7
5F97975F97C55F97975F97975F97C55F97C5979797979797A7A7A75FC5C5A7A7A7A7A7A7
5F97C55F97975F97975F97975F97975F97975F97975F97975F9797005F5F4949492C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C002C00002C004900002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C002C002C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C2C2C2C000000000000
0000002C2C2C002C00002C00002C00002C00002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C00002C00002C2C0000002C000000002C0000002C000000000000002C0000
00002C2C0000002C000000002C00002C2C2C00002C00002C2C00002C2C2C2C2C2C002C00
0000002C0000000000002C00002C0000000000000000002C00002C2C0000000000000000
000000000000002C002C0000002C00002C00002C002C2C2C00000049000000002C00002C
0000002C2C2C2C2C2C0000002C000000002C2C2C2C2C2C2C2C2C2C002C002C2C2C00002C
2C2C2C2C2C2C002C002C2C2C
5F97C50097C597C5C5C5C5C5C5C5C5C597C5A7A7A7A7A7A7C5C5EFB6B6B697975F737373
5F9797005F5F005F5F5F5F5F5F5F5F5F5F979797975F97C55F97975F9797A7A7A7B6B6B6
B6B6B6494949737373C5C59797975F5F5F5F5F975F5F5F5F494949005F5F5F97005F5F00
5F5F5F5F5F5F5F975F4949494949492C2C2C005F5F5F5F005F5F005F5F5F494949000049
4949492C2C2C5F5F002C2C2C4949492C2C2C005F004949494949494949492C2C2C5F5F00
4949495F5F00005F002C2C2C5F5F5F00975F5F5F5F5F5F000073005F5F5F5F5F5F494949
005F00494949005F5F005F005F5F00975F005F5F5F00975F5FC5975F97979797979797C5
5F97C5A7A7A797C5C5C5C5C5A7A7A7A7A7A7C5C5C5C5C5C597C5C55FC5C5979797A7A7A7
5F97C55F9797979797A7A7A797C5C5C5C5C55F97979797975F97975F97975F97975FC5C5
5F97975F97C55F97975F97975F5F975F97975F97975F97975F9797A7A7A7A7A7A7C597C5
97C5C59797C55F9797979797A7A7A75F97975F975F00975F005F5F5F975F5F5F975F9797
5F5F5F5F975F5F5F9700975F0097970097975F979700975F00975F005F5F009797009797
0097970097975F97975FC5975F97975F97975F97975F97975F97970097975F97975F9797
A7A7A75F97C55F979797C5C55FC5C55F97C55F97975F97975F97979797C5A7A7A7979797
A7A7A75F97975F97975F97975F97975F97C55F97975FC5C55F97C55FC5C55F97C55FC5C5
5F97975F97975F97975F97975F97C55F97975F97975F97975F97975F5F975F5F972C2C2C
2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C002C002C2C2C
00002C2C000000002C00002C2C2C2C2C2C2C2C2C2C737373002C002C00002C00002C2C2C
0000002C2C2C0000000000002C000000002C2C000000002C2C2C2C2C2C2C2C2C2C2C2C2C
002C00000000000000000000000000002C002C00000000002C000000002C000000000000
002C00002C002C00002C0000002C002C2C2C002C002C000000002C002C00002C00000000
2C2C2C002C000000000000002C0000000000002C0000000000002C000000000000000000
000000000000000000002C000000002C0000002C002C2C2C002C00002C00002C002C2C2C
00002C00002C00002C2C0000002C00002C002C2C2C494949002C002C2C2C4949492C2C2C
2C2C2C0000002C00002C2C2C
5F97C597C5C597C5C597C5C59797C5005F5F5F5F5F494949A7A7A75F97975F5F975F975F
5F5F975F5F5F005F5F005F5F5F97975F97975F97C59797C5A7A7A75F97C55F979797C597
A7A7A7C5975F0073005F5F5F8585855F975F5F975F97975F4949495F5F000073005F5F5F
5F5F007373735F5F005F5F5F2C2C2C2C2C2C2C2C2C005F005F5F00494949494949494949
494949494949004900494949005F004949494949494949495F5F5F005F00494949494949
5F5F5F494949005F5F0049005F5F005F5F5F5F5F5F5F5F005F5F00494949494949005F00
4949495F5F005F5F5FC5C55F5F5F5F5F97005F5F005F5F5F0097975F9797A7A7A7A7A7A7
5F97975F97C5A7A7A7A7A7A7A7A7A75F9797D4D4D4D4D4D4A7A7A75F97975F97C597C597
5FC5975F97975F97C55F97975F97C55FC5C55F97975F97975F97975F97C55F97975F9797
5F97975F97970097977373735F97975F97970097975F97970097C55F97C59797C5B6B6B6
5FC5C55F97975F97C597C5C55F97975F5F975F9797005F5F00975F5F975F5F5F5F5F5F97
5F5F975F5F5F5F5F5F737373005F5F5F5F9773737300975F0097970097970097975F9797
5F97975FC597A7A7A79797975FC5975F97975F97975F97970097975F9797979797A7A7A7
A7A7A75FC5C5A7A7A797C5C55FC5C55F97975F97975F97C55F97C59797C59797C5B6B6B6
A7A7A75F97975F97975F97975F97975F97975F9797A7A7A79797975F9797A7A7A75F9797
A7A7A75F97975F97C55F97C59797975F97975F97975F97975F97975F979700975F2C2C2C
002C0000002C002C002C2C2C2C2C2C002C002C2C2C2C2C2C002C00002C0000002C2C2C2C
2C2C2C002C002C00002C2C2C2C2C2C002C002C2C2C2C2C2C2C00002C2C2C2C2C2C000000
2C00000000004900002C2C2C0000002C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C002C00
2C2C2C00002C2C00000000002C2C2C2C2C2C00002C002C0000002C0000002C2C2C000000
000000002C000000002C2C2C002C002C0000002C002C000000002C00002C2C000000002C
2C2C2C002C0000002C0000000000002C00002C2C2C0000000000000000002C2C2C002C00
0000002C00002C2C2C0000000000002C2C2C00002C2C2C2C2C2C2C002C002C000000002C
00002C2C000000002C00002C002C00002C00002C002C00000000002C2C2C2C2C2C494949
2C2C2C2C00002C000000002C
0097975F979797C5C55F979797C5C55F5F5F005F5F005F5F005F5F5F5F5F005F5F5F975F
5F5F975F97975F9797005F5F7373735F97979797975F97975F9797A7A7A75F97975F97C5
C5C5C5B6B6B65F975F005F005F5F5F8585857373735F5F5F5F975F5F5F005F5F005F5F5F
5F5F005F5F000049004949492C2C2C494949005F0049494997975F5F975F5F5F5F5F5F00
4949494949492C2C2C4949494949494949494949492C2C2C2C2C2C2C2C2C2C2C2C494949
4949495F975F4949495F5F5F5F5F5F4949494949495F5F005F5F005F5F5F5F5F002C2C2C
005F5F00C5975F975F5F975F5F975F5F5F005F5F5F5F5F5F005F5F85858597C5C597C5EF
97C5C55F97C59797C55F97C55F97975F97975F97975F97975F97975F97C5A7A7A7A7A7A7
5F97975F97975F97975F97975F97975F97975F97975F97975F97975F9797A7A7A75F9797
5F97975F5F970097975F97975F97975F9797A7A7A797C5C5A7A7A75F97C55F97C55F9797
A7A7A75F97975F97975F97C55F97975F9797009797005F97005F975F97975F9797737373
5F5F5F00979700979700975F005F97009797009797009797005F97005F975F97975F97C5
5F97975F97975F97975FC5975F979700975F5F97975F97970097975F97975FC5975FC5C5
5FC5C597C5C5A7A7A75FC5C59797C55F97C55F97975F97975F97C55F97C55F9797A7A7A7
5F97975F97975F97975F97975F97975F97975F97975F97C55F97C5A7A7A75F97C597C5C5
5F97C55F97975F97975F97975F97979797975F97975F97975F5F975F9797005F5F494949
2C2C2C2C2C2C490000002C0000002C2C00000000002C2C2C2C2C2C002C0000002C2C2C2C
2C2C2C2C2C2C002C00002C002C2C2C2C2C2C002C002C2C2C002C004900000000002C0000
2C2C2C000000002C00002C00002C002C2C2C2C2C2C00002C2C2C2C2C2C2C002C002C2C2C
2C2C2C2C2C2C00000049000000002C2C2C2C002C00000000002C00000000000000000000
2C000000002C002C00000000002C00002C00002C00002C0000002C2C2C2C2C2C2C002C00
002C00002C002C2C2C00002C49000000002C2C2C2C0000002C000000002C2C2C2C2C0000
49000000002C002C00002C002C00002C2C2C00002C2C2C2C2C2C2C2C0000002C002C2C2C
2C000000002C0000002C2C2C2C2C2C2C2C2C002C00002C0000002C2C2C2C5F5F0000002C
4949492C2C2C002C002C2C2C
5F97C59797C55F9797009797005F5F975F5F005F5F005F5F494949005F5F5F9797979797
979797B6B6B60097975F97975F97C55F97C55F97979797C59797C5A7A7A797C5C5B6B6B6
C5C5C55F97975F5F005F5F5F5F5F005F975F97975F5F5F005F97002C2C2C005F5F5F5F5F
5F5F004949492C2C2C005F002C2C2C004900005F004949492C2C2C5F975F2C2C2C5F5F00
005F00494949002C004900005F5F5F4949495F975F5F975F2C2C2C2C2C2C494949494949
4949494949494949495F975F5F5F5F4949494949494949495F5F5F0073002C2C2C007300
005F5F5F97975F975F5F975F00975F7373735F5F5F858585005F5F7373735F97975F9797
97C5C5C5C5EFB6B6B697C5C55FC5979797975F97975F97C597C5C5A7A7A7A7A7A7A7A7A7
5F97975F97975F5F975F97970097975F97975F97975F97C55FC5C55FC5C59797975F9797
0097970097970097970097975F97C55F979797C5C5A7A7A7A7A7A75FC5C5A7A7A75F9797
5F97975F97975F979797C5C55F97975F5F975F97975F5F975F5F975F5F5F5F5F97009797
005F5F0097975F9797005F970097975F5F5F5F975F5F97970097975F97C5A7A7A7A7A7A7
5F97C55F97975F97975F97975F97975F97975F97975F979797C597979797A7A7A7979797
A7A7A75F97C55FC5C59797C55F97975F97979797975FC5C5A7A7A75F9797A7A7A79797C5
5F97975F97975F97975F97975F97975F97975F97975F9797A7A7A75FC5C55F97C55F9797
5F5F975F97975F97C55F97C5A7A7A75F97C55F97C55F5FC55F97975F5F97005F97005F5F
2C2C2C2C00002C2C2C2C2C2C002C002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C00002C49000000002C2C2C2C002C00002C00000000002C000000002C0000490000
002C002C2C2C0000002C00002C2C2C2C2C2C2C2C2C2C2C2C2C0000002C0000000000002C
2C2C2C2C2C2C002C00002C002C2C2C002C00002C0000002C00002C002C000000002C0000
00002C00002C002C00000000000000000000000000002C00000000002C0000002C00002C
0000000000002C2C2C00002C00002C000000002C002C2C2C002C002C2C2C002C00002C00
002C002C2C2C00002C002C00002C002C2C2C2C2C2C002C00002C00002C00002C0000002C
00002C0000002C2C2C2C2C2C0000000000002C2C2C002C000000002C2C2C2C2C2C00002C
2C2C2C2C2C2C002C002C2C2C
5F97975FC5C5009797005F5F7373735F5F5F005F5F005F5F005F5F005F9797C5C55F9797
00975F00975F009797B6B6B65F97975F97975F97C55F97979797C597C5C59797C5B6B6B6
97C5C5B6B6B697C55F5F5F5F002C0097975F5F5F005F5F00005F5F5F5F5F5F5F5F5F5F00
0049002C2C2C5F975F4949492C2C2C2C2C2C494949005F5F005F5F005F002C2C2C5F5F00
4949492C2C2C4949495F975F97975F9797005F5F5F97975F4949492C2C2C2C2C2C005F00
4949495F5F5F5F975F5F5F5F5F5F5F5F5F5F005F5F005F5F005F5F49494900975F005F5F
005F5F009797005F5F00975F00975F009797005F5F5F5F5F005F5F5F975F5F97975F9797
5F97C597C5C5C5C5C597C5C597C5C59797C5B6B6B697C5C55F9797979797009797B6B6B6
5F975F5F97975F975F00975F7373735F979797C5975F9797A7A7A7A7A7A75F97975F9797
5F97975F97975F97975F97975F9797B6B6B6B6B6B697C5C55F97C55F97975F97975FC597
5F97975F97C55F97C55F97975F97975F97975F97975F9797005F5F009797009797009797
00975F005F5F5F9797005F97009797005F975F97970097975F97975F97C59797C55F97C5
5F97975F9797737373005F975F975F5F5F975F9797A7A7A75F97C55F97C59797C597C5C5
5FC5C597C5C55FC5C55F97979797975F97C55F9797A7A7A79797975F97C55F97C5979797
8585855F97975F97975F975F5F97975F97975F97C5A7A7A7A7A7A7A7A7A75F97C55F9797
5F97C55F97975F9797A7A7A75F97C55F97975F97975F97975F5F970097975F5F97494949
2C2C2C2C2C2C2C2C2C00002C2C00000000002C2C2C00002C002C002C2C2C00002C2C2C2C
2C2C2C2C2C2C00002C2C2C2C490000002C00000000000000000000002C0000002C00002C
2C00002C00002C000000002C00002C2C2C2C002C002C00002C2C2C2C2C2C2C2C2C000000
2C2C2C00002C2C2C2C2C2C2C002C002C0000000000002C0000002C002C00002C0000002C
002C002C000000002C0000000000000000002C00000000002C00002C2C2C00000000002C
0000002C2C2C2C2C2C002C00002C002C2C2C0000002C2C2C002C002C2C2C00000000002C
2C00002C00002C00002C2C2C002C00002C002C2C2C000000000000002C002C2C2C2C2C2C
00002C00002C2C0000002C002C00002C0000002C00002C00000000002C0000000000002C
2C2C2C2C2C2C002C002C2C2C
5F5F975F9797005F975F5F5F005F970097975F5F5F5F5F5F5F97975F97975F975F737373
005F5F005F5F005F97005F5F5F5F97005F5F005F97005F975F9797B6B6B6B6B6B6C5C5EF
B6B6B6A7A7A75F97975F97975F5F5F4949495F5F5F5F5F005F5F5F5F5F005F5F5F5F5F5F
5F5F5F5F5F5F5F975F5F975F5F5F5F2C2C2C0049002C2C2C0073002C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C5F975F2C2C2C5F5F5F005F5F005F5F5F5F5F004900494949005F5F
4949495F5F005F975F5F5F5F5F5F5F5F5F5F5F975F005F5F005F5F5F975F005F5F5F9797
5F5F5F00975F00975F005F5F005F97005F5F005F970097975F975F5F5F5F5F97975F9797
5F97975FC5C55FC5C55F97C55F97C5A7A7A79797978585858585850097970097975F9797
5F5F5F00975F00975F0097979797975F97975F979797C5C597C5C597C5C55F9797858585
5F9797A7A7A75F9797A7A7A7B6B6B65F97979797975F97975F97970097975F97975F9797
5F97975FC5C55F97975F97C55F5F975F97C55F97C50097970097975F9797005F97009797
5F5F975F979700975F009797005F975F97975F97970097975F97975F97C5A7A7A7858585
5F97975F97975F97977373735F97975F97975F979797C5C5A7A7A75F97C597C5C597C5C5
97C5C55F97C55F97C55F97C5A7A7A79797975F97C5A7A7A797C5C55F97C59797975F9797
5F97975F97970097970097975F97975F9797A7A7A75F97975F97975F97975F97975F9797
5F97975F97C55F97C55F9797A7A7A75F97975F97975F97975F97975F5F975F5F97005F5F
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C002C00
002C002C2C2C2C2C2C490000002C002C2C2C00000000000000000000000000000000002C
000000002C002C2C2C00002C00002C4900002C0000002C00002C0000002C00002C00002C
002C00000000002C00000000002C00002C002C000000002C002C00002C00002C002C0000
00002C002C002C000000002C2C00000000000000002C0000002C002C2C2C2C2C2C2C2C2C
0000002C2C2C2C2C2C2C2C2C00002C2C2C2C000000002C002C2C2C2C2C2C002C0000002C
2C0000000000002C0000002C2C0000002C00002C00000000000000002C002C2C2C002C00
000000002C00002C00002C00002C0000002C2C2C2C00002C2C2C2C00002C2C0000000000
0000002C2C2C2C2C2C2C2C2C
5F975F5F97970097970097975F5F975F979700975F5F975F5F97975F975F5F5F5F5F5F97
005F5F00975F005F5F005F97005F5F005F5F5F97977373735F97975F97C597C5C59797C5
B6B6B6B6B6B6C5C5C5B6B6B697979797C5975F9797C5C55F00975F5F5F5F5F5F005F5F5F
4949495F5F5F5F5F5F7373735F975F2C2C2C4949495F5F5F4949492C2C2C2C2C2C005F00
2C2C2C002C00002C00002C005F5F005F5F5F005F5F5F5F5F4949490049004949495F5F00
5F5F00005F5F5F975F4949494949495F5F5F5F975F5F975F5F975F00975F00975F005F97
005F9700975F005F97005F5F00975F009797005F5F00975F5F975F5F5F5F5F5F5F005F97
005F975F9797A7A7A79797C5A7A7A75F97970097975F97975F97977373735F975F00975F
4949495F97975F975F85858597979797979797C5C5B6B6B697C5C55F97975F97975F9797
5F97C55F97975F97C55F97979797975F97C50097975F97975F97970097975F97975F9797
0097975F97975F97975F97975F97C55F97975F97977373737373735F97975F975F009797
0097975F97970097975F97975F9797005F975F97975F97970097975F97975F97C55F97C5
5F97975F97975F97975F97979797975F97975F97C55F97C55FC5C597C5C5A7A7A75FC5C5
5F97C55FC5975F97975F97975F97C55F97C55F97979797979797975F97975F97C5858585
5F97975F975F5F97975F97975F97975F97C55F97975FC5975F97C55F97975F97C55F9797
A7A7A75F97975F97C55F97C55F97C55F97975F97977373735F97975F5F97005F97494949
2C2C2C2C2C2C2C2C2C2C2C2C00002C00002C2C2C2C0000002C2C2C2C2C2C2C2C2C490000
2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C0000000000000000002C2C2C2C00002C0000
2C2C2C2C2C2C2C2C2C2C2C2C002C00002C0000000000002C002C0000002C00002C002C00
00002C2C00000000002C2C2C2C2C2C2C2C2C00002C000000002C002C0000000000000000
00002C0000002C000000002C00002C00000000002C002C0000002C00002C2C2C2C000000
0000002C2C2C00002C2C2C2C2C2C2C00002C2C00002C2C2C2C2C2C2C2C2C002C00002C00
2C000000002C002C002C0000002C002C0000002C00000000002C0000002C00002C000000
00000000000000000000000000000000002C2C2C2C0000000000002C2C2C2C2C2C002C00
2C2C2C4900002C000000002C
0097970097970097975F5F5F5F9797005F97005F5F7373735F5F975F5F5F5F97975F5F5F
5F5F5F005F5F005F5F00975F005F5F005F5F005F5F005F9700979700979797C5C55FC5C5
9797C597979797C5C5979797A7A7A75F5F5FA7A7A7A7A7A7A7A7A74949495F5F5F5F5F00
0049005F5F005F5F5F5F5F5F5F975F5F975F494949494949494949007300002C00002C00
0049002C2C2C002C000049004949495F5F5F5F5F5F005F975F5F5F5F5F5F0073005F5F5F
0073004949495F5F5F005F5F5F975F5F975F4949497373735F5F5F005F9700975F005F5F
005F5F00975F005F5F005F5F00975F5F5F5F5F5F5F009797005F5F5F5F5F5F975F5F5F5F
5F975F7373735F9797A7A7A7005F978585855F975F5F5F5F005F5F5F5F5F5F97975F9797
5F97975F97975F97975F97C5A7A7A7A7A7A7A7A7A797C5C58585850097975F9797858585
A7A7A75F9797979797A7A7A7B6B6B65F9797979797005F975F97970097975F5F975F9797
5F97975F97975F97975F97C55F97970097975F97975F97975F5F5F5F97975F5F97009797
5F97975F97975F97975F97975F97975F97975F97975F979797C5C5A7A7A75F97975F9797
5F97975F97975F97975F97975FC5C55FC5C55FC5975FC5975F97975F9797A7A7A7A7A7A7
5F97975F97975F97C55F97C55F97975F97975F97975F97975F97C55F97975F9797009797
5F97975F97975F97975F97975F97975F97975F97975F97975F97975F97975F97975F97C5
5F97C55F97975F9797A7A7A75F97975F97C55F97C55F5F975F97975F5F97005F97005F5F
494949000000002C00002C002C2C2C2C2C2C0000002C00002C2C2C002C004900002C2C2C
00000000002C2C0000002C002C2C2C2C2C2C0000000000002C2C2C2C2C2C2C2C2C002C00
2C000000002C2C2C2C002C002C000000002C000000002C002C000000002C2C2C2C000000
000000002C002C000000002C2C00000000002C2C2C002C0000000000002C2C2C2C000000
00000000002C00002C2C0000002C002C2C2C2C2C2C00002C00002C00002C00002C2C0000
002C002C2C2C00002C2C2C2C2C000000002C002C002C0000002C00494949002C00002C00
002C00002C002C2C2C002C00000000002C002C00002C00002C2C2C002C00002C00000000
2C2C2C2C2C2C002C000000000000000000002C2C2C2C00002C00002C2C2C00002C002C00
4900002C2C2C2C2C2C2C2C2C
5F5F5F0097975F97975F9797005F975F5F977373735F975F005F5F0097975F5F5F5F975F
005F5F005F5F005F5F005F5F00975F5F5F5F005F5F005F5F005F5F005F5FB6B6B6858585
5F97975F97975F9797A7A7A74949490073005F5F5F5F5F5FC5C55FC5979797975F5F5F00
5F5F00494949005F005F5F00494949002C00005F5F494949494949005F5F2C2C2C494949
4949492C2C2C005F005F5F5F005F5F5F9797005F5F5F5F5F5F5F5F005F00004900494949
2C2C2C5F5F5F5F5F5F4949495F5F005F5F5F00975F5F975F5F5F5F005F5F005F5F009797
00975F5F979700975F00975F00975F005F975F5F5F5F97975F5F5F5F9797005F5F5F975F
5F5F5F005F5F005F5F005F5F005F5F5F97975F975F5F5F5F005F975F975F5F979700975F
5F5F5F5F97970097975F97975F97975F97975F97975F97975F5F975F97975F979797C5C5
5F97975F979797C5C5C5C5C597C5C55F97C55F97975F97975F97975F5F975F97975F9797
0097975F97975F97975F97970097975F97978585855F5F5F5F97975F975F0097975F9797
5F97975F97975FC597A7A7A75F97975F97975F97975F97975F9797A7A7A75F97975F9797
5F97975F97975F97975F9797A7A7A7A7A7A75F97975F97975F9797A7A7A75F97C55F9797
5F97975F97975F97975F97975FC5C55F97975F97975F97975F975F5F9797009797009797
00975F5F97975F97975F97975F97975F97C55F97975F97975F97975F97975F97975F97C5
5F97C55FC5C5979797979797A7A7A75F97C55F97975F97975F97975F9797009797005F5F
2C2C2C2C2C2C002C00002C002C2C2C2C2C2C490000002C002C2C2C002C0000002C00002C
00000049000000002C2C2C2C2C2C2C002C00002C00002C002C2C2C00002C00002C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C0000002C2C2C2C2C2C002C00002C002C0000
002C002C2C2C002C0000002C000000002C002C2C2C0000000000002C2C2C2C2C2C2C2C2C
2C000000000000000000002C002C002C2C2C002C002C2C2C2C2C2C00002C00002C2C2C2C
00002C00002C2C2C2C00002C2C2C2C2C2C2C002C00002C002C2C2C000000002C00494949
00002C2C2C2C2C0000002C0000002C002C00002C000000002C0000002C002C0000002C00
2C2C2C002C00002C000000000000000000002C2C2C00002C2C2C2C2C2C2C002C0000002C
2C2C2C2C2C2C49000000002C
0097C500979700975F005F5F005F5F5F97975F9797005F5F00975F005F5F005F5F005F5F
494949494949005F5F005F5F005F5F5F5F5F005F5F5F5F5F5F5F5F5F5F5F5F975F5F975F
858585B6B6B65F5F5F5F5F5F5F97975F975F49494985858597C55F97975FC5C59797975F
5F5F005F5F5F4949494949495F975F5F97975F975F5F5F00494949004900005F002C2C2C
2C2C2C4949495F5F5F97975F005F5F5F5F5F5F5F5F005F5F005F5F005F00005F5F494949
005F005F975F5F975F5F5F5F5F5F5F5F975F005F5F5F5F5F5F975F5F975F5F5F5F5F9797
5F97975F975F5F979700975F00975F5F97975F5F5F009797005F5F00975F005F975F5F5F
5F5F5F00975F00975F005F5F005F5F005F5F737373005F5F00975F5F5F5F5F9797005F5F
5F5F5F5F5F5F005F5F005F975F5F970097975F975F0097975F9797A7A7A75F9797A7A7A7
B6B6B69797975F97C55F97975F97C55F97970097975F97975F97975F97975F97975F9797
00975F5F97970097975F97970097975F97975F97975F975F7373735F975F5F97975F97C5
5F97975F97975F9797A7A7A75F97975F97975F97975F5F975F97975F97975F97975F9797
5F5F975FC5C597C5C55F9797A7A7A75F97970097975F975F5F97975F97C55F97975F9797
5F5F970097975F97975F97975F5F975F97970097975F5F975F97970097975F97975F9797
5F97975F97975F97975F97975F97975F97975F97975F97975F97975F97975F97975F97C5
5F97975F97C55F9797A7A7A75F97C59797975F97975F5F975F5F975F5F97005F97005F5F
2C2C2C002C00002C002C2C2C002C002C2C2C00002C002C002C2C2C2C2C2C2C2C2C002C00
4900002C2C2C2C2C2C002C000000002C2C2C0000002C00002C000000002C2C2C2C2C0000
002C002C2C2C2C2C2C00002C2C2C2C002C0049000000002C2C2C2C2C0000002C00002C00
0000000000000000000000002C000000002C2C2C2C00002C2C000000002C0000002C0000
002C0000000000002C00000000000000002C2C2C2C002C002C2C2C00002C002C0000002C
0000002C000000002C00002C2C0000002C002C2C2C002C00002C002C2C2C2C2C2C490000
00002C000000002C00002C002C000000000000000000002C002C00002C00002C00000000
2C0000002C002C0000002C002C2C2C002C0000002C490000002C00002C00000000490000
2C2C2C00002C2C0000000000
0097975F97970097970097977373737373735F5F5F005F5F005F5F5F5F5F494949494949
5F975F005F5F005F5F005F5F00975F5F5F5F5F975F005F5F5F5F5F005F5F005F5F005F5F
494949005F5F5F5F5F5F97975F5F5F97C5C54949495F5F5F5F975F97975F5F5F00975F00
5F5F5F5F9700005F004949495F5F005F975F5F5F5F4949494949492C2C2C494949000049
2C2C2C005F5F5F975F5F975F5F979700975F005F5F005F5F5F5F5F5F975F4949495F5F00
005F5F4949495F5F5F5F5F5F4949495F975F005F5F5F97970097975F979700975F5F9797
9797979797979797975F97978585855F975F5F97975F975F5F5F5F005F5F005F5F005F5F
5F975F5F975F5F5F5F00975F005F97005F5F005F5F005F5F005F5F005F975F5F5F00975F
7373737373735F5F9700975F737373005F975F97975F97979797975F97C55F9797A7A7A7
A7A7A797C5C5A7A7A75F97C59797975F97975F97975F97970097975F97975F97975F9797
5F97975F97975F97975F97979797975F97975F97975F97975F97978585855F97975F9797
9797975F97C55F97975F97979797975F97975F97975F97975F97975F97975F97975F9797
5F97975F975F5F97C55F97975F97975F979700975F005F5F5F97975F97975F97975F9797
5F5F978585855F97970097975F97970097975F975F5F97975F975F5F9797009797009797
5F97975F97975F97975FC597A7A7A75F97975F97975F97975F97C59797975F97975F97C5
5F97C55FC597A7A7A75F97C55F9797A7A7A78585855F97975F97975F9797009797005F5F
2C2C2C2C2C2C490000002C002C0000002C002C2C2C2C2C2C002C002C2C2C2C2C2C490000
002C0000002C2C2C2C4900002C2C2C002C002C000000002C002C002C2C2C00002C002C00
2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C0049000000002C000000002C0000002C000000
00000000002C00000000002C00002C00000000002C2C00002C2C2C00002C00002C2C0000
002C002C000000002C0000002C000000002C2C2C2C002C002C0000002C00002C002C2C2C
00002C00002C2C2C2C00002C2C2C2C002C0000002C0000002C000000002C00002C00002C
002C000000000000000000000000002C000000002C2C2C2C000000000000000000000000
002C00002C000000002C2C2C2C2C2C2C0000002C00002C002C00002C00005F5F0000002C
2C2C2C2C2C2C00002C2C0000
C5C5C5A7A7A79797975F97C597C5C5005F5F005F5F005F5F5F5F5F494949005F5F005F5F
005F5F005F5F005F5F005F5F0097975F5F5F5F5F5F5F5F5F005F5F005F5F005F5F005F5F
005F5F5F5F5F4949495F5F5F5F97975F975F5F97975F5F5F005F5F5F5F005F5F5F494949
5F970000975F5F975F5F975F0049005F5F005F975F5F5F00737373005F00005F5F494949
002C000073004949495F975F5F975F5F975F00975F00975F5F975F005F5F494949737373
5F975F5F975F5F5F5F5F975F00975F5F975F5F97975F97975F9797009797005F975F5F97
5F97975FC5975F97975F9797A7A7A75FC5975F97970097975F5F5F5F975F00975F005F5F
5F5F5F5F975F5F975F5F975F5F5F5F005F97005F5F00975F005F5F5F5F5F5F975F009797
5F975F5F97975F5F97737373005F97009797979797979797D4D4D497C5C597C597B6B6B6
5FC597A7A7A75F97975F97975F5F975F97975F975F5F9797A7A7A75F9797009797005F97
0097975F97975F97975F97975FC5C55F97970097975F97975F97975FC5975F9797979797
5F97975FC59797C5975F5F979797975F97975F97978585855F97975F97970097975F9797
5F97975F97975F9797A7A7A700975F5F5F975F97975F97975F97979797975F97975F9797
8585855F979700979700979700979700975F0097975F975F5F97975F97975F97975F975F
0097975F97975FC5975F9797A7A7A75F97975F97975F97975F979797C5C55F97C55FC5C5
5F97979797975F97975F97C59797975F97C59797975F5F975F97975F97975F9797005F5F
2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C002C00002C00002C00002C0000002C000000
002C002C0000000000002C002C2C2C2C2C2C2C2C2C00002C2C2C2C002C00002C002C2C2C
2C2C2C2C2C2C2C2C2C0000002C2C2C2C2C2C00002C2C2C2C490000002C00000000490000
002C002C2C2C000000000000002C002C000000002C00002C000000002C00002C002C0000
002C00002C00002C000000000000002C2C2C2C2C2C2C2C2C002C000000002C00002C2C2C
002C00002C00002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C00000000000000002C
2C000000002C002C00002C0000002C0000000000002C2C2C002C00002C002C2C2C000000
2C2C2C002C002C2C2C002C00002C00002C002C2C2C002C00002C002C000000002C2C2C2C
002C00002C0000002C000000
C5C5C5D4D4D4D4D4D45F97979797975F9797005F5F005F5F5F5F00494949005F5F005F5F
00975F005F5F00975F005F5F005F5F5F5F5F005F5F005F5F005F5F5F5F5F5F5F5F005F5F
494949005F5F00005F005F005F5F5F5F5F5F5F5F5F5F5F5F005F00005F5F494949005F00
005F5F00975F005F5F00975F005F00005F5F5F9700494949494949494949494949005F5F
494949005F5F2C2C2C005F002C2C2C00975F00975F00979797975FC5C55F97975F5F5F00
5F5F5F5F975F5F975F005F5F5F5F5F5F975F5F975F5F5F5F005F5F005F970097975F9797
5FC5975F97975F97975F97975FC5C55FC5C55F97977373735F975F5F975F5F975F005F5F
5F975F005F5F5F5F5F005F5F5F5F5F5F5F97005F5F00975F5F5F5F5F97975F975F5F9797
00975F5F97975F97970097975F9797979797A7A7A797C5C5A7A7A7A7A7A75F97C55FC597
5F97975F97979797975F97975F97975F97975F97975F97975F97975F97975F97975F9797
5F97975F97975F97975F97975F97979797975F97975FC5C5A7A7A79797975F97975FC597
A7A7A79797975F97C55F97975F97975F97975F97975F97975F97975F97975F9797A7A7A7
5F97975F979797C597005F975F97975F97975F5F975F97975F97C55F97975F97975F9797
73737300979700975F00975F00979700979700975F0097975F97970097975F97975F9797
0097975F97975F97975FC5975F97975F97975F97975F97975FC5C55FC5979797975F97C5
97979797C5975F97975FC5C55F97975F97975F97C55F97975F97975F5F975F975F494949
2C2C2C002C0000002C2C2C2C000000002C002C000000002C49000000002C2C2C2C2C0000
002C00002C002C2C2C00002C2C2C2C2C2C2C0000002C2C2C2C2C2C000000002C0000002C
2C2C2C2C2C2C002C000000002C00002C2C2C0000000000002C2C2C002C002C2C2C002C00
002C0000002C2C2C2C002C00002C00002C0000002C002C00000000002C00000000000000
002C002C2C2C0000002C00002C000000002C2C00002C2C2C002C0000000000002C00002C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C0000002C000000002C
00002C2C2C2C0000002C2C2C00000000002C002C0000002C00002C002C00002C0000002C
002C00000000002C00002C00002C00002C000000002C2C2C0000002C000000002C00002C
2C2C2C2C2C2C2C2C2C000000
D4D4D4D4D4D4C5C5C597C5C597979700979700975F005F5F005F5F005F5F005F975F975F
00975F009797005F5F5F5F5F005F5F5F5F5F5F975F4949495F5F5F005F5F005F5F005F5F
005F5F005F5F005F5F2C2C2C5F5F5F5F975F005F5F5F5F5F005F5F7373735F5F005F5F5F
4949495F5F5F5F5F5F494949005F004949495F5F5F5F5F004949492C2C2C005F005F5F00
5F5F5F0073005F5F0049494949494949494900975F5F5F975F97975F97970097975F975F
5F975F97975F7373735F97975F97975F975F0097975F5F970097975F97975F97975F9797
9797975F97975F97975F9797979797B6B6B6C5C597A7A7A75F97975F97975F97975F5F5F
00975F005F5F7373730097975F975F5F5F977373735F975F00975F5F5F00005F5F5F9797
005F5F00975F5F97975F97975FC597A7A7A75F97975F97979797975F97975F9797009797
A7A7A797C5C55F97975F97975F97975F97975F97975F97975F97970097970097975F9797
5F97977373735F97975F97975F97975F97975F97975FC5C55FC5975FC5C5A7A7A75F9797
B6B6B65FC5C5A7A7A75F97975F97975F97975F97975F97977373735F97975F97975F9797
5F97978585855F97975F97970097975F979797C5975FC5975FC5C55F5F975F97975F9797
5F97975F97975F979700979700975F009797009797005F970097975F97975F97975F9797
5F97975F9797A7A7A75F97979797975FC5975F97975F9797A7A7A7A7A7A7A7A7A7A7A7A7
97C5C55F97975F97975F97C5979797A7A7A75F97975F97975F97975F9797005F975F5F5F
2C2C2C2C2C2C002C0000002C2C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C002C2C2C0000000000002C00004900002C0000000000000000000000
2C2C2C002C00002C00002C0000002C00002C0000002C0000002C00002C0000002C2C0000
2C00002C2C2C002C00002C000000002C000000002C2C0000000000000000002C00000000
002C00000000000000002C000000000000000000000000000000002C000000002C00002C
2C2C2C002C000000002C00000000002C2C2C2C2C2C002C00002C0049494900002C002C00
2C0000002C002C2C2C002C002C000000002C002C000000002C2C2C002C00002C002C2C2C
00000000002C000000000000002C00002C0000002C002C002C2C2C00002C2C2C2C2C2C2C
00002C00002C000000002C00
C5C5C597C5C55F97C55F97975F5F975F5F5F5F5F5F005F5F5F5F5F5F5F5F5F9797A7A7A7
5F975F5F9797B6B6B65F979785858500975F494949005F5F5F5F5F494949005F5F00975F
005F5F2C2C2C005F5F4949495F975F494949005F5F494949005F007373735F975F5F5F5F
00975F5F5F5F5F975F2C2C2C2C2C2C5F5F000049004949492C2C2C2C2C2C2C2C2C005F5F
4949495F5F5F2C2C2C004900005F004949495F5F0000975F5F5F5F005F5F0097975F9797
97975F5F5F5F5F9797005F975F5F975F975F5F975F5F5F5F5F5F5F5F97975F97975F9797
5F97978585855F97975F97975FC5979797979797C5A7A7A75FC5975F97975F97975F5F5F
005F5F0097975F5F5F005F5F00975F5F97975F975F5F975F005F5F005F5F5F97975F975F
005F5F979797A7A7A75F9797A7A7A75F97975F97979797975F97970097970097975F975F
5F97975F97975F97975F97975F97970097975F97975F97975F979700979700975F5F9797
5F9797A7A7A75F97975F9797858585979797A7A7A75F97C59797975F97975F9797A7A7A7
A7A7A7A7A7A79797979797975F97975F97975F97979797975FC5975F97975F97975F9797
A7A7A75F97975F97975F97975F97975F97979797975F97975F97975F97975F97975F9797
5F97975F97975F97975F97970097977373735F975F0097975F97975F97975F97975F9797
5F9797A7A7A75F97975F97975F97975F97979797975F97975FC5C55F97C5A7A7A75F97C5
5F97C50097975F97975F97975F97979797975F97975F97975F97975F97975F5F97494949
494949002C002C2C2C00002C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C00002C2C2C
00002C002C002C2C2C002C00490000002C00002C002C2C2C002C000000002C2C2C2C2C2C
2C2C2C0000002C0000000000002C00002C00002C00002C002C0000000000000000002C00
002C00002C000000002C000000002C002C000000000000002C00002C2C2C2C2C2C490000
00002C00002C2C0000002C002C000000000000000000000000000000002C2C0000000000
2C2C2C002C002C0000494949002C002C2C2C2C2C2C2C2C2C0000002C2C2C002C002C2C2C
002C00002C002C2C2C2C000000002C2C0000002C0000002C002C002C00002C00002C2C2C
2C0000002C002C00000000002C2C2C002C00002C002C2C2C2C2C2C00002C2C2C2C00002C
2C2C2C2C2C2C002C00000000
5F97970097975F97975F97975F97977373735F5F5F5F5F5FB6B6B6005F5F5F975F5F975F
8585855F97975F9797009797005F5F005F5F005F5F494949005F5F5F5F00494949005F5F
4949495F5F5F5F5F5F005F004949495F5F5F0049000049004949494949495F5F5F5F5F5F
5F5F5F5F5F5F5F5F5F4949495F5F5F005F00494949002C00002C00004900005F005F975F
5F5F5F2C2C2C005F5F5F975F5F975F005F5F5F9797494949494949494949005F97979797
97C5975F97975F97975FC5979797979797970097975F97970097975F97975F97975F97C5
97979797C5979797975F97975F97C55F97975F97979797975F97975F97975F97975F975F
5F979700975F5F5F5F5F5F5F5F97977373730097975F97975F97975F97975F5F5F009797
5F97975FC597A7A7A7A7A7A78585855F97975F5F975F975F5F97975F97975F97975F5F97
5F97975F97975F97975FC5975F97975F97970097975F97975F9797005F975F97975F97C5
A7A7A75F97C55F97978585855F97975F97975F97975F97975F97975F97975F97975F9797
A7A7A7A7A7A7A7A7A7A7A7A75F97C55F97975F97975F97978585850097975F97975F9797
0097975F5F5F5F97975F9797A7A7A79797979797975F5F975F97975F97975F97975F9797
5F97975F97975F97975F97970097975F97975F5F975F97975F9797A7A7A7979797858585
979797A7A7A75FC597858585979797979797A7A7A797C59797C5C5A7A7A797C5C55FC5C5
5FC5C5A7A7A75FC5C59797975F97C5A7A7A75F97975F97975F97975F97975F5F97005F5F
0049002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C490000002C002C2C2C2C2C2C2C2C2C
0000002C2C2C2C2C2C2C2C2C00002C002C00002C002C2C2C2C2C2C002C00002C0000002C
2C2C2C002C002C00000000002C00002C2C2C2C2C2C0000002C00000000002C000000002C
2C2C2C002C002C00002C000000002C2C00000000002C2C2C00002C002C0000002C2C2C2C
000000002C00002C002C0000002C002C000000000000000000000000002C000000000000
002C00002C00002C002C2C2C2C2C2C0000000000002C2C2C2C2C2C00000000000000002C
002C002C0000002C0000000000002C2C0000002C000000002C000000002C000000002C00
000000002C00000000002C002C2C2C002C00002C002C2C2C2C2C2C00002C2C2C2C2C2C2C
2C2C2C00002C2C2C2C000000
5F97975F97975F97C50097975F97975F97975F97975F5F5F7373735F5F5F5F9797737373
A7A7A7A7A7A75F97975F5F5F005F5F5F5F5F5F5F5F005F5F005F5F5F5F5F494949005F00
005F00005F5F5F5F5F5F5F5F5F975F005F002C2C2C2C2C2C4949495F975F005F5F005F5F
005F5F00975F7373734949492C2C2C007300494949005F002C2C2C2C2C2C005F5F5F5F5F
4949494949494949497373735F97975F975F5F97974949495F5F5F005F5F005F97A7A7A7
5F97975F97975FC5C55FC5C59797C5A7A7A75F97975F97970097975F97975F97975F9797
5FC5975F97C55F97975F97975F97970097975F97975F979797C5C5A7A7A7A7A7A75F97C5
5F97975F97975F97977373735F975F5F979700975F5F975F4949495F97975F97975F9797
97C597A7A7A75F97975FC5C5A7A7A7A7A7A75F97975F975F005F975F97975F9797737373
5F97975F97975F97975F97975FC5970097975F97970097975F97975F97975F9797979797
5F97975FC5975F979797C5975F97975F97975F97C55F97C55F97C55F97975F979797C597
5F97975F97975FC5C5A7A7A79797970097975F97975F97975F97975F97975F97975F9797
5F975F5F97975F97975F97979797975F97975F97975F97975F97970097970097975F9797
5F5F975F97975F97975F97970097977373735F97975F97975F97975F97975F97975F9797
5FC5C5A7A7A797C597A7A7A7A7A7A797979797C5C5B6B6B6A7A7A7A7A7A79797979797C5
5FC5C5A7A7A75FC5C55FC5C5A7A7A79797979797975F97C55F97975F97975F9797005F5F
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C000000002C000000002C2C2C2C2C2C2C2C2C
2C2C2C49000000000049000000002C2C2C2C002C002C2C2C4900002C2C2C000000000000
002C00002C0000002C002C00002C000000002C00002C00000000000000002C00002C0000
00002C2C00002C0000002C0000002C00002C00002C002C002C2C2C00002C2C2C2C00002C
490000002C002C2C2C002C002C2C2C2C000000000000000000000000002C00002C000000
2C2C2C00002C2C000049000000002C2C00002C2C2C0000000000002C2C2C2C2C2C002C00
2C2C2C00002C2C2C2C00000000002C002C0000002C00000000002C0000002C2C2C2C0000
2C2C2C2C0000002C002C000000002C002C002C2C2C5F5F000000002C2C2C2C0000002C00
2C2C2C2C2C2C00002C2C0000
97C5C5B6B6B65FC5C55FC5979797C5B6B6B697C5C597C597B6B6B6A7A7A75F979797C5C5
D4D4D497C5C5858585005F5F5F5F5F00975F005F5F005F5F005F5F4949494949492C2C2C
4949495F5F00494949005F5F494949004900005F5F005F0049494900975F5F5F5F5F5F5F
005F5F005F5F5F5F5F5F5F5F5F975F2C2C2C4949492C2C2C4949492C2C2C4949495F975F
49494997C5C597C5C5A7A7A7A7A7A79797975F975F5F975F5F5F5F0097975F97975F9797
5F97975F97975F9797A7A7A797C5C597C5C5B6B6B697C5C55FC5975F97975F97C59797C5
A7A7A75F97975F97975F97970097975F5F5F7373735F979797C5C597C5C597C5C5A7A7A7
5FC5978585855F5F5F7373735F975F5F979700979700975F7373735F9797005F97009797
5F97970097975F9797A7A7A7A7A7A79797975F97975F97970097975F97975F97975F9797
5F97975F97975F97978585855F97975F97975F97975F97975F97975F5F975F97975F97C5
5F97975F97975F97975F97975F97975F97975F97975F97975F97979797975F97975F9797
009797A7A7A7858585A7A7A75F97C55F97C59797975F97C55F5F975F97975F9797009797
5F5F975F97975F97975F97975F97975F97975F97975F97975F97975F979700975F009797
005F970097970097975F97970097970097975F97975F97975F97975F97975F97975F9797
979797979797A7A7A7A7A7A7979797A7A7A7A7A7A75FC5C59797C55F97C55FC5C55FC5C5
9797C55F97975F97C59797C5A7A7A75F97975F97975F5F975F97975F5F97009797005F5F
494949002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C000000002C2C2C000000002C00
2C2C2C2C2C2C2C2C2C002C002C2C2C490000002C0000002C2C2C2C002C002C0000002C00
2C2C2C00002C002C00002C00002C00002C00002C00002C00002C000000002C000000002C
002C002C2C2C00002C00002C00002C2C2C2C2C2C2C002C002C2C2C2C2C2C002C002C0000
00002C002C002C2C2C002C00002C002C000000002C0000000000002C00002C2C2C2C2C2C
002C00002C00002C00002C002C2C2C2C2C2C2C2C2C000000000000002C00002C00000000
00002C000000002C00000000002C0000002C0000000000002C000000002C2C2C2C000000
00002C2C00002C2C2C00002C00002C002C002C2C2C2C2C2C002C00002C002C2C2C2C2C2C
2C2C2C490000000000002C00
C5C5EFA7A7A75F97975F9797005F5FC5C5EFB6B6B69797975F5F975F9797D4D4D4D4D4D4
D4D4D49797C5A7A7A7005F5F005F9700975F005F5F4949495F5F5F4949494949492C2C2C
494949005F00005F5F00975F5F5F5F005F00494949005F5F5F5F5F5F5F5F494949005F5F
005F5F005F5F005F5F5F5F5F00975F4949492C2C2C2C2C2C005F5F5F5F977373735F5F5F
5F97979797C597C5C597979797979797C5975F975F97979797C5975F975F5F9797009797
005F5F0097975FC5C597C5C55FC5C59797C5B6B6B6A7A7A7A7A7A75F97975F9797A7A7A7
0097975F975F5F5F975F5F5F0097975F97975F97975F97975F5F975F97C5009797009797
5F9797B6B6B6A7A7A79797975F9797005F5F5F975F5F975F5F975F5F975F5F97975F9797
5F975F0097975F97970097975F97975F97C55F97975F97975F97975F97975F97975F9797
5F97C55F97975F97975F97975F97975F97970097975F97975F97975F97975F97975F9797
5F97975F97975F97975F97975F97C55F97975F97975F97C55F979700975F0097975F9797
00975F005F975F97975F97975F97975F97975F97975F5F975F97979797975F97975F9797
5F97975F97C55F97C5A7A7A75F5F975F97975F97970097975F97975F97975F97975F9797
5F97975F5F975FC5975F97975F97975F97975F97975F97975F97975F97970097975F9797
9797975FC597A7A7A75FC59797C5C55F979797C5979797975FC5C55FC5C5A7A7A75F97C5
9797979797975F9797979797A7A7A7A7A7A75F97C55F97975F97975F5F975F9797005F5F
4949492C2C2C2C2C2C002C002C2C2C00002C002C0000002C0049000000002C2C2C002C00
00002C00002C2C2C2C2C2C2C00002C00002C2C2C2C2C2C2C0000002C2C2C00002C002C00
4900002C2C2C2C2C2C0000002C2C2C002C000000002C2C2C2C2C2C0000000000002C2C2C
00002C2C000000000000000000002C00002C2C2C2C002C00002C002C2C2C2C2C2C002C00
2C2C2C00002C00000000000000002C00002C2C00002C000000000000000000002C002C00
00002C002C000000002C2C2C0000002C00002C2C2C002C00002C00000000002C002C0000
2C2C2C2C00000000000000002C000000002C0000002C00000000000000002C2C2C000000
2C2C2C002C002C0000002C002C2C2C00002C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
002C00002C002C00002C0000
B6B6B6A7A7A79797978585855F5F5FD4D4D4A7A7A7B6B6B65F97975F97975F97C59797C5
97C5C55F9797A7A7A7005F5F8585855F975F005F5F5F5F5F005F5F5F5F5F5F5F5F494949
5F5F5F0073005F5F5F005F5F005F004949490073004949495F5F5F005F5F005F5F005F5F
00975F005F5F5F5F5F005F5F005F5F5F5F5F737373005F5F005F5F7373735F5F5F005F5F
5F979797C5C5A7A7A79797975F979700975F0097975F5F005F975F00975F005F97005F5F
005F5F5F97975F979797C5C5A7A7A797C5C55FC5C55FC5C5B6B6B6A7A7A79797975F9797
0097975F9797009797009797009797009797005F975F5F975F97975F979700975F5F975F
5F97C55F97C5D4D4D48585855F97977373735F5F5F0097970097970097975F97975F9797
5F97C55F97975F97975F97975F97975F97975F97970097975F97975F9797979797A7A7A7
5F97975F97975F97975F97975F97975F97C55F9797A7A7A7A7A7A75F97970097975F9797
5F97975F97975F97975F97975F97975F97975F97975F97975F5F5F005F975F97975F5F97
00975F5F5F975F97975F97975F97975F97975F97975F97975F5F975F97979797975F97C5
5F97975F97975F97975F97975F97975F97975F97975F97975F97C55F97C55F975F5F9797
5F5F975F97975F97970097975F97975F97970097975F97975F97C55F97C55F97975F9797
5F97975F9797858585979797979797A7A7A7979797A7A7A75F97C55F9797979797979797
A7A7A75F9797A7A7A7A7A7A75F97975F97C55F97975F97975F97975F97975F5F97494949
2C2C2C2C2C2C002C004900002C2C2C00002C2C2C2C002C0000002C2C00002C2C2C2C2C2C
2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C000000002C0000002C00002C
00002C002C0000002C00002C00002C002C002C2C2C00002C0000002C00002C00002C2C2C
00002C00002C0000000000000000004900004900002C2C2C002C0000002C00002C2C2C2C
2C2C2C2C2C2C0000000000002C2C2C00002C2C0000002C00002C000000002C2C2C000000
2C0000002C002C2C2C00002C00002C002C00002C000000000000002C2C2C002C00000000
00000000002C002C00002C0000000000000000002C002C0000002C2C000000002C000000
00002C002C00002C00002C00000000002C00002C0000002C2C2C2C002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C00002C
B6B6B697C5C5C5C5C5A7A7A75F5F5FEFEFC5FFEFEF5F9797C5EFEF97C5C5B6B6B697C5C5
009797A7A7A77373735F97C55F975F494949005F5F005F5F005F5F5F5F00005F005F5F5F
97975F5F975F2C2C2C4949495F5F005F5F5F005F5F00975F005F5F005F5F005F5F005F5F
005F5F5F5F5F005F5F9797975F97975F97975F97975F5F5F5F9797A7A7A75F97975F9797
00975F5F97977373735F5F975F975F005F9700975F005F9700975F005F5F005F975F5F97
005F970097975F9797A7A7A75F97975F9797A7A7A75F97C5A7A7A75F97C597C5C5B6B6B6
7373735F9797009797005F5F5F97970097975F97975F5F975F97975F9797737373494949
005F5F5F97970097975F975F5F975F009797009797009797005F975F975F5F97975F9797
5F97970097978585855F97C50097975F97975F979797C5C5A7A7A7A7A7A75FC5975F9797
5F97975F97975F97C55F97975F97975F9797979797B6B6B65F97975F97975F9797009797
5F9797A7A7A75F97975F97975F97C55F5F975F97970097975F5F975F97975F5F975F9797
5F97975F97970097975F97975F97975F5F975F97975F5F975F97975F97975F97975F9797
9797975F97C5A7A7A75F97C55F97975F97975F97975F97C55F97975F9797009797005F97
5F97975F5F5F5F97975F97975F97975F97975F97975F97970097979797979797975F9797
5F97975F97975F97C55F97C55F9797A7A7A75F97C5A7A7A75FC59797C5C55F97C55F9797
5F97975F9797A7A7A79797975F97979797975F97975F97975F5F975F97975F5F97005F5F
2C2C2C2C2C2C002C0000002C2C2C2C002C002C0000002C002C2C2C002C00002C002C2C2C
002C000000002C2C2C002C002C2C2C00002C00002C0000000000002C2C2C00002C2C2C2C
0000002C0000002C002C2C2C0000000000002C2C2C002C000000002C000000002C2C2C2C
49000000002C000000000000490000002C00002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C0000002C2C2C002C002C2C2C00002C2C0000002C002C0000002C00002C00002C00
2C2C2C002C0000002C00002C2C00002C000000002C2C00002C2C2C00000000002C000000
00002C000000000000002C002C00000000000000000000002C000000002C000000000000
000000002C00002C000000000000002C0000002C002C2C2C97975F2C2C2C002C002C2C2C
2C2C2C4900002C2C2C2C2C2C
B6B6B697979797C5C597C5C55F5F97005F975F5F979797975F97975F97C55F97975F9797
A7A7A75F9797009797005F5F005F5F005F5F005F5F005F002C2C2C5F5F5F5F5F5F5F5F5F
005F005F5F5F5F975F4949495F5F5F005F5F005F5F5F5F5F5F5F5F4949495F5F5F005F5F
005F5F5F97977373735F9797A7A7A75F9797005F5F979797B6B6B6A7A7A75F975F009797
5F9797A7A7A700975F5F5F5F0097975F97970097975F97975F5F5F005F5F5F5F97005F5F
005F97005F5F5F5F97005F5F5F9797979797A7A7A75F979797C5C5979797A7A7A7A7A7A7
5F97970097975F97975F97970097975F97978585855F97970097975F97975F5F97005F97
005F5F00975F005F975F5F97005F5F00975F0097970097970097975F97975F97975F9797
5F97975F97975F97975F9797005F970097979797C55F97975F9797979797A7A7A75F9797
5F97C5B6B6B6A7A7A797C5C5A7A7A7A7A7A7B6B6B6B6B6B6A7A7A75F97C55FC5C55F9797
5F97C55F97975F5F975F97C55F975F0097975F5F5F0097975F97975F97975F5F975F975F
5F97978585855F97975F97975F97975F97970097975F97975F97975F97975F97975F97C5
5F97975F97975F97975F97975F97C55F97975F97975F97975F97975F9797005F975F9797
00975F5F97975F97970097975F97975F97970097975F97975F97975F97975F9797858585
5F97975F97978585855F97975F97979797975F97975FC5975F97975F97975F97C55F9797
5F97C55F97975FC597A7A7A7A7A7A7A7A7A79797975F97975F97975F9797009797005F5F
494949002C002C2C2C002C002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C00002C2C2C
002C00490000002C00002C000000002C0000000000000000002C002C2C2C00002C002C00
2C2C2C2C2C2C2C2C2C0000000000002C00002C2C2C002C000000002C000000002C00002C
00002C2C2C2C002C00002C00002C002C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C00002C
00002C2C2C2C2C0000002C0000002C00002C2C2C2C2C0000002C00002C00000000000000
002C002C000000002C000000002C000000002C00000000000000002C2C2C0000002C0000
00000000000000000000000000000000000000002C00002C000000000000000000002C00
00000000002C0000000000000000002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C002C00
2C2C2C00002C00002C000000
C5C5C59797C55F97C55F97975F97C55F97975F97975F9797C5C5EFB6B6B65F97975F9797
5F979700979700979700975F005F5F4949494949495F975F2C2C2C97975F2C2C2C005F5F
00975F005F5F5F5F5F494949494949005F5F005F5F005F5F4949494949495F5F97979797
005F5F5F97975F979797C5C597C5C573737300975F97C5C5C5C5C597C5C55FC5C5979797
5F97975F5F5F5F5F5F5F5F5F005F5F5F5F5F5F5F5F5F5F97005F5F5F979700975F00975F
009797005F975F5F97005F970097975F97975F97979797975F979797C5C5A7A7A7A7A7A7
A7A7A75F975F5F975F5F5F975F97970097975F97975F97970097975F97975F5F5F005F5F
005F5F005F5F005F975F975F005F5F5F975F005F975F97975F97975F5F5F5F97975F975F
5F97975F97975F97975F97975F97975FC5C5979797979797979797A7A7A7979797009797
97C5C5A7A7A75F97C5B6B6B697C5C5B6B6B6B6B6B697C5C5A7A7A7A7A7A75F97C55F9797
5F97970097970097975F5F975F97975F97975F97975F97975F97975F97970097975F9797
5F97C55F97975F97975F9797005F975F97975F97975F5F5F5F97975F97975F97975F9797
5F97C55F97975F97975F97975F97975F97975F9797A7A7A75F97975F97975F97975F9797
5F975F005F5F00975F5F97970097975F97970097975F97975F97975F97975F97975F9797
5F97975F97975F97975F97975F97975F97970097975F97975F97975F97C55F97975F97C5
A7A7A75F97C5A7A7A75F97C5A7A7A75F97979797975F9797009797737373005F97005F5F
2C2C2C2C2C2C002C0000002C5F979700002C2C2C2C2C2C2C2C2C2C00002C00002C002C00
4900002C2C2C002C002C2C2C2C2C2C002C002C00000000002C000000002C2C2C2C2C2C2C
002C00002C002C2C2C00002C00002C2C2C2C2C2C2C002C002C00000000000000002C2C2C
2C2C2C2C2C2C2C2C2C00002C00002C2C2C2C2C2C2C00002C002C002C2C2C2C2C2C2C2C2C
00000000002C2C2C2C002C002C2C2C000000002C00002C00002C00000000000000000000
002C00002C0000002C0000000000002C2C2C2C2C2C00000000000000000000002C00002C
002C00000000002C002C2C2C2C000000002C0000002C2C2C000000002C0000002C00002C
0000002C2C2C2C00002C2C2C2C0000002C002C2C2C002C002C0000002C002C000000002C
002C0000002C2C2C2C2C0000
C5C5C5C5C5C55F97C55F97975F9797A7A7A79797975F9797A7A7A75FC5C5C5C5C55F97C5
A7A7A7A7A7A79797975F9797005F5F5F5F5F5F975F0049002C2C2C5F5F5F004900005F5F
005F5F005F5F5F5F5F005F5F494949737373737373005F5F005F5F494949A7A7A75F9797
5F97C5A7A7A7B6B6B697C5C59797975F97975F97C5C5C5C5D4D4D497C5C55F97C55F9797
00975F0097975F9797737373737373005F5F5F5F5F5F975F5F5F5F737373737373009797
5F5F5F5F5F5F5F97979797975F5F5F5F9797979797A7A7A79797C5A7A7A797C5C5C5EFC5
C5EFC5C5C5C5B6B6B65F97975F97975F97975F97975F5F5F7373735F5F975F975F005F5F
009797005F5F5F5F5F5F5F970097970097975F97975F97975F97975F97975F9797009797
0097975F9797009797009797979797979797A7A7A75F97979797975FC597979797B6B6B6
B6B6B6B6B6B6B6B6B6C5C5C5B6B6B697C5C5C5C5C5B6B6B6C5C5C59797C55F97C5A7A7A7
5F97970097975F97978585857373735F97975F979700975F5F97970097975F9797858585
5F97975F97975F97975F97975F97970097975F97975F97975F97975F97C55F97C55F9797
5F97978585855F97978585855F97978585855F97975F97975F97975F97975F9797009797
5F97970097975FC5C55F97975F97C50097975F97975F97975F97970097975F97975F9797
7373730097975F97970097975F97975F97977373730097975F9797858585A7A7A79797C5
97C5C55F97C55F97975F97979797975F97C55F97C55F97C55F97970097975F97972C2C2C
2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C002C00002C0049000000002C000000002C00
002C0000002C002C00002C002C2C2C49000000002C0000000000002C2C2C00002C002C00
2C2C2C002C002C00002C2C2C00002C2C2C2C002C00002C0000002C00002C002C002C2C2C
00002C002C00002C002C2C2C00000000000049000000002C002C00002C00002C00000000
0000002C2C2C002C00002C00002C0000002C2C0000002C002C00000000002C2C2C00002C
2C000000000000000000002C00002C002C0000002C002C0000002C2C2C2C2C000000002C
002C00002C0000002C002C002C00000000000000002C0000000000000000000000002C00
002C00002C00002C0000002C00002C00002C2C00002C2C2C00002C2C2C2C2C00002C2C2C
002C0049000000002C000000
C5C5C5C5C5C5C5C5C5C5C5EFA7A7A797C5EFB6B6B65F97C5C5C5C597C5C597C5C55FC597
5F97975F97975F97C55F5F5F5F5F5F4949495F975F0049000049002C2C2C005F5F005F97
5F97975F97975F5F5F00975F9797975F97975F5F5F00975F005F97005F5F005F5F9797C5
5F9797B6B6B697C5C58585855F9797A7A7A75F97C59797C597C5C5A7A7A75F97C55F9797
A7A7A700975F5F975F5F5F974949495F5F5F5F5F5F0097977373735F5F5F5F5F975F5F97
5F5F97005F5F5F5F5F5F5F970097975F5F975F97975F5F97A7A7A75F9797A7A7A7A7A7A7
A7A7A7979797A7A7A75F97975F97977373735F97975F5F975F5F975F97975F97975F5F97
009797005F5F8585855F97975F9797005F5F5F979700979700975F5F975F5F97975F9797
5F97975F97975F97975F97C55F97975F97975F9797A7A7A7A7A7A7979797C5C5C5A7A7A7
97C5C597C5C5B6B6B6C5C5C5C597979797975F979797C5C5979797A7A7A7979797979797
005F5F005F9700975F0097975F5F975F979700975F5F97975F97975F979700975F5F9797
5F97975F97975F97975F97975F97975F97977373730097975F5F975F97975F5F975F9797
5F97975F97C55F97975F97975F97975F97975F97975F97970097975F97975F9797A7A7A7
5F979700975F5F97975F97975F97975F97977373735F97970097975F97975F9797009797
5F97975F97975F97975F97975F97975F97970097975F97975F97975F97C55F97975FC5C5
979797A7A7A75F97975F97975F97975F97C55F97979797975F5F975F5F975F9797494949
2C2C2C2C2C2C2C00000000002C2C2C2C2C2C002C002C2C2C00002C2C2C2C2C0000002C00
0000002C000000000000000000002C2C2C2C00002C00002C2C2C2C002C0000002C00002C
00002C00002C00002C2C2C2C002C00002C002C2C2C2C2C2C2C2C2C00002C002C00000000
2C00002C00002C2C2C002C000000002C0000002C000000004900002C2C2C2C2C2C002C00
00002C2C2C2C002C002C0000002C0000002C00002C00002C00000000002C00002C00002C
2C2C2C00002C2C00002C2C2C2C2C2C2C2C2C5F5F5F002C00002C002C0000000000000000
000000002C0000002C002C00000000000000002C00000000002C000000000000002C0000
2C0000000000002C0000002C2C000000002C0000002C00002C2C2C00002C00002C2C2C2C
002C002C0000002C00000000
C5C5C5C5C5C597C5C5A7A7A7B6B6B6C5C5C5B6B6B65FC5C5B6B6B65F9797A7A7A75F9797
5F97975F5F97005F975F97975F975F0073005F975F5F5F5F5F5F5F2C2C2C00975F009797
5F97975F97975F97970097975F97975F5F5F005F5F00975F005F5F005F5F737373009797
5F97975F97C55F97C597C5C55FC5C5EFC5C597C5C5A7A7A75F97975F5F97C5C5C59797C5
97C5C5A7A7A75F97975F979797C5C55F5F5F737373005F5F005F5F00975F5F5F975F9797
005F5F005F5F8585855F97975F9797005F97009797005F5F5F5F5F5F5F5F979797A7A7A7
A7A7A7A7A7A797C5C597C5C55F97975F97975F97975F97975F97979797975F97975F9797
5F979797C5C5C5C5C55F97975F97975F97975F97970097970097975F9797009797009797
B6B6B6A7A7A79797975F97975F97975F97C5B6B6B6A7A7A7A7A7A7979797B6B6B697C5C5
B6B6B6A7A7A7A7A7A7A7A7A75FC5C5A7A7A75F9797A7A7A797C5C55FC5C5009797005F5F
00975F00975F00975F0097975F975F5F975F5F975F00975F5F5F970097970097975F9797
5F975F005F9700975F0097975F97975F975F5F975F5F97970097975F97975F9797009797
5F97975F5F975F97975F97975F97975F97975F97970097975F97975F97979797975F9797
5F97970097975F97975F97975F97975F97975F97977373735F97975F9797A7A7A75F9797
5F97975F97975F9797A7A7A75F975F5F97975F975F5F97975F97C55F97975F97975F9797
9797975FC59797C5C55FC5975FC5C55F97975F97975F97C55F97975F97975F975F005F5F
2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C2C2C
2C2C2C00002C000000002C00002C002C2C2C2C2C2C2C2C2C002C00002C002C00002C2C2C
2C00002C2C2C00002C00002C000000000000000000002C0000002C002C00002C00002C00
2C2C2C002C002C2C2C2C2C2C000000002C002C000000002C2C2C2C002C002C2C2C2C0000
002C00002C002C0000490000002C002C2C2C002C00002C000000002C000000002C000000
0000002C000000002C002C005F5F5FC5C5C5FFC5C52C2C2C0049002C2C2C2C2C2C2C0000
00002C2C00000000002C2C2C2C2C2C00000000002C0000000000002C2C2C00000000002C
00002C2C0000002C002C2C2C494949002C002C000000002C2C0000002C000000002C2C2C
002C002C2C2C002C00000000
B6B6B697C5C59797C597C5C5E1E1E1E1E1E1D4D4D4C5C5C597EFC597C5C5A7A7A75F97C5
5F97975F97975F97975F97C59797975F975F00975F2C2C2C2C2C2C2C2C2C5F9797005F97
005F5F5F5F975F5F97737373009797005F5F00979700979700975F005F5F5F9797005F5F
009797B6B6B697C5C5C5C5C55FC5C597C5C55F97975FC5C55F97975F97975F979797C5C5
B6B6B68585855F979797C5C597C59797C5C55F9797005F5F5F5F5F5F5F5F00975F5F5F5F
0097979797975F979797C5975F97975F975F00975F5F5F5F4949495F5F009797975F975F
97975F97C597979797979797979797A7A7A75F97975F97C597979797C5C55F97C5A7A7A7
97C5C5C5C5EFD4D4D4B6B6B65F97975F97C59797975F97975F97979797975F9797858585
5FC5C5A7A7A7A7A7A7A7A7A79797975F97C55F97975F97975F979797979797C5C5A7A7A7
5FC5975F97975F9797A7A7A75F97975F97975F97975F97975F97C55F97975F5F5F005F5F
00975F0097975F97975F97975F5F5F0097970097975F5F5F0097970097975F975F5F9797
00975F0097970097970097975F97975F5F9700979700975F7373738585855F5F97009797
0097975F97975F97975F97970097975F97975F97970097975F975F5F97975F97975F9797
5F97975F97975F97975F97975F97975F97975F97975F97975F97975F97975F97975F9797
9797975F97975F97975F97970097975F97975F97979797979797979797979797975FC5C5
5F97C5A7A7A75FC597A7A7A75F97975F5F975F97975F97975F97975F5F975F5F5F494949
2C2C2C2C2C2C002C002C2C2C002C00002C002C2C2C00002C002C002C2C2C00002C002C00
490000002C0000002C2C00000000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00000000
00000000002C2C00002C2C2C002C00002C00002C0000002C2C2C2C2C2C2C2C0000002C00
000000002C00002C00002C000000002C2C2C2C2C2C2C2C2C00002C2C2C2C000000000000
002C00000000002C0097975F2C2C2C002C002C2C2C000000002C0000002C2C2C2C002C00
000000002C0000002C000000002C00A7A7A7005F5F49494900002C000000002C00000000
2C000000002C0000002C2C2C2C2C2C0000000000002C2C2C002C000000000000002C0000
00002C2C0000002C0000002C00002C0000002C2C2C2C000000002C2C2C2C2C0000002C00
2C2C2C2C0000002C002C0000
97C5C5B6B6B65F97C597C5C597C5C5E1E1E1EFC5C5E1E1E1C5C5C5C5C5C5B6B6B6979797
5F97975F97C55F97975F9797A7A7A74949495F5F5F4949495F5F5F2C2C2C5F979700975F
005F5F005F975F9797B6B6B6A7A7A75F9797B6B6B65F975F0097978585855F975FC5C597
A7A7A7B6B6B6C5C5C5A7A7A79797C5B6B6B697C5C5B6B6B65F97975F97975F97975F9797
9797C597C5C55F975F858585737373005F5F00975F005F5F5F5F5F00975F005F5F494949
494949005F5F00975F005F97005F5F00975F005F00494949005F00494949494949737373
5F97977373735F975F5F97975F97970097975F9797A7A7A75F97C597C59797C597979797
A7A7A7B6B6B6B6B6B6B6B6B6979797A7A7A7A7A7A75FC597A7A7A797C5C55F97975F97C5
5F97975F97C55FC5C55FC5975F97975F97975F97C55F97975F97975F9797A7A7A75F9797
5FC5C55F97975F97975F97975F97975F5F97009797A7A7A75F5F5F7373737373735F5F5F
00975F005F9700979700979700975F00975F5F975F5F975F00979700979700975F009797
00975F0097970097975F97970097975F97975F9797005F975F975F5F975F5F9797005F97
00979700975F5F97975F97975F97970097975F97970097975F97975F97975F97975F9797
5F97975F97975F97975F97975F97975F97970097975F97975F97979797975F97C597C597
9797975F9797A7A7A79797978585855F97975F97975F9797A7A7A7A7A7A7A7A7A7A7A7A7
A7A7A79797975F97C59797975F97979797975F97975F97975F97C55F9797009797494949
4900002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C00002C00002C00002C0000
2C2C2C0000002C2C2C00002C002C004900002C2C2C002C002C2C2C000000002C002C0000
002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C000049000000002C2C2C2C
0000000000002C00002C2C2C00002C002C002C2C2C2C2C2C0000002C000000002C2C2C2C
002C000000000000005F5F002C2C2C2C000000002C2C2C2C002C00490000002C00002C00
002C002C2C2C00002C00002C2C2C2C000000002C002C2C2C2C2C2C000000002C00000000
00002C00002C2C000000002C00002C0000000000002C000000000000002C00002C002C00
00000000000000000000002C002C0000002C2C2C2C002C00002C002C2C2C002C00000000
2C2C2C002C00002C002C2C2C
5F97C597C5C5C5C5C5C5C5C5C5EFEFEFC5EFE1E1E1E1E1E1B6B6B6B6B6B6B6B6B65F9797
5F979797C5C55F97975F9797B6B6B6B6B6B697C5C5979797C597975F9797A7A7A7A7A7A7
5F979700975F5F9797B6B6B6B6B6B6A7A7A797C5975F97975F9797C5C5C5979797A7A7A7
9797C5B6B6B6B6B6B6B6B6B6A7A7A7B6B6B6D4D4D4B6B6B6A7A7A75F9797C5C5C5A7A7A7
5F97978585855F975F00975F5F975F005F5F5F5F5F005F5F5F5F5F5F5F5F005F5F5F5F5F
005F5F00975F00975F00975F005F5F2C2C2C494949005F5F7373739797975F975F5F5F5F
005F5F5F5F5F5F5F5F5F97970097975F97975F97975F97979797975F97975F97975F9797
A7A7A7B6B6B6B6B6B6B6B6B6A7A7A7A7A7A75F9797B6B6B65FC597B6B6B6A7A7A797C5C5
9797975F97975F97C55F97978585855F97C55F97979797975F97975F979797C5C597C5C5
A7A7A75F97975F97975F975F5F975F5F5F975F9797009797009797005F5F005F9700975F
00975F005F5F005F5F005F5F00975F00975F00975F5F975F00975F00975F00975F00975F
00975F5F979700979700975F5F975F7373737373735F9797005F9700975F5F975F009797
005F975F5F97005F5F5F97975F9797979797A7A7A75F97975FC5975F97975F97975F9797
5F97975F97970097970097975F97975F97975F97975F9797979797979797A7A7A7A7A7A7
A7A7A79797975F97C55F9797A7A7A75F9797A7A7A75F97975F97C55F97979797975FC597
5F97979797975FC5C55F97979797975F97975F97975F97975F5F9700975F5F5F972C2C2C
2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C002C000000002C2C2C2C2C2C2C2C2C
00002C00002C00002C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C00002C002C002C2C2C
0000000000000000002C2C2C2C2C2C2C2C2C002C000000002C2C2C002C002C2C2C2C2C2C
2C2C2C2C2C2C002C002C2C2C00002C002C00002C002C2C2C002C0049000000002C00002C
4900002C0000002C000000002C2C2C2C2C2C00002C00002C002C000000000000002C0000
002C002C2C2C0000000000002C2C2C2C0000002C002C0000000000000000000000000000
00000000000000002C00002C0000000000002C2C2C2C0000002C002C00000000002C0000
0000004949494949492C2C2C00002C2C2C2C2C2C2C002C00002C002C2C2C2C2C2C490000
002C00002C002C0000000000
5F97975F97C597C5C597C5C5A7A7A7C5C5C5D4D4D4D4D4D4D4D4D4C5C5C5B6B6B6D4D4D4
B6B6B6E1E1E197C5C55F975F5F9797979797A7A7A7B6B6B6B6B6B6B6B6B6C5C5C5979797
858585A7A7A75F979797C5C597C5C5A7A7A75F97975F97975F9797C5C5EFA7A7A7A7A7A7
A7A7A79797C5D4D4D4B6B6B6C5C5C5D4D4D4C5EFEFB6B6B6A7A7A75F9797B6B6B6B6B6B6
B6B6B65F97979797977373735F5F5F4949495F5F5F5F975F5F5F5F005F5F494949005F5F
5F975F005F0000975F4949495F5F002C2C2C5F5F5F005F5F5F5F00494949B6B6B697C597
5F5F5F7373735F97975F97975F97975F97975F97975F979797C5975F97975FC597B6B6B6
B6B6B6C5C5C59797C597C5C5A7A7A75F97C5979797009797A7A7A7A7A7A797C5C597C597
5FC5C59797975F97970097975F97975F97975F97975F97975F97975F97975F97C5979797
5FC597005F5F5F975F5F975F00975F00975F5F5F5F00975F00979700975F00975F005F5F
005F9700975F00975F00975F00975F00975F5F5F5F5F975F5F975F5F5F5F005F5F009797
00975F5F975F00975F0097975F975F7373735F5F975F97975F9797009797009797005F5F
00975F00975F5F97975F97975F97975F97975F97975F97978585855F97975F97975F9797
8585855F97975F97975F97975F97975F97975F97975F979797C5975F97975FC5C597C597
979797A7A7A7979797979797A7A7A7979797979797979797A7A7A7A7A7A7A7A7A7979797
979797A7A7A79797979797975F97975F97975F97975F97977373735F5F975F5F5F494949
2C2C2C2C2C2C2C00002C2C2C4900002C2C2C2C2C2C2C2C2C2C2C2C2C0000002C002C2C2C
00002C2C2C2C002C000000000000004900002C2C2C00002C2C2C2C2C2C2C2C2C2C002C00
4900002C00002C00000000002C2C2C002C000000002C000000002C00002C00002C2C2C2C
2C2C2C00002C49000000002C002C00002C00002C000000002C000000002C49000000002C
00002C002C002C00002C2C2C00002C00002C000000000000002C00002C002C000000002C
2C0000002C0000002C002C00002C0000002C002C000000000000000000000000002C0000
00002C00000000002C2C000000002C00000000002C0000002C00000000002C000000002C
0000000000000000002C2C2C002C00002C0000002C2C0000002C00002C002C0000002C00
00002C000000002C00000000
5F97975F97970097975F97975F9797E1E1E1D4D4D4EFEFC5C5EFEFC5C5C5E1E1E1C5C5C5
D4D4D4C5C5C5EFC5C5B6B6B68585855F975F858585A7A7A7B6B6B6B6B6B6A7A7A797C5C5
A7A7A797C5C5FFEFC5FFEFC5D4D4D4C5C5C5B6B6B6A7A7A79797C5B6B6B65F979797C5C5
B6B6B6B6B6B6B6B6B6E1E1E1C5EFEFC5C5EFB6B6B6B6B6B6A7A7A75F979797C5C5C5C5C5
97C5C5E1E1E1C5C5C5A7A7A75F9797005F5F5F97975F5F5F737373858585005F5F737373
494949005F00494949005F5F005F5F5F5F5F5F5F5F5F975F007300494949005F5F005F5F
7373735F97975F9797737373A7A7A7A7A7A75F97975F97975F97975F97C55F97975FC5C5
A7A7A797C5C5C5C5C5C5C5C5A7A7A7A7A7A75FC59797C5C597C5C5A7A7A7A7A7A7A7A7A7
A7A7A75F97975F97975F97975F97975F97975F9797858585A7A7A75F97C5A7A7A7A7A7A7
9797977373730097975F97970097975F975F5F975F5F5F5F00975F00975F009797005F5F
00975F737373005F5F005F5F5F5F975F5F5F5F5F979797975F97979797975F97975F9797
00975F5F5F5F5F975F0097975F97975F5F975F975F5F975F5F975F00975F5F979700975F
00975F0097975F97975F97970097970097975F97975F97975FC5975F97975F97975F9797
5F975F0097975F97975F97975F9797A7A7A75F97975F97979797975FC597979797979797
A7A7A7A7A7A7B6B6B697C5C597C5C55FC5C5979797A7A7A7A7A7A7A7A7A7979797979797
97C5C55F97979797975F97979797975F97975F97975F97975F5F975F97975F5F5F2C2C2C
490000490000002C002C2C2C2C2C2C2C2C2C002C00490000002C00490000002C00490000
2C2C2C002C00002C002C0000002C00002C004900002C2C2C00002C2C2C2C0000002C0000
00002C2C00002C2C2C2C000000002C494949002C0000002C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C00002C2C2C2C00002C2C2C2C2C2C2C2C2C2C0000002C000000002C00002C000000
00002C0000002C00002C0000002C002C2C2C2C000000002C2C2C2C2C2C2C2C000000002C
2C00000000002C00000000002C00002C2C2C002C00000000000000002C002C2C2C00002C
2C00002C000000002C00002C2C0000002C000000000000000000002C2C2C0000002C0000
0000002C2C2C002C002C2C2C002C002C2C2C00000000002C002C00002C00002C002C2C2C
2C2C2C00000000002C002C00
A7A7A70097975F9797009797D4D4D4D4D4D4B6B6B65F97C5A7A7A7A7A7A7C5C5C5C5C5C5
C5C5C597C5C5A7A7A7C5C5C597975F005F5F975F5F00975F4949495F9797494949858585
C5C59797C5C5D4D4D4D4D4D4C5C5C5D4D4D4D4D4D4D4D4D4C5C5C5C5C5C5B6B6B6C5C5C5
C5C5C597C5C5C5C5C5D4D4D4B6B6B6B6B6B6C5C5EFC5EFEFD4D4D4C5EFEFB6B6B6D4D4D4
D4D4D4C5C5C5B6B6B6A7A7A75F975F5F975F8585855F97975F5F5F5F5F5F5FC5C5B6B6B6
494949005F5F009797005F5F5F97974949495F5F5F005F5F4949494949498585855F975F
5F9797858585A7A7A7A7A7A7B6B6B6C5C5C5A7A7A75F97C55FC597D4D4D4B6B6B6C5C5C5
B6B6B6FFEFC5C5C5C5C5C5C5C5C5C5B6B6B6979797A7A7A7A7A7A79797C5A7A7A7A7A7A7
5F97975F979797C5975F97975F97975F97978585855F97975F97975FC5C5A7A7A7858585
5F979700975F8585855F975F005F5F73737300975F7373735F975F5F5F5F5F5F5F005F5F
5F5F5F005F5F5F97975F5F975F979797979797C5979797979797978585855F97975F9797
5F5F975F97975F97970097975F97975F97975F975F5F975F5F97975F5F5F5F97975F975F
0097975F975F5F975F0097975F97978585855F97975F97975F97979797975F97975F9797
5F975F5F97975F97975F97975F97979797975F9797A7A7A7A7A7A75F9797A7A7A797C5C5
A7A7A797C597A7A7A7A7A7A797C5C55FC5C5A7A7A7979797A7A7A75FC5C55F97975F97C5
A7A7A79797975F97975F97975F97975F97979797975F97978585855F9797005F5F2C2C2C
002C002C2C2C002C00002C002C2C2C2C2C2C002C00002C00002C002C2C2C2C2C2C2C0000
2C2C2C00002C002C002C2C2C2C2C2C002C002C2C2C2C2C2C002C000000000000002C0000
002C0000002C00002C002C002C2C2C002C00002C002C2C2C2C2C2C2C2C2C002C00002C00
002C0000002C00002C00002C2C2C2C002C002C2C2C0000000000002C00002C2C2C2C0000
49000000000000002C000000002C0000002C00002C00000000002C0000002C0000000000
00002C2C0000002C002C0000002C002C2C2C2C2C2C002C0000002C0000000000002C0000
2C0000002C00002C002C2C2C00002C00002C2C000000002C002C000000002C0000002C00
000000002C002C2C2C00002C000000000000002C0000000000002C2C2C2C2C2C2C002C00
002C002C0000000000000000
0097975F9797A7A7A7C5C5C5C5C5C5979797C5C5C5A7A7A75FC5C55FC5975FC5C597C5C5
B6B6B6C5C5C5B6B6B69797C59797979797975F5F5F8585855F5F5F005F5F005F5FB6B6B6
E1E1E1B6B6B697C5C5C5C5C5C5C5C5D4D4D4C5C5C5B6B6B6C5C5C5C5C5C5C5C5C5C5EFC5
C5C5C5B6B6B6D4D4D4C5C5C5C5EFC5C5C5C5C5C5C5B6B6B697C5C597C5C5B6B6B6B6B6B6
C5C5C5C5C5C5B6B6B6D4D4D4B6B6B6A7A7A797979797979797975F00975F005F97005F5F
5F9797009797005F5F005F5F5F975F007300494949005F5F5F5F5F5F975F00975F005F5F
5F97C55FC5975F9797B6B6B6B6B6B6EFC5C5E1E1E1B6B6B697C5C5C5C5C5C5C5C5C5C5C5
EFEFC5EFC5C5D4D4D4B6B6B6C5C5C5B6B6B6B6B6B65F97C597C5C55FC5C597C5C597C5C5
5F97975F97970097975F97970097975F97975F97975F97975F97979797979797975FC5C5
A7A7A78585855F5F5F5F979700975F5F975F5F975F5F975F5F975F5F5F5F5F5F5F009797
5F5F5F5F5F5F5F975FA7A7A75FC597A7A7A7A7A7A79797979797975F97975F97975F9797
5F975F5F97975F97975F97975F97975F975F5F97975F97975F975F009797009797009797
00975F5F5F5F7373735F97975F979700975F5F97975F97975F97975F97975F97975F9797
0097975F97975F9797A7A7A75F97975FC5975F9797A7A7A75F9797A7A7A7A7A7A7B6B6B6
A7A7A7A7A7A7A7A7A797C5C5A7A7A7A7A7A7A7A7A7A7A7A7A7A7A75F97C55FC5C55F9797
9797979797979797975F97975F97979797975F5F975F97975F97975F975F494949494949
2C2C2C0049002C00002C2C2C00002C2C00002C2C2C2C00002C0000002C002C2C2C00002C
0000004900002C00002C2C2C2C2C2C2C2C2C002C002C2C2C0000000000000000002C0000
00002C2C00002C00002C2C2C0000002C0000002C0000002C0000002C00002C2C2C2C2C2C
00002C2C2C2C2C2C2C00002C490000002C0000002C0000002C000000002C00002C2C0000
002C002C2C2C0000002C00002C2C2C002C00002C002C00002C00002C00000000002C2C2C
00000000002C00002C000000002C00002C002C2C2C000000002C00002C00002C00002C00
00002C00002C002C0000002C00000000002C00002C2C2C2C2C2C2C00000000002C2C0000
0000002C2C2C5F97972C2C2C002C000000002C2C2C2C2C2C002C00002C002C2C2C002C00
2C2C2C2C0000000000000000
8585855F9797979797A7A7A7A7A7A75F97975F9797979797A7A7A70097978585855F9797
C5C5C5B6B6B6A7A7A7979797858585B6B6B65F975FA7A7A7A7A7A75F979797C5C597C597
979797A7A7A7B6B6B6C5C5C5B6B6B6C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5E1E1E1D4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4C5C5C597C5C5B6B6B697C5C55FC5C5B6B6B697C5C55FC5C5
97C5C5B6B6B65F979797C5C55F9797A7A7A75F97975F975F00975F5F9797A7A7A75F9797
005F5F005F5F5F975F0097975F975F4949495F5F00005F5F00975F005F975F5F5F5F9797
5F9797979797B6B6B6C5C5C5C5EFC5C5C5C5C5C5C5D4D4D4B6B6B6B6B6B6B6B6B6C5C5C5
C5C5C5C5C5C5D4D4D4C5C5C5C5C5C597C59797C5C5B6B6B6A7A7A7A7A7A7A7A7A75F9797
5F97978585850097975F97970097970097975F97975F97975F97975F97975FC5975F9797
A7A7A75F975F005F975F975F5F5F97005F5F00975F5F975F7373735F5F977373735F975F
00975F5F97975F9797979797A7A7A7A7A7A75FC5C55FC5979797975F97978585855F9797
5F97975F97975F5F975F97975F97975F97975F97975F97975FC5975F97975F5F5F00975F
00975F0097975F979785858500975F5F975F5F97975F97975F97C55F97975F97975F9797
5F9797A7A7A75F97975F97978585855F97975F97975F97975F9797979797979797979797
5FC59797C597A7A7A7B6B6B6B6B6B697C5C597C5C597C5C55F97C55F97975F97C5979797
5FC5C59797979797975F97975F5F975F97975F97975F97975F97975F5F5F005F5F2C2C2C
00002C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C000000
002C0000002C2C00002C00002C00002C2C2C002C000000002C2C2C737373002C002C2C2C
002C00000000002C002C000000002C002C00002C002C2C2C2C000049000000002C002C00
002C002C2C2C2C2C2C00002C00002C2C000000002C002C00002C0000000000002C002C00
002C00002C002C0000002C002C2C2C002C00000000002C00002C00000000000000000000
0000002C2C2C00002C000000002C00002C002C0000002C00000000002C00002C0000002C
00002C00002C0000002C00000000002C000000002C002C000000002C000000000000002C
002C00494949C5C597002C00002C00002C00002C002C2C2C000000002C002C2C2C00002C
2C2C2C00002C2C2C2C000000
5F979797975F9797977373735F9797005F9700975F5F97975F97975F97975F975F5F5F5F
B6B6B6979797975F5F8585855F5F5F5F5F5F5F5F5F5F5F5F5F975F5F5F5F005F5F737373
B6B6B6C5C5C5C5C5C5C5EFC5C5C5C5C5C5C5B6B6B6C5C5C5D4D4D4D4D4D4C5C5EFD4D4D4
D4D4D4D4D4D4D4D4D4D4D4D4B6B6B65F97975F9797B6B6B69797C500979797C5C55F97C5
5F9797B6B6B6C5C5C55F97975FC5C5B6B6B65F975F5F5F5F97C5975F97975F975F858585
5F5F979797977373737373735F5F005F5F005F5F5F0097970097975F975F5F97975F9797
5F9797A7A7A75F97C597C5C5C5C5C5C5C5C5E1E1E1E1E1E1C5C5C5B6B6B6C5C5C5C5C5C5
C5EFC5EFC5C5C5C5C5C5C5C5C5C597C5C5C5B6B6B65FC597A7A7A7B6B6B697C5C5009797
5F97975F97970097975F5F975F5F970097975F97975F97975F97979797975F97975F9797
5F97975F5F5F5F5F5F5F5F5F5F975F5F979700975F0097975F9797737373005F97009797
005F5F005F97009797A7A7A79797979797C55F97C5A7A7A78585855F97975F9797858585
5F97975F979797C5975F97C55F97975F97975F97970097970097975F97975F97975F9797
0097975F975F5F5F975F5F5F0097975F97975F5F975F97979797975F97C55F97975F9797
5F9797979797A7A7A7979797A7A7A75FC5975F97975F97975FC5975F979797C5975F9797
9797975F97975F979797C5C5A7A7A797979797C5C597C5C55F97C55FC5975F97C55F9797
5F97979797975F97975F97975F97975F97975F97975F97975F97977373734949492C2C2C
2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C002C0000002C490000002C00002C00
2C00000000000000002C2C2C002C0000002C002C00000000002C002C0000002C00002C00
002C00002C000000002C00002C2C2C2C2C2C002C002C2C2C2C00000000002C00002C2C2C
002C00002C00002C002C2C2C2C2C2C002C00002C002C2C2C2C2C2C2C000000002C002C00
2C000000002C002C002C00002C0000002C00000000002C002C00002C2C2C2C2C2C000000
0000002C2C2C0000002C0000002C00002C00000000002C002C2C2C002C002C2C2C002C00
002C00002C0000000000002C0000000000002C00002C0000000000002C0000000000002C
2C2C2C002C0000000000002C002C000000000000002C2C2C49000000002C2C2C2C2C0000
002C00000000490000002C00
C5C597C5C59797C5C573737300975F005F5F7373735F5F5F5F975F5F975F5F5F5F494949
8585854949495F975F4949495F9700007300004900494949494949005F0000975F5F5F5F
5F9797A7A7A7C5C5C5E1E1E1C5C5C5C5C5C5D4D4D4EFC5C5C5C5EFC5C5C5D4D4D4C5EFC5
D4D4D4D4D4D4E1E1E1E1E1E1E1E1E15FC597009797B6B6B65F97975F975F5F5F5F5F975F
5F9797C5C5C5C5C5C597C5C5A7A7A797C5C5A7A7A77373735F5F975F5F975F9797737373
005F5F00975F5F5F5F007300005F5F005F5F005F5F005F9700975F5F975F5F975F5F975F
8585855F5F97A7A7A797979797C5C5B6B6B6B6B6B697C5C597C5C5C5C5C5D4D4D4D4D4D4
C5C5C5EFEFC5EFC5C5EFEF97B6B6B6A7A7A79797975FC5C597C5C55F97C55F9797009797
5F97975F97970097975F97970097975F97975F979797C5C55FC5C55FC5C55F9797005F5F
009797005F5F5F5F5F5F5F5F009797005F5F005F5F005F5F5F975F5F97977373735F9797
5F9797979797A7A7A75F97975F979797C5975F97975FC5979797975FC5C55FC597009797
5F97975F9797A7A7A7A7A7A70097975F97975F97975F97975F97975F5F5F5F97975F9797
5F97975F97975F975F5F97975F97975F97975F97C5A7A7A75F9797A7A7A79797975F9797
A7A7A7A7A7A7979797A7A7A75F97979797975F97975F97975F97975F97975F9797858585
5FC5975F979797C5C5B6B6B697C597A7A7A797C5C597C5C597C5C55F97C55F97C55F97C5
5F97975F97975F97979797975F97979797975F97975F97975F5F97737373494949494949
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C00002C000000002C00002C0000002C0000
002C002C0000002C00002C002C0000000000002C00000000000000490000002C00490000
2C2C2C00000049000000002C2C2C2C002C00002C002C2C2C00002C002C00002C002C2C2C
000000002C00002C00002C002C2C2C2C0000002C0000002C00002C00002C2C0000002C00
490000002C00002C0000002C000000000000002C00002C00002C002C2C2C00002C000000
002C00002C002C2C2C00002C0000002C00000000002C2C2C002C00002C002C00002C2C2C
002C002C000000002C0000000000002C2C2C002C002C000000002C000000000000000000
000000002C000000002C0000002C002C2C2C002C002C2C2C002C002C2C2C00002C2C2C2C
0000002C0000002C00000000
97C5979797978585859797975F97975F5F5F005F00005F5F4949495F5F004949495F975F
5F975F5F5F004949490049005F5F005F5F5F4949490049005F5F00494949005F5F5F5F5F
73737397C5C5D4D4D4C5C5C5D4D4D4E1E1E1B6B6B65F979797C5C5D4D4D4C5C5C5C5C5C5
C5C5C5EFEFC5E1E1E1C5C5EFD4D4D4A7A7A7A7A7A797C5C5A7A7A75F97975F9797005F5F
005F5F5F9797A7A7A7A7A7A75F97975F97975F979797C5975F5F5F009797009797005F97
5F9797005F970097970097975F5F97005F5F005F5F5F5F5F005F5F7373738585855F9797
5F97975F97975F97975F97975F97975FC5C597C5C597C5C5C5C5C5C5C5C5C5C5EFC5C5C5
D4D4D4C5C5C5EFC5C5B6B6B6A7A7A75FC5C55FC5975F97979797975F97975FC5C55F97C5
5F97975F97975F97975F97975F97975F97975F97975FC5C55F97975F97C55F9797009797
00979700975F5F5F5F5F5F5F5F5F5F5F5F5F00975F005F5F5F97975F5F975F97975F9797
5F97975F97975F97975F97975F97975F5F975F97975F97975F9797A7A7A7A7A7A75F9797
5F9797979797B6B6B65F97975F97979797979797975FC5C55F97975F97975F97975F9797
5F97975F97975F97975F97975F97975FC597A7A7A7A7A7A7979797A7A7A75F97975F9797
A7A7A7979797A7A7A75F97975FC5975F97975F97975F97975F97975F97975F97975F9797
5F97975F97975F979797C5C55F97975F97975F97C597C5C55FC5C55F97C59797C55F9797
5F97C55F97975F97975F97975F97C55F97C55F97975F97978585855F975F4949492C2C2C
4900002C2C2C2C2C2C2C2C2C2C2C2C2C00002C00002C00002C2C2C00002C49000000002C
002C0000000000002C2C000000002C2C00002C2C2C2C00002C2C2C002C002C2C2C002C00
002C00002C002C2C2C00002C002C002C2C2C2C2C2C002C00002C0049494900490000002C
0000004900002C2C2C00002C2C2C2C2C2C2C002C00002C00002C002C2C2C00002C490000
2C0000002C00002C0000002C000000000000002C002C2C2C0000002C0000002C00002C00
2C2C2C2C2C2C000000000000000000002C000000002C2C2C2C2C2C002C00002C00002C00
002C002C00002C0000002C00002C002C0000002C00002C0000000000000000002C000000
000000000000000000002C002C00002C2C2C2C2C2C2C2C2C002C00002C002C2C2C2C2C2C
0000002C2C2C2C2C2C00002C
A7A7A7B6B6B6005F5F979797B6B6B65F975F005F5F5F5F005F5F005F9700005F00007300
494949494949005F5F2C2C2C494949494949005F002C2C2C4949492C2C2C4949495F5F00
009797979797A7A7A7EFC5C5D4D4D4C5C5C5C5C5C597C5C55F9797D4D4D4D4D4D4C5C5C5
C5C5C5C5C5C5C5C5C5C5C5C5E1E1E1D4D4D497C5C55F9797A7A7A75F975F494949005F5F
009797009797A7A7A797C5C5B6B6B6A7A7A7A7A7A7B6B6B65F97975F5F5F5F5F00005F5F
49494900975F005F5F009797005F97005F975F5F5F005F5F005F97005F97005F5F5F5F97
5F5F970097975F97975F97970097975F97C597C5C55F97C55FC5C597C5C5C5C5C5EFEFC5
EFEFC5EFEFC5C5EFC597C5C5A7A7A7979797A7A7A79797C5A7A7A7A7A7A7A7A7A75F9797
5F97975F97C5A7A7A75F97C59797975FC5C59797975F97975FC5C55FC5C55F97975F5F5F
5F97975F979700975F5F5F5F5F5F5FA7A7A70097975F979700975F5F97977373735F9797
00979700979700979700975F0097977373735F97975F9797979797A7A7A797C5C55F9797
5FC5C597C5C55F97975F5F975F5F97009797A7A7A7A7A7A79797975F975F5F9797009797
0097970097975F97975F97975F97975F9797A7A7A7A7A7A7A7A7A79797975FC5975F97C5
9797C5A7A7A79797975F97975F97975F97975F97975F97975F97975F975F5F97975F975F
5F97975F97975F97C59797975FC597A7A7A75F97C55FC5C55F97C55FC5C55FC5C55F97C5
5F97C55F97C55F97979797975F97975F97975F97975F97975F5F975F5F5F4949492C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C002C0000002C
4900002C2C2C2C2C2C2C2C2C00002C2C2C2C0000002C0000002C002C0000002C00000000
2C2C2C2C00002C0000002C002C2C2C00002C2C2C2C002C002C2C2C002C00002C00002C00
00000000002C00002C2C000000002C00002C002C00002C002C2C2C002C002C0000002C00
002C00002C002C000000002C0000002C0000002C002C00002C0000002C002C000000002C
002C00002C002C2C2C00000000002C002C002C00002C2C2C00002C002C00002C0000002C
002C00000000002C00002C00002C002C00002C000000002C0000002C000000002C002C00
00002C000000002C002C000000002C00002C2C2C2C2C0000000000002C0000002C2C2C2C
2C2C2C2C2C2C0000002C2C2C
858585494949005F5F005F5F5F97979797977373737373735F5F004949490049002C2C2C
005F00494949494949005F005F5F5F5F5F5F5F5F5F494949494949494949494949005F5F
005F5F5F97975F9797C5C5C5C5C5C5C5C5C5C5C5C597C5C5B6B6B6B6B6B697C5C5C5C5C5
D4D4D4C5C5C5C5C5C5C5C5C5C5C5C5B6B6B6D4D4D4C5C5C5B6B6B697C5C55F979700975F
00975F5F975F0097979797975F5F97A7A7A7C5C5C5C5EFC5EFC5C58585855F5F97494949
2C2C2C4949495F975F009797005F5F0097975F975F009797005F5F5F5F97005F5F005F5F
005F5F005F5F7373735F9797005F975F97C57373735F9797A7A7A7D4D4D4C5C5C5EFC5C5
FFEFC5EFEF97C5C5C5C5C5C597C5C55FC5C55F97979797975F97975F9797009797009797
97C5C5B6B6B65FC5C5B6B6B6C5C5C5A7A7A797C5C55F97975F97975F97975F97975F9797
0097975F9797737373005F97005F970097975F975F5F5F5F5F97975F97975F97C55F97C5
5F97975F97970097970097975F97979797C55FC597A7A7A75F979797C5C597C5C55F97C5
5F97975F97C50097975F97975F97975F97975F97975F97C55F97C55F97975F97975F9797
5F97979797975F97975F97975FC597979797A7A7A7979797A7A7A7A7A7A75F97975F9797
5F97975F97C55FC5970097975F97975F97975F97975F97975F97975F97975F97975F9797
5F97975F9797A7A7A797C5C55F9797B6B6B65F97C55FC5975FC5C55F97975F97975F9797
5F97C55FC5C55F97C55F97975F97C55F97C55F5F975F97975F5F975F5F5F4949492C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C002C004900002C000000002C2C2C2C2C2C2C002C00002C00
2C2C2C00002C002C002C00002C2C2C2C2C2C2C2C2C2C2C2C002C002C0000000000000000
2C0000002C00002C00002C000000002C000000002C2C00002C0000000000002C002C2C2C
002C002C2C2C00002C2C2C2C2C2C2C2C2C2C002C0000002C002C002C2C2C2C2C2C002C00
0000002C2C2C00002C2C00002C0000002C00002C002C2C2C002C002C2C2C2C0000002C00
002C00002C002C2C2C002C002C2C2C2C2C2C002C0000002C2C0000002C002C0000000000
00002C00002C00002C002C002C000000002C002C000000002C000000000000002C000000
2C0000002C0000002C2C000000002C2C2C2C002C000000000000000000002C2C2C2C2C2C
4900002C2C2C2C2C2C000000
5F5F97005F5F005F5F005F5F5F5F5FB6B6B697C5C597C55F005F5F7373735F5F00004900
4949495F5F5F4949495F5F000085005F5F5F5F5F5F4949494949490049004949495F9797
00975F0097975F9797009797C5C5EFA7A7A7C5C5C5C5C5C5B6B6B65F97C55F97C55FC5C5
C5EFEF97C5C5B6B6B69797C597C5C5C5C5C5B6B6B697C5C5D4D4D497C5C55F97975F9797
0097975F97970097975F975F5F975F5F5F5F9797C5C5C5C5EFC5C5B6B6B69797975F975F
5F5F977373735F97975F97975F5F975F975F5F5F5F00975F00975F00979700975F00975F
005F5F00975F005F97005F5F005F97005F9700975F0097975F5F975FC5C597C5C597C5C5
B6B6B6B6B6B697C5C5B6B6B697C5C55F97975F97975F5F5F5F97975F97975F97975F9797
5F97975F97C55F97C5C5C5C5C5C5C5A7A7A75F97975F97975F5F97737373005F97009797
B6B6B65F97975F5F97009797005F5F005F977373735F9797005F975F97975F5F97009797
0097975F5F975F97975F97975F97975F97C59797975F97C59797975F97C597C5C5A7A7A7
5F9797A7A7A7A7A7A78585855F97970097975F97975F97975F97975F9797009797858585
5F97975F97979797975FC5C5979797A7A7A7A7A7A7A7A7A75F97C55F97C50097975F9797
5FC5975F97970097975F97970097975F97975F97975F97975F975F5F97979797975F9797
5F9797979797A7A7A797C5975F979797C5C55FC5C55F97C55F97C55FC5C5A7A7A75F97C5
5F97C55F97978585859797979797975F97975F97975F9797005F974949492C2C2C2C2C2C
2C2C2C2C2C2C490000002C002C2C2C2C2C2C002C000000002C2C2C002C002C2C2C2C2C2C
002C00002C00002C002C00002C2C2C2C2C2C002C00002C00002C002C0000002C002C0000
2C00002C2C2C2C2C2C2C2C2C2C000000002C00002C2C2C2C2C00002C2C2C002C0000002C
002C00002C002C2C2C00002C002C00002C002C000000002C00002C002C00002C00000000
2C0000002C00002C00002C002C2C2C002C000000002C000000002C00002C2C0000002C00
2C2C2C49494900002C2C2C2C002C0000002C00002C000000002C002C0000002C00000000
2C000000002C0000000000000000002C0000002C00002C0000002C2C0000002C002C2C2C
00002C002C00000000000000000000002C002C2C2C2C00002C2C2C2C0000000000494949
5F0000002C00000000000000
5F5F5F5F5F5F5F97974949492C2C2CA7A7A797975F5F5F5F5F5F5F5F5F5F005F00494949
494949005F00007300005F5F0085005F5F5F00975F005F5F4949495F5F0000975F005F5F
005F5F005F5F00975F5F5F97858585009797C5C5EFB6B6B6A7A7A7A7A7A75F97C5B6B6B6
5F97C597C5C55F97C55F97C597C5C55F97C597C5C5B6B6B65F97C55F9797A7A7A7C59797
A7A7A7009797005F5F005F5F5F5F5F73737373737397C5C5C5C5C5D4D4D4C5EFC5B6B6B6
5F97979797975F97C55F97975F5F5F5F5F975F5F5F00975F005F5F009797009797009797
005F97009797009797005F97005F975F975F5F5F970097975F97975F9797A7A7A75F9797
A7A7A79797C5C5C5C5B6B6B6B6B6B697C5C59797C5A7A7A7979797A7A7A75F97975F97C5
5F97C55F97975F97C5C5C5C55F97975F97975F97975F97975F975F5F97975F9797979797
5F97975F97979797979797978585855F97975F5F5F7373735F5F975F97C59797975F9797
5F97975FC5C55F97C5A7A7A7A7A7A7B6B6B65FC5975F97975F97C5B6B6B69797C5C5C5C5
5F9797979797A7A7A75FC597A7A7A75F97975F97975F97C55F97C55F97975F97975F9797
5F97C5A7A7A7B6B6B697C59797C5C5A7A7A7A7A7A79797975F97975F97975F9797009797
5F97975F97975F97970097975F97975F97975F97970097975F97975F97975F97975F9797
97C597A7A7A75F97975F97C55FC597A7A7A75FC5C55F97C55F97C55F97C5A7A7A75F97C5
A7A7A75F97C55FC5C59797978585855F97975F97975F97975F5F97005F5F005F002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C00002C00002C2C2C2C00002C002C00002C002C2C2C2C2C2C
2C2C2C002C000000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C000000002C00000000000000
2C2C2C2C2C2C00002C2C2C2C2C00000000002C2C2C2C2C2C00002C002C00000000000000
2C2C2C2C2C2C2C2C2C2C000000002C2C0000002C002C2C2C002C00002C000000002C0000
2C00000000000000002C00002C2C2C2C2C2C000000002C0000002C2C2C2C002C00002C00
00002C00002C00000000000000002C2C2C2C2C2C2C2C0000002C00002C00002C0000002C
00002C002C00002C0000002C00000000002C0000002C2C2C2C2C2C00002C002C00000000
2C0000002C0000000000000000000000000000002C00002C00002C000000002C002C2C2C
2C2C2C002C00000000000000
A7A7A75F975F9797C5A7A7A75F5F002C2C2C005F5F5F975F5F5F5F7373737373735F5F5F
5F975F5F5F5F4949495F5F005F975F494949005F5F5F5F5F005F5F005F5F005F5F005F5F
005F5F005F5F005F5F4949490097975F5F5F858585A7A7A75F975F97C5C55F9797D4D4D4
B6B6B6C5C5C55FC597B6B6B65F97C55F97C55F9797A7A7A7A7A7A75F979797979797C5C5
C5C5C5B6B6B6A7A7A75F5F5F005F5F4949495F97005F5F97A7A7A7C5C5C5B6B6B6C5C5C5
B6B6B6A7A7A7A7A7A79797975F97975F97975F9797737373009797009797009797009797
005F975F975F5F5F5F5F5F5F005F5F5F5F5F005F975F97975F97975F97C55F97975F9797
5FC5C5D4D4D4C5EFC5D4D4D497C5C597979797C5975FC5970097C55F97975F9797009797
5F979797C5C5B6B6B697C5C55F9797009797005F975F97975F97975F9797A7A7A797C5C5
5F97C55F97975F97970097975F975F5F5F975F975F5F97975F975F5F97975F97975F5F97
0097975F97C5A7A7A75F97C55F97C5B6B6B6B6B6B6C5C5C597C5C597C5C597C5C5B6B6B6
9797C597C5C55FC5C55F97C5A7A7A75FC5C55F97C55F97975F97975F97975F97975F9797
5F9797A7A7A7A7A7A7A7A7A7A7A7A7A7A7A75FC5C5A7A7A75FC5975F97970097C55F9797
0097975F97975F97975F97975F97970097977373735F97970097975F5F975F97975F9797
5F97975F97975FC5C5A7A7A7A7A7A75FC5C55F97C55F97C55F97C55F97C55FC5C55F97C5
5F97C55F97979797979797975F97979797975F97975F97975F5F975F5F5F4949492C2C2C
2C2C2C002C00002C002C2C2C2C2C2C2C2C2C0000002C2C2C002C00000000002C002C2C2C
00002C2C00002C2C2C2C2C2C2C2C2C002C0000002C002C00002C00490000002C00002C00
2C2C2C2C2C2C2C0000002C0000000049000000002C2C2C2C2C2C2C2C2C2C002C00000000
2C00000000002C2C2C00002C00002C002C002C00002C2C2C2C2C2C0000004900002C2C2C
002C0000002C000000002C00002C002C2C2C2C2C2C2C2C2C002C0000002C49000000002C
2C00002C0000002C002C2C2C2C2C2C49494900002C0000002C0000002C0000002C00002C
002C00002C00002C002C2C2C002C00002C00002C00002C00002C000000000000002C0000
0000002C2C2C2C000000002C002C002C2C2C0000002C2C2C002C00002C00490000002C00
002C00002C002C00002C0000
C5C5EF9797975F97975F9797A7A7A78585855F5F5F5F975F5F975F5F5F5F5F5F005F5F5F
5F5F5F5F5F5F4949495F5F005F5F5F5F5F5F5F5F5F5F9797005F5F00975F5F5F5F5F5F5F
494949005F5F00975F005F5F005F5F5F97975F5F97B6B6B6005F5F5F9797D4D4D45F97C5
C5C5C597C5C5979797A7A7A700975FB6B6B65F979797C5C55FC5C55F97975F97975F9797
5F97979797975FC5C5C597975F5F004949495F5F5F0097975F97975F97C597C5C5C5C5C5
97C5C5C5C5C5C5C5C59797975F97C59797979797979797975F97975F97975F9797005F97
5F97975F975F5F5F5F5F975F0097975F97975F97975F97975F97C55F979797C5C5B6B6B6
9797975F97C55F9797A7A7A7B6B6B6B6B6B6A7A7A75F97975F97975F97C55F97C55FC5C5
C5C5C55F97975FC5C55F97970097975F97970097975F9797A7A7A797C5C5C5C597A7A7A7
5F97975F97975F5F5F005F97005F5F005F97005F5F8585855F97975F97975F5F975F9797
5F9797A7A7A75F97975F97C5B6B6B6C5C5C5C5C5C597C5C5C5C5C5B6B6B6B6B6B697C5C5
B6B6B6A7A7A7A7A7A75F97975F97C5A7A7A79797975F97975F97975FC5975F97C55F9797
5F97975F9797A7A7A7A7A7A75F97C55FC5C55F97975F97975F97975F97975F9797009797
005F5F5F97975F97975F97975F97975F97975F97970097975F97970097975FC5975FC5C5
5F9797A7A7A79797975F97C55FC5C5A7A7A7A7A7A75F97979797975F97C55F97975F97C5
5F97C55FC5C55F97C55F97979797975F97975F97975F97975F9797005F5F494949494949
2C2C2C002C002C2C2C002C00002C002C0000000000002C00002C002C000000002C002C00
002C002C2C2C002C002C00002C2C2C0000000000002C2C2C002C00002C00002C00000000
00000000000000002C490000002C00002C002C2C2C2C2C2C00002C2C00000000002C0000
002C002C0000002C0000002C2C2C2C2C2C2C2C000000002C002C002C000000002C2C0000
002C00002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C00002C2C2C2C002C00
2C000000002C00002C00002C2C000000000000002C2C2C2C2C0000002C00002C002C0000
2C2C2C002C00000000002C00002C00002C000000000000002C2C2C002C000000002C0000
002C000000002C0000000000002C00000000000000002C00002C00002C00002C002C0000
2C000000000000002C2C0000
EFC5C5C5C5EF5F97975F97975F975FC5975F0073004949495F975F4949495F975F494949
4949494949494949494949495F5F5F494949005F5F005F5F005F5F005F5F49494900975F
4949495F5F5F005F5F005F5F5F9797005F5F5F5F975F975F5F5F97005F97005F97009797
5FC5975F97975F979773737300975F5F97C55F97975F97975F97975F97C55F9797009797
0097975F97975F97977373735F975F4949495F975F5F975F5F97C55F97C55F979797C5C5
9797975F979797C5C55FC5C597C5C5B6B6B6A7A7A7B6B6B65FC5C5C5C5C5A7A7A75F975F
5F97979797975F97975F975F005F97005F975F97975F9797A7A7A75F97975F97975F9797
97C5C55F97C55FC5C55FC5C5B6B6B65FC5C55F97975F97975F97975F97975F97975F9797
5F97975F97975F9797A7A7A7005F975F9797A7A7A7A7A7A79797C55F97975F97975F9797
A7A7A75F97975F97975F97975F97970097975F97975F979700979700975F0097975F5F97
5F97975F9797A7A7A797C5C597C5C5B6B6B6C5C5C597C5C5C5C5C5C5C5C5C5C5C597C5C5
B6B6B6A7A7A75F9797979797A7A7A79797975F97C55F9797A7A7A75F97975F97975F9797
5F97975F97975F975F9797979797979797975FC5C55F97975F97975F97975F97975F9797
0097975F97975F5F975F97975F97975F97975F5F975F97975F97975F97975F97975F97C5
A7A7A79797975F97C55F9797A7A7A7A7A7A75FC5975F97979797979797975FC5975F97C5
9797C59797975F97C59797979797975F97975F97975F97975F5F5F4949494949492C2C2C
002C002C2C2C4900002C2C2C2C2C2C002C002C00002C00002C00004900002C2C2C002C00
2C00002C000000002C2C000000002C00000049000000002C2C2C2C2C2C2C000000000000
00002C00000000002C0049000000002C2C2C2C2C2C002C002C00002C0000002C002C2C2C
2C0000000000002C002C2C2C002C00002C000000002C2C2C000000000000000000000000
4900002C2C2C00002C2C2C2C2C2C2C2C2C2C00002C002C0000002C00002C2C2C2C002C00
2C000000002C2C2C2C2C000000002C2C2C2C2C2C2C002C00002C00002C00002C00002C00
2C2C2C2C2C2C002C000000000000000000002C000000002C2C00000000002C0000002C00
00002C000000002C002C2C2C0000000000002C2C2C2C2C2C002C00002C002C2C2C2C2C2C
0000002C0000000000000000
D4D4D4C5C5C55F5F5F5F5F00005F002C2C2C2C2C2C2C2C2C494949494949494949494949
2C2C2C005F00494949002C002C2C2C5F5F5F5F5F5F005F5F005F5F005F5F005F5F005F5F
5F5F5F73737300975F5F5F5F5F5F5F5F9797009797005F975F975F5F5F5F005F975F9797
5F97975F979700975F009797005F97005F9700975F009797005F975F979797C5C5005F97
005F5F5F5F5F5F5F5F005F5F005F005F97975F97975F97975F97975F97975F97975F9797
A7A7A79797975F97975F979797C5C597C59797C5C597C5C5A7A7A75F9797005F975F9797
858585A7A7A79797975F97975F97975FC5975F97975F9797A7A7A797C5C55F9797009797
979797B6B6B6B6B6B65F97C5A7A7A75F97C55F9797005F975F97975F97975F97975F9797
5F97975F97975F97975F97975FC5C5B6B6B697C5C59797C5A7A7A70097975F97975F9797
5F97975F97978585855F97975F97975F97975F97975F9797005F5FA7A7A797C5C5A7A7A7
A7A7A797C5C5B6B6B697C5C5B6B6B6B6B6B6C5C5C5B6B6B697C5C5B6B6B6C5C5C5B6B6B6
B6B6B65FC5C5A7A7A7A7A7A75F97C55FC5975F97C597C5C59797975F97975F97C5979797
5F97975F979797C5C597C5C55FC5975F97978585855F97975F97975F97975F9797009797
5F97975F97975F97978585855F97975F97975F97975F97975F97975F97975F9797A7A7A7
5F97975F97979797975F97975FC597A7A7A79797975FC5975F97975F97C55F97975F97C5
5F97975F97C55F9797A7A7A75F97975F97975F97C55F97975F5F5F2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C000000002C002C2C2C2C2C2C002C0000002C002C00
00002C002C0000002C002C002C2C2C00002C00002C00002C2C2C2C002C000000002C2C2C
2C2C2C2C000000002C737373490000002C002C2C2C002C00002C00002C0000000000002C
0000002C0000002C002C2C2C2C000000000000002C2C2C2C2C2C2C002C000000002C0000
00002C2C2C2C2C2C2C2C2C2C00002C00002C0000000000002C2C2C2C2C2C2C2C2C2C0000
2C000000002C00000000000000002C0000002C2C2C002C002C2C2C000000000000002C00
4949492C2C2C2C2C2C00002C002C002C000000002C000000002C002C0000002C002C2C2C
0000002C000000002C0000002C000000000000000000002C002C002C2C2C002C0000002C
00002C00002C2C0000000000
D4D4D4B6B6B64949495F5F5F2C2C2C0000492C2C2C5F5F002C2C2C0049000073002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C005F5F5F5F5F005F5F005F5F005F5F005F5F005F5F
5F5F5F4949495F5F5F5F975F5F975F005F5F5F5F5F00975F494949005F9700975F5F5F5F
5F97C55F97975F9797005F5F009797005F9700979700975F0097970097975F9797737373
5F5F5F005F5F4949495F5F5F009797A7A7A75F97970097C50097975F97975F5F5F5F975F
7373735F97975F97975F97977373735F97C55F97975F5F978585855F97970097975F9797
979797B6B6B6A7A7A7979797A7A7A7979797979797A7A7A797C5C55F97975F97C55F9797
5FC5979797975FC5C55F97975F97975F97975F97970097970097978585855F97975F9797
5F97975FC5C5A7A7A75F9797C5C5C5B6B6B6A7A7A75F97C55F97975F97975F9797A7A7A7
B6B6B65F97975F97975F97975F97979797975F9797979797858585A7A7A7A7A7A797C5C5
C5C5C5EFEFC5C5C5C5EFC5C5B6B6B6D4D4D4C5C5C5B6B6B6B6B6B6D4D4D4C5C5C5B6B6B6
C5C5C5B6B6B697C5C5A7A7A797C5C5A7A7A7A7A7A7A7A7A7A7A7A7979797A7A7A7A7A7A7
5F97975F979797C5C597C5C59797975F97975F97975F97975F97975F97C55F9797009797
5F97970097970097975F97975F97975F97975F97975F97975F975F5F97979797975F9797
9797979797975F97C5A7A7A75F97975F97C5A7A7A79797C59797975F97975FC5975F9797
5F97975F97C55F9797979797A7A7A75F97977373730097974949494949492C2C2C004900
002C002C2C2C2C2C2C2C2C2C00002C2C2C2C2C0000002C002C2C2C00002C2C2C2C00002C
00002C00002C002C00002C002C00002C0000002C002C00002C2C2C0000000000002C2C2C
00002C0000002C0000002C00002C00002C0000002C2C2C2C002C000000002C00002C0000
002C0000000000000000002C000000002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00
49000000002C002C0000002C002C002C2C2C00000000000000002C00002C00002C000000
00000000002C00002C00002C2C2C2C2C2C2C00000000000000002C00002C00002C002C00
00002C2C2C2C2C2C2C2C00000000002C2C2C00002C0000002C00002C2C2C00002C2C2C2C
2C2C2C002C00000000000000002C002C00000000002C0000002C00002C0000002C2C2C2C
002C00002C0000002C2C0000
D4D4D497C5C55F975F494949005F002C2C2C2C2C2C005F002C2C2C2C2C2C2C2C2C494949
4949492C2C2C2C2C2C2C2C2C0049005F9797005F5F005F5F005F5F005F5F005F5F5F5F5F
005F5F005F5F5F5F5F4949495F5F5F005F5F009797005F975F5F5F005F5F00975F009797
0097975F9797979797009797005F5F005F5F5F5F5F5F5F5F00975F5F975F5F5F5F5F5F97
5F975F2C2C2C005F5F0097970097975F9797A7A7A7A7A7A75F97975F5F5F005F5F737373
5F97970097975F97C59797975F97975F975F5F97975F5F5F00975F005F5F005F5F005F97
005F5F0097975F97975F9797A7A7A75F97975F97975F97975F97975F97970097975F9797
0097975F97C55FC5975F97975F97975F97975F97975F97975F97975F5F970097975F9797
005F975F979797C5C5C5C5EFC5C5C597C5C59797975F97975FC5975F97975F97975F9797
5FC5C55F979797C5979797975F97975F97979797979797975FC5975F979797C5C5B6B6B6
B6B6B6B6B6B6C5C5C5C5C5C5C5C5C597C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5C597C5C5
B6B6B697C5C5A7A7A797C5C5A7A7A7A7A7A79797975F97C59797975F979797C5C5B6B6B6
97C5C5B6B6B65F97975F97C55F97C55F97975F97975F97975F97975F97975F97975F9797
5F97975F97975F97975F97975F97975F975F5F97975FC5975F975F9797975F9797979797
979797A7A7A75F97975F97C59797C5979797A7A7A75FC5C5A7A7A7979797979797A7A7A7
A7A7A79797975F97C55F97975F97975F97975F97C5005F5F4949492C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C002C00002C002C2C2C00002C2C2C2C2C2C2C4900002C0000002C00
2C2C2C00002C002C00002C00002C002C2C2C2C0000002C0000002C000000002C002C2C2C
00002C2C00000000000000002C0000002C002C2C2C002C002C00000000002C2C2C2C2C2C
0000000000002C00000000000000000000002C2C2C00002C2C2C2C2C2C2C2C2C2C000000
000000002C00000000000000002C002C2C2C2C2C2C49000000002C00002C2C2C2C000000
002C002C000000002C000000002C000000000000002C000000002C000000002C002C2C2C
002C002C2C2C00002C2C000000002C000000002C0000002C2C2C2C0000002C000000002C
2C2C2C2C2C2C000000002C00002C002C2C2C00002C002C000000002C0000000000000000
2C000000000000002C000000
C5C5C5A7A7A75F5F5F4949492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C5F5F5F4949492C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C005F0000975F00975F005F5F5F5F5F4949495F5F5F5F5F5F
005F5F005F5F005F5F5F5F5F5F5F5F005F5F005F5F005F5F005F5F009797009797009797
5F97975F97975FC5C55F979700975F737373005F5F5F975F5F975F004900004900004900
2C2C2CA7A7A75F975F5F975F5F5F5F5F97975F97C597C5C55F5F975F97975F975F009797
009797005F5F005F5F5F5F5F7373735F5F5F5F97978585855F975F4949495F5F5F005F97
005F5F7373735F97970097975F975F5F975F5F97975F97975F97975F97975F5F975F9797
5F97975F97975F9797A7A7A75F97975F97975FC5975F97979797975FC5975F9797009797
5FC59797C5C5A7A7A7A7A7A75FC5C5979797A7A7A75F97975F97975F9797C5C5C5C5C5C5
A7A7A7B6B6B6A7A7A797C5C5A7A7A7A7A7A7A7A7A75FC597A7A7A797C5C5B6B6B6C5C5C5
C5C5C5C5C5C5B6B6B6C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5B6B6B6C5C5C5D4D4D4B6B6B6
B6B6B697C5C5B6B6B6B6B6B6A7A7A7A7A7A7A7A7A797C5C5A7A7A75F97975F9797A7A7A7
A7A7A75FC5C5A7A7A7979797979797A7A7A75F97975F9797979797A7A7A75F97975F9797
5F979797C5975F97975F975F5F97975F97975F97975F97975F97975F9797979797979797
5F97979797975F97975F97975FC5975F97C597C5C55F97975FC597979797A7A7A75F97C5
5FC5C55F97975F97975F97975F97C59797975F97975F975F5F5F5F005F002C2C2C2C2C2C
002C002C00002C2C2C002C002C2C2C2C2C2C4900002C2C2C00002C00002C002C00490000
2C2C2C002C002C2C2C0000002C0000002C00002C00002C002C2C2C2C2C2C2C0000002C00
002C0000002C00000000002C00000000002C002C00002C000000002C00000000002C2C2C
2C2C2C2C2C2C00002C00000000000000000000002C2C2C2C2C2C2C002C00002C00000000
2C2C2C2C2C2C4900002C2C2C00002C00002C2C000000002C2C2C2C2C2C2C002C00002C00
002C0000002C00002C2C2C2C2C2C2C00002C00002C002C00002C00000000002C00000000
0000000000002C0000002C002C2C2C2C00002C2C2C2C2C2C002C0000002C002C00002C00
2C2C2C2C2C2C0000002C2C2C2C2C2C00002C2C2C2C002C002C00004949492C0000000000
0000000000002C0000000000
B6B6B69797978585854949490049004949492C2C2C2C2C2C2C2C2C005F002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C4949492C2C2C494949494949005F5F5F975F5F5F5F005F5F005F5F
005F005F5F5F005F5F005F5F5F975F005F5F005F5F005F00005F5F005F5F4949495F5F5F
009797005F5F5F5F5F7373735F975F005F5F5F975F737373002C002C2C2C2C2C2C2C2C2C
490000005F5F7373735F5F5F5F975F5F5F5F5F975FA7A7A7005F5F5F975F005F5F00975F
7373735F5F5F5F5F5F5F97975F975F494949005F5F00975F7373737373735F97975F9797
5F97975F5F5F00975F00975F00975F5F975F00975F00975F5F975F5F97975F97975F9797
5F97975F97975F97970097975F97975F9797A7A7A7A7A7A78585859797975F9797979797
5F9797C5C5C5C5C5C5B6B6B697C5C5B6B6B69797975FC5975F97975F97975F9797A7A7A7
B6B6B697C5C597C5C5979797A7A7A79797C597C5C5A7A7A797C5C5979797B6B6B6A7A7A7
C5C5C5B6B6B6C5C5C5B6B6B6EFC5C5C5C5C5C5C5C5C5C5C5B6B6B6C5C5C5C5C5C5C5C5C5
A7A7A7A7A7A7A7A7A797C5C5B6B6B6A7A7A7B6B6B6B6B6B697C5C5A7A7A7A7A7A7A7A7A7
5F97C5979797A7A7A7A7A7A75F9797A7A7A79797975F97975F97975F97975F97975F9797
5F97975F97975F97970097977373735F97970097970097975F97975F97975F97975F9797
97C59797C59797975F5F97975F97C55F97975F97979797975F9797979797A7A7A79797C5
5F9797979797858585C597975F97975F97975F97975F97974949492C2C2C2C2C2C494949
2C2C2C002C002C2C2C0000494900002C2C2C00002C00002C002C002C2C2C002C00002C00
2C2C2C0000002C2C2C002C002C2C2C002C002C2C2C00002C002C00002C0000002C002C00
002C000000000000002C2C2C0000002C2C2C2C2C2C002C00002C0000002C002C002C0000
00002C00000000002C000000000000002C0000002C2C2C2C00002C002C00002C00490000
002C002C0000002C002C2C2C2C2C2C00002C002C002C2C2C00002C2C2C2C002C00002C00
002C00000000002C002C0000000000490000002C00002C00002C00002C002C2C2C002C00
002C00002C00002C0000000000002C2C2C2C002C002C2C2C002C00C597972C2C2C000000
002C002C2C2C2C2C2C2C2C2C00002C2C000000002C2C0000000000002C000000002C0000
2C2C2C00002C2C00002C0000
A7A7A78585855F5F005F5F00005F005F5F00494949FFFFFFC5975FA7A7A7D4D4D4FFFFEF
494949FFFFFFFCFCFCFFC597FFFFEFC5975F5F5F004949495F5F5F00975FFFFFFF979797
FCFCFCEFEFC5FCFCFCC5EFC5FFFFEF5F5F5FFCFCFC97C5EFFFFFEFA7A7A7FFFFFFFFFFEF
975F5FC5C5C5C5C5C5FFEFEF979797FCFCFC9797974949490049002C2C2C2C2C2CD4D4D4
EFC5C597C5C5E1E1E1EFC597A7A7A7B6B6B6FFFFFF5FC5C5FFFFFFC597977373735F9797
5F975F005F5F005F5F5F975F5F5F5F5F5F5F5F5F5F0097975F5F5F5F5F5F5F9797A7A7A7
5FC59797C5979797975F97975F97975F97975F97970097970097970097975F975F005F97
5F97975F97975F97975F97979797C597979797C5979797C5A7A7A75F97975F97C597C5C5
97C5C5C5C5C5C5C5C5C5C5C5D4D4D4C5C5C597C5C59797975F9797C5C5C5E1E1E1EFEFC5
5F5F5FFFEFEF737373FFFFC5005F5FFFFFEFFFEFEFB6B6B697C5C5B6B6B6FFFFEF5F5F5F
FFEFC5EFC5EFB6B6B6FFFFC5A7A7A7FFFFEFA7A7A797C597FFFFEFEFC5C5D4D4D4B6B6B6
5F5F5FFFEFEFFCFCFCFFFFEFFFFFEFD4D4D4C5C5C5FFFFEF975F5FFFFFEFB6B6B6FFFFEF
FFFFEFFFFFC5A7A7A7A7A7A7494949FFFFEFFFFFFF979797E1E1E1C5C59797979797C597
5F97C5005F5FFFFFEFFFEFC5737373FFFFEF5F9797EFC5C5FFFFFFA7A7A7FFFFEF005F5F
FFFFEF979797C5C5C5FFFFC5737373C5C5C597C5C5A7A7A75F9797FFFFEFA7A7A7FFFFEF
B6B6B6FCFCFCA7A7A7FFFFFF8585855F97975F97975F9797EFC5C55F5F5F2C2C2CFFFFEF
2C2C2CFCFCFC5F5F5FFFFFFFFFFFEF5F5F002C2C2C2C2C2CFFFFEFFFFFFFC5975F490000
FFFFEFFFFFEFA7A7A797975FFFFFEFFFFFEFFFFFC5E1E1E1004900FFFFEFFFFF972C2C2C
FFC5EF2C2C2C004900FFFFEF97975FFFEF972C2C2C730000FFFFC55F5F5FFFFFFFFFFFFF
2C2C2C2C2C2C5F0000FFFFC5494949FFFFC5FCFCFCFFFFEFFFFFC5C55F97FCFCFCFFFFEF
975F97FFFFFFFFEFEF005F5FFFFFEF5F5F00FFFFFF494949FFFF972C2C2CFFFFC55F5F5F
FFFFFFFFFFC5EFC5C597C55FFFC5C5005F5F2C2C2C002C00B6B6B6FFEFEFFFFFEF737373
FFFFFFFCFCFC5F975F5F5F5FFFFFFFFFFF97FFC5EF5F975FFFFFFFFFFFEFEFEF97002C00
FFFFFF2C2C2C2C2C2C004900FFFFC5494949002C002C2C2C2C2C2C2C2C2C002C002C2C2C
2C00002C0000002C00000000
97C5C5B6B6B6C5C5C5005F004949499797005F97005F9797FFEF97EFEFC55F5F00FFFFFF
494949FFFFEF005F5F007300FFFFFFFFFFEF5F5F5FFFFFFFFFFFEFFFFFEFB6B6B6858585
FFFFFF737373FFFFEF5F975FFFFFFF5F5F5FFFFFFF005F975FC5C5EFEFEFB6B6B697C597
C5C55FC5EFC5FFFFFFC5C5EFC5C5C5FFFFEF97975F005F5F005F002C2C2C5F5F5FD4D4D4
EFC597EFEFEFD4D4D4FFFFEF5F9797FFFFEFFFFFFFC5C5975F9797FFFFEF5F97975F5F97
5F97975F979700975F7373735F5F5F5F5F975F975F5F5F5F5F5F5F005F5F009797737373
7373735F5F977373735F5F5F5F975F5F97975F97978585855F97975F97975F979797C5C5
B6B6B6B6B6B6A7A7A75F9797A7A7A75F97975F979797C5C59797975FC5979797C5B6B6B6
C5C5C5D4D4D4C5C5C5D4D4D4C5C5C5D4D4D4C5C5C5B6B6B6B6B6B697C5C5FFFFEFEFC5C5
737373FFFFFFC5C597FFFFFF737373FFFFEFC5C597C5C5C5C5C5C5C5C5C5FFFFFFFFFFEF
FFFFEFFFFFEFE1E1E1FFFFFFFFFFFFFFFFFF494949FFFFFFA7A7A7FFFFEF5F9797FFFFFF
FFFFFFC5C5C5FFFFFFFFFFFFB6B6B6E1E1E1C5C5C5FFFFFF979797B6B6B6C5C5C5FFFFFF
C5C597B6B6B65F9797A7A7A7FFFFEFEFC5C5737373FFFFEFFFFFEFFFFFEFC5C5C5858585
979797737373A7A7A7FFFFFF5F5F97FFFFFF979797FFFFEF85858597C597FFFFEF979797
FFFFEFA7A7A7C5EFC5FFFFFFEFFFEFFFFFFF5FC5975F97975F97975F97C5FFFFFFFCFCFC
5F97C5FFFFFFA7A7A75FC5C55F97975F97975F97975F5F5FEFEFC55F5F00002C00FFFFFF
FFEFEFFFFFFF5F5F5FFFFFEFFFEFC55F00000049002C2C2C858585FFEFEFFFFF97D4D4D4
EFC5972C2C2CC5C59797975FFFFFFFFFEFEFFFC597FFC5EF858585A7A7A7FFFFC52C2C2C
FFEFFF2C2C2C002C00FFFFEF979797FFFFFFFFFFEF5F5F00FFFFC5FFEFEFC5C55F2C2C2C
2C00002C2C2C5F5F00FFFFFFFFFFFF5F5F5FFCFCFCFFFFEFFFEFC52C2C2CFFFFEFFFFFFF
C59797FFFFFFFFFFEF2C2C2CFCFCFCA7A7A7FFFFC5004900FFFFFFFFFFFF5F975FFFFFFF
5F5F00004900FFC5C5FFFFFFFFFFFF4949492C2C2C2C2C2C5F005FFFFFFFFFFFFFFFEFFF
C5C55F002C00FFFFC5FFEFFF97C55F2C2C2CFFC5C500975FFFFFFFFFFFFFC5C55F2C2C2C
FFFFFF2C2C2C2C2C2CFFC5C5FCFCFC2C2C2C002C002C2C2C00002C002C0000002C2C2C2C
00002C2C0000002C00000000
005F00A7A7A7B6B6B65F5F5F97975F5F5F5F005F00005F5FFFC597EFEFC52C2C2CFCFCFC
5F5F5FFFFFFF007300005F00EFC55FEFEFC59797002C2C2C2C2C2C00975F005F5FFFEFFF
FFFFEF737373FFFFFF5F975FFFFFFF5F9797FFFFFFFFFFEFFFEFEFE1E1E1C5C59797C597
C5C597FCFCFCFCFCFCC5C5C5FCFCFCFFFFEFFFFFFFC5C55F494949005F5FC5C5EFFFFFFF
FFEFC5FCFCFC858585FFEFC5B6B6B6FFEFC5FFFFFF858585EFC5C5FFFFFF979797737373
979797979797979797975F5F5F5F5F7373735F975F00975F5F5F5F005F970097975F9797
5F975F005F5F5F5F977373730097970097975F97975F9797005F975F5F5F5F97975F9797
979797979797A7A7A7A7A7A7C5C5975FC597A7A7A797C5C5B6B6B65FC59797C5C5C5C5C5
C5C5C5D4D4D4D4D4D4C5C5C5D4D4D4D4D4D4D4D4D4D4D4D4C5C5C5C59797FFFFFFEFEFC5
737373FFFFFFA7A7A7FFFFFF737373FFFFEF858585C5C5C5D4D4D4C5C5C5FFFFFFFFFFFF
FFFFFFFFFFFFEFEFC5D4D4D4C5C5C5D4D4D4B6B6B6FFFFFF97979797979797C5C5FFFFFF
FFFFFFB6B6B6858585B6B6B6FFFFEFE1E1E1C5EFC5FFFFFFFFFFEF858585B6B6B6FFFFFF
8585859797975F97C597C5C5FFEFEFFFFFEF97C597EFEFC5FFFFEFC5C5975F97975F9797
5F97975F9797FFFFEF97975F858585FFFFEFA7A7A7FFFFFF8585855F9797FFFFFFFFFFEF
737373EFEFC5FFEFC5A7A7A7EFEFC5FFFFEF5F97975F97975F9797737373FFFFFFFFFFFF
5FC597FFFFFFA7A7A79797978585855F9797737373979797FFFFFFFFC5C5979700FFFFFF
494949FFFFFF494949FFFFC58585852C2C2C00002C002C00FFFFFFC5975FC5975F737373
FFFFEFC59797B6B6B697C55FFFFFFFC59797C5975FFFEFEFFFFFFF2C2C2CFFFFC5EFEFC5
FFFFFFEFEFC52C2C2CFFFFEF979797FFFFC5A7A7A75F5F5FFFFFC5B6B6B6FFFFEFB6B6B6
00002C002C00494949FFFFC5C5C597FFFFC5FFFFEFEFC5C5C5C597C55F97EFFFC5C5C597
C55F97FFFFEFEFC5C5494949858585EFEFEF5F975F2C2C2CFFFFC5EFC5C5FFFFC5C59797
FFFFEFEFC597FFC5C5C5C55FEFC5C55F975F2C2C2C002C00C59797C5EFC5C5C5C5C59797
FFFFEFFFFFEFC5C55F975F5FFFFFFFEFEFC5FFC5C5494949FFFFFFC5EFC5C5EF5FFCFCFC
FFFFFFFFFFFF005F5FFFFFEF975F5F97975F2C00002C2C2C2C2C2C002C002C2C2C2C2C2C
2C2C2C0000002C0000000000
4949495F5F00A7A7A797C5975F975F5F5F004949490073005F5F00494949005F5F494949
4949492C2C2C2C2C2C005F002C2C2C5F5F005F5F00004900004900005F5F5F5F97005F97
0097975F975F005F5F005F5F005F5F005F5F005F5F005F5F5F975F0097975F9797009797
005F975F975F005F97005F5F005F5F5F5F00494949005F5F5F5F5F737373005F5F005F5F
0097975F5F5F5F9797005F5F5F5F975F5F975F975F005F5F5F979700979700975F5F5F5F
5F5F5F5F97975FC5975F97975F97975F97975F97975F97975F97975F979700979700975F
5F979773737385858500975F005F5F005F5F009797005F970097975F97975F97975F9797
5F97975FC5975F979797C5C597C5C5B6B6B6C5C5C5C5C5C5C5C5C5C5C5C5B6B6B697C5C5
97C5C5C5C5C5C5C5C5D4D4D4C5C5C5D4D4D4EFC5C5D4D4D4D4D4D4EFEFEFFCFCFCE1E1E1
C5C5EFFFEFEFC5C5C5EFFFEFC5C5C5C5EFEFEFEFEFD4D4D4D4D4D4EFC5C5C5EFFFC5EFEF
C5EFEFC5EFC5D4D4D4C5C5C5EFEFEFC5C5C5C5C5C5C5C5EFFCFCFCC5EFEF97C5C5C5EFEF
C5EFC5C5C5C5EFEFEFE1E1E1D4D4D4D4D4D4C5C5C5C5C5EFC5EFEF97C5C597C5C597C5EF
C5EFEFD4D4D4A7A7A797C5C5C597C5C5C5C597C5C55F9797C5C5C597C5C5B6B6B65F9797
5F97C55F979797C5C597C5C5A7A7A7B6B6B697979797C5C5C5C5C597979797C5C597C597
A7A7A7A7A7A75FC5975F9797A7A7A75F97975F97975F97975F9797A7A7A75F9797A7A7A7
A7A7A79797979797975F97978585855F979700975F5F5F977373734949492C2C2C494949
2C2C2C494949005F5F494949494949490000002C00002C00002C004949492C2C2C2C2C2C
2C2C2C4949492C2C2C00002C2C2C2C2C2C2C002C002C2C2C2C2C2C00002C2C2C2C2C2C2C
2C2C2C2C2C2C002C002C2C2C002C002C2C2C002C002C2C2C2C2C2C00002C4900002C2C2C
2C2C2C490000002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C00002C2C2C2C2C2C2C002C002C2C2C2C2C2C494949002C002C2C2C00002C
2C2C2C00002C2C2C2C2C2C2C2C2C2C2C00002C2C2C002C00002C00002C002C2C2C002C00
002C00002C00002C00002C0000002C000000002C002C2C2C00002C2C2C2C002C0000002C
00002C00000000002C002C002C2C2C002C00002C002C2C2C002C00002C0000002C00002C
0000002C000000002C2C2C2C
A7A7A75F5F5F5F5F975F5F5F494949975F00975F5F005F5F5F5F5F494949494949494949
00975F4949494949492C2C2C005F005F5F00005F002C2C2C2C2C2C2C2C2C5F5F5F5F975F
005F5F5F9797005F5F5F5F5F009797005F5F00975F4949494949494949495F5F5F494949
5F5F5F005F9700975F0097975F5F5F494949005F5F5F975F5F5F5F5F5F5F5F5F5F005F5F
005F5F005F5F005F5F005F5F5F5F975F5F975F5F97005F5F5F5F5F5F975F5F5F5F5F975F
7373735F975F5F97975F97975F979797C5C5B6B6B65F9797A7A7A75F97977373735F9797
5F9797A7A7A75F97975F97975F9797005F97005F970097975F97977373735F97975F5F97
5F9797A7A7A7A7A7A797C5C597C5C5C5C5C597C5C5C5C5C5B6B6B6E1E1E1C5C5C5C5C5C5
C5C5C5C5C5C5B6B6B6C5C5C5D4D4D4D4D4D4C5C5C5E1E1E1E1E1E1E1E1E1D4D4D4C5C5C5
C5C5C5B6B6B6D4D4D4D4D4D4EFEFC5B6B6B6D4D4D4B6B6B6D4D4D4D4D4D4C5C5C5C5C5C5
D4D4D4D4D4D497C5C5C5C5EFB6B6B6C5C5C597C5C5C5C5C597C5C5B6B6B6B6B6B6B6B6B6
A7A7A7A7A7A7B6B6B6C5C5C5C5C5C59797C5A7A7A7B6B6B697C5C597C5C55F97C5A7A7A7
97C5C597C5C597C5C5A7A7A797C5C59797C55F97975F9797B6B6B65F97C55F97975F9797
9797975F97975F97975F97975F97975F97979797975F97975F97975FC5979797975FC597
5F97C58585855F97975F97975F97975F97977373735F97975F97975F97975F97975F9797
5F97975FC5975F97975F97978585855F97975F97974949492C2C2C2C2C2C2C2C2C2C2C2C
4900002C2C2C00002C2C2C2C2C0000002C00000000002C00002C000000000000002C0000
002C002C2C2C00002C2C2C2C2C2C2C002C002C2C2C2C2C2C00002C00002C00002C2C2C2C
00002C002C00002C00002C000000002C00002C00002C00002C0000002C0000002C2C0000
002C00002C002C2C2C2C2C2C002C00002C002C2C2C2C2C2C2C2C2C002C002C2C2C002C00
002C00002C002C00002C2C2C2C2C2C002C002C2C2C4900002C00002C2C2C00002C000000
000000002C00002C00002C0000000000002C00002C2C2C2C2C2C2C002C002C0000002C00
002C00002C002C2C2C002C000000002C2C2C002C002C2C2C00005F2C2C2C2C2C2C2C2C2C
0000000000002C2C2C002C002C2C2C002C0000002C002C00002C00002C000000002C0000
002C0000000000002C002C00
5F97975F975F00975F00975F4949498585855F97970097975F9797A7A7A7005F5F494949
5F5F5F5F975F4949492C2C2C2C2C2C5F5F00005F002C2C2C005F00004900494949494949
5F5F5F5F5F5F5F5F5F5F5F5F005F5F5F5F5F5F975F005F5F5F5F5F5F5F5F004900005F00
5F5F00494949005F0000975F494949005F5F005F005F5F975F97975F979700975F005F97
00975F005F5F005F5F5F97975F9797009797005F5F00975F7373735F97975F5F975F9797
5F979700975F5F97970097975F97975F97975F97C55FC5C5A7A7A79797975F97975F9797
5F97975F97C597C5C59797C58585855F97975F97975F97975F97975F97975F97975F9797
A7A7A7C5C5C597C5C5B6B6B6B6B6B697C5C5B6B6B6B6B6B6C5EFC5FFEFEFFFEFC5EFC5C5
E1E1E1D4D4D4EFC5C5C5EFEFE1E1E1D4D4D4C5C5C5D4D4D4D4D4D4EFC5C5EFC5C5C5C5EF
C5C5C5C5EFC5C5C5C5C5C5C5D4D4D4C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5EF
D4D4D4C5C5C5C5C5C5C5C5C5B6B6B6B6B6B6C5C5C5C5C5C5B6B6B6C5C5C59797C597C5C5
97C5C59797C597C5C59797C597C5C597C5C597C5C55FC5C5A7A7A7A7A7A79797979797C5
97C5C5A7A7A797C5C59797C5A7A7A75FC5C59797C55F97979797975F97C55FC5C55F9797
5F97975F97975F97975F97975FC5975F97975F97975F97975F97975F97975F9797979797
9797975F97975F97975F97975F97975F97975F97975F97975F97975F97975F97975F9797
5F97975F5F975F97975F97975F9797005F975F5F5F4949492C2C2C2C2C2C002C00002C00
002C00002C002C2C2C002C002C2C2C002C00002C002C2C2C002C000000002C2C2C490000
00002C00002C002C002C2C2C002C0000002C002C002C000000002C00002C2C00002C0000
00002C002C00002C002C000000002C00002C0000002C2C2C00002C002C002C00002C2C2C
002C002C2C2C002C002C2C2C00002C2C2C2C00002C2C2C2C2C2C2C00002C2C2C2C2C2C2C
0049002C2C2C002C002C2C2C2C2C2C2C2C2C002C00002C00002C002C2C2C2C2C2C2C2C2C
2C2C2C002C00002C00000000002C002C2C2C00002C00002C002C00002C0000002C2C2C2C
2C2C2C2C2C2C002C00002C00490000002C002C2C2C2C2C2C00002C0000002C2C2C00002C
2C00000000000000002C2C2C002C002C000000000000002C002C0000002C2C000000002C
00002C000000000000002C00
979797979797A7A7A7A7A7A78585855F97979797975F9797C5C5C597C5C55F97975F9797
005F5F494949494949005F004949494949494949494949492C2C2C5F5F00004900005F5F
5F5F5F5F5F5F737373005F5F5F5F5F005F97005F5F005F5F5F975F5F5F5F4949495F975F
00975F5F5F5F5F5F5F5F975F5F5F5F005F97005F975F5F978585855F5F97005F5F005F5F
00975F00975F00975F5F97970097975F5F975F97975F97975F97975F975F5F5F5F5F9797
0097975F5F975F97975F97975F97975F97975F97975F97C55FC5C5A7A7A79797975F9797
5F97975F97975F97975F97975F97C55F97975F97979797975F97C55F979797C5C5A7A7A7
5F979797C5EFB6B6B6C5C5C597C5C5EFFFC5E1E1E1EFEFC5B6B6B6EFEFEFEFEFEFE1E1E1
EFC5EFE1E1E1E1E1E1D4D4D4E1E1E1E1E1E1D4D4D4C5C5C5C5C5C5E1E1E1C5C5C5C5C5C5
D4D4D4C5C5C5D4D4D4C5C5C5D4D4D4EFC5C5C5C5C5C5C5C5D4D4D4D4D4D4D4D4D4C5EFC5
D4D4D4D4D4D4C5C5C5D4D4D4C5C5C5C5C5C5B6B6B6C5C5C5C5C5EFB6B6B6B6B6B6B6B6B6
9797C597C5C5B6B6B6C5C5C5C5C5C5B6B6B697C5C59797C55FC5C597C5C5B6B6B65F97C5
97C5C597C5C5B6B6B6A7A7A79797C5A7A7A797C5C55F97C5979797A7A7A75F97C5A7A7A7
5F97975F97975F97975F97975F97975F97975F97975F97975F97975F97975F9797A7A7A7
5F97975F97975F97975F97975F97975F97C5A7A7A75F97975F97975F97975F97975F5F97
5F97975F97975F97975F97975F97975F9797005F974949492C2C2C2C2C2C002C00490000
2C2C2C2C2C2C2C2C2C4900002C2C2C002C00002C00002C00002C00490000002C0000002C
2C2C2C0000002C00002C2C2C2C2C2C2C2C2C002C00002C000000002C2C2C002C00000000
2C00000000002C000000002C2C2C2C2C00002C2C2C002C000000000000002C0000000000
002C00002C00002C002C2C2C00002C0000002C00002C0000002C002C2C2C2C2C2C002C00
002C002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C00002C00002C2C2C2C2C2C2C00002C
00002C00000000002C0000002C2C2C2C2C2C2C2C2C002C00002C00002C0000002C00002C
00002C002C002C00002C0000002C00002C00002C002C2C2C00002C2C00002C2C2C00002C
00002C2C2C2C000000002C0000002C0000002C000000002C002C0000002C2C0000000000
00002C0000002C2C2C002C00
00979797C5C5C597C55F97975F97975F97C5A7A7A7B6B6B6C5C5C5FFEFC5D4D4D4A7A7A7
B6B6B6A7A7A7005F5F005F004949494949492C2C2C005F005F5F005F5F5F005F5F005F5F
005F5F5F975F005F5F5F5F5F005F975F5F5F5F5F5F005F5F5F979700979700975F5F9797
5F97975F975F00975F005F5F5F97975F97975F5F975F97975F97975F97975F9797005F5F
005F97005F5F00975F5F9797A7A7A75F97977373730097975F5F5F5F97975F9797009797
5F97975F975F9797C5A7A7A79797975F97975F97975F97979797979797C597C5C55F97C5
5F97C5C5C5EF5F97C58585855F97975F979797C5C55F979797979797C5C597C5C5B6B6B6
97C5C597C5C5C5C5C5D4D4D4E1E1E1FFEFEFE1E1E1C5EFC5EFEFEFE1E1E1E1E1E1FFEFEF
FFEFEFE1E1E1D4D4D4D4D4D4EFC5EFEFC5C5FFEFEFEFEFC5D4D4D4E1E1E1FFEFC5EFEFC5
D4D4D4D4D4D4D4D4D4C5EFEFC5C5C5C5C5C5C5C5C5C5C5C5D4D4D4C5C5C5D4D4D4D4D4D4
D4D4D4C5C5EFB6B6B6D4D4D4C5EFC5D4D4D4B6B6B6C5C5C5B6B6B6C5C5EF97C5C5B6B6B6
97C5C5C5C5C5B6B6B6C5C5C5B6B6B697C5C597C5C597C5C55F97C5A7A7A79797C5B6B6B6
97C5C5B6B6B6B6B6B697C5C59797C59797975F97C59797975F97C55F97C55F97C55F9797
5F97975F97975F5F975F97975F97975F97975F97970097975F97979797975F97975F9797
5F97979797975F97975F97975F97975F97C55F97975F97C55F97975F97975F97975F9797
5F97975F97975F97975F97975F97975F975F005F5F4949492C2C2C002C00002C002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C002C000000000000002C0000000000002C00002C002C2C2C
2C2C2C2C0000002C002C2C2C002C002C2C2C002C00000000002C0000002C002C002C2C2C
000000000000002C0000002C002C00002C00002C002C00000000002C000000002C000000
2C0000002C00002C00002C0000000000000000002C2C2C2C2C0000002C002C2C2C00002C
0000000000002C0000002C002C000000002C00002C00002C002C002C2C2C2C2C2C2C2C2C
0000002C2C2C2C2C2C00002C000000002C002C2C2C0000000000002C2C2C2C2C2C00002C
000000002C0000002C00002C002C00000000002C00002C002C2C2C00002C00000000002C
00002C002C002C00002C2C2C0000000000000000000000002C000000002C00002C00002C
2C2C2C00002C2C00002C2C2C
5F97979797C597C5C55FC5C5979797D4D4D497C5C5C5C5C5C5C5C5C5C5C5C5C5C5B6B6B6
5F97C55F97C55F975F005F5F5F5F5F005F5F005F005F5F5F5F5F5F005F97005F97005F5F
5F5F5F5F5F5F737373005F975F5F5F5F5F975F5F5F5F979700975F5F975F5F9797005F97
005F970097975F5F970097970097975F97975F5F975F97975F97979797970097975F9797
5F97975F97975F97C5A7A7A75F97975F97975F97974949495F5F5F5F97975F975F5F9797
5FC5975F97975F97979797975FC5C597C5C55FC597979797A7A7A7A7A7A797C5C59797C5
A7A7A797C5C5B6B6B6A7A7A75F97C59797C55FC5975F97975FC5C5C5C5C5C5C5C5B6B6B6
9797C5C5C5C5C5C5C5FFEFC5EFC5C5FFEFEFFFEFC5EFC5C5FCFCFCC5C5C5C5EFEFD4D4D4
C5C5C5C5C5C5C5C5C5C5EFEFE1E1E1EFC5C5D4D4D4D4D4D4EFC5C5D4D4D4C5C5C5EFC5C5
D4D4D4D4D4D4C5C5C5D4D4D4C5C5EFC5C5C5C5C5C5C5C5C5C5C5C5D4D4D4D4D4D4C5C5C5
C5C5C5C5C5C5C5C5EFC5C5EFC5C5C5C5C5C5C5C5C5C5C5C5C5C5C597C5C597C5C5C5C5C5
A7A7A797C5C597C5C597C5C597C5C5B6B6B6B6B6B69797C597C5C597C5C5A7A7A797C5C5
5F97C5A7A7A7B6B6B69797C5A7A7A7A7A7A79797979797C55F9797A7A7A7A7A7A75F9797
A7A7A75F97975F97975F97975F97975F97975F97975F97975F97975F97975F9797A7A7A7
5FC5C55FC5C55F97975F97975F97C55F97975F97C55F97979797C55F97C55F97975F9797
5F97975F97975F97975F97975F5F975F5F5F005F5F4949492C2C2C002C002C2C2C2C2C2C
2C2C2C00002C2C2C2C002C00002C002C2C2C2C000000002C2C0000002C00000000000000
00002C2C2C2C0000002C2C2C000000002C00000000000000002C0000002C002C0000002C
490000002C00002C0000002C002C002C00002C000000002C00002C002C00000000002C00
002C00002C00002C000000000000004900002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C
0000002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
002C002C2C2C00002C00002C00000000000000002C0000000000002C2C2C2C2C2C000000
0000002C2C2C00002C2C2C2C2C00000000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C000000
2C00002C0000002C002C2C2C2C00000000002C2C2C002C002C00002C2C2C2C2C2C002C00
002C002C2C2C000000000000
5F97979797979797C5B6B6B69797C5B6B6B6C5C5C5D4D4D4B6B6B697C5C5A7A7A75F97C5
C5C5C55F97975F97970073005F5F5F005F00005F5F009797005F5F005F5F005F5F005F5F
5F5F5F5F975F737373005F5F005F975F5F970097975F5F975F5F5F5F97975F97975F9797
5F9797005F9700979700975F0097975F5F975F5F975FC5C55F97C55F97975F97975F9797
5FC5975F97C59797975F97975F5F970097975F979700975F5F5F975F97970097975F9797
005F5F5F97970097975F97975F97975FC597A7A7A79797C55F97975F97C55F97C55F97C5
97C5C597C5C5C5C5EFC5C5C5B6B6B69797979797975F97C55F9797A7A7A7B6B6B6E1E1E1
EFFFEFEFEFC5E1E1E1D4D4D4FFEFC5FFEFC5EFEFEFFFEFEFE1E1E1EFFFEFFFEFC5D4D4D4
C5C5C5C5C5EFC5C5EFC5C5C5C5C5C5D4D4D4D4D4D4D4D4D4E1E1E1C5C5C5EFC5C5E1E1E1
C5C5C5D4D4D4D4D4D4C5EFC5D4D4D4C5C5C5C5EFEFC5C5C5C5C5EFEFC5C5C5C5C5D4D4D4
D4D4D4D4D4D4B6B6B6C5C5C5C5C5C597C5C5B6B6B6C5C5C5B6B6B697C5C597C5C59797C5
5FC5C597C5C597C5C597C5C59797C5C5C5C597C5C597C5C5A7A7A797C5C5B6B6B65FC5C5
A7A7A79797C5A7A7A797C5C55F97C5A7A7A75FC59797C5C55FC5975F97C59797975FC5C5
A7A7A75F97C50097970097975F97975F97975F97975F97975F97975FC5975FC5C55F9797
5F97C55F979797C5C5A7A7A75F97975F97C55F97975F97975F97975F97975F97975F5F97
5F97975F97975F97975F97975F97975F5F5F4949492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C0000002C2C2C2C2C2C2C2C2C002C0000000000002C00002C002C000000002C0000
002C00002C00002C00002C002C00000000002C00002C0000002C00002C002C0000002C00
00000000000000002C2C0000002C000000002C2C2C5F5F5F2C2C2C0000002C0000002C00
0000002C2C2C00002C2C2C2C2C2C2C002C002C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C002C2C2C002C002C2C2C2C000000002C002C002C2C2C002C002C2C2C
00000000002C0000000000002C00000000002C2C2C002C002C000000002C00002C000000
0000002C2C2C2C0000002C00002C0000002CC597970000000000002C2C2C2C000000002C
00002C2C0000002C00002C0000002C000000002C00002C00000000002C002C2C2C002C00
002C00002C000000002C0000
5F97975F97C5B6B6B6C5C5C5D4D4D4B6B6B6C5C5C5C5C5EFC5C5EF9797C59797C55F9797
9797C5C5C5C597C5C55F5F5F5F97975F9797005F5F00975F005F5F5F5F5F005F97005F5F
005F5F005F5F005F5F00975F005F5F5F5F970097975F9797005F97005F975F97975F9797
5F97975F9797005F970097970097975F97975F9797005F975F97975F97975F9797009797
5F97975F97975F97975F97975F97975F97975F97975F5F5F9797975F97C55F9797737373
5F97975F97975F97975F97975FC597A7A7A7A7A7A7A7A7A70097970097975F97975F97C5
A7A7A75F97C597C5C5C5C5EF97C5EFC5C5EFC5C5C597C5C5D4D4D4C5C5EFC5C5EF97C5C5
C5C5C5E1E1E1D4D4D4C5C5C5B6B6B6D4D4D4D4D4D4E1E1E1E1E1E1FFEFC5D4D4D4E1E1E1
E1E1E1D4D4D4D4D4D4D4D4D4E1E1E1E1E1E1E1E1E1EFEFC5E1E1E1E1E1E1C5C5C5B6B6B6
D4D4D4C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5D4D4D4D4D4D4D4D4D4E1E1E1C5C5C5C5C5C5
D4D4D4C5C5C5C5C5C5D4D4D4C5C5C597C5C5C5EFC5C5C5C5B6B6B6B6B6B6A7A7A7B6B6B6
A7A7A7C597C5B6B6B697C5C5B6B6B697C5C597C5C5B6B6B697C5C597C5C55F97C5B6B6B6
9797975F97C5A7A7A7B6B6B6A7A7A7A7A7A75F97975F97975F97C55F9797A7A7A75F9797
5F97C55F97975F97C55F97975F97975F97975F97975F97975F97975F9797A7A7A75FC5C5
5F97C55F97C5A7A7A75F97970097C55F97975F97975F97975F97975F97C55F97975F9797
5F97978585855F97977373735F5F97005F5F005F5F002C002C2C2C4949492C2C2C00002C
002C002C00002C00002C2C2C00002C2C2C2C00000000002C2C0000002C002C0000000000
0000000000000000002C2C2C002C004900002C00000000002C2C2C2C0000002C00002C00
2C000000002C2C2C2C0000000000002C000000002C00002C00002C2C2C2C2C2C2C000000
2C000000002C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C00002C00002C002C002C2C2C
2C2C2C000049002C002C2C2C00002C00000000002C2C2C2C002C000000000000002C2C2C
2C2C2C000000002C000000000000002C2C2C002C002C00002C2C2C00002C00002C000000
2C2C2C2C2C2C002C00002C00002C000000002C000000002C2C00002C0000000000000000
2C00002C2C2C2C2C2C002C00000000002C00000000002C004900002C2C2C49000000002C
2C2C2C2C2C2C2C2C2C2C2C2C
5F97975F9797A7A7A797C5C5B6B6B697C5C597C5C597C5C55F97C597C5C5A7A7A7979797
0097975FC5C50097975F9797005F97009797009797005F5F005F5F5F5F5F00975F5F5F97
005F9700975F005F5F005F5F5F5F5F5F5F5F5F97975F5F5F5F5F975F97977373735F975F
5F97975F5F5FA7A7A70097975F97975F975F0097970097975F97970097975F979797C5C5
9797975FC5C5A7A7A79797975F97975F97975F97975F5F5F5F5F975F97975F97975F97C5
5F9797B6B6B69797975F97975F9797009797A7A7A70097975F97975F9797009797009797
A7A7A75F97C5A7A7A79797C5B6B6B6B6B6B6C597C5A7A7A75FC5C50097979797C59797C5
C5C5C5C5C5C5C5C5C597C5C5C5C5C5EFEFEFE1E1E1E1E1E1D4D4D4E1E1E1D4D4D4C5C5EF
E1E1E1C5C5EFEFEFC5E1E1E1FFC5C5E1E1E1D4D4D4C5C5C5D4D4D4EFC5C5D4D4D4E1E1E1
B6B6B6B6B6B6B6B6B6C5C5C5C5C5C5D4D4D4C5C5EFD4D4D4C5C5C5D4D4D4D4D4D4C5C5C5
9797977373735F5F5FA7A7A7B6B6B6C5C5C597C5C5A7A7A7A7A7A7A7A7A797C5C5A7A7A7
A7A7A797C5C597C5C59797C5B6B6B6B6B6B69797C55F97C5A7A7A75F97C59797C55F97C5
5F9797A7A7A7A7A7A7009797A7A7A79797975F97975F97978585855F97979797975F97C5
5F97975F97979797975F97C55FC5979797975F97979797975F9797005F5F005F5F2C2C2C
2C2C2C2C2C2C4949495F5F975F97979797975F97975F97975F97C55F97975F97975F9797
5F97975F97975F97975F97C5005F97005F5F49494900002C00002C002C00002C002C2C2C
002C0000002C0000000000002C00000000000000002C00002C0000002C00000000000000
002C002C2C2C2C2C2C002C0000002C00002C00002C0000002C2C2C002C002C00002C0000
2C00002C2C2C2C2C2C0000002C00002C000000002C00000000002C002C0049494900002C
00002C2C2C2C002C00000000002C00002C002C000000002C00002C002C00002C00002C00
2C2C2C2C2C2C2C0000002C0000002C2C00002C2C2C2C2C2C002C000000002C00002C2C2C
002C002C2C2C2C0000000000000000002C002C0000000000002C00000000002C00000000
00002C000000000000000000000000490000002C002C2C2C00002C00002C000000000000
000000002C0000002C2C000000002C2C0000002C002C0000002C0000002C00002C2C2C2C
0000002C0000002C00000000
5F97975F97C59797C55F97975F97C50097970000495F005F5F5F5F0000735F5F5F5F5F5F
5F5F5F5F5F970097975F97970097970097970097975F97975F5F97005F975F5F5F5F5F5F
005F972C2C2C5F5F5F5F5F5F5F005F5F5F5F5F005F5F5F5F5F5F5F5F5F5F737373737373
5F5F5F5F005F5F005F5F5F5F5F005F5F005F975F5F0097978585850049005F005F494949
4949494949495F005F5F005F5F5F5F5F005F5F97C55F97975F97975F9797004900494949
4949494949494949494949495F00975F97975F97975F97C573737300002C2C2C2C494949
5F5F5F5F5F5F5F005F5F005F2C2C2C5F97975F97C55F97975F005F5F005F5F005F5F5F5F
5F5F004949494949495F005F5F0097B6B6B697C5C5C5C5C5D4D4D4C5C5C55F005F5F5F5F
5F5F5F5F5F5F5F005F4949495F5F5F5F5F5F975F97D4D4D4D4D4D4EFEFC5B6B6B6494949
0000495F005F7373735F5F975F5F5F490000979797C5C5C5C5C5EFD4D4D4858585494949
5F5F97975F97975F97975F97975F97B6B6B6C5C5C52C2C2C5F005F5F00975F5F5F5F005F
5F005F975F97975F5F5F5F5F5F5F5F5F5F5F5F5F5F5F005F5F5F975F5F5F975F97979797
5F97975F97C50097975F5F975F5F5F5F005F5F005F5F005F5F5F5F97005F5F97975F5FC5
5F97975F97975F97975FC5C55F97975F979700002C0000004949495F5F97975F97975F97
975F97975F97975F97975F977373735F5F5F5F97975F97975F97975F97975F97975F9797
7373735F97975F97975F5F972C2C2C2C2C2C4949495F5F5F737373737373975F5F494949
002C002C2C2C2C2C2C4949495F5F9797009797005F5F5F975F0097975F97975F97975F5F
2C2C2C000000002C000000002C00005F005F975F5F975F97975F97737373975F975F5F5F
5F000000002C002C00975F5F73737385858573737397005F975F5F975F5F975F97975F5F
002C00002C00002C00002C00002C00975F5F975F975F5F97975F975F5F97970097494949
0000002C2C2C975F97975F5F975F5F975F97494949002C002C2C2C5F5F5F858585737373
737373975F97975F97970097975F97975F5F2C2C2C975F97975F97970097975F97975F97
975F97975F975F5F5F2C2C2C490000002C002C2C2C002C00002C002C00005F005F975F5F
970097975F97975F974949492C00004900002C2C2C00002C00002C2C2C2C2C2C2C00002C
2C2C2C002C002C00002C0000
0097975F97975F97975F97975F97979797C55F5F975F5F97975F97975F97975F975F5F97
975F97975F979797C5B6B6B65F97970097975F97C59797C5B6B6B67373735F9797005F97
005F5F005F975F5F97975F97975F97975F97975F97975F97975F97975F97975F975F9797
975F97975F97975F97975F97975F975F5F975F5F5F009797009797009797975F97975F97
858585975F97858585975F97975F97975F975F97C55F97C55F9797005F9700002C5F5F97
975F975F5F97975F97737373005F975F5F975F97972C2C2C97005F975F97737373975F97
975F975F5F97975F5F975F975F5F5F975F97858585A7A7A79797975F9797975F975F5F97
975F97858585975F5F975F9797979797C5C5B6B6B6C5C5EFC5C5C5C5C5EFA7A7A75F5F97
975F97975F975F5F97975F97975F97975FC5B6B6B6C5EFC5EFC5C5494949000073975F97
975F97975F975F005F975F97975F97975F97975F975F5F5FC5C5C5B6B6B62C2C2C737373
975F97975F97975F97975F97970097975F97B6B6B6005F5F975F975F5F97975F5F5F5F97
975F97A7A7A7A7A7A7975F97975F9797005F975F97975F5F5F5F979797979797975F9797
5F97979797975F97975F9797975F975F5F97737373975F97975F975F5F975F97C55F9797
5F97975F97975F97975FC5C597C5C52C2C2C97005F975F97970097975F979700975F5F97
5F5F977373735F5F97975F975F0097975F97975F974949499797975F97975F97975F9797
5F97975F97975F9797000000975F97975F97975F97975F97975F977373735F0097975F97
5F5F5F975F5F2C2C2C2C2C2C2C2C2C5F005F970097737373975F975F00972C2C2C2C2C2C
0000002C0000002C005F005F737373975F975F5F5F975F5F975F97975F97970097975F97
975F97975F972C2C2C2C2C2C494949737373737373975F9797009749494900002C2C0000
2C00000000000000002C0000002C005F5F9797005F737373975F975F00002C2C2C2C2C2C
5F0000975F97975F975F5F975F5F5F5F5F97975F975F5F5F002C00002C0000002C5F5F5F
975F5F5F5F97975F97975F970000000000002C2C2C975F979700975F005F2C2C2C2C2C2C
4949495F5F5F5F5F9797005F5F5F5F2C2C2C2C2C2C00002C002C005F5F97975F975F0097
975F97975F97975F975F5F97494949002C00002C002C2C2C2C2C2C2C2C2C2C2C2C002C00
002C002C2C2C002C00002C00
0097975F5F970097975F9797A7A7A7A7A7A797C5C5A7A7A75F9797975F97975F97975F97
97C5EF97C5C55F9797B6B6B65F97975F97975F9797B6B6B6C5C5EF5F97C55F9797009797
5F9797005F975F9797005F5F975F97975F97975F97975F975F5F97A7A7A79797975F9797
005F5F975F97979797975F97975F970097975F97970097975F9797A7A7A7A7A7A7979797
975F97858585975F97975F9797C5C55FC5C5A7A7A79797975F9797009797002C00975F97
975F97975F5F5F975F5F97975F97975F97972C2C2C975F97975F97975F5F975F97975F97
5F5F5F005F5F5F5F97005F975F5F97975F975F5F978585855F97975F97972C2C2C975F97
9700975F5F5F737373A7A7A75FC597A7A7A7B6B6B6C5C5C5C5C5C5C5C5C5C5C5EFC5C5C5
5F5F5F5F5F97975F97975F97B6B6B6D4D4D4C5C5C5C5C5C52C2C2C975F97975F5F975F97
975F97975F97A7A7A7B6B6B6C5C5C5B6B6B6975F97975F97975F97494949975F97975F97
5F5F97975F97975F979797C5979797975F97975F972C2C2C5F5F5F970097975F9797C5C5
B6B6B6A7A7A797C5C597979700005F975F97975F97737373979797A7A7A7A7A7A75F9797
A7A7A75F97C55F97C55F9797737373975F97975F97975F979797975F97975F9797A7A7A7
5F97C5A7A7A7A7A7A75FC5C5A7A7A74949497373735F5F97975F975F5F975F97975F97C5
5FC5C59797C55FC5978585855F5F5F970097975F97975F97975F97A7A7A79797975F9797
5F97975F9797002C005F5F97975F97975F97970097975F5F2C2C2C002C004900002C2C2C
4949495F5F9749494900002C00002C002C007373737373739700975F5F5F2C2C2C000000
2C0000000000975F975F5F5F975F97975F979700974949492C2C2C005F5F2C2C2C002C00
4949495F5F975F5F5F2C2C2C002C005F5F5F737373970097975F9700000000000000002C
002C00000000000000000000002C00737373975F975F5F975F005F2C2C2C002C002C2C2C
975F97975F979700975F5F9749494900002C2C2C2C5F5F5F2C2C2C002C002C2C2C00002C
5F5F975F5F97975F9749494900000000000000002C5F5F5F97005F002C00002C002C2C2C
2C2C2C2C2C2C4949495F5F975F5F972C2C2C002C002C2C2C2C2C2C5F5F9797005F975F97
5F5F5F4900002C00002C2C2C494949002C002C2C2C2C2C2C002C002C2C2C2C2C2C490000
2C2C2C49000000002C002C00
0097970097975F975F5F97975F97975F979797C5C597C5C55F97C5005F5F975F97975F97
A7A7A75F97975F97975F97975F9797A7A7A75F97C55F97C5C5C5C5A7A7A7B6B6B6A7A7A7
0097975F9797A7A7A75F5F97975F97975F97975F97975F97A7A7A7A7A7A79797C55F97C5
5F5F5F975F97975F97975F97975F975F9797A7A7A75F97C59797975F97975F97975F9797
975F97975F97975F978585855F97C5979797A7A7A75F9797009797005F97005F5F970097
975F5F5F5F975F97970097975F97974949495F005F975F97975F5F5F5F975F5F975F5F97
5F97975F97C55F9797009797009797C5C5C55F5F975F97C59797975F97972C2C2C975F97
975F97975F975F5F975F97975F9797A7A7A797C5C5C5C5C597C5C5C5C5C5B6B6B697C5C5
2C2C2C975F97975F97975F97B6B6B6B6B6B6E1E1E14949499700979700975F5F97975F97
975F97EFC5C5B6B6B6D4D4D4D4D4D4D4D4D4D4D4D4B6B6B65F5F9700002C975F97975F97
975F5F9797C5C5C5C5C5C5EFC5C5C5B6B6B65F5F5F975F975F5F97975F5F975F979797C5
97C5C59797C55FC5C55F97C52C0000975F975F5F5F975F975F9797A7A7A75F97975F9797
5FC5975F9797979797009797975F97975F97975F9797005F5F97C55F97C59797975F97C5
5F97975FC5C5A7A7A7A7A7A75FC5C55F5F5F5F0097975F975F97975F97975FC5C55F9797
5F97975F97975F97C55F97979797975F5F9797005F737373970097975F97979797979797
5F9797005F5F975F5F5F5F9797005F975F975F5F5F2C2C2C2C2C2C002C002C2C2C2C2C2C
002C0000002C975F5F2C2C2C2C0000002C00970097975F975F5F977300002C0000000000
000000494949975F97970097737373975F5F2C2C2C002C002C2C2C00002C00000000002C
000000002C00975F5F2C2C2C2C2C2C5F5F5F737373975F97975F972C2C2C2C000000002C
002C002C2C2C0000000000002C0000975F97975F979700974949492C2C2C0000002C2C2C
5F5F97970097970097975F5F00002C00002C2C2C2C002C002C2C2C2C2C2C00002C000000
5F5F5F975F5F97009700002C2C00002C0000002C005F5F974949492C2C2C2C2C2C00002C
2C2C2C2C00002C2C2C5F005F97005F975F972C2C2C2C00000000495F5F978585855F5F97
002C002C2C2C2C2C2C2C2C2C2C2C2C00002C00002C2C2C2C00002C002C002C2C2C002C00
4900002C2C2C0049002C0000
005F970097975F9797005F975F975F5F97975F97C597C5C55F97975F97C5858585975F97
5F5F975F97C55F97975F97975F9797005F5F5F97975F97975F979797C5C55F97C55F97C5
5F97C55F9797005F5F975F97979797975F97975F97979797C5C5C597C5C597C5C59797C5
975F97975F97975F97975F97975F975F97979797975F97975F97975F975F5F97975F975F
975F97737373975F975F97975F97975F97C59797978585850097975F97972C2C2C5F5F97
975F97975F975F97975F979700975F0000497373735F5F97975F975F5F975F9797005F97
005F5F00979700975F00975F0097975F97975F9797005F5F005F970097972C2C2C970097
975F975F5F975F97975F97C55F97975F97975F979797C5C5A7A7A75F979797C5C55FC597
2C2C2C975F97975F975F5F97C597C597C5C5B6B6B6494949975F5F737373975F97975F97
D4D4D4D4D4D4E1E1E1EFC5C5B6B6B6EFC5C5D4D4D4D4D4D4B6B6B6002C00975F97970097
975F97C5C5C5C5C5EFD4D4D4D4D4D4C5C5C5C5C5C5975F97975F97975F97975F9797C5C5
B6B6B697C5C55FC5C55F9797000000975F5F975F97975F97979797A7A7A75F9797979797
5F97975F97975F97975F9797975F975F5F5F975F97975F975FC5975F97975FC5C5A7A7A7
97C597A7A7A7A7A7A75F97C55F9797737373975F5F975F975F97979797975F97975F9797
97979797C5979797975F97975F97975F97C5005F97975F977373735F5F975F9797979797
5F979700002C970097975F97975F975F5F5F2C2C2C2C2C2C2C2C2C00002C000000002C00
2C2C2C2C2C2C00002C00002C00002C00002C5F5F5F5F5F5F975F975F005F002C002C2C2C
002C00975F5F9700975F5F9773737300002C0000002C2C2C2C2C2C2C2C2C2C000000002C
2C2C2C002C0000002C002C00002C005F005F975F5F5F5F97975F5F002C0000002C2C2C2C
2C2C2C2C2C2C002C002C2C2C00002C5F5F97975F5F975F974949494900002C2C2C2C2C2C
975F5F975F97975F974949492C0000000000000000002C0000002C00002C2C2C2C2C2C2C
975F97975F975F5F972C2C2C002C00002C002C2C2C97009700002C00002C2C2C2C2C2C2C
002C002C2C2C2C2C2C2C2C2C975F978585855F5F5F002C0000002C5F005F975F97975F97
2C2C2C00002C002C002C2C2C2C2C2C490000002C0000002C2C2C2C002C00002C002C2C2C
2C2C2C2C2C2C002C00002C00
00979700975F5F5F975F5F975F97975F97C597C5C597C5C55F97C5009797494949975F97
975F975F97975F5F975F9797005F975F97975F5F975F97977373730097975F97975F9797
5F5F975F97972C2C2C975F97975F97975F97975F975F97C5C5C5C5C5C5C5C5C5C5B6B6B6
A7A7A7975FC5975F97975F97975F97A7A7A797C5C5B6B6B69797978585855F975F005F5F
5F5F5F975F97975F975F97C55F97975F975F9797975F979700979700975F494949975F97
970097975F975F97978585852C2C2C975F97975F975F5F5F975F97737373009797005F5F
5F5F5F5F97975F5F9700975F0097975F5F5F005F5F005F5F00979700975F2C2C2C975F97
5F005F975F975F5F975F97970097975F97975F97975F97975F97975F97975F97C5979797
00002C737373970097858585B6B6B6B6B6B6494949975F97975F975F0097975F97B6B6B6
B6B6B69797C5B6B6B6B6B6B6FFEFC5E1E1E1EFEFC5B6B6B6C5C5C5858585975F97975F97
975F9797C5C5C5C5C5D4D4D4EFC5C5D4D4D4B6B6B62C2C2C5F5F5F5F5F9773737397C5C5
9797C5B6B6B6B6B6B6A7A7A700002C975F977373735F5F975F97975F97975FC5C597C5C5
9797979797975F9797A7A7A7975F97975F97975F97975F975F97975F97C5A7A7A7979797
8585859797979797975FC5C55FC597737373737373975F979797975FC5975F97C5979797
5F97979797978585855FC5975F97975F97979797C55F5F97975F97975F5F975F97979797
5F975F97005F975F97970097975F972C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000000000
002C002C00002C00002C000000002C000000975F975F5F975F5F975F005F2C00002C2C2C
00002C975F5F975F97975F9700002C00002C2C2C2C002C0000002C2C0000002C002C2C2C
00002C00002C2C0000002C002C2C2C494949975F5F975F9797005F4900002C0000002C00
00002C00002C002C00002C002C2C2C975F5F975F97975F974949492C2C2C2C2C2C002C00
5F5F9797009797009749494900002C2C2C2C002C002C2C2C2C2C2C00002C2C2C2C000000
975F979700975F5F972C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C002C002C2C2C2C2C2C
0000002C2C2C2C2C2C000000970097975F9797005F2C2C2C00002C5F5F97975F97970097
00002C2C2C2C002C002C2C2C00002C002C002C2C2C2C2C2C002C00002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C00002C
5F9797005F5F5F5F975F5F975F5F975F97975F97975FC5C55F97C55F97C5005F975F5F97
975F970097975F9797005F975F5F975F5F977373737373735F97975F97975F9797009797
5F97975F97975F5F5F975F97975F97975F97975F9797C5C5C5C5C5C5C5C5C5C5C5C5C5C5
B6B6B6975F97975F97975F978585855F97970097975F9797737373005F0000975F494949
5F5F97975F97975F975F9797005F975F97975F5F975F97975F97975F97974949495F5F97
975F97975F5F5F975F5F97970000005F5F5F975F97975F975F5F5F5F5F5F5F5F975F5F97
005F5F005F97005F975F5F97005F5F005F5F005F5F005F97005F97009797004900975F97
975F979700975F979700979797979700975F5F97975F97975F97975F97975F97975F9797
2C2C2C8585855F5F97975F97A7A7A7B6B6B60000005F005F975F97975F97975F97D4D4D4
E1E1E1D4D4D4B6B6B697C5C59797C5C5C5C5C5C5C5D4D4D4D4D4D4B6B6B65F5F97970097
5F5F97B6B6B6C5C5C5C5C5C5D4D4D4C5C5C5B6B6B6000000975F975F0097975F97C5C5C5
B6B6B697C5C5C5C5C59797C5000000737373975F97975F5F97979797C5C59797C5979797
5F97975F97C5979797979797737373975F97975F975F5F97A7A7A797C5C5A7A7A75F9797
A7A7A79797975F97975F97975F9797979797975F97975F979797975F97975F97975F9797
A7A7A75F97975FC5C59797975F97C55F979797C5C5494949737373975F975F5F5FA7A7A7
2C2C2C975F97975F97975F5F4949492C2C2C2C2C2C2C2C2C2C2C2C002C00002C002C0000
0000002C2C2C2C0000002C002C2C2C0000005F005F975F977373735F5F002C2C2C000000
975F97975F97970097975F5F2C0000002C002C2C2C2C2C2C2C2C2C000000002C002C2C2C
0000002C00000000002C0000002C002C2C2C975F975F0097975F5F002C00002C00002C00
002C00002C00002C00002C002C2C2C97005F5F5F975F5F974900002C2C2C002C002C2C2C
975F5F975F97975F5F2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C0000002C2C2C2C000000
5F5F975F0097975F972C2C2C002C002C2C2C2C2C2C0000002C2C2C002C00002C00002C00
0000002C2C2C002C00490000975F975F0097975F97002C000000495F5F97970097975F97
2C2C2C2C2C2C00002C002C002C2C2C002C002C0000002C002C00002C0000002C00490000
2C2C2C2C0000002C002C2C2C
5F97C55F97970097975F5F975F9797005F970097970097C5A7A7A70097975F5F97494949
975F975F5F97005F5F5F5F975F97975F97975F975F5F97975F975F0097975F97975F9797
009797494949975F97975F97975F97975F975F5F975FC597C5C5EFC5C5C5C5C5EFC5C5C5
9797C5975F97975F97975F97975F975F975F49494900975F5F5F5F005F004949495F5F5F
5F5F97975F97975F975F97C55F97975F979700979700979700979700975F004900975F5F
5F5F97975F97005F975F97975F005F970097975F979700975F5F5F5F5F5F005F5F5F5F5F
005F5F005F5F00975F00979797979700975F005F5F005F5F00975F00975F004900737373
5F5F97975F975F975F5F97975F97975F97975F5F970097975F5F9797C5C55F97975F9797
002C005F5F97975F5F975F97979797A7A7A7494949975F975F5F5F975F97979797C5C5C5
97C5C59797C5C5C5C5C5C5C5B6B6B6C5C5C597C5C5C5C5C5D4D4D4C5EFC5A7A7A7975F97
975F97737373737373B6B6B6A7A7A7B6B6B6C5C5C5004900975F97975F97975F97B6B6B6
C597C5B6B6B6B6B6B6C5C5C5002C00975F97975F97975F97B6B6B6B6B6B6A7A7A7A7A7A7
5FC597A7A7A797C5975F9797975F977373735F5F97970097A7A7A7A7A7A7A7A7A7A7A7A7
A7A7A75F97975FC5979797975F97978585855F97975F97975FC5C59797975F97975FC597
5F97975F97975F97975FC5C55F97975F5F975F9797004900975F97975F979700975F5F97
000000970097975F5F975F974949492C2C2C4900002C2C2C4900002C2C2C2C0000002C00
2C2C2C2C2C2C002C000000002C2C2C002C00975F5F975F975F5F975F5F5F2C2C2C000000
970097975F97975F972C2C2C00002C2C2C2C2C2C2C00000000002C0000002C2C2C2C2C2C
00002C00002C0000002C0000002C005F0000975F975F5F97975F5F002C00002C002C0000
002C00002C002C2C2C2C2C2C2C2C2C737373975F975F5F5F2C2C2C2C0000002C002C2C2C
5F0097975F975F5F5F2C2C2C2C2C2C002C002C2C2C002C000000000000002C2C2C004900
737373975F97975F974949492C2C2C2C2C2C0000002C2C2C0000002C0000000000000000
000000002C005F005F9700975F5F97975F97975F97002C000000005F005F975F97975F97
2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C002C00002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C000000
97C5C55F97970097975F97975F97970097970097975F97975F97975F97C55F9797005F97
9797975F5F975F975F5F97975F97975F975F5F9797005F97B6B6B65F975F5F97975F9797
5F97972C0000975F975F9797975F978585855F97C597C5C5B6B6B6C5C5EF97C5C5C5C5EF
A7A7A7979797975F97975FC57373735F975F494949005F5F5F5F5F2C2C2C494949494949
5F5F5F975F97975F975F9797A7A7A75F5F975F979700979700975F005F5F4949495F5F97
975F5F5F5F97005F5F00975F975F5F737373975F97975F975F5F5F5F5F5F5F5F5F5F9797
005F9700975F00975F00975F5F5F5F5F97975F9797005F5F005F5F5F5F5F000049975F97
975F5F975F975F5F5F5F97975F9797005F970097975F97975F97975F97979797975F97C5
002C00975F5F975F97975F9797979797C5C55F005F5F5F97975F97975F97A7A7A7A7A7A7
97C5C5A7A7A7B6B6B69797C5C5C5C5C5EFEFC5C5EF97C5C5C5C5C5B6B6B6EFC5C5A7A7A7
970097975F97975F5F975F972C2C2CA7A7A7B6B6B600002C975F975F5F5F970097C5C5C5
B6B6B6B6B6B6C5C5C597C5C500002C975F97975F97970097C5C5C5B6B6B6B6B6B6B6B6B6
97C597A7A7A797C5975F97975F5F5F73737397005F975F975F97975F9797A7A7A75FC597
5FC5C55F9797A7A7A79797975F9797A7A7A75F97979797975F9797A7A7A75F9797979797
5F97975F97975F97975F97C59797975F97975F9797490000975F975F005F975F975F5F97
2C2C2C975F97975F97975F97494949002C002C2C2C002C00002C0000002C2C2C2C490000
002C000000002C00002C00002C2C2C00002C975F97975F5F975F97494949000000002C00
975F975F005F975F9749000000002C2C2C2C00002C2C0000002C002C0000002C0000002C
2C2C2C0000002C0000002C00002C0000002C737373975F975F5F972C2C2C2C000000002C
00002C00002C2C2C2C5F000000002C737373737373975F974949492C2C2C2C2C2C2C2C2C
975F5F5F0097970097494949002C00002C002C2C2C000000000000002C002C000000002C
975F9797005F975F972C2C2C2C2C2C2C2C2C00002C0000005F5F5F5F5F97975F97737373
975F97975F97737373975F97975F5F975F97975F5F2C2C2C000000737373858585975F97
2C2C2C2C2C2C00002C2C2C2C2C2C2C002C00002C0000002C00002C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C00002C2C0000
5F97C597C5C5B6B6B6A7A7A75F97975F97975F97975F97975F97C55F97975F9797009797
005F5F975F97975F975F5F975F97C5009797C597C59797975F97C55F975F5F97975F9797
5F97975F5F5F975F97975F97975F975F5F975F97975F97C5A7A7A7B6B6B697979797C5C5
A7A7A7975F97975F97975F97975F5F9797975F975F5F5F5F5F5F005F5F002C2C2C004900
975F97737373975F975F9797A7A7A7A7A7A75F97975F975F5F975F005F5F000049975F97
975F97975F97005F5F009797975F97975F975F5F97975F97494949005F5F2C2C2C2C2C2C
5F005F49494900490000005F005F005F975F5F97975F97975F97975F9797005F5F975F5F
975F97975F5F5F5F5F00975F5F5F9700979700975F005F5F5F5F975F9797A7A7A7C5C5C5
002C00975F97975F97975F97B6B6B6B6B6B6494949975F97975F97975F97979797A7A7A7
5F97975F97975F97C55F97C5B6B6B697C5C597C5C5C5C5C5C5C5C5C5C5C5B6B6B6C5C5C5
C5C5C5A7A7A75F5F97975F97975F97975F975F5F5F000000975F97975F97975F97A7A7A7
A7A7A7B6B6B6B6B6B697C5C5000000737373975F97975F97C5C5C5C5C5C5B6B6B6B6B6B6
A7A7A7A7A7A7A7A7A7A7A7A7975F979700975F5F97975F97979797A7A7A75FC5C5979797
5F97975F97975F97975FC5975F97975F97975F97975F97978585855F97975F97975FC597
5F97975F97975F97975F97975F97C55F97979797972C2C2C5F5F5F975F97970097975F97
2C00005F5F97975F5F975F972C2C2C490000002C002C2C2C2C2C2C2C2C2C490000002C00
002C002C0000002C000000000000002C00005F005F975F5F5F5F975F005F00002C2C2C2C
975F97737373975F9700002C00002C00002C000000002C000000002C00000000002C0000
00002C2C00002C2C2C002C000000002C2C2C975F5F5F009773737300002C2C0000002C00
00000000000000002C2C2C2C2C2C2C970097975F975F005F2C2C2C002C000000002C2C2C
975F97975F979700972C2C2C0000000000002C2C2C490000002C00000000002C00002C00
5F5F97737373975F974949492C2C2C2C2C2C000000970097975F97975F975F5F97970097
5F0097975F5F7373735F5F97975F975F5F5F2C2C2C2C2C2C2C2C2C975F97975F97975F97
2C00002C2C2C2C2C2C002C000000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C4900002C2C2C
002C002C2C2C2C2C2C002C00
C5C5C5B6B6B6B6B6B6A7A7A7979797A7A7A7979797A7A7A79797C55F97C50097975F97C5
5F9797975F97975F97005F975F9797B6B6B6B6B6B65F97975F97975F97975F5F97009797
2C2C2C975F975F5F97975F97975F975F97975FC5C55FC5C59797C597C5C5D4D4D45F97C5
A7A7A7975F97975F97975F978585855F97978585855F975F2C2C2C005F5F4949492C2C2C
5F5F5F975F97975F975F979700975F00975F005F5F5F975F005F5F00975F2C2C2C975F97
975F97975F975F97970097975F5F5F5F5F97975F9797005F975F5F975F975F5F97975F97
975F97975F97975F97970097975F9797005F2C2C2C5F97975F5F97005F972C2C2C975F5F
975F97975F978585855F97975F97975F97970097975FC5C597C5975F97975F9797979797
2C2C2C975F5F5F5F97970097A7A7A7A7A7A7494949975F5F5F5F97975F97A7A7A75F97C5
5F979797C5975F97C55FC5C55F97C5A7A7A75FC5C597C5C5C5C5C5C5C5C5B6B6B6C5C5C5
D4D4D4B6B6B6C5C5C5C5C5C5A7A7A7975F97975F5F975F97975F5F5F5F97975F975F9797
B6B6B6D4D4D4D4D4D4C5C5C52C0000975F97975F97975F97B6B6B6B6B6B6B6B6B6B6B6B6
A7A7A7A7A7A75FC5C5A7A7A7975F5F975F97975F5F5F00975F97975F97C55F97975F9797
A7A7A75F97975F97979797975F97975F97975F97975F97975F97975F97975F9797979797
9797975F97975F97975F97975F97975F9797005F5F975F97975F97975F975F5F975F5F97
2C2C2C5F5F97975F97975F972C2C2C002C0000002C2C2C2C2C2C2C00002C002C00002C00
0000002C2C2C0000000000002C000000002C7373735F5F97975F5F2C2C2C002C00002C00
9700975F5F9797005F5F5F97858585975F97975F97975F97975F97975F5F5F5F97975F97
737373975F5F0000002C2C2C2C2C2C000049975F97858585975F97002C00002C002C0000
0000000000002C000000002C2C2C2C9700975F5F97975F974949490000002C2C2C2C2C2C
975F5F9700979700972C2C2C002C002C2C2C00002C002C00002C0000002C2C0000002C00
737373975F97975F972C2C2C002C000000005F005F9700975F5F5F975F97975F975F5F5F
5F005F7373735F5F5F4949492C2C2C2C2C2C002C00002C002C00005F5F97975F97975F5F
00002C2C2C2C002C000000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C4900002C2C2C2C2C2C
0000002C2C2C2C2C2C00002C
B6B6B6C5C5C5D4D4D4C5C5C55F979797C5C5B6B6B6B6B6B6C5C5C55FC5C59797975F9797
5F9797005F5F975F97975F9749494900005F005F5F5F5F5F5F005F5F005F5F005F494949
5F5F5F975F97975F97975F97975F975F97975F97C5C5C5C597C5C5B6B6B6979797A7A7A7
A7A7A7975F97975F97975F97975F975F97978585855F5F5F5F5F002C2C2C005F00494949
5F5F5F975F97975F978585855F9797009797005F5F005F5F005F5F00975F2C2C2C970097
5F5F97975F97005F97005F974949495F0097975F97975F975F5F5F737373005F5F005F5F
005F5F5F5F5F5F5F975F979700005F5F5F5F975F5F975F5F5F97975F9797005F5F975F97
975F5F975F975F5F975F97975F97975F97975F9797A7A7A75F97975F97C55F97C55F9797
00002C5F5F97975F5F975F975F97C5A7A7A7494949975F97975F975F5F97B6B6B6979797
5F97C5B6B6B69797975F97975F97979797975F97975F97C597C5C597C5C5C5C5C5C5C5C5
B6B6B69797C597C5C597C5C5C5C5C5B6B6B6C5C5C5000049975F5F975F97975F97B6B6B6
C5C5C5C5C5EFC5C5C5C5C5C500002C5F5F97975F5F975F97C5C5C5C5C5C5B6B6B6C5C5C5
A7A7A797C5C5A7A7A7A7A7A7975F97975F975F5F975F5F975F97970097975F97C55F9797
5F97C55F97C55F97975F97975F97978585855FC597A7A7A75F97979797975F97975FC597
5F979797C5975F97C55F97C55F97C57373734949495F5F5F975F9797005F7373735F9797
0097975F5F5F737373975F972C2C2C2C00002C2C2C00002C2C2C2C2C2C2C2C2C2C00002C
0000002C2C2C000000002C00002C002C0000975F975F0097975F974949492C2C2C002C00
5F0097975F97975F974949492C2C2C2C2C2C2C2C2C00002C2C2C2C002C002C2C2C002C00
975F5F975F979700972C2C2C002C005F005F5F5F97737373737373002C00002C00002C00
0000000000000000002C2C2C2C2C2C5F5F5F975F97975F974949492C00000049002C2C2C
975F975F0097975F5F2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C00002C002C0000002C
5F5F97975F979700972C2C2C0000000000005F5F5F975F97975F975F5F972C2C2C002C00
002C0000002C2C2C2C4900002C2C2C002C002C2C2C002C00490000975F975F5F5F975F97
2C2C2C00002C2C2C2C00002C00002C2C2C2C49000000002C490000002C002C0000002C00
2C2C2C2C2C2C2C2C2C00002C
97C5C5C5C5C5C5C5EFC5C5C597C5C5B6B6B6C5C5C5B6B6B6A7A7A797C5C55F97975FC5C5
5F9797A7A7A75F5F97975F97975F97975F97975F97975F97975F97975F97975F97975F97
975F97975F97975F97975F975F97975F979797C5C59797C597C5C5A7A7A7C5C5C59797C5
5F9797979797975F97975F975F5F977373738585855F5F005F5F005F5F005F5F5F2C2C2C
5F5F97975F97975F975F975F5F5F975F5F5F005F5F009797005F97005F5F2C2C2C970097
975F97975F97009797005F97005F5F975F5F975F97975F5F00975F5F5F97005F5F005F97
005F975F5F9700979700979700005F5F5F97737373975F5F5F97975F975F494949975F5F
5F5F975F5F975F5F5F5F5F5F0097970097975F97975F97C55F97C55F97C5005F97009797
2C2C2C970097975F975F5F5F5F97975F9797B6B6B6970097975F5F975F978585855F97C5
A7A7A7C5C5C5A7A7A75F97975F9797A7A7A75F97C55F9797C5C5EFC5C5C52C2C2C5F5F5F
C5C5C5B6B6B6A7A7A7B6B6B69797C5B6B6B6C5C59700002C9700975F5F97975F97A7A7A7
B6B6B6A7A7A75FC5C55FC5C5000000975F97975F97975F9797C5C5B6B6B6C5C5C5B6B6B6
A7A7A7A7A7A7A7A7A7A7A7A7975F97975F5F975F975F5F975F97C55F97C5A7A7A75F97C5
97C5C55FC5C55F97C55FC5C5A7A7A75F9797A7A7A75F97975F97975F97979797975F9797
5F9797858585005F5F2C2C2C000000494949975F97975F97737373975F97975F5F5F9797
5F97975F005F975F5F975F972C2C2C002C004900002C2C2C002C002C2C2C2C2C2C000000
002C002C000000002C2C2C2C00002C000000975F975F5F979700974949492C2C2C00002C
5F0000975F975F5F9797005F2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00
97005F5F5F97975F972C2C2C002C00490000975F5F5F5F97975F972C0000002C002C0000
2C2C2C2C2C2C000000000000000000970097975F979700975F5F5F2C2C2C002C002C2C2C
5F5F5F975F97975F974949492C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C000000
7373735F5F975F00972C2C2C2C00002C2C2C5F5F5F975F9797005F49494900000000002C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C0000002C2C2C2C2C0000970097975F97975F97
4900002C2C2C2C2C2C002C0000002C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C
002C002C2C2C2C2C2C002C00
A7A7A75F979797C5C5B6B6B6A7A7A7D4D4D4B6B6B6C5C5C5C5C5C597C5C5B6B6B697C5C5
B6B6B6A7A7A7494949975F975F5F975F97975F5F975F5F975F9797737373005F972C2C2C
975F97975F97975F975F5F975F97979797975F9797C5C5C55F979797C5C597C5C597C5C5
975F97975F97975F97975FC5858585737373975F5F97975F5F97005F5F5F4949492C2C2C
975F97975F97737373975F97005F5F00975F5F975F5F97C5005F5F005F5F000000975F5F
970097975F97005F5F00975F7373735F5F5F5F5F5F975F975F00975F5F5F5F5F975F5F97
005F5F005F975F5F5F005F97494949975F975F5F975F5F5F5F97975F97972C2C2C5F5F97
975F5F975F978585855F979700975F5F5F975F97972C2C2C5F9797005F97005F975F9797
000000975F97975F5F975F975F97975F97C5A7A7A700005F975F97975F9797005F5F9797
97C5C5C5C5C5B6B6B6C5C5C5B6B6B69797C5A7A7A797005FA7A7A7D4D4D42C2C2C975F97
B6B6B697C5C597C5C5B6B6B6B6B6B6C5C5C597C5C5000000975F97975F97975F97A7A7A7
5F97975F97975F97975F97C500002C5F5F97975F97975F975F5F97A7A7A7A7A7A7A7A7A7
A7A7A7B6B6B69797979797979700975F5F97970097975F5F5F97C55F97C597C5C5A7A7A7
5F97C5A7A7A797C5C55F97C5A7A7A75F97C59797975FC5C58585852C2C2C0000495F005F
5F005F970097970097975F97970097975F975F5F97975F5F5F5F5F975F975F5F975F9797
5F5F97005F5F970097975F97975F5F2C2C2C2C2C2C2C2C2C002C00002C00002C00490000
0000005F009700002C2C2C2C00002C2C00005F5F5F737373975F975F005F2C0000002C00
005F5F975F5F97005F975F972C2C2C2C2C2C2C000000002C2C0000002C002C2C2C000000
975F97975F97975F972C2C2C002C0000002C975F5F975F97970097002C002C2C2C002C00
002C00002C0000002C2C2C2C002C00975F97737373975F5F4949492C2C2C00002C002C00
9700979700975F5F972C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C0000002C2C2C
975F97975F979700972C2C2C2C2C2C002C002C2C2C5F5F5F7373735F5F5F002C00000000
000000002C00002C002C2C2C000000975F5F002C0000002C002C00975F5F975F97975F97
2C2C2C002C004900004900002C2C2C4900002C2C2C002C004900002C2C2C2C2C2C000000
2C0000002C002C2C2C2C0000
A7A7A75F97975F97975F97979797C5A7A7A7B6B6B6E1E1E1C5C5EFC5C5C597C5C5B6B6B6
97C5C55F97C5979797975F97979797A7A7A75F97975FC5C55F97C55F9797009797494949
975F97975F975F5F97975F975F979797C5C5B6B6B65FC597C5C5C59797975FC5975FC5C5
5F9797979797975F97979797975F97A7A7A7A7A7A79797975F975F5F5F5F494949000000
975F97975F975F5F977373735F5F975F5F5F5F5F5F005F5F5F5F97005F5F2C2C2C975F97
975F5F975F97005F5F00975F009797005F97975F975F0097975F5F005F97005F975F5F97
005F9700975F005F975F5F5F5F5F5F975F97975F975F5F975F97C55F975F004900975F97
5F5F97975F975F5F97737373005F975F5F97005F5F9700975F9797009797009797009797
004900975F5F975F97975F979797C5A7A7A75F97975F97975F5F5F975F97975F97979797
C5C5C5C5C5C5B6B6B6C5C5C597C5C597C5C55F5F5F975F97975F97C5C5C5002C005F005F
9797C5C5C5C5B6B6B69797C59797C5B6B6B6494949970097975F97975F975F5F975F97C5
A7A7A79797975FC5975F97C500000097005F975F975F5F5F5F5F97A7A7A797C5C55FC5C5
5F97C55F97C59797972C2C2C5F5F5F975F97975F97975F5F5F97C55F97C59797975F97C5
5F9797A7A7A75F97C597C5C597C5C55F97C597C5C5005F5F2C2C2C975F5F975F9797005F
975F97970097975F97975F97975F5F975F97975F97975F97975F975F5F5F5F5F975F9797
5F5F97494949737373975F5F9700974949494900002C2C2C2C2C2C002C00490000002C00
2C00005F5F97490000002C002C2C2C000000975F5F975F5F975F5F494949002C002C2C2C
2C2C2C5F005F975F975F5F5F2C2C2C002C0000002C2C2C2C00002C2C2C2C2C2C2C2C2C2C
970097970097975F5F00002C002C00494949737373970097975F97975F5F00002C2C2C2C
00002C0000002C2C2C2C2C2C2C2C2C975F97975F97975F974949490000002C0000000000
9700975F5F97975F972C0000002C000000002C000000000000002C00002C00002C000000
9700979700979700974900002C2C2C002C002C2C2C975F97975F97975F5F2C2C2C002C00
0000002C2C2C002C00002C002C0000975F5F00000000002C2C0000975F975F5F5F737373
000000000000000000000000002C00002C00002C002C2C2C2C2C2C002C002C2C2C2C2C2C
2C0000002C002C0000002C00
97C5C55F97975F97975FC5975F97C55F97975F979797C5C5C5C5EFD4D4D4B6B6B6C5C5EF
C5EFEF5F9797C5C5C55F9797975F975F979797C5C5C5C5EF97C5C59797C55F9797975F97
975F97975F97975F975F97C5C5C5EFB6B6B6B6B6B65F97C55F97975F97C50097975F9797
2C2C2C975F97975F97975F97975F97975F975F5F5F5F5F5F7373734949492C2C2C5F5F97
737373975F97975F97975F975F5F5F00975F005F5F005F97005F5F2C2C2C5F5F97975F97
975F97975F97005F5F00975F005F5F005F5F005F97975F975F5F5F5F5F5F005F97005F97
5F5F97005F97009797002C0097005F5F5F97975F975F5F975F975F5F5F97000000975F97
975F5F975F97005F9797005F975F5F4900005F005F975F975F5F97009797005F5F005F5F
00005F975F975F5F5F975F97B6B6B6C5C5C59797975F97975F9797975F97975F97975F97
979797A7A7A797C5C55F97C55F97C55F979700002C5F5F5F975F97A7A7A7A7A7A7975F97
5F5F5F7373735F5F5F5F5F5F5F5F5F2C2C2C5F005F975F97975F5F5F5F97975F975FC5C5
5F97C59797C58585857373735F005F975F975F5F97975F975F5F97975F97494949979797
5F97975F97972C2C2C5F5F5F975F97975F97975F979797975F97975F97975F97975F9797
5F97C55F9797A7A7A78585855F97975F97C55F5F5F5F005F737373975F97975F97975F97
5F5F97975F975F5F975F5F975F005F975F5F975F5F5F5F975F5F975F97C55F9797009797
5F5F5F5F005F2C2C2C975F97975F97737373494949002C002C00002C2C2C002C002C2C2C
002C00975F5F49494900000000000000002C5F5F5F970097975F975F005F2C2C2C2C2C2C
002C00000000970097970097975F972C2C2C002C000000002C2C2C00002C000000975F5F
975F97975F972C2C2C0000000000005F005F975F975F5F5F975F975F005F975F5F494949
2C000000002C000000004900975F5F975F97970097975F972C2C2C002C005F005F975F97
5F5F5F975F9797005F970097975F5F975F97975F979700972C2C2C002C0000002C2C2C2C
737373975F5F5F5F972C2C2C2C2C2C00002C2C2C2C2C2C2C9700975F5F5F5F5F5F2C2C2C
002C00002C00002C002C0000737373975F5F4949495F5F5F975F97975F97975F975F5F5F
975F97975F5F5F5F97975F97975F5F2C2C2C00002C2C2C2C002C00002C00002C002C0000
002C0000002C2C2C2C00002C
97C5C55F97C55F975F5F97C55F97975F97C55F97975FC5C597C59797C5C5C5C5C5C5C5EF
9797C59797C59797C5C5C5C5975F97975F979797975F97979797C59797972C2C2C5F5F97
975F975F5F97975F97979797A7A7A7A7A7A797C5C55F9797B6B6B65F9797005F5F975F97
975F97975F97975F97975F97975F975F5F97858585975F97975F97737373975F97975F97
975F97975F975F5F5F005F97975F97975F974949495F005F5F5F5F975F97975F97975F5F
5F5F97975F5F005F977373735F97970097975F5F975F5F97975F97975F97494949005F5F
005F97005F5F2C00005F0097975F97975F975F5F5F5F97C55F5F5F975F97975F97975F97
7373735F00975F5F5F5F5F97975F5F975F97975F5F975F97005F975F97975F5F5F970097
975F97975F97975F97975F5FA7A7A7B6B6B65F9797A7A7A79797979797975F5F97975F97
975F97975F5F2C2C2C00002C2C00005F005F975F97975F97975F97A7A7A75F97C5A7A7A7
9700978585855F5F97737373975F975F5F9797005F970097975F975F5F975F97C55F9797
9797975F9797975F97975F97975F97970097975F97970097737373737373970097975F97
5F5F977373735F5F5F970097737373737373975F9797C5C597C5C59797C55FC597979797
5F97C55F97975F9797A7A7A75F97975F97C5000000970097975F97975F97975F5F970097
975F5F5F5F975F5F975F5F975F5F975F97975F97975F97975F97C55F97975F97975F9797
5F5F5F005F5F2C2C2C00002C5F5F97975F5F5F5F5F737373494949002C002C2C2C494949
5F005F975F5F975F5F5F005F975F5F5F5F97975F97975F975F5F9797005F00002C2C2C2C
0000000000004949495F005F970097975F972C2C2C002C000000000000005F5F97975F97
7373735F005F00002C970097975F97975F975F005F737373975F972C2C2C494949737373
975F5F975F97975F97975F5F975F975F5F97975F97494949494949002C00002C00002C00
5F5F5F5F5F977373735F5F5F97005F5F0097975F97970097494949737373975F5F5F5F97
5F5F977373735F00974949492C0000002C0000002C0000002C2C2C5F5F97970097975F5F
5F5F5F4949495F005F970097975F5F975F97002C00002C00494949975F975F5F5F975F97
5F5F5F5F5F5F5F5F5F5F5F97975F972C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C002C004900002C2C2C
005F975F97975F97975F97C55F97975F9797A7A7A7A7A7A7A7A7A7C5C59797C5C59797C5
B6B6B6C5C5C5EFC5C5C5C5C5737373975F97B6B6B6EFC5C5B6B6B65F9797005F5F975F97
5F5F97975F975F5F97B6B6B6A7A7A7C5C5EFA7A7A75F97975F97C55F97C55F97975F9797
5F97C5975F97975FC5975F97975F978585855F5F5F975F97975F97975F97975F97975F97
975F975F5F5F00975F005F97005F5F5F5F97975F97975F97975F97975F97737373975F97
975F975F5F97005F975F975F5F975F005F5F5F97975F5F975F5F97975F97975F97975F97
975F975F5F97975F5F975F5F975F977373735F97975F97975F5F975F97975F5F975F5F97
5F5F97975F5F975F5F005F975F5F975F5F975F5F975F5F975F5F975F5F977373735F9797
5F5F97975F97975F97975F975F5F5F5F97975F97975F5F975F97970097975F9797737373
975F975F5F97975F97975F97975F97970097970097975F975F5F975F9797B6B6B6C5C5C5
B6B6B6A7A7A7975F977373735F5F97975F5F975F975F5F5F5F5F975F97975FC5C5A7A7A7
9797C5C597C5B6B6B6979797737373975F97975F97975F975F5F5F5F5F975F5F97975F97
5F5F97975F97975F975F5F979700975F5F97A7A7A75FC5C55F97C55F9797A7A7A797C5C5
97C5C5A7A7A797C5C59797975F97975F979797005F975F9797005F5F5F97975F97979797
97C5C597C5C59797C55F97C55FC5C55F97C597C5C55F97C55F97C55F97975F5F975F9797
5F5F5F494949002C002C2C2C00002C2C2C2C5F5F5F5F0097975F975F5F5F5F5F5F970097
975F5F5F5F9700002C2C2C2C2C2C2C2C2C2C494949975F5F970097975F972C2C2C490000
002C002C0000002C0000002C5F5F5F5F5F5F975F975F5F97975F97975F975F00975F5F97
4949490000002C0000000000002C0000002C4949495F5F5F9700972C2C2C2C2C2C2C0000
5F005F975F5F975F975F5F975F005F975F975F005F2C2C2C2C2C2C2C2C2C000000002C00
975F97975F97975F9749494900002C00002C2C2C2C2C2C2C2C2C2C2C2C2C002C0000002C
4949495F5F5F975F975F5F5F002C00002C0000002C2C000000002C00002C5F005F970097
975F97975F5F975F97975F977373732C2C2C00002C002C002C2C2C975F5F970097975F97
2C2C2C0000002C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C
2C2C2C002C00000000002C00
005F975F97C500979700979797C5C55F97975F97C5C5EFEFEFC5C5C5C5C5B6B6B697C5C5
C5EFFFC5C5EFC5C5EFB6B6B69797C5975F97975F97E1E1E1D4D4D4A7A7A7975F97858585
975F97975F975F5F975F97C50097C55F97C55F97C55F97C50097C55F975F5F9797A7A7A7
005F970097975F97975F5F97005F975F97975F5F5F737373005F5F7373735F5F5F5F5F5F
5F5F5F00979700979700975F005F97005F97005F5F5F5F977373737373735F5F975F5F5F
5F5F9700975F005F975F975F5F97975F97975F5F975F97975F97977373737373735F5F97
5F5F975F5F978585855F9797009797009797009797005F975F97975F97C5A7A7A75F9797
5F97C55F5F977373737373735F97970097975F5F975F5F5F5F5F975F5F975F5F975F9797
5F97C55F97975F97977373735F97975F975F005F975F97975F975F5F9797009797009797
7373735F97977373735F5F977373735F97975F97975F97C55F97C55F97C5B6B6B6B6B6B6
C5C5C5B6B6B6B6B6B6B6B6B697C5C59797C59797C5B6B6B6B6B6B6A7A7A75F97C59797C5
9797C5B6B6B69797C597C5C5B6B6B65F97C55F97975F5F975F97970097975F9797A7A7A7
5F5F975F5F975F5F975F5F975F97C5A7A7A75F97975F97975F97C55F97C55F97C55F9797
A7A7A75F97C59797C59797C55F97C5005F5F975F97975F97975F97975F979797C55FC5C5
A7A7A75F97C5A7A7A75FC5C55F97C59797975F97C55F97975F97975F97975F97975F5F97
005F5F4949492C2C2C00002C00002C2C2C2C2C2C2C49000000002C00002C49000000002C
2C2C2C00002C2C2C2C0000002C000000002C2C0000002C002C2C2C2C2C2C2C2C2C002C00
002C00002C002C2C2C002C00002C002C2C2C00002C2C2C2C494949494949000000000000
0000002C2C2C00002C2C000000002C00002C00000000000000002C002C00000000002C00
00002C2C2C2C4949494949492C2C2C000000000000000000002C00002C0000002C2C2C2C
5F5F979700979700972C2C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C002C002C2C2C2C2C2C
2C2C2C002C004900002C2C2C2C2C2C00002C2C2C2C2C2C2C00002C00002C00002C2C0000
00002C00002C00002C2C2C2C00002C00002C000000002C00000049975F97970097975F5F
490000002C0000002C002C00002C0000002C2C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C
2C2C2C4900002C2C2C000000
005F5F005F97009797005F970097975F97975F97975F979797C5C597C5C5D4D4D49797C5
9797C5C5C5EFC5EFEFC5C5EFB6B6B65F5F5F975F97B6B6B6C5C5C5494949975F97975F97
975F97975F975F97C5D4D4D4B6B6B6B6B6B65F97C5B6B6B6A7A7A75F5F975F5F975F5F97
8585855F975F7373735F97979797C500975F8585855F975F494949007300494949005F5F
005F5F009797005F5F5F975F5F5F975F5F5F5F5F5F5F5F5F005F5F737373005F5F5F5F97
5F975F005F5F00975F005F5F5F97975F975F5F9797005F975F97975F97975F9797009797
005F975F97979797C55F97975F97975F9797005F970097970097970097970097975F9797
5F97975F97979797C55F97975F97975F97975F5F5F5F975F5F97970097975F97975F9797
5F9797005F975F97975F97975F97970097975F975F5F979773737300975F5F5F5F5F9797
5F979797C5C50097975F97975F97975F97975F97C55FC5C597C5C59797C5979797B6B6B6
B6B6B697C5C597C5C597C5C5C5C5EFC5C5C5B6B6B65FC5C55FC5C597C5C597C5C55F97C5
97C5C597C5C5A7A7A75F97C597C5C5A7A7A75F97975F97975F97975F97975F9797A7A7A7
A7A7A75F97975F97975F97975F97975F97C55F97C55F97C50097C50097975F97975F97C5
5F97C5979797A7A7A79797C5A7A7A75F5F5F737373970097975F97975F5FA7A7A79797C5
97C5C597C5C5A7A7A7A7A7A7A7A7A75FC5C5A7A7A7A7A7A75F97975F9797005F975F5F5F
4949492C2C2C00002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C00002C2C2C2C
00002C00000000002C2C2C2C00000000002C49000000002C00002C002C0000000000002C
0000002C0000002C00002C002C2C2C2C2C2C0000002C00002C000000002C2C2C2C000000
2C2C2C2C2C2C00002C00002C2C0000002C00002C00490000002C00002C00002C00002C00
2C2C2C2C2C2C00002C2C2C2C002C00490000000000002C00002C000000000000002C2C2C
5F005F5F5F97975F97494949002C00002C002C2C2C0000000000002C00002C2C2C00002C
000000002C00002C00002C0000000000002C002C002C00000000002C2C2C00002C00002C
2C2C2C2C2C2C2C2C2C002C002C2C2C00002C00002C0000005F00009700975F5F97975F97
2C2C2C2C2C2C2C2C2C002C002C00002C2C2C002C002C00002C2C2C002C0000002C2C2C2C
002C002C2C2C002C00000000
005F97009797005F5F005F975F97975F5F970097975F979797C5C5A7A7A797C5C597C5C5
97C5C5C5C5EFC5C5C5C5EFEFC5C5EF97C5C5975F97975F97C5C5C5005F5F5F5F97975F97
975F97975F9797C5C5E1E1E1A7A7A75F97975F9797A7A7A75F97975F97975F97975FC5C5
5F5F975F5F5F5F5F97005F5FC5C5C5005F5F5F975F494949494949005F5F005F00005F5F
009797005F97005F975F5F97005F975F5F5F005F5F5F5F5F5F97975F5F975F5F97005F97
5F5F5F00975F5F5F5F5F5F5F005F97005F975F975F5F97970097970097975F9797005F97
005F5F005F97005F975F97C59797C55F979700979700975F005F975F97970097975F9797
5F97975F97979797975F97C55F97970097975F97975F5F977373735F9797009797009797
5F5F975F5F975F97975F97975F97975F97975F97975F5F97005F5F009797009797009797
5F5F5F005F5F5F97975F97975F97975F97975F97975F97C55F97C55F9797A7A7A79797C5
97C5C5B6B6B6B6B6B6B6B6B6C5C5C597C5C5B6B6B69797C55F97C597C5C597C5C5B6B6B6
5F97C5A7A7A75F97C55F97C59797C55F97C55F97979797975F97975F97975F97C55F9797
5F97975F97975F97979797975F97979797975F97975F97C55F97C55F97979797975F9797
5F97975F9797979797A7A7A79797C55F9797970097975F97970097975F5F9797C597C5C5
A7A7A797C5C55F97C55FC5C5A7A7A75F97C5A7A7A75F97975F97975F5F5F005F975F005F
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00002C002C2C2C2C2C2C
00002C2C000049000000002C0000004900002C2C2C2C2C2C00002C00002C2C000000002C
000000002C002C2C2C002C002C2C2C2C2C2C4900002C2C2C00002C2C2C2C2C2C2C002C00
2C000000002C2C2C2C00002C00002C2C0000000000002C000000002C0000002C002C2C2C
2C2C2C002C000000002C2C2C00002C00002C00002C002C00002C0000000000002C2C2C2C
7373735F005F7373735F5F5F00000000002C0000000000002C2C2C2C2C2C00002C000000
002C002C2C2C00002C00002C2C2C2C2C2C2C002C000000002C0000002C002C000000002C
2C2C2C2C2C2C2C2C2C00002C00002C002C00000000002C002C2C2C5F5F97737373975F97
2C2C2C0000000000002C00002C2C2C2C2C2C002C002C2C2C2C2C2C00002C4900002C2C2C
002C00002C002C2C2C002C00
005F5F005F5F005F5F5F5F5F97975F5F5F5F005F5F0097970097C55F97975F97C55F9797
5F97C5C5C5EFC5C5C5C5C5EFC5C5C5D4D4D4737373975F97B6B6B65F5F97975F975F5F97
975F979797C5A7A7A7A7A7A7A7A7A7C5C5C597C5C59797979797975F9797005F975F5F97
5F5F5F5F5F5F5F5F975F97C55F9797005F5F5F97004949494949494949495F5F005F5F5F
5F5F975F5F975F5F975F97975F5F97005F975F5F97005F97005F5F00979700975F005F5F
7373735F975F005F5F5F5F5F5F5F5F5F5F975F97970097970097975F97975F97975F9797
5F97975F97975F9797A7A7A7A7A7A7A7A7A70097975F97970097970097970097975F9797
5F97975F97975F97C55F97C59797975F97C5A7A7A75F97975F9797979797009797009797
005F970097975F97975F5F975F97970097975F97977373735F5F5F5F5F5F5F975F00975F
5F5F5F7373735F5F977373735F97975F5F970097975F97975F97975F97975F9797A7A7A7
A7A7A7A7A7A797C5C5A7A7A7B6B6B6C5C5C5C5C5C5B6B6B697C5C5A7A7A7A7A7A797C5C5
B6B6B6A7A7A7A7A7A75F97C59797C5A7A7A797C5C55F97975F9797979797A7A7A797C5C5
9797C59797979797975F97975F9797A7A7A7A7A7A7A7A7A7A7A7A797C5C597C5C5979797
A7A7A75F97979797975F97979797975F9797975F5F5F5F5F975F977373735FC5C59797C5
97C5C597C5C55F97C55F97C55F97C55FC5C55F97975F979700002C005F5F005F97005F5F
2C2C2C2C0000002C002C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C00000000
000000002C0000002C2C0000002C002C2C2C002C0000002C2C00002C2C2C2C2C2C00002C
2C2C2C002C000000002C2C2C002C00002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C
2C2C2C2C2C2C2C2C2C2C2C2C00002C00002C2C00002C2C2C2C2C2C2C2C2C00002C2C2C2C
002C00002C002C2C2C002C0000002C2C0000002C00002C000000000000002C0000002C00
7373735F5F5F5F5F974949490000000000002C2C2C2C2C2C2C2C2C2C2C2C000000000000
00000000002C2C2C2C2C2C2C2C2C2C2C2C2C002C00000000002C002C2C2C2C2C2C000000
2C2C2C00000000002C000000000000002C002C2C2C2C2C2C5F005F9700975F5F97975F97
2C2C2C002C002C0000002C0000002C002C002C2C2C0000002C2C2C2C2C2C2C2C2C2C2C2C
00002C2C2C2C2C2C2C2C2C2C
005F5F005F5F005F97005F5F5F9797737373005F5F009797005F975F97C50097970097C5
5F97975FC5C597C5C5C5C5C5C5C5EFEFC5EFA7A7A7975F97975F97975F97975F97858585
975F97B6B6B6A7A7A7B6B6B6B6B6B6B6B6B697C5C5B6B6B65F9797B6B6B65F97975F9797
005F5F737373005F97737373005F97005F5F5F975F005F00494949005F5F494949005F5F
005F97009797005F975F5F975F5F975F5F975F5F97005F97005F5F5F5F5F005F975F5F5F
005F5F0097975F5F975F5F9700975F5F979700975F0097975F97975F979700979700975F
005F975F97975F97975F9797009797A7A7A75F97C55F97970097975F9797005F975F9797
5F5F975F97975F97975F97975F97975FC5C5A7A7A7A7A7A75F9797B6B6B697C5C5B6B6B6
4949495F005F975F5F5F5F5F009797005F5F7373735F975F5F975F00975F005F5F009797
005F975F5F5F5F97977373735F97975F97977373735F97975F97975F97975F97C55F97C5
9797C5A7A7A7A7A7A7A7A7A75F97C5B6B6B697C5C5B6B6B6C5C5C5B6B6B6B6B6B6A7A7A7
B6B6B6A7A7A7A7A7A75F97C597C5C59797C5A7A7A7A7A7A797C5C55FC5C597C5C55F97C5
5FC5C597979797C5975F97975F97C5A7A7A7A7A7A7B6B6B6B6B6B6B6B6B6A7A7A7A7A7A7
97C5C59797C597C5C55F97C55F9797A7A7A75F005F975F97975F97975F975F9797A7A7A7
9797C597C5C55FC5C5A7A7A7A7A7A7A7A7A79797975F979700002C975F97005F5F2C2C2C
2C2C2C002C002C2C2C2C2C2C00002C4900002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C000000
002C00002C00490000002C0000002C2C2C2C0000495F5F5F97005F5F5F0000000000002C
00000000002C2C2C2C002C00002C002C2C2C00002C00002C00002C2C2C2C002C00000000
00002C2C2C2C2C2C2C2C2C2C2C2C2C000000002C002C2C2C2C2C2C00002C000000002C00
00002C00002C2C2C2C2C2C2C002C00002C002C2C2C2C2C2C002C002C00002C2C2C005F5F
7373735F5F97975F5F5F5F5F00002C0000002C2C2C2C2C2C002C002C2C2C2C2C2C000000
5F5F5F5F005F5F5F972C2C2C002C00002C00002C0000002C00002C00002C2C00002C2C2C
002C002C2C2C2C2C2C00002C00000000000000002C2C2C2C5F005F975F97970097975F97
002C00002C0000002C2C2C2C2C000000002C0000002C2C2C002C00002C00002C002C2C2C
00002C2C2C2C2C2C2C002C00
5F5F5F005F5F005F97005F5F005F5FA7A7A7005F5F5F5F5F7373735F5F97005F97005F97
5F97979797975F97C55FC5C5A7A7A797C5C5B6B6B65F5F97975F97975F97979797975F97
975F97C5C5C5C5C5C5D4D4D497C5C5C5C5EFA7A7A75F97975F97975F97C55F97975F5F97
005F975F5F975F9797005F9700975F00975F005F5F2C2C2C5F5F00494949494949005F5F
00975F5F975F005F975F5F97005F975F5F975F5F9700975F00975F7373730097975F9797
005F5F005F5F005F970097970097975F975F5F97975F97978585855F975F5F9797009797
0097970097975F5F975F97975F97978585855F97975F9797737373005F975F97975F9797
5F97975F5F975F97975F97975F97C55F97975F97975F97975F97975F97975F97975F9797
00005F975F97975F975F5F975F5F5F73737300975F00975F00975F5F975F5F975F00975F
005F97005F5F00975F00979700975F5F975F5F5F5F005F5F5F9797005F975F97975F9797
9797979797975F97C5B6B6B6B6B6B6C5C5C5C5C5C597C5C5B6B6B6C5C5EFC5C5C597C5C5
97C597A7A7A7A7A7A7A7A7A7A7A7A7B6B6B697C5C5B6B6B69797979797975F97975F97C5
5F97975F9797A7A7A75FC5C5979797A7A7A75F97C5C597C597C5C5A7A7A75F97C597C5C5
97C5C597C5C5A7A7A7A7A7A797C5C5B6B6B65F5F97975F97970097975F97A7A7A75F97C5
97C5C59797C5A7A7A79797979797975F97975F97975F979700002C975F97005F5F2C2C2C
002C0000000049000000002C2C2C2C2C2C2C002C002C2C2C00002C49000000002C2C0000
00002C2C2C2C002C002C2C2C00002C002C00975F97970097975F97975F5F2C2C2C2C2C2C
49000000000000002C2C2C2C2C2C2C0000000000002C00002C2C2C00002C002C00000000
49000000002C2C2C2C2C2C2C000000000000002C002C2C2C002C00002C002C0000002C00
0000002C2C2C2C2C2C494949002C000000002C2C2C2C2C2C00000000002C0000002C0000
4900004949495F5F5F5F5F5F002C00002C0000002C2C00000000002C0000002C00002C00
737373975F5F975F5F975F5F00002C00002C2C2C2C002C002C2C2C00002C00002C2C2C2C
2C2C2C2C2C2C00002C0000000000000000000000005F5F5F002C002C2C2C494949975F5F
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C002C0000002C2C2C2C2C2C2C2C00002C2C2C00002C
2C2C2C002C002C2C2C00002C
005F5F005F5F005F5F005F5F005F9700975F5F5F5F5F975F5F975F009797494949005F5F
5F97975F97C55F97975F9797A7A7A79797975F97C5A7A7A7858585975F97975F97975F97
B6B6B6C5C5C5C5C5C5C5C5C5C5C5C5B6B6B697C5C5A7A7A797C5C55F97975F97975F5F97
5F5F9773737300975F5F975F00979700975F005F00005F004949495F5F5F005F5F005F5F
0097975F97975F5F975F5F970097975F97975F97975F97975F97975F5F975F5F975F5F97
5F5F5F009797005F975F975F5F97977373735F97975F97975F97975F979773737300975F
005F97005F5F5F97975F97975F97979797970097975F97975F5F975F97975F9797A7A7A7
8585855F97975F97978585855F5F970097975F97975F97975F97975F97975F9797009797
5F005F975F5F975F979700975F5F5F5F5F5F5F97970097975F979700975F00979700975F
005F5F005F5F7373735F5F975F97975F9797005F97005F5F5F97975F97975F97975F97C5
5F97975FC5C55F979797C5C597C5C597C5C55FC5C597C5C5A7A7A75F97C597C5C5B6B6B6
97C5C55F97975F97979797C55F97C55F97C55F97C55F97975F97975F97975F97975F9797
5F97975F9797A7A7A75F97975FC5975FC5C5A7A7A7A7A7A7A7A7A7A7A7A7A7A7A75F9797
9797979797C5B6B6B6B6B6B697C5C59797C55F97C55F005F5F5F979700975F5F975FC5C5
5F97C55FC5C55FC5975FC5C597C5979797975F97977373732C2C2C975F97494949002C00
000000002C00002C00490000002C002C0000002C0000002C00002C00000000002C00002C
00002C2C2C2C00002C002C000000002C2C2C97005F975F5F975F5F975F972C2C2C2C2C2C
00002C2C2C2C4900002C2C2C2C2C2C002C00490000002C000000000000002C00002C0000
00002C2C2C2C2C2C2C2C2C2C002C00002C000000002C2C2C2C2C2C00002C2C00002C2C2C
00000000000000002C00002C00002C00000000002C00002C2C2C2C2C2C2C2C000000002C
00000000002C00002C0000000000000000002C2C2C00002C2C000000002C000000000000
975F5F975F9797005F975F5F2C2C2C002C0000000000002C00002C2C000000002C2C0000
000000002C0000000000002C000000000000000000000000002C00002C00002C002C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C00002C002C00002C00002C002C2C2C002C00002C002C0000
0049002C2C2C2C2C2C002C00
005F5F005F00005F5F5F5F5F5F975F005F5F7373735F5F5F5F5F5F5F5F5F0097975F9797
5F9797005F97A7A7A797C5C5A7A7A7A7A7A75F97975FC5C55F5F97975F97975F97975F97
97C5C597C5C5C5C5EFC5C5C5C5C5C5C5C5C5B6B6B65F97C55F97975F97975F97975F9797
7373735F975F00975F5F975F5F975F5F97004949492C2C2C4949495F5F5F5F5F00494949
005F975F979700975F5F9797005F97009797005F975F97975F97970097970097975F9797
5F979700975F5F97979797975F97970097975F97975F97975F97975F97975F97975F9797
5F97975F5F970097970097975F97975F97975F5F975F5F5F5F5F977373735F97C5A7A7A7
9797977373735F97975F975F0097975F97970097975F97975F97975F97975F5F975F9797
5F5F97975F97975F975F5F5F5F5F975F5F975F975F00975F00979700975F00975F5F975F
005F977373735F97975F975F5F975F5F97975F97975F975F5F97975F975F5F9797858585
5F9797A7A7A7979797A7A7A7A7A7A75FC5C5A7A7A7A7A7A75F9797B6B6B697C5C597C5C5
97C5C597C5C55F97C5A7A7A75F97C55FC5C55F9797A7A7A75F97975F97975F97975F9797
9797979797975F9797A7A7A75F97975F97C5B6B6B697C5C5B6B6B6A7A7A7A7A7A75FC5C5
A7A7A75FC5C597C5C597C5C597C5C597C5C597C5C5979797975F97975F979700975F5F5F
5F97979797979797C59797979797975F9797005F5F000049975F5F975F97494949000000
2C00002C2C2C002C00002C00002C00490000002C00002C002C2C2C00002C4949492C2C2C
000000002C0000002C2C00002C0000002C005F5F5F975F5F97005F5F005F2C2C2C490000
002C002C2C2C2C2C2C002C00002C00002C002C000000002C00002C00002C00002C000000
0000002C2C2C2C2C2C002C002C2C2C0000002C000000002C00000000002C002C00000000
000000000000002C00002C002C00004900002C2C2C00002C2C2C2C002C000000002C2C2C
2C2C2C0000002C000000000000000000000000000000000000002C0000002C2C2C00002C
97005F975F97975F974949492C2C2C4949495F000000000000000000002C00002C000000
00002C00002C0000002C0000002C002C2C2C002C00002C0000002C2C2C2C2C2C2C2C2C2C
2C2C2C0000000000002C000000002C00000000002C2C000000002C2C2C2C2C2C2C00002C
00002C2C000000002C002C00
005F5F005F5F4949495F5F5F005F5F005F5F005F5F5F5F5F5F5F5F5F5F5F005F5F5F9797
5F979700975F9797975F97975F979797C5C55F97975F9797005F97975F97975F975F9797
5F97C597C5C5C5C5C5C5C5C5D4D4D4C5C5C5B6B6B6B6B6B6A7A7A75F97970097975F9797
5F5F5F7373735F975F5F97975F97975F5F5F4949495F5F004949492C2C2C494949005F5F
0097975F97970097975F97975F97975F97970097975F979700975F009797005F5F009797
0097975F97975F9797005F97009797979797979797A7A7A75F979700975F5F97975F9797
005F975F9797005F975F5F975F5F975F97975F9797005F975F5F5F5F975F00975F5F9797
5F97975F97975FC5C59797979797979797975FC5975F97975F97975F97975FC5975F9797
5F97975F5F975F5F5F8585855F97975F97970097975F97977373735FC5975F97975F9797
0097970097975F97975F97975F97975F5F975F5F975F5F975F5F975F97975F97975F9797
5F97975FC5C5A7A7A7C5C597A7A7A7A7A7A7A7A7A7979797A7A7A79797C5B6B6B6C5C5C5
B6B6B6B6B6B69797979797979797975F97C59797975F97975F97975F97975F9797A7A7A7
A7A7A7B6B6B6A7A7A797C597A7A7A7B6B6B6A7A7A75FC5C55F97975F97975F97C55F9797
5F97C55F97975F979797979797C5C597C5C597C5C59797C5858585975F97737373975F97
975F5F4949495F005F002C00000000005F5F975F5F975F5F975F975F5F5F5F005F000000
000000002C00000000002C002C2C2C00002C2C000000002C00002C2C2C2C494949002C00
2C2C2C002C00002C00002C0000002C2C2C2C2C2C2C00002C2C2C2C0000002C00002C2C2C
2C2C2C2C000000002C00002C2C2C2C00002C00002C00002C002C000000000000002C2C2C
002C00000000002C00002C00002C00002C00000000000000000000490000002C00000000
00002C2C0000002C002C000000002C00002C2C2C2C2C2C2C494949002C00002C00002C00
00000049000000002C2C2C2C002C0000002C0000000000000000000000002C2C2C00002C
002C002C2C2C2C2C2C002C00002C002C2C2C00000000002C00000000002C002C00000000
000000000000000000000000002C00002C00002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C002C0000000000000000000049000000002C002C002C0000002C002C2C2C2C2C2C
002C002C2C2C2C2C2C000000
005F5F5F5F5F494949494949005F5F005F5F00975F005F5F005F5F5F5F5F5F5F5F5F975F
005F005F5F5F5F979797975F005F5F005F5F5F975F5F5F5F5F5F5F5F5F97975F97A7A7A7
5F975FA7A7A7A7A7A7B6B6B6C5C5C5A7A7A797C5C5C5C5C5C5C5C55F97975F97975FC597
5F97975F97978585855F975F5F975F4949494949494949495F5F5F5F5F005F5F5F009797
005F975F97975F97975F97975F97975F97975F97975F97975F97975F97975F9797009797
5F975F5F5F970097975F97975F97975F97975F97970097970097970097975F9797A7A7A7
0097975F97979797975F97975F97975F97C55F97975F97970097975F97975F97975F9797
5F97975F97975F97975F97978585855F97975F97975F97978585855F97C55F97975F97C5
5F97975F97970097975F5F975F97975F97975F97975F97975F97970097975F97975F9797
0097975F97975F97975F97C55F97975F975F7373735F97975F97975F97975F97975F9797
5F97C55FC5C5A7A7A7A7A7A7A7A7A7B6B6B6B6B6B69797975F97975F97C597C5C5B6B6B6
B6B6B6A7A7A7A7A7A79797975F97975F97975F9797A7A7A75F97975F9797A7A7A797C597
A7A7A7A7A7A7B6B6B6A7A7A797C5C55F97979797975F97975F97975FC597858585979797
5FC59700C597A7A7A75F97975FC5C5B6B6B697C5C5B6B6B697C5C5A7A7A75F5F97975F97
975F97970097975F97975F97970097975F97975F97970097975F972C2C2C2C2C2C002C00
2C2C2C2C2C2C2C2C2C002C002C2C2C002C002C2C2C2C2C2C002C002C2C2C2C2C2C490000
00002C2C0000002C002C0000002C002C00002C2C2C00000000000000000000002C00002C
000000002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C002C002C0000490000002C00
2C00000000002C000000000000000000000000000000002C002C00002C00000000000000
002C00002C00002C00002C002C2C2C2C2C2C2C2C2C00002C000000000000002C00000000
49000000002C00002C00002C00002C2C2C2C00002C00000000000000000000000000002C
00000000002C00002C00002C002C0000002C002C0000002C00000000002C000000002C00
000000000000000000002C002C2C2C002C00002C002C2C2C2C2C2C002C00002C00002C00
002C00002C0000002C490000002C0000002C002C002C2C2C002C002C000000002C002C00
002C002C2C2C002C00000000
005F5F5F5F5F005F5F005F5F005F5F005F5F005F5F005F5F005F5F005F5F005F5F2C2C2C
005F004949495F5F00A7A7A7005F5F00975F5F975F5F5F5F5F97975F97C5979797B6B6B6
9797970097975F979797C5C5B6B6B6A7A7A797C5C59797975F9797979797858585737373
8585855F97979797975F5F5F4949494949495F5F5F494949494949005F005F975F00975F
009797A7A7A75F9797A7A7A75FC5975F97C55F97975F97978585855F9797005F975F975F
5F5F970097975F97975F97975F97975F97C50097975F97975F97970097975F97975F9797
5F97978585859797975F97975F97975F97975F97C5A7A7A75F97975F97979797975F9797
A7A7A79797975F97975F97975F97975F97975F97C55F97975F97975F97975F97C55F9797
5F9797005F975F5F975F97975F97975F97975F97975F97975F97975F97975F97975F9797
5F97979797975F97975F97975F97975F97970097970097975F97975F97975F97975F9797
5F979797979797C5C5A7A7A797C5C5A7A7A7A7A7A7A7A7A7B6B6B697C5C59797C5C5C5C5
B6B6B697C5C5A7A7A79797979797979797C55F97975F97975F9797A7A7A7A7A7A7A7A7A7
A7A7A7A7A7A75FC5975FC5C59797975F97975F97C59797975F9797A7A7A797C5C55FC5C5
97C5C5A7A7A79797978585855F97C59797C5B6B6B6A7A7A7A7A7A7A7A7A7979797A7A7A7
5F97977373735F5F975F5F975F5F975F5F975F5F975F97974949492C2C2C2C2C2C2C2C2C
002C002C2C2C2C2C2C2C000000002C00002C2C2C2C2C2C2C002C002C0000494949005F00
2C2C2C494949002C00002C00000000000000002C00000000002C00002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C002C00002C0000002C000000002C00002C002C2C2C2C0000
2C2C2C2C000000002C0000000000002C00002C00002C2C2C2C2C2C002C002C0000002C00
00002C0000004900002C00002C2C2C2C2C2C00002C2C2C2C0000002C2C2C2C2C2C490000
2C000000002C2C2C2C2C2C2C002C002C000000002C2C00000000000000002C000000002C
00000000000000002C2C2C2C2C2C2C002C00000000000000000000000000000000002C00
002C002C000000000000000000002C00002C2C00002C2C2C2C2C2C002C00002C002C2C2C
2C2C2C00002C00002C2C2C2C2C2C2C00002C00002C2C2C2C2C2C2C00002C49000000002C
002C0000002C2C2C2C2C0000
4949495F5F5F5F5F5F005F5F005F5F00975F005F5F5F97975F97975F979700975F00975F
2C2C2C5F975F5F5F005F5F5F5F5F5F5F5F5F9797977373735FC5975F9797A7A7A7A7A7A7
5F97970097977373735F5F5F5F97C5A7A7A7D4D4D497C597A7A7A7858585737373858585
8585855F5F5F5F5F5F5F975F494949005F5F4949495F5F5F5F5F005F975F5F5F5F979797
9797975F9797A7A7A75F97975F97C55F97975F97975F97975F97975F97975F97975F9797
5F97975F97975F97975F97975F97975F97970097975F975F0097970097975F5F975F9797
5F97975F97975F97975F9797A7A7A75F979797979797C5C59797975F979797C5C59797C5
B6B6B6A7A7A75F97975F97970097975F97975F97975F97979797975F97970097975F9797
0097975F97970097975F5F975F97975F97975F97975F97975F97975F97975F97975F9797
5F97975F97975F97975FC5975F97975F97975F97975F97975F97970097970097975F9797
A7A7A7A7A7A75F97975F97C597979797C5C5B6B6B6A7A7A7A7A7A79797C5A7A7A7A7A7A7
5F97C59797975F97975F97975F97975F97975F97975F97975F979797C597A7A7A7A7A7A7
5F97975F97C55F97C59797C5A7A7A75F97975F97975F97975F97975F97C55F97C55F9797
979797979797A7A7A7A7A7A797C5C5B6B6B697C5C59797C597C5C55F97C5A7A7A75F9797
5F97C5979797A7A7A75F97975F97977373735F5F975F5F5F4949492C2C2C2C2C2C00002C
2C2C2C2C2C2C00002C2C2C2C00002C2C2C2C00002C2C2C2C2C2C2C5F5F5F9797975F5F5F
494949002C002C2C2C000000002C00000000000000000000002C00002C00002C00002C00
002C002C2C2C2C2C2C000000002C002C2C2C002C004900002C2C2C2C2C2C002C002C0000
2C2C2C00002C00002C002C00002C00002C002C2C2C2C2C2C002C00002C002C2C2C2C2C2C
2C00002C0000002C00002C002C2C2C2C2C2C00002C002C00002C002C2C2C002C002C2C2C
00002C00002C00002C2C2C2C2C2C2C2C2C2C00002C0000000000002C00002C000000002C
00000000000000002C002C000000002C2C2C0000000000000000000000002C2C2C2C2C2C
002C002C0000000000002C002C2C2C002C002C2C2C2C2C2C002C002C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C002C00002C000000000000002C000000002C2C000000000000002C2C2C2C
002C004900002C2C2C2C2C2C
5F5F5F005F5F5F5F5F005F5F5F975F005F97005F5F005F5F7373735F5F5F00975F005F5F
5F5F5F4949495F5F005F975F005F5F005F004949495F975F5F97978585855F9797A7A7A7
A7A7A75F975F5F97975F975FC5C5C5B6B6B6979797858585A7A7A75F97977373735F975F
73737397975F5F97975F5F5F5F5F5F005F5F005F5F7373737373738585855F5F5F979797
5F97C5979797A7A7A7979797A7A7A75F97975F97970097975F97975F97C55F97975F9797
5F97970097979797C5B6B6B65F97975F97975F97970097975F97C50097975F97970097C5
0097C55F97975F97970097C55F97975F9797A7A7A75F97975F97C59797C5B6B6B6A7A7A7
97C5C55F97C55F97979797975F97975F97975F9797A7A7A75F97C55F97975F9797858585
5F97975F9797009797A7A7A75F9797A7A7A78585855F97975F97975F97975FC5C5979797
5FC5975F97C55FC5C55F97975F97975F97975F97C55F97975F97979797975F97975F9797
5F97975F97975F97975F97975FC5C55F97979797975FC5C55FC5C55FC5C55F9797A7A7A7
97C5C55F97975F97975F97975F5F975F97975F97C5979797A7A7A797C5975F97975F9797
5F97975F97975F97975FC5C55F97975FC5975F97975F97C55F97C55F97975FC597A7A7A7
A7A7A75F9797A7A7A797C5C5A7A7A797C5C59797C59797C5A7A7A7A7A7A7A7A7A75F97C5
5FC5C55F9797A7A7A75F97970097975F97978585855F5F5F2C2C2C002C00490000490000
2C2C2C2C0000000000000000002C002C00004900002C2C2C2C2C2C4949494949492C2C2C
2C2C2C2C2C2C00000000000000000000000000000000000000000000002C002C00002C00
2C0000002C0000002C002C0000002C00000049000000002C2C2C2C2C2C2C002C00002C00
00000000002C000000002C00002C00002C002C2C2C2C2C2C2C2C2C0000002C2C2C2C2C2C
00002C2C2C2C00002C2C2C2C2C2C2C002C002C2C2C00002C2C0000002C000000002C2C2C
002C0000000000000000000000002C2C2C2C2C2C2C00002C2C2C2C000000002C00000000
000000000000000000002C0000002C002C00002C0000002C0000002C2C2C00000000002C
002C00000000000000002C002C2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C00002C000000
2C2C2C002C002C00000000002C0000002C002C2C2C00002C00002C00000000000000002C
002C00002C002C2C2C002C00
00975F00975F5F5F5F5F975F5F975F5F5F5F5F975F005F5F5F5F5F5F975F5F5F5F5F5F5F
005F5F0073005F975F5F5F5F97975F005F5F4949495F975F5F975F5F5F5FA7A7A7979797
5F97975F975F5F975F5F5F5FB6B6B697C5C597C5C5A7A7A75F97977373735F975F00975F
5F5F5F8585857373739797975F9797737373737373A7A7A7A7A7A7A7A7A7B6B6B697C5C5
A7A7A75F97975F97C59797970097C55F97970097975F97975F97975F97975F97975F9797
5F9797009797C5C5C5A7A7A75F97975F97C597C5C55F97970097975F97970097975F9797
5F97C5B6B6B65F97975F97975F97975F97C597C5C55F979797C5C59797C597C5C59797C5
A7A7A7979797A7A7A7A7A7A797C5C5B6B6B65FC5C5A7A7A7A7A7A75F97C55F97C5A7A7A7
5F97975F97975F97C5A7A7A75F97975F9797C5C5C597C5C5A7A7A75F97975F97975F97C5
5F979797C5975F97975F97975FC5975F97975F97975F97C55F97C5A7A7A79797C55FC5C5
A7A7A75FC5C55FC5C5A7A7A7A7A7A7A7A7A7A7A7A75F97975F97975F97975FC5975F5F97
5F97975F97975F97975F97979797975F9797A7A7A7A7A7A7A7A7A75F97C55F9797979797
979797979797A7A7A79797975F97979797975F97975F97975F9797A7A7A75F97975F9797
A7A7A7A7A7A797C5C55F97C597C5C5B6B6B6B6B6B697C5C597C5C5B6B6B65FC5C55F97C5
5F97C55F97C59797975F97975F97975F97975F5F5F2C2C2C2C2C2C2C2C2C002C00002C00
2C2C2C00002C002C00000000002C0000002C4900002C2C2C2C2C2C2C2C2C2C2C2C002C00
000000002C002C2C2C0000000000000000000000002C00002C00002C2C2C002C00000000
000000002C002C2C2C0000000000004900002C2C2C2C2C2C2C2C2C2C2C2C002C00002C00
000000002C000000002C0000000000000000490000002C002C0000002C002C2C2C2C2C2C
2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C2C00002C000000000000
002C002C000000002C00002C00000049000000002C00002C000000000000000000000000
000000000000000000002C00002C0000000000000000002C00000000000000000000002C
002C0000002C000000002C00002C00002C002C2C2C2C2C2C00002C0000000000002C0000
002C00000000002C00002C0000002C00000000002C2C2C2C0000002C000000000000002C
002C00002C0000002C2C0000
5F5F5F005F5F5F975F5F975F5F975F494949005F5FA7A7A7005F5F005F5F007300494949
5F5F004949495F5F5F005F5F5F9797005F5F5F5F005F5F5F4949495F975F5F5F975F975F
5F975F005F5F5F5F5F4949495F5F975F97975F5F977373735F975F97975F005F5F494949
5F5F5F5F5F005F5F005F5F5F5F97975F9797A7A7A7C5EFC5C5C5EF97C5C5B6B6B69797C5
97C5C55F97C55F97975F97C55F97975F97975F97975F97970097975F97C55F97975F9797
0097975F97975F97C55F97975F97975F97975F97975F9797A7A7A75F97C55F9797979797
5F97C59797C55F97C55F97975F97975F97975F97C597C597A7A7A797C5C597C5C5B6B6B6
C5C5C5C597C597C5C597C5C5B6B6B6C5C5C597C5C55F97C55FC5975F97C55F97975F97C5
A7A7A7A7A7A7A7A7A79797C597C5C5B6B6B697C5C5B6B6B6C5C5C5C5C5C597C5975F9797
979797A7A7A7A7A7A75F97C59797975F97975F97979797975F97C55F97975F97C55FC5C5
A7A7A75F97C5A7A7A7979797A7A7A7979797A7A7A75F97979797975F9797A7A7A75FC597
A7A7A75F97C55F97975F97975FC5C55F97C5A7A7A7A7A7A75F97975F97975F9797A7A7A7
5F97C55FC5C5A7A7A75F97C55F97975FC5975F97C55F97975F9797A7A7A75FC5C5A7A7A7
A7A7A797C5C55F97C5A7A7A797C5C597C5C5B6B6B697C5C5A7A7A79797C5A7A7A75F97C5
5FC5C5A7A7A75F97975F97975F97975F5F97005F5F2C2C2C2C2C2C00002C2C2C2C2C2C2C
49000000002C002C000000000000002C0000002C00002C002C2C2C2C2C2C2C2C2C000000
2C0000002C00002C002C000000002C0000002C00002C00000000002C2C2C00002C000000
000000002C002C2C2C2C2C2C2C2C2C002C004900002C2C2C002C00002C000000002C2C2C
2C2C2C0000002C000000002C2C000000002C00002C002C00002C002C2C2C000000000000
2C2C2C2C2C2C490000002C002C2C2C2C2C2C002C0000002C00002C000000000000000000
002C00002C002C2C2C2C2C2C2C2C2C00002C00002C2C0000002C00002C002C2C2C000000
00000000000000000000002C000000002C002C00002C00000000000000000000002C0000
2C2C2C2C2C2C000000002C0000002C00000000002C00002C2C2C2C2C000000002C002C00
000000002C00000000000000000000000000002C00002C000000002C2C2C2C2C2C2C2C2C
2C2C2C002C002C2C2C002C00
5F5F5F5F5F005F5F000073005F5F5F5F5F5F5F975F5F97000049000085005F5F5F5F5F5F
5F5F5F5F975F5F5F5FA7A7A74949495F5F5F4949497373737373737373739797975F975F
975F5F5F5F5F005F5F0073004949497373735F975F5F5F5F5F975F5F5F5F494949007300
5F5F5F5F5F5F7373739797975F9797A7A7A75FC5C597C5C597C5C55F979797C597A7A7A7
5F97C597C5C55F97C55F97975F97970097975F97C55F9797A7A7A75F97975F9797858585
5FC5C5A7A7A75FC5C55F97C5979797A7A7A75F97975F97975F97C55FC5C59797975F9797
979797979797A7A7A7A7A7A75F97C55F97975F97C55F97C55F97C5A7A7A7B6B6B6B6B6B6
A7A7A797C5C5A7A7A7979797A7A7A79797C597C5C5A7A7A7A7A7A797C5C55FC5C59797C5
A7A7A7B6B6B6C5C5C5C5C5C5C5C5C5C597C597C5C597C5C5C5C5C5C5C5C5B6B6B6979797
979797A7A7A75F97C55F9797A7A7A75F97C55FC5C50097975F9797A7A7A75FC5C597C5C5
97C5C5B6B6B6A7A7A7A7A7A79797979797C55FC5C55F97975F97975F97C5A7A7A75F9797
5F97975F97C5A7A7A797C5C55F97C597C597A7A7A75F97C55FC5970097C55F9797A7A7A7
9797C55F97975F97975F97975F97975F9797A7A7A75F97C59797975F97C5A7A7A7A7A7A7
A7A7A797C5C59797C597C5C59797C59797C5B6B6B6B6B6B697C5C597C5C5A7A7A7A7A7A7
5F97C59797C55F97975F97978585855F5F97005F5F002C00002C002C2C2C490000002C00
002C004900002C2C2C00000000000000002C2C2C2C002C0000002C2C2C2C002C002C0000
002C00002C002C2C2C002C00002C002C2C2C002C002C2C2C2C2C2C0000000000002C0000
002C00002C00002C002C0000002C00002C00002C00002C002C2C2C2C2C2C0000002C2C2C
00002C002C002C00002C2C2C2C2C2C000000002C00002C00002C002C00000000002C2C2C
2C2C2C002C002C2C2C2C2C2C2C2C2C2C2C2C002C00000000002C000000002C00002C0000
00002C000000000000002C0000002C2C2C2C0000002C0000002C00002C00002C00000000
0000002C00002C2C2C2C000000002C002C00002C00002C002C000000000000002C002C00
002C002C2C2C002C00002C002C2C2C0000000000002C2C2C00002C002C00002C00000000
000000002C000000000000000000002C0000002C0000002C002C00002C002C2C2C000000
002C0000000000002C000000
5F5F005F5F005F5F004949495F5F5F494949005F5F49494949494949494973737397975F
4949495F5F5F5F5F5F9797975F975F5F5F004949494949498585858585859797C55F9797
5F5F5F5F5F5F5F975F005F5F5F5F5F975F5F4949495F97974949495F5F5F005F5F5F5F5F
5F5F5F5F5F9797C5C5C5C5C5A7A7A79797975F9797B6B6B69797975F975F5F9797858585
5F97975F97979797C55F97970097970097979797975F97C55F97975FC5975F97975F9797
9797975F97C55F97C55F97C597C5C55FC5C55FC5C55F97C55F97975F9797A7A7A75F97C5
5F97C55FC5C55F97C59797C59797975F97C59797970097C55F9797979797A7A7A797C5C5
B6B6B697C5C597C5C597C5C5B6B6B697C5C59797C5A7A7A75FC5C5C597C597C5C597C5C5
9797C5B6B6B6B6B6B6B6B6B697C5C597C5C5A7A7A7B6B6B697C5C5B6B6B6B6B6B65F97C5
A7A7A75F97C597C5C5A7A7A7A7A7A75FC5C55F97C55FC5C55F97975F97C55F97979797C5
97C5C5A7A7A7B6B6B6A7A7A797C5C5A7A7A7A7A7A7979797A7A7A75F97C55F97C55F97C5
5FC5C59797C597C5C55F97C59797C5A7A7A7A7A7A7A7A7A75F97975F97975F979797C5C5
B6B6B6A7A7A79797979797975F97975F97975F97C5979797A7A7A7A7A7A7A7A7A75F97C5
97C5C55F97C5A7A7A79797C597C5C597C5C597C5C5A7A7A797C5C55F97C597C5C5979797
979797A7A7A75F97C55F97977373735F5F5F4949492C2C2C002C002C2C2C00002C002C00
00002C2C2C2C490000002C0000000000000000002C2C2C2C2C2C2C002C00000000002C00
002C002C0000490000002C00002C00000000000000002C0000002C2C0000002C00002C00
0000002C2C2C2C2C2C002C00002C00002C002C2C2C2C2C2C002C0000002C2C2C2C00002C
00002C002C00002C0000002C00002C2C2C2C490000002C00002C00002C000000002C2C2C
002C00005F5F00002C2C2C2C2C2C2C2C2C2C002C000000000000002C2C2C494949000000
00002C2C000049000000002C4900002C2C2C002C00002C000000002C2C2C00000000002C
00000000002C00000000002C0000002C0000002C00002C0000000000000000002C2C0000
00002C00002C002C0000000000000000000000000000000000002C2C2C2C002C002C2C2C
002C002C00002C00000000000000002C2C2C00002C2C2C2C002C00000000000000000000
000000002C00002C00000000
5F5F5F00975F4949495F5F005F975F005F5F2C2C2C97975F494949005F5F97C5C597C597
5F5F5F5F5F975F97979797C597975F5F5F5F5F5F5F97C5C55F9797A7A7A7C5C597494949
5F5F5F5F5F5F005F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F975F5F5F5F7373735F5F5F
858585737373A7A7A7A7A7A7A7A7A773737397979797979797C5C57373735F9797979797
A7A7A75FC5C597C5C5A7A7A75FC5C55F97975F97975FC5975FC5C55F9797A7A7A75F9797
9797C597C5EFB6B6B697C5C597C5C597C5C55F97C55F97C59797978585855F97C55F97C5
5F97975F97975F97C5A7A7A7D4D4D4A7A7A7A7A7A75F9797A7A7A75F97C55F97C5979797
97C5C5C5C5EFB6B6B6C5C5C59797C597C5C5B6B6B65F97C59797C597C5EFC5C5EF97C5C5
97C5C597C5C5B6B6B697C5C597C5C597C597A7A7A75F97C55F97975F97C55F9797B6B6B6
C5C5C597C5C5A7A7A75F97C55F97C5B6B6B65F97C55F979797C5C59797C5A7A7A797C5C5
5F97979797C597C5C5A7A7A79797C5979797A7A7A75F9797A7A7A75F97975F97C55F9797
979797A7A7A797979797C5C59797C55FC5C55F97975F97C55FC5C59797975FC5C5979797
A7A7A7979797A7A7A75F9797A7A7A75F97C55F97975F97C5A7A7A797C5C597C5C5A7A7A7
9797975FC5C5A7A7A75F97C5B6B6B697C5C597C5C597C5C597C5C597C5C55FC5C55F97C5
A7A7A7A7A7A75F9797005F975F5F974949492C2C2C002C004900002C2C2C00002C2C2C2C
2C2C2C2C2C2C00002C0000002C000000002C2C2C2C2C2C2C2C0000000000000000000000
0000002C2C2C00002C2C2C2C002C002C000000000000000000000000000000002C000000
0000002C2C2C2C2C2C00000000002C2C2C2C2C2C2C002C0000000000002C2C2C2C00002C
2C00002C2C2C000000002C00002C002C2C2C002C002C2C2C2C2C2C2C2C2C0000002C0000
00002C00000000000000002C2C2C2C000000002C00000000002C002C2C2C000000000000
2C2C2C00002C00002C00000000002C00002C00002C000000000000002C002C000000002C
00002C00002C2C2C2C00000000002C002C002C000000002C002C0000000000002C00002C
2C2C2C00002C002C002C000000002C4900002C0000002C0000002C000000002C00002C00
2C2C2C00002C002C000000002C0000002C002C2C2C2C2C2C002C002C0000000000000000
002C000000002C00002C0000
4949495F5F005F5F005F5F005F5F5F494949494949494949005F5F4949495FC5C5737373
7373737373735F9797A7A7A75F97975F975F5F97975F97975F97975F5F5F975F5F979797
8585855F975F5F5F5F5F975F5F5F00005F5F494949005F5F5F5F5F737373737373005F97
8585857373735F97975F97975F97977373739797975F9797B6B6B6B6B6B65F97975F9797
5F97974949495F5F5F5F97975F5F9797C5C55F97975F97975F97C55F97C55F979797C5C5
9797C59797C59797C5B6B6B69797C55F97970097975F97C5A7A7A79797C55F97C55F97C5
5F97C55FC5C59797C55F97C55F9797A7A7A7979797A7A7A75F9797A7A7A79797975F9797
5F97C5B6B6B6C5C5C597C5C5C5C5C5C597C597C5C597C5C5C5C5EFB6B6B6B6B6B697C5C5
C5C5C597C5C5A7A7A7A7A7A75FC597A7A7A79797975F97975F97C55F97C597C5C5B6B6B6
5FC5C55FC5C5A7A7A75FC5C55F97975F97C597C5C55F97C55F97C55F97C55F97975F9797
5F97C5858585A7A7A797979797C5C59797975F97975F97975F97C55FC5C55F97C55FC5C5
A7A7A797C5C5A7A7A75F97C55FC5C55FC5C55F97C5A7A7A75F97975F97979797975F97C5
5F97978585855F97975F97C55F9797A7A7A75F97C55FC5C597C5C59797C55F97C59797C5
A7A7A7A7A7A7A7A7A7A7A7A7B6B6B697C5C597C5C597C5C5A7A7A7979797A7A7A7A7A7A7
5F97975F97C5005F97005F97005F5F2C2C2C002C002C2C2C00002C2C2C2C2C2C2C2C2C2C
00002C002C0000002C002C00002C0000000000002C0000002C0000002C00000000000000
2C00002C2C2C2C2C2C000000002C000000000000002C0000002C002C2C2C2C2C2C00002C
002C002C2C2C002C000000002C000000002C00002C2C2C2C49000000002C002C00490000
002C002C2C2C0000002C2C2C002C002C2C2C002C002C00000000002C00002C2C2C2C2C2C
2C2C2C2C2C2C0000002C2C2C4900002C00002C2C2C2C2C2C2C2C2C00002C2C0000002C00
00002C00002C2C2C2C2C2C2C2C2C2C0000000000000000000000002C000000002C2C2C2C
2C2C2C002C0000002C00002C00002C002C002C000000002C0000000000002C2C2C00002C
00000000002C002C00002C0000002C00002C00002C00002C2C0000002C002C2C2C002C00
00002C00002C00002C00002C2C0000002C00002C00002C000000000000002C0000000000
2C000000002C73737300002C
5F5F5F4949494949495F5F5FA7A7A77373735F5F00005F5F5F97C55F5F5F005F5F5F975F
4949495F97975F97977373735F97C58585855F975F5F5F005F5F5F5F975F858585A7A7A7
A7A7A75F5F5F4949495F5F5F5F975F5F5F5F5F5F5F5F5F5F9797975F97975FC5C5A7A7A7
979797A7A7A79797975F97975F979797C5C597C5C55F979797975F5F5F5F737373005F5F
5F5F005F975F005F5F5F97975F97970097979797C5A7A7A75FC5C5A7A7A75FC5C55F97C5
5F97C5A7A7A7A7A7A75FC5C55F9797005F9700975F005F975F97975F97C55F97C597C5C5
97C5C5B6B6B65F97C55F97975F97C55FC5C597C5C597C5C5B6B6B65F97C55F97C597C5C5
9797C597C5C5A7A7A79797C5B6B6B6C5C5C597C5C597C5C5B6B6B6B6B6B69797C597C5C5
C597C5B6B6B6A7A7A75F97C55F97C59797975FC5C55F97975F97C59797C5B6B6B697C5C5
B6B6B6A7A7A7B6B6B69797C59797C55F97C50097C5A7A7A79797C597C5C55F97C55FC5C5
5F979797C5C55F97C597C5C55F97C55FC5C55F97975F97975F97975F97C597C5C5A7A7A7
9797C5A7A7A7A7A7A75F97975F97975F9797A7A7A7A7A7A75FC5C55F97C55FC5C55F9797
5F9797A7A7A75FC5C59797979797979797C5A7A7A75FC5C5A7A7A70097C55F97C55F9797
5F97C5A7A7A75F979797C5C59797C5B6B6B6A7A7A75F97C597C5C597C5C5979797A7A7A7
5F97C55F97975F9797005F5F4949492C2C2C2C000000002C2C2C2C00002C0000002C2C2C
00000000002C002C00002C00002C002C000000000000000000002C00002C002C00000000
002C0000002C2C2C2C002C00000000002C002C2C2C002C00002C00002C00002C00000000
00000000000000000000002C00000000002C00002C2C2C2C00002C2C2C2C002C00002C00
002C002C2C2C002C0000002C2C2C2C002C0049000000002C2C000000002C2C2C2C2C2C2C
2C2C2C002C0000002C2C2C2C002C002C2C2C2C2C2C2C2C2C00002C49000000002C002C00
2C2C2C00002C2C2C2C2C2C2C2C2C2C002C002C00000000002C000000002C00002C00002C
00002C00002C0000000000000000002C2C2C00002C000000000000000000000000000000
2C2C2C00002C00000000002C00002C00000000000000002C00002C2C00002C2C2C002C00
0000000000002C000000002C000000002C00002C002C2C2C002C000000002C0000002C00
002C00002C002C2C2C002C00
5F5F007373735F5F5F5F5F00A7A7A797975F858585737373975F975F5F975F975F979797
0049005F5F977373735F5F5F975F5F007300005F00005F005F5F5F4949497373735F5F97
A7A7A75F975F5F5F5F4949495F5F5F858585737373A7A7A79797975F97975F979797C5C5
C5C5C55F97975F9797975F97B6B6B673737349494997975F4949495F5F5F494949494949
7373734949495F97975F975F005F5F5F97975F97C55F97975F97975F97975F97975FC5C5
5F97975F97975F97975F5F9700975F005F5F7373735F5F970097975F97975F97C55F97C5
97C5C597C5EF97C5C59797975F97975F97975F9797B6B6B6A7A7A75F97975FC5C55F9797
5FC597A7A7A7A7A7A7A7A7A79797C597C5C597C5C597C5C597C5C5A7A7A79797C5B6B6B6
B6B6B6B6B6B6A7A7A75F9797A7A7A70097975F97975F97975F97975F97975F97975F97C5
A7A7A797C5C597C5C597C5C597C5C5A7A7A75F97C55FC5C55FC5C5A7A7A75F97975F97C5
5FC5C55F97C55F97979797975F97975F97975F97975F97975F9797A7A7A797C5C59797C5
5FC5C55FC5C55F97975F9797A7A7A75F97C55F97C59797975F97975F979797C59797C597
A7A7A79797975F97975F97975FC5C55F97C5A7A7A75F9797A7A7A75F97C55F97C55FC5C5
5F97979797975F97975F9797B6B6B697C5C59797C597C5C5A7A7A7A7A7A7A7A7A7979797
5F5F97737373009797005F5F4949492C2C2C2C2C2C002C00002C00002C002C2C2C002C00
00002C2C00002C2C2C2C2C2C002C00002C0000002C2C2C2C2C2C2C2C2C2C2C0000002C00
000000002C00002C002C2C2C002C00002C002C2C2C00000000000000000000002C000000
00000000002C2C2C2C00002C002C00002C00002C00002C00002C00002C00002C00002C00
00002C002C002C2C2C49000000002C2C2C2C00002C00002C00000000002C2C2C2C002C00
002C00002C0000002C002C002C2C2C002C002C2C2C2C2C2C000000002C00000000000000
2C000000002C2C0000002C00002C00002C00002C002C2C2C2C2C2C002C000000002C2C2C
2C000000002C002C002C0000002C0000002C2C2C2C0000002C0000002C00000000000000
00002C00000000000000002C2C000000000000000000002C00002C2C2C2C002C00000000
2C0000002C002C2C2C000000000000002C0000002C000000002C005F5F5F2C0000002C00
000000002C00002C00000000
0073005F5F5F5F975F5F5F5FB6B6B65F5F5F97C5978585857373735F9797737373737373
5F5F5F7373739797975F5F5F5F5F5F494949005F5F4949495F5F5F5F5F5F5F5F97979797
9797975F5F5F4949495F5F5F7373735F5F005F5F5F858585B6B6B697979797C5C597C5C5
C5C5C597C5C5A7A7A75F97979797974949495F5F5F005F5F2C2C2C494949494949494949
494949494949005F5F85858597C5975F5F5F494949005F5F5F97975F97975F97975F9797
5F97975FC5970097975F97C5A7A7A75F5F975F5F5F5F5F97005F975F97975F9797009797
9797C597C5C5A7A7A75F9797A7A7A75F97975F97979797979797C5A7A7A75F97C55F9797
5F97979797975F97975F97975F9797C5C597979797B6B6B6A7A7A7A7A7A797C5C55F97C5
9797C55F97C55F97C55F9797A7A7A75F97975F97975FC5975F97975F97975F9797009797
0097975F9797A7A7A7B6B6B6B6B6B6B6B6B65F97C55F97979797C59797C59797C5A7A7A7
5F97975F97979797979797975F97975F97975F97975F9797009797A7A7A79797C597C5C5
A7A7A75F97C5005F97005F970097975F97975F97975F97975F97C55F97C5979797A7A7A7
9797979797979797979797979797975F97975F97C597C5C55F97C55F97C55FC5C55F97C5
5F97C55F97979797C5A7A7A797C5C5A7A7A797C5C59797C5A7A7A75F97C59797975F97C5
5F97975F97975F9797005F5F2C2C2C2C2C2C2C2C2C000000000000490000002C002C2C2C
002C002C00002C2C2C0000000000002C2C2C2C2C2C2C2C2C002C00002C00002C00490000
002C00002C002C2C2C2C2C2C00002C2C2C2C00002C0000000000000000000000002C0000
00000000002C00002C00002C002C0049000000002C00002C2C0000002C005F5F002C0000
2C2C2C2C00002C2C2C00002C002C002C2C2C00002C2C0000002C00000000002C002C2C2C
00002C2C2C2C00002C2C2C2C002C00002C00000000002C00000000002C002C2C2C490000
00002C2C2C2C2C2C2C2C2C2C0000002C000000000000002C2C2C2C002C000000002C2C2C
00002C000000000000000000002C002C2C2C00002C2C2C2C000000002C00000000000000
2C0000002C0000000000002C00002C00000000002C00000000002C737373002C00002C00
002C002C000000002C2C2C2C0000002C2C2C000000000000002C0000002C00000000002C
2C2C2C002C002C2C2C000000
2C2C2C005F5F5F975F737373005F5FA7A7A7A7A7A7858585A7A7A7B6B6B65F97975F5F5F
4949498585855F975F4949495F5F5F005F5F5F5F5F5F5F005F5F5F858585979797A7A7A7
5F9797A7A7A75F5F005F5F5F5F5F5F005F5F4949495F975F5F97975F9797737373B6B6B6
97C5C5737373737373C5975F5F5F005F5F5F494949494949005F00005F004949495F5F00
4949495F5F5F5F5F5F5F5F5F5F5F5F494949494949005F5F5F5F5F5F5F975F975F5F9797
5F9797A7A7A75F97975F97975F5F5F005F5F5F5F5F5F5F5F5F97975F975F5F9797009797
5F97C55F97C5B6B6B6B6B6B65F97975F97978585855F97C55F97C55F97975F97975F97C5
97C5C59797975F97979797975F97975F979797C597A7A7A7B6B6B6A7A7A7A7A7A7A7A7A7
9797975F9797A7A7A75F97975F97975F97975F97975F5F975F9797005F970097C55F9797
5F97C59797C5C5C5C597C5C5C5C5C597C5C55FC5C55F97C55FC597A7A7A7979797A7A7A7
5F97C55F97975F97C55F97975F97975F97975F97975F9797A7A7A797C5C55FC5C59797C5
5F97975F97975F97975F97975F97975F97975F97C55F97975F9797979797A7A7A7A7A7A7
A7A7A75F97C55F9797A7A7A797C5975F97975F97978585859797C55F97C55F979797C5C5
5F97975FC5C597979797C5C597C5C597C5C55F97C55F97975F97C55F9797A7A7A7979797
0097975F97975F5F974949492C2C2C2C2C2C2C2C2C002C002C2C2C00002C2C000000002C
002C00002C002C2C2C000000002C00002C0000002C002C002C2C2C002C002C2C2C002C00
00002C2C0000002C002C2C2C000000002C0000002C2C00002C00000000002C0000002C00
002C002C2C2C00000000002C002C00002C002C000000002C000000000000000000002C00
002C00002C00000000000000002C002C2C2C2C2C2C002C00002C00002C002C2C2C2C2C2C
00002C2C2C2C00002C2C2C2C2C00002C2C2C00000000002C00002C00002C2C2C2C00002C
49000000002C2C2C2C2C2C2C2C2C2C002C002C000000002C00002C00000000002C00002C
00002C002C002C2C2C00000000000000002C0000000000002C2C2C00000000002C2C0000
00002C2C2C2C00000000000000002C2C000000002C00002C0000005F5F5F000000002C00
000000002C00000000002C00002C00002C000000002C0000002C0000000000000000002C
2C2C2C002C00000000000000
4949495F5F5FB6B6B6A7A7A75F5F5F5F5F5F5F9797A7A7A797C5C5A7A7A75F9797737373
B6B6B697C5C57373735F5F5FB6B6B6858585975F5F4949498585855F5F5F975F5F5F97C5
9797975F9797858585737373005F5F7373735F5F5F4949495F5F5F005F5F9797975F9797
005F5F494949A7A7A75F5F5F4949495F5F5F4949495F5F005F975F5F5F5F5F5F5F5F9700
5F5F00005F5F005F5F005F5F5F975F4949492C2C2C0049005F5F5F005F005F975F005F5F
0097975F97977373735F975F005F5F005F5F5F5F5F005F5F5F5F975F5F975F5F5F5F9797
5F97975F97C59797C5C5C5C5B6B6B65F97975F97975F97975F97975F97975F97975F9797
5F97975F97975F97979797975F97975F9797A7A7A7979797979797A7A7A797C5C55F97C5
5F97975F97975F97C55F97975F97975F97975F97975F97975F97975F979700975F009797
5FC5C55FC5C5A7A7A797C5C59797C597C5C597C5C5B6B6B6A7A7A7A7A7A7A7A7A75F9797
A7A7A79797C597C5C55FC5C55F97975F979797C5C5B6B6B697C5C59797C55F97C5979797
0097970097975F9797005F970097975F97975F97975F97975F97979797979797C55F9797
5F97979797975FC5975F97C55F97975FC5C5A7A7A79797979797C5A7A7A7A7A7A7979797
A7A7A7A7A7A7A7A7A7A7A7A7B6B6B69797C55F97C55FC5C5A7A7A75F97C55F97975F9797
5F5F975F9797005F5F2C2C2C2C2C2C2C2C2C002C00002C002C2C2C002C002C000000002C
00002C2C2C2C2C2C2C2C0000002C004900002C2C2C00002C2C0000002C002C2C2C2C2C2C
2C00002C00000000000000002C000000002C00002C2C000000002C2C000000002C2C2C2C
002C002C2C2C002C00002C002C0000002C002C000000002C00002C00002C00000000002C
0000002C000000002C002C000000002C2C2C002C0049000000002C002C002C2C2C00002C
490000002C002C2C2C00002C00002C2C2C2C2C2C2C002C0000002C2C2C2C2C2C2C2C2C2C
00002C2C2C2C2C2C2C2C2C2C002C002C2C2C002C0000000000002C00002C00002C2C2C2C
2C2C2C0000002C2C2C002C000000005F5F5F00002C0000492C2C2C000000002C002C0000
00002C2C2C2C00000000000000002C00000000002C002C00002C002C000000002C2C2C2C
002C000000002C00000000002C2C2C2C2C2C00002C5F5F0000002C2C0000000000000000
002C00000000000000000000
5F975F5F5F5F5F5F5F858585A7A7A75F975F5F5F5F9797C59797975F97975F5F5F737373
A7A7A797975F5F5F5F5F5F5F5F975F005F5FA7A7A75F97978585857373735F5F97A7A7A7
A7A7A7A7A7A7979797737373005F5F5F975F005F5F4949495F5F005F5F5F4949492C2C2C
5F5F002C2C2C494949494949005F00494949005F002C2C2C5F975F005F5F5F5F5F005F00
0073005F5F5F5F5F5F5F5F5F4949494949495F5F5F004900494949005F5F005F5F5F975F
7373735F5F5F5F5F5F5F975F5F5F5F5F5F5F005F5F005F5F5F5F5F5F97975F97975F5F97
5F9797B6B6B69797C55F9797B6B6B65F97975F97975F97975F97975F97975F97975F9797
5F9797979797A7A7A75F97975F97975FC5975F97975F97C55FC597979797A7A7A7979797
5F97975F97975F97975F97975F97975F97975F97975F97975F97C55F97970097975F9797
5F97C55F97C597C5C597C5C5C5C5C5B6B6B697C5C597C5C5B6B6B6A7A7A7A7A7A7A7A7A7
5F97975F97975F97975F97C55F9797B6B6B697C5C55FC5C55F97975F97975F97C55F9797
5F97970097975F97975F97975F97975F97975F97975F97975F9797A7A7A797C5C5A7A7A7
A7A7A75F97979797975F97975FC5C5A7A7A7A7A7A7A7A7A7A7A7A7A7A7A797979797C5C5
B6B6B6B6B6B6A7A7A79797C597C5C55FC5C55FC5975F97C5A7A7A75F97975F97975F975F
5F97975F5F5F494949002C002C000000002C00000049000000002C49000000002C000000
2C0000002C0000002C2C0000002C0000002C2C2C2C002C002C2C2C002C002C2C2C002C00
002C0000002C2C00002C00002C000000002C00002C2C2C2C00002C00002C2C2C2C002C00
2C2C2C002C00002C00002C000000002C2C2C00002C00002C2C000000002C000000000000
2C2C2C2C2C2C2C00002C00002C2C2C2C2C2C00002C00002C2C2C2C2C2C2C00002C494949
2C2C2C2C2C2C2C2C2C2C2C2C00002C2C2C2C2C2C2C2C2C2C002C00002C00002C002C2C2C
002C002C2C2C00002C00002C002C00000000002C002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
000000000000000000002C00000000000000000000979797C5C597002C002C000000002C
002C002C00002C000000002C0000002C2C2C2C000000002C0000002C2C2C002C0000002C
00000000000000002C000000000000000000002C00A7A7A72C2C2C00002C000000000000
00000000000000002C000000
5F5F5F5F975FA7A7A75F97975F975F7373735F975F5F97979797975F97975F5F5F494949
5F97975F5F5F0073004949494949495F5F5F005F5F737373C5C5EF5F9797A7A7A75F5F5F
5F9797A7A7A78585858585855F5F5F494949494949005F005F5F5F5F5F5F2C2C2C002C00
5F5F5F5F5F5F4949495F5F005F5F5F4949495F5F005F5F5F005F5F005F5F0073005F5F5F
5F5F5F005F5F5F97005F5F5F5F5F004949495F5F005F5F00007300005F5F5F5F00494949
005F5F494949005F5F0097975F975F5F975F005F5F005F5F5F5F5F5F5F978585855F9797
5F97975F97C5A7A7A7A7A7A797C5C55F97C59797975F97975F97975F97975F97975F9797
9797C55F97C597C59797C5975F97C58585855F9797005F975F97975F9797979797A7A7A7
9797975F97975F5F975F97975F97975F97975F97975F97975F97C50097975F975F009797
5F9797A7A7A7A7A7A7B6B6B6B6B6B69797C597C5C59797C55FC5C5A7A7A7B6B6B6B6B6B6
B6B6B6A7A7A75FC5C55FC5C55FC5C5A7A7A797C5C55FC597A7A7A79797975F5F975F9797
5F97975F97975F97970097975F5F975F97975F97975F9797A7A7A7A7A7A75F9797A7A7A7
A7A7A79797975FC5975F97C5979797858585A7A7A75FC5C5A7A7A75F97C597C5C5B6B6B6
B6B6B65F97C59797C59797975F97C5979797979797A7A7A75F97C55F97977373735F9797
005F97005F5F4949492C2C2C2C2C2C2C2C2C2C0000002C00002C000000002C2C2C000000
0000002C000000002C00002C00002C002C000000002C2C2C2C2C2C2C2C2C2C2C2C2C2C2C
2C2C2C2C2C2C00002C000000002C002C0000002C00002C002C2C2C2C2C2C2C2C2C2C0000
2C2C2C0000002C000000002C00002C00002C0000002C00002C0000000000000000000000
002C002C2C2C2C0000002C00002C00002C002C00000000002C2C2C002C00490000002C00
2C2C2C002C00002C00002C00002C002C00002C00002C00002C2C2C002C00002C002C0000
2C00002C00002C0000000000002C002C00002C0000002C00002C00002C002C2C2C002C00
002C002C00000000002C00000000002C00002C0000000000494949000000000000002C00
000000002C000000000000002C00002C000000002C000000002C00002C005F5F5F2C2C2C
2C0000000000000000002C00002C00002C00002C00002C00000000002C00000000002C00
000000000000000000002C00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{216.125, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004>0001Ib000`400?l00000o`00003oooooool?
ooooo`00ooooool?ooooo`00ooooool?ooooo`00ooooool?ooooo`00ooooool?ooooo`00ooooool?
ooooo`00ooooool?ooooo`00ooooool?ooooo`00ooooool?ooooo`001_ooool02`2GaIL0aLG50<G5
U`2n_ZL0UiNG05mOG`2GUiL0olG50>o5a@0/;2`09@0F0080000/0`0/;2`04`25QHD0ZZZZ02`/;000
0000;00004T000000000;2`/02DF002GaLD0aNo_0?o_a@35UiL0][Jf0<FGU`3RklD0ono_0>o5a@3o
olD00P0/;2`20000;00@02D05P00Gel0GemO05nGG`3oklD0;2`/000/000F5R`002`005nGU`35aLD0
aNo_04U9B@1OGel0f/F^0;Jf]P80aLG_00H002`002`0000/;2`05R`F07=cL`0/;2`209NGU`0L02`/
;00002`0`l>^02`/;000;000GiNG0<G5a@0002`0;000071SC01OaLD0UiNG05mO000/;2`0GemO02`/
;01YJFT0GiNG001OG`1OGel0aNo505mO0000;000JVYZ09NGG`1OUel0BDU902`/;080000000`0;000
02`/;02WYjL0UiMO0<G5U`1OGel002`00000000001H0;2`/000/00000002000/000=02`/;02UYJD0
kno502`/;019BDT0;2`/05mOG`35aEl0[W]O0<G5U`3oonl0GemO05nGG`04000/000902`/;0000000
;2`/0000B@25QHD0E71D0?o_k`3oolD0GemO0080BDU901X0UlFG0=WIf@0002`0000/02`/;00002`0
GemO0?ook`0F5R`0;2`/0000B@2GUiL0YjNW05mOG`35aIL0HV960<G5a@000000000/05nGG`2GUel0
Lg=c05A`L02GaLD0Gel008F5Q@8002`00P0/;2`0203Xj>P0Gel0001OG`25QHD0UlG50?ook`1OUiL0
AV961@0/;2`01@2f][H0[Zik0<G_a@3oonl0o?cl00<0hN7Q00@0ATHF05mOG`2GUiL0GiMO0P19BDT0
301cLg<0dm?C0>o5a@1cLg<0000/02`/;000;000000001HF;00/;2`0ono_0?ooo`80;2`/01000000
01HF0000B@00GiMO0;Jf]P35aIL002`004U9B@0U9BD0GiMO02`/;019BDT0Lg=c09NGU`00;000HV9R
0P1OUiL0302WYjL0;2`/02`/;000Gel0aLG501I65P0/;2`0aNo_0>7Qh@2GaIL0aLG_0>ooa@80;2`/
0100kno5001OG`00;00002`00=CDe02U`ZD005l00>o5a@35klD0e=CD0<G_a@3_knl0D51@02`/;01O
05l0GenG2?ooool000Kooooo00/0][Jf05l0G`0/;2`0000F02`/;0190000;2`/0:NWY`2f][H0;2`/
01HF;00302`/;0070000;01OUel0BDU90>:W``0/;2`0B@00000/000202`0000<0000;00F5S/0UiNG
09O5a@3oknl0ono50>o_a@35aLD0HTI608F5Q@35knl0aNo50`0/;2`03@0/00005QHF07=cL`2GGel0
kno_09MOG`000000;2`/01HF0000000005mO09O5a@3_klD00P3QhN40103Xj>P0ono50?ook`35aLD2
000/000602`/;00F5R`0UiMO05nGa@2f][H0;2`/0P00;000202L/I`0BDU90000001OUlD0aNo5000/
00000000JVYZ0P0/;2`0402f][H0BDU905nGG`19BDT0<5mO02`/;000;00005mO0:NWY`3oknl0Gel0
000F002WYjL0aLFG07=cL`19BDT202`/;009000/000/;2`0;2`/09NGU`35aIL0aIMO05nGG`00;000
5R`F008002`001H0000002`/;000;00002`00;6aW035aIL0kno50;Jf]P2WYjL0aIMO07=cL`1OGel0
YjNW0<G5U`3oolD0;2`/07=cL`00;0005P00000/000/;2`0GemO0P1cLg<02`0/;2`0VYZJ0?o_a@3_
klD0klG50>o_a@3_onl0YjNW01HF;00/;2`0000/0080;2`/01D0ooo_0<FGU`0F5R`0BDU90:NWY`1O
Uel0UemO05mOG`0/;2`0HWUR0:NWY`0/0000000/000/001OUiL0UiNG09N^N`2f][H0;2`/001OG`2G
Uel00P00;0002@0/;2`0SXj>0;Jf]P3oonl0koo50?o_k`3okol0;2`/07^GN`02000/000702`00019
0000000/09NGU`3ommX0ono_0<G5a@0209NGU`0504U9B@1cLg<0`ZFU09O5U`1OGel00P0/;2`00`2W
YjL0ono5075aL@0302`0000;04T000000000000001HF5P19BDT0aLG50?ook`00Gel0001905mOG`0j
JFT00P2GUiL0400/;2`0001902`/;00/;2`05THF04U9B@1OUiL0][Jf0019002WYjL0;2`/04aSQ`2f
][H0GiNG08F5Q@19BDT202`/;00J0=CDe00U9DT0;2`/0>ooo`3De=@0hN7Q0>o_k`2GUel0<30F04U9
B@3_aLD0GemO0000B@0/;2`0GenG0<G5a@1cLg<0hN7Q09NGG`19BDT0o?cl0?o_k`1@D50002`002`/
;01OGel8ooooo`001_ooool04P0/;2`0000/0000;00002`0B@0002`/;00002`0klG50>o_a@1cLg<0
;2`/0000;000Gel0BDU905mOG`2GGel0UlG509IiSP80000/0`00;000300/;2`0D51@05mOG`35aLD0
klG508F5Q@0/;2`0B@0001HF;000Gel0][Jf0<G5U`80;2`/01@0B@000000;00/;2`0GemO05o5U`3Q
hN40;2`/02`0000/;2`05R`F02`/;01cLg<0BDU90<G_k`35aNl0BDU902`/;000Gel0UlG50=CDe0<0
;2`/00D0<69<0000;02GaLD0YjNW000/000202`/;00<04bBTP3_aIL0GemO0<G5a@35knl0;2`/0000
;027Hf<0B@00000/001OGel0UlFG0P19BDT0200F;1H002`002`/;00002`0GiMO0:NWY`2f][H0NHiR
0P0002`20:NWY`0305mO0019BDT05S/F0080000/00l0;2`/0:NWY`35aIL0Uel007=cL`0`Gc00GemO
000/000/;2`0000/02`/;019BDT0][Jf0>o5a@0/00000`0002`05`00;000000F0000;02WYjL0][Jf
0?o_a@19BDT0Lg=c0316001cLg<0GiNG08F5Q@00L`00UiNG0?o_a@3gf/D0;2`/0>7Qh@3oklD0YjNW
000/000002`05QH/008002`000h004T00;Jf]P3oknl0;2`/04aRC035klD0aING000/002GaEl0;000
04U9B@13FD<0GemO02`/;08002`000P0GemO0;Jf]P3Cj?00kno_0>7Qh@2GaEl0BDU90:NWY`<0;2`/
00X0kno_0>o5a@2f][H0][Jf09MOU`3oonl0JFUY07=cL`0/0000000/0P0000000`0/;2`0X76P02`/
;00202`/;00=0000;00/;2`0;2`/01HF5P0002`0klG_0?o_o`2f][H0Lg=c02`/;00F5R`002`00000
00020000;00<000/000002`0JFUY05o5U`3_knl0aNo_0<G5a@2GUlD0GlG509N^TP35aIL0QHF50P0/
;2`03P0/0000000/05A`E02WYjL0QHF5000/000/;2`0GiNG02`/;020Fe/0;2`/001OG`2GaIL0BDU9
0P0/;2`05`3_knl0O7al05mOG`2GUel0000/02`/;02GGel0aOo5031<AP0/;2`0BDU909O5U`1cLg<0
00190=CDe02WYjL0aOo_0>o_a@19BDT002`00019003oool0Njik0080;2`/00<0GemOooooooooool0
1_ooool000Kooooo01805R`F01H0000F5QH08AHQ01HF5P0F01H05QHF07^BTP2fcKH0Yg]k05ARHP1b
@d<0>VUY07=cL`16HV80[jN_0>7Qh@0Y:C@202`/;00H02D0000U5P005R`F01H/5P0`B5X0Ym[30=[3
[P0/;2`09@0F01HF;00001H0;24Q01H/5P1DL700ooO_07URHP1DC4`0D51@031O<02ZYZH0P:nW0?3X
j00k>c/001H00P00;000I00F;1H0>U0j04IRAP33aLD0f/?302`/;00F01H05R4F02`/;01O[/D0l>SX
07URHP005P005R`F04aGC01n[Zh0aLG501H/5P0U5P005QH/000/000_CBl0NjjB06YZJP1@D500Njj^
0;jn_P00>`00E5me07]<C00k5QH0;2`/07^GN`2GTY80@g9b04AK=P0U01H09EAD05mOG`0FATH0>VUY
08>OW`2/[:`0YJEb08MSH`1iHf<0GUiN08>3P`2LW8D0HFmQ05mO<016AQH0ATI603/k>`2;RjL0km[5
0;jnY`1ZJWD0Qib70:NBN`2BTY80W9b505ADE02l_;`0b[6V030`5P00;000;1HF01H0000001H05P00
024F8@0F;1H0>`0002DU9@1aLG40fm_C0;JfVP2NVX@0[jNB09b7Q`2OWh<0P82>07UiN@0F;1H02aH0
071`L03Jf/D0UXj>000F5P00;000;00000//2`0F;1H0ATI60=?;b`2^[Zh09BDk069RHP29XY<201HF
;00T09O5U`1<C3005R`F02`/;01oRgl0E71`08j>SP0/000001H001HF;01lO7`0YjNa04aSH`1RNGT0
aLG50:k3TP0`Gel0Ng]O031R<00Q8AH0bm[50=[5TP0F;1H001H002`F5P0U>bD0U9n605mO<00`C5@0
9C/U02DU>`0F5QH09BDU0<o?a@1YJCX0;1HF10000000400;2`/05P0F09:^[P3Rh^80W9bL07:>SP0/
5QH0=Te=001D<00UE2D0<5mO03/k>`2>SXh0d];B0;Fe/@20P8020316<00402`/;00F5QH0TWRB08fT
Y080;2`/00L09BDk01HF;00F;1H0Gg]k069iHP0/;2`0UjjG0080>c/k02<0][Jf05A`L01YThD05QHk
02`F5P3JmmX0Gg]O069RHP1DN5@0f_og07J>P03=h^80GUiN04I6AP0F;1H05QH/08NLW01aOfH001HF
03/k>`3Jknl0`mZ^09;3[`3Xl>P0@41006YDE03RmoL0JHF5051@D00/;2`0E6YD09Nj/016HTH0;2`/
05mOG`08ooooo`001_ooool202`/;0030000;00F5P00;2`/00<0;2`/00X0aING0?ook`3gmmX0koo_
0?o_k`3oklD0kno_0?o_k`0/;2`0;1HF0P00;0001P0/;2`0000/02`0001OUiL0L9b70<G5a@80;2`/
010002`002`/;00/0000;2`/02`0000002`0ooo_0?o5a@3_olD0ooo_0?ooo`3CdkH0ooo_0=CDe00/
;2`0000/0P0/;2`04`0/5QH0;2`/0:NWY`3lo?`0;2`/000/00000000B@000000;000Gel0aNoo0=CD
e02GUel0aLFG0?ORhP35klD0klG5000/000/;2`00P00;000>P16ATH0YjNW0000;000;00005mO0<G5
a@2GUiL0TZj^0<G5U`0/0000000/09NGG`19BDT002`007UiN@0/;2`004T002`/;000;000;2`/04U9
B@2UYJD0aIMO001OG`1cLg<0YjNW0<FGU`35aLD0][Jf0=CDe035klD0aLFG07=cL`3_klD0hN7Q05mO
G`000000;00005mOG`1cLg<0QHF507=cL`35UiL0UIFE05mOG`0/;2`0;0000000000/0000000/000/
000/000002`00000001OGel0aLG50>o5a@2f]Yl302`/;080000/00@0;000000`0035aLD0ooo_0P0/
;2`06@00;000;2`/03YN>P1OGel0aNo_0?clo03_klD0UlFG0?ook`0/;2`002`009NGU`1OG`00;2`/
04U9B@0/;2`09@0F09NGG`1OGel0Gel0000/0000Gel0UlFG0:jBN00/00000P0/;2`07P19BDT0aNo5
02`/;01OGel0Ph>30;Jf]P3oklD0000002`000000000B@0001HF;02f][H0UlEO0019001cLg<0GemO
05nGG`3;bm<0GemO07=cL`00;000000004T00000000002D0001OG`1OUiL0o?cl0?ooo`80kno500l0
cLg=0<G5a@3QhN40ooo_0>7Qh@3_knl0;2`/000F5P0/;2`002`00019002GaIL0aNo50<G5U`0FATH0
0P0/;2`01P0002`0GiMO05nGU`0/;2`0<7]O000/0080GiNG00l0GiO509NGG`0/;2`0Ng]k000/000/
;2`0koo_0=CDe01OUel0hN7Q001OG`0F5QH0BDU909O5U`1OGel00P00;0004`0/0000[ZjG08F5Q@00
G`00knoo0019002WYjL0ooo_05UIF@00B@00e=CD0<G5U`1OUel0;2`/000/003CX;`0GenG001OG`1O
Gel02?ooool000Kooooo00D0;2`/02`0000/;2`05R`F000/000202`/;00<05mOG`2GUiL0ooo_0>7Q
h@3_aLD0UiNG05mOG`3oonl0koo_05l0000F5QH0000/0P0/;2`01@0002`005mO04U9B@1STY80UemO
008002`00100;2`/0000;000;0005QH/00000019BDT0aNo50?o_k`3lo?`0aING04U9B@1DE6X0o?cl
0;Jf]P0/;2`0000/0P00;0005`16ATH005l00>7Qh@250000B@00000/0019000001H00000001OGel0
UlG50?ooo`3oonl0ono50<_;``3oonl0koo_02`/;00/0000;2`/0000;00jJFT0YjNW0080000/00D0
;2`/09O5a@1OUlD0SZFU0<G5a@0202`/;00B05mOG`2GUel002`004akU`0/;2`0UlEO000/000/;2`0
BDU905mOU`1<Ng/0knnG04U9B@0/;2`0000005mOG`35aLD0C4aD0P1OGel02P2GUiL0][Jf0:NWY`3_
klD0BDU9030`AP0/000002`004T00000;0020000;0040<^f]P1OGel0GiMO0000008002`00180000/
000/00000000000/04U9B@2WYjL0kno50:NWY`0F5QH0000004T00000;000;2`/0000;000;000E5AD
0?o_k`2GGel20000;00802`0001cLg<0JFUY0;Jf]P2GGiL000190?o_k`3De=@2000/000V05nGU`25
QHD0000/02`/;01OGel0Lg=c000F001OGel0UlFG08F5Q@000000;2`/08F5Q@2f][H002`002`/;00/
000002`00;Jf]P35klD0][Jf0:k5a@2GaLD0ooo_02`/;000G`00;2`/000/000F01H0GemO0?o_a@3_
aLD0e=CD0?o_k`3QhN40h^oJ0<G5U`00;00205mOG`0:0000;000;000Gg]k0<G_a@3oool0ono_04U9
B@0002`0;2`/00005P80;2`/01X0ono_0?o_a@0/;2`002`001H/5P1OUel0aNo50>o5a@25QHD0;2`/
04U9B@0U9C/0000/02`/;01cLg<0;2`/09NGG`0/;2`0HV9R05nGU`2f][H0GemO09O5a@1OGel0;2`/
05mkN`8004T000D0e=CD001OG`25QHD0kno_05mOG`0202`/;0090>7Qh@1OGel005mO00000000;000
fm_K0<Gok`2GUiL0aLG50080;2`/00`0aNo_04IRHP0/;2`0GemO0>7Qh@1cLg<0GemO0000;01aUG40
kno509O5U`1OGel8ooooo`001_ooool06@0/;2`0000/000/000F5QH000000000;000Gel0GemO0;Jf
]P3oknl05TI602`/;00002`0;2`/05nGU`2WYjL0klG502`F5P0002`002`00000;01OGel0Lg=c000/
003_h]X00`0/;2`02000;000B@00000/00005QH0;2`/05mOG`3oknl0UemO0`0/;2`04`0`C4H0hN7Q
0<G5a@1OGel0;2`/05mOG`1cLg<0Gg]O0<G_a@3oonl0;2`/000/000/;2`0000000005P1OGel0BDU9
0>7Qh@35UiL00P0/;2`02@0FAV80aNo_0?o_k`0/;2`002`002`00019BDT0TY:B05l0G`0302`/;00D
09NGU`1OUel0GiO50<G5a@0/;2`0000005nGU`35Uel002`0051@D01OGel0UlFG05mOG`0004T0001O
001OG`0k>c/0GiNG0?ooa@2GG`0202`/;00=000/0023E5@0000002`00000;000;2`/07=cL`2f][H0
aLFG03/k>`0002`002`00000;002000/000604T0000F;1H0aLG505mOG`19BDT0GiMO0`1OGel0=`1O
Uel0GemO09NGU`3QhN40YjNW0000;00F5P00;000000/00000000000/04U9B@1cLg<0C70`0>o_k`00
04T0BDU907=cL`1OGel0GiNG0:j^[P000000;2`/0?ook`3oknl000000000;01DJU@0aLFG05nG0019
BDT0GiMO02`/;035aIL05QHF02`0002GaIL0QHF505nGG`1cLg<0YjNW0;bl_00002`0;2`/000/0000
02`0;2`/0<G_k`3QhN40mno50>7Qh@3_klD004T005mO001OGel00P0002`01`00Gel0o?cl0000000/
0000000002`0000j>SX00P35aLD01P1OUel002`005mOG`1OUel0fm_K09NGU`80;2`/00@002`00000
000/;2`05P0F0P0/;2`0201OGel0aOo50>ook`3oknl0[jn_0:NWY`2GUiL0aLG50P19BDT0100/;2`0
5R`F05mOG`00L`0202`/;00=0000;00/;2`0Pin30;Jf]P00B@00;2`/0<G_a@1OGel0;2`/07^B[P00
Gel0GiO507=cL`0202`/;0060?o_k`00Gel0;2`/02`/;02GUiL0aNo50P1OGel02@0004T0NGUi0019
0035aNl0GiMO000/0000B@00BDU907^^N`0202`/;0080>o_o`2f][H0GiMO001O0027QhL0;2`/07=c
L`1OGel8ooooo`001_ooool202`000070000;00F;1H0;2`/05nGG`1OGel0UlFG0>7Qh@0202`/;00J
000/000/;2`0;2`/0000;02GGel0kno_01Hk5P00;00004T007=cL`2GGel0Lg=c0>7Qh@1aLG40;2`/
0000;00/;2`002`002`0000002`05QH005mOG`00B@00kno502`/;000;00202`/;00:01I6AP35knl0
ooo_09NGU`25QHD0Lg=c05nGG`3Kdm/0ooo_09MOG`80000/00H0;2`/0000;00F0000GemO09O5U`3o
klD2000/000;00000016ATH0UlG50?ooo`00;000000/0019001cLg<0Hf=i02`/;000;0000P0/;2`0
@P1OGel0GlG504U9B@35aNl0UlEO0000;01OUiL0aLFG02`/;000AS00GiNG04U9B@1OUel0GemO000/
000/;2`0>c/k05mOG`2GUel0aLG50>o_a@19000002`007USC01OU`00;2`/000/0000000002`007=c
L`2WYjL0QhM`05mO0000;0000000000/000/000002`002`F5P19BDT0hN7Q0<G5G`1OG`0004T0000/
000k5QH0Gel005mOG`3oonl0][Jf09NGU`1cLg<05P0F000/001O05l0Lg=c08F5Q@19BDT0GiMO0=[J
a@3oknl0ono50:NWY`2GUel0aLFG02`/;080000001D005l00?clo00/;2`002`002`/;033`l<0UiNG
09NGG`35aIL0BDU902`/;01cLg<05R`F000/00000000aLFG09O5U`35aLD0YjNW0:o3``25QHD00`00
;0003`000000][Jf0>o5a@0`HS00BDU90;Jf]P3_kiL005mO05mOG`1OG`0001HF04U9B@3_onl002`0
000000020000;00902`/;00/0000000/04T0002WYjL0][Jf0>o_k`1YJFT0000/0080000000H0000/
04T0000/000001HF05mOG`1OUiL20<G5a@0K0;Jf]P1cLg<0E5AD0>o5a@2WYjL0BDU902`/;00002`0
;2`/04I6AP1cLg<0GemO02`/;01OaIL0Gel0001OG`1KP5/0UlFG04U9B@00;000YjNW001OG`00B@00
RjNW0:NWY`35knl0BDU90080;2`/00h0UemO0<Goa@16ATH002`0001OG`3_onl0aNo5001OG`3_onl0
5TI602`/;01OGel0aNo505nGG`80;2`/00/0[ZO302`/;00/;2`0e=CD0>o_k`35klD0][Jf0=?Xd`0/
;2`0BDU905mOG`08ooooo`001_ooool06P000000;0000000;00/5QH005mO05mOG`1OaIL0klG505mO
G`0002`0000F02`0000002`000000000;02WYjL0hN7Q0:NBTP1OUiL0Lg=c05mOG`3_klD0koo_0?o_
o`1iHV80000/0P00;00202`/;0070000;00FATH0BDU90>7Qh@35UiL0;2`/000/000202`0000B01HF
;02GUiL0o?cl0<G5a@3oklD0ooo_0?o_k`2^TY80ooo508F5Q@0/;2`0;000000/000/;2`0>SY@04U9
B@3oklD0;2`/0P0002`01P0/00005QH/0<G5k`3lo?`0GemO0:NWY`80UlG50240_[jn000/000/0000
000/04T000000000][Jf02`/;02GaLD0GenG07=cL`2f][H0e=CD0019001DE5@0Gel002`/;02WYjL0
;2`/05mO000/;2`0GiNG04U9B@1cLg<0YjNW08F5Q@2f][H0knnG01HF002WYjL0ooo_0<G5G`0/;2`0
0P0002`01`00Gel0[/Ek04U9B@1OGel0G`00001O000/00000P00;0000`1cLg<0ooo_0>o5U`020<G5
U`0J09O5U`2_[jl0YjNW0<G_a@2f][H0klG505mO00190000IfMW07=cL`1OUel004T00:NWY`35aLD0
YjNW03/k>`3_aLD0ooo50?o_a@19BDT0;2`/0000000F5QH0;2`/0?o_k`2f][H202`/;00;09NGG`1S
N7T0;2`/09NGG`2GGel002`007=cL`1OGel0N5AD000/000002`00P35aLD01@25QHD0][Jf0820P01O
Gel0YjNW00<002`000h0o?cl0>o5U`1SND`002`004T00025QHD0aLFG04T0000/;2`05R`F02`/;03o
onl0000002`00080000/00<0>aHF000/000/;2`00P00;000101OGel0ono_0;ViW01cLg<202`/;007
0000;000;00002`004IRAP2f][H0aNo_08F5Q@0302`/;00J06>>H`2WYjL0BDU90000B@0/;2`002`0
04U9B@1DL5@0BDU909NGU`00Gel0YjNW09NGU`1OUiL05S/F0:NWY`19BDT0;2`/09O5a@25QHD0GemO
08^;R`0/;2`0UiNG05nGG`1OGel202`/;0090<G_k`1OUg/0000/05l0G`35aIL0;2`/0<G5a@3QhN40
<4a60080;2`/00l0hN7Q08F5Q@0002`0;2`/09:_Y`1OGel0BDU90>ook`3_klD002`00<G5a@3Cl>P0
Lg=c02`/;01OGel02?ooool000Kooooo00d0B@00000/000/;2`05QH/05mOG`1OUel0hN7Q0:NWY`0/
;2`002`000005P0/0000000/0080;2`/00X0BDU909NGU`2PX:00BDU90<G_a@3oknl0aLFG04U9B@3o
knl0NGUR0P0/;2`01`19000002`0000/000/0000D51@09O5a@3oklD00P0/;2`0<`0/000002`002`0
000`C4`0GiMO0?clo035UiL0GemO02`/;000;000AS0`0?o5k`35UiL0;2`/0000;00/;2`0000/02DU
>`35aLD0aING02`/;0190000000/02`0000F5R`0GenG0?o_o`3oool0ooo_0>ook`3QhN40koO3000/
000/0000000/001OG`1OGiL0UiNG03/F5P19BDT0UlFG0<FGU`1OUiL0aNo_05mO0000<4H0aIMO0000
000002`0UiMO000/000204U9B@04000/000/;2`0UiNG0:NWY`80Lg=c00/0h]Z^05mOG`2GUel0UiMO
02`/;02GUel0Lg=c02`/;01kUiL0knnG09MOG`0304U9B@0402`/;02BHg/0kno509NGG`<002`000H0
;2`/01H0000/;2`0;2`/04U9B@3_aLD20<G5U`0:01H/5P1OUel0][Jf0:NWY`25QHD0;2`/0000;00/
;2`0GiNG0?o_a@<0000/00/0000000009@25QHD0ooo_0<G_a@2GUiL0QHF50?ook`000000Lg=c0<G5
U`0202`/;00305l0002WYjL0C69<008002`001L0aLG509MOG`1OUel0B@000:NWR`00B@00GemO05nG
U`1OGel0BDU90>o5k`35aIL0C69<02`/;000;000;2`/08F5Q@2f][H005mO07:>SP2GUiL0e=CD0019
000202`/;0040000;0005QH0;00002`/;08002`000<0;2`/0?ook`2i^K400`1OGel01@1OUel0GiNG
07=cL`2W`l<0e=CD0080;2`/01T002`002`/;01OUel0[ZjG0000B@0/;2`00000000/001OUel0;2`/
03/k>`0002`0GemO05nGU`1OGel0;2`/0:NWY`0/;2`0UlFG001OG`00B@00GiNG09NGU`1OaIL0QIb5
0080001901P0klG505mOU`00;000;2`/04U9B@1k[Zh0GiMO0<G5k`0/;2`002`000000035klD0>Uhj
02`/;000;000klG_05mOG`00Gel002`009bLY03lo?`0UlG50?clo02GUel2000/000405UIF@35klD0
GiNG05mOG`Sooooo0006ooooo`0[02EDE00k>c/0>c/k069DE02LQi`0hN7Q08iiN@0F;1H05QH002`/
;00F8AH0;1HF02`/;00F5R`0<31605mOG`1k[Y80noOJ08j>SP20P800;2`/01HF;00/;2`0][Jf09^K
V`16HTH0>U0j04a<AP0jD3X0AT``051@D01@LfP0bl_;09J>N@0F;1H001HF000/000F;1H05QH/055h
K@2BYi80NF9R02`/;00201HF;00V01H/5P0N@3D0mnog0>o5a@0/;2`0ATI6031<AP0`C300QXIh0;5S
H`005QH0000F0000000F5QH05QH00312>`33fZh0bl_;01HF;00U01H002`005nB[P3;h]h09@0F01HF
000F5QH0D51@08^W_P0F;1H02b`;01H/5P2GUjh0HV9R01HF;01DL8L0Rh^;02U0@02f][H2000/0010
07^^U`1DE5@0Gg]k05AD;P19BDT0>c/k02Dk9@1RHV80^ZF>07US<00eBcD0AV960;Rh^03Jh/<0ATI6
0696AP1<HS00Gel`0::RUP3;Yi80>c/k05ADE01I@d<0E5AZ07USH`1hN6<0N8iS0<>BTP1kNel0BDU9
02`/;00F;1H02`/001H/5P005QH002`004IiAP27W8L0f/F^08FLNP20Fe/09BDk01HF5P0U000001HF
000k001aRVH0^/:U03/F5P00;0009BDU04a<<01`L5@0P8j>075aL@1IFET0h^[R0?ogk`1aLHL05QH/
03e8<@35[YL0<30F02Dk9@805R`F04H0ATI609:PQ`0k9BD0000F09nf]P3Jbjh0SZF>000F000Y5R40
W9bL0767L@1ZVVX0HhMS08j>SP3Xj?00klG505]@D0005P009AH001HF;00/0000WYjN0=?Cd`2PUXX0
TY:B0:Fj^P2OWkH0UIFE06UY>P19BDT0@4iB051@D013@eT0<5@007^BN`2TY9`0kno_0:ZRXP2>NGT0
P82009b0N02WYf<0h^;J0=[JfP1NMGD0<4``05]aF`1SW4`0_[j;0:NWC01iHd`0=3@d02`/;000;000
E71D06MWI`0F;1H0<4aD04mMG@1DL700P82006MWI`0k>c/05R`F0:NnY`0`ETP0SXj>08>3P`1YQHD0
Gg]k0P0/;2`08@1mWIl0GUiN02`/;01KP5/0V[JJ0:FjY@16HTH0HgUS06YZG01iSWT0dnSX051@D00F
HTH0;2`/071DL02=Wi/09BDk02`/;00k>c/0f_O;0:k3[P16HV80U9Al01HF;01iHV80W:BL0<?Jb`1k
TW/0AT``01HQ5P1iHV80Qib7031OG`08ooooo`001_ooool02@35aIL0aLG50>7Qh@3Xj=<0ono502`/
;000;000B@00000/000202`/;00>000/000/;2`0;2`/05nGG`1OG`00hN7Q08M`L00/;2`002`002`0
000002`0;2`/09NGU`3<c<`205mOG`80BDU900d0GemO09NGG`3Rf/<0kno502`/;000;000B@0002`/
;0000000;2`/04>>LP2GGel0;2`/008002`000X0B@00000/0000<4H0aNo_0?o_a@1OUel0UiNG0<G5
a@3oolD0moO_0`0/;2`050000000B@00000/0025W8D0klG505l0000002`0;2`/000/0000Gel0[jo;
000/001OUel0GemO0>o_a@35aLD0;2`/000F0019BDT0UiO50P0/;2`03@00;000aIMO0:N;R`35knl0
Gel002`/;02WYjL0;2`/0019000`L4`0;2`/001OG`00B@000P0/;2`01`2WYjL0HT``0000;0000000
Lg=c0<G5U`0/;2`00P0000000`0F5QH0][Jf09NG000204U9B@0;02`/;00000005P0F02`00000;000
YjNW0<G5U`1OGel0Uel005mOG`2GUel00P1cLg<07@1OGel0aLG50>o_a@0U>bD002`002`/;0000000
04T005nGG`1OGel0UYJF02`/;019BDT0Lg=c05nGG`19BDT0UiNG00005P00;000GemO0?o_k`0002`0
;2`/000/003;h/<0aLFG09NGG`0/;2`0QHF50080;2`/00X0L71D05nGG`2f][H0hN7Q0?o_a@2WYjL0
000/000/000/;2`0klG_0`2f][H01035knl0ono505mkN`190002000/000402`00019BDT0ooo_000F
5P8002`000/0;00007=cL`2GUiL0UiMO05nGG`3_olD0aNo50?o_k`3_aLD0GemO000/000202`/;00;
0000;00/;2`005mO0?clo03De=@0YjNW08F5Q@1OGel0Lg=c0:NWY`2GaIL00P0/;2`02P00Gel0Lg=c
04U9B@1OUel0;2`/04U9B@1<Ng/0GemO001OG`0004T204U9B@0E05nGU`1YQHD0QHF502`/;01OGel0
GiNG001O000/;2`0NHjF05mOG`2GaIL0BDU90>o_a@0/;2`0e=CD0<G_a@1<HS00;2`/0:NWY`35kiL0
Lg=c0080;2`/0180NHii08F5Q@19BDT000190>o5U`0/;2`0Lg=c0=_Kf`1OUel0;2`/000/000/;2`0
UiNG09O5U`1DL5@0;2`/0000B@19BDT8ooooo`001_ooool01@35UiL0QHF505mOG`1aLG40e=CD0080
;2`/00d0000002`/;000;0005R`F0000;000;000Lg=c05mOG`2GUel0klG501HF;00/;2`0B@0000<0
;2`/00X0GemO0<_RfP3oknl0koo_0>ooa@3lo?`0klG50;Jf]P3IfMT0ono_0P0/;2`02000;0000000
0019001OUiL0VYZJ02`/;000;00000000P0/;2`02`0/0000D3Xj05nGU`35knl0kno_0>ook`2WYjL0
;2`/07V>N@1O0000000/0080;00000<0000/001O0027W8L00P0/;2`0;@0/000002`0000/0000;000
[jn_0?o_k`3oonl0ono_0?ooo`3oknl002`00000001OGel0YjNW02`/;0000000;2`/09NGG`2G`jh0
UiO50;Jf]P00;000UlG502`/;0000000Hdak05nGG`0/;2`0GemO05mOU`19BDT0;2`/0;jnY`35aEl0
02`002`/;025QHD0aLEO0000;00000009@0F05mOG`2GaIL0aLEO05mO000204U9B@0U01HF5P0002`0
B@000000;02GUiL0aLEO09NGG`2G[Ul0UemO09NGG`35aIL0kno50?o_k`0/;2`0C68`0019001OGel0
GiMO04U9B@1OGel0koo50?3`j03lo?`0aLFG07=cL`2f][H0;2`/0000;00001H0;0000>ooa@1OGel0
;2`/0000B@3lo?`0JFUY0<FGG`0202`/;00:09NGG`0/;2`0;2`/06=SHP2WYjL0UiNG0>o_a@3oonl0
;2`/09NGG`8002`002<0knoo07=cL`0002`002`00;Jf]P3_aLD0TTaO05nGG`0002`002`00000;00/
;2`0ooo503Y@>P0/;2`0000002`00000;000;000000/003Xj=<0aLG507=cL`0/;2`002`000000000
B@009DTU02`/;000Gel0o?cl0>ook`35knl0GemO04I6AP0202`/;00D0:NWY`2GUel0;2`/02`/;01`
E700GemO09NGU`0/;2`0GiMO001OG`2WYjL0JFUY04U9B@0/;2`0BDU907=cL`2GUiL0YjNW09nf]P1O
G`0202`/;00<0;Jf]P1cLg<0000007V>SP3De=@0GiNG0:NWY`2GUel0000002`/;02f][H09EAD0P0/
;2`05P35aIL0GiMO05mOG`00;000LG5a0>o_k`2GaIL0aLG_02`/;019BDT0000/01HF5P2GaIL0GiMO
02`/;00002`0;2`/08F5Q@2^aIL0GemO05nGG`00Gel8ooooo`001_ooool04@0/;2`0000/000/001@
D500hN7Q02`/;00002`002`002`/;000;0005P0005mOG`1cLg<0BDU905nGG`2f][H0aING00<0;2`/
0P0/000010000000GemO0;VaW019BDT202`/;0070000;000;000000/09:^TP3oknl0G`0002`/;002
05nGG`0<05nGU`1cLg<0bkJf000/00000000B@0002`00000;0000000069RAP1OUiL0aING0P0002`2
02`/;00307QSN@2GGel0;2`/008002`000<0;2`/05mOU`2fWil00P0/;2`01P000000;2`/04T00000
0000b/[:08F5Q@80;2`/01@0GiO50>ook`0/;2`0000F05mOG`2WYjL0B@000000;00/0000GiNG069R
HP0/;2`0UlG504U9B@2GaIL0G`0002`/;00`HT`0GiNG0<G5U`80;2`/02X002`002`/;016ATH0UiNG
0<G5U`3_aIL0000/08F5Q@3QhN40aIMO0016000/;2`0Lg=c0:NWY`3_aIL004T004U9B@1ONc00Lg=c
05mOG`19BDT0GiMO0?ook`3oklD0E30`0000;000;000;2`/09NGU`2WYjL0ooo5031D<01OGel0BDU9
09NGG`3oonl0UemO02`/;000AS00kno50>o_k`1O00020000;00J02`0000002D0UiNG0>o5a@0/;2`0
05l00?ooo`0/;2`0Hf=R05mOG`0/;2`0000009NGG`2GaIL0;2`/04a<HP19BDT0UiMO04U9B@3oknl0
ooo5001OG`1<HT`0000/0>7Qh@2GUel302`/;00408F5Q@2GUg/0BDU907=cL`8005mO00L0BDU90>oo
k`1<HT`002`002`/;0000000B@000080000/00D0P7RL0<G5U`1OGel0GemO05nGG`0205mOG`0505mO
<03_klD0o?cl0=CDe02GUiL00P0/;2`00`0F>aH0UiNG05mOG`0204U9B@0M02`0000/;2`0O7al02`/
;01cLg<004T005o5a@19BDT0GiNG03/k>`00B@00GiMO001OG`1cLg<0GiNG05nGG`1KFh00BDU9000/
000/;2`0UiNG05nGG`1OGel0NHj>02`/;02f][H0aNo_08F5Q@00;0000P0/;2`06@2B`i8004T002`/
;00/;2`0aLG505nGU`1OGel0U7in02`/;019BDT0aLG50>o_a@1cLg<0GemO01H/5P0002`0aLFG08F5
Q@00B@00000/000/002BYjL0][Jf0<G5k`19BDT02?ooool000Kooooo01X0;0000000;00/00009BDU
0?o_a@00;000;2`/02`00000B@00GemO07alO01cLg<0BDU90019003De=@0klG502`/;00k5QH0000/
02`0000002`0000005mOG`1cLg<0]YnO02`/;080000/00L0;2`/000/000/;2`0QhN70?o_k`3_aIL0
BDU90080GemO00<0aLFG0>o_a@3R`jL00P0/;2`2000/000402`/;000;000E71D0?o_k`D0;2`/00<0
HhiS0:NWY`1OUel00P1cLg<0101OG`00][Jf09JFSP0/;2`202`0000C000/000/;2`0GemO0<_J[P0/
;2`002`002`/;01OUiL0aLG_02`0000001H0GiNG0;Jf]P0/;2`0000/0019001OaLD09BDU0000;002
09NGU`0G09O5a@35aIL002`005ADE019BDT0QHF505mOG`00000005mO05nGG`1DC4`0;2`/08F5Q@1O
UiL0YjNW0>o5a@1OUiL0UiNG08^WY`1cLg<0;2`/0<G5a@35aIL00P3_aLD01`3gh/D0kno50<G5G`35
aIL0ooo_0?o_k`00Gel01@0/;2`01@0002`0UiNG0=?Cd`3De=@0YjNW00@0;2`/0140FEUI0?ooa@0/
;2`0;2`/000/000/;2`0BDU906UYJ@3De=@0UiMO09O5U`3lo?`0G`00000/0027Qg00;2`/00190002
09NGU`0?02`/;02GUel0HV9609O5U`1cLg<0;0000000;03oonl0ooo502`/;019BDT0ooo_08F5Q@19
000002`00080000001d0SWUi0<G5G`19BDT0GemO05nGU`2f][H0knoo08jUY@19BDT0;2`/000/0000
02`002`00019002ZZZX0oooo0>7Qh@3oaLD0ono_0?clo03_onl0h/?30<G5a@3_klD0;2`/0000000/
;2`005mO0<G5U`0204U9B@80;2`/0180000/05mO001k[YL0;2`/05nGG`00Gel0Lg=c001OG`19BDT0
<31604U9B@1OUiL0GlFG09O5a@2GUiL0GemO02E99@00Gel202`/;00904U9B@35knl0UlFG09bLW00/
;2`004T009MOU`1OaIL0GemO0080;2`/00X0SZF>07=cL`00B@0004T002`/;03_onl0aNo50:O;[P19
BDT000000P0/;2`03@2WYjL0UlFG031RC000;000;2`/07=cL`35aIL0aNo_09O_k`2^f]X0GiNG04U9
B@1OGel02?ooool000Kooooo00L002`00000000002`05QHF0>o_k`35Gel004T00080GiMO00P0GemO
04H`<02GUiL0aLG50>o_a@3okol0ono_04U9B@<0;2`/00P002`0001OG`1cLg<0BDU908iiN@0/0000
;2`/0000;0<0;2`/0140JVYZ0?o_k`3_onl0aLFG0<G_a@3_olD0ono50<FGU`3Cdkh002`002`/;000
;000B@00000/0025QHD0HWUi09MOG`0202`/;006000/000/;2`002`004aSN@35aLD0][Jf0P3oknl0
2P3oonl0o?cl082FN00/;2`0000/02`/;019000005mO02`/;027QhL2000/000[02`0001OUlD0aNo_
09NGG`25W8D0hN7Q0<FGG`00;000;000001OG`2f][H001HF02`/;025QHD0YjNW05nGU`35klD0Uel0
04a<HP00;00004T005nGU`1OUel0000/02`/;00k>c/0UiMO000/000/;2`0Lg=c09NGU`3_klD0ono5
031<E01OUel0UiNG0?o_o`35Uel0BDU9000/000F;1H0;2`/09NGG`020>o5a@030>o_U`19BDT09C/U
00@0;2`/00/0GemO0<G_a@2LY9`0;2`/0000000/;2`002`00000;01OGel0Yl>W04U9B@0202`/;00D
05mOG`19BDT0GemO0;Jf]P1OGel0ono_0>o5a@0002`000000000;01SHf8004T004U9B@2GUel002`0
09NGG`2WYjL0031609NGG`19BDT20000;00J04U9B@3oool0P9a<04U9B@3oklD0UiMO05mOG`0/0000
000002`0000F0000hN7Q0<G_o`3_knl0aNo_09O5a@0/;2`0cN;=04U9B@1OGel0GiMO04U9B@0/;2`0
GiMO0>o_m`2WYjL202`/;00804T0000/0000B@0001H/5P1OUel0ooo509NGU`2WYjL205nGG`0405mk
G`0/;2`002`002`/;0<0BDU900@0HWUR02`/;01OUiL0GiMO0P0/;2`00`00Gel0AV96002GU`0205nG
U`0<04U9B@35UiL0Gel003/k>`2f][H0GemO02`0000002`0UlEO09NGU`2WYh/005mO0P0/;2`07@2W
YjL0GlFG05mOG`00B@00NGUi09O5a@1cLg<0BDU902`/;01OUel0;2`/0>;RhP2GaLD005mO00190000
02`002`009NGU`1kTW/0;2`/04U9B@00Uel0aOo509NGa@1cLg<0>c/k05nGU`2WYjL0GemO00Sooooo
0006ooooo`0<000/000/;2`0;2`/05ADE03QhN40klG505mOG`19BDT0;2`/09MOG`2WYjL0Lg=c0P0/
;2`02`2f][H0ono_02`/;00/;2`002`00000;019BDT0Lg=c05mOG`3QhN409BDk00<0;2`/00T0000/
02`/;00002`0TZN^0>o5a@3_klD0][Jf09MOG`0/;2`00P00;0000`3gmn8002`002`/;002000/0005
02`00025QHD0[l>B02`/;00/00000P00;0002P0002`0;2`/04akN`3QhN40aLG509NGU`1cLg<0;2`/
0000B@2FSYH202`/;00>0000;00/;2`0GiMO09O5U`2FSYH00000000/000/;2`005nG0<G_k`3oonl0
moOJ0>o_k`3oklD202`/;00Y07=cL`2f][H05R`F0000001OGel0Lg=c0000;03De=@0UiO506=iC000
0000;2`/09NGU`25QHD0aIMO02`/;016HTH000190<G5U`0/;2`0000/0000B@1OUel0][Jf03160000
0000;2`/08F5Q@3De=@0;2`/05mOG`00;000;2`/0000000/0000;2`/0;Jf]P3QhN40E71D05nGG`1O
Gel00P1OUel00`35knl0hN7Q069RAP0302`/;00>05mOU`1cLg<0Gel00=[J[P3_klD0aLFG09NGG`2G
aIL0UlG504U9B@0F5R`0UiNG0?ook`00000202`/;00<0<G5a@1k[Ul0GiMO000/002GUel0000005mO
G`1O05l0Ni9S0>ooa@0/;2`0GiMO0P00;0003@1OGel0ooo_0?ook`3oool0klFG05nGG`0/;2`002`0
0000000002`002`00>7Qh@19BDT00`00;000200F;1H0YjNW0>7Qh@35klD0YjNW0<G_a@3oool0>c/k
0P0002`01`00000002`0000/0000;000YjnW0<G_k`1cLg<00P0/;2`01`35aIL0][Jf04I6AP00;000
BDU902`/;02GaEl00P19BDT0201RHTH0GemO04U9B@00Gel0;2`/04U9B@2GUel0E71`0P2GUlD03P1O
Gel0000/02`/;035aIL0BDU908F5Q@2f][H0aNo509O5a@1OUel0;2`/09FEU@25QHD005mO0P0/;2`0
3P2WYjL0Lg=c05nGG`0F5S/0koo_0;Jf]P3_klD0aNoo05nGG`0/;2`05R`F09NGU`2GaIL0GiMO0P0/
;2`0100002`0[][J0<G5k`2GUlD209NGU`060:NWY`00Gel09AH002`/;019BDT0GemO2?ooool000Ko
oooo00@002`0001OG`1OUiL0GemO0P3_knl01@35knl0o?cl0>o5a@1OGel0>aHF00<0;2`/01D0BDU9
0?o5a@2f][H0<7]k05nGU`1cLg<0BDU905nGG`3oklD0klG501H/5P0/;2`002`002`/;00002`004T0
07=cL`2_TY80YjNW00190000;000100/;2`0202ndm<0BDU909NGG`25QHD0GiMO08F5Q@1OUel0W:BL
0P0002`01@0/0000000/02`/;000Gel0TZNB0080;2`/00H0000/02`/;00/;2`0;2`/09:WP00/;2`2
000/0004001OG`1cLg<0kno_04H`<08002`00440001907=cL`3lo?`0olG502`/;02GaLD0kno502`/
;000;000QHF50;Jf]P005QH0;2`/05mOG`1O0000B@0005o5a@2WYjL0NHii02`0000/;2`0UiNG05mO
G`1OUiL0GemO04U9B@0/;2`004T00<FGU`2GUiL002`00000;000Gel0Ujik02`/;000;000;2`/05mO
G`3_aLD0;2`/02Dk9@00;000000/0000000002`0;2`/09NGU`3Xj=<0aLG50<G5U`2f][H0hN7Q0>o_
k`35aIL0LW9b04U9B@1cLg<0BDU902`/;02WYjL0aLG504aR<035aLD0ooo_0:NWY`02000/000B02`/
;00F5R`0hN7Q0000;000;000e=CD0?ook`1OGel0GdaO02`/;000;000GemO000/00000000UlEO09O5
a@2f][H0klG50P25QHD202`/;0080<ff]P19BDT0o?cl0?o_a@2GUel0GiMO05mOG`0/000202`/;003
0<G_k`35aEl002`00080;2`/00l001HF000/000/000002`00>o_k`3oool0GemO01HF;00/;2`005l0
04U9B@00Gel0GiNG0<G_a@2fbl/00P00;0003P2WYjL0aLFG04U9B@0/;2`05R`F000/002GUiL0GiMO
05l00019BDT0GiMO05A`L01cLg<005mO0P19BDT01`00Gel0GiNG09nOW`0/;2`004T005nGG`00G`00
0P0/;2`02P1@D500UlFG04U9B@19BDT0YjNW00000019BDT0>c/k09O5U`1OUiL202`/;00500190035
knl0Uno505A`L035klD00`0/;2`01`35klD0QHF502`/;00/;2`0GemO0>o5a@35klD00P2GaLD00`2f
cKH004T0000/000202`/;00404U9B@25QHD0@g9b001c0080GemO2?ooool000Kooooo00/0GemO079b
LP2LQhL0hNGQ0<_Cb`2FSWT0SWUi01HF;0005QH0;2`/02TQ5P0201H/5P0D051@D00`>P00j>SX0=WI
f@3Kdm<0f/F^08N7Q`20SWP0mno_0>ogk`0k>c/08B4/01HF000/;2`05QH/02Dk9@1OGel0TZjB09^V
V`0F5R`302`/;00D0000;00/;2`05R`F0;Jja01h[jl0[Zj^08N7Q`2JVYX0[ZNB0=[_fP2:SXX0;2`/
02D0000F5R`0;2`/051@D00`Nel0[KFY01HF000F5R`202`/;00301H/5P0jD3X0XkZ/0080T/>W0880
^;Rh0<71`@3nm_H0fZj^01HF;00002`00316031kN`1k[Zh0h/_301H/5P0F5P/0E8M`0?kfh@2_bl<0
]/^f0:n_[`3XdnP05QHQ000F5P2W_[h001H0000/000F5QH0[/FG09f[Z`1RHTH09C/U0:k3N`0/;2`0
5TI606V5J@1?FUX0;2`/03/k>`16AQH0SW9b06=iC02OWh<0HWUR07B0IP1RHV80UIFE06V5J@1<C4`0
TY9k0>;=c@1/K4T05QH/0316<00k>c/0AS0`02DU>`0jGSX0]KFV04``<016ATH09C/U01HF;00U9C/0
N7Qi09^KS@1ONel0Hf=R06=iC01DJU@09@0F01H/5P1VOg@0h][505ADJP0/5QH09BDk051@D00k>c/0
/;jn08N7L01nU7h0[jn_07QSN@00;000050004eYF`0k>c/05QH/09NGN`1NGUh002`008>3P`27WI80
01HF075aL@3Rh/<0NiNG04IRAP0U>bD0UYIn01H/5P0`<4H0JVYZ09J>N@2WYh/0NiMO05nGG`0F;1H0
E71`0;K=c@35aLD0NGUi051@D00`<4H02b4;01H/5P00AS00C69<08^;R`3Rh^80Hi:B07]kN`1<Gc00
JFUY08F5Q@3Rf/D0W9ba09:^[P18De<0LW9b09nOP`1RHV80>c/k0P0/;2`0201dM6H0E5AD03YYJ@19
BDT0Gg]k04I6AP1`Qg00EeMG0P19BDT0<@0UE5@0LXib08>fW`23Wh<0@U1=05ADE00F>aH0L71`05mk
G`0FATH0ATI606fPR@2WYjL0E5AD03/k>`0UBBD0_]>W031kG`0n?Sh0HV9R09;J``2a^I`0<99k0820
P016HTH001HF071UI@2BTW/0Ni9k04I<C0009AH001HF07V>N@2M[Z/0LIEa07V>SP2^[Zh0][Jf05B3
P`0j>Uh0FUYJ04IRAP1DL5@0AV9604HF5P0k>c/0C99k03iXB01OUg/00P1DE5@8ooooo`001_ooool0
1035aIL0kno50=CDe02W`l<202`/;009000/000/;2`0;2`/000/000/5QH0;2`/0:NWY`00Gel0ono_
0080klG500l0;2`/0000;00002`0000/09O5a@3QhN40UemO06UYJ@1OUel0GemO05nGG`2f][H0aNo5
0?o_a@0k>c/00P0/;2`02@00;000;2`/02`/;00/;2`0YjNW0=[5[P2GUiL0;2`/04T000020000;00;
05mOa@2>NIH0;2`/0019001cLg<0QHF509NGG`35aNl0NGUi02`0000/;2`00P0002`0101OUel0UiNG
0:k;``1cLg<302`/;00P05mOU`3oool0;2`/02`/;01cLg<0GiNG0?ook`0/;2`0;000000/001OUiL0
ono_04U9B@0002`0G`1O0<G_k`27L5@0GiMO0<G_a@19BDT002`00000;02WYjL05TI60:NWY`2f][H0
aLG504T00000;000GiMO031O<000;00202`/;00C001OG`1OGel002`002`/;01ZJVX0;2`/02`00000
;000GemO05nGU`2GaLD0UiNB08F5Q@2WYjL0][Jf0<G5a@2f][H0e=CD09:GG`0202`/;005000/000/
;2`0;2`/02`/;02OWil00`00000202`/;00C07=cL`3Cdl/0;2`/02`/;025QHD0GemO0<G_a@35aLD0
ATI60?ook`0/;2`0000/02`/;000G`00UlFG03/k>`1OGel0000002`/;00205mOG`0902`/;02;Rh/0
02`00000002GUiL0klG504U9B@0004T0YjNW0080;2`/0P0002`0400/;2`0][Jf0?o_a@25QHD0UlFG
0>o_k`3_aLD0hN7Q0>ooa@1cLg<0JFUY08F5Q@2WYjL0o?cl0;Jf]P19BDT20000000?02`/;000B@00
UlG50>7Qh@1cLg<0BDU906>7<02GUiL0BDU902`/;0000000GiMO04U9B@0FATH0BDU9008005mO00H0
GlFG05nGG`0/;2`0L71D02`/;01OaIL205nGU`0=02`/;02GUiL0BDU905nGG`19BDT005mO04U9B@25
QHD0GiNG05AD9@19BDT0QHF507=cL`0202`/;0040=CDe01OUiL005mO0<G5a@80;2`/00`0][Jf0<G_
a@1cLg<09C/U02`/;000;000UlFG0;Jf]P00Gel0GiMO0;[2^P1OUiL402`/;00305mOG`0UE5@0;2`/
0080GiMO00L0UiMO02`/;02GUlD0UYJF04U9B@0002`005mO00Sooooo0006ooooo`040000;00/;2`0
aLG50:2l_080GemO00X0BDU902`/;00/;2`002`004IRHP1OUel0Uno50>o5a@35aLD0UemO0P0/;2`0
1`0002`0;2`/02`/;01OUiL0koo_0>o_a@35f/D00`35aLD03P2f][H0hN7Q02`/;00/;2`002`00000
000/;2`004T005mOG`2f][H0GiNG04I6AP0/;2`0B@000`0/;2`0201O05l0UIFE08F5Q@1cLg<0QHF5
09NGU`2GaLD0o?cl100/;2`08019BDT0GiNG09O_a@1RATH0;2`/0000000002`0000005mOU`3QhN40
JFUY08F5Q@3QhN40onoo04U9B@000000;0000016<02GaLD0ono_0000000/000002`009O5a@2^[W/0
][Jf0>7Qh@0/;2`0000/000/002GaLD002`00P2WYjL0601OUiL0GemO02`/;01OUel05V9605mOG`00
02`0BDU902`/;019BDT0GiMO09NGG`0k5QH0YjNW09NGG`0/;2`002`002`/;0190000UIFE05nGG`00
02`0;2`/000/0080;2`/02d0cLff08F5Q@1OGel0Lg=c08F5Q@1OGel0aLG50;ZjY@1OUel0;2`/04U9
B@2GUiL0GemO09NGU`3Rf/<0ooo_09O5U`2f][H0aLG504T0000002`0NIJ>0<FGU`0/;2`0BDU909O5
a@2GaIL0GiMO0316<035aNl0;2`/000/001cLg<0GlEO09O5a@1iNGT0GemO02`0000002`0hN7Q0?o_
o`3lo?`0bl>_05nGU`00;0000P0002`2000000030?ooa@2PX:00GemO00<002`00P0/;2`0103;bl<0
ono_0>o_o`0/00030000;00C0316<00004T0hN7Q0>7Qh@19BDT0000/02`/;01iNGT0BDU9000/000/
;2`0UiMO02`/;019BDT0<5mO04U9B@1OUiL0Lg=c05mOG`0204U9B@0505iNGP00Gel0GiNG04U9B@1O
Uel00P19BDT0100FATH0Lg=c05nGU`1OGiL205mOG`0E02`/;01ONel0BDU9001OG`2GaIL0GiMO02`/
;035aLD0_[jn05nGa@2GaEl005mO0000;000;000;2`/0:NWY`1bLW80;2`/000/001O0000hN7Q0080
YjNW0100aJjG001OG`00B@00BDU902`/;019BDT0;2`/069RHP0/;2`0GiNG07=cL`1OGel0UiNG02`/
;025JFT002`00P1OGel8ooooo`001_ooool01P2WYjL0GemO09O5a@3;Yf<0GemO07=cL`<0GemO0140
Lg=c07]kN`3oknl0][Jf08F5Q@0/;2`0001902`/;00F5R`00000001OU`1cLg<0UlG50>o_k`3oknl0
L71`000/000202`/;00309O5a@35aLD0Gel00080;2`/03l002`002`/;01cLg<0QHF50;Jf]P1OG`00
000/02`/;00002`0B@0002`/;000;000Lg=c0;bPX02GaIL0aNo50=CDe035aLD0][Jf0?o_k`005P00
;2`/0000;00/;2`0UiNG05nGG`25QHD0>aHF02`/;00002`002`002`/;035aLD0aNo_0?Oom`3oknl0
o?cl0?ook`0/;2`002`002`/;01DC6<0ono_05mO0000;000000/000/001OGiL0W9b5001OU`35knl0
;2`/04T00000Gel0aLG502DF002WYjL0;2`/001OG`2GaIL0BDU90<G_k`0k9BD00`19BDT02@1OG`00
BDU905mOG`19BDT0NiMO04U9B@1OUel0aLFG0019000202`/;00P09YZVP0/;2`0;2`/0000000/;2`0
;000000/001hN7P0aLG50>o5a@2f][H0klG50<G5a@3QhN40koO_07=cL`19BDT0;2`/09NGG`35aLD0
UiNG03/k>`2f][H0kno507=cL`0/000002`00000B@2j`[X004T00;Jf]P3QhN4204U9B@0907=cL`0k
>c/0YjNW05nGG`0/0000000/09O5a@0/;2`0`i:B0080GemO00T0000/05nGU`35kol0QHF50<71`@1O
Gel0Lg=c02`/;00002`00P0000001@1cLg<0N:Ah00000000;000000000<0000/00D0LG5a0>o5a@00
02`0BDU905mOG`0205nGG`0308NLQ`3QhN40][Jf0080;2`/00<0QHF50<FGU`0F5R`00P0/;2`01P00
;000BDU904U9B@19BDT0Gg]O05nGU`<0GemO00L005mO04U9B@0`Ng/0GiNG05nGG`0/;2`0Lg=c0080
BDU901<0JHF505nGU`19BDT0Lg=c0:NWY`19BDT0;2`/069RHP19BDT0;2`/09L0G`3QhN40Lg=c0:NW
Y`0UE5@0;2`/0:NWY`1OUiL0GiMO00<0;2`/00D0cN;R09O_a@2GaLD0UlG50<G_o`0302`/;00A04U9
B@1OGel0GemO001OG`1OaIL0UlFG051@D01OUiL0;2`/09NGG`1OGel0;2`/05mOU`1<TW/0UlFG0:NW
Y`19BDT02?ooool000Kooooo00`0UlG50<G5a@35aLD0cN;=0>o_a@35klD0hN7Q0>o_k`3oonl0kno_
0<_;b`1OGel302`/;005000/000/;2`05S/F05nGU`19BDT00P3De=@00`1OGel0;2`/01H05P0202`/
;00504U9B@3De=@0o?cl07=cL`1YQFT00P1cLg<00`2GUiL0kno_0>o_o`0202`/;00D000F5P0002`0
000/02`/;000B@00GiNG09NGU`3Jf/D0aLG509MOG`0/;2`0;00009NGU`3_kol002D00000000/;2`0
UiMO05mOG`3_aLD202`/;080000/00@0001905mOG`35knl0e=CD0P0/;2`01`00;000o?cl00190000
L`00Lg=c0:kQh@3oaLD00P00;0004@0/000005mO0>o_a@1iHV80;2`/0>7Qh@19BDT002`00:NWY`35
aLD002`009O5a@00;000;2`/09O5U`2WYjL0Lg=c0080BDU900P0GemO09O5U`190000;2`/04U9B@1O
Gel002`005nGG`80GemO00D0aLG50=CDe02WYjL0>SY@0>o_k`0209O5U`0;09NGU`1OUel0GemO0<?3
``3_aLD0;2`/0000;00/000000000000;01`C3000P2f][H01`3De=@0UemO000/000/;2`0HV9R0>7Q
h@0002`00P0/;2`01@1OGel0QHF50=[_fP3oonl0hN7Q0080000001<0;2`/05mOG`0F;1H0UiNG05nG
a@0/;2`0000/09O5a@00G`00JVYZ0;Jf]P1OGel0;00002`/;035aNl0GiNG01HF;035aIL0UiMO0080
GemO00D0000002`/;00002`0`m[J000/000202`/;0040000;00/;2`0;2`/08^WY`80aLG500L0ono5
0>o5a@2GaLD0YjNW08N7Q`1O05l005l00080Lg=c00D0BDU90:NWY`0F5R`0001905mOG`0204U9B@06
002GG`00Gel0Gg]k04U9B@1OGel0;2`/0P19BDT0102GUiL0LW9b04U9B@1OUel204U9B@0507=cL`00
Gel0E71`09MOG`1OGel00P19BDT02P1cLg<0BDU905@UE02GaLD004T005mOG`00Gel0UiNG0<G5a@1N
GUh202`/;003000/002GaIL0GiNG0080;2`/00@0UiO509NGU`1OGel0;2`/0`19BDT04P0F5R`004T0
05o5U`35aLD0UemO001OG`2WYjL0Gg]O000/001cLg<0][Jf02`/;00004T0GlFG07^G[P0/;2`0000/
001OG`Sooooo0006ooooo`<0;2`/00P05QH/02`/;00002`0BDU905mOG`1OUiL0klG50<>^[P80GemO
00H005nG04U9B@1OGel0BDU904>>LP1OGel20>7Qh@0:05mO00190000000/01HF;00002`0;2`/05nG
U`3De=@0ono_0:NWY`<0aLG500H0e=CD0>o_o`3lo?`0;2`/000/00005P020000;00705mOG`2GUel0
YjNW0<G5a@0`<4H0;2`/000/000202`/;00:05nGU`3QhN40Lg=c09O5U`2WYjL0o?cl0>ook`1OG`00
000/01HF5P80;2`/00D0GemO05o5U`35knl0GemO01HF;00202`/;0050?ook`1cLg<0QHF509NGa@3R
f]X00P0/;2`05`0002`0;2`/05nGU`3oklD001HF000/003QhN40GemO0:NWY`3De=@0YjNW02`/;02G
aLD0;2`/0000;02GUiL002`002`/;01`Qg0002`0001OG`19BDT0UlEO0080;2`/0140BDU904I6AP0/
;2`0QHF509NGG`00;000;2`/08F5Q@3=cLd0kno502`/;025QHD0][Jf0>o_a@2f][H0`[Zj05nGU`02
02`/;00C000/00000000;2`/01H/5P19BDT0ono_04U9B@0/;2`00000001OG`2U^ZD0GemO04U9B@00
Gel0GiMO04U9B@3_onl0YjNW0?clo00202`/;00G000/002GaIL0;2`/04a`<025QHD0UiNG05mOG`0/
0000aNo_09O5U`0F5R`0YjNW0<G5U`0/;2`002`00<G_k`1OUiL0000F0000;01cLg<0aLFG05mOG`1O
UiL00P2GUiL05`3Cfkh0Gel004U9B@1cLg<0GemO05l0G`35aLD0o_Kf02`/;0000000000/000/0019
BDT0aOoo09O5a@2GUiL0UiMO09NGU`35aIL0BDU90000;00F;1H0GemO0080BDU900L005mO05mOG`1O
UiL0Gg]k02`/;019BDT0;2`/00<0Lg=c00X0FEUI001OG`19BDT005mO04U9B@1cLg<0QHF507^BTP19
BDT0QHF50`19BDT02P1OUel0>c/k05mOG`2GUiL0YjNW0000B@0/;2`0BDU908^WY`1OUel302`/;005
0>7Qh@35klD0UlG509:^Y`19BDT00`0/;2`05000B@0005l007:>SP1cLg<0QHF502`/;025QHD0;2`/
001OG`0`AS00Lg=c05nGU`0/;2`0Lg=c09O5U`25QHD0L71D000/00190000GemO2?ooool000Kooooo
0`0/;2`02P0F5QH0;2`/001OG`1OUiL0][Jf09O5a@3QhN40h^;R0>7Qh@3De=@20<G_a@0A0<G5a@3_
aLD0fm_K0>o_k`3De=@0GiNG02`/;000;000;2`/02`F5P1OUel0GiO505mOG`35aLD0hN7Q0;Jf]P1Z
JVX00`0/;2`02P3okol0o?cl000/000/;2`05QH00000B@1OUel0QHF50;Jf]P35aLD202`/;0800000
00`0;2`/0000;02GaLD0ono_0=>n_P3_aLD0e=CD0:NWY`3oonl0olG50000000001H202`/;00507=c
L`35aOl0aING02`/;0005QH00P0/;2`30?ook`0I0?clo03X_:00;2`/0000;000;000GiNG0?o_a@35
UiL0;2`/0019003_klD0ooo508F5Q@35aLD0BDU9030`<025QHD002`002`/;01OaLD0;2`/000/0023
][H0;2`/05nGG`0304U9B@80;2`/00D0>c/k05mO0000B@00Lg=c09O5U`0202`/;00505AZE02GUel0
UiNG00190000;0000P0/;2`0=@2^`jh0kno505nGG`1OaEl0GemO08F5Q@1OUel0GemO0>7Qh@2GUel0
GiMO04U9B@1cLg<0BDU90>;gfP1OU`00QHF505nGG`35klD0YjNW0000;01SYjL0000/02`/;000B@00
][Jf07=cL`1OUel0JVYZ0000;02GUel0UlG505o5a@35aLD0o?cl01H/5P0/;2`0][Jf0?o_a@2GUel0
aNo_05mOG`0F5QH0;2`/0000;02GUiL0ono50=CDe035aLD0GemO05@U9@2WYjL0][Jf0080aLFG0P3o
ool00`0U9BD0;2`/000/0002000/000I09O5a@3_knl0;2`/0000;02WYjL0aING02`/;00002`0;2`/
02EDE019BDT0GemO04U9B@00Gel0Lg=c05mOG`1ONg/0BDU905nGG`25QHD0GiNG04U9B@1OUel0BDU9
05nGG`02001OG`0<07=cL`00Gel0BDU905iNGP19BDT005mO05nGU`19BDT0;2`/09O5G`1bSXh0GemO
0P0/;2`02P2f][H009MO000/000k>c/0e=CD0:NWY`1OUiL0UlG50<G_k`1OUiL302`/;00905mOG`19
BDT0BDU90000;01OUiL0SXj>05nGG`1cLg<0GemO0080;2`/00`005mO02`/;025QHD004T005o5U`2G
Gel0;2`/04U9B@1YQFT0000/02`/;019BDT8ooooo`001_ooool02@0/5QH05QH/030`<01ADE`0L8N7
06>BTP27W8L0P7R7075aL@0202`/;00m01H/5P0/;2`05QHk02`/;01RHTH0C7]k07N5Q@3=cLd0mno_
0=CDe033f/D0[Jf]09:^[P2M][H0_;bP0?OgfP1aUG40HTI602`/;00k5QH0000/04I6AP16HV80>VUY
0?KfmP3omoL0`l_30;[2^P2][Jd0Ph>30:nWTP3Rf]X0moOJ02`/;00F01H0;0/;0000;00F;1H0>c/k
075aL@2OWil0JVYZ01hF000F5P00;1HF01HF;02^aMX0mm[504aR<00k<3/0<70`0<:j^P3Kfm/0HV9R
02`F5P0F5P008bhS05B3P`35kmX0QibT03XjD00202`F5P250820U@1kUg/0[m[J0=?Cb`2i^KT0h/_;
02`/;00i?3`0YjNW0?OJb`0/;2`05QH/0?3Xj01OGc00Kiim0:ikG`0F;1H05TI607]kTP0F01H0AV9R
01hY:@1kNd`0Win304I6AP0F;1H0E5AD07^G<00k9BD05S@F031O<01hN7P0AV9R0;jnY`27Qg00UYJF
05mOG019BDT0[Zik0:NWN`0`HS00>U0j04IRAP0[:cH0TY9k0=?C_P33[i80NHii08ihH`1hN7T0P820
08iiN@3Cdkh0_;bl09jNWP20P800E5AZ02/U7P3gmnl0dkbl08N7Q`0F;1H0ATI607RFN02dajX0NF=S
0:2l_01KFe/0N7Qh05mO<00k>c/0Gei707QhN00F;1H0YkjW09nf]P0F5QH0AV9R07n;M0005P009EAD
0=?K_P1aLG40JVYZ0:j^U`1JJ6D05QHF03160000<300/k>c0=[_fP1aLG40<4a603]68`0/;2`0>c/k
031D<03`l>P0[Y:B069iHP1`Qg00Pin309:W``2P_;`0aLF^081hSP1RHTH0>e@k07UiHP0k>c/0;2`/
02DU>`00E0005TI603eDE01OGc00>XEY05mkN`19BDT0<5mO02`/;01NGUh0E71`05nGN`1DL700Gg/`
02EDE00FATH0@V9205mkN`1DE5@0<5mO04IRAP0203/k>`0_03M?C`1WIfL0E71`0:FUY@16HV80E5AD
09nfW`0/;2`0JVYZ07:>LP1aLG40E71D04I6HP2n_[h0F9f70:BTY01bLXh0Gg]<031kN`0k>c/0;2`/
0316001KKDd0Gg]k031kC01bSW80<5mO03YYJ@16HTH0:2Q508F5J@0jD3X0;2`/031<E01kNel0<4a6
05]YJ@1<HgT0Pinf05mkG`0F5R`05R`F0:k5U`1;FD/0;2`/07QhN01OGel02?ooool000Kooooo00@0
;2`/000000000000>aHF0P0/00001P0/;2`0GiNG07=cL`00GiL0Gg^G05nGU`80UlG500H0][Jf0<G5
k`35knl0aNog0:NWY`1cLg<202`/;00307=cL`1OGel0O7al0080kno500D0GiMO07=cL`1OGel0GemO
031kTP0205mOG`030>o_k`3oaLD0;2`/0080;2`/00D05QH/02`/;019BDT0ono_0?o5a@0202`/;00G
05mO<01OUel0GiMO0=CDe02GGel0;2`/0000;00k5QH002`004U9B@1OGel0kno50>ooo`3_knl0e=CD
0<G_a@3De=@0Uel002`/;00/000002`004aSQ`35onl00P0/;2`04`00;000000/0019002SXj<0e=CD
08F5Q@0004T0ooo_02`/;000;000GiMk0?ook`0/;2`0000/04U9B@35aLD0ooo507]kG`3_aLD00P35
klD05019BDT0000/0:NWY`00;000UiMO05mOG`2WYjL004T005mOG`0/;2`0Lg=c01I6AP19BDT0GiMO
02`/;019BDT0UlEO04U9B@1`L5@0aLFG0`35klD03@2f][H0aNo50=[_a@3_klD0o?cl08F5Q@0/;2`0
000/02`/;00F;1H0;2`/05mOU`3oolD00P0/;2`05000B@00TY:B0:NWY`0002`0BDU90<G_a@3QhN40
BDU90:BTW01OGel0BDU902`/;01cLg<0GemO02`/;027C300UiNG0;Jf]P35aLD0YjNW0P0/;2`0101`
L700BDU9001OG`35klD302`/;00B08>3P`1OUiL0Lg=c0:NWY`3De=@0o?cl0>7Qh@2f][H0UlEk05nG
G`35aLD0ono_0<G5a@3_aLD0YjNW0316<03QhN40UlG_0P2WYjL01P25QHD0Lg=c069RAP0002`0;2`/
05nGG`80BDU900T0GemO031ON`1cLg<0BDU9001OG`0/;2`0Lg=c02`/;01DL7000P19BDT06P1OGel0
;2`/05mOG`19BDT0GUiN001OG`1OUel0;2`/04U9B@1OGel0GenG05nGU`00Gel0;2`/05mOG`1OaEl0
000/02`/;02O]Yl005mO02`/;00005l0;2`/08F5Q@2f][H0WinO0P19BDT202`/;00805mOG`1OUel0
GiMO07^BN`25QHD0;2`/04U9B@25QHD202`/;00B05mkG`00;000GemO0:NWY`1OUel0GlEO0<G5U`1@
D500;2`/0<G5U`1cLg<0;2`/04U9B@2GUiL0<4aD04U9B@3_aLD0GemO2?ooool000Kooooo00D0000/
00000019000001H0000/000302`/;006000/000/;2`0BDU905mOG`25QHD0GenG0P1OGel00`00Gel0
>c/k0000;00202`/;00@0000;000Gel0;2`/08>3P`3De=@0kno50;Jf]P35aLD0UiNG0:NWY`2OWh<0
kno_0>o_a@0/;2`002`002`/;0<0000/01<00000001OG`3De=@0kno509NGU`2f][H0dm>l0?ook`3o
klD0aNo502`/;000;000000002`F5P00Gel0GiMO09NGU`2GaLD0BDU90080;2`/00h000190<G5a@3_
aEl0;0000000;019BDT0`m[305mOG`00;000;2`/000/00000000QHF50<?;TP<0;2`/00D0aOoo09NG
G`2WYjL0Yl=k0<FGG`0202`/;00705nGU`3oool0;2`/01H/5P3De=@0GiNG0;Jf]P0202`/;00<05o5
U`0/;2`0QHF50000002WYjL005l005nGG`0/;2`0GemO04I6AP19BDT0;2`/0P1OG`001`00Gel0UlFG
02`/;00/;2`0BDU90<G5a@2GUel00P00;00202`/;00[0:NWY`35kiL0GemO05nGU`25QHD0LXib09NG
U`3oklD0Lg=c04U9B@1OGel0UiMO09ZJJP3QhN40kno_0>o_a@19BDT005mO04U9B@2^[YL0BDU90:NW
Y`2GUel0GiMO001OG`2GUel0C7US05nGU`2WYjL0QHF50:NWY`1OUel0000006>>N02f][H0UlG50<G_
k`1OG`00;2`/000/0000<1H0aLFG0>7Qh@0204U9B@0902`/;000;000;2`/02`/;03okol0BDU90000
;00/;2`0000/0080;2`/00/0UlG509NGU`0/;2`0;00009O5G`2GUel05R`F000/000/;2`0Gel004U9
B@02001OG`05079bSP1OGel002`007=cL`0/;2`00P25QHD0301ONel0BDU902`/;01OUel0GemO05nG
U`1cLg<0GUiN02`/;019BDT0Gel007=cL`80GiNG01L0JVYZ05mOG`1OUel0;2`/04U9B@1cLg<0GemO
01HF>`2GUiL0QHF50;Jf]P2GaLD0GemO02`/;00FATH004T007=cL`0002`0GiMO09O5U`35UiL0Lg=c
071`E002000/000709NGG`1OUel004T005o5U`25W8D0;2`/09NGU`0202`/;080YjNW00/0AV960;Jf
]P1OGel0;2`/000/002WYjL0GiMO03/k>`35aLD0][Jf04U9B@08ooooo`001_ooool01@000000;000
0000;00`5S0002`00080;2`/0`00;00060005P00;0000000;00/;2`0BDU905mOG`00Gel0O7al05nG
U`2GUiL0YjNW09O5a@35klD0aLG50=?Xd`3De=@0QHF509NGU`2f][H0kno50=CDe035f/D0e=CD05mO
G`80BDU90`0/;2`07@0`5P00GiNG05mOG`3_knl0e=CD08F5Q@2GUiL0GemO000/000/;2`0aLG_001O
0019BDT0;2`/03/k>`1OUel0aNo50;Jf]P0/;2`002`002`00000;000000005nGU`3_aIL0Lg=c05nG
G`2WYjL0ooO_00<0;2`/00@004T005nGG`3De=@0P8200P0/;2`0;@1OGel0aNoo0?o_a@3oolD0ooOg
09MO0000Gel0GemO0=CDe02f][H0;2`/02`F5P35aLD0;2`/09O5U`1OUel0Uno509NGU`0FATH0Lg=c
000/001OGel0UlFG0<G5U`0/;2`0BDU905A`E00/;2`0BDU902`/;01OGel0GiNG05mO001k[W/0;2`/
04U9B@1cLg<0aLG505mO0000L`005R`F02`0000002`0hN7Q0>ooa@020>o_a@0H0=[5a@35aLD0koo_
0<G_a@25QHD0Gel00:NWY`0k>c/0o?cl05mOG`00;000;2`/04U9B@2WYjL0Fe]a0=CDe02WYjL0GiMO
05mOG`0/;2`0aLFG031`<01OUel0YjNW0P0/;2`03@2GUel0GiMO06>>N035aIL0000/09NGU`2GaLD0
;2`/02`000005QH0][Jf0<G5a@1OUel0100/;2`0100/5QH0e=CD0<G5G`1OUel208F5Q@0C09O5U`3J
kmX0UemO02`/;02WYjL0aLG505mOG`0/;2`05QH/001OG`19BDT0GemO04U9B@1OUel0GiNG04U9B@1O
Gel0001O0:NWY`0205nGU`0J05mOG`16HTH0GemO02`/;01OGel0Lg=c05mOG`00Gel0>SY@04U9B@00
Gel0QHF505nGU`2WYjL004T004akN`00Gel0;2`/09NGG`19BDT0;2`/05mOG`2>SW80UlG505nGU`00
B@0202`/;00404U9B@1@D50002`000190080GemO00L0001909NGG`00B@00N7Qh02`/;02GaIL004T0
0080YjNW01<0GemO02`/;035aLD0QHF500000000B@00YjNW05mOG`0U01H0aLG507=cL`0/;2`0BDU9
09O5U`1OG`00VYZJ0<FGG`19BDT005mO00Sooooo0006ooooo`0;02`0000002`0;00002D05P00;000
B@00000/00000000;2`/0000;00F00000P0002`302`/;0040000;00F5R`0;2`/02`/;0<0Lg=c00d0
05mO03/k>`0/;2`0;2`/02`0000/;2`0Lg=c0;Jf]P3Jf^l0hN7Q0>o_a@35klD0][Jf00<0YjNW00L0
[jn_0<G5a@3QhN40BDU9000/00000000000/00<0;2`/00T0aNo508F5Q@1OGel0GiMO05mkN`2WYjL0
][Jf000/000000000P0/;2`00`0F5QH0GemO0<G_a@020>7Qh@030<G_k`2f][H0Xj>S0080BDU901l0
05l007=cL`35klD0aLG501H/5P00;00005mO05nGG`3QhN40YjNW05mOG`1ZJVX0aLFG05mOG`2GaEl0
hN7Q04U9B@0/;2`0NHj>05mO000/;2`0][Jf09O5U`2GaLD0aLG505mkN`0/;2`0000/09O5U`190000
YjNW0080GiMO01<0E5AD05mO000/;2`0;2`/05mOG`19BDT0Lg=c06VLQ@35aIL0UlEO05nGG`2GaLD0
aNo50;Jf]P2OWil0GiMO0<G5a@3_knl0;2`/0080000/01405QH/000/000/;2`005mO0>o_a@00;000
;2`/0300AP3oklD005l0000/000/;2`0GlEO0>o_a@2TY:@0aING05mOG`0204U9B@0E0000001cLg<0
HV=S0:NWY`2GaIL0B@00000/0035aLD0UiNG05A`L035knl0;2`/0000;000;000UlG509O5U`1YQHD0
YjNW0<G_a@1OUel0GemO0080UiMO00@009MO0:NnY`3De=@0oooo0P35aLD01`35knl0][Jf06MWI`35
klD0aLG504U9B@0002`00P0/;2`01P0UBBD005mO04U9B@19BDT0GiMO05nGU`80BDU900D0GiMO05nG
U`1OUiL0GemO05nGG`0304U9B@0605nGU`1OGel0BDU904U9B@00Gel09E@U0P1OUiL01P25QHD0BDU9
04U9B@2GUiL0;2`/0:NWY`80BDU900@0GiMO04U9B@1OUel0E71`0P0/;2`04P1OUel0BDU900000000
;000GemO09NGG`2GaIL005l002`/;01OUel0000/09NGa@1kTY80UiNG04U9B@0/;2`0UiNG05mOG`80
;2`/0140aLFG05mO0000B@00GiMO0<G5U`1OUiL05THF09O5U`00G`00;2`/0<G5U`2f][H0GiMO0<GJ
[P19BDT0B@0005mOG`08ooooo`001_ooool0100002`00000000/000F01H2000/00050000000/;2`0
02`004T0000001H00`000000100/;2`0000/02`0000F5R`202`/;00<02`0000002`0;2`/04U9B@1k
NiL0GiMO05o5U`2f][H0aLG_0>7Qh@2f][H0ATI60P0/;2`01P35UiL0kno_0>7Qh@3_knl0hN7Q0=?X
j0<0;2`/00`0000002`/;00/;2`0<4a`05nGU`35klD0e=CD0<G_k`35kol0aNo_0?ook`19BDT202`/
;0080000;00/;2`002`0031R<035aLD0YjNW0000;00/00020000;00<07RWY`2GUel0UiNG0:NWY`3o
onl0oooo02`/;00F;1H0BDU905nGU`3QhN40klG50P0/;2`01@1iSXh0ooo_0?o_k`35aIL0aLG50080
;2`/0140[Jf]02`/;019BDT0][Jf02`/;000Gel0e=CD09;5[P19BDT0000009NGU`0/;2`0GiMO05mO
002f][H09E@U04U9B@0202`/;00504U9B@1OUel0BDU9071`E00/;2`00P2WYjL03`2GaIL0e=CD07=c
L`2GNg/0YjNW0;Jf]P35aLD0QHF505nGG`0/;2`0;1HF04T0001OGel0koo50000000202`/;00:0:k5
[P1OGel0;2`/05nGU`35aIL0Lg=c09MOU`2LW8L0BDU909NGG`80BDU900<0;2`/05mOG`1<L4`00P2G
UiL01@35aIL0;2`/00000035klD0SXj>0080YjNW00T002`00000;000;000aLG50<gRhP2WYjL005mO
09NGU`2f][H00P2GaLD03035kol0QIbL04U9B@0/;2`002`00000;00/;2`0][Jf0:NWY`1OGel00000
04T00080000/00@0;2`/03/k>`0005l0UiMO0P1OGel02`19BDT009MO05mOG`1OUiL0BDU907=cL`19
BDT0GemO001OG`1DL700Lg=c0080BDU900L0GemO02`/;000G`00LW9b07=cL`0/;2`0GiMO0080;2`/
00<0BDU908f=S@19BDT00P0/;2`209NGG`80BDU90`1OGel0501OUel0B@000:NWY`1@D50004T005nG
G`0/;2`0UiNG05nGG`1OGiL0GiMO069RHP1cLg<0;2`/000/0035aLD0QHF502`/;01DJU@0GemO0P0/
;2`03P2f][H0UiNG001O002?Shl0][Jf02`/;035aLD0aLFG0019003QhN40Ph>302`/;0190000GemO
2?ooool000Kooooo00P0;2`/000/00000000000F02`000000000;00002`/;08002`000P0;0000000
00000000;0000000;0000000;000000/00@0;2`/0P00;0002P0F5R`0BDU905mOG`1cLg<0GemO001O
000/;2`0>c/k02`/;019BDT202`/;00L05mOG`2WYjL0UlG50;jn_P35aLD0UiMO05nGG`19BDT0UlFG
05nGU`2fbkH0aNo_0;Jf]P1OGel005mO02`/;019BDT0VYZJ0>o5U`0/0000;2`/001O0000Gel0Gel0
09:WTP2f][H0;2`/0000;080000000`0UiNG09;3``35onl0aOo_0<G_k`3De=@0ooo_02`0001bSXh0
GiNG0>o_a@2f][H202`/;00<000/003Cdm<0BDU902`/;00002`0olG505mOG`2GUel0YjNB02`/;02f
][H0aLG50P0/;2`05P35klD0E71`05mOG`19BDT0GiMO0000002GUiL0BDU907=cL`1OGel0BDU905mO
G`0/;2`0BDU9001OG`1OUel0L71D05mO0000B@00;2`/0000B@35aIL202`/;00A000/0000B@00000/
0?o_a@35olD0UlFG079bLP1cLg<0ono_09O5U`25QHD0Lg=c0<G5U`2OWil0aLG50<G_a@2f][H00P19
BDT0803De=@0<5mO0>o_a@1OGel0;2`/000/001OGel0;2`/0:NWY`1cLg<0000/0:NWY`2GUiL002`0
09NGU`0`C300;00009O5U`25QHD002`002`00000;000YkjW000/000/0000;2`/000/000/;2`0ono_
0019000/;2`0000/0P0/;2`02`2GUel0kno50<FGU`0F;1H0UemO04U9B@0005l005l007=cL`0/;2`0
E5@U0080BDU900L005mO05mOG`00Gel0BDU905nGU`19BDT0GemO00<0BDU900X0Lg=c05A`L019BDT0
GemO04U9B@1O05l0QHF505nGU`1DE2D0GiMO0P19BDT05@2GUel005mO001OG`1YQHD0QHF509NGU`1O
Gel0;2`/000/001OG`00>c/k05mOG`2GUel0GiNG05nGG`19BDT0GiMO04I65P2WYjL0;2`/05mOG`02
04U9B@0A0:NWY`0/;2`0HhM<05mOG`00B@00BDU90<G5U`19BDT0;2`/06=SL01cLg<004T005o5a@2W
YjL0GemO05nGG`1`Qg000P3De=@01@35aIL0BDU902`/;035aLD0GiMO0080;2`/00<0BDU9oooooooo
ool01_ooool000Kooooo03<05QHF01H0000F5QH000/;000/0000000002`000005P00;0005R`F00/Q
5P005P009@0001H/5P0F5P005P0F01H/5P0Q2aH001HF01HF000k5QH002`001H0000001H08B4Q02`/
;00F5R`0;2`/01HF;00F01H0AV9R069^KP1bLW80LXj>08FLW02BTZh0TY:B0727Q`1iSXh0KVI^04IR
HP1DJU@0WkJO09MkC01kNel0`mZG0;BdT`1hNF<0C7U<069iHP1iSWT00P1aLG40101VLFL0_ZNW0:j^
N`2LW8D20<^f]P2A07QhN02LYY40HTHF069RAP16HTH0N7Qh09nf]P1<Qf<0H6YP01Hk5P0/;2`0ATHF
04IRHP35koL0[/^W0<[:]@3Bd]80[Y9h03/k>`0F5P00<3160:kRfP1ZKVX05R`F051@D03JmmX0SXj>
08N7Q`2PX;`0_;b]0<?JTP2^aLD0ATHF03/k>`1<Qf<0N7Qh03@d=01DL700JVYZ0;jnY`16HQH0NiMk
03/k>`1OGel0HgmS04IRAP0UBBD0<5mO0316<00k>c/05S/F04df=P1OUel0Nf=O04a`C01aLG40Ph>3
0:kJa@20YH`0TY:B09ZJVP1SYi80]/_;0820P01RHTH08B`Q02DU9@1`L700aLG507UiHP0U9C/05R`F
01hN>`3JhZh0C5mO05A`L02BTY80Ph>309;3[P25QHD0AV9607]kG`0`Gc00>c/k08j>SP1kTT`0KWal
072LQ`1k[Y80;2`/069RHP1<L4`0L8M`07=nL`0U00005QH/04aiC01hN7P0UlF^08^;Y`1ZP800Ujik
08f=S@1iSWT0HWUR0820N02fcLd0TZNW06=lL@1ZJVX0<8M<0<G5U`35fYL0JVYZ02Dk9@1iNGP0NHjF
08^WR`3CbkH0L71`031SHP1RNGT0GUiY05B3P`2;Rh/0_ZN;06=hN@0FATH0NiNG06j:O019BDT0E5AD
031kN`1OUg/0<7]k06UYJ@0fFdd0JFTj05A`L01NGUh0C7]k05A`E00k>c/0CE]=04I6AP0306UYJ@0Z
06V5Q@0`Gel0GhU]031OG`0UBBD0;1HF03YY>P0`G`00E71D04IRAP0UE2D0AV96075aL@0UBBD0GUiN
069RHP19NU<0E71D07^GN`0UBBD0;2`/05n^N`16ATH05R`F09BRR00UBBD0QhM`075aL@1STT`0L8M`
07^GG`1fSGH0Hi:B0:NWY`16ATH0>c/k0<GJa@2B[YL0@Dm105ADE035aLD0JFUY0P0/;2`01@3_f/D0
Fg9b02`F5P0002`09EAD00Sooooo0006ooooo`8002`000X0000001HF;00002`000000000;0000000
000/04T0000F000000000P00;0000`0/0000000/000/000202`/;08002`000@0;2`/000/0000;000
5P000P0000008P19000002`0000/000/;2`0000/02`/;000;000;2`/0000;01OGel005mO04U9B@00
Gel0UiMO05mOG`2WYjL0aNo50>o5a@0/;2`0>VUY0<G5a@3_klD0e=CD0;Jf]P35aLD0QHF503/k>`1O
05l0YjNW0<G_a@2WYjL0aNo509NGG`1aLG420;Jf]P0>09O5U`25QHD0;2`/02`/;0005QH0Gel008F5
Q@2f][H0aOo_08F5Q@0002`05R`F05nGU`3QhN420<G_k`0=0=CDe025QHD0;2`/05mOG`3_ool0BDU9
0000;0000000aLG5075aL@3oaNl0klFG02`/;00209NGU`0C02`/;01ZJVX0;2`/000/002WYjL0Lg=c
09O5a@19BDT0GemO04U9B@1OGel0UiMO02`/;019BDT004T002`/;016HTH0BDU909O5U`020019000<
05mOU`35knl0C68`0000;000;000;2`/09NGU`2f][H0QHF506UYJ@35klD0aNo_0P19BDT04@00B@00
GiNG0>ogk`35klD0e=CD0:NWY`0/;2`0GiO504U9B@1hN7P0UiNG04U9B@0/;2`0BDU909O5U`00;000
NiNG0080;2`/0140][Jf02`/;000Gel0aLFG069iHP2GUiL0Gel0000/00000000GiNG0;Jf]P005P00
;2`/0000;000;000GiNG0?ook`020019000J001D<019BDT0aLFG04U9B@00B@00GlFG02`/;02G[W/0
aNo50>7Qh@1OUiL0YjNW0<G5a@2WYjL0f^o_05nGG`0002`0;2`/07=cL`35aIL0;2`/05mkN`1OGel0
BDU905nGG`1OUiL204U9B@0405nGN`1cLg<004T007=cL`80;2`/02P0BDU905nGU`1OGel0BDU905nG
U`1OGel0Lg=c02`/;00`Nel0Gel005mOG`19BDT0UiNG05mOG`19BDT0AWU602`/;01OUiL0BDU909NG
U`19BDT0GiNG03/k>`25QHD0GemO0000B@2WYjL0UlFG04U9B@1OGel0>c/k09O5U`00Gel0;2`/04U9
B@2GUel0GemO0016<035UlD0BDU90P0/;2`01P2WYjL0UiNG04I6AP1OGel0klG505mOG`80;2`/00D0
kno508F5Q@0/;2`0001O04U9B@08ooooo`001_ooool02000;000000/02`/;00F5P00000/02`00000
;000000/0P00;0001@0/000002`002`00000;000;00000<0;2`/00L002`002`00019000002`002`/
;000;00001H00080;00000P0000/02`/;000;000B@00000/00000000;2`/0000;080;2`/00@0000/
02`0001ZJVX0QHF50P3_klD302`/;00?07QhN035klD0aNo50<G_a@3_klD0e=CD0>o_a@3=cLd0e=CD
0:NWY`1cLg<0GemO05nGU`35aLD0bl^f0080;2`/00P0Uel0002GG`2WYjL0UiMO09o;]P2f][H0e=CD
05mOG`80;2`/00/0000/04a`C035aLD0GemO02`/;00002`0aNo_000/000`L4`0kooo05mOG`0202`/
;00P0<G_a@2WYjL05QHF0<G5k`3_klD0YjNW0;Jf]P3_aIL0BDU908^WY`19BDT005l009NGG`0/;2`0
YjNW05nGU`2WYjL0AV9602`/;01OaIL0QHF505mO0000Gel0;2`/03/k>`1OGel0BDU909NGG`1OGel0
;2`/001OG`2n_ZL205nGG`0D05mOG`00Gel0GiMO0<G_k`2n_[h0YjNW0<G_a@2GaLD0aNo_0;Jf]P1c
Lg<05S/F07=cL`3_aLD0;2`/0:NWY`2f][H0YjNW08N7Q`1OUel202`/;00D05mOG`0/;2`0;2`/09nf
W`2GUel0;2`/08F5Q@1OaIL0GiNG0:NWY`0/5QH0GemO0:NWY`35klD0aLG_0=CDe035aLD0NiMk05nG
G`1OGel209O5a@0Q0<G_o`1OaLD0YjNW0<GJ[P00;000001909NGU`2WYjL0Gel009NGU`2W_ZL0GemO
09O5U`2GUel0UlFG0;Jf]P2GaIL05QH/09NGU`35aLD009MO04U9B@35aLD0GemO07^^N`1OGel0BDU9
05mOU`19BDT0QHF505nGU`1DL700;2`/0080BDU900l005mO05nGG`1OUiL0GemO05nGU`1OGel0BDU9
0000B@00B@00;2`/07QhN02GUel0QHF504U9B@00B@000P0/;2`0501DQe@005mO05nGG`1OUel0GemO
04U9B@1OUel0;2`/05nGU`19BDT005l00;Jf]P1OUel0YjNW09O5U`1DE5@0][Jf05nGG`0002`0;2`/
0P1cLg<04P0F;1H0][Jf07=cL`000000;2`/0:NWY`2GUiL09C/U05mOG`35aLD0GiMO04U9B@0004T0
kno509FEU@1OUel0aNo505mOG`Sooooo0006ooooo`80000/00@002`001H000000000;0000P0002`0
0`000000;000000F00020000000302`0000002`002`00080;2`/00<002`00000;00/;2`00P00;000
1P0/;2`0GSXj000/00000000000/02`/;08002`001005R`F02`0000/;2`0000/02`/;00002`0;000
0000;01iNGT0aLFG05mOG`00B@00;2`/05nGU`35aLD0][Jf0`0/;2`01@00B@00UiMO0<G_a@3JklD0
aLG50080aLFG00`0YjNW0>o5U`3De=@0T/F^0:NWY`3QhN40aLFG05mOG`2f][H0UemO031kN`35klD4
02`/;00608F5Q@2>YHh0;2`/02`/;000;000GiNG0P35knl03`3Cj>P0aLFG000/000/;2`0knoo0:NW
Y`0/;2`0<4aD0<G5a@19BDT0;2`/0;Jf]P3_aIL0UiNG09nf]P0205mOG`0D05mO000/;2`0aLFG02`/
;02GaLD0E71D000/000/;2`0GiNG05mOG`0/;2`0BDU902Dk9@0/;2`0Gel005nGG`00G`00YjNW09O5
U`1<TY8309O5a@80aNo_00H0UiNG05ADE01OGel0BDU90<G_a@25QHD202`/;009051@D035aLD0;2`/
05nGG`2f][H0kno50<FGU`1DE5@0UiMO0080BDU900l0QHF502`/;02GaEl0HV9R05mOG`2GUel0;2`/
05mOG`1cLg<0QHF506YZJP000000;2`/0:NWY`1OUiL00P0/;2`01P0k>c/0][Jf0<G_a@19BDT00019
02`/;08002`000P0TY9<04U9B@1cLg<0QHF50:NWY`3De=@0UiNG05mOG`80GiMO01X0UiNG0>7Qh@1O
G`00GemO07RLH`00Gel0GiNG09NGU`25QHD0aNo505mO001DE5@005mO05nGG`1OGel0GiNG08F5Q@1O
Gel0E5AD04U9B@00Gel0YjNW05nGU`1cLg<009NG06MWI`80;2`/00X004T005nGG`00;000GiNG09nO
W`0002`0BDU90019001OUel000190P1OUel02P0/;2`0000/05nGG`19BDT0QHF504U9B@1@D500GlFG
04U9B@2GaIL204U9B@050:NWY`2GUiL05R`F0<G5k`25QHD00P0/;2`05025QHD0Lg=c02`/;02f][H0
GenG0019000/;2`0YjNW09NGU`0UE5@0aLG50>o5a@2f][H000190<G5a@1OG`00f][50<G5a@1OGel0
BDU92?ooool000Kooooo00/002`002`0000000005QH/0000000002`002`002`0000002`0B@00000/
000300000080;2`/00@002`001H00000000000000P0002`03000;000;2`/05ADJP00;000;0000000
000/000002`002`/;00F5R`0GiNG000/0080;0000P0002`00`0/;2`0VYZJ0=CDe0020>o_a@0>0;Jf
]P35aLD002`002`F5P0/0000;2`/0;Jf]P3QhN40][Jf000/000/;2`0kno_0>7Qh@2GUel202`/;00:
04U9B@16AQH0GemO09O5G`1OUel0aLFG05mOG`2f][H0TY:W0<FGU`80;2`/00H0UiNG0;Jf]P35aLD0
AQI602`/;000Gel20<G_k`0705mO000002`0SYJF0<G_a@3QhN40aNo50:NWY`0202`/;00C09:WY`1O
Gel0;2`/02`/;02GaLD0][Jf07=cL`2n_[h0;2`/07=cL`19BDT005mO07=cL`1O05l0UlG509O5[P0/
;2`002`002`/;00205nGU`0304U9B@16AQH0;2`/0080;2`/00H0Lg=c001O000/;2`0YjNW09O5U`0/
;2`20000;00B0019002WYjL0dm?C0:NWY`2GaLD0YjNW0<G5U`00Gel0UlFG0<GJfP3De=@0aLG505mO
G`2WYjL0aLG504U9B@1iNGT0GemO0P19BDT03@1OUel0GemO0:NWY`1DE5@0000/07=cL`19BDT0QHF5
02`/;000B@00E5AD05mO001OUel00P2GaLD01P1OUel0;2`/03/k>`1OaIL0aNo_0;Jf]P<0aLFG01/0
UiMO01I6AP3De=@0;2`/0<G5U`3_klD0UiNG09O5G`0`QC00QHF50019000/;2`002`009O5U`1OUel0
VYYZ0<G5a@3De=@0Gel002`/;01OGiL0hN7Q01I6AP1OGel0GiNG07=cL`1OUiL00P19BDT0300`Nel0
GiNG09NGU`1OUel0GiNG05mOG`19BDT0>c/k02`/;01OUiL0GiMO09O5U`80;2`/00@0HV9R05nGG`0/
;2`0QHF50P1cLg<00`19BDT0JFUY02`/;00207=cL`0E0019002GUiL0GemO04akN`1OGel0Lg=c05nG
U`19BDT0;2`/0:NWY`00Uel05R`F0;Jf]P1OUel0;2`/0019001OUel0GemO01HF5P35UlD0GlFG0080
;2`/00d0][Jf0=CDe00UE5@0e=CD09NGU`3QhN40klG_0<G5U`0/;2`0[/>B0>o_a@00Gel0GemO00So
oooo0006ooooo`0<02`00000;000000001HF5P00;00000000000;00/0000;2`/000/000F0000B@00
0P0000001P0/;2`002`002`/;00F;1H002`0000000<0;2`/00@0000002DF0000;00002`00P0/0002
000/000301HF;00/;2`0;00000<0000000@0000/001OG`2WYi80BDU90P0/;2`01`00;000kno50<G_
a@3_olD0e=CD0;Jf]P19BDT00P0/;2`00`25QHD0f^o509MOG`0202`/;00@05mOG`3_klD0BDU9051@
D000B@00;2`/05mO002f][H0aLFG09NGG`2>SW80;2`/09NGU`3_klD0QHF50<G5k`80;2`/00h0YjNW
0<G_k`1OGel000000000;000;000Ykjn0;Jf]P2GUlD0hN7Q05mOG`1OG`00UlEO0:ZZZP80;2`/00T0
05mO0<G_a@19BDT0;2`/0<_Ja@35aLD0UlG502`/;01OGel00P19BDT01P2GUiL0LG5a05nGG`0/;2`0
05l004U9B@80Lg=c00/0AV96000/0000B@00BDU905mO002GUel0GiMO03/k>`25QHD0][Jf0:NWY`02
09O5a@0:0=CDe019BDT0;2`/05mOG`0004T0kno508F5Q@0/;2`05TI60<G5a@80BDU90P35klD04P2f
][H0>VUY001O000/;2`0BDU905nGG`1OUiL0UiNG04bBN`00B@0002`005o5U`1cLg<0][Jf02`/;000
02`0QHF50;Jf]P80Lg=c01T0][Jf09NGU`1k[Zh0UlG504U9B@00B@00BDU90019002GaIL0Gel007:U
SP0/0000GemO09MOG`1cLg<0aLFG05mOG`2^fZh0000/02`/;01OGel00019000/002GaEl0YKZj0080
;2`/00T0aLG502`00000;000UiNG0>S`d`35knl0B@0009O5G`19BDT00P1OUiL0101ONiL0GiNG05mO
G`00Gel302`/;004031OG`25QHD0;2`/07=cL`80;2`/00@0UiNG031kC01OGel0Lg=c0P19BDT0101O
Uel0;2`/05iNGP19BDT20:NWY`0>09NGU`25QHD0GiNG05A`L000Gel0GemO08F5Q@1OGel002`007=c
L`1OGel0>c/k0>o_a@19BDT202`/;00D0:NWY`1OGel0;2`/09NGU`3_klD0;2`/001OU`3_klD0][Jf
0<c<c01OG`00BDU90:NWY`3_aLD0BDU902`/;01RAV80GiMO07=cL`1OGel8ooooo`001_ooool03P00
0000;2`/0000;00F5P0002`002`0000002`002`002`0000002`05QH00000;0190000000/0P0/;2`0
400000009AH0000000000000;2`/0000000002`0;2`/01H/5P0/;2`002`00000;0190000000/02`/
;00/5QH204T000<0;2`/00<005mO05mOG`2LQhL00P0/;2`02`0002`0UiMO0<G_a@25QHD09E@U0<FG
U`19BDT0UiMO0<G5a@3QhN40YjNW0080;2`/028004T00<G5U`2WYjL0GemO05nGG`35[YL0QHF505nG
G`1OGel0BDU905mOG`3De=@0ooOJ0?clo01OG`00;2`/0?o_a@2f][H0kno50:kJ[P35knl0;2`/000/
000002`005mO0<G_k`0F5R`0;2`/09NGU`35klD0UenG07=cL`2f][H0U9BD0P00;0001P35onl0GemO
02`/;00/;2`0]/_;000/0080YjNW00L0klG502`/;019BDT0GemO06YZJP1OUiL0GiMO0080;2`/00@0
BDU905nGU`0UE5@0Gel00P0/;2`01P19BDT005mO05mO002=SHd0aLG505mOG`80;2`/0340BDU909O5
k`2fbl/0UlFG09O5a@35aLD0GemO00190019BDT0V[Jf001OG`35aLD0klG5001OG`35klD0BDU905nG
G`1OGel0;2`/05nGG`00;000UlFG05mOG`1DE5@0UiNG0000;01OUiL0YjNW02`/;02GUiL0[Zik0:NW
Y`35aLD0GlFG04U9B@0/;2`0Gel009;J``2GaIL0UlG508F5Q@35aIL0QHF5001O0035klD0C9:B0<FG
U`0/;2`0BDU90080UlFG00H0][Jf04IRAP2WYjL0;2`/0019002WYjL209O5U`0?01HF5P2f][H0BDU9
0019003De=@0UlFG0>7Qh@1<AS00GemO0<G5U`00Gel0YjNW05mOU`1OGel0E71D00<0;2`/01/00000
02`/;00002`0C4a604U9B@1OUiL0BDU905mOG`25QHD005mO051@D01OUel0BDU902`/;02GUel0BDU9
0019001bLT<0YjNW0019001OG`00UlFG001OG`19BDT0PinO02`/;019BDT00P1OGel04`0/;2`0G`1O
05nGG`16ATH0UiNG0<G_a@00Gel0;2`/0<G_a@1OUel0E5A`0<G_a@2GUiL0GiNG0>o_a@0/;2`0001O
09nf]P19BDT00P0/;2`01`2GaIL0GemO000/000`AS00UlFG05nGU`19BDT02?ooool000Kooooo00P0
;0000000;00/000001HF00000000;0000000000/0080000/00T001H002`0000002`0;2`/0000;00/
0000000/01HF;000;0000`0/;2`0200002`002`0000/000/;2`000000000;0190000;0001000;000
2P0/;2`002`005mOG`1OGel0kno502`/;000;000;2`/08F5Q@2WYjL202`/;00;0:O3TP2f][H0aLG5
09NGU`1OG`00aLG_001O002BTW/0aNo507=cL`0/;2`00P00;0008@0002`0QIb505mOG`1OGel0kno5
02`/;0000000B@0006ZJVP0/;2`0aLG50<G5U`2GaLD0kno509O5G`1SNg/0ooo_05mOG`1OUel0aLFG
0:NWY`0/;2`0>c/k0<Gok`2GUiL0;2`/0000;000;00005nG0:o;[`2GU`00e=CD0<G5a@0202`/;00a
05nGU`1IFET0BDU90=CDe00/;2`0aLG509NGU`2GUel0;2`/05ADE01OGel0UiNG09O5a@190000;2`/
04U9B@0`Nd`0GemO00000019BDT005l005mOG`19BDT0<70`04U9B@2f][H0GlFG001OG`19BDT005mO
09:^a@1OGiL0Lg=c0:NWY`2f][H0UlG50<G_a@0UBBD0YjNW02`/;000Gel0][Jf07=cL`35aLD0L71D
04U9B@0/;2`0UlG502`/;00205mOG`0:06YZJP2GUiL0GiNG09O5a@2WYjL0BDU902`/;01NGUh0BDU9
05mOG`80][Jf0P2GaLD0501ONi80;2`/02`/;000;000UlFG05mOG`1OUel0;2`/05mkTP1OGel0Gel0
09NGU`1cLg<0aLFG0000001<HT`0GemO05nGG`1cLg<0aLG50P0000003P1RNDH0GiNG0<G5a@35klD0
][Jf04U9B@3De=@05QHF000/003oklD002`002`/;02GGiL0GemO0P0/;2`03P00G`00BDU90000;02G
Uel0BDU9032GN`1OUiL0GemO09NGG`1OGel0;2`/05mOG`0U9C/0GiMO0P0/;2`03`1cLg<0;2`/05nG
U`1bSW80aLFG05mOG`19BDT0YjNW05mOG`00;000Njik02`/;019BDT0GiNG05mOG`0202`/;00=0<G5
U`0UE5@0aLG_09NGG`35klD0GenG09NGG`00Gel0[jn_001OG`19BDT0e=CD07=cL`0202`/;00608^W
Y`19BDT002`00000002GUiL0Lg=c0P0/;2`00`2GaIL0GiNG05mOG`08ooooo`001_ooool01@0/0000
5P0002`F5P0;5QH0>bDU0080000000@05QHF00005P0000005P/F0`0F;1H03P0/5QH001HF000F5P0;
000001H0000F5P0F5R`0;2`/000F5P0/5QH02b`;04a<C00F5P00;0000P0U01H07`0F;1H02`/;06M3
@`27Hd`0JX1Z0:jBTP2^[Zh0dnSC000F001JIEX0TY:B069RHP1ZJVX0;2`/069RHP2_[jl0CdmQ0000
B@0k>c/0HgQi08NLQ`1aLG40JVYZ0<Vn_P1hN7P0LW9308n?S`1kTW/0SXii07]kG`1QEUH00P1<HT`0
PP1DE5@0YJF>08>3P`2USXh0UIV=07URAP0k>c/0;2`/09baW02>NGT0;2`/0:>a_`2BTY80YjNB0<G5
[P3<c<`0[Y9k05AD9@2=/jL0HWU604IRAP0k>c/0Hhih0:n_[`27Qi`0Bd];03/k>`2n_[h0aNog07RF
N02BYjL0_]_C04A?A01iSWT0>c/k06=SN@23Ph<0<7]O0:Nn_P1aLG40<65F05A`E01DE5@0BDU904ak
G`1`L700E5AD02iD?013LW80BDU9031R<00F;1H0>c/k02ED9@1DHU@0IfMW05nBTP2_[jl0Lg=c04IR
HP1RNGT0OYR:09FEU@25QHD0L71`0;Jf]P1kNg/0NHii09N]X`1`Qg00L8N7071`L02W_[h0YjNB05A`
E01=Fd@05TI602E99@0F;1H0AV96031kG`1DL700HGYj04IRAP2B[Zh0E5AZ01H05P2LW8L0QhN709JF
R`1cLg<0E8>305AZE01RNGT0YjNW08^;R`0kEdd0<7/`07^GN`1YJFT0<5mO07alO025QFT0QIb507JV
/@2GUel0<4aD069RAP0`HS00HV96079bLP1eME/09C/U05UIF@1<C700;2`/069RN@1aLG40M7mY07]k
N`0k>c/05QHk0;kC_P0k5QH0<5mk08nVL`1RHV80[Zin02`/;00k>c/201H/5P0m000`2`16ATH0LW:>
04I6AP1OGel0<7]O04IRAP1<Hf<004H`04U9B@1OGel0>c/k06MWI`1YJFT0;UAO07^GU`0`E300SZFU
08>3P`2>SXh0NiMk05e[J`1ONel0<5mO03/k>`2GaG/005mO02`/;02;YiT0>c/k05nBN`23Wil0<7]O
04U9B@33f/D0NHii07N?T@20P800BDU90316<03=cLd0<5mO02`/;01^N6d0Gg]O01H/5P1`L700NiNG
03/k>`0F>aH0Zif[031OG`0k>c/0;2`/0;kC_P1YJFT05TIR024Q;03Rh/d0LXj>02EDE008ooooo`00
1_ooool01`00;000000/04U9B@0/5QH0000/0000G`0000000P0/0000100002`002`0000/000002`2
000/0080;2`/00P002`002`0000/0000;2`/0000;00/;2`0000002`F5P80;2`/0180000/00000000
;0000000050j>P3De=@0BDU90000;00/;2`0e=CD0>o_k`35aLD0f^o50<FGU`00B@00BDU90<G_a@3_
aLD202`/;00/09O5U`35klD0;2`/02`/;000;000kno505AZE00/;2`0GiNG0;Jf]P2GUel0YjNW0;Jf
]P2^[W/0klG508F5Q@00;000;2`/05mO002f][H0E5AD08F5Q@0/000005mO04U9B@1OUiL0UiMO05AD
L035aLD0B@0004U9B@35knl0;2`/09O5a@2J][H0GemO001OG`3De=@0GiNG04U9B@0/;2`0>aHF0<G_
k`1OGel202`/;00=05nGU`35ool0aNoJ05mO002GaIL0UiNG02`/;000Gel0Lg=c04U9B@1<Ng/0GiMO
02`/;00204U9B@0:05o5U`1OUiL0ATI602`/;01OUiL0BDU908F5Q@0/;2`005l006MWI`80GemO00D0
GiNG0<G5U`25QHD0UiNG09OJa@0202`/;00504U9B@1OaIL0aLFG04U9B@1`QhL00P19BDT06P00Gel0
GemO0;Jf]P1OGel0L5AD02`/;000;000GiL00019001OGel0GiNG01I6AP1cLg<0YjNW09O5a@2GaIL0
05mO05o5U`0UE5@0BDU902`/;019BDT0aLFG001OG`19BDT0JFTj0P0/;2`03@1OUel009MO04U9B@0/
;2`0B@0009N^[P1OUel0UlFG0<G5U`1OG`00QHF5000/001@D5000P1OGel03@2GUiL0BDU90:NWY`00
02`0HV96000/002GaIL0;2`/0000G`2WYjL0UiO505B3P`3lo?`00P00;0006@0002`002`00:NWY`1<
Ng/005mO05nGG`00B@0005mO09NGG`19BDT0E71D001OG`1cLg<0QHF505o5U`1cLg<0GiNG06V5W019
BDT0UlG507=cL`00B@00UlFG04U9B@1IFET00P19BDT02P00Gel0UlFG05mOG`1OGel0][Jf05mOG`2W
YjL0GemO0;Jf]P35klD204U9B@090:NWY`1OUel0;2`/02`/;03QhN40GemO02`/;01iSWT0GiNG0080
;2`/00/0][Jf05mOG`00B@00TZNB05nGG`1OGiL005mO0>ook`2GaLD0QHF505mON`020<G5a@0305mO
Gooooooooooo00Kooooo0006ooooo`0402`0000/;2`0000001HF0080000/00H002`002`00000;000
B@0001HF0000;00202`/;0080000000/0000;2`/000/00000000B@00000/000/00020000;00401H/
5P0/0000000/02`00080000000X0;00006>^[P2GUel0;2`/000/00000000Lg=c0:NWY`25QHD0>c/k
0P35klD01P35aLD0Lg=c0=CDe00/;2`0`l>^0<G5U`80;2`/02P004T00;Jf]P19BDT001HU09NGG`2W
YjL0000/000/0035aIL0YjNW08N7Q`35aEl0UiMO0>o_U`35aIL0;2`/001O0023Wil0GiMO000/0000
02`0;2`/04U9B@3De=@09BDk09O5a@35UiL0Lg=c05nGU`2GUel004T00:jGN`35aLD0QHF509O5U`2G
UiL0aLFG09O5U`2ndkh002`00P0002`02@35klD0][Jf02`/;020P800aLG_0:NWY`0/;2`005l008F5
Q@0204U9B@0N07QhN000Gel0GiMO05mO000/;2`0BDU908F5Q@1ONg/0;2`/04U9B@1OGel0BDU905mO
000/;2`09E@U05nGG`1OGel0;2`/09O5U`1OaIL0BDU901I6AP35aLD0UiNG07=cL`2f][H0Lg=c05o5
U`2fbkH0GemO0`2GaLD05@1OGel0BDU905A`E00/;2`0Gel002`/;019BDT0GiNG04U9B@2O][H0UlFG
04U9B@0/;2`0YjNW0;Jf]P2GaLD0JFUY07=cL`2GaIL0][Jf05mOU`0204U9B@0H02EDE01OGel0UlFG
0;Jf]P35aIL002`007=cL`0/;2`0NlFW02`/;00004T0BDU905mOG`00B@00UiNG07]k<02WYjL0;2`/
09NGU`00B@00GemO0000;01<HS00;0000P2GaIL03@3_onl0;2`/0<G_a@0F>aH0e=CD000/000002`0
][Jf001OG`1OGel0E5AD04U9B@1OUel00P19BDT08@1OUel0;2`/05n^U`1OUiL0GiMO08F5Q@1OUiL0
05mO04U9B@1hN7P0;2`/0;Jf]P19BDT0;2`/0:NWY`19BDT0QhM`05nGG`00Gel0UlFG09NGU`1OUel0
aLG505iNGP2GaIL0GiMO0000B@19BDT0][Jf05nGG`0/;2`0RjNW07=cL`0202`/;00C0<G5a@1OGel0
;2`/075aL@25QHD005mO02`/;02f][H0GiMO05nGU`3Jf/D0koo_05nGU`25QHD0koo50<G5U`2GaLD0
X:2P05nGU`0205mOG`Sooooo0006ooooo`070000;00/0000;00002`F5P00000002`002`/;0020000
0004000/000F5P0002`0000/0080;2`/00@0000004U9B@00;000;2`/0P00;000400/0000000/0000
;00F01H0000/0000000/0000000/000/000004T0TYMk02`/;000;000000/09NGU`2f][H202`/;00<
01Hk5P3De=@0;2`/0000000/;2`0aLG50;Jf]P1bLW80aIMO0019002f][H0aLFG0P0/;2`01013FD<0
UiNG02`/;000B@020<G5U`0602`/;027L700;2`/04U9B@3_aIL0aLFG0P2GUel0100k>c/0YjNW0?o5
a@00;00204U9B@0S0;Jf]P1iSWT0GemO0;Jf]P0/;2`005mO09O5a@00Gel0GUiN000/001OUiL0][Jf
09NGU`35aLD0UiMO0;jn_P1OUel0][Jf0<G_a@0002`0;2`/0000B@1KP5/000190<G_a@3oonl0aLG_
02`/;000;000GiO5031OG`2GUiL0BDU905nGU`1OGel00P19BDT01016ATH005mO02`/;019BDT305mO
G`0B03/k>`19BDT0Lg=c0019001OaIL0YjNW05mOG`23Wh<0GemO05l00019BDT0GlFG08F5Q@1cLg<0
L8N705nGU`19BDT0UlFG0P1OUel0102GUel0BDU9001OG`2GaEl204U9B@8005mO00/0AV9R02`/;02G
aLD0GlFG0019002GUiL0BDU902EDE000UiL0][Jf05mOG`02001OG`0H04U9B@1DL5@0;2`/09NGU`00
02`0UiMO02`/;035aIL0GlG506MWI`2GaEl0;2`/09NGU`00Gel0GiMO09NGU`1<HS00BDU90000;00/
;2`0GiMO02`/;02GaIL0FD=30P2GUel03`0/;2`0UiMO02`/;02WYjL05QH/0<G5a@0002`0QHF504U9
B@1cLg<0BDU901Hk5P00G`00GemO04U9B@0205nGU`0;05nGG`1DE5@0Lg=c04U9B@1cLg<0BDU9001O
G`0/;2`0@g9b001OG`2GaIL00P19BDT01P2GaEl0QHF507:>SP2GaIL0UiNG07=cL`80GemO01T0UiNG
01I6AP2f][H0Lg=c02`/;01OGel0][Jf05mOG`0/;2`0Rh^W05mOU`19BDT0;2`/0:NWY`1OUel004T0
05iNGP35aLD0GemO001OU`3_olD0aNo50:NWY`31`L40kno50080hN7Q00D0YjNW04U9B@2WYjL0h][R
07=cL`0204U9B@Sooooo0006ooooo`0F02`0000002`002`00000000002`0000002`/;00002`00000
0000;0005P00;2`/04T0000002`002`00000001cLg<05R`F0000;00/0000;2`/000/0080;2`/00P0
5R`F001OG`19BDT002`002`/;00/0000GemO08j>N@80;2`/01P004T005nGG`0/;2`0;2`/000/001<
HS00;2`/000/000/;2`0GiMO0<G5a@00;00003160<G5a@35aIL0GemO0<G_U`0/;2`0UlEO0;jWY`0/
;2`002`00>o5a@35Uel202`/;00M07UiHP1OGel0aLFG02`/;000;000aLFG05nGG`0UE5@0;2`/0;Jf
]P3oklD0UemO0000;02GaLD0]Yn302`/;01OUiL0][Jf0019000/;2`0aNo503/k>`2GaIL0GemO0000
;035aEl0;2`/05mOU`2f]Yl00P1OGel0702f][H005l00<G5U`2f][H0E5AD0<G5U`190000;2`/0<G5
a@19BDT0YjNW09NGG`1DQhL0BDU905nGG`0/;2`0GiNG05mOG`0/;2`05THF05mOG`1OUel0BDU902`/
;019BDT0GiNG03/k>`19BDT205mOG`0B04U9B@1OGel0UlFG05iNGP1OUel0UlFG08F5Q@2GUiL0GlFG
09NGU`1k[W/0GlFG09NGU`2WYjL0GemO001OG`1OGel05TI60P0/;2`04@00B@00Lg=c05mO002GaLD0
UlF^04U9B@0/;2`0QHF50;Jf]P1OGel0Lg=c07:USP2GaIL0GemO04U9B@00B@00BDU90080;2`/02@0
UlFG09NGG`19BDT0BDU9002GG`2f][H0aLFG04a`<01OG`00aIMO0<G5U`19BDT0UlEO09NGG`1RHV80
;2`/0<FGU`0/;2`0YjNW05nGG`00;000C4aR000/001OGel0000/09NGG`0/;2`0UiNG02`/;035aLD0
Gel007=cL`0/;2`0UiMO0019001DE5@305nGU`0705nGG`00Gel0UiMO05AD9@2GUiL005mO07=cL`02
04U9B@0R05mOG`1DL5@005mO09O5U`1OUel0Lg=c08F5Q@2WYjL0Ng]k04U9B@2WYjL0GemO04U9B@1c
Lg<0GemO04I6AP2f][H0GiMO02`/;000Gel0aLG505nGG`0/;2`0Njj^05mOG`19BDT0;2`/0<G5a@3Q
hN40GiNG09:BH`2f][H0UlFG0>o_k`80Lg=c00`0aNo508NLQ`0/;2`0aING0=CDe01OGel0B@00000/
002nYjL0GiMO04U9B@00Gel8ooooo`001_ooool03@0/000000000000000F5P00;00000000000;000
000002`00000;000000002`/;00/00000`0002`00`1900009@0F00000003000000050000;000;000
01H0000/000002`00P0/;2`00`0/0000e=CD0696AP0202`/;00609MO0035UiL0000002`/;0000000
Ph>30P0/;2`07P19BDT0aNo502`/;00/;2`0C69<05mO0000000002`00;Jf]P2WYjL0BDU909:^N`35
aIL0kno504U9B@00;000Lg=c0>o5U`1RHV80aLFG02`/;000G`00aLFG02`/;019BDT0JVYZ0:NWY`2G
Uel0YjNW0>7Qh@80ono501<0[/>^09NGG`3_klD0GiMO0<G5U`00B@00YjNW069RAP1OGel0Gel00000
;000Gel0BDU902`/;00`L4`0UiMO09O5U`1OUel0;2`/0080UlG500d0YL:j04U9B@19BDT0aLFG04U9
B@1OaIL0GenG08F5Q@1kNg/005mO00190000Gel0BDU90080GemO0P19BDT01P1OUel0GemO04U9B@1c
Lg<0GemO031`C080;2`/01D0GiMO04U9B@1OUel0GlFG05ADE01OUiL0UiNG05nGG`2WYjL0GlFG05mO
G`1bYJD005mO09O5U`2WYjL0GiNG0019001OGel09BDk000/001OGel00P19BDT02`2GUiL0GlG502`/
;02GaIL0GiMO09O5U`2GUel0;2`/04U9B@0`<300GiMO008005mO030005l004U9B@00Gel0NiMk000/
0000B@00GiNG001OG`1OGel0000/0>o_a@2^[YL0BDU905mO002GUel0;2`/09NGG`00;000<7]O09O5
G`1OGel0UlFG02`/;02GUel0000001H/5P00;000UiMO02`/;02GUel0;2`/0;Jf]P2W_[h0aLFG0<G5
a@2f][H0;2`/05nGU`1OGel0GiMk07=cL`19BDT0UiMO05mOG`19BDT0GiMO05AD9@1OUel304U9B@05
001OG`1OUiL0SHf=05nGU`25QHD00P2GUiL205mOG`0:06UYJ@19BDT0YjNW04U9B@0/;2`0GemO001O
G`0k>c/0UiNG001OG`80;2`/01`0][Jf05nGG`00B@00][Jf08F5Q@2GUel0GiO50;Jf]P1cLg<0aNo5
0;Jf]P00Gel0olG50;Jf]P19BDT0;2`/0:NWY`1DL5@0;2`/0000;03QhN40GemO05mO00000000SWUi
05nGG`25QHD0GemO2?ooool000Kooooo00L0;0000000000/00005QH00000;000;000;2`/00<00000
00X05P000000;0000000GemO000/000/;2`002`00000;00/000000000P0/0000100/;2`002`0000/
000000020000;080;2`/00D0aLG50820P000B@00QHF50;Jf]P0302`/;0090000;01aLG40;2`/02`/
;02GaIL0UemO0000;000;000TY9k0080;2`/00H0UlFG0<G5U`19BDT0000/0:N;R`0/;2`40<G5U`0K
02`/;02^[YL0;2`/05mO002f][H0;2`/0:NWY`35Uel0C6=<02`/;000B@00QHF50:NWY`3oonl0ono5
02`F5P2f][H0klG50019002GUiL0aLG50;Jf]P2n_X/0000/09O5U`35aIL0;2`/0080BDU900D0E6YD
0000;01OUel0;2`/09O5G`0209NGG`0909nfW`2GUiL0BDU905mO002WYjL0GenG09NGU`0/;2`0T/>B
0080GiMO01<0;2`/05nGG`19BDT005mO04IRHP0/;2`004T005mOG`1OUel0;2`/001OG`0`Ng/0BDU9
001OG`19BDT0GemO001OG`00G`00WkJO0080UlFG00T005mO002GG`2GaLD005mO08F5Q@19BDT0GiNG
07=cL`00Gel00P1OGel02P19BDT0Gel005nGG`1OUel0GemO0:NWY`2GUiL09DTU02`/;01OaIL207=c
L`0305nGG`2WYjL0L71`0080GemO02/0;2`/001OG`1OGel0GiNG04I6AP00G`00GiMO07=cL`2WYjL0
000/02`/;03_onl0ATI602`/;035UiL0;2`/05mOG`1OUel0QHF504aR<00002`0UemO09NGU`0/;2`0
Lg=c02`/;00F;1H0BDU90<G5U`1cLg<0aLFG09O5a@3_klD0][JO02`/;035aLD0BDU909NGU`00B@00
05mO031D<02WYjL0BDU90080GemO00L0BDU905nGG`19BDT0GiMO05mOG`1OUel0QHF50080GiNG0240
LXib07=cL`19BDT0BDU90:NWY`1OGel0;2`/04bBN`0/;2`0GenG05nGG`19BDT0GemO05nGG`0k>c/0
Lg=c05nGU`19BDT005mO0<G_a@2GaIL0GemO0:k3TP35aLD0QHF50<G_k`1OGel0;2`/09MOG`27QhL0
BDU907=cL`1OaIL00`0/;2`02`2BYi80;00002`/;02GGiL0UlFG001OG`0/;2`0E5AD09O5U`1cLg<0
BDU900Sooooo0006ooooo`0:00005P0F5P0001HF01H;000F5P005QHF01HF000F00005P0F01HF;080
5P0000L0;2`/01HF;00F01H001H001HF5P0F8AH05R`F008002`000H0;00000005P0F;1H02b4;01HF
000F;1H302`/;02e01H/5P2LYY`0bl^f08iiN@35klD0cKJJ07V>N@2f][H0TZj^08nJQ01SSV<0_[jW
0=?C_00/;2`05QHF04a`<01OGe@05R`F069iHP20P800;2`/000U5P2f]Yl0<D0S08^WR`2BTW/05R`F
069<<035aIL0E6YD07fDR@1<Nel0][JO069iAP1k[Ul0W8EY07UiHP1HF400FEUI04akC01RHV80HV96
01H/5P25QHD0AU`^03/k>`2n_[h0HTHF030`AP1<TY80Uji<04AJA035klD0N7Qh0316C01YW8D0HXii
08F5Q@0mH340AV9601I6AP1OGc00;2`/031Y<00k>c/0B5I802Dk9@1OGel0Njik0727L02OWil0JHEY
08j>LP1KS800N7Qh08NLQ`2W_ZL0L71`06MWI`0UGRD0=TeK05iNGP0FATH09DTU05ADE00jLcX0>c/k
049XFP0jQFT0>U0j03/k>`19BDT0E71`02EDE01OXiD0<8M<05A`L01DQg00E71D05mkN`2UYHh0GgQ]
05A`E00UBBD0JHEY03/k>`1DE2D0BDU901h`:@1RHV809EAD032BN`1OaJh0JIbL05ADE01]Pf40UlG5
069iN@1`Qg009EAD07]kU`1`L700FfM=031D<00UE5@0E5@U031D<016ATH0AV9604eKF`1ONd`0Ni9k
0000;00F>aH0E30002`/;03fm_H0J5]J031R<02G[Ul0UiMk02`F5P1DE5@0NiMO04ABE`1DE5@0Gg/`
07:>LP1RHTH0SHf=0696AP2<PH40HTI601H/5P1R<3009EAD0:NWY`0F5QH0<F5C04I6AP2f][H0BDU9
07^^U`1DE5@09EAD04QFB01k[YL0>VUY06V5Q@1kNel0Ng]k07^GG`1]Nfd0LXj>031kG`1YW8D0E5AD
06V5Q@1bSXh0@T9207:>SP0202`/;00[09JFUP1YQFT0;2`/06f9K@1DE5@0GemO07^^N`1DE5@0P820
09N^U`1@MU00WinO09NBU`2B[Y80_]>n079bLP20P800HWUi07N@M`0/;2`0N7Qh0:j^N`1OGel05QH/
01H/5P2;VH/0>c/k01HF;02f][H0E71`02`/;00F5P00V:JH05iNGP0k>c/05QH/0=[3a@25QHD0ATI6
02Tk:@3gkmX0W;6L05mOG`08ooooo`001_ooool30000000301H05P0/000000000080000000@0000/
0000000F01H002`00P0000001000;000;2`/0000;00F5P02000/00070000000002`00000000/000F
5R`002`002`/;002000/00030000;00/;2`0Nel`0080;2`/00<0GemO0>o5a@0/;2`00P0/;2`02P35
fZh0BDU90000B@35klD0Gel00;Jf]P35kiL0;2`/05nGG`3De=@202`/;00m0<G5U`0/;2`0AV9609MO
G`00;000UlFG0;Jf]P0/;2`0GemO06YZJP2GaIL0YjNW02`/;035aIL0;2`/0<G5U`35aG/0;2`/09MO
G`0/;2`0UiMO02`/;02GGel0JUAD0000001OUiL0aNo5000/001OGel0aNo501H/5P1OUiL0G`0005mO
G`0/;2`0][Jf02`/;01KLE/005mO0>ooU`2GUel0GiMO04U9B@1OG`00>c/k04U9B@00B@00BDU902`/
;01OUel0;2`/07=cL`2^f]X0UlG507=cL`1OUiL0Lg=c0;Jf]P2GUel0E71D001O000205nGG`0505mO
G`00Gel0GemO05ADE01OGel00P00Gel03000B@00BDU905mOG`1bLW8005mO04U9B@1OUel0GlFG08F5
Q@1cLg<0GiMk05nGG`80GemO00D0GiMO001O0019BDT0AV9608F5Q@0305nGU`0=09O5U`19BDT0WkJf
09NGU`2GaIL009MO09O5U`1OUiL0QHF5031kG`19BDT005l008F5Q@0205nGG`0R09NGU`1IFET0G`00
0000002GGel0;2`/09O5U`25QHD0UlG506YZJP19BDT0YjNW09NGG`000000UlEO05mOG`1DL700Lg=c
04U9B@0/;2`0UiMO02`/;035UiL0NGUR0000000002`0;2`/07=cL`1OG`0002`00;kC_P2f][H0UiMO
04U9B@80Lg=c0140UiNG07_5U`1OUiL0UiNG09O5a@00Gel0QHF505nGG`16ATH0GiMO02`/;01OUiL0
05mO02`/;01OUiL0<5l`09NGU`0204U9B@0G08F5Q@1OUel0GemO08j>LP1OUel0UlFG07=cL`2GUiL0
aNo505mOG`2>YHh0UlFG04U9B@1OGel0YjNW05mOG`00;000;2`/09bLQ`00B@00;2`/0;Jf]P1cLg<0
0P0/;2`04P25W8D0GemO02`/;01OGel0aNo507=cL`0/;2`0TZNB05nGU`1OGel005mO04U9B@3_klD0
GlFG06V5J@35UlD0kno505mOG`Sooooo0006ooooo`0302`/;000;00000000080000/01l0000002`0
00000000000/02`0000U0000;2`/000/000/;2`0000/02`/;00/0000<30`0000000/000000000000
;00/000002`002DF0000;000;0000000000/0000000/001OG`1IFET0;2`/000/0019BDT0][Jf0080
;2`/00`002`007UiN@00;000;2`/09O5U`35klD0BDU9001OG`2^`g/0aIMO0>o5a@19BDT20;Jf]P0J
02`/;01iNF8004T004U9B@35aIL0;2`/00000035aIL0D51@0<G5U`0/;2`0GiMO02`/;01OUiL0QHF5
07UiHP1OGel0GiL009O5U`0/;2`0UiMO02`/;01RC300;00005mOG`2f][H2000/000V09O_a@0F5S/0
GemO0<G5a@0/;2`0000/05nGG`1OG`00JVYZ02`/;019BDT0UemO001OG`2WYjL0GiNG02E99@0/;2`0
Gel0001900000000Gel004U9B@1cLg<0Gi9k09O5a@2f][H0UiNG0:NWY`1OUiL0Lg=c08^WR`1OGel0
BDU905mO001OUel0BDU905mO000UE5@305mOG`80BDU901/005mO05mkG`1OUel005l004U9B@1OUiL0
QHF505nGG`1OUg/009MO09NGU`1OG`00GemO05mO000/;2`0L4a<05nGG`1OUiL0UiNG09O5U`19BDT0
UlFG08>OW`19BDT0GemO05nGU`00Gel00P1OGel00`0k>c/0;2`/05nGG`0205mOG`0Q09NGU`1OGel0
C68`09NGG`0/;2`0aLFG001OG`2WYjL0;2`/0?clo01RNGT0UiNG04U9B@2GUel0GiMO02`/;019BDT0
9DTU04U9B@25QHD0;2`/09O5U`00B@00aIMO04akN`00B@00UlFG0<G5U`0/;2`0aNo508F5Q@20P8L0
;2`/0080YjNW0300GlFG05nGU`1OUiL0Lg=c05mOG`19BDT0GiNG04U9B@0/;2`0GiNG02`/;01OaIL0
GemO07=cL`1OGel0BDU908F5Q@0UE5@0UlFG05nGG`1cLg<0UlFG09NGU`25QHD0GUiN09NGU`1OUel0
Lg=c04U9B@2GUiL0BDU902EDE025QHD0GemO02`/;025QHD0GiNG05mOG`0/;2`0UjjG05mOG`0/;2`0
GemO05o5U`19BDT0;2`/075aL@25QHD2001OG`060<G_a@1OUiL0GiMO0:NWTP3QhN40UlFG0P2GUiL0
1P2f][H0hN7Q09OR[P35aLD0GiNG001OG`Sooooo0006ooooo`0302`00000;000;0000080000/0P00
00002@0/0000000/0000000F5QH0;0000000;000;000B@00000/00030000000>02`/;00/0000000/
0000;00/00005R`F000/000002`0;00004T00000;000GemO06:>N@0002`202`/;00809MOG`0/;2`0
000/001OG`1iNGT002`002`/;02GaIL202`/;01@04U9B@27Qg00;2`/05o5U`2WYjL0;2`/0;Jf]P2G
Uel0f/F^09NGG`3_aIL0Uel004T00035aIL0BDU906=SL019BDT004T009MOG`0/;2`0UiMO0000;01i
NF80UlFG02`/;02GUiL0GemO04U9B@1OGel0Qib702`/;019BDT0aNo_05mO0000;000GiMO07V>N@19
BDT0aNo_02`/;000;000GemO0<G5U`0`<300;2`/04U9B@2GaEl0;2`/001OG`00;000W;6L04U9B@1O
Gel0;2`/05mO000/;2`0BDU9001O000k>c/0Lg=c0000G`1OUel0][Jf001OG`1OGiL0Pin309NGU`1O
Gel005mO04U9B@1OUel0GemO01I6AP1OGel0BDU907=cL`1OUel0BDU905mOG`0`Gc0304U9B@0D05mO
G`2GUiL0BDU902E`E01cLg<0GiNG001O001OGel0BDU90019000`HV<0Lg=c05o5U`1OUlD005mO0:NW
Y`00Gel0JFUY05mOG`25QHD205nGG`0505mOG`19BDT0BDU905nGG`1OGel00P1OUel0<`2GGel0000/
04I6AP2GUel0GiMO09O5a@25QHD0klG502`/;02GUiL0E2ED05nGG`00B@00;2`/04U9B@1OG`000019
04bBC00/;2`0UlFG05mOG`1OUel0UiMO08F5Q@1WIfL0UiMO0019001cLg<005mO0<G5U`00;000Ni9S
02`/;01cLg<0GemO05nGU`1OGel005mO051@D02GUiL0;2`/08F5Q@1OUel0BDU907=cL`1DE5@0GiMO
04U9B@1OUel0QHF507=cL`0309NGU`0]08F5Q@2GUiL0Lg=c001OG`1OUel09EAD02`/;01OaIL0Lg=c
02`/;01cLg<0QHF504I6AP2GUel0GemO04U9B@0/;2`0][Jf05nGG`19BDT0LG5a09NGU`1cLg<0;2`/
0<G5a@00Gel0BDU90820P02GaLD0GemO002GG`2GUiL0GenG0:NWY`2B`jh005mO09NGU`2f][H0hN7Q
05o5G`0/;2`0QhM`0<G5a@1OUel0GemO00Sooooo0006ooooo`8002`000<0;00001H05P0000000P00
;0001P0/;2`000000000000F5QH0;00002`/;080000000<0;2`/02`0000k00000`0002`0<`0/0000
000/0000000F5QH0BDU902`0000/;2`002`002`/;01OGel0HhiS0000;00/;2`0GiMO05l000190000
;2`/05nGG`20P800B@0005nGG`35aLD0;2`/0000;025QHD0Hf8`02`/;035aIL004T00000;02WYjL0
aING075aL@35aIL0BDU90;Jf]P35aLD0UiMO09MOG`2USXh0;2`/09O5U`0/;2`0UlFG02`/;02GUel0
5U0F04U9B@00Gel0;2`/05mOG`0204U9B@0]0<?5a@35aIL0;2`/0<G5U`35klD004T0001OG`2WN6<0
04T005nGU`1OG`00000/05mOG`35aLD004H`000/0000Gel0UlG5000/0000Gel0Gel0069iHP2GaIL0
000/0:NWY`0/;2`004T0001OG`19BDT0E5AD04U9B@0002`0UiNG05mOG`00Gel0GiNG05nBN`1OGel0
YjNW05mOG`1OUel005mO05mOG`16HTH005mO0080GemO01T005mO07=cL`00G`00E5AD001O0019BDT0
05mO05nGU`1OUel0GemO079bLP00Uel0YjNW05mOG`1cLg<0GemO02`/;01OUiL005mO001OU`1OGel0
09MO02`/;01OaIL0GUiN0080GiNG03D009MO04U9B@19BDT0BDU903/F5P00Gel0;2`/05nGU`0/;2`0
Lg=c02`/;00FATH0UiNG05mOG`3_aLD0;2`/05nGU`00;000UiNG0:Nn_P1cLg<0UemO05nGG`0/;2`0
GiNG09NGG`1DL5@0Lg=c0019000/;2`0Lg=c000/001cLg<0HTI604U9B@25QHD0;2`/0;Jf]P0/;2`0
Lg=c06=SQ`19BDT0GiMO04U9B@00Gel0Lg=c04U9B@1NGUh0GiNG04U9B@1cLg<0GiNG02`/;00205nG
G`0409NGU`1OUiL0UlFG09NGU`80GiNG0180Ng]k05mOG`00Gel0BDU9001OG`19BDT005mO05mkN`0/
;2`0GemO07=cL`1OGel0;2`/05nGU`1DL5@0BDU908F5Q@00Uel202`/;00A0;Jf]P1cLg<0HTIR09MO
G`2GaIL0GiMO0<G5a@35onl009MO0:F>Y@1OGel0aNo5002GU`2GUiL0GiNG05mOG`2WYjL00P1OGel0
2019BDT0e=CD09O5U`1OGel05R`F09NGU`2f][H0BDU92?ooool000Kooooo00L002`002`00000;000
000002`0000/;2`0;00000<0000000D05QH0000/00190000000002`0000202`/;00P00005P0002`0
;2`/0000;00/0000000002`/;00F5R`002`00000;00/;2`0000002`/;019BDT0NGUi0000;00/0000
][Jf02`/;000;000;2`/09NGU`1RHTH0;2`/08F5Q@35Uel002`00000;02GaEl05R`F05mOG`2WYjL2
000/000H0<G_a@0/;2`0LG5a02`/;000B@00YjNW0019000/;2`0aLFG069RAP2WYjL0UiMO0;Jf]P2G
Gel0GemO09MOG`1SC4`002`004U9B@1OUel0;2`/05mOG`19BDT0UYJ>0P3_aLD07035Gel0BDU90<G5
a@0/;2`0_]>n02`/;01OaIL0][Jf05mO0019BDT0aLG501H/5P35Uel0;2`/0;Jf]P0/;2`005mO09O5
U`0F5S/0BDU902`/;000;000BDU905nGU`19BDT0GlEO031O<00/;2`2001O000804U9B@1OGel0GemO
08>OW`2GUiL0GemO0:NWY`1OaIL204U9B@0505mkG`19BDT0GiMO05mOG`00Gel00P1OGel04@0k>c/0
GiMO0000B@1cLg<0GemO07=cL`1OUel0E5AD001OG`1OUiL0GemO001OG`0/;2`0GiMO05mkU`1cLg<0
YjNW008005mO02h0GiNG08F5Q@16HTH0Lg=c001OG`00G`00;2`/04U9B@00B@009DTU04U9B@1cLg<0
000002`/;01OGel005mO05mkN`2GaIL000000<G5a@00;00004T00>o5a@2GaLD0D51@0<G_a@0/;2`0
BDU905mOG`1cLg<0;2`/04akC019BDT0QHF502`/;01OGel0Lg=c02`/;00`L300UiMO04U9B@1OUel0
aLG509O5a@35aLD0;2`/0P1cLg<02@1OGel005mO05mOG`00Gel0Gi9k09NGU`25QHD0GiNG09NGU`02
05nGU`0;08j>SP1OGel0GemO09NGU`00Gel0GiNG001OG`19BDT0GiMO001OG`0/;2`00P1OGel03P19
BDT0LXib05mOG`00B@00GiNG07=cL`00Gel0UemO06UYJ@1OGel0][Jf0:NWY`1OUel0;2`/0P35aIL0
202B[Zh0;2`/02`/;02WYjL0e=CD02`/;02GUiL0[^o50P1OGel03`2GUiL0UlG505nGU`19BDT0P820
09O5U`1cLg<0;00004U9B@2f][H0GlFG04I6AP00;000UiNG05mOG`08ooooo`001_ooool01@00;000
;2`/0000;00F5P00000/0080000000d0;00004T0000002`09AH00000;000;000;2`/000/000/0000
000001H000000000;2`/00@0000/00l0;1HF02`/;00002`0;2`/0000;035aIL0kno507UiHP00;000
GiMO0=CDe000B@00;2`/0000B@2GUiL00P0/;2`0201OUiL0;2`/02`/;00/;2`0aLG502`/;035aIL0
BDU90P0/;2`00`3De=@0;2`/075aL@0202`/;00?09MOG`0/;2`0UlFG02`/;01kGel0000/0<G5U`00
B@00YjNW000/000004T0UiMO05nGG`00;000BDU90080;2`/01<0UemO075aQ`00;000ono504T00000
02`0][Jf0<G5U`1kGel0kno50>o_U`00;000aLG50<G5G`2GaIL0C4a60>o_a@0/0000YjNW0080;2`/
00/0aLFG04I65P0002`0Gel00000;02GaIL002`002`/;02WYjL0E5AD05nGG`0202`/;080GemO01@0
;2`/05A`E01OGel0UiNG07=cL`00Gel0UlG505nGU`1DE5@0GiMO04U9B@0005l0Gel005mOG`00UiL0
E5AD02`/;02GUiL005l005nGU`80GiMO00l0E5AD05mOG`1OUel005mO04U9B@00;000GemO031OG`25
QHD0;2`/04U9B@1OUel0UlFG001OG`19BDT00P00Gel204U9B@0;02`/;019BDT0FEUI05nGG`19BDT0
;2`/05mOG`1OUiL0GemO04b7C019BDT00P0/;2`08@2GUel005nG001OG`3QhN40;2`/09NGU`35aIL0
YjNW0000;01OGel0GiNG069RHP1OUel004T009NGU`1cLg<0GiMO09NGU`1bLW80;2`/0;Jf]P00G`00
kno507=cL`35aLD0SXj>05mOG`19BDT0UlFG002GG`1OUiL0BDU907:>SP0305nGU`0>05nGG`1cLg<0
GemO05ADE000Gel0BDU905nGG`1OGel0BDU905o5U`1DE5@0Lg=c04U9B@00Gel205nGG`0C05mOG`1D
L5@0GiNG001OG`19BDT0GiNG05nGG`00Gel0YjNW05nGU`2WYjL005mO07=cL`3De=@0aLG504U9B@1a
LG40GiMO05mOG`0204U9B@0D05nGU`19BDT0L71`0<G5a@1OUiL0;2`/05mOG`2GaIL0GemO03/k>`2f
][H0UlFG05mOG`0/;2`0BDU90<G5a@0`C8D0;2`/0000B@1OGel8ooooo`001_ooool02`0F01H05QH0
01HF5P0Q8AH05QH001H0000F;1H0;2`/000F5P0001H05R4Q00<0;2`/06`05QH/0000;00/;2`05QHF
000F5P0F5P0002DF01H05P005P0001HF0357<@005QH05QH005B3E02^TY80W9b7069iHP2fbjP0_[jn
08iiN@2PX:00f^oJ0820P02U^ZD0YjNB08VJK`1DPh<0_[jW04I65P0FAQH0TY9O09MkN`0lB4L0][JO
02`/;000B@00YjNW0:ikN`0F;1H0U8Ij01H/5P2n_ZL0;2`/000k002WYjL002`005ARB@0`E300N7Qh
02D05P1<<4H0>c/k02`/;00l;Rh0C4aD031kG`0U>bD0C70`01I6AP0UE5@0Qh1]01H/5P3C_[h0<2D0
000/001DE5@0dnSC01HF2`2G[YL05R`F01HF;00UE5@0][JO0316<02VYXd0HWUi0:k5[P27QhL0TY:B
05^;F`1KRh/0PZJ@04aSN@2n_ZL0NGUR08>OW`009BD0E5@U04aRC01DGfd0E4``02`/;01OTW/0>c/k
06YZJP0`L4`0:C/Y03/k>`1OGel005@`05A`L01OGg/0AV960820P00`Nel0E71`06UYJ@0`Gel205mO
G`2405QHIP0k>c/0BDU905A`E00`Gel0C99<06V5Q@18B6d0<5mO05ADE01ONel0>c/k01I65P1YJFT0
Gfe]05B7Q`1OUg/0GiNG07QhN00`Gel0AV9R04QOK@0`Gel09BED02ED9@0/;2`0<5l0031OG`0mBdl0
<5@`04IRHP1YJFT0JHF5030`AP1SND`0;U<l05A`L023Ph<0Ng^G04I6AP1ZJVX0Gg]O02`/;01lJVX0
L7QS0:Fj^P1`QhL0HWUi05A`Q`1<Ug/0FUYJ04akN`1`C4`0QHF505UIF@1kGel0C7]k07inL`2O]Yl0
NHii0>S`j01SW6<0[/G508N7Q`0;BF40GiNG05mkN`13LW80Gg]k05mON`0`Ng/0FVQX05ADE00UE5@0
BDU905mOG`19BDT0Gg]k03eDE01OUg/0L71`05ADE01k[W/0JFUY03YYQ@1@MWH0NiNG04=bLP1hN7P0
UYJF05nGU`1kUiL0J:B=04akN`1kNg/0C9NG07^^U`1YQFT0Ng]k071`L01DE700E71`05nBN`1DE5@0
9C/U04aSQ`2;Rh/0ADE5051@D02;YjL0Gg]O04I6AP1ZJVX0UIFE03HfB01DE5@0QIbL05nGN`0UE5@0
ATI6071hH`1CR6l05S/F0820P02WhZL0E71D04IRHP16ATH0][fm09;3Y`2L/I`0GemO2?ooool000Ko
oooo00H002`00000000000005QH/00000000;0030000;00404T0000F5P00;2`/02`/;08002`000H0
;2`/000/000k0000GemO02`/;00002`3000/000901H05P19000002`005mO0035UiL002`002`/;01i
NGT002`00080;2`/0380GemO0<G5a@0/;2`0;2`/0:j^U`0/;2`0BDU90;Jf]P2GaIL002`00<G5U`2W
Rh/0GiNG0<FGG`35aIL0UiMO0<G5U`2GUiL0TY9<0:NWY`35aIL004T009O5U`2GUel0;00006965P25
QHD0;2`/08F5Q@0/;2`0UiMO02`/;016AQH0;2`/001O000/;2`0GiMO02`/;000B@00LE]K02`0002W
YjL0;2`/000/001OGel0aNo5000F5P2GUiL0;2`/00000080GemO00/0;00004aOG`00;000GiNG02`/
;0000000UiMO02`/;01iHV80aLG5000/00020:NWY`0D0;Jf]P2GaLD0UlG50820P000B@00GiMO02`/
;01OGel0UiNG02`/;01DL700GiMO04U9B@1OGel005mO04U9B@00B@00JFUY05nGU`1cLg<2001OG`03
05mOG`1cLg<0<5mk0080BDU901<005l009NGU`1cLg<0BDU905mO<000Uel005mO05mOG`00;000BDU9
05mOG`1O[Zh0GiNG05nGa@00Gel0Lg=c05mOU`1OGel0E5AD0080;2`/00d0BDU90019001OGel0000/
03/k>`1OUiL0;2`/05mOG`0/;2`0BDU9001OG`2GaJh0UiNG0080;2`/00D0BDU9001O0000Gel0GiNG
0;K=c@0202`/;00>0?o_a@0002`002`005o5a@1ONc00GemO02`/;01OUiL0GemO05o5U`19BDT0<99<
0;Jf]P35UiL302`/;00<04U9B@0`Gel0GemO002GG`1OGel0BDU9001OG`1OGel0<5mO001OU`1OUiL0
GiMO0`1OUiL01@2GUiL0GiNG05nGU`1OUiL0QHF50080GiNG00P0Gg]O001OU`19BDT0BDU905nGU`19
BDT005mO079bLP80GemO01H005mO07=cL`1OUel0BDU905B3P`19BDT0;2`/04U9B@2f][H0GiNG04U9
B@0/;2`0UIFE001OG`00;000aLG509O5U`1OUel005mO09:^U`1OUiL005mO0P2GaIL03@1OUel0GiNG
07]STP1OUiL0UiNG09NGG`19BDT0aLG509O5a@1aLG40;2`/05mOU`00Gel02?ooool000Kooooo00<0
;2`/0000;00000000P0/;2`00`00;000;2`/000/0002000/00030000000/0000;2`/0080;2`/00h0
000/02`000005P00;00002`/;000000002`002`0000002`001HF02`00000;000GemO0<EOG`80;2`/
00H0C7U<02`/;00/;2`0;2`/05nGG`35aLD20000;004099kN`0/;2`002`009MOG`80;2`/00X0UlFG
06965P0/;2`0aLFG05mO0000;000YjNW09MOG`1ZE5@0UiNG0P2GaIL0:@1cLg<0YjNW0<FGU`1<Ng/0
UiNG000/002GUel0BDU907=cL`00;000HV9602`/;02GUel0;2`/05mOG`1OUel005mO05AZE00002`0
YjNW05mO000/;2`0GemO0>o_a@00;000UiNG000/000/0000GemO09NGG`000000HTI60000;01OGel0
02`00000;02GaEl002`004I<<01OUiL0;2`/008002`000D0GemO000/001cLg<0AWUR09NGG`0205mO
G`0609NGG`0/;2`0;2`/08>OP`1OUel0BDU90P1OGel01P1OG`00;2`/01I65P1cLg<0BDU905nGG`<0
GemO00@0<5mO05nGG`19BDT0BDU90P00Gel06`1OGel0<5l`05nGU`1OUel005mO02`/;01OUel005mO
05mkN`1OaIL0GiNG05nGG`0/;2`0Lg=c001OG`19BDT004T004U9B@00Gel0GiMO04U9B@00Gel0E71D
0019000/;2`0GiMO02`/;00209NGU`030727Q`0/;2`0Lg=c008002`001<0aLG507=cL`2GaEl0;2`/
0<G5a@1OUel0;2`/0;Jf]P1cLg<0UlG509nf]P1OG`00GemO05nGG`2GUel0GiMO09NGG`2BTY8004T0
0080;2`/00h0000/02`/;00/;2`05QHF04U9B@1OGel0Lg=c05mOG`1OGiL0Lg=c05nGN`1OUiL0GemO
05nGG`80BDU90180GiMO031OG`1OUiL0BDU905mOG`1OUel0GemO001OG`1OGel0Lg=c001OG`00;000
BDU90:NWY`00Gel0>c/k09NGU`1OUel204U9B@0807=cL`1OUel0<7]k09NGa@2f][H005mO09NGU`1O
Gel20:NWY`0509ZJ]P2f][H0UlG509O5a@2GUiL00P2GaLD02`23][H0YjNW05nGU`1OUiL0GenG07=c
L`25QHD0AQI604U9B@1OGel0BDU90080;2`/00D0BDU9031D<00/;2`0001905mOG`08ooooo`001_oo
ool04P0002`0;0000000000F01H0;000000/000/;2`0;000000/000/0000;1HF0000;00/;2`002`0
02`/;00002`0;2`/01H/5P80000/00`0;000000/0000;000;2`/000/000002`0;2`/05l00035UiL0
;000000/001aLG4302`/;00807=cL`3_klD002`00000;02BTW/0;2`/0000001cLg<202`/;00I05nG
G`1<AS00;2`/05nGU`00;000;2`/0:NWY`0/;2`0HdaR000/000/;2`0aLFG02`/;02GaIL0BDU908j>
SP1OUel0UiMO05nGG`00Gel0GemO001O001DL5@0;2`/05mO0002000/000_07=cL`1OU`00C69<02`/
;02WYjL0UiL0000/0019BDT0kno502DF0025QHD002`00000;019BDT0YjNW000/001kNc00;2`/04U9
B@1O0000;2`/08F5Q@00;000<4H`001OG`0/0000000/04T0000/;2`0000009NGG`0`AP00BDU902`/
;02GUel002`004U9B@1OG`00NiMO02`/;019000002`00019001cLg<0Gel002E99@00B@000`1OUiL0
301OGel0BDU905A`E000GiL0Lg=c05mO0019BDT0UiMO05nGU`1DE5@0YjNW05mOG`80BDU900`0GemO
05mOU`1OGel0YjNW05nGG`19BDT0QHF5002GG`1OUel0;2`/04U9B@00Gel202`/;00X05nGG`19BDT0
9C/U02`/;01OUel0BDU909NGU`1OUiL0;2`/07UiHP25QHD0BDU90;Jf]P2GaIL0G`0002`/;01OGiL0
LW9300000035aIL0aLG50;Jf]P35klD0GiMO02`/;01cLg<0QHF502`/;00002`002`004U9B@2U^ZD0
kooo0<G5a@2GUiL0hN7Q09O5a@35klD0l?3`09NGU`80;2`/00D0BDU9001OG`0/;2`09EAD02`/;002
001OG`0605nGG`1OGel005mO05mkG`19BDT0GiMO101OGel0300`Gel0BDU905nGG`1OUiL0BDU905mO
U`1OUiL0<7/`02`/;02GaLD0aLG505o5a@80GiNG00D0YjNW05o5a@1OUiL0UiO50;Jf]P0305nGU`05
08>O]P25QHD0QHF509NGU`1OUiL00P19BDT01@0`Gel0BDU9001OG`1OGel005mO0080BDU900<0E5AD
02`/;00/;2`00P1OGel202`/;00405l`G`19BDT0BDU905mOG`Sooooo0006ooooo`07000/00000000
000000005P000000;2`/000/00020000;005000/000F5R`0;2`/02`/;000;0000P0/;2`00`0002`0
5QH/02`/;002000/001R02`00000000000000000000/;2`0000/05mO002GGel0;2`/0000;01KFg40
04T002`/;0000000BDU90<G5U`00;000000004aOG`0/;2`002`009MOG`0/;2`0B@0005nGU`1<AP00
;00005nGG`00B@00000/09O5U`0/;2`0NF9R02`/;00002`0aLFG04U9B@1OUel0;2`/069RHP1OG`00
UiMO05nGG`1OG`00GiMO02`/;01YJFT0GiMO05mOG`2GUel004T0000/001OGel0JUAD0019003QhN40
aIMO000/001OUel0][Jf000F5P1OUiL0Gel00000;01OG`00aLFG02`/;027L5@002`004U9B@2GGel0
02`009NGU`00;000C30U0000B@1OGel0000/05mO0000Gel0;00009NGU`0`<000000/02`/;01OUel0
02`00000;0000000@d=W08F5Q@00;000GiMO001O0019BDT0GemO031D<000B@0205mOG`0305nGG`1O
UiL0Lg=c0080GemO00T009NG02`/;00/;2`0GemO07=cL`1ONel0YjNW05nGG`19BDT00P00Gel01@25
QHD0<9MO05mOU`00Gel0Lg=c0080GemO00d0Gel002`/;000G`00Gel002`/;01OUiL005l004U9B@0`
E000GiNG05o5U`1OGel0BDU90080;2`/01P0C8iS0:NWY`2WYjL005mO02`/;025QHD0;0000000B@1D
Ph<0GemO0;Jf]P19BDT0000/02`/;01OUiL0AV9R0000;000B@00GiMO09NGU`1cLg<0aLG504I6AP00
;00202`/;00C05mOG`25QHD0aLFG05ADJP00;000UenG0<G_a@0002`0Gel004U9B@1RNF8004T007=c
L`1OGel0BDU905nGG`0005l0LXj>001OG`0205nGU`0407=cL`1OaIL0GiNG07^G[P80GiO500l0UlG5
0:NWY`2WYjL0UiNG08>3P`1OGel0GiMO001OG`0/;2`005mO07=cL`0UE5@004T002`/;01OGel00P0/
;2`205mOG`0505ADE01OGel0GemO001OG`25QHD00P1OGel02@0jJFT0GiMO02`/;000Gel0BDU905mO
G`19BDT09EAD05mOG`02001OG`0407=cL`1OUel0;2`/02DU00<0GemO2?ooool000Kooooo00`002`0
0000;00/0000000002`0000/;2`0000/0000000/000002`0000F5P0/;2`2000/000502`/;00002`0
000/01HF;00002`00P0/;2`01000;000;00002`0000000020000;00:04U9B@2GGel0;00002`/;01S
HhL0;2`/0000;00/;2`0GemO0<FGG`80;2`/00X0NemO02`/;00/;2`0UiNG0000;000;000GiMO0696
AP00;000GiNG0P0/;2`0701OUel0B@0006=RC00/;2`002`00:NWY`0/;2`0GiMO04T0001<E30004T0
05nGG`00Gel0Gel002`/;000;000ATHF04U9B@1OGel0000007=cL`2GUel0BDU90820P01OGel0hN7Q
0:NWY`2GUel20;Jf]P0409:^N`35aLD0][Jf05mO0080aLG50140Gel00;jnY`000000UiNG0<FGU`00
0000UlFG0000001OUel0BDU909O5G`1OUel0BDU909NGG`0/0000GemO04ai<002000/000>02`/;000
;000Gel002`/;00003/0UemO05nGG`1cLg<005mO09NGG`00B@00JFTj04U9B@00Gel205mOG`80GiNG
00T0<9NG05mOG`00Gel0BDU902`/;01OGel005mO05mkG`25QHD00P19BDT03@1OUel0GenG05mOG`1O
TY8005mO05nGU`1OGel0BDU902`/;000;0005THF04U9B@1OGel00`19BDT04P1cLg<0E71D09NGU`19
BDT0;00004U9B@0004T0Lg=c06YZJP25QHD0BDU9001OG`1OGel005mO09NGU`1cLg<0Ng]k000/0080
000/01T0GiNG02`/;000B@00Gg]O09NGU`19BDT002`000190035klD0GiL007]kG`2GUel0GiMO0<G5
U`00Uel0UlFG05mOG`1DPh<0BDU905nGG`1OGel0e=CD0000B@1OGel0Gi9k0080UiNG102WYjL0102G
[Zh0GiO509NGU`2WYjL205mOG`0307=cL`1DE5@0GemO0080GemO00D0BDU902`/;01OGel05THF02`/
;00204U9B@0C05mOG`19BDT0BDU906UYJ@00Gel0GemO001OG`1OGel007<0001OG`19BDT0E5AD04U9
B@1OGel0BDU902`/;01OGel0Gel005ADE00305mOG`0507=cL`1OGel0BDU905mOG`00Gel00`19BDT0
1P1OUel0000/03/k>`00;000QHF5001OG`Sooooo0006ooooo`0A02`00000;000000/01H05P0002`0
000009O5a@0/;2`0;0000000;00F01H0;0000000000/0000000/02`0000000000P00;0002P0/;2`0
000/02`/;00002`0;00001H0000/;2`002`004U9B@35aLD202`/;00908j>N@35Uel0;2`/02`/;01O
Uel0kno50000;01OG`00[/G5008002`000L0UiMO05mO0000;000BDU907URAP0002`0GiMO0080;2`/
00<0GiMO02`/;01RNDH00P0/;2`02@2GaIL002`0001OG`19BDT0HV960019001OUel005l005l00002
02`/;00D04I65P1OGel0BDU902`/;01OGel0UemO05mOG`1hW6<0ono_04U9B@3_knl0aLG509MOG`2G
aEl0dm>n09NGU`1cLg<0kno505mOG`3De=@20;Jf]P0O09NGU`2WYjL0][Jf05mO002f][H0GiNG08>3
W`2GaIL0GiNG09O5U`1OaIL0aLG505nGG`35aIL0WinO0000;01OGel0;2`/05mO002WYjL00000000/
001OGel0Gel00019000/;2`005l005mO0016HQH0BDU905nGG`02001OG`0>04U9B@1OUiL0Pin305mO
G`19BDT0GiMO04U9B@0/;2`0GemO06UYJ@00Gel0BDU902`/;01OGel205nGG`80GiNG00<0GemO05mO
001OG`000P0/;2`04P1ONc00GemO04U9B@19BDT0GemO05nGU`1OGel0GiMk05mOG`0/;2`0GlFG04U9
B@0/;2`0UemO02`/;01OUel0YjNW0;Jf]P80Lg=c02H0UiNG05mOG`0F;1H005mO05mOG`1OUel0GemO
07=cL`0/;2`0Yi:B0;Jf]P2WYjL0e=CD0<G5U`2GUel0GemO04aSE019BDT0UlFG0019002GaEl0G`00
09NGG`23We@0Lg=c05nGG`0002`0BDU90<G_U`000000E71D04U9B@00G`00GemO04U9B@00Gel0Gel0
02EDE0<0BDU900/0GemO04U9B@1OGel0BDU907=cL`19BDT005mO05mOG`00Gel0BDU9031OG`0204U9
B@05001OG`19BDT005mO04U9B@0UE5@00P00Gel302`/;00407=cL`1OGel0Lg=c05nGG`80Lg=c00d0
GemO05nGG`1OGel0Gg]O05mOG`19BDT0;2`/05mOG`1OUel0UiMO06V5J@0/;2`0GiMO0080BDU900H0
UiMO02`/;01bLW80;2`/0000;019BDT8ooooo`001_ooool03`0F000001H001H/5P0F2aH0;1HF01HF
5P005P009AH002`/;0005QH08AHQ000F0000;0005QH/01H0000201H/5P0301HQ2`0F;1H05QH/0080
5QH/0;809@0F000/000F5P/05R`F02`/;016HV80TZj^0=?K_P2^`g/0SiZ407V>N@3JaJh0NGUi0=>n
_P1@D500P5]K09NBTP2KVi/0TY9k07UiHP2^[W/0Ni9k07]OG`2^[YL0P81K06=R<02OWil0TY9O06=R
<023Wil0NiMO07R4JP1<L300L71D09NGN`1RNDH0Gg]O05ADE01TJ4P0AQHF05n^N`0F>aH0Ng/`03/k
>`1ONc008dHk07^GG`1OUel09@0004TU9@1kNel09DTU08^:K@0F;1H0>c/k0=>n_P1<C4`05P0005nG
<025KV<05R`F05mOG`3J[W/0;2`/07]kN`3J`i80;ST^075aL@0F;1H001H009MkN`0F5QH0NjjG01H^
>@16ATH0000F051@D00F;1H09C/U05nGU`0U9C/0D7=X0820P01kTY80C8MS09nOW`1DL8L0HWUR05J8
I01IFET0E71`05mkG`1kNel0ATHF01I6AP12E2/0E5@U02`/;00jJCX0AV9R04U9B@0`<5@0F7Ad032G
U`0`Uel0<5mk05mkN`0/;2`0<5mO06V5M`0`Gel0<5l`04U9B@1YJCX09G1D04=bLP1TP800Gg]O05AD
E00FAQH0;2`/04I65P00Gc00CFU=031O001OGc00@fM305mkG`1YQFT0Gg]O04QkB016ATH0YjNW05iN
GP16HTH0E5AD031OG`0eLU/0L71D03YYJ@1DL5@0<7]O07]kG`0`Nc00>VUY08N7K@0jGSX0TYMk071`
E01<Gc00C69<08F5J@1JCd@0N7Qh01H/5P1@D5009BE905A<<025QHD0CDe=07^^N`13FD<0Ng]O069i
HP1WIfL0Re^;06=eH`1ONel0Ni9k069iAP1SHf80<69<0<GJTP1fNEd0>c/k02`/;00k>c/0;2`/0P1D
E5@00`0NCDd0BDU901I6AP0202EDE00705mOG`1DE5@0:UA202EDE00`Gel0E5@U05ADE00203/k>`04
03M?C`0`Gel0Gg]O02EDE080E5AD0280E71D01=XFP1NGUh0E5AD031kG`1DL5@0E5@U05A`E016HTH0
ATI605B7E00k>c/0E5AD05A`E00UBBD0>c/k04AKF`0jJFT0>Uhj051@D016NF809DTU07]kN`17IdL0
WkJ306YZJP1RNF80N7Qh04IRHP2>YHh0Ae=7069SC01k[YL09EAD2?ooool000Kooooo00H0;0000000
;000;0005P0002`/;000000202`/;0040000;00/;2`0;2`/02`000<0000/0`0/;2`00`000000;000
0000;00202`00004000/000F5R`002`002`00080000/0580GiNG05mOG`1SNF<0;0000000;01OGel0
aNo502`/;000;00005mO069RAP0002`0UlFG05mO000/0000000/0<G5U`0F;1H0BDU90<FGU`000000
BDU90<G5U`0/;2`0L8M`02`/;02GUiL0;2`/05mOG`2GUel0;2`/071`E01OUel0;2`/05mOG`00;000
GemO02`/;01kNel0BDU905mO000/;2`0Gel005mOG`0/;2`0W6UY0000002GUel0aING02`/;00002`0
UemO04``<00/;2`0GemO05l000000000Gel009MOG`00;000;0000000;000B@00Gel002`0001OUiL0
;2`/02`00000;000Gel000000000;000GemO0000;00`Qd`0Gel008F5Q@0/;2`0GiMO02`/;01OG`00
<5@`0P0/;2`205mO000;04U9B@1OG`00E5AD05nGG`1OGel0BDU9000/001OUel0GemO03/k>`2GaIL0
0P1OUiL0301cLg<0BDU905mOG`1ONel0GiMO001OG`1OUel0BDU905nGU`1cLg<0>VUY05mOG`<0BDU9
00d0Gel004U9B@0`Nel0GiNG05nGG`19BDT0;2`/001OG`2GaIL0ATI604U9B@00B@00GiNG0080GemO
00<005mO04I6AP1OGel00P0/;2`08P19BDT0GemO02`/;019BDT0HWUR05o5G`0004T0Gel0001O0025
QHD005mO07QhN02WYjL0GemO02`/;02GUiL0QHF502`0000`G`0002`0001O000/0000;2`/07=cL`00
02`0NGUR08F5Q@0/;2`0UiNG02`/;02WYjL0aNo50696HP35aIL202`/;00N00190019BDT0Gel003/k
>`1OG`00GemO04U9B@1cLg<0001905mOG`0k>c/0Lg=c05mOG`19BDT0GiMO05mOG`1cLg<0<4aD04U9
B@0/;2`0GiMO04T0002GGel0;2`/04=I@`00Uel0BDU90019000/0000UiNG0P0/;2`00`2GNg/0GemO
05nGG`0202`/;080GiMO00X0C71<05mO0000;000UiNG02`/;0190000UiNG02EDE01OUel004T00P1O
aLD01P2GUel0;2`/07^^TP00B@00Lg=c04U9B@Sooooo0006ooooo`0409NGU`0/;2`002`000000080
;2`/00/00000000/00000000;2`/00005P000000;2`/04T0000/;2`0B@0002`/;002000/00<0;2`/
0P0000000`0F5P0002`0000/000302`/;00J07=cL`1ZJVX0000/0000;01OG`00klG502`/;0000000
;2`/05UIF@0002`005l00<G5G`00;000000009O5U`1<AP00;0000<FGU`00;000;2`/09NGG`0/;2`0
L4``02`/;025QHD202`/;00>05nGG`0/;2`0AV9602`/;019BDT0GemO05mO001OUel0;2`/031k<000
;000G`0005mO000/;2`204U9B@0:04a`C0000000aLEO09MO0000;00004T009NGG`0F5QH002`009MO
G`80;2`/0180GiL002`/;016ATH0;2`/000/000005l0Gel0000/002GaLD05V960<G5U`00Gel0UiMO
07=cL`00B@00GiNG02`/;01<HhL205nGU`0605mOG`2WYjL0BDU905nGU`1OUg/0Lg=c101OGel01P19
BDT0AV96001O00190000BDU908F5Q@80GemO00@05THF05nGG`1cLg<0UiNG0P1OGel01@19BDT0LXj>
04U9B@00Gel0Gel00080Lg=c00`0GiNG05ADE000B@0005l005mOG`19BDT0;2`/001OG`1bSXh005mO
05mO001OGel204U9B@0305mO000`Nel0Gel00080GemO00L005mO05nGG`1OUel0>c/k07=cL`19BDT0
GemO0080BDU90P1OUel05P1kUel0UiMO09NGU`1OUel0GemO02`/;01O0000E5AZ05mOG`25QHD0GemO
02`/;035aIL0QHF509nOW`1OU`00YjNW0000B@1OGel0;2`/04U9B@0F;1H302`/;0070>o5U`0/;2`0
QHF502`/;03QhN4005mO07=cL`0305mOG`0B05A`L01OUel0BDU905nGG`1cLg<0GemO001OG`25QHD0
05mO02`/;025QHD0BDU905nGU`1OGel0JFUY07=cL`1OGel005mO0P1OGel08P19BDT0<70`02`/;000
Gel0GiNG05mOG`19BDT0GiMO07=cL`0/;2`0BDU900190019BDT005mO04U9B@0/;2`0<7/`02`/;01O
UiL0;2`/001OG`2WYjL0;2`/069RAP0/;2`005l00<G5U`1OUel0;2`/001OG`25W8D0;2`/0;Jf]P00
Gel8ooooo`001_ooool01000000002`00000000F000202`/;009000000190000000004T000005P00
000002`/;00/000002`00080000000X09AH0000/000/;2`0;2`/0000;000;000;000000F000/;2`0
;0000P0/;2`01`0002`0001904IRAP0/;2`0000005mOG`2GaLD00P0/;2`0400002`0L8M`0000;000
;000UlFG000/0000000005mO07URAP00;000YjNW000/00000000GiNG05mO001@D50202`/;00909NG
G`0/;2`0UiMO02`/;01OC30004T005nGG`0/;2`0UiMO0080;2`/02d05S/F05mO001OG`0004T004U9
B@1OGel0G`0008iiN@19BDT0][Jf000/0019BDT0UiMO09O5U`0`E000GiMO0>o_a@0/;2`0GemO0;Jf
]P2GUel0N7Qh09O5U`00Uel0][Jf09O5U`1OUiL0YjNW09nfW`1OGiL0QHF50:NWY`1OaIL0BDU905o5
a@00Gel0GjjG001OG`1cLg<0UlFG05mOG`2GUel0BDU904I65P1cLg<00P1OGel03@1OG`0004T002`/
;01kNel0GiMO05mOG`0/;2`0BDU9001OG`1cLg<0Gg]<05nGG`2GUiL00P1OUiL0301OGel0Gel007^^
U`19BDT0GiMO04U9B@1OUel0UiNG001OG`16AQH0B@0004U9B@80GemO0P1cLg<0B@1OGel0GiMO05nG
G`00G`00Gel005nGG`1OaIL0JFUY02`/;01OGel0BDU905nGG`1OG`00GemO05mO<01OUel0BDU905nG
G`1OGel0GiMO04U9B@0002`09DTU05nGG`00;000UiMO02`/;01OUel0B@0006=RC02GUel0BDU90000
000/0000aLFG02`/;016AQH0000004U9B@25QHD0UemO05mO002GUel0Ph>302`/;035aEl0;2`/001O
G`1OGel004T006=RC00002`0GemO02`/;00/0000;2`/05nGG`1DL5@005mO04U9B@1OGel0BDU905nG
G`1OGel0Gg]k08F5Q@1OGel0GlFG05nGU`1OUel0GiNG05nBN`1cLg<0101OUiL01000Gel0LXj>05nG
U`1cLg<309NGU`0305nGU`1cLg<0NjjG008005mO01H0GiNG07=cL`00Gel009NG05A`E000Gel0GemO
04U9B@1OaLD0UemO02`0001RNDH000190<G5a@1OGel0000/02`/;03_klD0D51@0:NWY`25QHD0GemO
2?ooool000Kooooo00@0000002`0000002`001H00P0/;2`2000/000802`00000;00001H002`00000
02`002`002`0000002`202`/;080000/00<0000002`00000;0000P00;0000`0/;2`0000/00000002
02`/;0060000;016ATH002`002`0001OGel0QHF50P0/;2`02`00;000E4a<02`/;00/;2`0aLFG0000
B@0/;2`002`007UiHP00;000UiMO0080000/01D0Gel009NGG`0k>c/0UiMO04T0002GUel0;2`/09NG
U`0/;2`0L71D02`/;01OUel002`009NGG`19BDT0UiMO05AD9@1OGel0BDU902`/;01OGel00P2WYjL0
8@20P8h0GemO0:NWY`1OGel0GlFG0<G5a@35klD0[/FG0:NWY`2GaLD0UlEO09O5a@19BDT0UlG508f=
S@2GaIL0][Jf04U9B@2GaLD0UemO0000;01@D500GlFG02`/;01OGel0BDU909O5a@00;000UlG504I6
AP1OUel0;2`/09NGU`0202`/;00=04U9B@16AQH0GiMO04U9B@00;000000/001OG`19BDT0<1H002`/
;01OG`00BDU905nGG`0205mOG`0I001OG`19BDT0GenG001OU`1OaIL0GemO04U9B@1kNel005mO05mO
0000Uel0UiNG001OG`1O00005THF04U9B@1OUel009NG09NGU`2GGel0GemO001O<01OGel0;2`/05mO
G`0202`/;00[04U9B@16ATH0GiMO002GG`1OGel0Lg=c05mOG`1OUel0GemO04U9B@0/;2`0BDU902`/
;019BDT005l002`/;00`AS00BDU902`00019BDT0;2`/0<G5U`00;000Hdb7000/0035Uel0BDU902`/
;02GaEl002`004a`<00/;2`0UemO000/000002`0UiMO000/000F0000Lg=c02`/;01cLg<0YjNW04U9
B@0209O5U`0;0;Jf]P190000;2`/04U9B@2GUel0BDU9031OG`1OGel009MO05mOG`1OUel00P1OGel0
501DE5@0Lg=c04U9B@1OUel0BDU905nGG`19BDT0E5A`07=cL`1OUel005mO0:NWY`00G`00QHF502ED
E01OUiL0GemO09O5U`1cLg<0;2`/0P2GaLD06@2;Rh/0UlG509O5U`1OGel0UlEO0<G_a@3QhN40L8N7
0<G5a@25QHD0UlG_0>o_a@1OGel0aOoo031OG`3QhN40][Jf05mO0000;000UlG50?ook`0`AS00aOo5
05nGU`1OGel02?ooool000Kooooo00D0000/0000000/00005QHF04T0000202`00080000/00@00000
000F5P0002`0000/0P0/;2`03@00;000;2`/01H/5P0/;2`0000004T0000002`002`002`/;00F;1H0
;00008F5Q@0/;2`00P00;0000`0002`0Ug]O000/000202`/;00504U9B@35Uel0;2`/02`/;02;Rh/0
0P0/;2`05`19BDT0aLFG02`/;00/;2`0W8Dj02`00019BDT0aIMO02`0000002`0UiNG069<<02GUel0
04T008F5Q@2GG`0005mO09NGU`1bLW80Uel002`/;01OG`00000/0080BDU902L0C70`000/000/;2`0
GemO09O5U`3QhN40aLG508N7Q`2f][H0aLG50;Jf]P35UiL0;2`/0;Jf]P20P80002`009NGG`2f][H0
000/000/002f][H0HTI605o5U`19000002`009O5U`1O000002`004H`002GUel002`005o5U`0002`0
UemO000/002WYjL0<4a<09NGU`00Gel00P0/;2`01000;000UlFG03/k>`2GUiL209O5U`0?0:NWY`1c
Lg<0UiMO05A`E01cLg<0GiMO001OU`1OUel0GemO05nGG`0`Nel0GemO001O001OUiL0GlFG0080GemO
00X0Gg]O05nGG`00G`00GiMO05mOG`1OG`00;2`/01I6AP00Gel0GiNG0P1OGel0101OUel005mO05AD
E000G`0204U9B@0405mOG`00B@00BDU905mOG`80GiMO02`009MO04U9B@00G`00BDU904I65P0/;2`0
BDU902`/;000B@00BDU905mOG`00B@009EAD02`/;025QHD0BDU909O5U`3_aLD0GlG50;>c/`0/0000
;2`/09MOG`1O05l002`009NGG`2GUg/0;2`/09NGG`0/;2`0;00005mOG`0/;2`05R`F02`/;00/0000
;2`/09NGG`0/;2`002`004IR5P35aLD0BDU9001OG`80GemO00L0Lg=c05mkG`19BDT0UiNG05mOG`1O
Uel0GenG0080GiNG01L0GemO05nGU`00Uel0GiMO07=cL`00Gel0GiMk09NGG`1OGel0BDU9001OG`19
BDT0GemO04I6AP1OGel0001908F5Q@1cLg<002`00:NWY`1OGel0NGUR05nGG`0205mOG`0E0<G5a@1O
Gel0YjNW08^;R`19BDT0aLG505mOG`2f][H0e=CD09NGG`2Bf/D0aLG509O5a@1OaIL0kno50;Jf]P35
klD0][Jf0<G_a@2WYjL005mO00Sooooo0006ooooo`070000000/0000000/00005P00;000;0000000
;0020000000502`0000F01H0;0000000;000;0000`0/;2`00`0F5R`0000/02`00003000/000502`/
;00F;1H0000/02`/;000;0000P0000000`0/;2`0TY9k09NGG`0202`/;008001OG`2GaLD0][Jf05nG
G`1STV<0UlFG02`/;00/00020<G5U`0=09MO002O]X<0aLFG05mO002GaIL0][Jf05mO002WYjL0QhMD
04U9B@1OUel0GemO07=cL`0209NGG`0f05nGG`00;000GiMO02`/;01OUel0Gel005mOG`1OUel0GemO
05l0002WYjL0aLG_0<FGU`00;000][Jf02`/;02GUiL0aLFG02`/;0000000UiNG04a600000000YjNW
04U9B@190000;2`/09NGU`0/;2`0UlFG000/0000B@00][Jf000/000/;2`05QH/04U9B@00B@00GlFG
000/001OG`0002`005nGG`1ONel0;2`/0:NWY`00Uel0UlG505o5a@1OUiL0JFUY05mOG`1OUel0GemO
0P1OUel01P1OGel0Lg=c05mOG`00Uel0GemO07=cL`80GiNG0180<7]O05nGG`19BDT0GemO05nGU`1O
Gel0Lg=c03YYJ@0/;2`0GemO0:NWY`2GUel004T004U9B@1DL700YjNW05nGG`25QHD205mOG`0904U9
B@00E000BDU902`/;000G`00BDU907=cL`1OGel0E5AD00<0GemO00D0BDU9001OG`00Gel0<9MO05nG
U`0205nGG`0J05mOU`1OUel0Lg=c07=cL`0`Nel0GemO02`/;02GaIL0BDU905mOU`0/;2`0ATHF05mO
G`00;000;2`/05nGG`0/;2`0BDU902`/;02GUiL0;2`/09NGG`2GUiL0QHF504U9B@0`AS0302`/;00<
0;Jf]P0002`002`004I65P2f][H002`005mOG`1OUel0GenG05nGU`1bSXh0GlFG1@1OUiL0401YQHD0
GiNG08F5Q@25QHD0GiNG05nGG`2GUiL0SXib09O5U`1OUel0UlFG07=cL`2GaIL0BDU9032BN`1OGel2
05nGG`0F0019001cLg<0GiNG05mO001`L700GemO0019002GUiL0Lg=c04U9B@25QHD0Gel`001OG`2G
Uel0BDU90;Jf]P00G`0005mO08^;R`19BDT0e=CD0<G5a@80;2`/00D0aLG50<?3[P35klD0][Jf05mO
G`08ooooo`001_ooool030000000;2`/0000000F000002`00000;0000000;000000/00190000000F
00000080;2`/0P00;00202`/;080000/00H0;2`/0000;00002`0B@0002D00000000202`/;0800000
00/0;2`/0:NBTP2GaIL0aNo505mO0035aIL0BDU905mOG`2f][H0C8MS05mOG`020<G5U`0C09MO0000
;000GemO08=DE00/;2`0UiNG0<FGG`0/;2`0YjNW09MOG`0/;2`0GiMO00190025QHD0Gel007=cL`1O
Gel0HWU6000/000302`/;00C09NGG`19BDT0JFUY02`/;000B@00UiMO0<EOG`0002`0BDU907UiN@00
;000YjNW05l00000;000;2`/0;Jf]P005QH0;2`/09NGG`020000;00?04U9B@35aIL004H`0:NWY`0/
;2`0GemO08F5Q@0/;2`0][Jf04IRAP1OG`00GlG509O5a@1OaIL0UlG50080GiNG0P2WYjL205nGU`80
GemO00T0QHF509nOW`1OUel0GiMO001O0019BDT0GiMO08F5Q@1bSXh0101OUiL03@1OUel0BDU907:>
LP19BDT0Gel005nGG`25QHD0GiNG05mOG`25QHD0UiMO08F5Q@1OGel00P19BDT02P1OUel0Gg]k05mO
G`1OGel0BDU90000B@00G`00Gel000190000G`0205mOG`0405nGG`1OGel0GemO08F5Q@80GiNG0P1O
Gel01000Uel0BDU905mO<01OGel304U9B@0V05mOG`0/;2`0;2`/03/k>`1OGel0;2`/09NGG`0/;2`0
Lg=c02`/;00`AP0002`009NGG`1OaEl0GemO04U9B@00B@00HV9609NG000/;2`0Gel0000/0019BDT0
GemO069RHP1OUel0;2`/0019002f][H0;2`/0019001<HS00UiNG02`/;01OUel0;2`/04U9B@00Gel2
05mOG`<0BDU901T0GiMO05mOG`1ONel0GenG07=cL`1OUel0GemO09NGU`1OUiL0GiMk08F5Q@1OUel0
QHF505nGU`2WYjL0GlFG09nOW`1OGel0YjNW05mOG`1OUiL0UlFG07=cL`19BDT0QHF50080GemO01H0
UlFG05nGG`0/;2`0UiNG03YN>P2WYjL0Lg=c000/002WYjL0Lg=c000/001kUel004T00=CDe025QHD0
;2`/000/0035aLD0D51@0<FGU`35klD0GemO2?ooool000Kooooo00P05QHF01H0000/5QH02`/;01H/
5P0F0000000001H0008001H000D02`0;01H/5P0F01H0;2`/000F5P0201HF;003024Q8@0002`05QH/
00805R`F0P005QH0200;2`/05QHF01HF5P0k5QH0000/000F5P0F;1H0XYBD0P0/;2`0KP1iNGT0T/G5
071`E00/;2`05R`F08V[U@1RATH05QH/069iHP2OWh<0HTI601H/5P28Kf40<4H`01HF;01`C4`0L71`
01HF;01ZJVX0CE]K04IRAP1DL5@0>c/k031R<00`Nc00<4H`031X<016HTH0E71D04I6AP0`HS005QH/
05mk<00d=3@0E71D09:BTP2>SWT05QH/04IRHP35aI80>2HV071`L02;Re/05QH/000/001OUg/0P5]K
01HF8@1OUel0Ph=D000/000`C300Rh^;09:BN`28NVl0Ujik081KF`2BYi80C8M<04IRAP1KRh/0DGMY
07^BH`0jJFT0Win307]kN`1KLE/0@eU30820P029UiL0AV9605mOG`16ATH0AV9R05A`L00`Nel0Fg9b
04IRAP1ONel0E71`069iHP0`C4`0<68`02<k<00`C300<4H`031<C00`<300GiMk05nBTP18RG/0<7]O
05mkG`1ONg/0UlG507^GU`1bLW80KWa^08F5J@1RHTH005@`05A`L01OUg/0>VUY05m]<00k>c/0<5@`
05ADE016ATH0>c/k0P1OGel00`1DE5@0>XEY06V5J@0205mkG`1Y05nGG`18Qf@0E8M`04IRHP0`TW/0
AV9R05A`L00`Nd`0<7IT05A`L013@eT0<5l`04IRAP1YQHD09DTU03/k>`0eCEP0[/FG030`AP2^[YL0
>c/k09:BTP0F5R`0Ni^905mk<016ATH0HTI6031R<00F;1H0GiMO03/k>`1YJFT09DTU04I65P0j>Uh0
5QH002`F5P0Q;240L5AD030`AP1kUel0>c/k075aL@1`L5@0CfE?09nfW`2W_ZL0Fh1K031kG`0`Gel0
<7]O06AbI01YJFT0LXib05mOG`0`Nel0GemO04U9B@0`KEl09EAD001OG`1YJFT0<5mO05mON`0`Gel0
I8j006V5J@1YJFT09G1D08>3P`1DL5@0NiNG05Z4MP1DWil0Pin308^WY`1bSXh0E8>308^WY`1kUjh0
KJj908^WR`2O]Yl0Gi:B05nBN`2B[YL0]/^f086=S@2GaIL0<5mO09baW01YQHD05S/F08>3P`16HV80
TZn^0:FUSP1DE5@0;2`/01H09@2^[YL0=EHe0<>^[P1bSXh0E5AD00Sooooo0006ooooo`<0;00000D0
5QH002`000000000;0000000000202`000080000000/;2`0;2`/000/00000000;0000000;0000005
02`/;00502`000005QH0;2`/02`/;00000000P0/00000`1OGel0TY:_000/000202`/;00i001OG`2G
aLD0GemO02`/;00/5QH0UiNG00190000;000;2`/0<G5U`00;000;2`/0:NWY`2GGel0000/001OG`2W
YjL0B@0004aSC00/;2`002`005nGU`1OGel0;2`/05nGG`1RHTH0GiMO001c001OUel0;2`/05nGG`1c
Lg<0NemO09MOG`35UiL0000002`/;02f][H0;2`/030`AP2f][H000190000001OGel0aLG502`/;01<
TW/0][Jf0<G5a@2WYjL0QHF502`/;02f][H05QHF0<G5U`0002`0aNo5008002`00140UiNG05mOG`00
Gel0YjNW02`/;019BDT0YjNW05mO001OGel0BDU907=cL`1OGel0Lg=c001OG`1OUiL0BDU903/k>`02
0000000502`000000000;0000000;00F5P000`000000300/;2`0;00002`/;01kNjh0GiMO001OG`00
B@00UiNG05nGU`1cLg<0QFUY02`/;080GiMO0P1OGel0101OG`0004H`001OG`19BDT305mOG`0R05nG
U`1YJHD0GiNG05nGU`1OUel0BDU905mOG`00Gel0Gel004U9B@1OGel0BDU908F5Q@1OGel005mO0727
L00/;2`005mO02`/;00002`0;2`/0;Jf]P25QHD0BDU90019002WYjL0BDU909O5U`19BDT0UiNG04bB
TP1OGel0BDU907=cL`80BDU900X0;2`/04=W@`2GUel0001909MOG`0/;2`0UiMO05mO002GUg/002`0
0P0/;2`02@0/0000BDU9000/001SND`0000/02`/;02f][H0GiNG07=cL`0405nGU`0708F5Q@1OUiL0
GiNG08F5Q@1OUg/005mO05nGU`0205mOG`0305nGG`00Gel0E5AD0080Lg=c00L005mO07=cL`00Gel0
GiNG05A`E01OUiL005mO0080QHF501`0001905nGU`1OGel0NiNG08F5Q@00Gel0YjNW09NGU`19BDT0
][Jf06V5J@3QhN40][Jf0:NWY`2f][H0YjNW0<G5a@23Wil0][Jf0<G_a@1OUel0;2`/08F5Q@2GaIL0
D51@0<G_a@25QHD0BDU92?ooool000Kooooo00H0;000000/000/00005S0`0<EOG`00;00200000004
000/000002`0000002`/;08002`000D0;0000000;00002`05R`F02`0000202`/;0040000;00/;2`0
000/000F5P80;2`/00L0000/000/000/;2`0;2`/04I6AP35knl004T00080;2`/01@0GemO0;Jf]P0/
;2`0;2`/04U9B@35aIL002`002`/;025QHD0][Jf02`F5P00;000YjNW05mOG`00;000UiMO0:NWY`1k
Nc00UiMO07=cL`80QHF500@0UiMO05nGG`1k[Ul005l00P2GUel01@1OGel0UlEO000/0016AQH0knoo
0080;2`/01/0GiMO09NGU`000000<4H`0;Jf]P0/;2`005mO09O5U`1OGel0][Jf0820P00/0000YjNW
04U9B@0/;2`0][Jf05mOG`1RNGT0000/09O5U`19BDT005mO08F5Q@00B@00C4aR09NGU`1OUiL00P1O
Gel01@00Gel0GiNG05nGU`1ONel0BDU90080;2`/00X0;000000/0000000001H002`00000000002`0
0000;000000002`00`0000005000;0000000000/000002`0Gg]k05nGU`1OUel0;2`/07=cL`2GUiL0
05mO05UIF@00G`00GiNG07=cL`1OGel0;2`/05mOG`0UE5@0Gel00P1OGel204U9B@0905mOG`0`NiL0
GiNG05nGU`1OGiL009MO09NGU`25QHD0PkJO0080UiNG01@0YjNW05nGa@19BDT0;000031DC01OG`00
;2`/0019000/;2`0000/0<G5U`00;0009AH00000;01OGel0;2`/0:NWY`0/;2`0UiMO07]kN`80;2`/
00H0;00004U9B@0/;2`0GemO05AD9@19BDT202`/;00>0000;01OG`00;2`/04=I@`2WYjL0UemO09NG
G`00;000UiNG04U9B@1DN5@0;2`/04T0003_klD204U9B@04001OG`0`Nel0GemO05mOG`80Lg=c00<0
GiNG001OG`1OUiL00P1OUiL0;01OaIL0GiNG05nGU`1OUel0<7^G09NGU`00Uel0Lg=c05mOG`00Gel0
GiNG031OG`00GiL0BDU905nGU`1OGel0;2`/09NGU`1OGel0Ng]k05mOG`0/;2`0UiNG07=cL`19BDT0
][Jf03YYJ@35aLD0GiMO04U9B@35aLD0UiNG09MOG`35aLD0Lg=c0=CDe02f][H0aNo50>o5a@35klD0
GiMk0<G5U`2GUiL0GemO2?ooool000Kooooo00@002`002`0000/00005QHF0P0/;2`01P000000;2`/
02`/;00002`05P00000/0080;2`/00L002`002`/;00/;2`05R`F04T0000/;2`002`000<0000/00/0
5P0F02`/;00002`0000002`/;000;00000000316<01OGel0aLG50019000202`/;00405nGU`35aLD0
;2`/02`/;080YjNW00@0UlFG05nGG`2GaIL0_[jW0P2WYjL01@1cLg<0YjNW0:NWY`0/;2`0AV960080
BDU902X0UiNG04U9B@0004T0GiMO03/k>`1OUel0BDU90000B@2GUel0;00005nGG`1aLG40kno_05nG
G`2GolD0aNo505mO0000;000RjNW0<G5U`35aLD0YjNW02`/;01OUel0aLG501Hk5P2GaIL0YjNW0019
002GaIL0GemO0000;01hN7P0Lg=c05mOG`00;000YjNW04U9B@2GUiL0Gg]O05nGG`00B@0305nGG`80
BDU900T05QH/0000000002`002`000000000;000;00001H00000;0001P000000;@00;000000/0000
00000000000/0000000`C680YjNW05nGG`0/;2`0GiNG0:NWY`2GUiL0>VTj05nGU`1OGel0BDU902`/
;019BDT0GemO031kG`1cLg<0GiNG05nGG`00Uel0GemO001OG`0`Nel005mO05mOG`1OUel0BDU9001O
G`19BDT0E5AD001OG`0004T005mO04U9B@1cLg<0GiNG05n^U`2f][H009NG09O5a@0205nGU`0;09O5
a@1OGel0E71D05nGG`0004T0;2`/04U9B@00;000YjNW05mkN`2GUel00P1OGel05P0/;2`0Lg=c02`/
;00`<5@0Gel009NGU`0/;2`0Lg=c02`/;000;000<2D009NGU`0/;2`0GemO09MOG`0/;2`0][Jf0<c<
c00/0000aLG50?o_a@19BDT205mOG`0B04U9B@1OGel0BDU908F5Q@1OGel009NG002GG`0jQHD0GiNG
05mOG`1OUiL005mO05nGG`25QHD0LXj>05nGU`2GUiL0GlG50P1OUiL08P2GaIL0Gi9k07=cL`00Gel0
UiNG001OG`0004T0GiMO05mOG`1kNel0GiMO001OG`1OUel0QHF504U9B@2GUiL0BDU90;Jf]P1OUel0
;2`/09O5U`25QHD0BDU909jNWP1OGel0YjNW0>7Qh@2GaIL0Lg=c0<G5a@3JklD0hN7Q09NGU`1OGel8
ooooo`001_ooool2000/00060000000001H0000002`0001OUiL0aING0P00;0000`0F5P00;0000000
;00202`/;08002`000<0000F0000;00/00000P00;00202`00005000F000/000002`0000/00190000
0P0000003@0F5QH0GemO001OG`35aLD0UiMO05mO000/;2`0aNo50<GgfP25QHD0][Jf001OG`25QHD0
0P2f][H00`00>`00GemO0:NWY`0302`/;00]09O5U`19BDT0UiMO07=cL`190000GiMO09NGG`00Gel0
GiMO02`/;000G`00GiL002`/;01OUel0Gel005^0F`35aLD0][Jf04U9B@2f][H0YjNW0<G5a@2;Yh/0
klG504U9B@00;00007<00<G5a@00;000NHii09NGU`0/;2`0][Jf07=cL`00;000GiMO02ED9@1OG`00
BDU909O5a@19BDT0Gel005mOG`1@D50005mO0080GemO0P00;0001P0002`0000000000000000002`0
02`00080000000<002`001HF000/00000P0000001@00;000;00002`000005P00;0000080000001H0
02`002`000000000<4aR09NGU`1OUel0BDU908F5Q@1OUel0Lg=c031`C01OGel0BDU900190019BDT0
GiNG05mOG`0`Ug/0GiMO07=cL`00Gel0GemO0P19BDT05`1ONel0BDU905nGG`1OGel0UlFG05nGG`1O
UiL0GiMk05mOG`19BDT0GiNG002GU`1OUiL0GemO03Z5Q@1OGel0GlG505mOG`2GaIL0GiNG09NGU`2W
YjL0GiN^0080GiNG00L0UiNG0:NWY`1OUiL005mO071`E019BDT005l00080UiMO00d0001905mOG`0`
E300;2`/0019002GGel0BDU902`/;02GUiL0;2`/05l0000/;2`0aING0080;2`/00@0QHF501HF5P35
klD0][Jf0P1OUiL00`1OGel0GiNG05mkG`0205mOG`0805nGU`1OGel0Lg=c07=cL`1OGel005mO04U9
B@1OGiL2001OG`0405nGU`1YQHD0GemO09O5U`80UiNG00@0GiNG0:NWY`2GaLD0UlFG0P1OUiL205mO
G`0407=cL`1OG`00LXib002GG`80QHF500P0GemO05mO0025QHD09EAD0<G_a@1OGel0BDU90:NWY`80
BDU900/0^K6L02`/;00/;2`0aNo509NGG`00;000YjNW0:k5U`35UiL0aNo5001OG`08ooooo`001_oo
ool0200/;2`000000000;00/000000000000;000;000;0000P0/;2`01@0F01H002`0000/000/;2`0
02`00080;2`/00H0000F00000000;000Lg=c02`/;00002`20000000<000/0019000002`002`/;000
0000;00001H/5P0/;2`0QHF50?o_k`3_knl0aNo50P35aLD03016ATH0Gel009O5U`2WYjL004T002`/
;02GUiL0C99O02`/;01OG`00UlFG04U9B@80;2`/0180QHF502`/;000;000UiNG04T0000/;2`0GemO
04a`<02GUiL0;2`/000/002GaIL002`002`/;02BTY80Lg=c000/000/;2`20<G5a@0C09O5U`1STV<0
;2`/0000;02GaIL0][Jf0000;000B@00WYjN000/0035aLD0UiMO05o5U`2WYjL005mO075aL@2GaLD0
BDU90:NWY`0207=cL`0502`/;0005QH0;000000/000002`00P0000003P0/0000000/000000000000
;0000000;000;0000000000/000F5P000000000/0000000002`00P0000006@0F000002`00000;000
0000;0000000000/;2`05QHF002GU`2GUiL0;2`/0:NWY`1cLg<0;2`/07:>SP0/;2`0Gel002`/;01O
Gel0Lg=c05mOG`16ATH0;2`/05mO0019BDT00`1OGel00`0`Gel0;2`/000/000202`/;08004T00140
05@002`/;01OGel005mO05mO0000G`00UiNG000`E02GaLD0BDU905o5U`00GiL0BDU905o5a@19BDT0
<5mO04U9B@02001OG`0705o5a@19BDT0][Jf031D002GUel004T007=cL`0204U9B@0902`/;01RHTH0
;2`/09NGG`0/;2`0UiNG00000000B@00C7]k0080;2`/00T0GemO0000;000B@00UemO01H/5P35aIL0
000/0000B@19BDT00P1OGel05`1YQHD0UlFG05nGU`1OUiL0GemO05nGU`1OGel0>VUY001OG`00GiL0
GiMO001OG`1OGel005mO031OG`00Gel0QHF505mOG`1OUiL0Lg=c08F5Q@23Wil0UlG50080][Jf0100
YjNW09O5a@2f][H0GiNG09nfW`2GaIL0][Jf09NGG`1cLg<0YjNW09O5U`1bLW80YjNW05mOG`1OGiL0
UiNG0P0/;2`02`2TY8L0;2`/05mOG`3_klD0BDU902`/;02WYjL0Ng]<000/0035klD0GemO00Sooooo
0006ooooo`0602`0000/;2`002`0000F000002`000000P00;0002@0/0000000/01HF5P0/;2`002`0
0000000/;2`0000/02`0000202`/;00:0000000/000002`0000/000002`05QH/04T0000002`00000
0000;0<002`000D0000004U9B@1OGel0GemO09NGU`020<G5a@0508N7Q`0/;2`0;2`/05nGG`35aIL0
0P0/;2`01P1SND`0GemO02`/;00/;2`0Lg=c0<FGU`80;2`/02D0UiMO04U9B@00Gel0GiMO09NGG`0/
;2`0N7Qh09O5U`2GUel0GemO08F5Q@19BDT0Gel007QhN000Gel004T00;Jf]P35aLD0BDU9001OG`1K
LE/004T009O5a@2f][H004T007=cL`35klD0Win30:NWY`00Uel0QHF50000B@1OaIL0UiNG04b^TP25
QHD0000/0080000000<0;0000000;00000000`00000202`000030000;0000000000000H0000000X0
01H000000000;00000000000;000;0000000000F00000000;0000P0000002P00;000000000005P1O
UiL0UiNG04U9B@2GaIL0UiMO05mOG`1@D50205mOG`0807=cL`00;000BDU905mOG`0UE5@0Gel0001O
0000B@0202`/;00A04U9B@0k>c/0Gel005nGG`1OGel0BDU905mO0019BDT0JIb508F5Q@1OUel0Gel0
001OG`19BDT0GemO05ADE01cLg<00P1OUel03P1OG`00GemO001OG`00B@00HV9609NGU`00;000;2`/
001OG`1OGel0GiNG09bLQ@25QHD0GemO0P0/;2`01P2GUel0;2`/07]kG`2GUel002`008F5Q@80;2`/
00/0UiMO03/k>`2WYjL0GemO02`/;000B@00UiNG02`/;01aLG40Gel002`/;00204U9B@03002GG`00
Gel0<7]O0080GemO00H0Lg=c05nGU`1OUiL0GiNG05mkU`1OUel207=cL`80GemO00D0GiMO031kG`00
Gel005mO07=cL`0205mOU`0R05nGU`1OTW/0GiNG05nGU`1OGel0][Jf05mOU`2GUiL0UlFG0:k5[P2f
][H0YjNW0;Jf]P1OaLD0][Jf0<G_a@2fbkH0aLFG001OG`2f][H0UiNG05mOG`19BDT0Qib702`/;01O
GiL0aLFG000/000/;2`0aNo5069RAP0/;2`0klG505mOG`Sooooo0006ooooo`0=000F000F5P005P0F
000;00000000000F000F5P005P005QH0000F5P0Q8AH05QHF02`/;002000F5P0701HF;00/5QH02aHQ
01H0000F5P0002`0000F000200005P0601HF0000;0005QH/01HF;00F01H05P000P0F5QH0KP005QH0
5QH/01H/5P0/5QH05QH/02`/;01@D500WZVY0:jWTP1RATH0;2`/03/k>`1<Qd`0QhM`04M7>@25W8D0
WkJO069iHP1RHc00HWUR0;jnY`2JYHh0C4aD0:FUSP2BTW/0QHEY03Y@>P1<HS00OWib0:ikG`1<HS00
<69<08FLQ@1OGc00E6YD05=MD`27QhL0LG5a04=I@`16ATH0W;6L05^0F`1XV8d0Ykjn08jUY@1`Qg00
TY:B07^BC027W8L0DHF504aSQ`0U9BD0ATI604a<HP0U9BD001HF01HQ2`0001H001H001HF5P005P00
5P00000F000;2`/05R`F0000000001H001H001H05P005P005P0000/;00005QH05P0001HF5P1@D500
000000005P002`00000001HF000001H001H00000000/5QH001H0000F5P0F000001HF01H000005P00
000F00/F5P1OUjh0NiMk05mkN`1ONel0N7Qh031R<012J4d0Gg/`03/k>`1OGc00BDU905mO001DE2D0
@UX[02EDE01OUel0<7]O0P1DE5@07`1OGel0Gg]]03/k>`16HV80<7]O05iNGP0`<300GemO04ALG00j
JFT0GemO04=bLP1IFET0E71D05mkG`1fMWH0P82004ak<01kNg/0NemO06V5J@27Qg00E5@U03]6>`1O
Nel0ATHF04aD<00U>bD0LE]K04I6AP2:P8/00P1RHTH08`0UE5@0GemO0727E01kNel0FEU;04a6<02B
Nd`05TI601HU001<Nd`0AV9605EDB@0F5QH0HV9607URAP0F5S/0aLG5031OG`2DWhP0000/05mkN`1k
UiL0GjjG05mkN`1<TW/0MgMg06UYQ@1cLg<0<7]k05nGG`0`Gel0Gg]k06UgM`1kUg/0<9Mk0080GiNG
01X0GiMk08F5Q@1^RVh0GemO06UYJ@1OGg/0Gg]k06UYJ@1YQFT0GiF903/k>`1OUiL05TI609NGU`1Y
JFT0E71`031kN`1YP6T0QIb506MWI`1kUiL0WinO06V5Q@2f][H0Shn40:j^[P80][Jf00h0f][509FE
U@2BYjh0/kf_04IiN@3Kfm<0GjjG051@D01aLG40cN;=04mMC`1<C700aMZG031OG`Sooooo0006oooo
o`0=02`00000000002`001HF00000000;0000000;00/;2`0000004T0000F;1H0;2`/0000;002000/
0080000/00D05QH/000/000000000000000/00020000000701H05P00;000;2`/02`/;00002`0;2`/
0000;00202`/;00;02`00000;000;2`/0000;000Gel0YjNW04I6AP2WYjL0aLG509NGG`2GaEl00P2G
aIL01035aIL0GemO00190025QHD20<G5U`0;001O000/;2`0UlFG0<FGG`00B@00001907=cL`35aIL0
Hi:B0<G5k`35knl00P2f][H04@1OUel0UiNG0;kC_P00B@00][Jf0<G5a@1cLg<0aNo502`/;01<NF<0
;2`/001OG`2WYjL0Lg=c02`/;00/000001HF0080000000D002`00000;00/000002`003XjD0020000
0080000/00@00000000/00005P00;0000P0000001P0/000000000000000002`001H0000/00800000
00<002`00000000000000`000004000/000C01HF5P00000002`002`0000002`0000002`/;0000000
GiNG05nGG`2WYjL0GlG505mOG`2WYjL09DTU001OG`1OGel0Gel0001OG`0204U9B@05031kG`1OGel0
Gel009NGG`1cLg<00P1OUel0;@16HTH0GemO02`/;01OGel0Lg=c05nGG`00Gel0<68`04U9B@0/;2`0
02`005nGG`1OGel005mO08>OW`2WYjL005mO05nGG`2WYjL0UiNG04U9B@2GaLD0[jn_05mOG`2GUel0
QHF509O5U`1cLg<0GiMO01H/5P3_klD0QHF505mOG`00Gel0BDU908F5Q@2GUel0GemO02`/;00002`0
aLFG000/000/;2`0TZik09NGG`0202`/;00407=cL`19BDT0000007V>N@<0BDU90P0/;2`02`1OGel0
JHF50:NWY`1OUlD0QHF505nGU`1OGel0Lg=c03YYJ@1OGel0GenG008005mO00X0Lg=c05mOG`1bSW80
GlFG05nGU`2WYjL0QHF505nGG`1OUiL0SHf=0P1cLg<04@0/;2`0YjNW05mOG`19BDT0QHF507QhN01O
Uel0;2`/09MOU`1OUel0BDU90:NWY`1YJFT0GenG09NGU`1OGel0QHF50080UlG500/0_;bl0>o_a@2W
YjL0kno_0<G5a@3_onl0][Jf07^^N`2WYjL0aLFG05mOG`08ooooo`001_ooool20000000:04T0000j
>SX0;0000000;0000000;2`/02`00000;0005QH0000/0080;00000D0;2`/000/0000;0009@00000/
000202`/;00:0000;000;000;00001H/5P190000;2`/000/000/0000000/00000080;2`/00/002`0
02`0000/0000000004T00000;000>aHF0000B@3_olD0YjNW000/000202`/;00G071`E035aIL0UemO
0000;00/;2`0;00009NGG`2^[W/0;00002`/;03De=@0;2`/05mOG`2GUel0QHEY05nGG`2f][H0BDU9
0<G_a@35aLD0GemO06?3[P35aLD00P00;0003`2WYjL004T0001OG`1bYHh0BDU9000/0000000002`0
0000000002`001H0000/000/000002`000000002000/000806=SHP000000;000000/00000000;000
0000000F01H2000000090000;000;000000000000000;00001H002`000000000000/00<0000000<0
5QH00000000000000P00;0001@0/;2`0000001H0000/00000000008002`00200000002`00000<4H0
UlG504U9B@1OGel0GiMO05nGU`00G`00E5@U04U9B@1OG`00BDU905mO0000Gel0GemO06V5J@1OUel0
QHF505nGU`19BDT0;2`/05mOG`1ONel0GlFG05mOG`0/;2`0UemO0000;019BDT0Gg]k09NGU`80BDU9
0P0/;2`01P1OGel05R`F0;Jf]P0/;2`0BDU909NGG`80QHF500`002`00:NWTP2WYjL0aLG505nG001O
G`00YjNW09NGG`1`Qg00YjNW0<G5U`25QHD209NGG`0304U9B@1kUg/0UemO0080UemO00/002`002`/
;02GaEl0;2`/04U9B@2GaIL0aNo50>o_a@000000;0000:jBTP020000;080GiMO00@0BDU908F5Q@0`
C4H0Lg=c0P1OUiL20:NWY`0905nGU`1ONg/0GiMO04U9B@1OGel0BDU905mOG`1OUel0JHEY0080GemO
02D0GlFG09NGU`1cLg<0UiNG07^^U`1OUiL0QHF505nGU`2WYjL0GemO02`/;02GaIL0N7Qh07=cL`0/
;2`0UiNG05nGG`0/;2`0UiO5051@D035UlD0Lg=c04U9B@1cLg<0YjNW05mOG`2LW8L0UiNG07=cL`3l
o?`0koo50:NWY`2GUiL0dm>n0?ooa@2f][H0GemO00Sooooo0006ooooo`07000/000/0000;2`/02`F
5P000000000/0000000202`00005000/000F0000;2`/000/000002`00P0/;2`00`00000001H002`/
;003000/0080;2`/00`05QH000000000;000;2`/02`0000002`0000001HF0000;000;2`/000/0019
00020000000O000/000F;1H0BDU905nGU`2GaLD0YjNW0;Jf]P1OGel05QH/02`/;02GUiL0aNo504U9
B@0/;2`002`002`/;035aIL0UiMO07=cL`2WYjL0GiMO04T0002fWil0;2`/002GU`2GaLD0BDU9000/
001OGel0AWUi000/000209O5a@0507=cL`19BDT002`001H05P0/00000P0000001`0/000002`00000
00005P00000/02`00000;0000P0000001000;0005QH0000/000002`200000008000/000000000000
000/00000000;0000000000/000300000003000/00000000000000@0000000<002`002`000000000
0`0000001@0F000002`000000000000002`00080000000X0<4H`0:NWY`1OUiL0GiMO05nGU`1OUel0
BDU9031OG`00Gel0YjNW0P1OGel01P1OUel0GiNG05nGU`1OUel005mO07=cL`80GiMO00/0GemO000F
5P2WYjL0GemO09NGG`0/;2`0klG502`/;01<C4H0UiMO04U9B@0205nGU`0?05mO000002`0QibL02`/
;035klD0BDU905mOG`2GUel0B@000:NWY`16ATH0BDU90000;02GaEl0YjNW0080;2`/00`0LXib09O5
U`1OGel0BDU909NGG`1OG`00UiMO08F5J@2GGel0GemO04U9B@1OUel202`/;00404akC019BDT0;2`/
05mOG`80aNo500@0aLG5081iH`00Gel0GemO0P0/;2`00`00;000;2`/06UYJ@02001O00090019001O
Gel0BDU905nGG`25QHD0GiO505nGU`1OaIL0GiNG0080GiMO00@0JHEY05nGG`1OUel0GiMO0P1OGel0
102GUiL0LW9b09NGU`2GUiL305nGU`0K07=cL`2GUel0C7]k08F5Q@00G`00GemO09O5U`19BDT0UiNG
04I6AP35UlD005mO02`/;025QHD0UlFG05nGG`1aLG40GemO04U9B@3oknl0UemO001OG`0/;2`0cKJf
08F5Q@35aLD0GemO00Sooooo0006ooooo`0402`00000;000;2`/02D05P80;00000T002`00000;00/
000002`002`F5P00;000;00000000000;0000P0/;2`00`0F0000;00002`/;00402`/;00<01HF;000
;000;2`/02`0000/;2`0;00004T000005QH0000002`00000Gel0;2`/0`000000800F5P00;2`/05mO
G`25QHD0UlFG05nGG`1OGel0dkjn0:NWY`2f][H0e=CD0>o_a@2GUel0Lg=c07]kG`1OUel0aLG50=CD
e03_aLD0UlG50<G5U`0k5QH0QHF507=cL`0/;2`0GiMO09O5U`2WYjL0AV9R0000;00/0000B@000P00
02`01@0/00005P0F00000000;000;2`/00<0000000D001H0000/000/0000000/02`0000200000003
000F0000;000;000008002`000@00000000/000F000002`00P0000002@00;000000002`000000000
5QH00000000/000002`002`/;00700000004000/000/00005P00000000<0;0000P0000001@16HV80
Gel005mOG`0/;2`0Lg=c0080GemO00/0JFUY05mO0019BDT005mO05mOG`1OG`00BDU906V5J@00Gel0
GiNG04U9B@0202`/;00I05nGG`16HV80BDU9001O000/;2`0YjNW04U9B@35aLD0>c/k000/00000000
;2`/04U9B@1OUiL0GlFG05nGN`35klD0BDU905mOG`0/;2`0Uel0000/00190000[W]O09NGG`0202`/
;00;05l00025QHD0aLFG000U9@000000YjNW05nGG`2WYjL0;2`/09NGU`1kUg/00`2GUel03019BDT0
GiMO08F5Q@1DE2D002`009O5a@2GUiL0GemO02`/;000;0005S/F001O0080GiMO0P1OGel0101OUel0
Gel004U9B@0/;2`404U9B@0305A`E01OUel0Lg=c0080UiNG00@0YjNW09O5U`1OUiL0GemO0`1OUel0
301OGel0GiNG05mOG`2WYjL0GemO0:NWY`1cLg<0YjNW09NGU`2WYjL0NiNG05nGG`80GemO01D0UlFG
04U9B@2GUel0ATI60<G5a@1OGel0;2`/0:NWY`1OUel0BDU907]kN`19BDT002`00>o5a@1OUel0BDU9
02`/;02PX:0002`009NGU`1OGel02?ooool000Kooooo00D0;00002`/;000000001HF00000003000/
00070000000/000001H004T000000000B@00000/000202`/;00301HF000002`002`000@0;2`/03D0
01HF0000000/;2`00000000/00190000;00002DF0019000002`00000;00/;2`002`00000000/0000
02`002`000190000000/02`0001cLg<0YjNW03YYQ@3De=@0kno50?o_a@3QhN40ono_0>o_a@2OWh<0
UlG50;Jf]P2GUel0GemO001OG`1OUel0Njj^05mOG`0/;2`0000/000/000002`0000001HF5P000000
000/02`000000000;2`/000000005P0002`000000002000/000402`0000002`00000000000<002`0
00<0;000000/000000000`0000001000;00000000000;00001H2000/00030000000/000000000080
00000P0/00000`0/;2`0;0000000000200000003000F0000000002`000@0000000<001H002`00000
00000P0/00004`00;000;00004a`C000Gel0GemO05nGG`1OUiL009MO05mOG`1DL5@0GiNG08F5Q@2G
UiL0GiNG08F5Q@1OUel0SXib02`/;01OGel00P2GUiL08P0/;2`002`003YN>P19BDT0GiNG02`0001O
G`00aNo5001OG`1k[W/0;0000:NWY`0002`005mO02`/;000;000RjN;02`/;01OGel002`004U9B@1O
Gel0GiMO000/000`AP00BDU908F5Q@2GUel0aIMO09NGG`00;000Ph>305mOG`0/;2`209O5G`0=09NG
U`2GaIL0W9b509NGG`2GaIL0Lg=c02`/;01OUiL0YjNW05mOG`2f][H0;2`/05nGG`03001OG`80GiMO
00L0QHF505nGG`2GaEl0BDU905mOG`1DE5@0GiMO00<0BDU900l0;2`/0000000k>c/0Lg=c05mOG`1O
Uel0GemO07=cL`1OGel0GiMk09O5U`2f][H0GiNG0;Jf]P1OGel00P1OUel0801cLg<005mO07=cL`1O
Uel0BDU908F5Q@1OUel0SXj>0:NWY`2GUel0UlFG09NGU`1cLg<0YjNW05n^N`2f][H0Lg=c02`/;02W
YjL0Lg=c001OG`1lO7`0BDU9000/0035aLD0GemO000/0019BDT0bjNB0000002f][H0GemO2?ooool0
00Kooooo00@0000/000/0000000001HF0P0000001`0/0000;2`/000/000002`001HF0000000/0000
0P00;0020000;00402D0000/0000000/04T000<0;2`/00@0>aHF0000000/0000;2`/0P0002`00`00
;0005R`F02`/;00302`/;005000/000/000002`002`F5P0002`00`00;0000`0/;2`002`005UIF@02
0000;00502`0000002`0B@000<G5a@2>YJD00P2GUiL02@25QHD0BDU90000;00/00000000000/0000
02`002`002`000020000000702`F5P000000000/0000000/0000000002`/;0020000000702`00000
02`0000000000000;0005QH00000000202`000040000000002`0000001HF0080000000<0;0000000
0000;0000P0000002`00;000000000000000;0000000000/0000000001HF000/0000000002`000@0
000000@0;00000000000000002`00P0000001@0/5QH00000000000000000;0000080000000@0NjjB
05mOG`2GUel0GemO0P1OUiL01P1OGel0NiNG05o5U`25QHD0BDU9000/0080BDU900T0NiNG05nGU`1O
UiL0UlFG05mOG`2f][H0GlEO031D002GaIL00P1OUiL0900/;2`0UiMO001OG`2GTW/0UiNG0;Jf]P0/
;2`0e=CD000/001OUel0E5AD000/0000B@00;2`/0019002GUel0aLEO09NGG`0`AS00000004T0000/
;2`0UiNG00190000Gel0SXib0:NWY`35klD0BDU902`/;035aIL0;00008^WR`2f][H0aLFG09NGU`80
UlFG00@0;2`/08f=S@3_knl0;2`/0P00Gel01@1OGiL0UiNG05mOG`1cLg<005mO00<0GemO00H0BDU9
05nGG`1OGel005mO05mOG`00Uel204U9B@0402EDE00/;2`002`004U9B@80GemO01`0;2`/05iNGP1c
Lg<0BDU908F5Q@2GaIL0][Jf05o5U`1ONg/0GemO05nGG`1OGel0QHF5001OG`2WYjL0GemO07:>LP1O
Gel0aLFG07=cL`25QHD0UlFG09NGG`23Wil0aLG508F5Q@1OGel0UiO50P1OUel02`2GUg/0;2`/02`/
;03_klD0GemO02`00019BDT0TZik000/003_aLD0BDU900Sooooo0006ooooo`0500005P005P00;1HF
01H;000001H00P0F00004`0/;2`05QH001HF;00Q2`005R`F01HF00005P00;00001HF;00/5QH02b40
000F000000009AH001HF000F5R`05R`F01hF5P0U00000P0F;1H201HF5P0=000/000/8B405R`F02D0
5P0F5R`0;2`/01H/5P0/;2`0000001<;000F01H09@0F01HF;00201H/5P0602`F5P0;2aH0000F0000
;00F;1H05QH/0P0001H0500;2`/002`0000/000002`05QH001HF5P005QH02`/;0000000F0000;000
000F5P0F5P0001H0000;2`0F;1H05P00000F000F5QH0000010005P001`00000001H0000/000F01H0
2`0;00005P0F5P000P0F000010005P00000F000;2`0F5QH200005P06000F0000000001H000/00000
00005QHF0P0F0000200F5P00000F01H/5P0F00/001H001H05P0F000001H00P0F0000100F2`000000
000000005P030000000@000;0000;000000F000F000F5P0001HF02DU9@1AQGL0Gg/`05mkG`1OGel0
NjjB07:>LP1kUiL0AEi501HF5P8001H003405P0000005P0F00002b4;04H`<00`C680E8M`09nOW`2G
[Y80LXj>07fDU02_[jl0JFV5069RAP1`QhL05V9607^BTP1^Pf80;2`/06>BTP1<Hf<0Rh^;075aL@35
aIL0F68`07]<<019BDT0HV9R09NGG`1OGc00E5@U02DU>`1CAcT0Nel`069RAP0/;2`0Ug]O08F5J@1R
NF80JFUK04a<AP2^`jh0NGUi0;jnY`00<5@0UiMO03Ti>@0F5TH0<71<0080AV9R00@0C70`08>OW`1<
LG40E5A`0P1DE5@01@1ONel0JHF506UYJ@1OKEl0GiMO0080Gg]O03T0GemO05ADE01DE5@0B5mO06UY
J@0UE5@0JFUY04U9B@1ONel0E5AD05YXFP1ONel09EAD031O<00k>c/09EAD02ED9@0gCcL0<5l`079b
LP19BDT0E71D03/k>`1WIfL0KG]]07^GU`20P800NiMk07^^N`1kTT`0QIb507^^N`1JPFP0AV9605A`
E01bSW80GiMO08>OP`1YQFT0S8b<06V5Q@2BNiL0RkjW09:^U`2O][H0QK6L096[W`1ONc00QhN70=[5
a@1YJFT002`009bLW01]UEH0;2`/0>oJa@1OGel02?ooool000Kooooo00P0000002`0000/00000000
02`/;00/0000;2`/000/00D0000001L0;2`/02`0000002`0;00001H00000;000;2`/000/00000000
000/0000000F5P00;2`/0000000/;2`002`00000000/000001HF0000000/0000000/000/000302`/
;00401H0000/0000;2`/04U9B@80;2`/00H0;00000005P000000000/02`/;000;0020000000301H0
00000000;0000080000000`0;000000/0000;000;0000000000/;2`0000/000/000000005P00000/
0000000202`00080000000P001H00000;000000002`000000000;000000/01HF5P<0000000T0;000
00000000;000000F02`00000000002`002`/;000;0000P000000200002`002`000000000;000000/
000/00000000000F0`0000001@00;000000002`/;0000000BDU9008002`00P0000004@00;0005P00
0000;0000000000/000/0000000009MO03YYJ@1OUel0Lg=c0:NWY`1OUiL0UiNG000/000001H0000/
0080000000@0000/000/000000005P000P0000007@0/0000000002`/;02WYjL0NiNG05mOG`2GUiL0
02`004U9B@2f][H0QHF505n^N`0/0000e=CD000/0035aLD002`00=CDe00U>bD0;2`/04U9B@1OUel0
04T0000/000/0000GiMO030`<00/;2`0GemO00<0UiMO00/0;2`/05l`<01OGel0GemO02`00035aLD0
;2`/0;Jf]P0FATH005mO07=cL`0205nGG`04001OG`1OGel0<7]k05nGU`80GemO00d0GiNG05nGG`00
GiL0JHF505nGG`1cLg<0GiMO05mOG`00Gel0GemO06V5J@1OGel0BDU900<0GemO00@0GiMO031OG`1O
Gel0GiMO0`1OGel0:@19BDT0GemO04U9B@19BDT0;2`/04U9B@1OGel0;2`/05iNGP0/;2`005mO04U9
B@25QHD0GemO09NGU`2WYjL0UmZ^05o5U`00B@00UiNG07=cL`1OGel0Lg=c031OG`1OUiL0GemO07=c
L`2GaIL005mO0<G5U`2UYJD0UlG50<G_a@3oknl0UlFG05nGa@3QhN40TZik05nGU`35klD0GemO00So
oooo0006ooooo`80000000D0;00002`/;00/0000;00004T00003000/000601H05P000000;0000;Jf
]P00;000B@000P0002`01`0/0000;2`/000/000/0000000/000/000F5P000`00;0020000000702`0
00005P00000/04U9B@00;000;00004U9B@020000000501H05P00;000001905mOG`00;0000P0002`0
1@0001H0000000000000;000000/0080000001d0000F02`/;000;000000002`0000002`0;2`/051@
D000;000000/000/0000000002`00000;00F5QH002`000000000;0000000000/0000000001H00000
000/;2`00000000/0000000002`001H05P02000/00<0000000D002`001H05P0002`000000000;002
0000000602`000000000;0000000000/;2`0;0000`0000000`005P00000002`/;002000/00030000
000/;2`05P000080000/00D002`00000000/;2`00000000F0003000/000900000000Gel0GiMO05nG
G`1OUiL0YjNW05nGU`19BDT002`00080000000@002`0000000000000;0000P000000200001H002`0
000/0000000002`002`0000/;2`0PinO0P00Gel03`2GaLD004T00<G5U`0/;2`0PinO05o5a@2GaIL0
;2`/05mOG`00;000B@0002Dk9@00B@00Gel005nGG`0209NGG`0<05nGG`2GUel0NiMO02`/;019BDT0
aIMO0019002GGel0;00003/k>`00;000UlFG0P2f][H02`0/;2`0][Jf05mkC01OUiL0Lg=c05mOG`1c
Lg<0GemO07=cL`1OUg/0GemO00<0GiNG00L005mO05mOG`1ONg/0GiMO05mOG`1cLg<0GiMO0080GemO
00D0<7]O05nGU`1OUiL0Lg=c001OG`0205mOG`0906V5J@1OUel0BDU905mOG`1OUel0Gel005mOG`1D
L5@0BDU90080GemO0P19BDT02P00Gel09EAD04U9B@1OGel0BDU9001OG`19BDT0Lg=c04U9B@1ONel4
09O5U`0704U9B@2WYjL0<5@`08F5Q@1cLg<004T009NGU`0207=cL`0;05mkG`2f][H0YjNW0:NWY`3_
klD0][Jf09O5U`2Wf/D0][Jf0<G5a@1OGel02?ooool000Kooooo00@0000/02`0000002`001HF0P00
;0001P0/00000000000/00000000;1HF0000;0<0;00000<0000/02`000005P000P00;0040000000:
01H/5P0/;2`0;2`/0000;0000000;000000000005P0002`005mOG`80000/00<002`002`0000002`0
0P0/;2`01P0/000002`0000/000002`002`0000F5P8002`000P00000000/000002`0000001HF0000
02`000000000;080000000D002`0000000000000000002`000020000;00302`0000`<300;0000080
000000<0;0000000000000000`0000001`00;000000000000000000001H00000;00/00000P000000
1@0/;2`0000000005P00;0000000008002`000@0;0000000000F5P0000000`00;003000000090000
5P0000000000000/00000000000/000/000F000002`00080000000<0;0000000000002`01@000002
05nGG`0507^^[P1OUiL0GiNG04U9B@0002`00P0000000`0F01H0000002`/;002000/0080000003D0
000F0000;00/0000;000000/000/0000000/069<C02GUiL0GiNG05mOG`2GaIL0aLG502`/;01DL700
GiNG05o5a@35aLD0;2`/05mOG`000000Gel`05mOG`0/;2`0GemO04T0001OUel002`00000001RC300
aLEO02`000190000GemO02`0002GUel0HgT`000/002GaIL0;2`/0<G5U`35aLD0][Jf07:>SP2GUiL0
QHF507=cL`25QHD0Lg=c05nGG`1OGel005mO05mOG`0205nGU`0307=cL`1OUiL0<5mO00D0GemO00T0
Lg=c03YYJ@1OGel0GemO002GG`1OGel0Lg=c001OG`1DE5@00P1OGel01`00Gel0BDU905mOG`00Gel0
<5mO07=cL`1OGel00P00Gel00`1OUel0BDU9001OG`02001OG`0N05mOG`00Gel005mO02`/;01OGel0
GUiN04U9B@2WYjL0UiNG0:NWY`2GaLD0aNo505A`L019BDT0GenG04U9B@1OUel0GiNG04U9B@1RHV80
Lg=c05nGG`0/;2`0UlG50:NWY`0/;2`0aLFG05nGG`1OGiL005mO2?ooool000Kooooo00L0000002`/
;00/000001HF000/00000000;00000<002`000<05QH002`0000002`00P00;0000`0/000002`0000F
5P020000000602`/;000;000;00004T0000U01H0000/0`0000002`0/;2`002`003/00000;000;2`/
0000;000;000;2`/02`000000000;1HF0080;2`/0P00;0002P0/;2`0;000000F00000000000/02`0
000/;2`0000002`/;00F5P0202`0000500000000;000;0000000000F01H00P0/00001`00000002`0
02`0000000005QH00000000/00000P000000200/;2`0;000000F0000;000000002`00000000002`0
0`000002000/00070000;0000000;00001H05P00;00000000000;0020000000=02`0000F5P00000/
0000000/;2`00000000/0000000002`000005P00;000000/000/00020000000402`/;00000000000
000/00<0000000`0;0000000000002`002`00000001OG`00UiNG05nGU`23Wil0UiNG02`/;00002`2
000/000I02`00000000002`002`00000;0000000000/00000000000F02`00000000002`000000000
02`0;000000F00000000][Jf0:NWY`1cLg<0UlG50;Jf]P1ZJVX0;2`/0:NWY`0205nGG`0I0<FGG`00
;000<31D04U9B@1OG`00B@0002`/;01OG`00BDU904T0001RHd`002`005mO0000Gel0UemO00190019
BDT0QHEY02`/;02GUel0;2`/0<G5G`0/;2`0QHF507RBH`0305nGU`0=07=cL`1OUel0UiNG05mkG`1O
GiL0GiMO05nGU`1cLg<0GiNG001OU`1YQFT0GemO07=cL`0405mOG`0906UYJ@1cLg<0GemO07=cL`00
Gel0GemO07=cL`1YQHD005mO00H0GemO00<005mO05nGG`1OUel00P1OGel01@1OUel0Gg]O001OG`0/
;2`005mO0080;2`/00<0BDU905nGU`165QH00P19BDT01@1cLg<0GemO0:NWY`00Gel0[/F^0080UlG5
00l0GemO001OU`2WYjL0Lg=c05mOG`0/;2`0QHF502`/;01OGiL0aLFG02`/;01KRh/0Gel002`/;019
BDT02?ooool000Kooooo00L0;2`/000/0000;00001HF0000000/0000;2`/00@000000P0/00001P00
0000;00002`/;00/00005R`F04T0008002`000L0;2`/000/000002`05QH/000000190000000/0080
;2`/00@002`0000F5P00;000;2`/100002`02P0/000001HF000000000000;2`/000/0000000002`0
0000000/00020000000402`/;00/00000000000F5P80;0000100000002`0000002`00000000F0000
0000;000000/000/0000000/0000000001H0000002`000000000;2`/0P0000000`0F5QH000000000
000300000005000/00005P0002`002`/;000;0000P0000000`0002`000000000000302`00004000/
000002`00000000/00D0000000<002`00000000002`00P0/00001`00;000000/000/00000000;000
0000000/00000`0000001@005P00000002`00000000005mO0080GiNG00<0UlG502`/;00000000P00
00001@0/0000000001HF5P000000000/0080000000<0000/000000005P000P0000004`0/;2`0;000
0000000000005P0F0000000/0000QHF505nGG`00G`00GemO0<G_a@0/;2`0][Jf02`/;03_knl0UlFG
02`/;01DE5@00P19BDT09@1OUel0BDU902`0001OGel0G`0004I65P1OGel0000002`/;02GUel005l0
02`/;01<HS00UiMO05nGU`00Gel0UlEO0019002GGel0NGUi0:NWY`1OUel0GemO07=cL`1OUel0GemO
06V5Q@1OUiL0GemO05nGG`1OGiL0GemO07=cL`0`Gg/0GiMO05nGU`1OUel00P1OGel01000GiL0JFUY
001OG`1OUel405mOG`0306UYJ@25QHD0Lg=c0080GemO00X0BDU9001OG`1DE5@0BDU905mOG`19BDT0
05mO002GG`1OGel0Gg]O0P1OUiL0200/;2`005mO001OG`1cLg<0;2`/01HFAP1OUel0GemO0`19BDT0
4`1OUel0E5AD05o5U`1cLg<0UlG_09O5a@35aNl0Uno505nBN`0/;2`0QHF504U9B@0/;2`0QHF5001c
001iNF80Gel00000;000Gel02?ooool000Kooooo00P0;2`/0000000/0000000/02`0000002`0;2`/
0000;080000000D001H00000000002`0;0000000;002000/0006000F5P0002`0;2`/02`/;000;000
B@001000;00302`/;00:0000000F01H0;2`/02`/;000;00000000000;00/;2`0;00001H00080;000
00h002`00000000/;2`0000/01HF000/;2`0;00002`/;0000000000/0000000F5QH0;0000000;080
000000<0;2`/0000;00F00000P0/;2`01`0/000000000000;00/000001H005nGa@0002`00`000000
0`00;000000002`000020000;00902`000000000;000000F5P000000;0000000;000000002`00080
000000<002`00000;000;0000P00;0003P0000005P0F000/000/000002`00000;0000000;0000000
000001H0;000000/000002`0;2`/0P0000004P00;000000/000/0000;000;000000/000002`001H0
02`0000002`0GemO05o5U`1OUiL0UlG_07UiN@0002`0000002`/;0@0000000<0000/000000000000
0P0000000`00;0005P00000000020000000D000/00000000000/000F0000;000UemO0000;00/;2`0
aLG509NGG`2WYjL004T00<G_k`0/;2`0aEmO05mOG`19BDT0Gel`04U9B@00B@0304U9B@80Gel001<0
Ng]O000/002GUel0;2`/09NGU`19BDT0;2`/03/k>`000000;2`/09NGG`35aIL0;2`/09NGG`2LN6<0
GiNG05o5a@2WYjL0GiNG0080GemO00D0Gg]k05nGU`2GUiL0GemO07=cL`0205mOG`0<031OG`1OGel0
GenG05nGG`1OGel0GiNG05nGG`1OGel0GenG07=cL`1OGel005mO0P1OGel02@1ONg/0BDU905nGU`1O
GiL0GiMO001OU`1OGel005mO05mOG`0204U9B@0405mOG`00Gel0GemO06UYJ@80GemO0P1OUiL01`00
Gel0GemO04U9B@1OGel0;2`/0000B@1900000P1OGel204U9B@0A07=cL`19BDT0BDU90:NWY`00B@00
Lg=c0<GJfP1OUlD0UiNG05o5U`00B@00YjNW05mOG`23E8<0Lg=c0000;01OGel02?ooool000Kooooo
00d05QH002`/;000;0005P/;000/000000005P0000005P0F5P00;00000/F000F0000000F00805QH/
00H05P0003Xj>P10@5T05QH/01H/5P0F5QH401H/5P0401HF00005QH0000/02`F5P805QH/00<02`/;
02`F5P0F5P000`005P00<@0/;2`0000/00005P0/;2`0000F0000000F0000000002`000005QH05P00
02`0000F01H0;1HF01HF0000;0002b`;01H05P005QH05QH001H/5P0001H0000001H05P0001H05QHF
000/000F5R`05P0001HF000S?2<05QH0000/000001H05QHF01HF000F5QH05QH0000F5P0001H0;000
01H/5P0F5P00000/01dF2`16<4`0C31603/U9@0/;2`00P005P004`0;00/05P0F0000000F5P0001H0
000000005P002`/;00005P00;0005QH0000/000F01H05P00000F000;5P00000F02`000005QH00P0F
000060005QH02`/00000000F5P00000F02`000005QH05P0F000F000000009BDk07:>SP2^[/<0_[kC
05]KF`005P0001HF00005P0000005P00000F000000002aH;000F5P80000004`05QHF000/00009AH0
000;01H0000001H05P00000F000000005QH0000000005P0001HF0000;0005P00;2`/05]KF`1<Hf<0
UiMk069iN@1<NF<0UemO000U5P0k>c/0<30`05mkG`0j>Uh05S/F05mO<01N>SX0HV9603YN>P1DE4H0
LXib069RHP1DE2D0;1HF05ADE000;000J7I202`/;01k[YL05R`F08>3P`1hE5@0]/^f09^CS01kNg/0
][Jf07^^a@2GaLD0PkJf08jUY@1OQhL0<7]k05mOG`1YJHD0LXj>05mkU`1bSXh0I820031OG`1YJFT0
Gemk06V5J@1YJFT0Gg]O04eTI01ONel0JFUY05mkN`1OGel0<5mk03YYJ@1TI6@0Gg]k0P0`Gel06P1Y
QHD0JFUY05mkG`0eLV@0<5mO05ADE01YQHD09EAD01Hk5P1OGel0:UYJ031OG`1YJFT0<5mO05mON`1O
Uel0GemO05mkN`17KEl0JHF505mOC00`C700C4aD05ADE00k>c/0B4Q80P0k>c/03`19BDT0GemO06UY
J@19BDT0=FAT0727Q`2^`jh0Ni9k0:NnR`2G[/<0T/>^07fDWP2BaL<0Ni:B02EDE008ooooo`001_oo
ool01@00;000000/02`/;00F;1H0B@0000<0;00000/0B@00000/00005P000000000/00000000000/
02`0000000005QHF000/000202`/;08002`000T0;2`/000/000/;2`002`002`/;01OGiL0;2`/000/
000U5P000P0/;2`02P0/0000000002`0000002`0000001HF5P0/;2`0000/02`0000002`202`00003
01H/5P00;00002`000<0;2`/00d002`0000F000002`0;00002`/;000;000000/02`0000F5P0002`0
02`0000/;2`0;000008002`000`0E5AZ000/00000000000002`0000002`0;00001HF0000;0000000
02`0000/;2`2000/000<03X0001OGiL0UiO50:NWY`25QHD0aING09MOG`0U9C/002`002`/;0000000
02`00P0/00001000;0000000000/000002`20000000>000/000000005QH00000000/000002`00000
;0000000000/000F000/000002`00000000002`202`0000<000F00000000QHF509O5a@1OUiL0BDU9
000/00005QH002`002`00000;00000000P0/00002@0F000002`005nGG`0/;2`0Uel005mO001OGel0
C4a<000/00090000000Y000/000002`0000004=3@`2GUiL0BDU90000;03_olD0Lg=c05nGG`0`Gc00
BDU905mOG`2GaEl005mO05nGG`1OGel0UiNG04IRAP19BDT0001907=cL`2GUel0000/02`/;000>`00
aLG509NGU`0/;2`0e=CD000/000/;2`0HV9602`/;02GUel0YjNW09O5a@2WYjL0GiNG07^^[P1OUiL0
0P1cLg<0301OGiL0Lg=c05mOG`1OUg/0GemO05nGU`1OUel005mO05mOG`19BDT0<5mO07=cL`80GiMO
00D0Lg=c001OG`1OUiL0GemO001OG`0305mOG`07001OG`1OGel0<5mO07=cL`00Gel0QHF5001OG`02
05mOG`0502EDE01OGel0;2`/04U9B@1cLg<00`1OGel00`1YQFT0QHF507=cL`0205mOG`0505nGG`2G
UlD09EAD04U9B@00Gel0100/;2`02`1ONel0GemO04U9B@1OUel0BDU909MOG`1OGel0Ujj^05nGU`2G
UiL0GemO00Sooooo0006ooooo`80;00000D0000/01H/5P0/;2`0B@0002`/;003000/0004000F0000
0000000002`00080;2`/00D0;00001HF5P0/;2`0;2`/02`00003000/000401H05P00;00002`002`/
;080000/00<0;2`/01HF5P0/;2`0100002`202`/;00E01H/5P00;000000/0000000002`0;2`/0000
;00/5QH0000002`0000002`002`002`/;00002`002`002`/;0000000;2`/000/000/0000000/00<0
02`000P0;000000/000002`0000001H/5P00;000000/000/0080000000/002`001H05P0/;2`0;000
0000;000;000000002`0001I0000UiO509MOU`0209NGa@070:NWY`2GGlD0Ug_509MOU`1cLg<0;2`/
02`00004000/000902`000000000000/00000000;000000/00005P0/0000000/00<0000000@002`0
000F000/0000000/100000003000;000GiMO08F5Q@2f][H0UemO02`0000000005P000000000/0000
000002`00080000000T05QHF09NG001OG`00B@0005mO002WYjL0aING03XF0000;0000`0/00000`00
;000000/00005P020000000d0000;000000000000000000F;1H0GemO09O5U`1OUel000000?o5a@1c
Lg<0E5@U02`/;01OG`00GemO05nGG`0/;2`0GiMO05mOG`1IFET0BDU909MOG`0/;2`0UiMO05mO002G
Gel0HV9R0000002GaLD0GiMO0<G5U`0002`0UiNG01HF000002`0000002`/;01OUiL0YjNW08F5Q@2>
SXh0GenG05nGU`2GUiL0GiNG05nGG`1OGel0Gemk05mOG`1OUel0GemO05nGG`80Lg=c00T0<5mO05mO
G`19BDT0GemO001OG`1OGel0GiMO07=cL`00Gel00P1OGel204U9B@0;05mOG`16ATH0BDU904U9B@1c
Lg<0QHF504U9B@00Uel0E71D001OG`19BDT00P1OGel04`0/;2`0BDU905mOG`1<Ng/0GemO09NGG`25
QHD0GemO08F5Q@1OUel0NjjG05nGU`1OGel004T004T00000Gel0BDU905mOG`0004T00P1OGel01@0/
;2`0BDU904U9B@1NGUh0;2`/0080GemO2?ooool000Kooooo01T0000/02`0000/0000D51@02`/;000
02`0B@000000;00/;2`002`0000F5P00;000000/02`/;000;000000002`000005P00;0000000;000
0000;2`/000/000/;2`05QHF00<0;2`/00T0000/0000000/00005QHF0000;00/0000;2`/0000;000
;0000P0/;2`01`0F5QH002`0000/000/000002`00000;00/;2`00P00;000200/0000000/02`/;019
0000000/03/0000002`0;0000P0/;2`202`00003000/000/;2`0000/0080000000H0;2`/000/000F
0000;0000000000002`200000003000/000F000000000080000000D0000/000/0000;000Hc000<EO
U`020:NWY`80UiO500@0YjNW09nO]P2GUlD0UiO50P2WYjL0402GUiL0Lg=c01H/5P0/0000000/0000
000/0000000002`0000000005R`F0000;0000000000/0000000/;2`30000000902`00000;000;000
0000;00000005S0`09NGU`35aLD0UiNG0080000000D0;000000F000/0000000002`00002000/000<
02`0000F5P00aING0<G5a@0002`0aEl009MOG`1c00005QH/000/000/000002`00P0000000`0/0000
01HF02`000030000000<000/000000005R`F00000019BDT0aLG504U9B@35aIL0GemO05mk<025QHD0
05mO0`1OUel01P00B@00UiMO05nGG`19BDT0;2`/0<G5G`80;2`/01`0BDU905ADE019BDT0aLG502`/
;03De=@005mO0<G_a@005QH0000/000/000002`0000004U9B@1OaIL0UYJF08F5Q@1OUel0GemO08F5
Q@2GUiL0QHF5031kN`1OUel0GemO05nGG`1OGel0GiMO0P1OGel205nGG`<005mO00D0GemO05mON`1O
UiL005mO07=cL`0305mOG`0804I6AP19BDT0;2`/001OG`1OGel0BDU905nGG`1YQHD205nGU`0N001O
G`00;00004T005nGG`19BDT0GemO001OG`1OUiL0BDU9000/0000Gel0UiMO05ADE019BDT0GemO001O
G`1OGiL0BDU90019000UBBD0GiMO001OG`19BDT0;2`/001OG`1OUel0;2`/08F5Q@19BDT0GemO2?oo
ool000Kooooo0P0000000`00;0005QH/02`/;002000/0080000000H0B@0001HF;000;000;2`/0000
;00/00020000;00302DF000002`002`000<0000000<0;2`/01H/5P0/;2`00P0/;2`02@19000002`0
02`0000k0000;2`/000/000002`0;00002`/;002000/008000001@00;0000`0F5R`0000000000002
02`/;006000/000/;2`0;2`/02`/;000;00000000`00;0000`0F;1H002`002`/;003000/000502`0
000F5P00;000000/000/00000P0000000`0/0000000F000/000300000004000/00000000HQI609NG
a@80UiNG00@0Ueo509NGa@2GUlD0Winf102GUlD01@35UlD0UiO509NG[P2GUiL0Gel000<0;00000<0
0000000/00005P000P0/00020000008002`001/05P000000000002`0000/02`00000;000000004ai
C02GaLD0GiNG04U9B@00;000000/000/00005QH0000/000/000/0000000/00000000;000`i9k0<EO
0035Uel0G`0008D00035G`001@0000001P0/000002`00000000F000002`00000;080000000h0000/
00000000;000000002`/;019BDT0aNo50:NWY`1OG`00ATI60000;01OUel0BDU905mOG`80UiMO00X0
02`0069RAP2GUel0YjNW02`/;000B@00YjNW0000001IFET0][Jf0P0/;2`01P35aLD0YjNW0=CDe000
0000;00000000080;0000P0002`00`1ONg/0UlG505nGU`0207=cL`0305nGU`1OUel0NiMk00<0GiMO
00D0GemO001OG`1OGel0JHEY07=cL`0505mOG`0;06UYJ@1OGel0GenG05nGU`1OGel0BDU905mOG`0`
Gel0;2`/001OG`1OGel00P0/;2`01@19BDT0<5mO09NGU`25QHD0GenG0080GiNG01<0GemO001OG`1D
E5@0Lg=c05mOG`0/;2`0BDU909NGG`1OGel0>c/k07=cL`1OUiL0GemO001OU`1OGel005mO02EDL019
BDT005l00080BDU900H0GemO04U9B@1DE5@005mO04T0001OGel8ooooo`001_ooool04@19000002`0
02`/;00k5QH0;000000/000/0000000002`0000002`05P0002`00000;000;2`/04T000000000;000
0080000/00@0000002`000000000;0000P0/;2`00`0/000002`002`00002000/00030000;000;000
0000008002`000D0;2`/000/00000000000001H00003000000<002`000`001H00000;00/00000000
000/000/;2`0000/02`000000000;00002`/;000;00302`00080000/00L0000002`0000/00000000
01H00000000002`00080000000<0;2`/0000;00F01H00P00;0001P000000000/000/00000000C4ai
0;H00080YjNW00H0UiNG09NGa@2GUlD0Winf09NGa@2GaLD409NGa@0I09Mka@2GUlD0aEmO09NGG`2G
UiL0BDU902`/;000;000000/0000000002`00000000/000002`0;000000/000/000002`00000;000
;000;000000/001O[W/0UlG509O5U`02000/000H0000000002`05QHF000/000/0000000005mOG`3_
aIL0aIMO0<EO0000;000;2`/04T0002GG`00000/000000005P00000002`00000;0000000000/0000
0000000F0P0000001000;000;00000000000;002000000070000;0000000;2`/0<G_a@35aEl0LW93
001O000205mOG`06000/000/;2`0;2`/09NGG`0F5S/0;2`/0P2GUel03@1OGel0;2`/04U9B@2WYh/0
UemO000/002GUiL0UemO0000002f][H05P000000;00/00000P00;0001P0/0000000/02`/;01OGiL0
YjNW09O5a@80Lg=c00H0GemO06V5J@2GUiL0Lg=c05nGU`00Uel207=cL`0407]OG`00Gel0GiMO05mO
G`80Lg=c0P1OGel00`1OUiL0GemO001OG`0208F5Q@0905nGU`1ONel0BDU9001OG`1OGel0;2`/001O
G`19BDT05TI60080GemO00L0UiNG07=cL`1OGel0GiNG0<G5U`1k[YL0GiMO0080BDU90P1OGel00`0/
;2`05TI605nGU`0204U9B@07002Ga@1OUiL0Gel006UYJ@1OGel0GenG09NGG`0302`/;00401I6AP19
BDT0GemO05mOG`Sooooo0006ooooo`060000;00/;2`0B@0002`0000002`002`00P0002`01000;000
000001HF5P0002`202`/;0040000;00/0000B@000000;08000000P00;0002P0/;2`0;00002`00000
;000;0000000;000;0000000000/001<<3070000000<01HF0000;000;000000/00000000;2`/0000
000F000002`00000;0000000;0000P00;0002`0F01H00000000000000000;2`/04T0000002`09AH0
000/000/;2`002`00080000/00D0;00000005P00000002`00000;00202`0000B0000;00/;2`002`0
00000000;0000000000/000/;2`0Gi9S0<EO002GGiL0YjNW0<FGa@2GUlD0UenG0:iOU`2GUlD0YjNW
102GUlD01P1kNjh0UiO509NGU`2GGiL0UiNG09NGa@80YjNW00@0HTI6000/0000;00002`00`000000
300F000002`0000/000/00000000000/0000G`00Njk305nGU`0/;2`0000002`/;080000000X05P00
02`/;02GUiL0aING0<EOG`35Uel0B@00000F5P00;000;0001@0000000`0002`00000000000050000
0006000/000000000000000/000002`002`0100000001`0/;2`0hN7Q09nOP`2GUiL0QHF505nGU`1O
Uel00P1OG`00302GUel0QHEY04T00000B@00UiMO02`/;01OGel0UiMO01H/5P2GaIL0GemO09NGG`80
02`000T0QHF504a<<00/000002`005mOG`0/00000000000/000001H00P0/;2`00`1OUiL0YjNW0:NW
Y`0205nGG`0405mOU`1cLg<0GiMO05mOG`80GiMO0P1cLg<01`1OUel0Lg=c08F5Q@00Gel0GiNG06UY
J@19BDT00P1OGel05@1cLg<005mO07=cL`1OUg/005mO05nGG`1OGel0BDU905nGG`19BDT0<5mO02`/
;019BDT005mO04U9B@0005l0GemO04U9B@2f]Yl0][Jf05nGG`0205o5U`0D05mOG`0/;2`0LW9b05mO
G`0/;2`005mO05nGG`1OGel0Gel007^^TP19BDT0GiNG002GG`19BDT0GemO05nGU`19BDT0;00004U9
B@1OGel8ooooo`001_ooool03@19000002`00000;00F;1H0;2`/000/00190000000/000/000002`0
5R`F000/000/00000P0/;2`20000;00801HF;00/0000;00002`/;00/0000;2`/0000;00F5P0302`/
;0040000;000;00002`003/F5P80;2`/00@002`004T0000002`0;0000P00;0000`000000000/0000
0002000/000602`0000F01H002`002`/;00/0000B@000P00;0001@0001H0000000000000;000;000
008002`000X001HF000/0000;000000/02`00019000002`001HF0000;000000/0P0/00000`0002`0
;2`/01HF000302`0000402`/;000;000000008L`<0<0UiO500H0aEnG0:NWY`35GlD0Winf09NGa@2W
YjL209NGU`0709MOa@2GUlD0]X>O09NGG`35GlD0UenG05nGa@0209MOa@060:NWY`2GUlD0YjNW09MO
G`00;000000/0P0/00009`1DE5@0UiMO0019000/0000000/02`/;02WYjL0WinO0<FGG`0002`00000
02`00000000002`0099kN`35Uel0aEl00<G5U`0002`0;0000000;00/5QH002`00000000002`00000
02`/;000000001HF02`0000002`000000000;000;0000000000F00000000000/000/00030000000<
01H05P000000000000000000;000000002`/;02LW8L0BDU909O5U`2GUel004T00`2GUel02`1kNel0
BDU909NGU`1OGel0Lg=c0<G5U`0002`0HWUR000/000/0000000/008002`000@0ono_01HF5P00;000
;2`/0P0000001`0/0000;2`/00005P00;000000/000/001900000P1OUiL01`23Wh<0GemO05mOG`1O
Gel0GiMO05nGU`1OUel0101OGel01`1cLg<0GiMO05mOG`0`Gel0GemO001OG`1OGel00P19BDT03P1O
Uel0E71`05nGU`25QHD0GemO001OG`1OGel002`005mOG`0/;2`0GemO04U9B@00Gel0Lg=c0P19BDT0
6@1NGUh0QHF50;Jf]P2WYjL0][Jf05mOG`1cLg<0<7]k02`/;019BDT0Lg=c04U9B@0/;2`0BDU904IR
AP19BDT0GlG_0<G5G`19BDT0;2`/05o5U`1OUel0GiNG0:NWY`00Gel02?ooool000Kooooo00@05QH0
02DF000/5QH0;24Q0P0/;2`01`005QH0;1HF01HF000k5QH02aHQ01H/5P0/;2`00P0F;1H01P0/;2`0
01HF024Q;00/;2`05P0F01HF00805R`F00X001HF00/F000F5P0002`001HF;00F;1H09AH0000F5P0Q
5P/05QHF0P0/;2`03P00;000;2`/000F5P0U5P0000/Q01HF000/5QH0;00001HF000/;2`05QH/01H0
000/5QH001HF0P00;0002`0F5R`0000000/;000F;1H0000002`000005QH0;00001H05P0;8AH05QH0
00805R`F0P00;0002`0F5P005QHF01HF00005P0002`0000F000F5R`05P0001HF2`0F01H05P000080
01H000/09@0F01H0002KBEL0WinO09nO]P2GNlD0Wh>f0:ik[P2OWkH0VjNn0;JOW`020:ik[P060:ik
a@2GNjh0Wh>O0:^3Z`2^Gc00Wh>f0P2GNjh209MO[P0I09NGa@2KSI/0Ug_50:n_[`1<HS00AT``01H0
5P005QH0ag/`0?N^002_TS00hZL00:ik<01lO7`0UlG309nOU0005QH0AS0`07USC01iHTH0Uf=<0;JO
P`1^Ebh0<30F000F5P0201H00006000F5P0F00002`/0000F000F5P005P000P005P001@00000000/;
000F0000000001H000805P0000<001HF00/;2`0000000P000002000F000601H000005P00000F000F
000000005P0F0P0F0000701FAc40][Jf04I6AP1k[W/0LW9b09nfW`1`Qg00C5@`0312<01SNF<0JVYZ
03/k>`1aLG40JUAD03Xj>P1DE5@001H005^0F`1<Gel0Gg/`08^;R`0/;2`05QHF01H000005QH0;000
000F000F01H200005P8001H00P0F0000100F5P00<31605I_I01O[YL205nGN`0805mOG`1OUel0LW9b
06V5J@1lO7`0Gg]O05mOG`1ONel205mOG`0404ebI00jJFT0E5AD05mkN`<0E5AD01809EAD03/k>`1D
L5@0Gg]O071`L01ONg/0C7]k05mOG`0jJFT09EAD02`/;016HTH0<7]O02`/;01WIfL0=Te=031OG`1O
Nel205ADE00D08>OP`1DPh<0QiF705^;R`2OWil0AV9601I6AP16ATH0JHF50451@@23Ph<0QHEY04I6
AP0k>c/0L8M`07^BN`11@D40Njj^0727L01DE5@8ooooo`001_ooool0100/;2`002`002`/;00F01H2
02`/;00504T0000/;2`002`002`/;00001H00P0/;2`01019000002`00000;00002`302`/;08002`0
00@0B@0002`/;00/0000B@001@0/;2`02`0F5P00;2`/02`/;00/;2`002`002`/;00/000002`003/F
5P0002`0;00000@002`000<0;2`/000/000/;2`00P00;000100/;2`0000001H05P0/00020000;005
02`00000;00002`0000F000002`00P00;0003@0002`002`002`000005P0002`002`00000000002`0
02`00000;00001H002`0000000000`0/00003@000000[Y;30<FGa@2GaLD0UiO509O5a@2f][H0UiO5
0:NW_P2GUlD0YjNW0<EOa@2GaLD00P2GUlD01`2OWkH0Y`000:NWY`2GUiL0YjNW09NGa@2GGlD00P2G
GiL07P2GUlD0UiNG0;Jf]P35GiL0][Jf0<G5U`3RNc00olEO0<FGG`2GUel0oiL00>o5U`35aLD0fW/`
09NGU`35UiL0Q@0005mO0000;000000001H0000/;2`0000/02`0000002`000000000;0005P000000
000/00@0000000@0000F00000000;000;000200000001@00;000000/000000000000000/00<00000
01<0000/01HF00000000BDU90=CDe035aIL0;2`/000/002GaIL09DTU09NGU`35klD0000/0000001O
Gel0aLG50=[5a@35aLD0;2`/0080000/00D002`002`0000F;1H000000000;003000000060000;000
0000000002`0000002`002`00P0/00001`0F5P00BDU905nGa@2WYjL0UiNG05nGU`1OUel00P1OGel0
0`2GUiL0QHF505nGG`0205mOG`0305ADE01OUel005mO0080GemO01<0GiNG05mOG`1DE5@0;2`/04U9
B@00Gel0BDU907=cL`00Gel0IfMW09NGU`1OUel005mO05nGG`19BDT005mO08F5Q@19BDT0UiNG0080
;2`/00H0GiNG04U9B@0/;2`0E71D04U9B@1OGel209NGU`0;0;Jf]P1OUel0Gd``07=cL`00G`00;2`/
001OU`2GUel0;2`/01I6AP2GUel00P1OGel8ooooo`001_ooool01@00;000;2`/0000;00F5R`0;2`/
008002`00P0/;2`02P00;000;1HF02`/;00002`0000002`/;00002`0;2`/000F5P00;00302`/;003
000/000/;2`002DF00<002`0100/;2`01000;000;2`/02`/;00/;2`2001OG`03000/000F;1H002`0
0080;2`/00D002`002`0000/;2`05R`F000/000202`/;00400000000;000;2`/01HF;080000/00P0
02`00000;00/000002`001HF5P0/000002`000000080;2`/00H002`002`F5P0/;2`0;2`/000/0000
0002000/000301HF5P0/;2`0;0000080000/0P00;0000`2^Njh0UlG509NGa@0409NGa@0:09N^a@2G
UlD0UiO509NGa@2GaLD0aIO50:NWY`2_[jl0aEl00:NWY`80aEnG00d0Ueo50<FGa@2WYjL0Wh>O09MO
G`35Uel0YjNW0<G5G`2WYjL0aLFG0>9k003_U`00oiL00080klFG00L0olFG0<G5G`3g[W/0Gel005l0
000002`0;2`/0080000000P001HF000/0000;0000000000/000002`0000001HF0080000000@0;2`/
0000000002`0;0000`0000001`0002`000000000;0000000000F00000000;000100000000`005P00
0000000/00040000000900005P00000002`002`0001OGel0;2`/05mOG`2f][H0>c/k0080;2`/00h0
UiMO0<G_a@0/;2`0;2`/05ADE00/;2`002`00000;0000000000/02`0000F01H000000000;08002`0
01T000000000;00000000000000/00000000;0000000;00/000001H00000000/;2`0Lg=c05nGU`2W
YjL0Lg=c05mkN`00GiL0GemO05nGG`25QHD0GiNG05nGG`1OGc0005mO0080Lg=c0P1OGel04P00Gel0
JFUY04U9B@1OGel0BDU9001OG`1OUel0001905A`L000Gel0YjNW05nGU`2WYjL0BDU905nGG`00Gel0
9E@U09NGG`80;2`/00/0YjNW04U9B@0/;2`0Ng]k000/0000Gel0YjNW05nGG`1OGel0YjNW07:>SP02
04U9B@08001c002f][H005mO02`/;01ZJVX0GemO02`/;01OGel8ooooo`001_ooool01`00;000;000
02`/;00F5QH002`002`0001900000P00;0003@0/00009AH002`/;00/000002`004T0000002`0B@00
01H/5P19000002`002`0000/;2`00P00;000200F5P00;00002`/;000;000;2`/000/0019BDT0;2`/
0P00;000200/;2`0B@0002`/;019BDT0;2`/000F5P0/;2`002`00P0/;2`00`0/0000;2`/01H/5P03
02`/;00502`00000;000000/000F5P1cLg<00P0/;2`01P19000002`0000/000F0000000004T000<0
02`000@0;2`/000F0000;00002`00P0002`01`0/;2`0;00001H/5P00;000;0000000001OGiL00P00
00002@0F5R`000190:NWY`2GaLD0aLG509O5k`2f][H0Njk509NGk`0409NGa@0509O5a@2GT]X0Y`00
09NGa@2WYjL0102GUlD0402^NiL0aING09NGU`1O05l0UiMO0<FGU`35aIL0hYL`05mO0035G`00olFG
0?o5G`3oU`00Uel00>;3C00/;2`209NGa@0405mOG`0/;2`002`001HF5P8002`000D0;00000000000
;000;00000005P040000000402`0000000005QHF02`0008002`0100000000`0002`00000000/0005
000000040000;000000002`00000;08000000140000/00000000;00000000<FGU`2WYjL0;2`/05mk
N`1cLg<0GemO0;Jf]P1OG`00000/000/002L/I`0B@0000000002000/000=00000000;00001H00000
;000000002`002`00000;000000/000F000/0000000002`000020000000A02`0000F5P00;2`/0000
0000;000;00005nGU`1OaLD0Njj^05nGU`1OUel0GemO05nGU`2GUiL0GiNG07]kN`19BDT00P1OGel2
001OG`0407=cL`1YJFT0GiMO07=cL`<0GemO00`0BDU902EDE019BDT0GiNG07=cL`1OUiL0GlFG08F5
Q@2GaEl0E71`04U9B@0/;2`207=cL`80;2`/00`0D51@02`/;02GUiL0BDU902`/;019BDT0QHF509bL
Q@2GaIL0GiMO09O5a@2WYjL204U9B@0409MkN`19BDT0;2`/05mOG`Sooooo0006ooooo`0502`00000
;000B@0001HF5P0/00000P00;0001P0/;2`002`002`/;00F;1H0;2`/000/0080;2`/00<0000/02`/
;00/5QH01@0/;2`0100/0000;1HF02`/;000;00204T000060000;000;0005QH0000/000/;2`0G`00
100/;2`0100F01H002`002`/;000;00302`/;00301HF;00/0000;2`/008002`000<0;0000000000F
;1H00P0002`3000/0003000000005P00000000<002`000H0;2`/0000;00F;1H0;2`/0000;00/0002
0000;006000/000F000002`002`/;0000000;2`/0P000000;@00;000000/02`00000;000;2`/0000
000/;2`0<31`09NGa@2GaLD0UlG_09NGa@2GaNl0UiO509N^fP2WYjL0UenG09NGa@2WYjL0UiO509O5
a@2GUlD0Ug_50<FGa@2W0000YjNW09NGG`19BDT0aING0?o5G`3oaIL0klEO0?o5U`3oaEl0kiL007<0
002FSTH0aING09NGa@2f][H0YjNW09MOa@2GaLD0FEUI0000;0020000000;000/000/;2`002`0000F
0000;000000002`00000000002`0000000005P001P0000000`005P00000000000004000000040000
5P00;000000002`/;0<0000000d05P0000000000000002`00000;00/0000000/02`0001YJFT0QHF5
09MOG`1O0000GemO0080][Jf00D0ATI6000/000002`0000002`/;00200000009000F00000000;2`/
0000000/00000000000/000001H0000000<0000/00<002`00000;0005P000P0000002@00;000000/
000/000/;2`0GiN^0:NWY`2GUiL0QHF505mOG`0205nGU`0C07]kN`25QHD0GemO001OG`19BDT0GemO
001OG`13LW80QHF507=cL`19BDT0Lg=c05mOG`19BDT0E5AD001OG`1OUel0BDU9001OG`0209NGU`0J
0;Jf]P1bLW80GemO05mOG`2GUel0GemO02`/;01OUiL0>c/k0000B@1cLg<0BDU902`/;01cLg<0GemO
02DUB@2f][H0YjNW09MOG`2WYjL0GemO05nGU`23Pe@0000/02`/;01OGel8ooooo`001_ooool00`00
;000;000000/000202`/;0030000;00/;2`0;2`/0080;2`/00<05R`F02`/;00/;2`02@0/;2`01@19
0000;2`/02`F5P190000;2`/00<002`000@0;2`/01H/5P00;00002`00`0/;2`00`190000;2`/03/F
5P0402`/;00604T0000/;2`0;2`/000/000/;2`0B@000P00;00502`/;0<0000000<0;000000/000/
;2`00P00;0000`0/;2`002`001H0000202`000070000000/0000;000000/000F5QH0000/000/0002
0000000402`/;00002`05QHF0000008002`00P0/;2`00`0004T05QHF0000;00202`/;00>0000B@1O
GiL0UiO50:jG[P2GGlD0UiO505nGa@2GUnl0UiO509O5a@2GUlD0YjNn09NGa@2W00020<G5U`0=09MO
G`35Uel0onmO0?o50035G`00olEO0<FG002GG`00a@000:mS<035aIL0UiO50:NWY`0309NGa@0A09nf
]P35aLD0aIMO05mO000/;2`00000000/000001H000000000;0000000;0000000000/000001HF0000
0000;0000`000000100/;2`001H00000000002`20000000:000/000000005QHF02`00000;000;000
0000;000000002`0000F5P@0000000H0;0000000000000005P0F000/000002`200000080000/00<0
5QHF0000000000000P000000100002`0000001H05P00;00200000004000/000002`0;000000F00D0
000000<0;00001HF5P0002`01@0000001016HV80UiNG09O5a@2WYjL205nGU`0D001OG`25QFT0GenG
07=cL`1OUel0GemO04U9B@1cLg<0E5AD05mOG`00Gel0Lg=c09NGU`1cLg<005mO05A`L019BDT005mO
04U9B@1OUiL204U9B@0;05nGU`2EUID0UlFG07=cL`1OUel005mO04U9B@25QHD0ATI6001OG`19BDT0
0P0/;2`0102GUiL005mO031DC01OGel202`/;00708F5Q@2GaIL0UemO0820P01OGel0YjNW05mOG`08
ooooo`001_ooool502`/;00:00190019BDT0;2`/02`/;00004T0>c/k04U9B@00B@00;2`/00190080
BDU900<0>c/k02`/;00/;2`00P0/;2`01`00B@00;2`/02`/;00/;2`002`002`/;000;0000P0/;2`0
200k0000;2`/02`/;0190000;2`/04U9B@0/;2`002`00P0/;2`00`00B@0002`002`/;00302`/;003
04T0000/;2`0;2`/00<0;2`/00L05QH/02`/;00/;2`0000/02`/;0000000;2`/008002`000L00000
0000;0000000;0000000;0005P00;2`/0080;00000@0000/0000000/;2`002`010000002000/0005
000F000/0000000002`0000/;2`00P00000030005P0002`002`/;00002`0;2`/0000;00000005QHF
0000;019BDT0GenG09O5a@80UlG_00@0GiO509NGa@35aNl0Gel00P0/;2`00`1c0000aEmO0:E<<002
0?o_U`090?o_G`3oaEl0;2`/05l00035[T`0aLEO0:NWY`35UlD0aEo50080Ueo500<0Wh>f0;Jf]P35
G`000`2WYjL0101OGel05R`F000/0000;003000000030000;00F0000;00000D0000000<0000/0000
000/;2`0100000002@0001H000000000;000000002`00000000002`001H002`000020000000502`0
0000;000;2`/0000;00F00000P0000001@00;0000000000/000000005R`F00<0000000d0;2`/0000
00000000000F00000000;000000002`00000;000000/01H05P0002`0;0000080000000H002`00000
;00001H002`00000000002`300000005000F000002`0UlG509NGU`1OUiL00P1cLg<01`1OGg/0GemO
05mOU`1OGel0GiNG05mOU`1cLg<00P00Gel205mOG`08001OG`1OGel0GiNG031kN`1OGel005mO04U9
B@00Gel204U9B@0607=cL`1OGel0YjNW05mOU`35aLD0UlFG0P1cLg<03000Gel0UiNG001OG`00;000
GiNG0:NWY`0/;2`0C71<05mOG`00;000BDU909O5U`80BDU900@0Gg]k0:NWY`2f][H0GemO2?ooool0
00Kooooo00l0>VUY05ADL000Gg/0B6ek031ON`1OGg/007]k031kN`0`Gg/007]k001]N`0UL70005mk
001kN`1ONg/00P1DL700200ZJ6P005mk001OG`0FATH0BDU904I6HP1DE5@0:D510P0FATH0200k>c/0
5S/F02E99@0/;2`0=3@d03/k>`0/;2`05R`F0P0/;2`00`0U>bD0;2`/02`Q8@0502`/;0<05R`F00l0
;2`/01H/5P0/;2`05R`F02DF000F2b405R`F0000;00F5QH0;2`/03/F5P0F;1H05P/;01HF000/0000
0P0F;1H01P0k00005QH0024/8@0F;1H0000F000000805QH000H05P0F000/000F01H0;000000/0000
01H201H0000R000F2`005P0001HF00005P0/5QH0000F01HF000;5P/05QHF0000000F01H05QH0000F
5P0F000000/002`/;00000005QHF01H05P0002`05R`F000`AP1GBV<0HV=h0316000F0000E5@U0:iO
<02n<000@Q<N0:L0003=C4`0bjL`0<]h<080^GP`00`0TWEO0:iOG`2G[/D0YjNW09NGa@2GGlD0UiN^
09nAZ`2GNlD0aC1O0:jGa@2WYjL209nO]P090:>9^P2OWkH0Ng]S05ADE00F0000000F01H000000000
01H00080000000P001H001HF5P0000002`0;0000000001H05QH0000000805P0002402`0;00005P00
5QH0000000005P005QH0000F000;000F00000000000F000F0000000001H0000F01H02`/;0000000F
5P00000F01H0000F5P00000F00/;2`000000000F000F0000000001HF000F00005P/05P00000F0000
01H00P000000400F01H001H;000F5P000000ATIR01H/5P005P00000F000;000F00005P0F0000000F
5P0001H001HF5P0;2`/200005P0@050j>P1<Hf<0QIbL08>OW`2=YjL0>VV505nGN`1ONg/0JHF503Z5
J@1kNg/0JGMY031kG`1ONg/0<5mO04U9B@809EAD0240HV9R05mkN`23Wh<0LW:>05A`L01DE2D0E5AD
05mOG`0`B4P0Gg]O05ADE00UE5@0UIFE05mkN`1DPh<0EYEk08^WR`0`Gel09EAD07alO00UE5@0;2`/
06QXJ00/;2`05QHk08f=S@19BDT0;2`/031OG`1_NV`0E5AD07]ON`1OGel02?ooool000Kooooo0`1O
UiL01`1ONiL0GiO5002GU`1OUiL0GenG05nGU`00UiL00`1OUiL01@1OUlD0GiNG05nGU`1OUiL0<9NG
00<009NG0P1OUiL01@1OGiL0<5nG05mOG`1OGel0GiMO0080GemO0`00Gel204U9B@0302`/;019BDT0
;2`/00L0;2`/00<002`004HF5P00B@000P0/;2`01P0002`0;2`/02`/;00U01H0B@000000;0@0;2`/
00/09AH002`/;00002`0;2`/04T0000/000002`001H/5P00;000000002`/;0020000000302`0000F
5P00;2`/00<000000P0/00000`0/5QH0000/02`0000202`0000702`/;00002`000000000000/;2`0
00000000;00200000006000F0000;000000/02`00000;000000/0P0/00001@005P00;000000/0000
0000UiMO00<0aEl000/0a@000;H0002f0000U`0005l00035G`005R`F09MOU`2GaLD0UiO50:NWY`03
09NGa@0;09MOa@2WYjL0aIO509NGU`2GGlD0UiO50:jGa@25QHD0UiNG0:NWY`0/00000P0000000`00
01H000000000000400000008000F00000000000000000000;00000000000;0005P02000/000402`0
00000000000/02`0008000000P00;0003P00000002`00000;000000002`00000;0000000;0000000
000002`002`0000F000002`0;0001@0000001000;000;0000000000002`400000007000/00000000
;2`/02`0000002`001H00000;0020000000E02`/;000000002`001HF5P000000;2`/0019000002`0
02`00000001OUjh0GlG505nGU`2GUiL0GiNG07=cL`1OGel0JHEY05mOG`2GUiL0GiNG0080Lg=c00<0
BDU9031OG`00Gel00P1OGel208F5Q@0>002GU`1OUiL0BDU904U9B@00B@00BDU909NGU`19BDT005mO
07=cL`1OGiL0GlFG07=cL`2f][H2001OG`04071`L019BDT0GiNG09MOG`80;2`/00D0YjNW02`/;00/
;2`0QHF505mOG`08ooooo`001_ooool0101OGiL0GiO505nGa@1OUiL205nGa@<0GiNG00<0GiO505nG
U`1OUlD00`1OUiL205nGa@<0GiNG00D0GiO505nGU`1OUiL0GiNG031k[P02002GU`<0GiNG00@009NG
05mkN`00GiL009NG0P1OGel01@00Gel0BDU904U9B@0U9DT0BDU90080;2`/00H0BDU902`/;00/;2`0
5S/F000/0000000202`/;005000/000/;2`05R`F0000;01900000P00;00202`/;00;02`F5P00;000
;2`/02`/;000;000;2`/000/000/5QH0000/04T0000000000P00;000100/00005QHF0000;000;002
0000000:0000;0000000<30`02`00000000002`002`00000000002`001HF5P80000000L0;2`/000/
00000000000001HF5P0002`0;0000080000000@0;00000000000;000000F0P0002`01P0/0000000/
0000000/0000_ZN;0>mO0080aEl000P0Q@0009L0000002`0000005mOU`2GUiL0][Jf09O5a@80UiO5
00/0UiN^09NGU`2GGiL0UiO509MOa@2f][H0aEnG09nOW`2GGiL0YjNW09NGa@02000000030000;000
0000000000@0000000D002`000000000000000000000;0030000000<000F000002`000000000;000
;0000000000/00005QH000000000;000000002`00`0000001@005P00;00002`00000;000000/0080
000000D05QH00000000002`00000000/00020000000301HF5P000000000/00@0000000H05QHF02`/
;000000002`002`0000002`300000006000/00000000000002`000000000000F0P0002`202`/;005
0000000002`05R`F05nGU`1OGiL00`1OUiL01@1OGel0@g9b05nGU`1OGel0QHF50080GiNG00H0GemO
02EDE019BDT0GemO04U9B@1OUel207=cL`0<08F5Q@1kNg/005mO02`/;019BDT0YjNW02`/;000Gel0
Ph>304U9B@2GUiL0QHF50P1OUiL03025QHD0E8>3002GG`2WYjL0BDU9000/0000Gel0UlEO01HF;000
02`0UlFG05mOG`Sooooo0006ooooo`0705nGU`1OUlD0GiO505nG[P2WYjL0GiNG09NGU`0205nGU`03
09NGU`1OUjh0UiNG0080GiO50`1OUiL01@1OUlD0GiNG05nGU`1OUiL0GiO50080GiNG00<0Gjj^05nG
a@1OUiL01@1OUiL2002GU`80GiNG00@0Lg=c05mOG`00GiL0<5mO0P00Gel01@1OGel005l002`/;00/
;2`0>c/k00<0;2`/00@0BDU90019000/;2`05R`F0`0/;2`01P00;000;2`/02`/;00k5QH0B@00000/
0080;2`/00P002`002`00000;000;2`/0000000/;2`002`002`/;08002`000@0000/0000000/0000
00000P0/00002@005P00;00002`/;0000000000/02`000000000AS0`02`0000200000005000/0000
000002`001H0000000000P00;0001@0002`0000002`0000/000001H000@002`000T0;2`/0:NWY`3R
h/D0BDU904T0003_Uel0UemO0000;00/;2`00`00;000200/;2`0UenG05nGU`2GUlD0UiOJ0:NWY`2G
GiL0UlG_0`2GUlD0102GNlD0Ueo509NGU`2GUlD300000005000F5P000000000000000000;0000P00
000010005P0000000000;0000002000/00@0000000<002`00000;00000000`0000000`0/00000000
00000002000/00030000000F0000000/008002`000H0000/0000000000005QH00000;000Gel30000
0003000/00000000000000@0000000T0000/000F000002`0;00005mOG`00;000000002`0000002`0
0P0000001`0/000000000000;00000005QHF00000000;0000P0000001@0/0000000/01HF5P0/;2`0
YjNW00@0GiNG00d0L71`05mOU`1OUiL0GemO05nGU`25QHD0GemO06UYQ@19BDT0GemO001OG`1OUel0
GemO0080BDU900X0QHF505o5U`1OGel0GiMO001OG`0/;2`0BDU9030`AP00Gel0UiNG0P1OGel03@2W
YjL0GiO505mkU`1OUiL0Lg=c04U9B@0/;2`0UiNG05mO000/5QH0YjNW05nGG`1OGel02?ooool000Ko
oooo00h0QHF505nGa@1OUlD0GiNG05nGa@2GUiL0GiO505nGU`1OUlD0GiNG08>O]P1OUlD0GiNG09NG
U`80GiNG00<0GlG505nG[P1OUlD00P1OUlD205nGU`0305nGa@1OUjh0UlFG00<0GiNG00@0GlFG05nG
U`1kUiL0GiO50P1OUiL00`1OGiL0GiNG05nGU`02002GU`09001OG`00GiL005mO05mOU`00Gel0BDU9
04=bLP0/;2`004T000D0;2`/00L0B@0002`/;000;000;2`/0019001OG`005S/F00@0;2`/0P00;002
02`/;009000/000/;2`0;0000000000/;2`05P0F00000000;00000000080;00000<0000/00000000
;0000P0000000`00;00000000000000200000007000/00000000000/02`00000;000000F02`00003
000/000302`00000000000000080000000X0000/000/000002`0BDU909O5a@2TY9`0;000000/003o
Uel002`00P0000000`005P00;00000000003000/00030000000U9C/0UiNG0080UiO500/0GiO509NG
a@1OUlD0Ug_509MOa@2GaNl0UiNG0000;000000002`0000F0004000000030000;0000000000000<0
000000@0;000000/0000000001H00`0000001000;00000000000000/000200000005000/00000000
000/000/000/00000`000000100002`000000000;000;0020000000302`/;000000002`000800000
00/05QH00000;0000000000/00000000;000000000005P00;000;2`/02`000020000;00:00000000
5QH00000000/000002`002`000000000;00000000000;0@0000000H0;2`/000F5P00;000000/02`/
;01OUlD205nGU`0308F5Q@2GUiL0GiMO0080GemO00T005mO05nGG`1YJHD0GiMO05nGU`19BDT0GemO
04U9B@00Gel00P19BDT0602WYjL0GiO505nGU`1OUel0BDU907=cL`0FATH0;2`/09NGU`0/;2`0000/
09O5U`1OGel0JVYZ08F5Q@2WYjL005mO05nGG`2GaLD0;2`/01HF>`35aLD0Lg=c05mOG`Sooooo0006
ooooo`80GiNG00@0UiNG08>O]P1OUiL0GiO50`1OUiL02P1OUlD0GiN^0:NWY`2GUiL0GiO50:NWY`1O
UiL0GiO508>O]P1OaLD305nGa@0409O5a@2WYjL0Njj^09NGU`80GiNG00@0GlG505nGU`1OUiL0GiN^
0P1OUiL00`1OUlD0GiNG05nGU`0205nGU`08032GU`1OUiL009NG05mOU`1OUiL009MO05nGG`1OGel3
001OG`030019000/;2`0;2`/00L0;2`/00D05R`F04T0000/;2`0;2`/0000;00202`/;00502`F5P00
02`0;2`/00000000;0000P0/;2`00`005P00;00002`/;00402`0000;01H00000000002`00000000/
000000000000;0000000000/00000000;0000P0000000`00;000000F000000020000000702`0000/
;2`002`00000000F;1H002`000000002000/00060:NWY`2GaLD0N6=R0000;0000000oiMO0P0/0002
000000030000;00/000002`000<0000000D0000F0000000/;2`0000/05mOU`0209NGa@0509Mk[P2G
UlD0UiO505nGU`00;0000P0000001P005P0002`00000000/00000000000/00h0000000L002`00000
000000000000000/0000000002`00080000000@001H000000000000002`00`000000200001H00000
00000000000002`005mOG`00000001HF0`000000100002`000000000;0005P030000000502`0000/
;2`0000/0000;00000000P0/00003000;000000/0000000F5QH0000002`0000002`0;2`/0000;000
00005P000000;080000000h002`007=cL`1OUiL0GiNG09NGU`1OUel0GemO05nGU`19BDT0GemO05A`
L01cLg<0GiNG001OG`80GemO00d0BDU905mOG`0UE5@0Lg=c05nGG`0/;2`0YjNW05nGU`2GUiL0031D
05mOG`19BDT0;2`/0080GemO00X0;2`/051@D00/;2`0GemO09O5U`2f][H0YjNW05mOG`1DL700UlFG
0P19BDT8ooooo`001_ooool01`2GaLD0YjNW0:NWY`1kUjh0UiNG05nGU`2GUiL00P1OUiL0102GUlD0
NiN^05nGa@1OaLD205nGa@80UlG500@0GiO505nGU`1OUiL0GlG50P1OUiL0202GUiL0GiN^05nGa@1O
UiL0YjNW05nGa@2WYjL0UiNG0`1OUiL00`2GUiL0GiNG05nGU`0;05nGU`0805mOU`00Gel005mO001O
G`1OGel0>c/k02`/;00004T602`/;00604U9B@0/;2`002`002`/;000;0005R`F0P0/;2`01P0/0000
;2`/04T0000002`05R`F000/0080;00000X002`004T0000002`002`000000000;000;2`/000/000/
0000000/0`0000001@0002`0000002`0000002`001HF0080000000H0000/00000000;000;0000000
00005P0202`0000500000025QHD0UlG50?ooo`0F5P000P0/;2`0103_Uel002`00000;000;0030000
0080;00000D002`002`/;00F5QH0000/02`/;0020000;080;2`/00H0HV9R09NGa@2GUlD0GiNG0000
;000;00900000003000/00000000000000D0000000<002`000000000;0000`0000002@00;000;000
0000000/0000000/00000000;0000000000/0004000000060000;0005P000000000/0000000002`0
0`0000004`0002`002`00000000/00000000000/000F01H00000000/000/;2`00000000/00000000
5R`F00000000;000000002`0000002`00P0000001`0002`00000000000000000000/0000000001H0
10000000100002`0000008>OW`00Gel208F5Q@0609O5U`1OGel0Lg=c05ADL01OGel0GiNG0P1cLg<0
1@1OUiL005mO001OG`0UE5@005mO0080BDU900d0QHF50<FGU`1OGiL0<7]k05nGU`1OUel0;2`/09NG
U`1OGel004T0030`G`0/;2`0GemO0080Lg=c00@005mO09O5U`3=cLd0YjNW0P1OGel8ooooo`001_oo
ool0201OUiL0GiN^08>OW`1aVk80WinO09nO]P1O[/D0NiN^0P2WYjL02P2OWil0PinO08>f]P2OWil0
YjNW08>f]P1O[/D0KJk507^G[P2WYkh207^^[P80GiNG00T0LJNb08>3W`2O][H0WkJf08^n_P23Wil0
PkJO05nGU`1OUjh00P1OUiL01P1kUiL0Pinf08>OW`1O[Zh0SI^K05nG[P<0GiNG0180GiN^05nGU`1O
UiL0GiN^05mkU`0`UiL0Gg^G002GU`00Ng/007^902E`E01YJFT005mk02EDE00k>c/09EAD02TY5P19
9BD202`/;00D000k000F;1H05S/F024/8@00;00001HF01H/5P009AH05R`F02`/;00Q;2409AH001HF
000U5P00000/000F000F5P002`/;01H0000F5P02000/000S000F000F5P00<c<X000/000F5P0002`0
0000000F0000000000002`0/00005P0F02D05P00;0005QH/01H/5P005QH08B4Q00005P005QH0NHii
0:n_[`3gh/<0Hf8`000;2`000000000F0?NG<00F5QH05P00000F000F00000000000F000F01H00P00
00001@005P005P0000005P005P0000000080000F00@00000000;8@0F5QH0000/0P005P000`0001H0
000000/;00080000008001H01@0000000`0F000000000000000200000003000;00005P0000000080
01H000L05QH000005P000000000F000F5P0001H001H00080000000L001H00000000001H05P00000F
0000000001H000<0000000X05P00000F5P0000005P0F000000002`000000000F000000005P0F0P00
0000=P0;00/05QHF000/000001H05QH0000/000/;2`04bTC0000000F5P00000F0000000F5QH00000
00/;000001H002`000005P0F5QH05QH/000F000Q5QH0AV=<05mOG`1OUjh0Ng^G05nGN`1YQFT0C75S
03Z5J@1DE5@0LXj>04akC025W8D0LXib06V5Q@12LfP0JFUY05ADE019BDT0JHEY04U9B@00<5l0RHV9
04aON`1kTY80Rh^;08^WR`1OGel0;2`/05ADE00F5QH0L71`05mOG`80;2`/00D0PinO06QF?P2n_[h0
RjNW05mOG`08ooooo`001_ooool0101OUiL0GiO505nGa@1k[Zh209O5a@0;05o5a@2GaLD0GlG509O5
a@1kUlD0GlG505nGU`2GUiL0GiO509NGa@2GaLD00P1OUlD205nGU`0<002GU`1OUiL0UlG507_5a@2W
YjL0GiNG05nGa@2WYjL0GiO505nGU`1k[Zh0UlFG0P1OUiL0401OUlD0GiNG05o5U`25QHD0Gjj^05o5
a@2GUiL0GlG505nGa@1OaIL0GiNG05mkU`1OUiL0GenG05nGU`1OUlD705nGU`0505nGG`00Gel0031O
02`/;000;0002@0/;2`02`00;000;00001HF000/;2`002`002`/;000;000000/02`/;00F;1H002`0
0080;00000L002`00000;00000005QH002`/;000000002`00080;2`/00<0;00000005P00;0000P00
;000300/;2`002`0000/0000;0000000000/002WYjL0][Jf0?ooo`0/;2`0000001HF5P8002`000<0
klFG02`/;000;0000`0000002@00;0000000000/000002`002`0000F0000;0000000000/00020000
000302`/;0000000000000D0000000D05P0000000000;0000000000/000<00000003000/00000000
000000H0000000H002`00000000/00005R`F0000;000;00400000003000F0000;000;00000<00000
00@0000/000F0000000002`00P0000002@00;000000/000F000/;2`000000000;000;0000000000/
00020000000302`0000002`000000080000/00@00000000/000002`002`00`0000000`0F5QH002`0
000000040000008002`00P0000009025QHD0GiNG0:NWY`1kNg/0QHF505mOG`2GUiL0GemO04U9B@1c
Lg<0GemO07:USP1OUiL0GemO002GG`1cLg<0GemO02`/;01`L5@0BDU907=cL`00Gel0GiMO0:NWY`1O
UiL0Ph=D05mOG`2GUiL0Gel002`/;00004T0GiMO02`/;02GUel0UiNG04U9B@Sooooo0006ooooo`0;
05o5U`2GUlD0GlG508>O]P2GUlD0YjNW09O5a@1OUlD0YjNW09O5a@2O]Yl00P1OUiL01@2WYjL0UlG5
09O5a@2GaLD0Pinf0080GiNG00H009NG05nGU`1OUiL0YjNW09nf]P2GUiL20:NWY`@0GiNG00@009NG
05nGU`1OUiL0GiO50P2WYjL01P1OUiL0PinO05nGa@1OaLD0GiNG09NGU`80GiNG00D0GiN^05nGU`1O
UiL0GiNG09NGU`0205nGU`0306V5Q@1OUlD0GiNG00<0GiNG00/005mO002GN`00Gel0GemO001OG`19
BDT002`00019000F;1H0;2`/000/000202`/;00A000/000/;2`0;2`/000/000/000002`00000000/
;2`0;00002DF000002`002`00000000/0000;2`/000/000F5P000`000000100/;2`0;0000000000F
5P0302`00009000/000/;2`0;000000/00005QH004T009O5a@3QhN40klFG0080000000H05QHF0000
0000;000aIMO000/000002`202`000060000000/000000000000;0000000;0000`0000001P0/0000
000002`00000;00001H002`000D0000000<001H00000000000000`0000000`0002`0000000000005
00000003000F5P000000000000H0000000`002`002`000000000;00000000000;0000000000/0000
000002`00000000/;2`20000000302`00000;00000000080000000`002`0000F000/0000000/000/
00000000;000000/00005QH0000/00000000;0030000000300005P0/;2`0;000008002`000P0;000
0000000/5QH0000/02`00000;00000000000;0<0000000l0000/0000000/0000;2`/0000;00F5QH0
000002`/;0000000;00002`/;01OUiL0<5mO05nGU`25QHD00P1OUiL01@00G`00GiNG02`/;025QHD0
GemO0080UiNG00H0QHF505mOG`19BDT0L71D04U9B@1OUel205mOG`030;Jf]P2GUiL0N7Qh0080GiMO
00P0BDU9000/0019BDT0GiMO000/002WYjL0Lg=c001OG`Sooooo0006ooooo`<0GiNG00P0Pinf0:NW
Y`1OUiL0YjNW05nGU`1OUlD0GlG507^^a@80GiO500D0UlG50;Jf]P2GUlD0UlFG032GU`0405nGU`80
UlG500@0NlG505nGU`1OUiL0UiNG0`1OUiL02@00UiL0GiNG05nGU`2WYjL0GlG50:NWY`1OUiL0UlG5
08>OW`0505nGU`0409NGU`1k[YL0GiNG09NGU`80GiO50P1OUiL00`1OUjh0GiNG05nGU`0505nGU`07
002GU`1OGel005nG001OG`1OGel0BDU903/k>`0302`/;004000/000/;2`0;2`/01H/5P80;2`/00H0
GemO02`/;00/0000;2`/0000;00/0002000/000500000000;000000001H05P0/00000P00;0030000
000301H0000/0000;2`/0080000000P0;000000/000/00005R`F0<G_a@35aLD0ono502`/;0800000
00D05QHF0000000/0000aIMO02`/;002000/000>000F0000000000000000000/000002`000000000
5QH002`00000;000;000;0000000;000;002000000050000;000000000000000000/00001`000000
0`005P000000000000030000000402`/;00F000000000000008002`000<0000002`/;00F00000`00
00001@0/000002`002`00000;0005P000080000000H0;000000000000000;2`/00000000;0020000
0003000/00000000;00000L0000002005P00000/000/;2`000000000;000000002`001H05P0/0000
02`002`00000;000000/02`000005QH0000002`0000002`0000002`0000/;2`001H0000/00000000
000/000/00000000000/01HF5P00;000000/00000080000/0200000005A`L01OUiL005mO05nGU`2G
UiL0Lg=c05nGU`1OGel0LW9b02`/;01cLg<009MO0:NWY`1OUel0GemO07^BN`0/;2`0GenG02`00019
BDT0GiNG04U9B@1DPh<0UiNG0:NWY`19BDT0;2`/09NGU`1OGel05R`F0<G5U`80GemO2?ooool000Ko
oooo00d0GemO08F5Q@1OUiL0NiN^0:NWY`1OUiL0YjNW05nGU`1OUlD0UiO507^^a@2GaLD0aLG500<0
UlG500<0YjNW05nG[P1OUiL00P1OUiL20:NWY`0505o5a@1kUiL0GiNG05nGU`1OUlD00P1OUiL03P1O
aIL0GiNG05nGa@1OUiL0UiNG09NGa@1OaLD0GiO50:NWY`23WkH0GiO505nGU`2GUiL0GiNG0P1OUlD0
0`2>SXh0UiNG05nGa@0205nGU`80GiO500D0GiN^05nGU`1OUlD0Geo505nGa@0205nGU`0405mkU`1O
GiL0GiNG05mOU`8009MO00@009NG05ADE000Gel0;2`/0P00;0000`0/000002`001H/5P0202`/;080
02`00P0/;2`02P0F5P0002`0000/000/;2`0;000000/000/00005QH0000/000/0002000/00040000
000/00005QH/02`/;080000000P0;2`/0000;0000000;2`/03/k>`2f][H0oooo04T00080;2`/00D0
000001HF5P00;00000000<FGG`02000/00040000;00001H0000002`/;08000000P00;00300000005
000/000/0000;000000/000/00000P0000001@0/0000aLFG000/0000000001H000T0000000<002`0
0000000/;2`02P0000001P0/;2`000000000;000000002`00000;080000000<002`000000000;000
0P000000200F5QH0000/000000000000;00000000000;0005P00100000001P0002`0000000000000
0000;2`/02`0008002`000X0;00001H05P0002`002`000000000;0000000000/00005QH000000P00
02`03`000000000/02`000005P00000/00000000;00000000000;00000005QH00000000/;2`002`0
0000;0020000000O02`/;025QHD0GiNG09NGG`1OGel0GiNG07=cL`1OUel0L71`04U9B@00Gel0UiNG
05mOG`1OUel0GiNG07]kN`19BDT0GiNG000/0019BDT0GlFG04U9B@1kNel0GemO09NGU`2GaIL0UlG5
0<G5U`1OGel05R`F0:NWY`0205mOG`Sooooo0006ooooo`0907=cL`1OUel0QHF508>O]P2GUlD0][Jf
0:NWY`1OUlD0UiO50080GiO50`2f][H605nGU`05002Ga@1OaLD0UiNG05nGa@0`UlD00P1OUlD00`2W
YjL0GiNG0:NWY`0205nGU`0405o5a@2WYjL0GiO505o5a@80GiO500<0YjNW032G[P2GUlD00P1OaLD0
1@2GaLD0GiO50;Jf]P2G[/D0UiO50080YjNW00D0GiNG09NGa@1OUlD0NiN^05mOU`0205nGU`80GiO5
00<0GiNG05nGa@1OUiL01@1OUiL01@00Nel005mO001OG`0/;2`005mO00@0;2`/00T0000/05nGG`00
;000B@000000;00F5P0002`002`00000;0000P000002000/008000000140;2`/02`000000000000/
01HF0000;000;0000000000/;2`0000002`/;000;000NF=S0>7Qh@2GG`00;2`/000/00020000000<
01H05P000000000009NGG`0/0000;2`/000/0000000002`002`00000000002`00P0000000`0001H0
;2`/00000003000000050000;00F5P0002`000000000;0001@000000100002`002`000000000;005
00000003000/00000000000000L0000000D001H0000/000000000000000/0007000000040000;000
00000000000F5P8002`00`0000000`0002`05QHF02`000040000000602`000005P00000002`00000
0000;0000P00;0003`005QH000000000000002`0000002`0000002`001HF02`0000002`0000002`/
;000;0000000000F00050000000502`0000F0000000/00000000;0000`000000400F01H002`002`/
;01OUiL0GenG001OG`1OUiL0GiMO07:>SP1OGel0BDU909NGU`00Gel0UiNG05nGG`1kUiL208F5Q@08
04U9B@00Gel0QHF5001OG`1DL5@005mO05mOG`2WYjL205mOG`0309NGU`1YJFT0UlEO0080GemO2?oo
ool000Kooooo0P1OGel00`1cLg<0Njj^09O5a@0209NGa@0309NGU`1OUlD0YjNW0080UlFG00H0UiNG
05nGU`1OUiL0GlFG05nGU`1O[YL205nGU`0B05nGa@1OUiL0UiNG09NGU`1OUiL0GiO505o5a@1OUiL0
GiO505nGU`25QHD0GiNG0:NWY`1OUiL0GiO505o5a@1OUiL0GiO50P1OUiL0201OUlD0YjNW0:NWY`2W
YjL0GiO509O5a@2O][H0GiNG0P1OUlD01@2WYjL0GiO505o5a@23Wil0GiNG00<0YjNW0P1OUiL0101b
SXh0QHF505nGa@2GUiL305nGU`04032G[P1OGiL005mO05mOU`8005mO00`0BDU9000/000/;2`002`0
04T00000;0000000000/00000000;00002`/;000;0020000000:000/000F5QH00000000/000/0000
000/02`00000Gel002`002`0008000000P0/0000100002`0B@000:j^[P3oonl302`/;0030000000/
000000000080000000H005mO0000;000;000000001HF00000002000/00030000000/;2`0;00000@0
000000H002`000000000;000000F0000000/0002000000030000;00000005QHF00<0000000<002`0
0000000002`00P0000000`0002`000000000000200000003000F00000000000000X0000000D002`0
0000000000000000000/000400000003000F5P000000000/00@0000000<0000F00000000;0001000
0000100001H0;000000/000/;2`20000000402`0000000000000000/0080000000D002`002`0000F
5P00000002`00002000000050000;0000000000F0000000002`01@0000009`00;000000000000000
0000;2`/0000;00F01H002`00000000002`0BDU905nGU`25QHD005mO07]kN`1OUiL007<009O5U`1c
Lg<0GemO07=cL`1kTW/0GlFG09NGU`00Gel0BDU909O5U`0/;2`0E71`02`/;019BDT0QHF505mOG`19
BDT0UiNG08^nY`2GUel0QHF504U9B@08ooooo`001_ooool01P19BDT0GemO08F5Q@2NWYh0UlG505nG
a@<0UlG50P2WYjL209NGU`0809NGG`1OUiL0GiMO07=cL`1kUg/0GiNG09NGU`25QHD20:NWY`0305nG
U`1OaIL0YjNW0080UiNG00@0UiMO05nGU`2WYjL0UiO50P1OUlD04@1OUiL0YjNW09NGa@1OUiL0GenG
08>OW`1OUlD0UlG505nGa@2GaLD0UiO505o5a@1kUjh0GlG505nGU`1OaIL0UlG50080GiO500T0YjNW
09NGa@1OaLD0UlG505nGU`1OaLD0YjNW08>O]P1OUlD00P1OUiL305nGa@0305nGU`00GiL0GiNG0080
GenG00<005nG05mOU`0UE5@01P0/;2`01P0/5QH002`00000;000;000000002`0008002`000L0;000
02`/;0000000000/0000000/000001H0008002`001@0000/02`00000;000000002`/;03Kfm/0UemO
02`/;000;000;2`/02`0000000005R`F02`/;00002`0GemO000/000/;2`002`0000F0080000000H0
02`002`/;00/0000000/000F0000;0030000000502`000000000;1HF02`00000;0000P0000000`0/
000000000000000500000003000/00000000000000D0000000<0000F000000000000100000000`0F
00000000000000040000000902`/;000000000000000000002`00000000/000/0000000F00800000
00<0;0000000;00000000P0000001@00;000000000000000;000;00000<0000000T0;2`/00000000
0000;000000/00005P00000/0000000/;2`00`0000001P005P00000/000000000000;0000000;080
000000@0;2`/00000000;000000/0P0000000`0U9C/0000/000000030000000402`00000;0000000
00000080000/00d0;2`/05mOG`1OUiL0<7]k05mOG`2WYjL0QHF505mOG`0/;2`0QHF5069iHP1OGel0
GiMO00<0GiNG00`0BDU905iNGP0/;2`0;2`/0:NWY`1OGel002`007=cL`1kNel0Lg=c0:NWY`1OGel8
ooooo`001_ooool08@1DPe@0<5mO08^;R`1kUID0WkJf09N^a@2^[]X0[/G_0:Nn_P2GaLD0ZkJ[09nO
W`2OWh<0O7al07:>LP1OUg/0JHEY06VCM`2=SHd0LXib08>fW`23Wil0NiN^05nG[P1]Ujh0GiNG07^^
U`2GaIL0NiNG07^^[P1OUlD0WkJf05n^[P0205nG[P0@07^G[P1OUjh0GiO505nB[P1aVkh0Pinf07^^
a@1O[Zh0Njk507^G[P2O][H0LI^W07^^[P2O][H0GiN^05n^[P80Gjk500l0EYN^08>O]P1OUjh0Pinf
07^G[P2O][H0NiN^08fKY`1k[Zh0NiNG07^Ga@1kUjh0GiN^07^GU`1]UkX0101OUjh02`1OUiL0<9N^
031kK@0`Ng/0BDU902EDE00UBBD0BBDU03/k>`0Q8AH05QH00080;2`/00h001H002`/;000;0002b`;
02`0000F0000000003/0000F5R`05R`F01H;00000000;00001HF;08001H001P0LG5a0<G5a@2a[K@0
5R`F000/000F5QH0;1HF00005P0k00005R4Q0000000F01H0<016000/00005P005R`F00/Q2`0001H0
5QHF02`0000F00005QH002Dk9@0;2`0201H05P0>01HF5P0F000001HF01H0000000/0000001H00000
5P00000001H/5P005P0000/;000000005P020000000:01H0000000005P00000000005P005P000000
00005P00000F000;00h0000000<0000;000000005P000P000000100001H000000000000001H30000
000301HF00000000000000D0000000`0000F000;2`0000000000000F00000000000F01H05P005P00
000000005P0F5P020000000;00005P0;2`0001H0000F00000000000F000000005P00000F01H00000
01H00P0F0000:P0000005QHF00002`005P00000F000F0000;0000000000F000;5P/05QH00000;00/
0000000F01H000005QH05R`F03]SE`0`Ng/0GiMk05mOG`1DQg00Rh^;08FLW01OGel0GiNG05@U9@23
][H0LW9b071`L01k[W/0TI6A01I6AP0U9C/0UjjG05mOG`0F;1H0Ng^G06IkC@0F5P00N7Qh05ADE0So
oooo0006ooooo`0?05mOG`1cLg<0QHF509N^fP2f][H0UlG_0;Jf]P2GaLD0e=CD09NGU`2WYjL0][Jf
09NGU`1OUel0Lg=c0080GiMO00X0O7al05nGU`1OUiL0GiNG09O5a@2f][H0QHF507:>SP2GUiL0QHF5
0P1OUiL01@2GUiL0GiNG07^G[P2WYjL0GiO50080YjNW00L0aLG_05o5a@2GaLD0WkJf05nGa@2GaLD0
UiNG0080GiO500<0GlG507^GU`2WYjL00P1OUiL03P2GUiL0GiO505nGU`1OUjh0GiO505nGU`2WYjL0
GiO505o5a@2WYjL0GiNG0:NWY`1OUiL0UiO50`1OUiL00`1kUjh0GiO509NGU`0405nGa@0305mk[P1O
GiL0Lg=c0080GemO0P19BDT302`/;00602`0000/;2`0B@000000;00F;1H0000/0P00;0001@0002`0
02`0000/000k5QH0000000<002`000h0BDU909O5k`3oool0NF96000/000/0000000002`/;00002`0
02`00000000/000002`002`/;08002`000D00000000F000/;2`000000000;003000/000301HF0000
02`0;00000<002`000<00000000F5P0000000P0000001000;000;000000000005P040000000602`/
;00/0000000002`/;000000002`00P0000000`00;00000000000000200000004000/000000000000
00005P80000000<002`0000000000000100000000`00;0000000000/000200000003000F00000000
000000P0000000P0000/0000000000005P000000;0000000;000000/0080000000X0000F000/0000
0000;0000000000002`0000000005P000000000/0P00000202`00008000F000000000000000/0000
02`00000000/00005QH3000000060000;00000000000000F000002`002`00P0000000`0002`0;000
000/000202`/;00804U9B@1OUlD0GenG05o5U`19BDT0PkJO05o5U`00Gel207=cL`0=0019002GaLD0
Ph>307=cL`0004T0UiNG05nGG`00;000BDU907^BN`0/;2`0001904U9B@08ooooo`001_ooool01025
QHD0UiNG05nGU`2W_[h309O5a@050;Jf]P2WYjL0QHF507:>SP25QHD00P1cLg<02`1OGel0GiMO07=c
L`2OWil0Lg=c05nGU`2f][H0UiO505nGU`25QHD0LXj>0080GiNG0100UiNG08F5Q@1OUiL0GiNG07^G
U`1cLg<0GlG509NGa@1OUlD0GlG509NGa@2WYjL0Njk50:NWY`2GUiL0GiO50P1OUiL01@2GUiL0<9N^
05nGa@1OUiL0UiNG0080GiO500D0GiNG05nG[P00UlD0GiNG09NGU`050:NWY`0705nGa@1OaLD0GiO5
05nGa@2GUiL0WinO0:NWY`0205nGa@060:NWY`1OUlD0GiO505nG[P1OUlD009NG0`1OUiL00`1OGel0
5TI6000/000502`/;00B03/F5P0/;2`0000/02`/;0190000000002`000005P00;000000/000/0000
02`00<G5a@3_onl0ono502`/;000;00000000`0/00004P0002`0;00002`0000/0000;2`/0000;000
;000000/01HF5P000000;2`/00000000;000000/02`/;00001H0000/00000080;00000D000000000
;000;00000000000;0020000000302`0000000005P000080000000H002`002`000000000000/0000
0000;0070000000302`/;0000000000000X0000000D001H000000000000000000000;00200000003
01H000000000000000/0000000@05P0000000000000002`00P0000003@0002`001H00000000/;2`0
000002`00000;000;000000F00000000;000000/000/00000P000000100001H0;2`/0000000/;2`5
0000000602`/;000;0000000000/000000005QHF0`0000001P0/000002`0000/00000000AV9R000/
0080;2`/00/0UiNG05nGU`00Uel0>VUY0:NWY`19BDT0QHF505mOU`0/;2`0UlG504IRAP0205nGU`08
09NGU`1OUiL0;2`/05mOG`23Wh<0000/02`/;000Gel8ooooo`001_ooool03`25QHD0YjNW09MOG`2U
YJD0UiNG0:NWY`2GaIL0QHF505nGG`1OUiL0LXib07=cL`1OGel0GiNG002GG`0205nGU`0:08>OW`1O
GiL0Lg=c05nGU`2f][H0GiMO07=cL`1bLW80Lg=c05nGG`80GiNG00<0Lg=c05nGU`1kUg/00P00UiL0
2`2WYjL0GiNG05nGU`25QHD0GiMO09O5fP2GaLD0GiO50:NWY`1OUiL0UiNG0080GiNG01<0GenG05nG
U`00UiL0UiNG0:NWY`1OUiL0UiO505nGa@2WYjL0GiO50:NWY`2GUlD0GiNG09nOW`2GUiL0GiO505nG
U`2GUiL0GlG50080UlG500L0YjNW05o5a@1OUlD0GlG5002GU`1OUlD0Pinf00D0GiNG00@0GenG05mk
N`1OGel0BDU91`0/;2`2000/0080;00000/05QH0000/000/0000;000001OU`2f][H0ooo502`/;00F
0000000/0000000202`/;08002`000<0000/000/0000;0000`00;0001@0000005P000000;00002`0
;0000080000/00D00000000F000/000002`002`000020000000:02`0000001H00000000/00000000
;2`/000/000000005R`F000/00P0000000D0;000000/0000;0000000000F000:000000030000;000
0000000000d0000000<002`0000000000000100000001000;000000000005P0002`50000000=0000
5P00000000000000000002`000000000;00F5P00000/00000000;000000/000/00030000000>000/
000000000000000/000/;2`0000F000/0000000002`00000;00/0000000001HF5P0/;2`3000/0080
000001X0000/00005P000000GenG09NGU`0002`0GemO05nGU`1k[Zh0GemO0;Jf]P0004T0GlFG04U9
B@1OGel0FEUI09NGU`1OUiL0Lg=c0:NWY`1OUel0QHF508^;R`0/;2`002`004U9B@Sooooo0006oooo
o`0409NGU`2f][H0aLG509nOW`80UiNG00D0QHF505nGU`1cLg<0GiNG05nGN`0307=cL`0609O5a@1c
Lg<0GiNG07]kU`2GaLD0YjNW0P2GaLD02P25QHD0GiNG06UYJ@1cLg<0UiNG05nGU`1OGiL0GiNG05nG
G`1OUg/205nGU`0D09NGU`1OUiL0YjNW0:NWY`1OUiL0GiN^05o5a@2WYjL0GiNG0;Jf]P1OUiL0GiO5
07^GN`1OUiL0UlG50:NWY`2GUiL0GiNG09O5a@1OUlD205nGU`050:NWY`1OUlD0GiO50:NWY`23Wil0
0P1OaLD0202GaLD0GiO50:NWY`1OUlD0Gjk505nGa@2GaLD0YjNW0P1OUlD01@2WYjL0PinO05nGU`25
QHD0GiO50080GiNG00<0GiO505nGU`1OUiL00P00Gel00`1OGel0;2`/000/000302`/;00=000/0019
0000;2`/02`/;0005P00000004T0000/;2`0UlG50?ooo`2GGel0;2`/01HF000302`/;0060000;00/
;2`0;00002`F5P19000002`00P0000020000;00401H05P0002`0;2`/000/0080000000/0;000000/
000/000002`002`0000002`002`0000000005P0002`002`000040000000301H000000000000000<0
000000<002`001H/5P0/00005P0000000`0002`00000000/000800000003000/00000000000000P0
000000<0;0000000;00000000P0000002P00;000000000000000;0000000000/000001H0;0000000
;00/0002000000090000;0000000000002`/;0000000000/00000000;0005P00008000000P0002`0
0`00;000000001HF00020000000402`/;000;00002`00000;0<0000001L0000/00000000;000000/
000/001DL700GenG001OU`00Gel0BDU905o5U`1OGel0AV96001OU`1OUel0GemO001OG`2GUel0YjNW
09nOW`1OUel0;00005mOG`08ooooo`001_ooool07@25QHD0YjNW09NGU`2_[jl0UiMO05mOG`19BDT0
Lg=c05mOG`25QHD0LXj>09O5a@1OaLD0UlG505nGU`25QHD0GiNG05mkN`1OUiL0YjNW09NGU`1OUiL0
QHF505mOG`1ONel0GemO09NGG`1OUiL009MO0080QHF500@0NiMO08F5Q@1OUiL0Lg=c0P2GUiL02P1O
UiL0GiO508>3W`35aLD0YjNW05nGa@35aLD0YjNW05nGa@1ONg/205nGU`0D0;Jf]P1OUlD0UiO50:NW
Y`1OUjh0GlG509O5a@1OUlD0GlG509NGU`1OaIL0WkJf05nGU`2WYjL0GiO50:NWY`2GUiL0GiO508>f
]P2GaLD205nGa@0505o5a@2WYjL0UiNG08>f]P1OaLD01@1OUiL0101ONiL0GiNG05mOU`00GiL3001O
G`80;2`/00D0BDU904T0000/;2`0;2`/0000;00202`/;00?000/0035aLD0UlG_0?o_a@0/;2`00000
01HF5P00;000;2`/000/000002`0;2`/0000;00F;1H002`00080000/00T0;00002`/;00000005QH0
02`00000;00000000000;00000000P0002`01`000000;2`/00000000000002`00000;0005P001@00
00001@00;000000F00000000000002`000D0000000<0000/00000000;000100000001@00;0000000
000000000000000/00H0000000<0000/0000000000002P0000001000;0000000000000005P0<0000
0003000/0000000000000080000000P0000/000000000000000F00000000;000000002`/;0800000
00/001H0000/00000000000/0000000/000002`00000000/;2`0000/0000000202`/;080000000@0
000/00000000000002`00P1cLg<03@0002`05P0002`0000/0000000/000/000002`0;000000/0019
BDT009NG05nGU`19BDT00P2GUiL02`23Ph<004T007=cL`1OUel0;2`/09O5a@1OGel0L71`07=cL`00
Gel0GemO00Sooooo0006ooooo`040:NWY`2GUiL0YjNW09:GN`80BDU900H0GemO05nGU`25QHD0YjNW
0:k5a@2WYjL209O5a@040:NWY`1OUiL0Lg=c07:>SP80GemO01H0Lg=c08F5Q@1OUel0BDU9031kG`1O
Uel0UiMO002GU`1OUiL0QHF505nGG`1YQFT0GiMO08F5Q@1OUiL0YjNW09NGU`1OUlD0QHF509JFUP2G
aLD0][Jf0P25QHD00`1cLg<0GiNG07:>SP0405nGU`0309O5a@00UiL0LXjU0080YjNW00<0GlG505nG
a@2WYjL0102WYjL205o5a@0709NGa@1OaLD0NlG50:NWY`1OaLD0GiNG05nGa@020:NWY`0609nf]P25
QHD0YjNW05nGa@1OUiL0UiNG1@1OUiL305mOG`0501I6AP00B@00;2`/000/001900000P0/;2`01@0F
;1H002`0001OG`35aLD0o?cl00H0;2`/00H002`00000;02GUiL0000002DF0000;0040000000@02`/
;00F5R`002`002`/;000;000000/000/000/00005QH/00000000;000;0000000000/000002`001H/
5P<0000000<0;2`/00000000;0000P0000000`00;00000000000000300000003000/000000000000
00l0000000<002`00000000000000`0000000`0/;2`0000000000006000000030000;00000000000
00T0000000<002`002`0000002`01@0000001@00;000000/0000000F5P00000/0080000000H0;2`/
02`0000/0000000/02`0000002`200000005000/000/;2`05P0F00000000;0000P0002`0500/;2`0
;00000005P000000000/02`0000002`00000000/000/0000000/00000000;000;2`/000/000002`0
0000000F00000000;2`/0P1OUiL03@1cLg<0GemO07QhN019BDT0UenG07=cL`0/;2`0GenG05mOG`19
BDT0aLFG05nGU`1OGel02?ooool000Kooooo0200SXib06UYJ@2GUc00KG]O06V5J@00Gel0<7]k05nG
[P23Wil0Ujk50:nj^P2OWil0Ng]k07alO02OWil0Ph>308j>LP1OGel0Gg]O05mk<01ONel0Gel`05mO
G`0`Gc00KHUO05nG<01OGel0JHEY08j>LP1YQFT0GemO07>1L`80GiMO02T0<5mO06UYJ@1OUg/0GiNG
0;Jf]P2AZj/0Pinf09n3W`1k[YL0NiNG09NGU`1kNg/0Xj>S07^GU`1OUiL0YjNW09nf]P1O[Zh0NiN^
06f^U`1OUlD0NiN^08>f]P2OWkH0Njk505n^[P1][Zh0WinO08>OW`1OUjh0PinO07^GU`2OWil0KJ>S
09nOW`2G[Zh0WinO07_5a@2O]Yl0YjNW09Vn_P0209nf]P0608>OW`1kUiL0NiNG07^^U`1oVi/0NiNG
0`1OUiL01P1YQHD0JFUY03ETI00UL5@0031D03/k>`<0;2`/01@05R`F06>LN03=h/d0l?3X07URAP00
5P005QH/02`/;00F5R405R`F000/000U000001HF02`/;00F;1H02aHQ02`/;000;000;00000005P80
5P0F01P05R4F01HF000/000001H001HF001<C300;1HF00/02`005P005P0001H05P0F00005P0F000/
000;5P0001H0000000005QH001H000005P0F5QH02`00000F000F00040000000400/F0000000001H0
0000008001HF00@001H0000;00005P00000F100000001P002`0001H0000000005P00000F000F00<0
000000L001H00000000000000000000F0000000000/000D0000000D001H00000000000000000000F
000200000004000F000000/00000000F008000000P0001H03`002`/000000000000F5P000000000F
000001H000/00000000001H001H00000000001H05P00000;000201H0000?000F000F5QH00000000F
0000000001HF01H000005QH0000001HF000000005P/;01H000005QH05P0F0080000F00X0000/0000
000;00/05P0001H/5P005P0002`000005P0000002aH;0P0001H03`0F;1H05TI604IRHP1ONi80<65Q
032GN`1kTY80WkJf04I6AP19BDT0Gg]O01h^2`25QI`0TZjG031OG`08ooooo`001_ooool03P2GG`00
UiMO05mOG`1kNel0UemO08F5Q@1OUiL0UiO50:NWY`35aLD0UIFE07=cL`1OUiL0Lg=c0P2GUiL00`19
BDT0<5mO05mOG`0205mOG`08001OG`19BDT0Gel005mkG`1OGel0GiMO05mOG`1cLg<205nGG`0G05mk
G`1OUel0GemO07=cL`2GUel0GiO505nGU`1OUel0PinO05nGa@1OUiL0YjNW05nGa@2GUiL0UlG509JF
UP2GUiL0YjNW09NGU`2WYjL0GiNG05nGa@23WkH0102GaLD01@1OaLD0UiNG08>OW`2WYjL009NG0080
GiNG00@0UiNG05nGU`1kUiL0YjNW0P1OUiL01P1OaLD0GiO50;Jf]P1OUiL0YjNW09O5a@80GiNG00D0
UiNG0:NWY`1kUjh0UiNG08F5Q@0205nGU`0405mOU`00GiL0GiN^001OU`<0GemO0P0/;2`04P0k>c/0
aLG50>o_k`1OGel0;2`/000/000/;2`002`001HF;00/000002`002`/;000;000000/000/000F01H0
B@000000;08002`00P0002`04@00;000;2`/000000000000;00002`/;000;00001H002`/;0000000
;2`/0000000/00000000000F5P000000;0000080000000@002`0000000005P00;0000`0000000`00
;00000000000000300000008000/000002`0000000000000;000;00000000000;0080000000309NG
G`000000000000H0000000D0000F0000000002`002`002`000020000000300005P000000000000L0
00000100;000000/00000000;000000F000/;2`0;0000000000/;2`0;0000000000F000002`002`0
0000000002`00P0000000`0F5R`000000000;002000/000500000000;00001H002`00000;0001@00
00001P0002`0;000000/000002`002`002`/;080000000@0000/00000000;00000000P0002`04P00
5QH000000000000/;2`0000002`0000002`0ATIR05mOU`00Gel0;2`/0:NWY`2GaLD0UiNG051@D000
Gel0UiNG05mOG`Sooooo0006ooooo`0609NGG`2GGel0UiNG07:>SP2WYjL0UiO50P2WYjL01@2f][H0
QHF508>OW`1OUiL0UiNG0080GiNG00H0Lg=c05nGG`1OGel005mO05mOG`1OUel205mOG`0504U9B@1k
Nc00GemO09MOG`1OGel00P1OUel03@1cLg<0JHEY07=cL`1OUel0UiMO09NGU`1OUiL0QHF505nGU`1k
[/D0UlG508F5Q@2WYjL00P1OUiL00`2WYjL0Gg^G09NGU`0309NGU`80YjNW00`0[jn_09O5a@2WYjL0
][Jf09NGa@1OUiL0YjNW07^GU`1OUlD0GiNG09O5U`2GUiL205o5a@0809JFUP2WYjL0UiNG0:NWY`1O
UiL0GiO505nGU`1kUiL205nGU`0505nGa@1OaLD0UiNG0:NWY`1kUiL01`1OUiL02@00UiL0GiNG07=c
L`1cLg<0GemO04U9B@27QhL0ono_0<G5U`0202`/;00602`000190000B@0001H/5P0002`000000`00
;0030000008002`000T0;2`/0000000/000002`00000000/000002`00000000/;2`00P00;00202`0
00<0000000H002`000000000;0000000000/000/00030000000>000/0000000000000000000/0000
000001HF5P00;000;2`/0000000/000000000000;0005P0600000003000F0000;000000000<00000
00<0BDU90000000000004@0000000`00;0000000000000030000000:000/000/00000000000/0000
01H0000/02`00000;000;000000/00@0000000d002`002`000000000000000005P0/;2`002`00000
000/;2`0000/000000005P0000000080;00000T002`00000;00000005QH/000/00000000000/0000
000/;2`00P000000100001H00000000/0000;00300000004000/000002`0000002`/;080000000@0
;00001H05P1OGel0GiNG0P19BDT01P1OaIL0GemO08^WR`00Gel0YjNW05mOG`Sooooo0006ooooo`05
09MO002GUel0UiNG0:NWY`35aLD00P2WYjL01035UiL0Uel005nGG`1YQFT409NGU`80GiMO0P1OGel0
1`00Gel0Lg=c05mOG`1OUel0Gel005mkG`1OGel01P1OUel02025QHD0GemO07=cL`1cLg<0YjNW09NG
U`1OUiL0PkJf0P2GUiL01@2WYjL0GiNG05nGU`1OUiL0NiMk0080GiNG00L0UiNG08F5Q@2GaLD0UiNG
05nG[P2f][H0YjNW00<0GlG500T0UlG50:NWY`1OUiL0YjNW05nGa@1OUiL0YjNW05nGU`1kUiL00P1O
UiL03P2GUiL0YjNW09NGU`1OaLD0NiNG09NGU`1OUiL0GlFG09NGU`1OUiL0GlG505nGU`25QHD0GiO5
0P1OUiL01P1OUlD0GiNG05mkU`1OUiL0GenG07=cL`80GemO00@005mO0:k5fP3oklD0;2`/0P00;000
100/;2`002`0000/001D<4`202`0000=0000000/;2`002`002`/;0000000;0000000;00/000002`0
0000000/00005QH002`000020000;00F02`/;000;0000000000F5P000000;000000/000/00000000
000/000F000000000000;00/00000000000/000000005QHF00000000;000000002`00080000000<0
01H000000000;0000P0000000`00;000;000000F000200000006000/000002`00000000000005P00
000/100000000`19BDT0000000000002000000030000;0000000000000<0000000<0000/00000000
00001@0000000`00;0000000000000050000000>000/000/0000000/0000000002`0;00000000019
BDT0000002`/;000000002`002`0000002`30000000<000F000000000000000/00000000;0000000
;00F01H000000000;000;000000/100000001000;00000000000001OGel20000;00=01HF0000;000
000002`000000000000/0000000F5QH00000000/0000000002`0000000030000;009000/0019BDT0
05mO05o5a@1OGel0C99k0;Jf]P19BDT0GemO00Sooooo0006ooooo`070;Jf]P35Uel0UiNG0;jn_P3_
aNl0][Jf0:NWY`0209MOG`0505mOG`1YJFT0YjNW09NGU`1OUiL00P1OUel02@1OGel0Gg]O05mOG`19
BDT0GemO04U9B@1OGel0Gel005mk<00505nGG`0407=cL`1YQFT0GiMO05nGG`80Lg=c00@0GemO05nG
G`1OUiL0RjNW0P2WYjL03P2GUiL0GiNG05nGU`1OaLD0JHF507=cL`1OaLD0QHF509NGU`1OUlD0UlG5
09nfW`2WYjL0GlG50P1OUlD00`2WYjL0UiO508>O]P0205nGU`0609O5a@1OUiL0UiNG05nGU`1kUiL0
YjNW0P1OUiL01@2GUiL0GiO505nGa@1OUiL0QHF50080GiNG00<0YjNW05nGU`1OUiL00P1OUiL00`1O
aIL0GiNG09NGU`0705nGU`0605mOG`1cLg<0fm>n05mOG`0/;2`0;0000P00;0003P0002`0;2`/01HF
;00/;2`0000/04T0000/000002`002`/;00F0000B@000000;00/0000;2`/0P0002`00`0001H0;000
02`0000202`/;0030000;00000005QH00080;0000P00;0002P0/0000000001H00000;00000000000
;0000000;0000000;00F5P0300000008000/0000000002`000005P000000000/02`00000;0060000
0004000/00000000000001H000D0000000<0BDU9000000000000100000000`00;00000000000000:
000000030000;0000000000000D0000000<0B@0002`000005P000P0000001000;000BDU900000000
02`400000004000/000000000000000F5P<0000000D0;000000/0000;00001HF0000;00500000003
000F5P000000000000<0;000014002`00000;00F5P00000/02`/;00002`0000002`0000000005QHF
02`0000002`000000000;0000000;00000005P02000/0080;2`/00H0Lg=c05nGU`1<E4`0GemO000/
001OGel8ooooo`001_ooool20:NWY`0=0<FGa@2n_[h0][Jf0:NWY`2GaLD0GiMO09MO002GGel0LW93
0:NWY`1OUel0GemO001OG`0205mOG`0G05AD9@00Uel0GemO05mOG`19BDT0GemO05nGG`1OGel0GiMO
04U9B@1OUel0UiMO07=cL`2GGel0GiMO07=cL`25QHD0GiMO07=cL`1OUiL0Lg=c05nGU`1OUjh00P2G
aLD305nGU`80QHF500L0GiNG07=cL`1OUiL0QHF505nGU`25QHD0NiNG0080GiNG00L0GlG509O5a@2G
aLD0GlG507^GU`1OUlD0YjNW00<0GiNG00H0GiO505nGU`1OUiL0GiO505nGU`1OUlD205nGU`0505nG
[P1OUiL0GiNG05nGU`1OUlD00P1OUiL00`1OUjh0GiNG07=cL`0405nGU`0=07^GU`1OUlD0UiNG09NG
U`1OUiL0GiMO0<G5k`3QhN40GiMO001OG`19BDT0;2`/000/000202`/;00901H/5P00;000B@0002`0
0000;000;2`/000/000F01H000000080;00000H0000/02`00000;0005P0002`00000;00200000006
02`00000;0005P000000000/0000000/0P00;000300002`000000000000/;2`0000002`/;00/0000
000001H/5P00000002`002`/;0<0000000D001HF0000;000;0000000000/000200000003000F0000
000000000080000000<002`00000000000003`0000000`00;00000000000000=00000004000/0000
00000000000/0080000000T0;2`/000000000000000002`000005P000000000/000002`00P000000
1P0/;2`05P0002`000000000;2`/00000080;2`/00<001HF0000000000000P00000202`00005000/
000/000002`00000;00004T00P0000001000;000000/000000000002000/00030000;0000000000F
00H0000000<05P00000/000/00000`0/;2`01@00Gel0<4aR05nGa@1OGel005mO00Sooooo0006oooo
o`<0aLG501L0_[jn09NGU`1OGel0BDU905mO0019BDT0Uel008FLQ@2WYjL0QHF505nGG`1OGel005mO
07=cL`00Nc00GemO001OG`1OUel005mO05mOG`1cLg<0Gel`001O000305mOG`80GiMO00d0Ng]O05mO
G`1cLg<0GemO05nGG`1OGel0GiMO002GU`1k[Zh0UiNG0:NWY`1OUiL0YjNW0080GiNG00T0Gg^G05nG
G`25QHD0UiNG07=cL`1OUiL0UiNG07^GU`25QHD00`1OUlD0102WYjL0GiNG08>O]P1OaLD605nGU`03
05nGa@1OUiL0GiNG00<0GiNG00D0GiN^05nGU`1OUiL0GenG05mOG`0205nGU`0305mkU`1OUiL0GiNG
00<0GiNG00<0UiNG05n^a@1OUlD00`2WYjL0101OUlD0UlG50:NW[P00GiL3001OG`0;02`/;0190000
;2`/01H/5P00;000000/04T0000/0000000/000/000U00001000;00202`0000F000F5P00;000;000
000/000002`002`002`/;0005QH0000002`0000/;2`0;000000/0000000001HF000/000/000002`0
02`000000000;00000005P<0000000`0000/00000000000001H0000/0000000002`00000000/0000
000/0000000/;2`2000000030000;0000000000000l0000000D05QHF00000000000000000000;00:
0000000702`00000;00000000000000002`00000000F00040000000402`00000;0005P000000;080
00000P00;0000`00000001HF0000;0030000000302`0000000005QHF0080000/0`00;0001P000000
01H0000/0000;000000/05mOG`80000000P002`001HF0000;000000/02`00000;000000/000/00<0
00000P00;0003@0/0000000001H0000/000002`002`/;000;000;2`/0000000`AS00Lg=c05nGU`19
BDT02?ooool000Kooooo00`0UlG50:Nn_P35aMX0][Jf0;jn_P2nYh/0Nc1O071D9@2GGc00Ng]O08fK
S@2GUg/207]k<00605A`E01DL2D0GemO05AR?@0U>bD0>c/k0P1OGel02P1ONel0<6T`04QOG`1OGc00
Gg/`031O<01ONel0GemO05mkG`1]REl206V5J@0E05nGG`1ONel0Gg]O05mkN`1YQHD0MI6[08>OW`1O
Njh0LXj>05nGU`1bSXh0GiN^09JFUP1bSXh0GiN^05nGN`1kUiL0PinO07^GU`1gTi<0GiNG0080Gjj^
00D0Njk505n^[P2=SHd0LI^W05nG[P0205nGU`0C08F5Q@1OUiL0JHF503F0SP1OGg/0SHf=07:>SP1O
NiL0<7^G05nG[P18RIL0<9Mk002GN`1ONg/0GiNG031kG`0`UiL0B9NG032GU`0205nGU`0;05nG[P1O
UiL0PinO06fSa@23WkH0UjjG09N^[P2^f^80aLG_0>SXd`1]RJ<00P1OUiL2032GN`0:031kN`0FATH0
>c/k024d8@0F5R`0;2`/01H/5P0/;2`05R`F02DF00805R`F00l0;2`/000/00000000;1HF01H/5P0F
2`0002`001H/5P0F5QH002`0000F000F;1H02aH001H05P0F5QH00P00;0000`0F01H00000000;0002
00000008000F000F5QH05QH000005P0;8AH0000001H/5P0/0002000F000:000000002`0001H00000
000F5QH0000F000F000F000000/F000F0080000F00H00000000F00005P0000/;0000000F00030000
000301HF5P0001H0000000<0000000<0000F000000005P000P0000001`0001H000000000000001H0
01H000002`005P001@0000000`0000/00000000000020000000U000F00000000000F000000005P00
000F000F0000000001H0069GE`005P005QH000005P0U9BD0000/01HF000;2`/0000F000F00000000
;00001HF0000;0002`0002`/;00F5QH05R`F000F000F5QH001HF000Q00005P005QH/000/00005P00
000F01H05P020000000302`0000001H0000/0080000F00d05P00000;5P005P0001HF01H0000F5P00
5QH/000F00002`/001H000005P0000005QH/0080000000@08AHF02`/;013@d<09EAD2?ooool000Ko
oooo00d0UiO509O5a@35UlD0UiN^0>nGG`2GGel0aING05mOG`2GG`00L`0005mkG`1OGel0Lg=c0080
UiMO0140Gel005nGG`1DE5@0Gel002`/;01OG`00;2`/04U9B@00G`009EAD04U9B@00G`00BDU9001c
0019BDT0GemO05mkG`0205nGG`0K05mOG`00Gel0GemO05mOG`00Gel0NiN^09O5a@2WYjL0GiNG09NG
U`1OGiL0Geo508jUSP25QHD0YjNW08F5Q@1OGiL0GiNG0:NWY`2OWil0UiO50:NWY`25QHD0GiNG05nG
a@2GUiL0Pinf0080GiNG00@009NG002GG`1OUiL009NG0P00Gel06`1OGiL0GemO001OG`00Gel0GemO
06V5Q@1OGiL0GiNG05mOG`1OUiL009MO05nGU`0`NiL0GenG002GU`1OUiL0GlFG05nGU`2GUiL0Winf
09O5a@2WYjL0GiO50<G5k`3oonl0UlG507^GU`0205nGU`80GiO500h0GiNG05nGG`1OUel005mO04U9
B@00;000B@0002`/;0190000;2`/000/0019000002`004T000D0;00000H0;2`/000/000/;2`0000/
02`0000F00020000;005000/000/;2`0;00002`0000000000P0/00000`0/;2`0000/02`000020000
000302`/;000000002`000<0000000T001H0000/00000000000002`/;0000000;2`/00000000;000
0P0000001@00;000000/00000000000002`00080000000D002`00000000000000000000F00070000
0004000/0000000002`00000;080000000<001H0000000000000100000000`005P0000000000;003
0000000@000/000F5P00000002`00000000002`00000000002`000000000;0000000000/000/0000
000002`0000F00<000000P0002`00`0000005P0002`/;00202`/;0090000;00/000002`001HF5P00
0000;2`/0000000/;2`0;000008002`000<0;1HF000/000/;2`00P00;0000`0/;2`0000/01H/5P03
000000080000;00/0000000002`000000000;2`/00000000;00200000004000F000002`0000/04U9
B@Sooooo0006ooooo`0B0=CDe02GaLD0UlG50;Jf]P35Uel0kiMO09MO002GGel0UiMO07=cL`1kNc00
UemO05mOG`2GUel0GemO09NG001OG`00GemO0P00Gel03P1OG`0005mO00190019BDT0<5mO05mOG`1O
G`00BDU905mO001OUel0GemO05A`E01OGel005mO101OGel00`1cLg<0PinO05nGa@0305nGa@80GiNG
00P0Ng^G09O5a@2GUiL0GiNG07=cL`1OGel0GiMO07^GU`80YjNW00H0GiNG09NGU`2WYjL0UiNG05nG
[P00Gel205nGU`05001OG`00GiL009MO031OG`00Uel00P1OGel01P00Uel005mO05mOG`1OGg/0QHF5
001OG`80GemO00H0GenG001OG`1OUg/0GiNG002GU`00Uel305nGU`0909nO]P2GUiL0GiNG0>ook`3o
knl0YjNW09NGU`1kUlD0GiO500<0GiNG00H0GenG05nGU`00UiL005mk001O00190002000/000:02`/
;000;0005R`F02`000190000000/02`0000002`002`001H/5P8002`000/0;2`/00000000;0000000
03/000000000;00002`/;000;000B@00000/00020000000@02`000000000;000000/000/000001H0
000/0000000002`002`/;00/0000000000005P000000000/000/0080000000<0;00000005P0/0000
3@0000000`005P0002`000000007000000060000;000;000000002`000009@00BDU91@0000000`00
5P000000000000040000000500005P00000000000000000/00000P000000300F5R`002`00000;00/
0000000002`0000000005P0F00000000;000000002`00080000/00D002`002`0000002`0;0000000
;00202`/;00901H/5P000000;2`/00000000;000001O07=cL`0/;2`05QH000<0000000@0;000000/
0000000001HF0P00000202`/;080000/00/001HF00000000000002`002`00000000002`000000000
;000000/04U9B@08ooooo`001_ooool01@35aLD0UlG509O5a@2WYkh0UemO00<0aIMO0140aLFG09NG
U`2GGel0UemO05mO002GGel0QHF509MOG`1OG`00Gel`04U9B@1OGel005mO05l0G`0/;2`0BDU902ED
E00504U9B@03001OG`1DE5@0GemO00<0GemO00l009MO05nGG`1OUel0GemO09NGa@1OUlD0UiNG0:NW
Y`1OGiL0GiNG07]kU`2WYjL0GiNG05mOG`1cLg<0101OUiL0402WYjL0GiNG09NGa@2WYjL0GenG05mk
U`00UiL005nG07=cL`00GiL005mO002GU`00NiL0GenG07=cL`1OUel305mOU`0G05mkU`1OGel005mO
001OU`1OUiL005mO05nGG`1cLg<0GiMO001OU`1OUiL0GiO505o5U`2GUiL0GiN^09NGa@3_knl0aLG5
0<FGU`2GaLD0GlG509nOW`1OUiL00P1OUlD405nGU`03032GU`1OGiL0GemO00<0;2`/00<002`001HF
;00/00000P00;000100002`0;2`/000000005QH2000/0080;2`/00<0B@000000;00001H00`0/;2`0
1P00;000;000000/000F01H0000002`/;08002`00P0/00001@0F;1H0000/0000000/000002`00080
;00000T0000F0000000002`0000/00000000;000000/01HF000000000P00;002000000030000;000
01H0000000<0000000@0;2`/00000000;000000F0P0000001`00;00000000000000/0000000F000/
000002`00P0000001`0/0000000/000000000000000/00000000;0000`0000001000;00000000000
000002`20000000800005P000000000000000000;000000/02`/;00F5QH30000000;0000;0000000
02`00000;00/;2`0;0000000;00/;2`000000000;00001H00`0000001@0/000002`00000000F01H0
00000080;2`/0`0000002`0002`05QH/0000;000;000;00002`/;00/000002`001H000000000;000
008002`000<000000000;00F00000P000000200/0000000/00000000;00000000000;000;00005mO
2?ooool000Kooooo01@0][Jf09NGa@2GaLD0Njj^09NGU`35Gel0kel00<EOG`35aIL0YjNW0:jGG`2G
Gel0Gel005mOG`19BDT0GemO05mO001kGel0QHF507=cL`80GemO00`005l0001OG`0UE5@0BDU9001O
G`1OGel0GiMO02`/;01OGel0<5mO05mOG`1OG`0204U9B@0405nGG`1OGel0GenG06V5Q@80GiNG01P0
UlG505nGa@1OUiL0GenG07^G[P2WYjL0UiNG05mOU`1OUiL0GiMO07=cL`1YQHD0GiNG0:NWY`1OUlD0
UiNG08F5Q@1cLg<0JFV507=cL`1OGel005mO05mOG`19BDT205nGG`0407=cL`1OUel0GemO05mOG`80
GiNG00X0<9NG05nGU`00Gel0GemO05nGG`1OUiL005mO031OG`00UiL0Lg=c0`1OUiL02P1OaLD0GiO5
09NGa@35aNl0ooo_09NGa@2GaLD0UiNG07^Ga@2GUiL205nGU`0608F5Q@1OUiL0GiNG05nGU`1ONiL0
09NG0`00Gel02P0/;2`002`002`/;00/;2`0B@00000/000/000002`00000000F000200000006000/
000/;2`0000002`000000000;2`/1000;0001@0002`05P00000/0000000002`00080000000D0000/
01HF000002`0000/02`00003000/0003000F0000000002`000D0000000<0000/02`0000000000P00
00001@00;000000002`0000002`002`00080000000@0;0000000000F5P0002`00P0000002P00;000
0000000000005P00;2`/000/00000000;0000000;00/000300000003000/0000000002`000D00000
00@0;0000000;00000005P000P0000001P0002`0000002`0000002`00000001OG`80;2`/00@0000/
0000000000005QH00`0002`01@0/;2`0000002`0000F5QH000000080;00000D002`000000000;000
01HF0000000202`/;080000000/0;2`/000/000002`0000/000/000/;2`00000000/000002`001HF
000/0002000000040000;00/00000000000F5P8002`00`0000001@0/000001H00000000002`0BDU9
00Sooooo0006ooooo`060;Jf]P2GaLD0GiO509:^``1OGel0Uel00P3_Uel00`35aLD0klG50:jBN`02
09NGG`0<04U9B@1OGel0GemO05mO001DE5@0GemO09NGG`1cLg<005mO05mO0019BDT09EAD0`19BDT2
05mOG`0B04U9B@1DE5@0GemO001OG`00L`00BDU905mOG`1cLg<0GemO05nGU`1OUlD0][Jf09O5a@25
QHD0GiNG09NGa@1OUiL0YjNW0P1OUiL0201cLg<009O505nGU`1OUiL0GiMO05nGU`1OUel0GemO0P1c
Lg<205mOG`0507=cL`1OUel0GemO05mOG`1cLg<00P1OUel305mOG`80Lg=c00H0Ng]O05nGG`1OUel0
GemO002GG`1OUiL207=cL`0305nGG`1OUiL0GiO500<0GiO500L0Pinf0<G_k`3lo?`0YjNW09NGa@1O
UlD0][Jf0080YjNW00<0GiNG0:NWY`1OUlD00P1OUiL02P1OUlD0GiNG05nGU`00GiL0GiNG05mOG`00
Gel0;2`/01HF;019000202`/;08002`000@0;00001H05P0/;2`0;0000P00;0004P0/;2`0000/01H0
5P00;000000/000/000/;2`0000004T0000F5P0002`00000000/;2`0;0000000;000000001H002`/
;08000000P0002`01P00;000000F02`/;00/000000000000;080000000X0000F02`0000000000000
0000;000;000000/000F0000000002`00P0000000`0002`000000000000400000005000/00000000
000000005P1OGel01@00000010005P0000000000000002`30000000<00005P0000000000000/000/
000000000000;0005P0002`00000000/0000000/0P00000020005P0000000000;00002`002`00000
000/00005R`F0P00;0001P0/0000000002`/;0000000000F0000008002`000h0000002`/;00/;2`0
5P0F00000000;000000/00000000;000000/0000000F0000000/00000080000/00H002`002`/;00/
000002`00000000/00020000;00<02`000005QH0000002`000000000000/000/00000000000F02`0
0000000005mO2?ooool000Kooooo00L0aLG_0:NWY`2GaLD0C:j^05mOG`19BDT0aIMO0080kiMO00D0
klFG0>;5[P2GGel0UemO08F5Q@0205mOG`0305mO001DE5@0GemO00<0GemO00L0BDU9002GG`0k>c/0
GemO0000B@1OG`00GiMO0080GemO00`007]O04U9B@1OGel005mO05mOG`00Gel0BDU905mOG`1kTY80
GiNG09NGU`2GaLD209NGU`0309NGa@23WkH0QHF500<0GiNG00T0GiO508F5Q@1bSXh0GiNG09NGU`25
QHD0UiNG05nGG`1OGel00P1OUel205mOG`0405nGG`1cLg<0GiMO05ADE080GiMO0`1OGel0201OUel0
Ng/`07=cL`1OUiL0GiMO05mOG`1cLg<0UiNG0P1OUiL0201OGel0QHF505nGU`1OUiL0GiO507^^[P35
aNl0aLG50`2GaLD02`2WYjL0UiO509NGa@2WYjL0GiO505nGU`1OaLD0UiNG05nGU`1kUjh0GiNG0080
GenG00D005nG05mOG`19BDT0;2`/000/000202`/;00C04T00000;000;2`/01H/5P190000000/02`0
0000;000;2`/02`000000000;2`/02`0000002`0000002`00000;00001HF000/000202`/;080;000
00<0000/01H/5P0000000P0000002`0002`00000000/00005P0002`000000000;000000002`00000
000002`00080000000@0;2`/0000000/;2`0;0001@0000001P19BDT0;2`/02`0000001H00000000/
00@0000000@05QHF00000000000002`00P0000001P0002`00000000/000002`0000002`/;0<00000
00<0000/000/000000000`000000300F00000000000000000000;000000/000000005P0F02`/;000
0000000/02`00080000/00`00000000/0000;00002`000000000;000;2`/000F0000;000;000000/
000002`20000000601H/5P00000000000000;00/000002`00P0002`50000000;02`/;0000000000/
000/000/;2`002`002`000000000000/0000000/00000`0000001P00;000000000000000;0000000
04U9B@Sooooo0006ooooo`0<08^WY`1DWil0Ujk504=bSP00Gel0E71`05mOG`3CYjL0dkjn0;jnY`3J
aJ<0[YMO0P2GUel02025JFT0NemO05mOG`1OGel0Gel`04I6AP0UE5@0GiMO0P1DE5@00`1?Cdl0E5AD
031O<00205ADE00?05mOG`1DL5@0FVQ2031kG`1DE5@0Gg]O05mOG`1DL5@0Gg/`05ADE01=LWh0Gg^G
07^^[P2W_]<0WkJf0080Njk500`0UJ>_05nG[P1OUlD0GiN^05mkU`23Wil0GiN^07:>Y@25QFT0Pin3
05ADE01kNc0207^GG`1B079bI01OGel0Gg]O05mkG`1OUc00Lg=c09NGG`1kREl0JHEY05nGG`1OGel0
Gi:B04akN`1YQHD0O7al08F5Q@2OWil0SZF>07alO01OUel0Ng]O07nWS@1YQFT0JFV507^^[P1kUjh0
JHF505nGU`31f]H0[l_309N^a@1O[/D0Njk508^W_P2G[Zh0Gj?508>f]P2OWkH0PkJf07_5a@23Wil0
WinO032GU`1aVjL0PinO05nGU`1OUjh0<7^G07=cL`1OUg/0E5AD04I6AP0k5QH0;2`/03/F5P0F;1H0
;2`/00/Q5P00;000;2`/01H/5P0/;2`05R`F02DF00005QH05P0001H05P005P005QHF0000000F01H0
2`0;0000000U5P0002`001H05P00;0005P0000//2`0/5QH09C/U01HF0080000001@002`001H;5P00
;0005P0000005P000000000F0000000;2`/05QH0000F5P0000005QHF0000000001H02`/000005P00
5P00000F000F0080000001D001H000/;000001H00000000F00000000000F0000000000/0000F000F
000F01H001H001H05P0F00002`0000005P000000000F0000000F5QH00P0000002P005P0000000000
000F5P005P00000F000;00/001H000005P005QH3000F000R000Q2`0000005P0F01HF000001H05P00
01HF5P0;000001H00000;00F;1H05QH001HF5P0F;1H000/;000F000001H0000001HF5P0F5P005P00
01HQ2`005P005P0000005P0F01H05R`F000F000F5QH000/;01H0000001H05P0001HF;08001HF00T0
2`/Q01HF;0005P00000001H000005P005QH001HF2`0F;1H00`005P001P0001H05P0000/;5P005QH0
000002EDE0Sooooo0006ooooo`80GiNG0140YjNW001OG`1OUel0GiNG05nGa@2WYjL0aLG50<FGU`2G
Uel0klFG0<FGG`2GUiL0UiMO05mOG`0/;2`0NemO05mO000204U9B@0505mOG`1OUel0GemO05ADE01O
Gel00P1OG`0405mOG`0=02`/;01OGel0Gel004U9B@1OGel0GiMO001OG`1OGel0GiO50:NWY`1OaIL0
GiO505o5a@020:NWY`0709NGU`25QHD0YjNW05nGa@2GUlD0UlG503YYJ@0405nGG`0A08F5Q@1OGel0
L5AD05mOG`25QHD0Lg=c05nGG`1cLg<0GiMO07^GG`1OUel0QHF509NGG`2WYjL0GiNG08F5Q@2>SXh0
0`1OUel208F5Q@0;09NGU`23Wil0UiMO09NGG`2GUiL0Lg=c04U9B@2WYjL0h^;J05nGU`1OaLD00P1O
UlD00`2GUiL0UlG508>O]P0205nGa@070:NWY`1OUlD0YjNW09NGU`2WYjL0Pinf0:NWY`0205nGU`04
05nGa@1OUiL0GiNG05mkU`8005mO100/;2`02@0F5P00;2`/000/0000;000000/0000000002`00000
0000;002000/000702`00000;00002`001H/5P00000002`000000002000/000A02`/;00/5QH002`0
0000;00/;2`0000/0000000/000001H002`/;000000002`00000000/;2`00000000F000/00000P00
000202`/;0H0000000@0000/0000000000005QHF0P0000000`0002`002`00000;0050000000302`0
00000000000000@0000000H002`000000000;00001H002`0000002`200000007000/000002`0000F
0000000002`000000000;0020000000401HF5P00000002`0000/0080000000/0000/01HF00000000
000/00000000;000;2`/0000;00F5P00;0000000;0040000000501H05P00;000000/0000000002`0
0`00;0002@0F0000000/0000;00/000002`00000;00000005P0F02`/;00200000004000/00000000
;2`/01H05P80000000<0;2`/000/000002`00P0000000`00;000000004U9B@08ooooo`001_ooool0
101OUlD0GiNG05nGU`0`GiL205nGU`0J05o5U`2WYjL0YjNW0;Jf]P35Ng/0aLFG0>nGG`35Uel0UiMO
04U9B@1OGel0HT``09MOG`0/;2`0BDU905mOG`19BDT0GiMO05mOG`0/;2`007<004U9B@1OUel0GemO
001OG`1ONel205mO000805mOG`1OG`00Gel004U9B@1OGel0<5l004U9B@2GUlD205nGa@80YjNW01<0
PkJO09NGU`1OUlD0GlG50:NWY`2GUiL0GemO06UYJ@1OGel0GiNG09O5a@2WYjL0UiNG05nGG`0`Nc00
GemO05nGU`25QHD0GiNG0080UiNG00@0SXj>05mOG`1OUel0YjNW0`1OUiL03`1bSXh0UiNG05nGG`1O
Uel0GiNG05nGG`1OUiL0WinO08F5Q@2GUel0GiL005mO001OGel0kno_0:oRfP020:NWY`0709NGa@2W
YjL0YjNW0:NWY`1kaLD0GiO505nGU`040:NWY`0605nGa@1kUjh0YjNW09NGU`1OUiL0GiO50P1OUiL0
200`UiL005nG07=cL`00Gel0BDU902`/;000;0005QH01000;000100/;2`0;00002D00000;00202`0
00<002`000@0;2`/000000000000;0000P00;0003@0/0000000F00000000;000000/02`/;000;000
;000000F5P00;000000002`0000002`00P0000000`0F5QH0000/000/0003000000030000;0000000
;0000080000000T002`00000000/;2`0000004IRHP000000000/0000000002`01@0000001P0002`0
000002`000000000000F02`000<0000000H002`002`0000001H002`000000000;002000000030000
;00F0000;0000080000001@0;000000/000002`05QHF0000;0000000;2`/02`0000002`0;000000F
00000000000/000/00000000;0000000000001H002`00000008002`000L0000/0000000001H0000/
02`0000/;2`0000/00<0;2`/00X05QH/02`0000002`0000/02`0000002`002`000005P000000;000
0`0000001000;000000F000/000002`2000000060000;000;000000F02`/;00/000005mO2?ooool0
00Kooooo00@0aLG509O5a@2f][H0<9NG0P1OUiL209O5a@0=0:NWY`35UiL0[YMO0<FGG`3_aIL0aLFG
09NGG`1OGel0UemO05ADE01OGel0BDU9001O000202`/;00<05mO0019BDT005mO05mO0000Gel0Gel0
04U9B@1OGel0Gg]O05mOG`1OG`00UiL00`1OGel01@00B@00E5AD001OU`1cLg<0GiNG0080YjNW00/0
UlG507^G[P2GUiL0GiNG09NGU`1OUiL0YjNW09NGG`0`Uel0Lg=c05nGU`0209NGU`050:NWY`2GUiL0
GemO05nGU`1OUlD00P25QHD01P1OUiL0UiNG08f=S@2GUiL0GiO509NGU`<0GiNG00T0O7al09MOG`2G
Uel0GiMO08F5Q@1OGel0GiMO08F5Q@2GUiL00P1OUel0101OGel0oooo0<G_k`2f]Yl209O5a@80YjNW
0100UlG509NGa@1k[/D0GiO505nGU`2WYjL0GlFG05nGU`1OUlD0GiNG08>O]P2WYjL0UiNG0:NWY`1O
aIL009O50P1OUiL01@25QHD0GiNG05mOG`00Gel0BDU9008002`00`0/;2`03P00000002`00000;00F
5R`0;2`/000/000/;2`0;00004T0000000005P0F0000000/0000000/0`0/00002`0001H000000000
000/;2`00000000/000/;2`05P0F02`/;000;000000/008002`000<0000001H0000/000010000000
2@00;00001H00000;00002`0000005mOG`0/;2`00000000/000400000005000/000002`0000001H0
0000;0000`0000001@0002`0000000000000000002`000<0000000D0000/000F0000000002`00000
;00200000009000/000001H000000000000/00000000000/000/00005R`F0080000/00H0;00002`/
;00/0000000/000F000/000202`/;005000/000002`0000001H0000/;2`00P0000001000;0000000
000/000001H40000000702`/;000;000;00002`/;00/000002`00000;0030000000?000F0000;000
000/0000;000000002`0000000005QH002`002`00000000002`00000;00000005QHF0080000000<0
BDU9ooooooooool01_ooool000Kooooo0P35aLD02@2f][H0Njk505nGa@2GaLD0UiO50:NWY`2GaIL0
UiNG0<F^N`020<FGG`050<FGU`35Uel0UiMO0:NWY`1`E5@00P2GGel00`1OG`0005l004U9B@0205mO
000:04U9B@00G`0004T005mOG`1OG`00GemO06UYJ@1OU`00Gel004U9B@80GiMO0`19BDT207=cL`80
YjNW00D0QHF509O5a@2O][H0UlG507=cL`0205nGU`050:NWY`1OGel0JHEY05nGU`2WYjL00P2GUiL0
301OUiL0YjNW07]kN`2WYjL0UlFG05o5U`2GUiL0YjNW09O5U`1bSXh0GiNG05nGG`80UiNG00D0QHF5
09NGU`2=SHd0QHF505mOG`0205nGG`0D09NGG`1OUel0JFUY05nGG`1OGel0Gel00<G_k`2f][H0ooo_
08>3P`2GUiL0GiNG09NGa@2GaNl0][Jf0<G5a@2O][H0UlG50:NWY`2GUiL20:NWY`80UiNG00<0GiN^
09NGU`2WYjL00P2WYjL00`1OUiL0GiO505nGU`0305nGU`05002GG`00Gel005mO01Hk5P0/;2`00P00
;000100/000002`002`/;0005QH302`/;00402`0000002`002`001H/5P8002`000L0;2`/0000;000
02`0000/01H05P0/0000000/008002`000<0;2`/0000000F00000P0002`2000/00070000;0000000
01HF000/0000000002`00000;0020000000300005P00000002`00080000000D002`00000000/0000
5P000000;002000000030000;000;000000000<0000000D002`0000000000000000001HF00020000
00050000;00000000000000000005QH00`0000001`0002`0000000000000;0000000000/00000000
0P0/0002000/0080000000L002`002`/;00000000000000F000002`002`00080000000l0;0000000
000001H002`00000000002`000000000;00/;2`001H002`/;0000000;0000000000002`00P00;000
300001H000000000000002`0000002`/;00000005P000000;000;000000/02`/;0@0000000D002`0
0000000000000000000/000300000003001OGooooooooooo00Kooooo0006ooooo`0>0<G5a@2f][H0
aLG50:Nn_P35aLD0UlG509NGa@2f][H0UiNG07=cL`2nYh/0QHF50<FGG`35aIL20<FGG`0909NGG`1k
Gc00GemO05nGG`2GGel0Gel00019001OG`00E5@U0080BDU900L0Gel004U9B@1OGel0GiL005mk<01O
G`00GiMO0080Gel000P0GiMO05mOG`19BDT0E5AD05nGU`1OUel0UlG509NGU`80GiNG00D0WkJf07=c
L`2WYjL0GiMO05mOG`0209NGU`0@07^GG`2GUiL0QHF505mOG`1OUiL0][Jf05nGU`1OUg/0UlFG09NG
U`2f][H0YjNW09NGU`1OUiL0Gg]k05nGG`80QHF501`0GiMO09NGU`2GUiL0O7al05mOG`2WYjL0Lg=c
05nGG`1OUiL0GiMO05mkG`1OG`00BDU905nGG`35aLD0oooo05mOG`2OWil0GiMO09NGU`2GaLD0YjNW
0;Jf]P2GaLD0Ykjn0:NWY`1OUlD0UiO50`1OUlD00`1OUiL0LZF>05nGU`0209NGU`050:NWY`1OaLD0
GiNG05nG[P1OUlD00P1OUiL01000Gel0GiNG001OG`0k>c/302`/;0040000;000;000;2`/02`F5P80
;2`/0`00;0001P0002`05R`F02`/;000;000000002`00080000000<05P000000000000000`00;000
2@00000001H0000/000002`002`00000000/000002`0000F0003000000040000;00/00000000000F
0080;00000H0000002`0000/0000000/00000000;007000000030000;0000000;00000<0000001l0
000F000/000000000000000/000002`002`001H000000000000/0000000002`0000002`/;00001H0
000002`/;00/0000000/000/0000000001H002`00000000002`002`0000002`0;000000F5P0002`0
;0000080000000H0000/000000005P000000000/000/0003000/000301H0000002`0000000<00000
0P00;0000`0F;1H0000/000/0002000000070000;000;000000000000000;00000000000;0020000
000500005P0000000000000/000002`00`00000202`/;00304U9BOoooooooooo00Kooooo0006oooo
o`0F0:NWY`2GaLD0e=CD0:k5a@35aLD0YjNW0>7Qh@2WYjL0GiO505mOG`2BUi80UiMO09NGU`35Uel0
aLEO0<FGG`2GUel0[ZiS04T0001OGel0GiMO09MO0080BDU900T09E@U04U9B@0/;2`0BDU905mOG`1O
G`00GemO031OG`0/;2`00P1OGel01`19BDT0Gel005mOG`1OG`009E@U001OG`1cLg<00P1OGel03025
QHD0Lg=c03YYJ@2WYjL0QHF507=cL`1OUel0GemO07=cL`1ONg/0GiNG05mOG`80GiNG00L0UlFG08F5
Q@1kUel0UlFG0:NWY`2f][H0UiNG0080YjNW00<0Ng]k05mOG`2GUiL00P25QHD20:NWY`0508>OP`25
QHD0UiNG05o5U`1OUiL00P1OUel0201kNel0Gel005mO0035kol0hN7Q09NGG`25QHD0GiN^0P2GaLD0
1P2WYjL0UiO509O5a@2GaLD0YjNW09NGa@80UlG500D0GlG50:NWY`1OaIL0GiNG09nO]P040:NWY`0:
05nGa@1OUiL0GiN^05nGU`2GUiL0QHF505nGU`1OGiL0Lg=c05ADE0@0;2`/00L002`00000;00F;1H0
;2`/000/000/;2`002`00080000000d05QH002`/;00/;2`0;2`/000/001cLg<00000000F000/;2`0
;00002`/;0000000;0000080000000P002`00000000000000000000/000002`05R`F02`/;0800000
00@002`002`00000;00001H00P0/0002000/000600000000;000000/01H000000000000/0P000000
1`0002`00000000000000000;0000000000002`00P000000100001H000000000000/;2`200000006
02`0000001H00000000/000002`002`00P0000000`0F5QH0000000000002000/0080000000<05P00
02`/;00/00000P00;0002`0/0000000/02`/;0000000000/000/000/0000000/0000000F5QH00000
0080000/0P00;002000000030000;00/000002`000<0000000H0;2`/01HF5P00;000;2`/0000000/
;2`20000;005000F5P00;000000/0000000/00000P00;0000`00000002`00000;0020000000602`/
;0000000000F0000000/;2`005mO2?ooool000Kooooo00/0GiO509NGa@35aNl0YjNn0<G5a@1OUlD0
UlG50;Jf]P1OUiL005mO08>OP`0209NGG`070<FGU`2GUel0aIMO09NGG`2LW9`0BDU902`/;00209MO
G`80Gel000D0BDU90019001OG`00GemO04U9B@0205mOG`0505A`E019BDT0BDU904U9B@1OGel00P19
BDT07`00G`00ATI60:NWY`1OUel0UiNG0;Jf]P1cLg<0][Jf08FLW02WYjL0UlG509NGU`1OUiL0UiNG
05mOG`2>SXh0YjNW09NGU`1OUel0GiNG09NGU`1OUiL0RjN;0:NWY`1OUiL0YjNW09NGU`2WYjL0UiNG
07^^N`2GUel00P2WYjL01P2f][H0YjNW0:NWY`2=SHd0GiNG0:NWY`80UiNG00L0GiMO05mOG`1OGel0
Gel005nGU`35aLD0klFG0080GemO00<0SXj>0:NWY`2WYjL00P2GUlD00`2WYjL0GiO509N^a@060:NW
Y`0305nGU`1kUiL0GiO500@0YjNW00@0GlFG08>OW`2GUiL0UiNG0P1OUiL01025QHD009NG031kN`00
Gel202`/;08002`000T0;2`/01HF000/;2`0;2`/000/000/;2`0000/02`000005QH00P0/;2`0200/
0000000/02`/;00002`0000002`/;000;000;0000P00;0000`0002`05P0F02`/;0020000000<02`/
;00/0000000000005P0/;2`002`002`0000002`0;000000/000F5P00000/0P0000001@0/;2`00000
00000000000001HF00<0000000@002`00000000000005QH01P00000010005P0000000000000/0003
0000000301H/5P00000000000080000000`002`002`0000F0000000/02`00000;000000002`00000
;00001HF00000000;00202`/;080000/00<001HF0000000000000P00;0000`0/;2`0000001HF5P02
0000;008000/00000000000/000/000/5QH0;2`/02`00000;003000000040000;0005QH00000000/
0080000/00L002`002`/;00F5P00;000000/000/0000000/00@0000000<002`00000000000000P00
0000100F00000000000/0019BDT8ooooo`001_ooool05`1OUiL0GiN^0:Nn_P2b_LT0[/G50:Nn_P2W
YjL0Gjk507^GU`23Wh<0GY63031OG`25QFT0]Yn309NGN`25QHD0aJik095kB02NWYh0Ph=D05l`000k
>c/0Ug/`0080Ng]O02P0<5l005mO<00UE2D0E5AD02EDE01DE5@0FUYJ05mOG`1OGc009EAD05mkG`19
BDT0E5@U05iNGP1JJ7H0Rh]K07]kN`0`Gel0YkjW05nGU`1ONc00JG9b08>OW`23]Yl0NjjG07]kN`1Y
JFT0GUiN05YfQ01<Ng/0YjNW07:>SP25QHD0Gjik08F5Q@1kRG/0JHF508>3P`2FUYH0NiNG0P2O][H0
6P28UXP0GiMk07=cL`23Wh<0UYJF05mkG`1bSXh0UXR805mkG`1kUg/0LXjU07:>LP1DL5@0Gel`06f9
B02B[ZL0aM[J0<_;P000J@00Gg]O05mkN`25QHD0UYJF07^^a@2O][H0Ujj^0P2OWkH06P2AWj/0NiO5
09nO]P1O[Zh0Pinf07^Ga@1O[Zh0GlF^07nK/P2WYjL0UiNG07^G[P1k[/D0Ujj^08>O]P1OUjh0NiNG
05nGU`1kUiL0LXj>08>3W`1ONiL0B7^906V5Q@1DE5@0>c/k0P0/;2`201H/5P80;2`/0P0F;1H02`00
;0005QH0024;2`0/;2`05R`F01HF;00F5P00000/01HF5P0;8@009AH0008001HF05/0;2`/01HF000F
5QH02`/Q01H000005QH09AH0000F00005QH0000F000000005P00000F01H/5P005P005QH001HF5P0;
2`/00000000F000F5QH001H001HF000F01H0000F00/000005P000000000F5P005P00000/000F000;
5P/05QHF0000000001H05QH000005P0F5P00000;01HF000F01H002`00000000F01H0000001HQ2`00
5P005P0F01H000005QH05QHF00005P0F8AH05P000000;00/;2`001H001H0000F01H0000;01HF000/
5QH0000F01H05P0002`0000F00/;5P0001H05P00000000005P005QHF01H05P0;2`/002`000005P00
00005P0F01HF0000;0005QHF01H05P0F0000000F01H0000U00005P0F01HF;0002b405QHF00805QH/
00`0000F0000000F01H02`/;01H0000001H00000000/0000000001H0000;00005P0200000007000F
000000005R`F00/;000001H001H0031OG`08ooooo`001_ooool205nGU`0>09O5a@2W_[h0aLG50;Jf
]P2WYjL0e=CD0:NWY`1OUlD0RjNn05nGG`25QHD0GiNG09NGG`2GaIL20<FGG`0B09MO002GUel0Lg=c
02`/;019BDT0UemO07]kG`2GG`00;2`/05mO000/;2`0GemO05mO001DL5@0Lg=c05nGG`1OGel0Lg=c
0P19BDT0401cLg<0JHEY05mOG`2WYjL0][Jf08F5Q@2WYjL0BDU907QhN02WYjL0GiNG07=cL`19BDT0
GemO0:NWY`23Ph<405mOG`80GiMO00T0LW9b05mOG`00Gel0GiMO0:NWY`1OaIL0GlG505A`L01cLg<0
0P1OUiL01`1cLg<0GiMO05nGU`25QHD0Lg=c05nGU`2GUiL00P2GUel04P19BDT0JHDj0<G_k`3oolD0
GemO07=cL`1OUlD0GiNG07alO02WYjL0GiO509O5a@2GUlD0YjNW09NGa@2OWil0YjNW05o5a@80GiO5
00/0GlG505nGU`2WYjL0PkJf05o5a@2WYjL0GlFG05nGa@2WYjL0GiNG05n^[P0205nGU`0309NGU`1O
UiL0GiNG00<0GiNG00<0GiMO05mOG`19BDT00P0/;2`00`0F5R`002`002`/;00202`/;08002`000<0
;2`/000/0000;0001000;0000`0F5R`0000/02`00004000/000;01H05P0/000002`002`/;000;000
000002`0000k0000000/02`0000000000P0/00004@0002`05QHF02`0000/;2`00000000/000002`0
02`002`/;0005P0002`002`00000;000;000000/00000000000F00@0000000<0;2`/000/00005P00
0P0002`01@0/;2`002`00000000000005QHF00@0000000`0;00002`/;00F5P00;2`/0000B@35aIL0
02`002`0000002`05P00000/000000020000;00;000/000/;2`05QH00000;0000000;0000000;00/
0000000001H0000000000P00;000100/;2`0;00004T0000F5P050000;00602`/;00000005QH/02`0
000002`002`00P0/;2`01P000000000F000/000002`0000002`/;080000000D001HF0000;0000000
02`002`000030000000302`0000/;2`0BDU900Sooooo0006ooooo`0405nGa@2WYjL0UlG50:n_[`80
UlG500`0YjNW0<G5a@2GaLD0GiO509nO]P1OUiL0Lg=c05nGU`00UiL0aLFG0>nGG`35Uel209NGG`0=
05mOG`2GUiL0;2`/09MO001kNel0UiL002`/;019BDT005l005mO0019BDT0E5AD05nGG`0205mOG`80
BDU900H0G`0004U9B@1OGc00BDU908F5Q@2WYjL205nGG`80GemO00@0GiNG08F5Q@2GaIL0YjNW0P1O
UiL01@1YQHD0GemO05mOG`1OGel0YjNW0080Lg=c00X0GiMO07=cL`1cLg<0GiMO05nGU`1OUel0QHF5
07alO02GUiL0QHF50P1OUiL0102GUiL0GiNG06V5Q@2GUiL205nGU`0?09NGG`1OU`00GemO0:j^OP3_
onl0UemO05nGU`2GUiL0GiNG0:NWY`2>SXh0Lg=c05nGU`2GaLD0][Jf0080GiO500L0WinO0:NWY`1O
UlD0GiNG09NGU`2WYjL0UlG50080YjNW00T0GiO509O5a@2WYjL0GiNG0:NWY`2GUiL0GiNG0:NWY`2G
UiL00P1OUiL01`2WYjL0GiNG05nG[P1OUiL0GenG07=cL`1OGel00P19BDT0100F;1H002`002`/;000
02`202`/;004000/000F5QH0;2`/02`000@002`000@09@0002`/;00/;2`0B@000P0/00001P0002`0
5QH0000000000000;0000000;0<002`000T0;2`/000000000000;2`/000/000000005P0F000/0000
00000P0002`200000003000/00005P00;0000080000/0P000000100/000000000000000/;2`20000
000402`0000002`05QH/02`000@0000/00<002`0000F5P0002`00`0/0000100002`002`0000/0000
;00202`/;080000/00X0000001HF000002`0;0000000000002`002`0000000005P00000/0P00;003
00000005000F0000000000000000000/00000P00;0000`0F0000;2`/02`000030000;003000/000/
;2`001H00080000/00P0;2`/000000000000000001HF00000000000/02`000<0000000D0000F0000
000000000000000/00020000000401HF5P000000;000001OG`Sooooo0006ooooo`040:NWY`2GaLD0
][Jf09N^a@@0UlG501L0UiO505o5a@1kaLD0YjNW05nGU`1OaIL0YjNW0;Jf]P35aIL0[W]k07<00035
Uel0BDU90<G5U`2GGel0G`0006V5J@1OG`00BDU905mOG`1OG`00BDU905mO000204U9B@0:05mOG`1c
Lg<0GemO05mO0000;000GemO05AD9@00Gel0][Jf09NGU`80GemO01L0Gel002EDE025QHD0QHF505mO
G`25QHD0GiNG09NGU`1OTY8005mO04U9B@1OGel0GenG0:NWY`2GUiL0E5A`05nGU`1OaIL0GemO09O5
U`1OGel005mO07^GU`0305nGU`0<0:NWY`2GUiL0YjNW07^GU`2WYjL0GiMO07=cL`1OUel005mO04U9
B@35f]X0onnG101OUiL02@1cLg<0Ng]k09NGU`2GaLD0GiO509NGa@1OUlD0GlG507^G[P040:NWY`06
05nGa@1OaLD0YjNW07^^a@2GaLD0UiO50P2WYjL02P1OaLD0YjNW0:NWY`1OUlD0UiO508F5Q@1OUiL0
UiO509NGU`1kUiL305nGU`0605mOG`1cLg<0BDU901H/5P0/;2`002`00`0/;2`00`0002`0<4H002`/
;002000/000;0000;00/;2`0000001H05P00;000;2`/000/000/;2`0;00004T0000F01H00P000000
1000;000000002`/;00/0003000/00040000000/;2`002`002`000D0000000`0000/000/000002`0
01HF000/000/000002`00000000/;2`0;00001HF000002`3000000040000;00000005P0F00000080
000/00<0;2`/02`00000;0000P0000002P0/;2`0;0000000;00002`0;000000F000/;2`0Lg=c000/
000/;2`20000000402`F5P0002`0;00002`00080;2`/0P0000001`0002`0;000000/000002`0;000
000/000F00000P0000001P00;000;000000/0000;00001HF000/0080000/00D000000000;000;000
;2`/01H/5P020000000402`000000000000002`/;080000000H0000/000/0000000002`000000000
01H200000008000/000004T0000004U9B@0F5P00000002`/;019BDT8ooooo`001_ooool0201OUlD0
][Jf09O5a@1kaLD0][Jf09NGa@2WYjL0UlG50P1OUlD0101k[Zh0YjNW09O5U`1OUlD205o5a@0J0:NW
Y`35[Ul0UemO0<FGG`1OGel0BDU905mO000/;2`0Nel`05mOG`2GGel0GemO04U9B@00G`00BDU9001O
G`19BDT0Lg=c05nGG`1OGiL005mO04U9B@0/;2`0>c/k04U9B@1OUiL205nGG`0605mO001OGel0E71`
05mOG`1OGiL0GiMO0P1OGel07`2GUiL0WinO04U9B@00Gel0GiNG09NGa@25QHD0UiNG06V5Q@2f][H0
YjNW05nGG`2GUel0BDU9001OG`0jJFT0Lg=c05mOG`25QHD0GiNG05o5U`2WYjL0NiNG05nGU`2GUel0
GemO05mO0019BDT0Lg=c0>;gfP1OGel00`1OUel04P1OG`0009NG05nG[P25QHD0GlG505nGa@2WYjL0
GlG50:NWY`1kaLD0UlG505o5a@2WYjL0][Jf0:NWY`2GaLD0YjNW05nGa@80UlG500D0GiO50:NWY`2G
aLD0YjNW09nOW`020:NWY`0705o5a@1OUiL0GiNG0:NWY`1OUjh0GenG09NGU`0305nGU`0905mOG`0F
ATH0000/02`/;00/0000000002`/;00000005P0000<0000/0`0/;2`01@0F0000;2`/0000;00/;2`0
;000008002`000D001HF0000000000000000000/000200000003000F000/0000000000<0;2`/00X0
000/01H05P00000000000000;0000000;2`/000/000000005QH/0P00;0001P0/000002`00000;000
;000000F02`/;0@0000000/0;00000005P0/00000000000/000/0000000002`/;00U0000000002`0
0002000/00060000;00/000001H0000/000/000002`00P0000001@00;0005R`F02`0000/0000000/
008002`00200;2`/01HF000002`0000/05l00000;000;0000000000F01H002`000000000;0000000
02`/;00/000001H00000;000;000;2`/0000000002`002`002`/;000;000000002`0000002`0;2`/
000/00000000000F0000;080000000<0;0000000;00000000P000002000/000709MOG`0002`002`0
000F5P0/000002`004U9B@08ooooo`001_ooool01`2GUiL0][Jf0;Jf]P1k[Zh0UlG50:NWY`35klD0
0P2GaLD0301OUlD0GjjG0:NWY`2WYjL0GiNG001OG`2WYjL0GiNG0:jGU`25QHD0UiMO0<FGG`80][Jf
00D0Gel005AD9@1OGel0BDU905mOG`0205nGG`0304U9B@0UBBD0BDU900@0GemO00H0;2`/04U9B@19
BDT005l004U9B@1OGel205mO0080GemO01T0Lg=c05nGU`1OUiL0GiMO05mOG`1cLg<0NiNG04U9B@00
Gel0GemO08F5Q@1OGel0Lg=c08j>SP1OaIL0UlFG09NGU`1OG`0005mO09O5U`1ONel0GiMO07=cL`2W
YjL0GiNG0080UiNG00P0NiNG09NGU`19BDT0GemO05mO001OUel0e=CD0:n_Y`80GiMO0P1OGel03@1O
Uel0QHF509JFUP1OaIL0GiO50:NWY`2GaLD0GiO509NGa@2OWkH0UiO505nGa@1OaLD00P2WYjL0302G
UlD0YjNW09O5a@1OUlD0GlG509NGa@2WYjL0UiO50:NWY`23WkH0UiNG05o5a@80GiO500@0GiNG07=c
L`1OUiL0UiNG101OUiL00`1cLg<0GUiN02`/;00302`/;00:02`00000;0005P000000000/00000000
000/000/;2`0B@00000F5P8002`00P0/;2`01P00;000000001H000000000B@00000/00<0000000P0
5QHF000/000/00000000000/00000000;2`/0000;080;00000P0000/02`0001O000002`00000;00F
5P00;2`/000/0080;00000X002`002`0000001H0000/0000000/0000000/02`/;000000001H00P0/
00002@00;000000/000/000/00005R`F02`0000002`002`00000;0020000000?01H05P00;0000000
02`00000;000;000000000005QH0000/02`0000002`002`00000000/00005QH/00D0000/00H00000
01H00000;000000/000/000/0002000/000;01HF000002`0000/0000;0000000000/000/00000000
01H0000/000/;2`00P0000020000;00300005P0/;2`0000000@0000000L0000F0000000/00000000
000/000/0000000/0080000000<002`004U9BOooool01oooool000Kooooo00X0UiO50:NWY`2f][H0
PkJO09O5a@1OUlD0UiO509O5a@35aLD0GlG50P1OUiL00`1OUel0GiNG05mOU`02002GU`0;07:>LP2W
YjL0UiMO05mO002GGel0aLFG05mOG`16ATH0BDU905l0G`1OGel00P19BDT0501OG`00E5AD04U9B@19
BDT0GemO05mO001OGel0BDU902`/;016AQH0BDU905mOG`1OG`00GemO05mO001OU`00Gg]O05nGU`00
Gel0GiNG0`1OGel00`0`Gc00GemO04U9B@0205nGU`0407=cL`1OUiL0GiMk0;Jf]P80YjNW00H0UiNG
05nGU`1OGel0JFUY05nGU`1OG`0205mOG`0;08F5Q@2GaLD0WinO0:NWY`1OUiL0Gel009NGG`1OaIL0
kno508M`E01OGel00P19BDT0101OGel0GiMO05mOG`23Wil209NGU`0709NGa@1OaLD0UlG509O5a@2W
_[h0GiO505o5a@0205nGa@80UlG500<0GiO508>O]P2WYjL00P2WYjL00`2GaLD0UiNG09O5a@020:NW
Y`0605nGa@2WYjL0GlG505nGU`1OUlD0GiN^1@1OUiL00`1cLg<0GemO001OG`0202`/;0060000;00/
0000;2`/0000000/0000000/0P0/000202`/;00602`F5P00;00002`00000;00/;2`002`00P000002
02`000080000;0000000;00002`0000F;1H0;2`/0000;0190002000/000;02`/;00F01H000000000
000/0000000002`/;0000000000/000F000000000P00;0004P0002`002`00000000F5QH0000002`/
;00/0000000/02`00000;00001HF0000000/;2`0;0000000;000;000000/02D0008000000P0/;2`0
100002`002`001H05P00;0020000000402`00000;00002`001HF;0<0000/0P0000001@00;0005P0F
0000;0000000;0000080000/01<000000000;00/0000000/02`/;000;0000000000/000F0000;2`/
00000000;000;2`/0000000002`0000001HF5P0002`002`00080000000@0;0000000000F5P00000/
1`0000001P1OGiL0000000000000;000000001HF0080000000<0GemOooooooooool01_ooool000Ko
oooo02`0_[jn08>f]P1k[/D0RJjj05nG[P1OUlD0Gjk50=_Kf`3=cLd0Ujj^05ZK/P1OUiL0Gg]k05mk
U`1ONjh0GiNG032GU`18KFd0L71`09NG<02^Uc00Nel`09MOG`1bLW80Hf=S05ADE01kGc00E5AD06V5
J@1OGel0C6T002]J@P1DE5@0Gel`05ADE01DE2D0GemO05ADE016AQH0>c/k04I6AP19BDT0<5l`031O
G`80GemO00X0FVQJ031OG`1DE5@0Lg=c06UYJ@0`G`00BDU903eD?@19BDT09EAD0P1DE5@0801kUg/0
E5AD06UgJ@2WYjL0WinO05nGU`2O]Yl0E5@U031O<018KEH0GUiN05mO001OGc00Ng]k05mkN`1kUiL0
NiNS09nOW`1k[W/0UiMO0:f][@3_mlD0bl^^04ebLP1bSXh0Pin307^GU`1ONel0Ng]O06MWI`2SXjl0
Ujk50`2WYjL06@2OWil0WkJf07^Sa@23WkH0WkJf07^^[P2WYjL0Njk508>O]P1k[Zh0LJNb0:NWY`23
WkH0YjNW08>f]P1O[Zh0NiN^05nS^P1O[Zh0GiNG0:NWY`1OUjh0NiN^05n^U`1aVi/00P1OUlD01P1O
[Zh0GiNG05nGU`0jQHD0GiNG001kN`8005mO0P0/;2`01P0/5QH0=`/001H0000F5P00000F000/0080
;2`/01H08AHQ02D05P0001H05P00000F000F0000000001H;2`0000005QHF02`0000F;1H001HF02`F
5P0;8AH05R`F000/000F5P000000000F000F;1H08B4F0P0F01H05@0F5P00000001H0000F;1H05QH0
01HF2`0F;1H0000F01H00000;000000F0000000002405P000000000002`0;1HF0000;00F5P0001HF
01HF000200005P0D01HF000F;1H05QH/00/Q5P005QH0;1HF000/000F5R`0000F01H0000F2`0002`0
000000005P005QH/01HF000002`05P0001HF;0005QH201HF;00>000F000F;1H07Qhd00005P000000
5P000000;00F;1H09BDk00/08@005P00;1HF02`/;00F;1H2000/000=01HF2`00;000;2`/00005P0F
01H001H0030`AP0F00005R`F00005P00000001HF01HF5P0201HF000B00/Q2`00;0005QH001H05P00
;0005P0001HF5P002`00000F01HF00005QH001H0000000005P0000/;01HF5P005P00BDU92?ooool0
00Kooooo01D0][Jf0:NWY`1OUlD0NlG505o5U`1OUiL0aLG_0;Jf]P35knl0aLG_09NGa@2WYjL0GiNG
05nGG`1OUiL0GenG05nGU`1OGg/0UiNG09NG0035Gel00P2GGel02P1OGel0Ug]O05mO001OGel0Gel0
04U9B@1OGel0BDU902`/;01OG`0204U9B@06001O0019BDT0GemO04U9B@0k>c/005mO0P19BDT03@1O
G`00GemO05nGG`0UE5@0Gel005mOG`0/;2`0BDU902`/;000G`009E@U02`/;01OG`000P1OGel02P1c
Lg<0GemO02EDE025QHD0UiMO04U9B@1OGel0BDU905mO001DE2D205mO000Y04U9B@1OGel0GemO07=c
L`1kUiL0UiNG05nGU`2GaLD0aLG50>o5a@2GUiL0Gg]O05nGa@1OUiL0Lg=c09MOG`1cLg<0GiMO05nG
[P2WYjL0UlG50:NWY`1OUlD0UiO505nGa@1k[Zh0YjNW09NGU`1OUlD0UiNG05nGa@1OUiL0YjNW0:Nn
_P1OUlD0GiNG05o5a@1OaIL0GiO505nGU`1kUlD00`2WYjL01P2GUiL0YjNW0:NWY`2OWil0GiNG05nG
a@80UiNG00<0GenG05nGU`0`UiL00P00GiL205mOG`0504U9B@00;0005R`F02`0001900000P0/0000
6@00000002`000005P0002`0;2`/0000;00/;2`002`00000000/0000000/02`/;00002`0B@0002`0
000002`0000F02`/;000;000;2`/02`0002WYjL0BDU901HF000/00000`00;0001@0002`0;2`/0000
;0005P00;000008002`00P0002`0400/00005QH/0000000/0000000/0000000/0000000/01H00000
000002`002`0000002`0;2`/02`0000001H202`0000=000/00000000;000000/0000000002`00000
000/0000000/02`/;000;0005P0F0000;003000/00040000;00/;2`05QH/02`/;08002`000P0;2`/
000/0000;000;1HF0000000002`002`002`0008002`000@05R`F02`/;00002`0;2`/0P00000202`/
;003000F5P00;00002`00080000/00`00000000/000F;1H002`00000;000;000000/000/00000000
01HF0000000002`200000006000/0000000002`000000000;00005mO2?ooool000Kooooo00@0][Jf
0:NWY`2GaLD0Hjk50P1OUiL02P35aLD0aNo_0<G5k`35aLD0Ykjn05nGU`25QHD0GiNG05nGa@1cLg<2
05mOG`0:001OU`1OUel0UemO09MOG`35Gel0UemO05mk<01OGel0Gel004U9B@80GemO00D0GiMO07]k
<000B@00Gel005mOG`0202`/;00404U9B@1OG`009E@U02`/;080BDU900D0GemO04U9B@1OGel0E5@U
05mO000204U9B@80Gel000X005l004U9B@19BDT0BDU902`/;01OGel0Gel0001O000`JD`0YjNW0`1O
G`0204U9B@0?01Hk5P0/;2`0BDU902`/;000B@00GemO05nGU`1kUg/0QHF509NGU`3oknl0ooo_09O5
U`2f][H0QHF50080UiNG00H0GiMO05mOG`1OUiL0GiNG06V5Q@1OUiL20:NWY`0609NGa@2GaLD0GlG5
07^^a@2WYjL0UlG50P2GUiL02@2GUlD0YjNW0:NWY`1kUjh0UiNG05nGa@1OUiL0GlFG05nGa@0305nG
U`0305nGa@1OUiL0GiO50080GiNG00D0GjjG05nGa@2WYjL0UiNG05nGa@0205nGU`0<05mkU`1OUiL0
09NG05nGU`1OGel0BDU902`/;00F;1H0;2`/000/000/0000000/0P0/0000100001H0;2`/02`0000/
;2`202`000<0000000<002`00000000/00000P0/;2`01P0U5P00000/02`/;00002`002`002`/;0<0
02`000<0;2`/0000000002`00P00;0006@0002`05QH00000;00002`0;0000000000/;2`00000000F
5P190000;0000000;00/0000000002`/;00F5P0002`00000000002`00000000/000/00005P0F02`0
000002`00P0000001`0/;2`0000001H00000;000000/0000000/;2`00P00;0001@0/;2`002`002`/
;00/;2`0;0000080;2`/00X0000F000/000002`0B@000000;00/000002`0000F00000000;2`/0P00
0002000/0080000000L0000/000/00000000000002`/;000;0005R`F0080000000@0;2`/0000000/
;2`0;0000P0000000`0/0000000/0000000200000003000F0000000000000080000000H0000/0000
00005P0000000000;019BDT8ooooo`001_ooool04P2GUiL0GiO50<G5k`2J]/d0GiNG05nGa@2GaLD0
hN7Q0<G5a@35aNl0RjNW07=cL`25QHD0GenG05nGU`1OGel0GenG001kG`80GiNG00L0UemO0<FG002G
Uel0UiMO0:jGU`1OGel0BDU90080Gel000L0GemO09NGG`1kNel0BDU902`/;01OG`0007<00080BDU9
00D0GemO02EDE019BDT0Gel004U9B@0205mO000305mOG`19BDT0;2`/0080Gel000H0;2`/04U9B@1O
G`00BDU902`/;000G`0204U9B@03001O001OGel0GemO00<0BDU900l004T004U9B@19BDT0E5@U02`/
;000B@00BDU9001O0019BDT0GemO05nGG`1OG`00koo_0<G_k`35aIL00P2WYjL01@2OWil0GiMO05nG
U`25QHD0UiMO0080GiMO00X0Pin308F5Q@2GUiL0][Jf0:NWY`2GUlD0GiO507^^[P2WYjL0GiO50P2W
YjL0302f][H0YjNW05nGa@23WkH0GlFG05nGU`2GUiL0GiNG05o5U`2WYjL0GiN^05nGa@D0GiNG00@0
Ng^G05nGU`1OUiL0UiNG0P1OUiL00`1OUlD0GiNG05nGU`0205nGU`0408F5Q@1OGel005mO01H/5P80
02`000D0B@0002`/;00/0000;00002`F5P0202`000040000;000000002`002`/;080000000D0000/
02`/;000;000B@000000;002000/0080000/00D0;2`/0000;00000005QHF0000;00202`0000?02`/
;000;00002`0000/00005P00;0000000;0000000;000000/00000000000F000/00000000;0000080
000000H0;00001HF5P000000;0000000;00/;2`2000/000501H05P0002`0000002`0000000000P0/
;2`02@0/5QH0;2`/0000000/0000;2`/0000001OUiL001HF000/000202`/;0050000;00/;2`0;2`/
01H05P0/00000P0002`0100/;2`0;000000/000F5QH2000/000:02`000000000;000000/000F5QH0
000/0000000002`002`002`00080000000P05QH0000/000002`0;2`/0000000/000002`0000F0080
000/00<0;0000000000000000`0000001P00;000;2`/00000000000002`001H05P80;00000<0BDU9
ooooooooool01_ooool000Kooooo00@0UlG509NGU`2GaLD0NiN^0P1OUiL02@35aNl0hN7Q0=CDe02G
aLD0][K;05mOU`1OGel0GenG05nGU`0205mOU`08001ON`1OGiL0BDU909NGG`2GUiL0QHF50<FGG`2^
Nel205mOG`0305mO0019BDT0Gel00080GemO00@0BDU902`/;000L`00BDU90P1OGel07`00Gel0<5l`
05mOG`1OGel0BDU905mO001OGel0GiMO05ADE000G`00Gel0001O000/;2`005l005mO000U>bD0BDU9
02`/;019BDT0;2`/001O001OG`00E5AD07=cL`1OGel005l005mO001OGel005l005ADE01OUel00`19
BDT03@1OG`00BDU905nG<01OaIL0UlG50?ooa@1OU`00Lg=c09NGU`23]Yl0GiNG09O5U`1OUel00`1O
Gel0201YQHD0GiMO09NGU`2WYjL0UiO50:NWY`1OUlD0YjNW0P2GaLD20:NWY`060;Jf]P2WYjL0][Jf
0:NWY`2GUiL0YjNW101OUiL02P1kUiL0GiNG05nGU`1OUiL0QHF505nGU`2GUiL0NiNG05nGa@2GUiL7
05nGU`80Lg=c00@0GenG05mOG`0FATH002`0100/;2`01P00000002`0000/00000000;2`/02`00080
02`000H05P0000000000000002`002`/;000;00402`/;009000/000/;2`00000000/000F5QH0000/
02`0000002`0;00000<002`000@05QH0000/0000;000;0000P0002`0100/00005R`F000/0000;002
0000;00:02`00000;0005P0F02`000000000;000000/000002`002`001H05P80;2`/0P0000001P0/
;2`0000/01H05P0002`00000000/0080000000<0;2`/01H/5P00;0000P0000001P0/0000000/02`/
;00F5QH0;0000000;080;2`/00<002`00000000/5QH00P0000020000;00702`/;000;00001HF000/
000/0000000/000/0002000000050000;00F;1H000000000000/;2`00P0002`01P00;00001H00000
0000000002`000000080;00000<001H002`0000002`00P00;0000`0/0000000000005P0200000003
04U9BOoooooooooo00Kooooo0006ooooo`0>0:NWY`2GaLD0][Jf07^G[P1OUiL0GiO509O5a@35klD0
aLG_0:NWY`1kaLD0UiNG05nGG`1OUiL205mOG`0C05mOU`0jJHD0GiNG05nGU`2WYjL0UiMO0<FGG`2G
Uel0W8EY09NGG`1O000004T005l0000/;2`0Uel005ADE01OGel0UemO02`/;00304U9B@03001OG`0U
E5@005mO00D0GemO00@0E5@U00190019BDT0;2`/0`19BDT00`0k>c/004T004U9B@0202`/;00;04T0
0000B@00Gg]O05mO001OGel0Gel004U9B@1OG`00GemO06V5J@1OG`000P19BDT07000G`00GemO05mO
G`1ONc00kno_0?ook`1OUel0Gel008F5Q@2GUiL0[jn_0<G5a@2GUiL0Gel005mOG`1OG`00GiMO05nG
N`2GUel0YjNW0<G5a@2f][H0GlG505nGa@1k[/D0YjNW05nGa@1OaLD40:NWY`0309nOW`2WYjL0YjNW
0080GiNG00<0UiNG05nGU`1OUiL01P1OUiL01P1bSXh0GiNG05nGU`1OUiL0UiNG05nGa@H0GiNG00<0
09NG05nGU`0k>c/00`0/;2`00`19000002`002`00003000/000302`00000;000;2`/00@0000000L0
;0000000;0190000000/01HF000002`0;000008002`000@0;2`/000/000F;1H0;0000P0000001`00
02`0;0000000000/000002`00000;00/;2`00P0000000`0002`002`002`F5P0202`/;080000/0P00
;0000`005QH0000/00000002000000030000;000;000000/008002`000<0;2`/0000000/00000P00
02`00`00;000;2`/000/0002000000050000;019000000000000000/00000`0002`00`0F000002`0
02`0000202`/;0090000000/000001HF0000;000;000;2`/02`0000002`0;000008002`000<00000
0000;00000000`0000002P0/;2`0000002`0000002`0000002`/;00000005QH002`/;0190002000/
0080000000/0;2`/00000000;000000/00000000;000000002`00000000002`004U9B@08ooooo`00
1_ooool0302GaLD0aLG_09O5a@2;YjL0GiO509O5k`2f][H0aLG_09NGa@2WYjL0Ykjn05o5U`<0GiMO
0P1OGel00`1YQHD0GiNG05nGU`0209NGG`80aIMO01@0Ug]O09MO001OG`0004T004U9B@1OGel0GiL0
05mkG`2GUel0Gel005mOG`1OG`0005l002`/;019BDT0E5AD05mOG`1OG`00GemO05nGG`80Gel000/0
<5@002`/;019BDT0Gel002`/;019BDT005mO031D000/;2`0Gel004U9B@0302`/;005031O<019BDT0
GemO001O0019BDT00P1OGel00`0FATH005l004U9B@0305mOG`0604U9B@2P_:00aLG_0<FG001OGel0
Gel00P1OUel02P2G[YL0YjNW0;Jf]P1OG`00Lg=c001OG`1OGel0LXj>0:NWY`1OUlD309NGa@0<05nG
a@1kUlD0UiO509O5a@2WYjL0UlG50:NWY`2GUiL0YjNW09nOW`2WYjL0UiNG0`1OUiL01`25QHD0GiNG
05nGU`1OUiL0GenG05nGU`00UiL0101OUiL0102WYjL0UiNG09NGU`25QHD705nGU`0402E`E000;000
;2`/000/00@0;2`/00P002`002`/;0190000;2`/000/000000005P0004T00080;00000@0;2`/000/
000000005P0F0P00;0001@0002`002`002`0000002`09AH00080000000H0;0000000000002`0;000
000/000F5P02000/0080;00000L0000/02`/;00F01H0000/02`/;0000000;2`/008002`000P05QHF
000/000/0000000002`0000/;2`002`002DF008002`000L0000/02`/;000;000B@0002`0000002`0
;000008002`000<0000004T0000F;1H00P0000001`0002`0;00002`0000002`05QH002`/;000;000
0P0/;2`03@00;000;00001H/5P000000000/000/000/;2`002`002`0000002`002`00000000002`0
0`0000002`0/00005QHF02`0000002`0;0000000;00/;2`0000/000F5P0/;2`002`00080000000<0
;000000/000000000P0000000`0/000000000000000200000003000/0000000005mO00Sooooo0006
ooooo`040:k5a@3=cLd0Njj^08>[Z`80[/G501`0cN;R0<G5a@2GaLD0_[jn07nb/P2O][H0NiNG05mk
U`1YJFT0Gg]O07=cL`1OUiL0UlG508F5Q@1SNg/0QHEY0:jGG`2nYh/0d9M]0<FGG`2GNel0L71D05mk
G`1D<300Gel`05m]B01kGel0Ng]O0P1ONel0>000Gc009EAD05AD9@12FUX0GiMO04U9B@1ONc00Gg]O
02`/;01OGc00FVPZ031D000k>c/09E@U04I65P19BDT0<5@003E=7P00G`00>c/k02D`000UGRD0BDU9
03/k>`1?CcL0Gel005ADE01DE2D0L5@U05ADE01OGc00I79=07]k<01kN`00JFUY05nG<01ON`00GiMO
0;WGc`2_Yf<0Gg]O05nG<01ONc00Ni9k05nGG`1oVhd0WkJf09:^N`2WYjL0WinO03YYJ@1OUiL0I79b
08>OW`2WYjL0Ujj^0`2GaLD03P1O[/D0YjNW09NGU`23][H0NiMk08j>SP2GUel0Lg=c07:>P01OUg/0
UYJF07^GU`1OUg/0LXj>0P1OUiL01@1YQHD0GiNG05nGU`1OUiL0<7^G00<0GiNG00L0LXj>05nGU`23
Wil0NiNG09NGU`1]UiL0<9NG00<0GiNG00D0NiNG05mkU`1=SX009EAD04U9B@0202`/;00Q02`0000F
;1H0=S4l02`F5P0F5R`0000F000F0000;0005QHF01hF5P0F5R`0;2`/01HF;00001H05QH/01H0000F
8AH002`0000F000/;2`0000001H0000F;1H08B4F000F5P0F5QH0000F01H/5P005QH05P0F01HF000;
8@/05QH0008002`001h05QH/000F000/5QH05P/;00005P0F;1H0000/000F00000000;1HF01h05P00
5QH0000F01HF0000;000;2`/01HF000;8@005P0F02`/;00F;1H0;1HF000F5P00;0002b4001HF;00/
;2`001H001HF00005QH201HF;004000F5P0k5QH05R`F01HF;080;2`/00<05R`F00005P0F01H00P0F
5P03000/000901H05P0/;2`05R`F01H/5P00;0005QH/024Q8@0F;1H001HF0080000000`05P0F01H/
5P005QH02b4F000F000002`05P0F00005P0`<300000000/F5P005P0400000004000F000C00/05QH0
01H05P<001HF00D05QHF01H;5P0`<0005P0004U9B@08ooooo`001_ooool03`1OUiL0][Jf09O5a@3R
knl0kno_0?o_a@3oaNl0aLG_09O5a@35aNl0PinO05nGU`2GaLD0YjNW05mOG`0205mOU`0I05nGU`2G
aLD005mO05mOG`2WYjL0aLEO0<G5U`3J[Y80aIMO0<G5G`2GUel0QHF505mO0019BDT0JFTj05mO001O
Gel0UemO05nGG`2GUel005mO02`/;00`Gel0BDU905mOG`0205mO0080BDU900P0<5mO04U9B@1OG`00
Gel002`/;019BDT0;2`/02ED9@<0;2`/00H005mO001O0019BDT09E@U0019001OG`0204U9B@0502`/
;01OGel0GemO05nGG`2GU`000P1OU`000`1OUel0YjNW0:j^Y`0205mOG`80BDU90140GemO07=cL`1k
[YL0UiMO07=cL`2GUiL0Lg=c001OG`1cLg<0Gg]O08F5Q@2WYjL0UiNG09O5a@2f][H0UiO509nf]P04
0:NWY`0;08F5Q@1OGel0Lg=c05mkN`1cLg<0GemO07=cL`1OUel0GiNG09NGU`1ONiL01`1OUiL00`00
UiL0GiNG05nGU`0205nGU`0309NGU`1OUiL0GiNG00D0GiNG00D0LXj>05mOG`1OUel005mO000/0002
02`/;003000F5P0/;2`000000080;0000P0000001@0F;1H002`002`/;000000002`00080;2`/0P00
;00402`/;0050000;00F5QH0;0000000000/;2`00P0/00001P00;000;00003/00000;0000000000/
0080;2`/010002`001H05P0/0000000002`/;00/0000;2`/0000;00F01H0000004T00000;000;000
0000;000000001H01@0/;2`02`0000005QH002`00000;000;000000/000/;2`002`00000;0190000
000/0080;0000P0/;2`0100F0000;0000000;000;00202`/;003000/000F5P0002`000@0;2`/00<0
000/02`/;000000010000000100/;2`002`0000F5P0/000200000005000/0000000002`002Dk9@00
02`00P000000100/;2`002`00000;00F01H30000000402`/;00/0000000/00005P80000000<0BDU9
ooooooooool01_ooool000Kooooo0P1OUiL00`35aLD0j>SX0>7Qh@020>7Qh@0B0<G5a@1OaLD0][Jf
04b^[P2f][H0GiNG07=cL`00Uel009NG001OG`1YQFT0YjNW002GG`1OUiL0GlFG09O5U`2f][H0kjj^
0P35Uel01P2GUel0QHF509NG002GUel0Gel`09NGG`80UemO00H0UiMO05nGG`00Gel004T002ED9@0/
;2`304U9B@0902`/;000G`00BDU904U9B@00G`0007<004U9B@0/;2`005l00080BDU900d0;2`/001O
000/;2`005l005mO000/;2`0BDU9001O001OGel0BDU9001O001OUel0Gel`0080GiMO01H0UiMO05nG
G`1cLg<0aNo_0;Vi/@1OG`00GemO05mO0000G`00GemO09NGU`1kNg/0GiMO05nGU`00Gel0Lg=c05nG
a@2WYjL0O7al05nGa@2GUiL0UiO50P2GaLD00`2f][H0YjNW0:NWY`020:NWY`80QHF50P1OUiL02P1O
Ug/0UiMO05nG0000Gel0GemO08F5Q@1cLg<0GiMk002GG`00UiL305nGU`0305mOU`0`UiL0GiNG0080
GiNG00H0UiNG0:NWY`2WYjL0PinO05nGU`25QHD405nGU`0407^GU`1cLg<0GiNG001OG`@0;2`/00<0
02`002`0000/;2`00P0/;2`00`1OGel05R`F000/0002000/000404T0000/0000000001H/5P<0;2`/
00@002`00000;00/;2`001HF0P00;0001`0/;2`002`0000/000/;2`002`001HF0000;0000`0002`2
0000000801H0000002`0;00004T0000002`0;2`/0000000/;2`2000/000602`/;000;00002`00000
00005P0000000P0002`0300/;2`0000000000000000002`002`000000000;0000000;00/;2`0000F
0000;0H002`0100/;2`01@190000;00002DF000/0000000/0080;2`/00<0000002`0000002`00`00
00001000;000;00002`/;00002`2000/000302`/;00/0000;2`/0080;2`/0`00;0002@000000;000
0000;00000005QHF02`00000;000BDU9000/00020000000401H00000;000;00004U9B@Sooooo0006
ooooo`0405nGa@2f][H0aLG50;K=c@80hN7Q00H0knoo09O5k`35aLD0aLG_07^^a@2f][H2002GU`0>
07=cL`1OGel0BDU905mOG`2GaLD0Lg=c002GU`2f][H0aLG50>o5a@3_aJh0klFG0<FGG`2GGel209NG
G`0:0<FGG`1OGel0Gel005mO002GG`00UemO05mOG`19BDT005l003/k>`80Gel000@0BDU9001O001O
U`0005l00P19BDT01`00Gel0BDU904U9B@0/;2`005mO01I65P0/;2`00P19BDT205mO000602`/;00U
E2D0001902`/;01OG`00BDU90P1OG`002@1DE5@0GemO05mO001OU`00GiMO0>o_a@35kol0NiL`05mO
000205nGG`0405mO001OGel005mO0727L080BDU900H0GiNG09NGU`2GUlD0UlG507^GU`35aLD20:NW
Y`0405nGa@2GaLD0UlG507^^a@80UlG50P2GUiL205nGU`0309NGU`1DE5@0GemO0080Lg=c00H0GemO
07=cL`1cLg<0NiMk05nGG`00UiL205nGU`0:05nGG`1OUiL0<9NG001OU`00UiL0GiNG05nGa@1OUiL0
UiNG07^GU`@0GiNG00<0GiO505nGU`1OUiL00P1OUiL00`1OUel005mO04U9B@0202`/;00304T0000/
;2`0;2`/00<002`000P09@00000/0000;000000/000/000/0000B@0002`F5P80;2`/0P0002`202`/
;00901H/5P00;00002`00000;0000000;00002`/;00000005QH000<002`00`000000100F0000;000
0000;00002`2000000<002`00P0002`01P00B@00;00002`0000002`002`00000;080;2`/00/00000
000/0000000002`00000000/;2`0;0000000;000;000;00002`/;002000/0080;2`/00H002`00000
0000000000000000;00000020000;00801H05P0000000000000/000/;2`002`0000000005QH30000
000602`000000000000/0000;00F5P0000000P00;000100/;2`002`002`/;00F5R`4000000050000
;000;000<4H`02`/;00002`00P00;0001P0002`0;00001H05P0/000002`004U9B@Sooooo0006oooo
o`0509NGU`35kol0UlG509N^a@3De=@00P3QhN401035klD0aLG509O5a@1KYjL205nGU`0D002GU`00
Gel0GemO05mOG`1ONiL0GiNG002GU`1OUlD0aLG50<G5U`35Uel0f/F^0>o5G`35aIL0UiMO05mOG`2G
Gel0UiL00696AP1OG`0205mOG`0605mO001cLg<005l002`/;019BDT0Gel00P19BDT00`00G`00Gel0
001O000204U9B@07001OG`19BDT005l004U9B@0/;2`0BDU905mOG`0304U9B@03001OG`19BDT0ATHF
00<0BDU900@0GemO05mO0000Gel0JFUY0P1OGel01`1OUel0GiNG0<G5k`35aEl0Ng]O05nG001OGel0
0P1OUel06`1OGel0BDU905mOG`00Gel0GemO05nGU`2GUiL0GemO09NGa@2GaLD0YjNW09O5a@2WYjL0
UlG509NGa@2GaLD0WkJf0;Jf]P2WYjL0UlFG07=cL`25QHD0Lg=c05nGG`0`Nel0Gel004U9B@0205nG
G`80GemO00@0Gg]O08F5Q@00GiL0GiMO0P1OUiL00`1OUel0<9NG05nGU`0205nGU`0<05nGa@2WYjL0
UiNG07^GU`1OUiL0GiO50:NWY`1OUlD0GlFG05nGa@1kUjh0GenG0P1OUiL2001OG`040019000F;1H0
02`002`/;080;000014002`00000;00002`0;2`/000/000/;2`0000002`0000002`0;2`/0000;00/
;2`0000/02`/;00002`0;00001H/5P06000/000402`0000/;2`0;0000000008002`00P000000100F
01H000000000000002`202`000030000;0000000;000008002`000<0aLFG05mOG`0002`00P000000
3@0/0000;2`/0000;00/;2`0000/01H000000000;0000000;000;000000/000/000F5P000P0/;2`0
1@0002`0;000000/00000000;2`/008002`000D0;2`/00000019000002`002DF000200000004000/
000/;2`0000/02`000@0000001L0000/000000000000;2`/01H/5P00;000000002`/;00002`0;000
000/000/;2`0000002`0000002`0000002`/;000;00001HF0000000002`0;0000000;00202`/;004
01HF5P00000002`004U9B@Sooooo0006ooooo`0<09O5a@35aLD0GlG50;K=c@35aLD0aNo_0>7Qh@35
aNl0][Jf05o5a@1OUiL0UiO50P1OUiL0101OGel005mO05mOG`0`Ng/205nGU`070;Jf]P2WYjL0QHF5
0;Jf]P3JklD0aNo50<G5U`020<FGG`0;09NGU`1cLg<0L5AD05l0002GGel007<005mOG`1OG`0005mO
04U9B@1OGel00P19BDT03000G`00BDU905mOG`00G`009E@U001O000/;2`0Gel004U9B@0/;2`004T0
02E99@80Gel00`19BDT02P1OGel0E5AD001O001OG`0004T005mOG`1OG`00GiMO06UYJ@2GGel209NG
G`050<G5a@3oklD0GiMO03YYJ@1OGel00`1OUel04P00G`00BDU905mkG`1OGel0BDU905mOG`1OUiL0
GiO509NGU`2WYjL0QHF50:NWY`2GaLD0UiNG0<G5a@2GaLD0Ykjn09NGU`80GiNG00L0GiMO05nGU`1O
Uel0GemO05mkG`1OUel0GemO0080GiMO00D0Lg=c09NGG`1kGel0Lg=c08F5Q@0605nGU`80GiO500@0
UlG505nGa@2GUiL0PinO0P1OUiL01P2WYjL0UiNG0:NWY`2GUiL0GiN^08F5Q@@0GiNG00<005mO01H/
5P00;0001P0/;2`01`00;00000000000;00/000002`00000;00F00001@0/;2`0100002`0;1HF02`/
;000;00302`0000;0000;000;0005R`F02`/;019000002`00000;0000000;00002`F5P0002`00P00
0002000/000=0000000F0000;000000/000/0000000/02`00000;00000000000;0190000000/02`0
00020000;00301HF000/0000000/0080;2`/00D0000/02`000005QH0;2`/02`000020000;080;2`/
00<05R`F02`/;00/;2`01@00;00200000005000/000/;2`0000/0000;00/5QH00`0000001`0002`0
00000000000/;2`05QHF04T00000;0000P0002`0500/000002`001HF;00/0000000/0000000/0000
;2`/000/000F5P0002`002`/;000;000;2`/0000;000;000000F02`/;000;000BDU92?ooool000Ko
oooo00h0GiNG05o5a@2WYjL0[Zk30<G5k`3De=@0hN7Q09O5k`2GaLD009O507^G[P2GaLD0GiO508F5
Q@<0GemO00<0<7]O0:NWY`2WYjL00P1OUlD01@2GUel0UlG50:Nn_P3_aLD0aLFG0080aIMO00H0QHF5
09NGG`25QFT0UiL009NGG`3_klD205nGG`80BDU900<005mO04U9B@19BDT00`19BDT01P1OG`00;2`/
04U9B@00Gel0BDU9001O008004T000h09E@U001O0019BDT0BDU905mOG`19BDT0;2`/03/k>`19BDT0
04T0000/0000G`00Gel005mOG`80GiMO00<0GemO0<G_a@35knl00P1OGel01@0`Gc00GemO05nGG`1O
Gel0Gel00080BDU900X0Gel`05mOG`25QHD005mO05mOG`1OUiL0UiO507]kG`2GUiL0GiO50`2GaLD0
1@35aLD0WkJf09NGU`1OUiL0UiNG0080QHF500H0GemO08F5Q@0`Gel0GemO05nGG`2GUel305nGG`08
07]kG`1cLg<0Lg=c002GG`00Gel0GiNG001OU`1lO7`505nGU`0305o5a@1OUjh0GiNG0080GiO500@0
GlG505nGa@1OUiL0GjjG1@1OUiL01019BDT0;2`/02`/;000;00502`/;003000/000/0000;2`/0080
02`000/0B@000000;000;00002`002`/;00002`002`002`/;0005QH0000/02`0000200000004000/
00000000;2`/02`F5P8002`001H0000/000/000/;2`0;2`/01H05P0/;2`0000/02`00000;000;000
000/000F5QH0;2`/02`00000;000;2`/02`00000;0005P000000;00/000000000P0002`0100/;2`0
01HF02`0000002`3000/00030000;00/;2`0;2`/00X0;2`/0P0000001P0F5P0002`0000/000002`0
;2`/000/0080000/1@0000001`0/0000000001HF;0000000;2`/0000;00/;2`00P00;0002@0001H0
;2`/02`0000/0000000/02`00000;00001H002`/;002000/00070000;00/;2`0;2`/000F000/0000
02`004U9B@08ooooo`001_ooool01@1OUlD0UiO50<G5a@1k[/D0aLG_0080e=CD0P2GaLD02@00UlD0
Njj^05nGU`2WYjL0UiNG05mOG`19BDT0GiNG031kTP0205nGU`0<09NGU`2GaLD0UiO50<G5a@2ndkh0
ono50;Jf]P35aIL0UiNG05nGU`1OGel0UYJF0P1OG`020<G5a@0605mO0000B@00BDU902ED9@19BDT0
;2`/0P00G`0202`/;00401Hk5P19BDT0BDU905mO0080BDU900<0;2`/03/k>`0/;2`00P19BDT01@00
L`00BDU9001O000`AP00;2`/008002`00P1OGel04`1OG`009EAD001O002WYjL0aLG50<G5U`1OGel0
BDU9031O<000G`0005mO05mO0000L`00BDU905mOG`1ONel0GemO05nGG`1cLg<00P2WYjL01P2GUiL0
Lg=c09O5a@1OUlD0UiO50:NWY`80aLG501D0WinO09NGU`2WYjL0YjNW09NGU`1OUiL0GiMO07=cL`1O
Nel0GemO05nGG`1cLg<0GemO05nGG`1OGel0Lg=c05mOG`1OUel0Lg=c05nGU`1OUel0101OUiL205nG
a@0:0:NWY`1OUiL0GiNG05nGU`1OUlD0UlG505nGa@1OaLD0GiO50:NWY`D0GiNG00<009MO04I6AP0/
;2`00P0/;2`01@00;000;2`/02`/;000;00000000080;00000D0;2`/000/0000;000000002`/;002
000/00040000;00/;2`0;2`/02`/;080000/0`0000004@0/0000000/01H/5P0/0000;2`/04T00000
;000;000000/000F5P0002`002`/;000;000;2`/0000;00/;2`0000F0080000000H0;2`/0000;00/
0000000000005P1900030000;00404T00000;00002`00000;080000000L0000/0000000/00005R`F
0000;0000000;0000080000/100/;2`02@0/000002`00000000/0000000/02`/;0190000000/02`/
;0040000;00502`/;00002`0000000000000;0000P0/;2`00`0002`0;2`/0000;00202`/;005000/
000/5QH002`0000/000/;2`00P000000300002`05P00000/000/;2`0;000000/0019BDT002`001H0
5P0002`0;00004U9B@Sooooo0006ooooo`040;jnd`2GUlD0Ykjn05nSa@80[/G50300[/GJ002Ga@1O
[/D0Njj^04R^[P1OUjh0PinO001kG`00Gel09EAD001OG`00KHT007^G04bGU`1k[Zh0][Jf0:n_[`2W
_]<0iNGU0=^n_P35aJh0f/FB0<F^N`2fWh<0[Zik09N7I03JUel0f][50<g=c@3Kfm/0Gel`07]kG`0U
E5@0@Um205mO<01ONc00GemO04U9B@0`G`00;2`/0318B00F>aH0>c/k02ED9@0FAQH0;2`/001D<00Y
>bT203/k>`0R031O<00k>c/0BDU902ED9@0fCCH0;2`/03/F5P00;000HV9602ED9@19BDT0<4P`08^W
R`33h]X0[i:B031OG`1DE5@0E5@U03eD?@19BDT0E5AD05AD9@19BDT0E5AD031OG`1OGdP0BDU9031O
G`0`Nel0E5AD05iNGP1DPh<0GhV909JFUP80Ujj^0100UlG505nG[P1OUlD0KJ>S09NG[P1O[Zh0NiNG
07^^a@2GUg/0JHEY031O<00`Nel0GiMO031kG`1OUel0E5@U0P1OGel0201OREl0Gg]O05nGG`1OUel0
JFV503Z5Q@1OUiL0<8VG0`1OUiL0301O[Zh0GiNG05nGU`18UiL0Gjk507^Ga@1OUlD0Gjk505nG[P2O
]Yl0Oi^W08>OW`@0GiNG00H0JFV504M]K@0k>c/0>c/k01H/5P0k5QH2000/000<00/F2`0/00005R`F
02`/;0005QH002`002DF000;;0/05R`F0000000F;1H05P0F0P005P00400F5R40;1HF05A`L0005QH0
5QH/00005P0000005QH001HF5P0F;1H0;000000/00005P00;2`/0000000F01H200000080;2`/00L0
5R`F02`F5P002`/0000F01H05P0F5P005P0F0080000001802`0;0000;00F5R`05P0001HF;00001H0
5QH000//2`0F;1H05P0001H05P0F;1H0000/000F5P0/8B40000/01H000005P0302`/;00901h;8@0F
5P009AH00000000F5QH0>aHF01HF;00;5R405R`F00<05QH/00T0;2`/00005P0F5P/0;1HF01H/5P00
01H05QHF01HF00005QH01@0F5R`03P0F;1H0;2`/01H05P0F2`0001H00000000F00005QH0000F000F
5QH04a<Y01H/5P0/;2`05R`F0P0F01H01@005P002`/002`F5P0F5P00BDU900Sooooo0006ooooo`05
0<G5a@2GaLD0UlG505nGa@2GUlD00P2GaLD0102WYjL0GiO509O5a@1OUlD205nGU`0>05mOG`00Gel0
09NG001OG`0`UiL009NG05nGU`2GaLD0GiNG09O5a@35aLD0l>SX0<G5a@2f][H20<G5U`0309NGU`2W
YjL0UiMO0080][Jf0P2GUiL01P1OUel0UemO05mOG`1ONel005mO09NGG`80BDU900D004T004U9B@0`
E00005l00019000202`/;004001O000/;2`09EAD04U9B@8005l00P19BDT02`0/;2`05S/F0019000/
000005l0000/0000B@00;2`/001O<035aLD0aIL00080BDU900<0;2`/0019000UBBD0100/;2`01@19
BDT0;2`/05AD9@19BDT0;2`/0080BDU900/005mO05nGG`2=SHd009NG05nGU`2GaLD0aLG_09O5a@25
QHD0PinO0:NWY`0309NGU`80Lg=c00@0BDU905mO<01OGel0UemO101OUel01P1ONel0GemO05nGG`1O
U`00UiMO05mOU`P0GiNG00T0<9NG09NGU`1OaLD0GlG505nGa@2GaIL0YjNW09nfW`2WYjL00P1OUiL0
3`2GUiL0GiNG05nGU`0`UiL0GemO0000;00/;2`002`002`/;000;0005QHF00000000;000;2`/0000
0002000/000502`F5P00;000;0000000;00000000P0/00000`00;000;0000000;004000000<002`0
00X0000/0000000000000000000/0000000002`002`0000/;2`0B@000P00;0000`0F01H00000000/
00020000;00302`000000000000/00<0;2`/00D0;0000000;0000000000002`000020000008002`0
00@0000/01HF;00002`0;000100/;2`01@0F;1H00000000000000000000/0080;2`/00P05QH/02`/
;00/;2`0B@000000;00/;2`002`001HF5PD0;2`/00/002`002`/;00/;2`0QHF50000;000;000000/
02`/;000;0005QH00000;00200000004000/000/;2`0;2`/02DU9@80;2`/00P002`002`/;00/;2`0
000/01H000190000000/001OG`Sooooo0006ooooo`080<G5a@2GaLD0UlG507^^a@2GUlD0GlG50<G5
k`1OUlD205nGU`04032G[P1OUiL0GiNG001OU`8009NG010005nG05nGU`00Gel0GiNG09O5a@1OaLD0
aLG_09O5a@2^f^l0e=CD0?o_a@35aIL0aLEO09NGU`2GUel0aG]<0P1OGel204U9B@80GiMO00X0GemO
05AD9@19BDT0GiL0001OG`19BDT0Gel002`/;00FAQH0BDU90P0/;2`01019BDT004T005mO000`E002
02`/;08005l00P19BDT202`/;00:05mO000/;2`0BDU902`/;019BDT0NGUi0?o_k`1OG`00BDU90000
B@80;2`/00<0BBDU04U9B@0/;2`01019BDT00`00G`00Gel005mOG`0304U9B@0405mOG`25QHD0GiO5
0:NWY`80][Jf00@0YjNW05nGU`2WYjL0QHF50P2WYjL02`1OUiL0Lg=c07=cL`1OGel0Gg/`05nGG`2G
Uel0Gel004U9B@1OUel0BDU90080GemO0P1OUel00`1OGel0GiNG002GU`02002GU`030:NWY`1OUlD0
GiNG00<0GiNG01D0GlG505nGa@1OUlD0GiNG05nGa@1OaLD0Pinf0:NWY`1OUiL0GiO505nGU`1OUlD0
GiNG05mkU`1OGel0BDU90019000/;2`002`002`0000F5P000P00;0001@0/;2`00000000/0000;000
5QHF00<0000/00@0;2`/02`00000;00001H00P0/;2`0400002`002`00000;00/000002`001HF0000
0000;2`/000/000002`0;000000/000F5P00;0000000;0000002000/000402`/;00002`002`00000
0080;2`/00@0000002`0000001H000000P0/;2`0100002`000000000000k0003000/000502`/;000
0000B@000000;00000000P00;0001`0/000002`002`0000F;1H00000000/000000000`0/;2`0100F
;1H0;2`/0000;00002`2000/000704T0000F01H0;2`/02`/;00002`0;2`/04T00002000/000502DF
0000;000;00002`/;00002`00P0/00000`005QH0000002`0000202`00080000/00D05P0F02`/;000
02`0000/000/000202`/;08002`000<0000/04U9BOooool01oooool000Kooooo00/0][Jf09NGa@35
aNl0Winf05nGa@2GaLD0aLG_09O5a@00UlD0GiNG032GU`0205nGU`05002GG`1OUiL0GiO505nGU`0`
Ug/00P1OUiL02P2GaLD0aLG_0;Jf]P3_aNl0]/gR0;Jf]P3_aLD0aLFG0>o5U`2GUel209MO000705mO
G`2f][H0Gel004U9B@1OGel0;2`/05mOG`0204U9B@0705nGG`0/;2`0Gel004U9B@0/;2`0>c/k04U9
B@0202`/;0040000B@19BDT0GemO05mOG`<0BDU900l0;2`/001OG`19BDT0;2`/04U9B@00;000;2`/
000/0000B@00;2`/0;K=c@1OGel004T002`/;000G`000P0/;2`00`0k>c/0B@0002`/;00202`/;00=
000/0019BDT0Gg/`02`/;000B@00BDU907=cL`2GGel0GiNG05B3P`2GaLD0GenG0:NWY`0308F5Q@03
09NGU`2GaLD0UiNG0080GiNG00H0GemO05nGG`1cLg<09G1D04U9B@0/;2`205mOG`0:05nGG`1OGel0
Gg]O05mOG`19BDT0GiL007=cL`00GiL009MO001kU`@0GiNG00D005nG05nGU`1kUjh0GiNG09NGU`02
05o5U`0=09O5a@1OUlD0WkJf05nGU`2WYjL0GiMO05nGU`25QHD0GiNG05mkU`1OGiL005mO04U9B@02
02`/;0040019000/5QH0000/0000;0@0000000D05R`F000/000/;2`0000/02`/;0020000;00301HF
0000;000;2`/0080;2`/0P00;0004@0/00005QHF02`/;00/;2`0;000000/000002`0;000000/000/
;2`002`002`00000;000;0000000;0005P00;0000080000/00D0;2`/00000000;0005R`F02`00002
0000;080000000`0000/00005P0002`0;2`/000/00190000;2`/0000;00F0000B@00000/000/0003
000/000403/F5P190000000/04T000<0;2`/00<001HF02`/;00/;2`00P0/;2`02`2GGel0GiNG01HF
;019000002`00000000002`0000002`0000000005QH/008002`000H00000000/0000;000;2`/01H0
5P00;0020000;00>02`000000000;00002`/;000;000;000000000190000000/04T0000F5P00B@00
02`/;019BDT8ooooo`001_ooool03`35aNl0UlG509O5a@2GaLD0][Jf09O5a@3De=@0UiO509O5a@1O
UlD0Njj^09O5U`25QHD0GemO0:NWY`0205nGU`0D05mOU`00Gel0GiO509NGa@2GaLD0aLG_0>7Qh@35
kmX0aLG50>o_a@2f][H0klFG09NGU`2GUel0Wc000<EO002f][H0UiNG09NGG`2GU`0205mOG`0401I6
5P19BDT0BDU902`/;080Gel000d0GemO02EDE01OGel005mO05mO0000G`00BDU905nG001OGc00;2`/
0019001OG`00BDU90080Gel000`0ATHF000/0019BDT0;2`/000/000/;2`005mO0=[5[P00Gel0Gel0
04U9B@1OG`0202`/;00303/k>`0/;2`0000/00<0;2`/00<005mO06UYJ@1cLg<00P1OG`00201OUel0
GemO08F5Q@2WYkh0UlG505nGU`2WYjL0GenG0P1OUiL01@1bSXh0UiNG09NGU`1OUiL0GiMO00<0GiNG
00@0Gg]k04U9B@00Gel0BDU90`1OGel02`0`Gc00GemO05mOG`1OGel0GiMO04U9B@00Gel0Gg]k002G
U`1OaLD0GiO500<0GiNG00<0NiNG05o5a@1OUlD00P1OUiL01@2GUiL0UlG509N^[P2WYjL0GiO500H0
GiNG00@009MO001OG`00;000BDU90`0/;2`01P0002`00000000000000000B@000000;080;2`/0P00
;0000`0/;2`002`002D00002000/0080000000D0;000000/0000;0005R`F02`00004000/00030000
;00F;1H002`00080;00000h002`00000;000;000000F02`0000002`002`002`0000/;2`002`00000
5P0/0000000/000/00<0000000<05R`F02`/;00002`00P0002`0100/;2`0000/01H05P0002`202`/
;08002`000@0;2`/02`F5P000000;2`/0P0002`202`/;00301HF;00/0000;2`/0080000/0P0/;2`0
2@0F;1H002`0000/000/0000;2`/000/000/0000000001H/5P02000/00050000000/000002`002`0
000001H00`0002`01P000000000/000/000/5QH0000002`00080000000<0;2`/000/000F5R`00P0/
;2`00`1O05ooooooooooo`06ooooo`001_ooool05035aLD0UlG509O5a@2^aMX0][Jf09O5a@3QhN40
aLG50<G5k`2GaLD0C:j^05nGU`2GaLD0GiO5002GU`1OUiL009MO032GU`00Gel0GiO50P35knl20=CD
e0050=[JfP2GaLD0][Jf0<FGU`3_UiL00P35Uel01P2GGel0aIMO0<FGG`25QHD0UiMO05mOG`80GiMO
0100>c/k04U9B@0/;2`0;2`/05mO001OGel0BDU905mk<019BDT0GemO05mO0000B@00BDU905mOG`0`
JC0005l00P19BDT01P1OG`00UemO05nGG`0k>c/0;2`/04T00080;2`/00H0BDU90<G5a@20P800BDU9
02`/;00004T302`/;00403/k>`19000004T004T00080;2`/00<005l001Hk5P0/;2`00`1OGel01P19
BDT005mO05mkN`2WYjL0GiO505nGU`80UlG500L0YjNW05nGU`1cLg<0YjNW07=cL`1OGel005mO0080
GiNG00T0<7]<001O0019BDT005mO001O001OG`00Lg=c05mOG`00Uel00P1OUel0101OU`00QHF505nG
G`1bSXh205nGU`030:NWY`1OUiL0GiNG0080GiNG00T0UiNG05nGU`1OUlD0GiNG05nGa@2WYjL0WinO
0:NWY`2GUiL01@1OUiL0201OGiL0GiNG05mOG`00Gel004T002`/;00U5P0002`00P0000001P0/;2`0
0000000/000F;1H0;2`/000/0080;2`/00h002`002`0000U01H002`00000000/0000B@0002`00000
;000;2`/01H00000;000;2`/000/0080;2`/00<0000002D05P0/00000P0002`03P00;000;2`/000/
000001H0;0000000;000000002`00000;00/;2`05P0F0000000002`0;2`/0P0000001@19000001HF
0000;00002`0B@000080;2`/00/0000/01H/5P0002`0000/02`/;00/0000;2`/04T0000F;1H0;2`/
000/000502`/;00:0000;0190000000/02`/;0000000;2`/01HF5P00;000;000000/00<0000/00T0
02`000005P0/;2`002`002`00000;000;000000/000F;1H00P0002`01P0/000002`002`/;00/0000
02`002`/;080000/00L002`004T00000;0005QH/0000;00/;2`0BDU900Sooooo0006ooooo`050<G5
a@2GUiL0UiO509O5a@2WYjL00P35aLD01035knl0aLG50:NWY`1DWil305nGU`03002GU`1OUiL0GiNG
008005mO00@0GiNG0;Jf]P35aNl0][Jf0`35aLD03P1OaLD0][Jf0<FGG`35UiL0UiMO0:ikG`1OGel0
aIMO09MOG`0/;2`0UiMO05mOG`19BDT0>c/k0P1OG`001P19BDT0GemO05mOG`1OGel0Gel005mOG`80
Gel00P1OGel0501OUel0Gel`05mOG`1OG`00BDU9001OG`19BDT0Gel004I65P0/;2`004T0001O000/
;2`0aLG50<G5k`1`L2D0BDU90019000/;2`0B@000P0/;2`02@0F;1H002`002`/;019BDT002`002`/
;01OG`00Ng/`04U9B@0307=cL`0305nGU`1OGel0NiN^00<0YjNW0P2GUlD0102GUiL0LXj>05mOU`1O
Uel305mOG`0705nGU`25QHD0GUiN04U9B@1OGel005mO05mOG`0205nGG`0305mO<01OG`00GiMO0080
BDU900<0GemO05nGG`1YQHD00P1OUiL01`2GUiL0GiNG09O5a@2GUiL0GiN^05o5U`2GUiL00`1OUiL0
1@2GaIL0YjNW09NGU`1OUiL0Lg=c0080QHF500@0GiNG05nG[P1OUiL0GiNG0P1OGel00`19BDT002`0
02`/;00302`/;005000/0000000002`002`/;000;0000`0/;2`00`00000002`000005P02000/0080
000/0P000000100/00005P0F000/0000;00402`/;004000F5P0002`0BDU9000/00<0;2`/00<05P00
0000000000000P0/;2`01@000000B@0001H05P000000;0000080000000/0B@00000/00005P0002`0
04T00000000002`002`/;000;000000F000/000202`/;0040000000/0000000/000F5P80;2`/00L0
000/02`/;00/;2`0000/02DF000/;2`0000/00@0;2`/00@0000F000/00000000000/0`00;00302`/
;0030000;00/;2`0;2`/0080000000/001HF0000000000000000000/000/;2`002`001H/5P00;000
000002`00002000/000502`0000F5R`0;2`/02`/;019BDT02?ooool000Kooooo00P0NiNG09nOW`2O
][H0/[jn09N^a@35aMX0cLg=05nG[P80<9NG01h069N905nGU`1k[Zh0NiNG07:>SP1YQFT0UlG507ZM
W@1ONg/0GiMk0:j^a@2n_[h0[/GJ0;K=c@2fc=L0UlG50;kCd`2GaIL0aJik0=ZGG`2GUel0Xg]807]k
<02^[Ul0Ug]O05mOG`1kNel0Gel`031O<00gCdl204U9B@0705mOG`0`Gel0Gg/`09NGG`29RDP0Ng]O
06V5J@0205mkG`0P05nG<01ONc00B6d`05AD9@1DE5@0ATHF05mO<00`G`0004H002=B2`19BDT09BD0
05AD9@2B`i80aLG506>LC00`@S00>aHF000k000U9@005R`F01Hk5P00;0008C@Q001D000F;1H09BD0
0016000k>c/0ATI603I1=P1DE2D204U9B@0=06MWI`1ONg/0Gg^G0:^f]P2_[jl0Ph>307^^[P2GUlD0
WkJf09nOP`1aLG40GemO06UYJ@0205mOG`0B05nGG`1DE5@0JFUY03eDE00`G`009E@U05AD9@1OG`00
Ng]O05ADE01OGdP0E5@U031k<01ONel0Gel005mOG`2GUel0EXUk0P1OUiL0201kUiL0Gjj^0:NWY`1k
[YL0NiNG07:>SP1kUiL0GiNG0`1OUjh00`2OWil0PinO05nGU`0205nGU`0507]kU`1kUiL0KING07^G
U`1bSXh00P1OUiL05@1ONel09EAD02Td:@0F;1H0>c/k000`5P00;000;1HF01H/5P0F8B40;000000/
00005QH05R`F000F000U01H05P/;01H0000k000001HF000/0002000F000402`F5P0Q8AH05P0001H0
5P80;2`/0P0F;1H02P0;5P00000/01H000005P005P0001H05P0001H02`/;01HF5P005P02000/0003
02`/;00002`05QHF0080;00000P05QH001H00000;000;2`/01HF5P0/5QH05QH/01H05P805R`F00T0
>aHF01HQ8@0F5R`05QH002`/;00F5P0002`001H/5P0;5QH00P0F5R`01`0F0000000/01HF;00/;2`0
7QH;01HF;00/;2`00P0F;1H03@0/;2`05QH/03@Q8@0002`05R`F01HF5P0F;1H001HF01HF5P0/;2`0
5R4Q01HF;00/;2`00P0F;1H00`0/5QH05QH002TQ5P0200005P80;2`/00d05R`F01HF;00N8@/05P0F
01HF0000;0005R`F02DF000k5QH02aHQ000F5P0/;2`0BDU900Sooooo0006ooooo`0409NGa@2GaLD0
][Jf09:^a@80UlG50P1OUiL01@2GaLD0][Jf05nGU`1OUiL0Lg=c0080GiNG00@009MO05nGU`0`UiL0
GlG50P2GaLD40<G5a@0:0;Jf]P2GUiL0aLFG0<FGG`2GUel0aIMO099OG`1OG`00Lg=c09MOG`80GemO
00D0BDU905mO000UE5@0GemO04U9B@0305mOG`0:05nGG`1kNel0GemO05mOG`1OG`00GiMO05mOG`1O
G`00<5l`04U9B@8004T000/002`005mO001OGel0Gg/005mO0000B@00GiNG0<G5k`19BDT0Gel002DU
000202`/;00604U9B@0/;2`0;2`/02`/;000>`0002`00P19BDT0300/;2`0BDU90019001DE2D0;2`/
07=cL`1OGel0UlG505nGa@2WYjL0UYJF05mOG`80Lg=c00@0GiO505nGU`1cLg<0Gg]O0P19BDT205nG
G`0408F5Q@00Gel0BDU903/k>`80Gel000L0;2`/001OG`1OGel0Gel005A`E02GU`00UemO0080GemO
00H0Gel009NGG`1OUel009MO05nGU`1cLg<705nGU`0405mOU`1OUiL0YjNW08>O]P80UiNG101OUiL0
1`1kUjh0UiNG05nGU`25QHD0GenG05nGG`1OGel00`0/;2`2000/00040000000/;2`05R`F02`00080
02`000<0;2`/000/0000;0000`0/;2`010000000;00004T0000/;2`4000/000502`/;000;000;2`/
02`/;00F5QH0100/;2`00`000000;00002`F5P020000000502`00000;000000/02`/;00001H00P0/
00002P00;0000000000/000000005QH002`/;000;000;0000000;000;00202`/;0@0000/00d0;2`/
0000;00k5QH0;2`/0000;000;000000002`0000002`05R`F02`/;000;000000/00<0;2`/00<05QH/
02`/;000;000100000001P0/;2`05QHF02`/;00/;2`002`002`/;08002`000X05QH/02`/;00/;2`0
;2`/000/000002`0000001H/5P0002`0;2`/0P00000202`/;00401HF;00/;2`0B@0004U9B@Sooooo
0006ooooo`0>09O5a@2f][H0aLG508^WY`3De=@0UiNG05nGU`2WYjL0e=CD05nGa@2B[Zh0GiMO05nG
U`00GiL2002GG`0505nGU`2_[jl0YjNW05nGU`2WYjL00P2GaLD06`35aLD0UlG508F5Q@00UiL0aLFG
0<G5G`2GGel0aEl007]OG`1OG`00GemO05nG001OUel0Gel002`/;01OGel0E5@U05nGG`1OGel0GiMO
04U9B@1OGel0GiMO07^G<01OGel0GiMO09MOG`0205mOG`0H001OG`0`E000BDU904U9B@00G`00;2`/
001O001OGel0<4H000190019BDT0aLG50?o5U`0/;2`004T0000k0000;000B@0000190000;000;2`/
04T0000F;1H0;2`/0P19BDT01@00B@0002`004U9B@1OC4`0;2`/0080BDU902P0UiNG05mOG`1OUiL0
Ph>305mOG`2GaLD0UiNG05nGU`1OGel0Lg=c05mkG`19BDT0GemO05nGG`1OGel0Lg=c05mO0019BDT0
;2`/04U9B@0/;2`0Gel002`/;01OG`00BDU905AD9@1OUel0UiMO09MO002GGel0Gel009NG001kUel0
09NG05nGU`1OGiL0GiNG09NGU`00UiL0NiNG201OUiL0101OUlD0GiNG07=cL`00UiL705nGU`0405mO
G`0FATH002`002`00080;2`/00@002`002`/;00/;2`0000/0P0/;2`02@0002`0;2`/000/000F;1H0
;2`/0000;0190000000/02`/;002000/0003000F5P00;00002`00080;2`/00H0000/02`/;00/;2`0
;2`/0000G`2f][H200000003000/000F;1H002`00080;2`/00@002`002`/;00002`001H00P00;000
10000000;000000/000/000302`/;00;000/000002`0000/02`0000F5QH0;2`/000/00190000000/
04T0000002`00`0/;2`01`190000000/0000;00/;2`05R`F02`/;000;0000`0/;2`0200002`001HF
02`/;000;000;0000000;00/;2`000001P0/;2`01@000000;2`/000F5P0002`0;0000080000/00H0
;2`/02`0000k00000000000/000/000302`/;00401HF;00/;2`0;2`/04U9B@Sooooo0006ooooo`80
UlG500`0][Jf09N^[P2GUiL0GiNG05nGG`2GaLD0YjNW05nGU`23][H0Lg=c05mOG`2f][H2001OG`09
001OU`1k[Zh0GiNG05nGU`1OUlD0UlG50;Jf]P35aNl0WkJf0080GiNG00H0YjNW0<FGG`35Uel0L`00
05AD9@00Gel305mOG`0505mO0019BDT0Gel007]O<01cLg<00P1OGel205nGG`07001OG`1ONel0GiMO
05mOG`00Gel0GiMO05mOG`0204U9B@04000/0000B@00;2`/04U9B@8005l000@09DTU02`/;02f][H0
aOo50`19BDT0100/;2`002`0000/0000;00302`/;00304U9B@0/;2`0;2`/0080;2`/00H0BDU9001O
0013LT<0BDU902`/;019BDT307=cL`0<09nf]P1OGel0QHF505nGa@2GUiL0GiMO05nGU`1YJFT0GiMO
05nGU`1OGel0GiMO0P1OG`005@19BDT003/000190000G`00;2`/000/0019BDT0Gel0001O001OGel0
GiMO05nG002GUel0Gel005nG001kNel0GiNG05nGG`2GUiL0GiMO05mOU`0205nGU`08002GU`1OGiL0
QHF505mOU`1OUiL0GenG07^GU`1OaLD505nGU`0305mkU`1OUiL0YjNW0080GiNG00H0Lg=c05nGU`0U
E5@0;2`/0019000002`602`/;009000/000/;2`0;2`/02`/;00F;1H0;2`/000/000002`0;2`/0080
02`00P0/;2`00`000000;2`/000/00030000;005000F0000;00002`009NGU`0/;2`00P0000002P0F
;1H0;0000000000/0000000/02`/;00002`05R`F02`0000002`20000000404T0000002`05QH0000/
0080;2`/00/0000/02`000000000;2`/000/0019000002`002`/;00002`0;2`/01H/5P0302`/;004
0000000/;2`0;2`/01HF;080000000P0;2`/000/000/;2`0;2`/02D05P0/000002`002`/;080000/
00D002`002`/;00F;1H0;2`/0000;00302`/;00604T0000F01H002`0000/00000000;0000P0002`0
100F;1H0;2`/02`/;00002`202`/;005000/000U01H0;2`/02`/;019BDT02?ooool000Kooooo00P0
GiNG05nGa@1OUlD0QHF505mOG`1OGiL0GemO001OG`80GenG00X0NiNG05mOG`25QHD0GiMO09NGU`25
QHD0GemO07]kU`0007<0][Jf0P2GaLD0302GUiL0][Jf08>3P`1OUiL0GenG09NGG`35Uel0aEmO05mO
000`E000GemO04U9B@@0Gel000H0BDU905AD9@19BDT0BDU905mO001OGel204U9B@09031Y<01OGel0
Gel005mOG`1OU`00GemO001OG`0FATH0Gel00080BDU900L005mO04U9B@00B@005THF05mOG`35aLD0
UemO0080BDU900D004T002EDE00/;2`0BDU9000/000204U9B@0F02`/;019BDT0;2`/001O000/;2`0
BDU9001OG`19BDT0ATI608F5Q@1OUel0Lg=c05nGU`1OUlD0YjNW07]kN`19BDT0YjNW09NGU`2WYjL0
GiNG05mOG`80Lg=c00@0GiNG05mOG`1OGel0GemO0P1OG`001@0k>c/005l000190019BDT004T00080
05l000/0Gel`05mOG`1OGel0GiMO07=cL`1OU`00Gel0079b@`1OUiL0GemO05nGG`02002GU`80GiNG
00h005nG05nGU`1OUiL009NG05nGU`00UiL0NiN^05nGU`2GUiL0GiO505nGU`1OGiL0GiNG07^GU`80
GiNG00H0GiO505nGU`1OUiL0GiNG02E`E019BDT202`/;08002`00P0/;2`20000;00502`00000;000
02`0000/000/5QH00P0/;2`01P000000000/000000000000000/000/0080;0000P0002`00`0/;2`0
;00002DF0002000/000604U9B@0/000002`002`000005QH0;2`/0P00;000300/;2`002`002`/;000
01H0;2`/02`000000000000/000/000/;2`0000F00000080000/00H0;2`/000/000/00005R`F000/
000002`202`/;00:000/000000005QH/02`/;000;000000/000/000/0000000/02`F5P80;00000P0
B@0002`/;00/;2`0;2`/01HF;00/;2`002`00000008002`000<0;2`/000/000F;1H00`0/;2`01@00
02`0;2`/0000;00F5R`0B@00008002`000D0000/0000000/;2`05QH0000/000202`/;0070000;000
;000B@0001HF000002`0;2`/04U9B@08ooooo`001_ooool205nGU`0<0:NWY`1<Uel0GemO002GU`1O
UiL0GiO509NGU`1OGel0LZFU05mOG`1cLg<0GemO0P19BDT02`1OGiL0GiNG05mOG`25QHD0UiO50:NW
Y`2GaIL009NG07^^[P1cLg<0YjNW00<0aIMO01<0Gel004U9B@1OGel0Gel005mOG`19BDT0G`0004U9
B@1OGel09EAD001OG`19BDT0;2`/04U9B@00G`0005mO04U9B@1OG`00BDU9008005l000h0BDU905nG
G`19BDT005mO001O001OG`00BDU905nGG`19BDT0ATHF0>ook`35aLD005mO04U9B@80;2`/00@05R`F
00190019BDT0BDU90P0/;2`01P00G`005THF02`/;00/;2`005l004U9B@80GemO00P0O7al05nGU`2G
UiL0Lg=c09NGU`1OUel0YjNW05iNGP<0UiNG00@0GenG05mOG`1OUiL0SXib0P1OGel0401cLg<005mO
05mOG`19BDT0GemO04I6AP00G`00;2`/04U9B@1OG`00BDU905mO0019BDT005l0001OG`1OGel205nG
G`0605nG002GNel009MO002GU`1OGiL0GiMO0P1OUiL02`0`UiL0GiNG05mOU`00UiL0Lg=c001OU`1O
UiL0LXj>09NGG`1OUiL0GlG50080GiNG00@0GiMO05nGU`1OUiL0GiNG0P1OUlD205nGU`0505mkU`00
Gel0;2`/000/001900000P0/;2`03@0F;1H0;0000000;00/;2`002`002`0000/;2`05QH/09NGU`00
0000;0000000;00000000P0/0000300F;1H000000000;019BDT0;00002`/;00000005QHF000/000/
0000;2`/000/0080;2`/00`002`00000000/0000000/02`/;00/0000000/01H05P0/;2`002`002`0
000002`202`/;00502D05P19000000000000000/;2`00P00;0001@005P0002`000000000;000;2`/
0080;00000P05QH/0000000/000002`002`0000/;2`0000/01H05P<0;2`/00H002`002`/;00/;2`0
5R`F02`00000;00502`/;00301HF;00/;2`0;2`/00<0;2`/00T002`002`/;000;000;2`/000/0000
000002`00000;00F5P000P0/;2`01@0002`0;2`/02`/;000;000;1HF0080;2`/00<0BDU9oooooooo
ool01_ooool000Kooooo00D0GemO05o5a@2GaLD0Gg^G05mOU`02002GU`060<G5a@1cLg<0GemO07]k
N`00Gel0GiNG0`00Gel02`1OaLD0JFUY05mOU`1OUiL0UlG505nGU`2GaLD005mO09O5a@00Gel0YjNW
0080aIMO00L0UemO05mOG`1DE2D0GemO09MO0000B@00GemO0080BDU900<0GemO05ADE000G`00100/
;2`02P19BDT05S/F0000;000B@0005l002`/;000G`0007<005AD9@00Gel205mO000505mOG`0/;2`0
;2`/07RWH`35aLD00`19BDT00`00G`00BDU904I65P0204U9B@0502`/;019BDT0BDU904U9B@0k>c/0
0P19BDT01P190000BDU902`/;00/;2`0E5AD001OG`<0GemO0P1OUiL01P00Gg/0YjNW0:NWY`00Gel0
UiO505nGU`80GemO00T005mO04U9B@1OGel0QHF505nGG`19BDT0;2`/05iNGP19BDT00P0/;2`04@1O
G`0005mO04U9B@0FD1H0GiMO001OG`1OUel0Uel009NGG`1OUel0NiM<002GU`1cLg<0GemO07=cL`1O
UiL009NG00D0GiNG0P00UiL01@1OUjh0GiNG05nGU`1OUiL0GiO500P0GiNG00H0YjNW05nGU`1OGel0
;2`/000/000002`2000/000401HF5P000000;2`/000/0080000000@0;2`/00005P00;000;2`/0P00
02`03@0/;2`002`002`/;00F;1H0;2`/000/000/;2`002`002`/;00/00005R`F02`/;00002`00P00
00003@190000;00001H05P0002`0;2`/0000;000;000;2`/000/000/;2`0000/02`0001900000P0/
;2`00`0002`0;2`/0000000202`00004000/000/;2`0;2`/02`F5P80;2`/00D002`002`0000/;2`0
;2`/01H/5P0202`/;0030000;00/;2`0B@000080;2`/0P0002`03@0/;2`0000/02`/;00/;2`05R`F
02`/;00002`0;2`/0000;00/;2`002`002`/;000;0000P0/;2`01@000000;00002`/;000;000;2`/
0080000/0`0000003000;00001HF000/000002`0000002`/;000;000;2`/01H/5P000000;2`/001O
G`Sooooo0006ooooo`0T05mON`2GUlD0Ng]k04QOU`1kNg/005mk031ON`0jJFT005mO05nGU`1ONhL0
Gg]k05mOG`0`Gel0GemO001OG`1DE5@0GemO05mkN`1OGel0WinO05mOU`0`Gg/0LXj>05]nS01kNg/0
aJik0:ikG`2GUc00Ug]O05mOG`12FQ<0>U0j030`<019BDT0Gel`0P1OGel07P1DE5@0B6d`05mO<00k
>c/004T002`/;00UE2D0BDU902`Q8@0F>aH0>c/k01H/5P0UBBD05THF02`/;01?CcL005mO02EDE01O
G`009DTU01H/5P0F>aH0^[Zm07URAP0FATH0BDU902ED9@00G`00;2`/01I15P80BDU900P05S/F02ED
9@0U>bD0>c/k03@d=0199BD05S/F03/k>`80BDU902H0E71D05YJFP1NGUh0E5AD05A`L02>SXh0]YnO
06VLW01ONhT0NiNG05mkU`1OGg/0<7^G06UYJ@1ONel0C6=<02ED9@1DE5@0BDU904I6AP0`Gel005@`
03/k>`1JFUX0>c/k02E99@0k>c/0BDU902Dk9@1DE2D08dd;05mOG`1OG`00Gg/`07]OG`2>LW80GemO
082>LPD0GiNG00<0GjjG06fGX`1OUiL00P1OUiL03P1ONiL0GiNG032GU`1TP8h0JHF5032GU`1OUiL0
PinO05nGU`00UiL0GhVS07^GU`1O[/D0GiN^0P1OUiL01`1kUiL0GiNS05mkU`1DL700>c/k02`/;00U
9C/00P0F;1H00`0U01H09AH001H/5P0201HF5P0<01HF;00;00005P0F01HF000/;2`05P0F0000;00U
000002`0000Q2`005QH002`00`0/;2`05`00;0005R`F02`/;00F;1H05QHF00005P0F01H05P0001HF
5P0F01H0000/03/0000002`0>aHF01HF;00Y8AH0;2`/01H/5P0002`05R`F02DF000F5R`05R4Q0080
9AH001l0>aHF01HF;00/;2`05QH001hF5P0/5QH09@0F02`/;0005QH05QHF02`/;00F8B405QH/01H/
5P0/5QH05R`F000/000F5QH08B4Q01H/5P0F5QH05QH/02`/;00001H00000000F000/;2`05R`F03/k
>`0/;2`0>c/k0080;2`/00l08B`Q01H0000F;1H0;2`/0000;00F;1H001HF00/;5P0F5P0001H00000
000/5QH001H00000000Q5QH00P0/;2`0200k5QH0000/01H/5P0F01H05R`F01HF000/;2`0BDU92?oo
ool000Kooooo00/0GiNG05nGG`1OUel0TW^G05mOG`00Gel0GemO001OU`00Gel0GiNG002GN`03001O
G`<0GemO00X005mO05mOG`1OUiL0UlG505nGG`00Gel005nG04akN`35aIL0aIMO0P2GUel01P1OG`00
GemO05mO<01OUel0GemO05nGG`80GemO00<0GiMO05mOG`0`Gc000P00G`001@0/;2`0BDU904U9B@0/
;2`05THF00<0BDU90P00B@002`1OGel0E5AD02`/;019BDT0GemO02`/;019BDT0GiNG07UiN@0/;2`0
05l00080;2`/0P19BDT202`/;004001O0000B@0005l0001O0080;2`/00T0BDU900190000G`0005mO
07=cL`19BDT0QHF505nGU`1OUel00P1cLg<01@25QHD0YjNW05mkU`2GUiL0BDU90080GiNG00<0BDU9
05nGU`1YJFT00`19BDT205mOG`0304U9B@00Gel0E71D0080BDU900T004T002`/;019BDT0BDU9031O
<01OG`00BDU905mOG`19BDT00P1OGel0201OUg/0GiNG05nGU`1OUiL0GemO002GU`1OUlD0Gjj^0P00
UiL405nGU`05032GU`1cLg<009NG05nGa@00UiL00`1OUiL405nGa@0305nGU`1OUlD0GiN^0080GiNG
00<005mO04U9B@0/;2`00P00;00010190000;2`/000/0000;00502`/;00:0000;0190000000/02`0
0000;0009AH005mOG`0/;2`0000004T0008002`000<05R`F02`0000002`00P00000202`/;00G01H/
5P0/0000;2`/000/000/;2`0000/02`/;00F5R`002`002`/;00002`0;2`/000/000/;2`09C/U000/
000002`0;2`/0000;00/;2`002`002`/;000;0001@0/;2`0200F5R`0001907=cL`00;000;2`/04T0
000/;2`05R`F1P0/;2`01@0F5R`0;2`/0000;000B@0000190080;2`/00L0000/01H/5P00;000B@00
0000B@0/;2`002`00080000000@0;000000/0000;000000/0P00;00302`/;0080000;00/;2`0;2`/
02`/;00U5P0002`002`/;019BDT8ooooo`001_ooool0101cLg<005mO001OG`1OGg/205mOG`0504U9
B@1OGel0GiNG05nGU`0`Gel00P00Uel01P00Gel0GemO05mOG`1OGel0<5mk001OG`<0GiNG00<0BDU9
001OG`0`NiL00P35Uel01`35U`00GemO05mOG`00B@00NiMO07=cL`1OG`000P1OUel01P19BDT005mO
04U9B@0`G`0007<004U9B@80;2`/00@005l004U9B@0/;2`0BDU90`0/;2`04P00G`00BDU904U9B@19
BDT0GemO04U9B@00G`00Gel00<G5a@1iHTH005l002`/;000B@00G`00001OG`0/;2`05THF001O0080
;2`/0`19BDT03`1DE2D0;2`/04U9B@19BDT0;2`/04U9B@0/;2`0<5mO0:NWY`2GUiL0QHF507=cL`2f
][H0aLG509O5a@0205nGU`0705mOU`1OUiL0GiNG09NGU`13LXh0GiMO05mOG`0304U9B@0A05mO0019
BDT0BDU904U9B@19000004T002`/;0190000BDU904I65P00G`00BDU905mOG`1OU`00Lg=c09NGU`0`
Ug/00P1OGel01P00UiL0GiNG05nGU`1OUiL0PinO001OU`<0GiNG00L0GiO505mOU`0`UiL0QHF505mO
U`1OUiL0GiO500D0GiNG00L0GiO505nGU`1OUlD0GiO505nG[P25QHD0GiNG008005mO100/;2`01`00
;000;2`/04T00000;000000/01HF0000;0000P190002000/000302`/;00002`0ATI60080;2`/00H0
000/07=cL`0002`002`002D05P0/;2`20000000904T0000002`0;2`/01HF;00/000002`00000000/
0000000/00P0;2`/00@05R`F0000;00/;2`0;2`/0P0/00001@0/;2`001HF02`/;00/;2`0000/0080
;2`/00<0000/02`/;00/00000P0/;2`02@0002`002`00000;00/;2`002`002`/;000;000;2`/0000
000502`/;00?0000000/;2`004T002`/;00F;1H0;2`/000/0000B@00;2`/000/000000005P0F000/
0000000002`00080;2`/00D0000/02`/;00/;2`0;2`/0000;00202`/;00502`0000/;2`0;2`/04U9
B@0/;2`02?ooool000Kooooo0P00GiL00`00Gel0<5mO001OG`02001OG`80GiNG00<0GemO001OG`1O
Gel00P1OGel02000Gel0GemO001OG`0jJFT0GemO05nGU`1OGiL0BDU90P00Gel01P1kUg/0aIMO09NG
G`2GUel0GemO04U9B@80GiMO00D0GemO04U9B@1OGel0BDU9001OG`0204U9B@0305mO000/;2`0;2`/
00<0BDU900<0;2`/02E99@0/;2`01@19BDT00`0F>aH007<005mO000205mO000=0;Jf]P2GaLD05THF
001OG`0/;2`004T0001OG`00B@0005l002E99@00G`00;2`/0019000204U9B@0502`/;00k>c/0;2`/
001O000/;2`01@19BDT05025QHD0GiNG09O5a@35aLD0YjNW07^G[P1OUiL005nG05nGU`1OUlD0YjNW
05nGG`1NGUh0GemO05mO0000;000Gel004U9B@0/;2`005mO0P19BDT202`/;004001O0000B@00Gel0
05AD9@<0BDU900D0GiMO001OG`1cLg<0Gg]k002GG`0205nGU`06002GU`1OUiL0GiNG05nG[P2WYjL0
GlG50P1OUiL01@2GUiL009NG03Z5Q@1OUiL009NG0080GiNG00D0GlG508F5Q@1OUiL0GiO505nGU`02
05nGa@0409NGU`1OUlD0GiN^05nGU`80GenG00@0GemO02`/;00/;2`05QH00P0/;2`20000;00=000/
000/;2`05QH/04T0000002`0;2`/0000000/000002`002`0000/;2`0000/04T000020000;003000/
000/;2`05QH/00@0;2`/00/0000/02`/;00F5QH000000000;019000002`004T0000002`0;2`/000/
000202`/;0<0000/00@05QH/04T0000/;2`0000/0P0/;2`00`0002`001HF04T0000502`/;00301HF
;00/;2`002`00080;2`/00T00000000/000F;1H0000002`/;000;000000/02`/;01900001`0/;2`0
100002`05R`F0000;000;00302`/;00304T0000F;1H002`000<0;2`/0P00;0001@0/;2`0000/000/
0000;000;2`/008002`000@0<4H`02`/;00/;2`0BDU92?ooool000Kooooo00@0GiMO001OG`00Gel0
<5mO1000Gel01P1OGel0GiMO031OG`1OGel0GiMO05mOG`8005mO00@0GemO031ON`1OUlD0GiNG0P1O
Gel02P1O05l0UiNG0<G5U`2GGel0BDU90<FG001OGel0BDU905mO001ONc0305nGG`80GemO00`0BDU9
001O001OGel0BDU902`/;000B@00Gel004U9B@00G`00>c/k02`/;000Gel404U9B@0;02EDE000G`00
GiMO04U9B@1OUiL0aLG505mO0019BDT0;2`/04U9B@00;0000P19BDT00`1OG`005THF0019000202`/
;0040019000/;2`0;2`/04I65P@0;2`/02<0BDU905mOG`16ATH0GemO09NGU`1OUiL0YjNW09NGU`1O
UiL0Ujk508F5Q@1OGiL0GlG509O5a@25QHD0BDU9031OG`1OGel0BDU902`/;000;000BDU905mO000/
;2`09C/U04U9B@1OG`00BDU904T0001OG`0005mO03/k>`2GG`00GiMO09NGG`0205nGG`0405mOG`1O
Gg/009MO002GU`D0GiNG00@0GiO505nGU`1OUlD0GiO50P1OUiL00`1OUjh0GiNG05nGU`0205nGU`04
09NGU`1OUiL0GiNG05nGa@<0GiNG0P1OUlD01@1OUjh0GiNG05nGU`1OUel0GemO00<0;2`/00@0000/
02`/;00002`0;2`/0P00;0001@005QH0;2`/000000000000B@000080;00000<0000001HF;00002`0
1@0/;2`02P0/5QH0;2`/02`/;00/;2`0000/02`/;00002`05QH0000/000/0002000/000400000000
02`09@0F02`00080;2`/00l0000/02`/;01900005QH/02`/;00002`0000002`/;00002`0B@0001HF
;0000000;2`/0000000/00000`0/;2`00`00;000;2`/02`/;00202`/;00;000/000F;1H0000002`/
;00002`0;2`/000/000/;2`001HF02`/;000;0001@0/;2`0100F5S/004T002`/;00/;2`205mOG`05
02`/;00F;1H002`0000/000/;2`00P00;0001@00000002`002`/;000;000;0000080;2`/00<0;000
02`F5P0/;2`00P0/;2`8ooooo`001_ooool3001OG`04031OG`00Gel0BDU9002GG`8005mO00<0GenG
001kG`00Uel00P1OGel2001OG`0?05mOG`1bLW80UlG505mOG`00Gel009NG05nGU`35aEl0[W/`05mO
G`1OU`00BDU905nGG`1OG`00GemO00<0GiMO00H005l004U9B@00;000Gel0001O000k>c/202`/;0@0
BDU900<0Gel`04U9B@0/;2`00P00Gel0600/;2`0Gel005mOG`00L`00Gel005mOG`35aLD0][Jf001O
000F>aH005l002`/;01OG`00BDU900190000Gel09E@U05mO0000G`00;2`/0019000/;2`0BDU903/k
>`80;2`/01@0BDU902`/;000;00002`004U9B@1cLg<0YjNW09NGU`1OGel0Lg=c05mOG`1YQHD0YjNW
05nGU`2f][H0GiO505nGU`1OGel0>c/k001OG`80BDU900H0;2`/04U9B@0/;2`0;2`/03/k>`1OGel2
04U9B@0402`/;01OGel0Lg=c02ED9@80GiL00P1OGel0101OUel0GemO031kN`00UiL205nGU`05002G
U`1OUiL009NG05nG[P1OUiL00P1OUlD01@2GaLD0GiNG002GU`1OUiL0GiMO00<0GiNG00<0UiNG05nG
U`1OUiL00P1OUiL0301OUlD0GiNG05nGU`1OUlD0GiNG05nGa@1OGiL0QHF507=cL`1OGel0;2`/01HF
;0<0;2`/00L0000/000/000/;2`05QH/02`/;00002`002`00080;2`/00<002`002`0000F;1H00P0/
0002000/00040000;00/;2`05QH/0000;0D0;2`/00@0000F02`00000;000;0000`0/;2`00`0k5QH0
;2`/000/000204T00080000/00<001HF0000;00/;2`00`0/;2`01P0002`0;2`/02`/;00/;2`0000/
02`/;080000/100/;2`01@0002`0;00002`/;00F;1H0000/0080;2`/00@002`002`/;000;000<4aD
100/;2`00`00;000;2`/02`/;00202`/;0030000;000;000BDU90080;2`/00<05R`F0000;0000000
1@0/;2`01000;000;2`/000/000/;2`2000/000402`/;00002`0;2`/04U9B@Sooooo0006ooooo`05
05mOG`00Gel005mO031OG`1OGel00P00Gel00`1OGel005mO001OG`02001OG`80GemO00P0BDU9001O
G`1OGel0Ng]k05nGU`00Gel009O505nGU`80aIMO00/0Ng/004U9B@1OGel0GemO04U9B@1OG`00BDU9
05AD9@00Gel0GiMO001O000204U9B@0:001c0019BDT0E5AD04U9B@00G`0004T004U9B@1OG`0005mO
02E99@80BDU900<005l004U9B@00B@000P1OGel01`1OG`0005l00<G5a@2f][H0BDU9001c000k>c/0
0P0/;2`03@19BDT005l004U9B@0004T0;2`/001OG`00G`00BDU900190000;000Gel004U9B@00B@00
0P0/;2`01000B@00;2`/02`/;00UE2D20:NWY`0=08F5Q@2GUel0BDU905mOU`25W9`0GemO08F5Q@2G
aLD0GiNG05mOU`19BDT0>c/k02`/;00204U9B@09001O0019BDT0BDU904U9B@1DE5@0Lg=c05mOG`19
BDT0;2`/0080GemO00@0ATHF05nGG`1OG`00GiMO0P1OGel00`00UiL0<7]O002GU`0405nGU`07002G
U`1ONiL0GiNG05nGU`2WYjL0GiNG0:NWY`0205nGU`06001OU`1OUiL0GiNG05nGU`2WYjL0GiO51@1O
UiL205nGa@0305mk[P1OGiL0GiNG0080GiNG00<0GemO02`/;00/;2`00P0/;2`00`00;000;00002`/
;00202`/;005000/000/;2`002`00000;00/00000P0002`02@000000;000000000190000000/02`/
;00002`05QHF02`0000502`/;00801HF;0000000;2`/02`0000/;2`002`002`/;00F5R`2000/0080
;2`/00<00000000/000k5QH00P0/;2`01P190000;2`/0000;00/;2`05R`F02`/;080000/0P0/;2`0
0`00;000;2`/02`/;00302`/;00<0000000/;2`09@0F02`/;000000002`002`/;00002`0;2`/01H/
5P0/;2`000001@0/;2`00`0F;1H0001O02`/;00402`/;008000`N`00B@00;2`/04U9B@00;000;2`/
0000000F5R`202`/;006000/000002`0;2`/000/000F;1H002`00P0/;2`8ooooo`001_ooool01`0`
Gel005mO001OG`0HGel005mO031kN`00Ng/00P00Nel2001OG`0W001kG`0`Ng/0<5mO05mOG`1DE5@0
<5mO031]K@19BDT0<9:G09:^N`2^[Ul0[YMO0:ik001JFR/0GemO071DE016AQH0BDU905mkG`1DE2D0
Gel`031Y0016ATH05THF04U9B@0UE5@0<5l`02ED9@12@T80>c/k02`/;00UBBD0>c/k05AD9@19BDT0
7T4N02Dk9@0UBBD0>c/k0080BDU901L0GemO031TB01ONc00X;bl0:f][@1ONel0E5AD02E99@1?CcL0
05l005AD9@00E000>c/k01I@5P0U>bD0>CTQ01I65P0k>c/005@`02`/;01O<000;2`/03/Y:@0201H/
5P0E02`/;00`Nel0LW9b06MWI`1/NWX0JHEY0:NWY`2BUel0L71D05A`E02WYjL0IfMW0:NWY`2;YjL0
HV9R06V5Q@1ONel0BDU903@d=00k>c/0;2`/0080>c/k0180BDU905ADE00UE5@0Fh20079bLP1ONel0
E5@U04U9B@1DE5@0NemO05I]6027L5@0E5@U05mOG`1YQHD0GiNG031kN`1TSX0205nGU`09001kN`1O
UiL0<9NG05nGU`18UiL007^G002GU`0`UiL0PinO0080Gjk500<0NiNG05nGU`1OUg/00P1OUiL01P1k
UiL0GiNG05nGU`1OUiL0<9N^032GU`80GiNG00<0NiNG076KV`1kUiL00`1OUiL01P1YQHD0GUiN02i1
;P0F;1H0;2`/02`F5P@0;2`/00H05R`F01H0000F;1H0;1HF000F000F5QH201HF;00602`/;00k5QH0
9@0002D0000/5QH05QH/0P0/;2`02P0F5R`0;2`/01H/5P00;000;1HF01HQ8@0001H0>aHF0000;00F
;1H202`/;00301HF;00/;2`0;2`/00805QH/01805P0001HF;00Y8AH05R`F01HF;00001H0;1HF01HF
;00/00005QH/000F000F5QH05QH/07]kTP0F;1H05QH/024Q;00/;2`201HF;00402`/;00F01H05R`F
01HQ8@80;2`/00H05QH/02`/;00F;1H0;2`/024Q8@0F5R`302`/;00401H/5P0F5QH0;2`/024Q=080
;2`/0P0F;1H03@0F>aH0ATI6095iN@1ONi80D51@031`<00FATH0;2`/01HF>`0Q;240;2`/01HF;00F
;1H00P0/;2`01@0F;1H08B`Q000F5P0/;2`09BED00Sooooo0006ooooo`07001OG`1OGel005mO031O
G`00Gel0BDU9002GU`02001OG`07002GG`00Gel005mO07=cL`00Uel0GemO05nGG`02001OG`0705o5
U`35aIL0UiMO0<FGG`1OGel0BDU907]k<00209NGG`0705mO0000Gel0BDU9001O001OGc00GemO02`/
;00205mO000>02`/;000B@00BDU903/k>`19BDT005l004U9B@00Gel0;2`/001O0016AQH0;2`/0019
000/;2`205mOG`80BDU900X0e=CD0;Jf]P00Gel0Gel002`/;01OG`005THF0019000/;2`004T01@00
G`001P19BDT0;2`/04U9B@19BDT0;2`/01Hk5P80;2`/0P1OG`005@00Gel0Lg=c06MWI`2GUiL0YjNW
001OG`1OGel0BDU90:NWY`1ONel0GemO001OG`1OGel0Lg=c05mO000/;2`05THF05mO000/;2`005mO
05mO000204U9B@0A001OG`2GUiL0GiMO05mOG`1OUel007<005nG002GU`00GemO05mO001OUel005mO
07=cL`1OUel0Lg=c031ON`00UiL00P1OUiL00`1cLg<0GiNG002GU`0205nGU`8009NG0P1OUiL01P2W
YjL0UiNG05nGU`00GiL009NG08F5Q@<0GiNG00P0GiO505nGU`1OUiL009NG05nGU`1OaLD0GiN^05nG
a@@0GiNG00<0GiMO05ADE000;0000`0/;2`00`00;000;2`/000/0002000/000902`0000002`00000
04T0000002`09@0002`/;000;000;2`/00@002`01P0/;2`02`005P00;2`/02`/;00/;2`0000/02`/
;000;0009@0F0000;0190000;2`/0080000000<0;2`/01H/5P1900000P0/;2`01`00;000;000000/
000F;1H0000/02`/;00002`00`0/;2`01P005QH0000/02`/;000;000;2`/0000;08002`00`0/;2`0
0`00;000000/02`/;00602`/;0030019000/;2`0;2`/00H0;2`/00L0ATIR08F5Q@19BDT0aNo505mO
G`19BDT0001O00T0;2`/00<0000002`/;?ooool01oooool000Kooooo00@005mO05mOG`1OUel0<7]O
0P00Gel01@1OUel005mO05mOG`00Gel0<5mO0080GemO00h005nG05mOG`1OGel0GemO031kG`35aEl0
aING0<EOG`2GGel0GemO05nGG`1kNc00aLEO09NG0080BDU900T005l005mO000`Gc00;2`/001O000/
;2`004T005mO0019BDT00P00G`001`19BDT0GemO04U9B@19BDT0Gel004U9B@0k>c/00`0/;2`204U9
B@0505mO000UE5@0][Jf04U9B@00Gel00P00G`001P1OG`00ATHF001O000/;2`005l005mOG`80BDU9
00<0>c/k04U9B@19BDT00`00B@001019BDT003/000190000B@0304U9B@0=05mO000`Nel0UemO09NG
U`00Gel0GiMO04U9B@1OGel0Ng]k09NGU`25QHD0GemO04U9B@0205mOG`0904I65P0/;2`0BDU904U9
B@1OG`00BDU9001O001OG`00GiNG0080GemO00`0GiMO09MOG`1OUel0UiL005mkG`19BDT005nG07=c
L`1OUiL005mO05mOG`00Ng/505nGU`05002GU`1OUiL0GiNG05nGU`00GiL00P1OUiL00`2GUiL0WkJO
05nGU`0305nGU`0305o5a@1OaIL0GiNG00D0GiNG00D0GiO509JFUP25QHD0GiNG05mOU`0205nGU`0:
05mOU`1NGUh0BDU902`/;00002`002`002`/;00/00005R`F02`0008002`000L0000/02`0000/;2`0
02`001H000000000;00000<0000/01<0;2`/01H/5P0/000002`00000000/0000B@000000;00001H0
;000000/000/;2`0000/02`/;000;0009AH00000;00/;2`0000/0080;2`/00@0;00002DF0000;000
000/100/;2`00`0F5R`0000002`/;00202`/;080000/00<05QH/000/000/;2`00P0/;2`00`0/0000
000/01H/5P0602`/;00901HF;00/;2`0;2`/02`/;000;000;2`/0000;000;0005R`F00@0;2`/00L0
02`002`/;01DE5@0GemO04U9B@35Uel0UiNG00D0;2`/00P002`002`/;00002`0000/01H/5P19BDT0
;2`/04U9B@Sooooo0006ooooo`09001OG`00Uel0GemO031OG`00Gel005nG05mOG`00Uel0GemO0080
05mO00T0GemO05nGG`1OGel005mO05mOG`00Uel0PinO0<FGG`35aEl00P35Uel02`1OGel0UiL009:G
G`2GUel0GemO04U9B@1OG`0005mO05mOG`0F>aH0Gel00080BDU900P0;2`/05mOG`19BDT0BDU902`/
;019BDT0Gel0001O0080BDU900@0;2`/04I65P19BDT005l00`19BDT0101OG`00X;bP0<G5G`1OUel4
04U9B@0303/k>`00;000Gel00080BDU900<005mO04U9B@0UE2D00P19BDT02@0/;2`005l0001O000/
;2`0ATHF02`/;01OG`00BDU905mO000204U9B@0@07]kC019BDT0GiNG04U9B@25QHD0GemO02`/;025
QHD005l008F5Q@19BDT005mO04U9B@00;000E5@U001O00@0BDU900H0Gel004U9B@1OUel0BDU9001O
G`1OGel205nGG`0905mOG`1OGc0009MO05nGU`1OUel005nG05mOG`1OGiL0Gg^G0080GiNG00@009NG
05nGU`1cLg<009NG1`1OUiL01@2G[YL0UiNG07=cL`1OUiL0UiNG00<0GiNG00<0UiNG05nGU`1OUiL0
0`1OUiL209NGU`80GiNG00@0GenG05nGU`1OUiL0LW9b0P0/;2`03P00;000;2`/02`/;000;000;2`/
0000;0190000000/02`0000/;2`0000/000/000F000002`0100/;2`01P00;0005R`F02`/;000;000
;2`/000/0080;2`/00X05P0F0000;00/;2`0;2`/02`00000;000;2`/000F5P0/;2`0000/0P0/;2`0
1@00;000;00002DF000/;2`002`000<0;2`/00<0;00001H/5P0/;2`00P0/;2`0100002`0;2`/0000
;00k5QH202`/;00504T0000/;2`002`002`/;00F5R`01@0/;2`00`0002`0;2`/02`/;00302`/;005
000/000/;2`002`001H/5P00B@000P0/;2`01000;000;2`/000/000k>c/2001OG`0304U9B@0004T0
;2`/00<0;2`/00T002`002`/;00002`002`002`0000FAQH00000000/000005l02?ooool000Kooooo
0P00Gel0401OGel0<7]O001OG`1OUiL0GemO05nGG`1OGel005mO031OG`1OGel005mO05mOG`1cLg<0
05mO09NGU`2fWh<20<FGG`0A09NGG`2GGel0GiMO05nGG`2BUel0GemO05nG001OGel0Gel004U9B@00
L`009EAD02`/;000B@00;2`/00190000Gel00P19BDT00`00B@0005l005nGG`0205mO00<0BDU90P0/
;2`205mO000>0019001OG`00WkJf05mOG`0/;2`0BDU902`/;01OGel0;2`/01I6AP19BDT002`00019
0000Gel204U9B@0801I6AP19BDT005mO001O0019BDT0Gel002`/;000AP0404U9B@03001OG`1OUiL0
Gg]O0080Lg=c00H0GemO09O5U`1OGel0BDU904=bLP1OGel204U9B@0902`/;01OG`00Gel005AD9@1O
G`00GemO04U9B@1OG`00BDU900<0GiMO00<0BDU905mOG`2GGel00P19BDT0201OUel0<5mO05mOG`1O
Gel005mO002GU`00Uel0GemO0P1cLg<305nGG`0405nGU`00Gel0<7^G07=cL`<0GiNG00@009NG05nG
U`1OUjh0UiNG0`1OUiL00`1OaIL0UiNG032GU`0605nGU`0908>OW`1OUiL0QHF505mOU`1OUiL0UiNG
05mOU`1ONg/0GemO0080;2`/00<0B@00000/0000;0000P0/;2`01`0002`0000002`0000/;2`0000/
000/000000000`0/;2`01@00;000000/000000005QH0;00000<002`00P0/;2`00`0F;1H0B@000000
;0020000;00402`/;00/00005QHF02`00080;2`/0P0002`01000;000000/000/0000;00402`/;006
01H/5P000000;2`/000/000/;2`002`00P0/;2`02`00;000B@0002`/;00002`002`002`/;00F;1H0
000/000/000002`000000080;2`/00<05QH/02`/;00/;2`0100/;2`00`00;000;2`/02`/;00502`/
;00302E99@0/;2`0000/008004T01@0/;2`020000000;2`/02`/;000;000;2`/0000;019BDT0;2`/
2?ooool000Kooooo0P00Gel02@00Uel0GemO05mOG`1OUiL0GemO001OG`1OGel005mO031OG`0405mO
G`0J05nGU`2WYjL0aJjG0<FGG`1OG`00Lg=c05nGG`2GUel0UlEO04aOG`19BDT0UiL004U9B@00G`00
BDU905mOG`19BDT0GemO02`/;000G`00BDU905mOG`00G`00;2`/02EDE01OG`0204U9B@0=05mO0000
G`0004T001I65P0/;2`004T0001OG`00B@00Gel007=cL`35TY80BDU905mOG`0304U9B@0<05mO0000
B@00Gel0001O0019BDT0;2`/04U9B@00Gel0E5@U001c000/;2`005l00`19BDT00`0FAQH0;2`/05mO
000202`/;00C05mOG`2f][H0C7]<04U9B@1OGel0BDU905mOG`0/;2`0GemO06V5J@1OGel0GiNG001O
G`1OG`00BDU905mO0019BDT0Gel002`/;00204U9B@0405mO0019BDT0GemO05mkG`80GemO00D0GiMO
05mOG`00Uel0GemO031O<00305mOG`06002GU`1OUiL0GenG07=cL`1OUiL009NG0P1OUiL01000Uel0
GiNG05nGU`1OGiL205nGU`04002GG`1OUiL0GiNG09nfW`80GiNG00L0GenG05nGU`2GaIL0YjNW07:>
SP2GUiL0GiO500@0GiNG00<0Gjj^0:NWY`1OUiL0101OUiL01@1OUg/0GemO02`/;00/;2`002`00080
;2`/00<05R`F02`/;00002`00P1900001@0/;2`0000/0000;00/5QH0;2`/008002`000D0;2`/0000
0000;0005QHF00000002000/000304T0000/;2`0;2`/00H0;2`/00H002`001H/5P00;000;2`/000/
0019000502`/;006000/000/;2`0;0000000;0005P00;2`/0P0002`01P0/;2`002`002`/;00/;2`0
000/000/00<0;2`/00<0000/01HF;00/;2`0100/;2`00`00;0005R`F02`/;00402`/;0030019000/
;2`05R`F0080;2`/00<002`002`/;00/;2`01@0/;2`02`00B@00;2`/02`/;00/;2`002`002`/;000
;000;2`/04T0000/00005R`F00<0;2`/2?ooool000Kooooo0`00Gel00`0`Gel005nG05nGU`02001O
G`80GemO00`09EAD04U9B@00Gel0BDU909NGG`35UiL0aLFG0<EkG`2GGel0GemO09NGG`1OUel209NG
G`0305mO<000G`00Gel000<0BDU900P005mO04U9B@19BDT002`0001O0019BDT0GemO02`/;080BDU9
00h005l004U9B@19BDT0BDU9001c0000Gel0BDU9001O0000B@00;2`/04U9B@1OGel0hN7Q09:BC080
BDU900d005mO04U9B@0/;2`0;2`/03/k>`19BDT0;2`/04U9B@1OGel0;2`/05mO000k>c/0Gel00080
05l00P0/;2`04P19BDT05R`F00190000B@00Gel000190000L`00][Jf071`E01OUel005l0001c0025
QHD0BDU90:NWY`1bLT<0GiMO05mO0080BDU90P0/;2`00`0k>c/0BDU904U9B@0204U9B@80Gel00100
05mO05nGG`1OUel0UiMO08F5Q@1OGel0Lg=c05mOG`0jQFT005mO05mOG`00Uel005mO002GU`1OUiL0
JFUY0P1OUiL02@00UiL0GiMO05nGG`1OUel0<9MO002GG`00UiL0GenG002GU`0805nGU`0409O5U`1O
UiL0GiNG05o5U`@0GiNG00D0PinO05nGU`2WYjL0GiNG08F5Q@0205nGU`0405mkU`1OUel0BDU902`/
;08002`00`0/;2`01000000002`00000000/000202`/;00501HF;00/;2`0B@0002`/;00002`00`0/
;2`01`0/00000000000/000/;2`0000002`/;00F;1H00P00;00202`/;006000/000/;2`09@0002`/
;0190000000/0P0/;2`00`0000005QH/02`/;00302`/;005000/000/;2`0;2`/02`/;019BDT01@0/
;2`02000;000;2`/000/000/0000;2`/000/000/5QH0000/0`0/;2`2000/000301H/5P0002`0;2`/
0080;2`/0P00;00202`/;007000/000/;2`0;2`/0019000/;2`00019000U9@0302`/;0030019000/
;2`0;2`/0080;2`/00<002`002`/;00/;2`00P0/;2`0100k5QH002`002`00019BDT8ooooo`001_oo
ool2001OG`07002GG`1OGel0GiMO05nGU`19BDT005mO04U9B@0205mOG`0d04U9B@00Gel0UiMO0<FG
G`35UiL0aIMO0:iO<01cLg<0aIMO05mOG`1OUel005mO05nGG`1DE5@0Gel004U9B@0/;2`0Gel002`/
;01OG`009E@U02`/;01OG`00;2`/05mOG`00L`00BDU9001O001OGc0005mO04U9B@0/;2`0BDU902`/
;000G`00BDU902`/;019BDT005mO001O002GaLD0aLG504U9B@00G`0007<0001O000/;2`005l002`/
;016AQH0;2`/001O0080BDU900X0;2`/001O000/;2`005l002`/;000B@00;2`/000/000/;2`004T0
0P0/;2`304U9B@0307=cL`16ATH0UemO0080;2`/00L0QHF505mOG`2GUiL0Ng]k09MOG`00Gel0GemO
0080;2`/0P19BDT01000G`00Gel005mO001OG`0305mOG`0405mkG`1OUel0Lg=c07=cL`80UiMO00<0
GiMO001ON`00Gel00P1OGel0301OUel0GiNG08F5Q@1OUiL0GenG07=cL`1OUel009NG002GG`00UiL0
07]k002GU`80GiNG00@0GlFG05nGa@1OUiL0PinO101OUiL209NGU`80GiNG00<0UiNG05nGU`1OUlD0
0P1OUiL00`1kUiL0UiNG0:NWY`0205nGU`0505mOU`1OUiL0GiNG05nGU`00Gel0100/;2`00`00;000
000/02`/;002000/000<00000000;00002`002D05P0/;2`002`002`00000;000;2`/04T0000/;2`0
02`00P0/;2`0100002`0;00004T0000002`402`/;00502`0000002`001HF02`/;000;000100/;2`0
0`0k5QH002`002`/;00202`/;080000/00D05QH/02`/;00/;2`002`00000;00202`/;00401H/5P0/
;2`0;2`/00000080;2`/00L0000/02`/;00/;2`002`00000;0000000000/0080;2`/00<002`002`/
;00/;2`0100/;2`00`0F5R`0;2`/02`/;00202`/;003000/0019BDT05QHF00D0;2`/00<0000/02`/
;000;0000`0/;2`01P00;000B@0002`/;00/;2`002`002`/;0Sooooo0006ooooo`06001ON`00Gel0
<7]O04Q]G`1YJHD0Gg]O1@0`Gel04@1DE5@0UiMO0<F^G`35[Ul0aIMO0:ikG`2AEQP0UiMO08F5J@1k
TW/0QHEY031kG`1DE2D0>e<k05mO<000>`005QHk0080ATI600L0E5@U04U9B@0UBBD0BDU902Dk9@00
Gc00>c/k00809E@U01l07U8f05AD9@0`Gc009EAD05ADE00`Gc00E5@U03I=C@0UBBD09EAD05A`9@2B
[/<0aLG305ADE00NCAh0>c/k02ED9@0UE5@0ATHF01I6AP19BDT0CDdN02E99@1DE2D09DTU01I65P0`
G`005THF02Tk:@0k>c/0BDU900805THF00@0>c/k01I@5P0U@RD05S/F0P1DE5@0;`19BDT0Win3031O
<01<LF<0GemO05AD9@0F>aH0E5AD06MWI`199BD0<4Q801I6AP16ATH09EAD05ADE00UE5@0>c/k04Q8
<00`E0009EhU05AD9@19BDT006T`031OG`1OGc00O7al08j>LP1bSXh0@hj>032GU`0`NiL0<9MO04Q]
K@00Gg/0<9MO05nGN`1OUiL0NiNG07^^[P1YTi<0NiNG06V5Q@0`UiL0>VV5031OG`00Nel0GhVG00<0
GiNG00T0<7^G05n^U`1kUiL0OjNW05nGU`0`UiL0GiNG032GN`1kUiL00`1OUiL00`1O[Zh0GiNG05nG
U`0205nGU`0505nGX`1kUiL0UiNG09nfW`1OUjh00`1OUiL02`0`NiL0>XEY04I6AP0/;2`05QH/01H/
5P0F8B405P0F01HF000/5QH05QHF00805QH/00X0>aHF01hQ2`0/5QH05QHF02`F5P0F5R`0;2`/03/F
5P0Q8B`0>aHF0`0F;1H03@0/;2`05QHF02`Q8@0F;1H05P0F000F0000;0005P0002`F5P0Y5QH05QH/
01HF5P0F5R`00P0F01H0100/;2`05QHF02DF000/;2`201H/5P0:0000000/;2`001H;000/000/5QH0
5R`F01HF;00k5QH05R`F00/;8@805R`F00h001H002`/;00F5R`001HF01H/5P0/5QH0000/02`/;00F
;1H0;2`/01H/5P0Q8B`05R`F02`/;0<05R`F0P0F5QH0200Q;2405R`F02`/;00F;1H002DF03/k>`0F
>aH08B`Q0`0/;2`01P0F;1H0;2`/01H/5P0Q;2405QH/000/00805QH/0P0F;1H0100Q8B`0;2`/02`/
;00k>c/8ooooo`001_ooool01P00Gel0GemO001OU`0`Gel0GiNG002GG`<005mO00T0GemO001OG`2G
UiL0UlEO0<FGU`35Uel0aEl009MO001YJFT00`1OUel00`1OGel0BDU904U9B@0202`/;008000/0019
BDT0BDU9001OG`19BDT05TI6001O0019BDT205mOG`0604U9B@1OGel0BDU905AD9@00Gel0GemO0`19
BDT01P1OGel0ATHF02`/;00/;2`0UlG50=CDe0D0BDU900@005mO04U9B@00Gel0;2`/0P19BDT00`00
Gel0;2`/000/000404U9B@0605mOG`19BDT005mO04U9B@1OGel0JFUY0P00G`003`19BDT0GemO04U9
B@19BDT0LXib05mOG`00Gel005nG0:NWY`00Gel0GemO07:>LP0/;2`004T005mOG`0204U9B@07001O
0000<2D0;2`/001c001OGel0BDU905mOG`0205mO000309NGN`1OUiL0GiNG008009NG00@0GiNG001O
G`0`UiL0GemO0P1OUiL01`1cLg<0UiNG0:NWY`1kUiL0GiNG05mOU`00UiL00P1OGiL305nGU`0305nG
a@1OUiL009NG0080GiNG00<0WinO05nGU`00UiL0101OUiL00`1OUjh0GiO505nGU`0305nGU`L0GiO5
00D0GiNG06V5Q@25QHD0GiNG04U9B@0302`/;00501H/5P0/;2`0000002`/;00/00000P0000003@00
;0005R`F02`/;00002`0;2`/000/000/;2`0000/03/F5P0/;2`0;0000000000/;2`00P00;0000`0k
5QH0;2`/000/000202`/;0060000000/;2`05QHF0000;00/;2`0;0000`0/;2`02@0k5QH0;2`/0000
0000;000;00002`/;000;000;2`/0000;00202`/;0050000;00/;2`0000/01HF5P0000000P0/;2`0
1P000000000/0000;00F5R`0;2`/000/00T0;2`/00<0000/000/000/;2`00P0/;2`200190004000/
000/;2`0;2`/01Hk5P80;2`/0P0002`302`/;00:000/000002`0;2`/000/000/;2`0;00001HF;000
0000;00002`/;0Sooooo0006ooooo`05001OG`1OGiL0GemO001OG`1cLg<00`00Gel204U9B@09031O
G`1OUel0UiNG0<FGU`2GUel0Uel005mO001YJFT0UiMO0080GemO00D005mO04U9B@00B@005S/F0019
000202`/;080BDU900/0;2`/04I65P00B@00BDU905mOG`19BDT005l005mOG`19BDT005l`001O0002
001OG`0705nGG`1OGel0GiMO001O0000;000;2`/0=CDe00204U9B@0302`/;01DE5@0;2`/008005l0
0P00Gel0200/;2`0>c/k02`/;00/;2`0BDU9001O0019BDT0Gel00P19BDT02@00G`00;2`/07=cL`1O
Gel0BDU905ADE000G`00Gel0001c000204U9B@0605nGU`1<Nel0Lg=c05mOG`2WYjL0UiMO0P1OGel2
04U9B@0;05mOG`1OUel0GemO04U9B@00Gel0>c/k04U9B@1OGel0BDU905mO001OUel00P1OGel00`25
QFT0GiNG05nGa@0205nGU`0605mOU`00UiL0GiNG05nGU`1OUel0GiNG0P2WYjL00`1OUiL0GiN^05nG
U`0205nGU`04002GU`00Uel0GiNG05nG[P<0GiNG00@0GiO505o5U`1OUiL0Pinf0`1OUiL03`2WYjL0
GiO505nGU`23][H0GiNG0:NWY`1OaLD0GiO505nGU`2WYjL0GiN^05nGU`1OUlD0UiNG0:NWY`0209NG
U`80GiO500<0GenG05mOG`00Gel01@0/;2`0400/000002`002`0000/0000;2`/0000;00/0000;2`/
0000;00/;2`002`002`/;00F5R`0000/02`/;00/000302`/;003000F000/000002`000<0000/00`0
02`003/F5P0/;2`0B@00000/000/;2`0000/02`/;00F;1H0;2`/0000;0190002000/000304T0000F
01H0;2`/0080;2`/00X002`002`/;00002`0;2`/02`00000;00005mO02`/;00002`000000`0/;2`2
0000;080;2`/00<0E5AZ02`/;00/;2`01P0/;2`00`0002`0;2`/02`/;00202`/;0030000000F>aH0
;2`/00@0;2`/00X002`001H/5P0/;2`0000/000/000/;2`004T00000;00/;2`0;0000P0/;2`8oooo
o`001_ooool01@1OGel005mO05mOG`0`Gg/0Lg=c00<005mO00H0GiMO04U9B@00Gel0YjNW09O5U`3_
Uel205mOG`0505mO001OGel0GemO07=cL`00Gel00P19BDT02@0/;2`05S/F04U9B@19BDT0;2`/04U9
B@0/;2`0BDU901I6AP02001OG`09001O0019BDT005l004U9B@00Gel09BE9001OG`00G`00Gel00080
05mO00/0GiMO031O0019BDT0UlG50<FG001OU`00BDU9001c000UGRD0Gel0001O000204U9B@80;2`/
01X05S/F02`/;000G`0005l000190000G`00BDU905AD9@19BDT0001O04U9B@1OGel005mO05mOG`0U
E2D005l0001OG`19BDT0;2`/001O002GU`00;2`/05nGG`1OaIL0GenG0:NWY`80GemO00@0E5AD001O
G`1OUel005mO0P19BDT0100/;2`09DTU04U9B@19BDT205mO0080GemO00H0Lg=c07:>SP1OUiL0GiNG
05nGa@00UiL205nGa@0308>OW`00UiL0GiO50080UiNG00D0GiNG05mOU`1kUiL0GiNG05nGa@0205nG
U`8009NG00<0GiNG09NGU`1OUlD00P1OUiL01@2GUiL0GlG507]k[P1OUiL009NG0080GiNG00H009NG
05mOU`0`UiL0GlFG05nGa@2WYjL205nGU`0405o5a@1OUlD0GiO509NGU`80GiNG00<0YjNW09NGU`1O
UiL00P1OUiL00`00Gel0BDU902`/;00202`/;004000/000/;2`00000000/00<0000/00<0000F0000
;00/;2`00P0/;2`202`0000502`/;000;00002`002`/;000;0000P0/;2`0100U01H0;2`/02`/;000
;00302`/;00701HF;00/;2`0000/0000000/;2`0000/02`/;002000/00030000000002`0000000<0
;2`/00@002`002`/;000;00000000P0/;2`02P0F5R`0;2`/02`/;00002`0;2`/0000;00/;2`05R`F
02`/;00002`802`/;00405mOG`00;000;2`/000/00@0;2`/00@0001902`/;00/;2`05TI60P0/;2`0
0`00;000;2`/000/000202`/;0030000;00/;2`0;2`/0080;2`/00<0000/01H/5P0/;2`00P0/;2`8
ooooo`001_ooool0101OGiL005mO001OG`0jJFT205mOG`@005mO00D0<5mO05nGG`1OUel0kiMO09MO
G`0205mOG`0307]kG`2GUel0Lg=c00@0BDU900`0>c/k04U9B@0/;2`005mO04U9B@00G`00;2`/01I6
5P0/;2`0Gel004U9B@00G`0204U9B@0@001O000`Gel0GemO04U9B@1OG`00BDU905mOG`00G`00>c/k
05mOU`35aLD005mO05mOG`1OG`0005l005AD9@80BDU901L004T002`/;00/;2`0BDU903/k>`0/;2`0
Gel0001O0019BDT0Gel002`/;00k>c/0UiMO001O001OGel0BDU905mOG`19BDT09E@U001O0000Gel0
GiMO001O000204U9B@0?05ADE025QHD0][Jf08F5Q@1cLg<0BDU907=cL`1DL5@0GemO04U9B@1OG`00
05l0001c0000Gel0<5mO0080BDU900T005l0001c001OGel0GiMO05mOG`25QHD0GiNG05nGa@2GUiL0
0P1OUlD01P1OUiL0NiN^002GU`1OUiL009NG001OU`80GiNG00@0Ph>O0:NWY`2WYjL0GiO50P1OUiL0
2@1OGiL0WinO05nGU`2GaIL0GiO505nGU`2GUiL0GiO505nG[P0205nGU`0305mOU`1OUiL0GiNG00@0
GiNG00D0GiO505nGU`00GiL0GiNG09NGU`0205nGU`0509NGU`1OUlD0GiNG09NGU`23Wil00P1OUlD0
0`1OGiL0GemO02`/;00202`/;00402`00000;00002`000000080;2`/00L0;00001HF000/;2`0;2`/
04T000000000000/0080;2`/00T0B@0002`/;00/;2`002`002`00000;0005QHF02`/;00002`00P0/
;2`01@00;000;00001HF5P0002`0;2`/0080000/00L002`002`/;00/;2`0;2`/0000;0000000;000
0080;2`/00<05QH/02`/;00/;2`00P0002`202`/;00301HF;025QHD002`000@0;2`/00D05R`F02`/
;00/;2`0;2`/000/000202`/;00301H/5P0002`0000/0080;2`/00H0000/02`/;00/;2`05R`F02`/
;000;00502`/;003000/000/;2`0;2`/00<0;2`/00D001HF000/000/;2`0;2`/0000;00202`/;004
01HF00190000000/02`/;0Sooooo0006ooooo`06001OG`1OGel0GenG06V5Q@00Gel0BDU90`00Gel0
1P19BDT09EAD05nGG`1OUel0UiMO05nG0080GiMO00<0NemO05mOG`19BDT00`19BDT01P0/;2`09E@U
02`/;000B@00;2`/04U9B@80;2`/00H0>c/k04U9B@1OG`0004T004U9B@00G`0204U9B@0?05ADE01O
Gel0BDU904U9B@1OG`00BDU90019000`Gel0aLG_09NGG`1OGel007<005nGG`19BDT0E5@U00<0BDU9
00<0GemO04U9B@00G`000P0/;2`05`00L`00;2`/04U9B@00G`00;2`/02ED9@19BDT0Gel004U9B@0/
;2`0Gel0001OG`1OG`00BDU905nGU`1OG`00GemO0:NWY`2GUiL005l004U9B@2GUiL0YjNW0080Lg=c
00<0GiNG06UYJ@00L`000P1OUel04000G`00GemO05mOG`1OG`0004T002`/;019BDT0Gel005mOG`00
Gel0Gel004b^U`2GUiL0GiNG0:NWY`1OUlD205o5a@0405nG[P1OUiL0GiNG001OU`<0GiNG00<0Pinf
05nGa@1OUlD00`1OUiL205nGa@0409NGU`1OaIL0YjNW05nGU`80UiNG00P0GiN^002GU`1OGiL0UiNG
05nGU`1cLg<005nG05nG[P80GiO50P1OUiL00`00UiL0GlG505nG[P0205nGa@040:NWY`1OUlD0GlFG
0:NWY`@0GiNG00@0Lg=c04U9B@0/;2`0;1HF0P0/;2`0200/0000000002`/;00/;2`0000001H/5P0/
;2`0000/0P00;0002025QHD0;2`/000F5P0/;2`0000002`0000/;2`002`00P0/;2`02@0002`002`0
02`/;000;000000/000/00005QH0;000000/000202`/;00604T0000002`0;2`/02`/;00002`0;000
0P0002`01@00;0005R`F02`/;00/;2`0000000<0;2`/00@001H002`/;000;000000/0`0/;2`00`0F
5R`0000/000/000202`/;003000/000/;2`05R`F00H0;2`/00L0000/02`/;00/;2`0;2`/0000000/
;2`002`000L0;2`/00@002`001H/5P0/;2`0BDU90`0/;2`00`1O00005R`F02`/;00202`/;0Sooooo
0006ooooo`0307=cL`1OGel0GemO00<005mO00d0BDU9001OG`19BDT0GiMO031OG`1OGel0UemO09MO
001OG`00BDU909NGG`2BNg/0BDU90080;2`/00P0BDU905mOG`19BDT0E5@U04T0000/;2`0BDU902`/
;080BDU900<0>c/k05mO000002`00P0/;2`04P00G`00BDU904U9B@0`G`0005l004U9B@1OUel0GemO
04U9B@0/;2`0Ni:B0<G5U`19BDT007<0001O001cLg<0BDU901I65P8005l000@004T004U9B@1OG`00
05mO0P0/;2`01000B@0005mO04U9B@00G`0204U9B@0E02`/;01OGel0GiMO05nGG`25QHD0BDU903Z5
Q@19BDT0GemO001OG`1OGel0UiNG09NGG`19BDT0GemO0<G5U`2WYjL0Lg=c04U9B@00B@00ATHF0080
BDU900H0Gel002`/;000Gel0GemO05mO0019BDT205mO000807=cL`1OGel0UiMO05mOG`0`UiL009O5
05nGU`2GUiL20:NWY`0905o5a@1OUiL0GiNG002GU`1OUiL0YjNW09O5a@2WYjL0NiN^0080GiNG00H0
GlFG05nGa@1OUiL0GiNG09nOW`2GaLD209NGa@80GiNG00D0UiNG05nGU`1OUiL0GiNG002GU`0305nG
U`0405nG[P1OaLD0YjNW05nGa@D0GiNG00H0YjNW09NGU`2GUlD0GiO505nGU`1OUjh405nGU`0305nG
G`19BDT0;2`/0080;2`/00H0000/02`00000;000B@0002`/;00F5P03000/00<0;2`/00T05QH/02`0
00000000;2`/02`0000002`002`002`/;000;0000P0/;2`01@0/000002`002`/;000;000000/00<0
;2`/00H002`002`/;00F5R`002`002`/;000;00302`/;003000F<00/;2`0;2`/00<0;2`/00@00000
0000;00002`000000`0/;2`01P00000001HF0000;00/;2`0000/00000080;2`/00T0000/02`/;00/
;2`0;2`/0000000/;2`002`002`/;00F;1H00`0/;2`00`0/0000;2`/02`/;00302`/;004000/000/
;2`002`00000;080;2`/00<00000000/000/;2`00`0/;2`00`190000000/02`/;008ooooo`001_oo
ool01`0`Gg/0Gg]k031kN`0`Gel0E5AD02EDE00`Gc000`1DE5@0101IFET0W9b509NGG`1`L70207]k
G`0405nGG`1XMUX0>c/k01Hk5P80>c/k02@0GemO05mO000UE2D09EAD02ED9@0UGRD05THF03/k>`0U
E2D0:DDY01Hk5P0UBBD0>c/k04U9B@0`Gel0ATI602ED9@0ZFQ<09E@U05ADE01ONel0E71D05ADE01Y
JCX0VZF:05A`E00`LS00E5AD05A`E00k>c/0Gg]k06QJ@P1DE2D09E@U031O000FAQH202ED9@03031O
600UBBD09E@U0080Gel`0P19BDT0:00mE5@0GemO05mkG`0`JC00Gg]k05A`L01ONg/0MgMg031Y<01O
Gel0Gg]k08>3W`1ONel0YjNW04eKM`1ONel0Ng]k05A`E019BDT0JFUY03YYJ@0`GaP0GemO05ADE01O
Gc009E@U05A`9@1ONel0J6Q208EYJ@1OGc00<5l004I6AP2GUel0LW9b03Z5J@0`RIL0Gg^^0:NWY`1O
UiL205n^[P0409nf]P2AZj/0Njj^07^G[P80GiNG00@0Win306V5Q@1ORIL0<9NG0P1OUiL0201bSZD0
GiN^08>OW`29Xj<0NiN^05nG[P1kUjh0GiN^0P1OUiL01P1YTi<0GiNG05nGU`1OUiL0JFV5032GU`<0
PinO00<0GiN^05nGU`1OUiL00P1OUjh03P1OUiL0YjNW08>OW`1bSZD0Gjk509NGU`2OWil0Vi^K07^G
U`1OUjh0NiNG05nGU`1OGg/0BDU90`0/;2`03@0F;1H0;00000005P0F5QH05QH001H;2`0`C680;2`/
01H/5P0k5QH05R`F01HF;00;2`/00P0F5QH201HF;00<02`/;00U5P002b`;01HF5P0F5R`0;2`/000F
5P0001H05QH/01HQ8@0F;1H05QH/0P0/;2`04`0F5R`001H001h;8@005P00000001HF5P0F5P005P0F
02D05P1ZJUl0ATI601HF5P0/;2`05QHF02`/;00F5QH0;2`/01H/5P0F5QH00P0/;2`01P0F5R`0;2`/
024/8@0/;2`001H001HF;080;2`/00h05QH/02`/;00F5R`0;2`/01Hk5P0`<6805QHk01HF;00F;1H0
5R4Q02`/;00F;1H0;2`/01H/5PH0;2`/00<05R`F01HF;00/;2`00P0/;2`201H/5P80;2`/00<05QH/
024d8@0F5R`00P0/;2`8ooooo`001_ooool2001OG`0309NGU`00Gel005mO00<005mO0P19BDT0301Y
JFT0YjNW09O5U`2GG`00Gel00<EOG`1cLg<0TY9O05mO000/;2`0BDU9001OG`80BDU900L0E71D04U9
B@0/;2`0BDU902`/;019BDT005l000<0BDU900P005mO04U9B@1OG`0007<004U9B@0FD1H005mO001O
0080GemO00D0GiMO0<G5k`27Qg00GiL005mOG`02001OG`03001O0000B@00GUiN0080;2`/00D0BDU9
00190019BDT0Gel003/k>`0205mO000F05mOG`19BDT0BDU905mO000UE5@0UiNG05mOG`2GUiL005mO
05nGG`2f][H0SHf=05nGG`1cLg<0GemO07=cL`2GUel0YjNW05mO<01OGel005mO04U9B@80;2`/0P00
Gel02@19BDT005mO001OG`00Gel005l005mO001YQHD0GiMO07=cL`0305mOG`0305mOU`1OGel0NiNG
0080GiNG00<0YjNW05nGU`2WYjL00P1OUiL0102WYjL009NG05nGU`1cLg<205nGU`03001kN`1OUiL0
QHF500@0GiNG00<0NiN^05nGU`1OUiL00`1OUiL00`25QHD0GiNG0:NWY`0205nGU`0505nGG`00UiL0
GiNG05nG[P1OaLD01P1OUiL01`2GUiL0QHF505nGU`2WYjL0UiNG0:NWY`2O]Yl01@1OUiL01P1OGel0
BDU902`/;00/;2`002`00000;0<0;2`/00<001HF02`0000/;2`00`00;0000`0/;2`05P0F02`/;002
02`/;0070000;019000002`0000F5P0/;2`0000/02`/;0030000000902`F5P0/000002`005mOU`0/
;2`0000/02`0000F5R`0000/0080000000P0000/000/0000;0005R`F02`/;0000000000/000/0080
;2`/00P05R`F0000;00/;2`0000/000/000/;2`002`001HF;0D0;2`/00D002`001HF;000B@0004T0
04U9B@0202`/;0030000;00/;2`05R`F0080;2`/00@002`002`/;00/;2`004T02P0/;2`01P19BDT0
;2`/02`/;00/0000;2`/000/0080;2`/2?ooool000Kooooo0P00Gel00`1OGel0<5mO001OG`02001O
G`0605mOG`19BDT0GemO031OG`35aEl0GemO0P1OG`004@2GG`00GiMO031kG`19BDT0;2`/001O0000
;000GemO05mO000UE2D005l002`/;01OG`00BDU9001O000/;2`005l00080;2`/01@0GemO04U9B@19
BDT005mO02`/;00FD1H0BDU9001OG`1OGel0Gel005nGG`2GaLD0<5@0001OG`1OG`000019001OG`00
G`0004T002ED9@80;2`/0P00B@001P1OG`00GemO05mO<01OUel0Gel004U9B@D0GemO00L005mO05mO
G`1cLg<0GiNG08F5Q@1kUiL0QHF50080GiNG00L0UiNG08F5Q@25QHD0UIFE04U9B@35aIL0Gel000<0
BDU900@09DTU05mOG`0/;2`0BDU90`1OG`00102GNel0GenG05nGG`1cLg<2001OG`05002GG`1OUiL0
NiNG09NGU`1OaIL00P2WYjL02P2GUiL0YjNW07^G[P1OUiL009NG05mOG`1OUel009NG001OG`1ONg/6
05nGU`0808>OW`1OUiL0GiNG09NGU`1OUiL0Lg=c05nGG`00UiL405nGU`03002GU`1OUiL0Ujj^0080
GiNG0P00UiL205nGU`0505nG[P1OUiL0UiNG0:NWY`1OUlD00P2WYjL0101kUiL0GiO505nGU`1OUlD2
05nGU`0305nGG`0k>c/0;2`/0080;2`/00<0000/04U9B@0/;2`00P0/;2`00`000000;2`/02`/;002
02`/;00304T000005QH0B@0000<0;2`/00<002`002`/;00F;1H00P0/;2`3000/000302`/;00F;1H0
02`000@0;2`/00X002`001HF00000000000004T00000;000000002`/;00F5R`0000/0P0/000202`/
;0040000;00F;1H002`002`/;080000000<0;2`/02`0000/;2`01@0/;2`00`0002`0;2`/02`/;003
02`/;00505nGU`00;000;2`/01HF;00002`00`0/;2`0100002`0BDU901HF;000;00802`/;005000/
000/;2`0;2`/000/000U5P000`0/;2`8ooooo`001_ooool2001OG`0305nGU`0`Gel0GiMO00@005mO
00P0GemO05nGG`35aIL0UiMO04U9B@1OG`00UemO09NGG`80GemO00L0;2`/09O5G`00Gel0BDU902`/
;000AP00;2`/0080BDU90P0/;2`02P00Gel0>VTj02`00000G`00;2`/04U9B@1OG`00GemO04U9B@00
E002001O000605nG001OUel0aNo_05mOG`1OGc00BDU90P1OG`02001O000502`/;00`Nc00BDU904U9
B@00G`000P1OG`001@00Gel0Gel`04U9B@00G`00BDU900<0GemO00<0JFUY07=cL`19BDT00P1cLg<0
2P19BDT0UiNG0:n_[`2WYjL0GemO09NGU`25QHD0Lg=c0;Jf]P1hN7P209NGG`0802`/;01OG`00Gel0
02`/;016ATH0BDU905mOG`19BDT205mO0008000/001ONel0GiMO05nGG`00Gel005nG002GG`25QHD2
05nGU`80UiNG00<0GiO509NGU`2GUiL00`1OUiL00`00UiL0Lg=c05nGG`02002GG`0306V5Q@1cLg<0
GiNG00<0GiNG00<0UiNG07^GU`2GUiL00`1OUiL00`1OGiL0GiNG05nGU`0405nGU`0B002GU`1OUiL0
<9O505nGU`25QHD0UiNG05nGU`1OaLD0GiNG07:>SP1OUiL0YjNW05nGU`1OUlD0UiO50:NWY`23WkH0
GiNG0P1OUlD01P2GUiL0QHF505nGG`0FATH0;2`/02`000<0;2`/00@002`004T0000/;2`0000/0P0/
;2`01@1OGel0000002`/;00F5R`002`00080;2`/00D002`002`/;000;000;2`/0000B@02000/0004
00000019000002`001H/5P80;2`/0P00;00010000000;2`/01HF00000002000/0080000000@002`0
01HF;000;000000/0P00;00010000000;2`/02`/;000;00702`/;0060000;00/;2`0;2`/04U9B@0/
;2`001HF0P0/;2`0201OGiL0;2`/02`/;0000000;2`/01HF;00/;2`002`00P0/;2`00`00;000GemO
01H/5P0802`/;006000/000/;2`0;2`/02`/;01900005R`F0`0/;2`8ooooo`001_ooool01P1OGel0
Lg=c05mOG`1DE5@0GemO04U9B@80GemO00/0BDU905mOG`23Wh<0aIMO09MOG`19BDT0UiL005nGG`19
BDT005l`05mOG`0202`/;00>04U9B@0/;2`0BDU9031Y000/;2`0GiMO05l0G`1OG`00;2`/05nGG`1D
E2D005mO05mOG`00Gel204U9B@0A001c001OG`009EhU04U9B@1OU`00GemO09O5a@2f][H0;2`/05mk
<000L`0005l005mOG`1OUel005l004U9B@1DE5@00P19BDT02000Gel0BDU90019000/;2`0Gel`001O
G`00L`00BDU90`1OGel02`2=SHd0QHF505nGU`1OUiL0GenG08F5Q@1cLg<0NjjB0;Jf]P2WYjL0Lg=c
0080YjNW00`0Lg=c07]kN`1OUel0BDU900190019BDT004T004U9B@1OGel005mO04U9B@00B@0305mO
000607]OG`00GiL009NG002GU`00Gel0Lg=c0P1OUiL01P1O[Zh0YjNW09NGU`1OUiL0GiO509NGU`80
GiNG00/0Lg=c05nGU`1OUiL0GiNG05mOG`1cLg<0Gg]k05nGU`1cLg<0GiNG07=cL`0205nGU`0:08>O
W`1OUiL0GiNG05nGU`00GiL0GenG05nGU`1ONiL005nG002GU`@0GiNG00<0NiNG002GU`1OUiL01@1O
UiL209NGU`0505nGa@1OUiL0GiNG09NGU`2OWil0101OUiL02`1OUlD0GiNG05iNGP0/;2`002`002`/
;000;000000/000/000/00009AH000<0;2`/00<002`002`0000/00000`0/;2`20000;00604T00000
;0005R`F04T0000/;2`000000P0/;2`00`0002`0;1HF02`/;00202`/;005000/000/;2`0000001H0
5P0000000`0/;2`20000000401HF5P0/000002`00000;0<0;2`/00<05QH/02`/;00/;2`00P0002`0
2P00;000000/02`/;00002`002`002`/;00002`0;2`/000/000F;1H302`/;003000/000/;2`0;2`/
0080;2`/00<0000/02`/;00002`0100/;2`00`00B@00;2`/02`/;00>02`/;0Sooooo0006ooooo`80
05mO00<009MO001OG`00Uel00P00Gel01P1OGel0BDU905mOG`2BNg/0UiMO09MO0080Gel000`0GiMO
0019000`Gc00Gel004U9B@2WYjL0GiNG07=cL`00Gel0GUiN0:NWY`1OUel205mO000Q0025000/;2`0
9E@U00190019BDT0Lg=c09NGG`0/;2`0Gel005mOG`0k>c/005mO05mOG`1OUel0aLG500250000G`00
Gg]O04U9B@00L`00BDU905mO0019BDT0QHF505mO0000B@00;2`/05mOG`0/;2`005l002`/;01DE2D0
BDU900@0Gel000@0BDU906UYJ@1OUiL0UiNG0P2WYjL02P00GiL0YjNW06V5Q@2GUiL0GiNG0:NWY`2G
UiL0QHF505nGG`1bSW8304U9B@0@05mO0019BDT0Gel0031Y0019BDT005l004U9B@00B@00Gel004U9
B@2GNel0GiMO002GU`19BDT005mO05nGU`80Lg=c00<0GiN^05nGU`1OUiL00P1OUiL00`1OUlD0GlFG
05nG[P0205nGU`05002GG`1cLg<0Lg=c07=cL`0`UiL00`1OUiL01@00UiL0GenG05nGU`1OUiL009NG
00<0GiNG00<009MO05mOU`1OUg/00P00UiL00`1OUiL009NG05nGU`0;05nGU`0405nGa@1OaLD0GiO5
0:NWY`<0GiNG00D0UiNG05nGU`1OUlD0GiNG05A`E00202`/;00502`0000/;2`002`0000/00000000
0P0/000402`/;003000/000F5R`0;2`/008002`000@0B@00000/000/;2`0;2`/0P00;0001@0/;2`0
02`00000;00/;2`05QH/00<0;2`/00D002`002`/;00/;2`05QH/0000000202`/;080000000D0;000
02D0000/000002`00000;00402`/;00:0000;00/;2`0;2`/000/000/;2`002`002`/;000;000;2`/
0000;0H0;2`/00<002`002`/;000;0000P0/;2`2000/000302`/;000Gel0;2`/0080;2`/00<05S/F
02`/;00/;2`01P0/;2`01`000000;2`/02`/;000;000;00002DF000002`00P0/;2`8ooooo`001_oo
ool00`00Gel009NG001OG`04001OG`<0BDU900@0[ZiO05mO001OG`00Gel00P1OUel02`0/;2`0<5l`
04U9B@1OGel0UiNG0:NWY`2GaLD0GemO08>3E02GUiL0001O0080BDU900/0Gel004U9B@1kNel005l0
05mO0019BDT005mO09NGG`00Gel0GemO031kN`0205nGG`050<G5k`35aEl0BDU904U9B@0`Gel00`1O
Gel02`19BDT0GemO09NGU`0jJCX0BDU9001O001OG`00BDU905mOG`0/;2`0ATHF0080Gel000H009MO
05mO001O05l0GiMO06UYJ@1cLg<405nGU`0:08F5Q@2WYjL0][Jf0;Jf]P35aLD0][Jf09O5U`1OGel0
NemO07=cL`8005l000<0;2`/04U9B@19BDT00P1OG`003@00L`0005mO02`/;019BDT007<005ADE02G
Gel0BDU9001OG`00GiL0GiNG07=cL`1OGel0101OUiL20:NWY`0605nGU`23Wil009NG05nGG`00UiL0
GiMO0P1cLg<0101ONel0GiNG002GU`00GiL205nGU`0;09NGU`1OUiL0GiMO002GG`1OGiL0GiNG001O
U`1OUiL0<9Mk05nGG`00UiL00P1OUiL00`00UiL0GiNG05nGU`0:05nGU`0=05nGa@2GUiL0GiO508>O
W`1OUiL0GlFG05nGa@1OUiL0UiNG05nGa@0`Nel004T0000/000302`/;00=000/000/;2`05QH/0000
00190000;2`/0000;00/;2`0B@0001HF5P0/0000;2`/0000;00302`/;0040000;00/;2`0;2`/02`0
00<0;2`/00X0;1HF000/000/;2`002`004T00000;000;2`/03/000000000;2`/0P00;0001@000000
000/02`F5P0002`002`000<0;2`/00P0B@00000F5P0/;2`0;2`/0000;00/;2`0000/02`/;080000/
1@0/;2`01P0F;1H0;2`/02`/;000;000;2`/00000080;2`/00<05S/F000/000/;2`00P0/;2`02000
04T002`001HF>`19BDT0;2`/0019000/;2`0BDU90`0/;2`01`19BDT0;2`/02`/;00/;2`0;00002`/
;000;0000P0/;2`8ooooo`001_ooool0100`Nel0JFUY05mOG`0`Gel2001OG`0D02EDE01OGel005mO
06UYJ@2[`X<0Uel`07]O<01OGc00Ug/`031Y001OG`00B5m805mk<01DE5@0JVYZ0:NWY`1iNF80>c/k
04aGC01NGUh205AD9@0R06V5Q@20P800C7]S0861MP1`L5@0QHEY08>3P`1ONel0E5@U031O<01DL5@0
<6@`06MWI`2UYJD0Fh]K06MWI`25JFT09E@U03]CD`1DE5@0<7]O07]kG`19BDT0E5@U05mO<01YJE80
PinO07alO00`Gel0BDU904I65P0k>c/0=dm?05mO0080E5@U00@0E71D05ADE01DE5@0GemO0P1kNg/0
1P2OWil0YjNW09nf]P2WYjL0[jn_07^GU`80E71`00h0JFV508f=S@2OWh<0Ng]]06V5J@1<Nd`09EAD
01I6AP0/;2`09E@U05=C8`1DE5@0Gel003160080E5@U0180E5AD05mO<01YQFT0<5mk08FLQ@1YQHD0
GiNG06VLQ@0`UiL0B7]k05nGU`1kUjh0GjjG07^GU`23WkH0NiNG06fGU`1OUg/2031kG`0D05nGN`0`
Ug/0<9Mk07NCT`0`NiL0GiNG07^^[P1OUiL0NiNG04bGU`1bSXh0JHF505nGG`0`Ug/0>VUY032GN`1b
SXh0RJ>G031kU`0`UiL205nGU`04031kU`1OUiL0GiNG032GU`<0GiNG01T0LXjU05nGU`1OUiL0GiN^
08>O]P1OUlD0WinO09nf]P1OUlD0LI^K05n^a@1OUiL0NiNG05nGU`2GUiL0NiNG04f0P00FATH0;1HF
02`/;00F;1H0;1HF01H/5P0/;2`0:AH;0080;2`/00@001H0051@D00F;1H05QH/0P0/;2`01`0k5QH0
5QH/01HF>`0F5QH05R`F02=18`0U5P000`0F;1H00`0F5R`05R`F01HQ5P0202`/;00>01H/5P0F5R`0
;2`/01H/5P0;8AH0000002DF000F01H05R`F000F000F;1H02`/F00005P005QH202`/;00<01HF;00F
;1H05R4F02`/;0005QH05P0F01H/5P0F5QH0;2`/024/8@0F;1H05QH00P0/;2`010005QH05R`F01HF
8@0F;1H202`/;00301H/5P0/;2`0;2`/00<0;2`/00<001HF02`/;00F5S/00P0k>c/03`0Q=24002DU
02`/;00F5S/05QH/01HF>`0/;2`0;24Q02`/;00F;1H0;2`/01H/5P0/;2`05R`F024/8@0202`/;003
03/k>ooooooooooo00Kooooo0006ooooo`<0GemO00<005mO001OU`00Gel00`00Gel0502GaIL0f/FG
09NGG`1OU`00GemO001c001OG`00BDU9001OG`1OGel0BDU905mOG`19BDT007<005nGU`2=SHd007<0
04U9B@35aLD0][Jf0P25QHD0101OUg/005mO05mOG`1OUel405mOG`0E05mkG`35aNl0UiMO001OG`19
BDT0Gel009NGU`0`Gel005mO09NGG`1OUel0UiNG05nGU`00Gel0Ph>305nGU`1OU`0005mO05mOG`00
G`00BDU90080GemO0180BDU9002GG`1OGel0UiNG001OG`1OGel0YjNW0;Jf]P2GUlD0aIO509NGa@35
aLD0Ujj^08F5Q@00Gel0GemO05mO001OGel208F5Q@0305nGG`19BDT0BDU90080;2`/00<0BDU9031D
0019BDT00`0/;2`04`00Gel0GemO05A`E02GUiL0GiNG0:NWY`1OGiL0GiNG05mOG`00GiL0<7]k05nG
a@2GaLD0YjNW09NGa@1OaIL0YjNW08>OW`00Gel00P1OUiL01P00Uel0YjNW09NGU`1kUiL0GlG509O5
a@80UiNG00X0GiO50:NWY`23Wil0GiNG05nGG`00GiL005mO05nGU`2GUiL0NiNG0`1OUiL01000UiL0
GiNG05nGU`1OUjh605nGU`0405nGa@1OUiL0UiNG09NGa@80YjNW00H0GiNG08>OW`1OUiL0YjNW05nG
U`1OaLD209NGU`0405mkU`00Gel0;2`/02`/;080000/00H002`00000;00F5QH002`002`/;000;002
02`/;006000/000/;2`0;2`/000/000/;2`002`00P0/;2`02P0F5QH0;2`/0000;0190000000/02`/
;000;0005QH/02`/;00002`202`/;00400000000;0005QH004T0008000000P00;0002@0/;2`0;000
00000000;000000002`00000;0000000000F0002000/00@0;2`/00D05QH/02`/;00/;2`0000/000/
000202`/;00301H/5P0/;2`0;2`/00`0;2`/00<05S/F0000B@0/;2`01P0/;2`01`00Gel0;2`/02`/
;000;000B@0001H/5P00;0000P0/;2`8ooooo`001_ooool305mOG`8005mO00H0GiMO001OG`00Gel0
05mO09NGG`35[W/305nGG`0K04U9B@1OG`00BDU9031kG`00;000;2`/001O0019BDT0;2`/04U9B@2O
Wil0GemO04U9B@0/;2`0QHF505nGU`1cLg<0GemO04U9B@1OGel0GiMO09NGU`1OUel0GemO05nGG`1O
Ng/0aNo50080Gel001X0GemO05mOU`2WYjL0BDU905mOG`1OG`00GemO001OG`1OU`00BDU907]kN`1O
UiL0QHF50;Jf]P25QHD0BDU9001OG`1ONel0BDU905mOG`19BDT0GiMO001OG`1OGel0Ng]<001OU`80
UiNG00D0UlG50;Jf]P2WYjL0NiNG05mOG`0204U9B@08001OG`1OGel0Lg=c07^GN`2WYjL0GemO05mO
0019BDT202`/;00<031O0019BDT0BDU902`/;000G`00GemO04U9B@13LW80UiNG08F5Q@2WYjL0Lg=c
0`1OGel01P1OUiL0GiO50:NWY`2WYjL0GlG509O5a@<0GiNG00<009NG05nGU`1OUiL00P1OUiL02@1O
Ujh0GiO505nGa@2WYjL0GiNG09NGU`2WYjL0WinO09NGU`02002GU`<0GiNG01<0GiN^05nGU`1OUiL0
QHF505nGU`00UiL0GiNG05BOW`1OaIL0GenG05nGU`1OUlD0GiNG05o5a@1kUiL0UiNG0:NWY`1OaLD0
YjNW0080GlG500T0GiNG09NGU`2GUiL0UiNG0:NWY`1OUiL0GiO505nGU`1OGel00P0/;2`00`00;000
;2`/02`/;00202`/;080000/00<0;00002`/;00/;2`00P0/;2`00`190000;2`/0000;00202`/;006
0000000/;2`0;2`/02`/;000;000000/1@0/;2`01@00;000000/02`/;00002`05R`F00<0000000@0
;00002`/;00002`05QH/0P0/;2`01@0002`002`002`/;00/;2`05QH/0080;2`/00L0000/02`/;000
0000;2`/01H/5P0/;2`0;0000080;2`/00<000000000;00F5R`00P0/;2`02@00B@00;2`/02`/;00/
;2`002`002`/;000B@00;2`/000/000202`/;0030019000/;2`0;2`/00<0;2`/00D004T002`/;00/
;2`0G`1O05mO000302`/;003000/000/;2`0;2`/0080;2`/2?ooool000Kooooo0`1OGel2001OG`06
05mOG`00Gel0aING05mOG`35aIL0fZj^0P1OUel205mOG`80BDU900X0JFUY04U9B@0/;2`0GemO04U9
B@1OG`00GemO0;blX02GUel0Gel00P19BDT00`25QHD005mO05UIF@0305mOG`0M09NGU`1OUiL0QHF5
001OG`1k[Y8005mO001c001OG`00BDU905nGG`00G`0005mO0:NWY`2GUel0BDU905mOG`00Gel0Lg=c
06UYJ@2GUiL0GiNG0:NWY`2GaEl0GemO04U9B@1kGel0GiNG08F5Q@19BDT00P1OUel04P19BDT0Gg]k
07=cL`2WYjL0UlG50;Jf]P2WYjL0GiNG06V5Q@1OUel005mO05mOG`19BDT0UiNG05nGU`1ONc00BDU9
05mO0080;2`/00<0B@00001O001DE2D00P19BDT03P0/;2`0BDU905nGG`1OUel0QHF505nGU`2WYjL0
GiNG07=cL`00Gel009MO05nGG`1ONiL0UiO50`2WYjL03P2GUlD0GiNG07^G[P1OUiL005nG09NGU`1O
UiL0QHF505o5U`1OUiL0UiNG05nGU`2WYjL0GiO50P2WYjL01023Wil0GiNG001OU`1OUiL209NGU`<0
GiNG010009NG001OU`1OUiL009NG05nGU`1OUjh0UiNG05nGa@2GUiL0GiO505nGU`1OUlD0NiN^09NG
U`2WYjL0GiNG0P2GUiL02P1OUiL0GlF^05nGU`2WYjL0GiNG05nGa@2GaLD0GiO505nG[P1OGiL302`/
;00402`0000/;2`002`002DF0080;2`/00<002`002`/;000;000100/;2`00`00;000;2`/02`/;002
02`/;006000/000/;2`0;2`/0000;00/;2`000190`0/;2`01P0/0000;2`/02`/;00/;2`05R`F000/
00<0;00000/002`002`/;00001H0;2`/00000000;000000/0000000/;2`05QH/0000;00502`/;003
01HF;00/;2`002`000T0;2`/00<002`002`/;00/;2`00P0/;2`01@00;000;2`/02`/;00/;2`00019
00`0;2`/00<0000/02`/;00/;2`00`0/;2`8ooooo`001_ooool0101OGel005mO001OG`0`Gel205nG
U`07001OG`1OGel0GemO0<FGU`35Uel0GemO07=cL`0205mOG`0<04U9B@00Gel0WinO05mOG`1OUiL0
UiMO001OG`1OGel0BDU90820P01OGiL005l00P19BDT02`1OUiL0BDU9031D<02GaLD005mO05mOG`00
G`00GemO09O5a@1OUiL0[/F^0080GemO00@0Lg=c001OG`0/;2`0Gel00P19BDT02000Gel0BDU905mO
G`19BDT0GemO05mkG`1OUel0QHF50P2WYjL03P2GUiL0UiMO031O<01OGel0UiNG05mOG`1OUel0QHF5
07=cL`1YQHD0UiNG05nGU`2GUlD0aLG50P1OUiL02@1NGUh0Gel0001OG`19BDT0GiNG09NGU`2WYjL0
E5@U05mOG`0204U9B@80;2`/00X0Gel004U9B@19BDT0;2`/001O001OGel0GiMO09MOG`23Wil0UiNG
0P1OUiL02019BDT0GenG05nGU`1OUiL0NiN^09O5a@1OUlD0YjNW0P2GaLD00`2GUlD0Ujj^0:NWY`04
05nGU`03002GU`1OUiL0GiNG0080GiNG00H0UiNG05nGa@1OUiL0GiNG05mOG`00GiL405nGU`0405nG
[P1OUiL0GiNG05mOU`<0GiNG00@0GiN^05nGU`2GUiL0QHF50P1OUlD04P1OaLD0GiO505o5a@2GUlD0
YjNW05o5U`1OUiL0GiO505n^a@1OUiL0UiNG08F5Q@2GUiL0GiO505nGU`1OUjh0Lg=c001OG`<0;2`/
00P0000/000/000F;1H002`002`00000;000;2`/04T000T0;2`/00<002`00000;00/;2`00`0/;2`0
0`0F;1H0000/02`/;00202`/;00402`0001900005R`F02`/;080000/00L00000000/001900005QH/
0000;00/00000000008002`00P0/;2`01@0002`0;2`/02`/;00/;2`002`000<0;2`/00D0000/000/
00000000;2`/000/000202`/;003000/000/;2`0;2`/00<0;2`/00<05R`F02`/;00/;2`02`0/;2`0
0`0F;1H002`002`/;00302`/;00302`0000/;2`0;2`/0080;2`/2?ooool000Kooooo0P00Gel00`19
BDT0GemO05nGU`0305nGU`0A05nGG`35aIL0YJEb07=cL`1OGel0Lg=c001c001OGel005mO08^;R`1O
Gel0][Jf05nGU`2GUiL0YjNW08F5Q@2EUID00P1cLg<01`1OGel005mO08F5Q@19BDT0E5@U05nGa@35
Uel00P1OUel0:@1OGel0aLFG08F5Q@2n_[h0YjNW0;Jf]P2GUel0UiNG05mO0019BDT0JHF504U9B@1O
Gel005mO001O001OGel0GiMO08F5Q@1OG`0007<005mOG`25QHD0YjNW07=cL`1bSW80BDU90:NWY`2G
UiL009MO05mOG`1cLg<0O7al05mOG`1cLg<0QHF509NGU`1OGel0YjNW071`L01OGel0BDU90080GiNG
00@0UiNG001c001DE2D0BDU90P0/;2`504U9B@0802`/;01OGel0BDU904U9B@1OGel0GUiN001OU`1O
Uel205mOG`0;05nGU`1OUlD0GlG505nG[P1OaLD0UlG505o5a@1OaIL0GlG509NGU`1kUlD01@1OUiL0
1@1OGiL0<9N^05nGU`1OUiL0UlG50080YjNW00<0GiNG032GN`1OUiL00`00UiL00`1OGiL009NG05nG
U`0405nGU`0605nGa@1OUiL0Gi:^05nGa@00UlD0GiO50P2GUiL0101OaLD0Gjk505nGU`1OUiL20:NW
Y`80GiNG0140LXj>05nGa@1OUlD0YjNW09O5a@1OUiL0UiNG05nG[P1OGiL005mO0000B@0/;2`0B@00
02`/;01OGel0<4H`000/000202`000050000;00/;2`0000/01H/5P0002`0100/;2`01`0002`0;2`/
02`/;00/;2`002`002`/;000;0000P0/;2`00`0002`0;2`/02`/;00302`/;00501H0000/;2`0;2`/
000/000/;2`00P00;000200F01H002`00000;000;000B@0002`/;00002`05R`F0`0/;2`2000/0005
02`/;00F5R`0;2`/02`/;00002`00P0/;2`00`00;0005QH/02`/;00202`/;0030000B@0/;2`0;2`/
00d0;2`/00<0Lg=c02`/;00/;2`00P0/;2`00`0002`0;2`/000/000502`/;0Sooooo0006ooooo`80
05mO0280GemO001OG`1cLg<0BDU905nGU`1cLg<009MO0:NWY`2>YG80GemO001OG`1cLg<0UiMO04U9
B@1OGel0][Jf05nGU`2GaLD0aLG50;Jf]P2GUiL0YjNW07^BTP35UiL0GiNG05mOG`2GUiL0GemO05nG
U`1YJFT0GemO09O5a@25QHD0GiO50P1OGel06P35aNl0PinO05o5a@2f][H0UlG509O5U`0/;2`0GemO
07]kN`1OGel0Lg=c0;Jf]P35aIL0UiNG05mO000jJFT0GemO05nGG`1cLg<0QHF504U9B@1cLg<0NiMk
05mOG`19BDT0GenG0`19BDT02P1ONg/0BDU905mOG`1OGel0GiNG04U9B@1OGel0SZFU05nGU`2WYjL2
07=cL`0508F5Q@19BDT0JFTj02`/;000B@000P19BDT00`00G`00BDU901I@5P0204U9B@0A05mOG`0/
;2`0Gel004U9B@1YQFT0GenG05mOG`25QHD0Lg=c05nGG`1OGiL0GiNG08>O]P2WYjL0GiO50:NWY`2G
UlD00P2WYjL01@23WkH0GiNG05nGU`1OUiL009NG0080GiNG00<0Gg^G05nGU`1OUiL00P2GUiL00`1O
UiL005nG05mkU`0205nGU`03002Ga@1OUiL009NG0080GiNG00<009NG05mOU`1OUiL00P1OUiL0102G
UlD0GiN^05nGa@1OUiL405nGa@0B05n^U`1OUiL0GiNG09O5a@1OUlD009NG05nGU`23Wil0GiNG0:NW
Y`1OaLD0GiNG0:NWY`1OUlD0GiN^002GU`1OGel0BDU90P0/;2`04@00;000;2`/03/F5P0/;2`002`0
02`0000/;2`0000/04U9B@0F;1H0;2`/000/000/;2`0B@0002`/;00002`05P0F0080;2`/00<002`0
0000;019BDT01P0/;2`01P0002`0000002DF0000;000;00002`/;08002`000@0;2`/0000;00002`0
02`00`0/;2`00`0002`0;1HF000/000302`/;08002`000P05R`F02`/;0000000;2`/0000;00/;2`0
02`001HF;0D0;2`/00<004T002`/;00/;2`00`0/;2`20000B@<0;2`/00H0001902`/;00/;2`005mO
0000;016HTH202`/;008000/000/;2`0;2`/02`/;00F;1H0;2`/04U9B@0/;2`8ooooo`001_ooool0
A@00Gel0<5mO02EDE00HGfd0GiN^02EDE025QHD0Njj^07^GU`2OWil0RJ=k04U9B@1DE5@0GemO06UY
J@1ONel0YjNW08VS^P3CdnP0aLG50;Jf]P2f]//0][Jf0>;JfP2M][H0Ug]<0:k5[P1kUg/0_[jn04U9
B@1lO7`0B7]O08f=S@1YQFT0WkJf0;K;]P2GUiL0UlG_08^W_P2B^]00Winf09N^[P2_[jl0SHf=05mO
G`1`L5@0S9Z<09nO]P1STW/0E5AD07:>SP1<Nd`0E5AD05AR?@16ATH0GemO08j>SP1DL700JFUY09nO
]P2IVIT0E5AD079bLP1OGel0E5AD031OG`0UE2D0MgM705mkG`0206UYJ@0I05ADE01OGel0Ng]<08f=
S@2OWkH0SHf=09nOW`1OUjh0NiN^08j>SP1KNdd0Gel`03/k>`19BDT0>c/k07=cL`1lO7`065<`031O
0019BDT0Gel`02EN9@1DE5@0BDU906ATC@02031ON`0D0:NWY`1ONg/0<7]k05nGU`23WkH0LI^W08>O
]P23][H0WkJf07^^a@23WkH0WinO07nKY`1OUiL0>XF5032GU`1YQHD0Gg^^05nGU`18RIL205nGU`07
09nOW`1k[Zh0Gg^G002GU`18UiL007^G032GU`0205nG[P80GiNG00h0GiNS032GU`0`UiL0<7^G05nG
U`1OUjh0Pinf07nKY`1OUlD0NiO508>O]P1O[Zh0NiNG05nGU`80GiN^00X0GiNG08>OW`2O][H0<9NG
05nGU`1]Ujh0GiN^07^^[P23WkH0WinO0P1kUjh0101OUjh0GiNG05mOU`00Gel302`/;00501H/5P0F
5QH05QH/02`/;00002`00`0F5R`00`0/;2`05QH/02`/;00202`/;00402`000005QH05R4Q01H/5P<0
;2`/00D05R`F02`/;00/8B40;2`/01HF;00202`/;005000F5P0U01H0:AHQ01H/5P00;0000P0/;2`0
100F5R`0;2`/01HF;00002`202`/;00501HF000F5R`0;2`/00/Q5P0F;1H00P0/;2`01`0F5R`0;2`/
01H/5P0F8AH05R`F01HF;00`HT`00P0/;2`00`0F5R`0;2`/02`/;00202`/;00701Hk5P0/;2`0;2`/
01Hk5P0Q8C@0;2`/000U5P0402`/;00601HQ:@0/;2`0;2`/02`/;00F5S/005@00P0/;2`02P0F;1H0
5QH/01H/5P0/;2`05R`F051@D00Y=2T0;2`/04U9B@0/;2`8ooooo`001_ooool02`00Gel0GemO001O
G`0`Gel0BDU9001OG`2GaLD0e=CD0<G5a@2WYjL0Ni9k0080GemO00D005mO05nGG`0/;2`0GiNG09nO
W`020<G5a@0=0<G_a@2f][H0hN7Q0:NWY`23Wh<0UiMO0<G5a@1cLg<005mO04U9B@00Gel0TW]k001O
G`0205mOG`0605nGU`2GaNl0QHF509NGU`1k[/D0][Jf0P2GaLD03`35aLD0GiNG05nGU`2WYh/0BDU9
001OG`1OGel0YjNW09NGU`1OGel0Yh^;0:NWY`19BDT0GemO05nGG`0207=cL`0C079bLP1OUiL0Lg=c
09NGG`1OGel007<005mOG`1ONel0QHF5001c001OGel0B@0004U9B@1OGel0<5mO05mOG`1cLg<0YjNW
09NGU`0205nGU`0K06UYJ@1OUel0QHF505nGG`1OGel0QHF50:NWY`1RHV80BDU905mOG`1OG`00BDU9
05mO001OGel0GiNG001OG`1OGel005nG05nGU`2GUiL0GiNG09NGU`1kUjh0][Jf09NGa@2WYjL0GiO5
0080YjNW00<0<9NG05mOU`1OUiL01`1OUiL02@2WYjL0UiNG05nGU`1OUiL0<9NG002GU`1OUlD0GiNG
09NGU`0205nGU`0406V5Q@1OUiL0GiNG002GU`<0GiNG00P0GiN^05o5a@1OaLD0UiNG05nGa@00UiL0
GiNG05n^[P80GiNG00P0YjNW05nGU`1OUiL009NG09NGU`1OUlD0YjNW09NGU`D0GiO500<0GiNG05mO
G`0/;2`00P0/;2`00`00;0005QH002`/;00502`/;00401HF;00/;2`0;2`/000/0080;2`/0180000/
01H/5P0/;2`0B@000000;00/;2`002`002`/;00F;1H0;2`/02`000190000;2`/000/000/;2`05QH/
02`/;00002`3000/000502`/;00002`002`002`/;000;0000P0/;2`00`000000;2`/02`/;002000/
000502`/;000;000;2`/02`/;00000000P00;00302`/;003000F5P0/;2`0;2`/00@0;2`/00<004T0
02`/;00/;2`01@0/;2`00`0F5R`0;2`/02`/;00202`/;003001OG`0/;2`0;2`/00X0;2`/2?ooool0
00Kooooo0`00Gel0601kUlD0GiO509O5a@2WYjL0hN7Q0;Jf]P35aIL0LW9305mO001OGel005mO05mO
G`19BDT0GemO07^^a@2GUlD0YjNW0<G5a@2GUiL0kno508F5Q@2BTY80GemO0;Jf]P8005mO00`009MO
07=cL`2n_[h0QHF50;Jf]P1OUel0UlG509NGU`2f][H0GiNG0:k5a@1OUlD20:NWY`0<001OG`35aLD0
UlG50:j^TP00G`00aLG505mOG`1OUiL0YjNW05nGU`1kTY80UiNG0P1cLg<06@2GUel0GemO08F5Q@1<
NiL0UiNG07=cL`1OGel005l008F5Q@19BDT0<6T`05mOG`00B@00BDU905mOG`1cLg<0BDU905mkG`1c
Lg<0GiNG07=cL`1OUiL0UiNG05nGU`1kNel00P19BDT02@1OG`00BDU904U9B@00G`009EAD05mOG`1O
G`00GemO05nG000205mOG`0609:^U`00Gel005mO001OG`25QHD0Lg=c0P1OUiL0201OUjh0YjNW0:NW
Y`2GUlD0UlG509NGa@1OaLD0Gg^G0`1OUiL01@00UiL0GiNG05nGU`1OUiL0UiNG0080YjNW00P0GiNG
002GU`1OUlD0Gg^G08F5Q@1OUiL0GlFG09O5U`80GiNG00<0<9NG05nGU`00UiL0101OUiL00`1kUiL0
GiO505nGU`0405nGU`0305nG[P1OUlD0YjNW00@0GiNG00P0PinO0:NWY`2WYjL0UiO505o5a@2GUlD0
GiNG07^G[P80GiNG00T005mO04U9B@0/;2`0;2`/000/000F5P00;2`/000/001900000P0/;2`00`00
02`001HF02`/;00402`/;003000/000/;2`002`000<0;2`/00P002`002`/;00F;1H0;2`/0000;00/
;2`0000/000/0080000/00L0;2`/0000;0000000;000000/000002`05QH/0080;2`/00P002`002`/
;00/;2`0;00001HF;000;000000/000/0080;2`/00T0000002`F5P0/;2`002`00000;0000000;2`/
000/000F;1H01`0/;2`00`0k>c/0;2`/02`/;00702`/;00307=cL`0/;2`0;2`/00<0;2`/00<0000/
02`/;00/;2`00`0/;2`00`19BDT0;2`/04U9B@08ooooo`001_ooool3001OG`0808f=S@35aLD0UlG5
09O5a@35aNl0aLG50;Jf]P1kNel405mOG`0<00190025QHD0NiNG08F5Q@2WYjL0Lg=c09NGU`1cLg<0
GiMO08^;R`1OG`00UiNG0`1cLg<01`25QHD0JHEY0:NWY`1OGel0GiMO09O5a@2GGel00P1OGiL07`2O
][H005mO05mOG`1OUel0GemO0;Jf]P2GaEl0E5@U07=cL`1OGel0UiNG0:NWY`1cLg<0GemO05iNGP25
QHD0UiMO0=CDe02GUiL0Lg=c02`/;01hN7P0][Jf0:NWY`19BDT0Lg=c08F5Q@1OGel0<7]O05mOG`25
QHD00P19BDT0101OUiL0BDU906UYJ@2GGiL20:NWY`0B09O5a@1OUiL0Lg=c07]kU`1OUel005mO0019
002GUel0YjNW07=cL`1OGc00GemO05nGG`1OGel0GiL005mOG`19BDT0C7]O0P00Gel01P1OUel0Lg=c
05nGU`2GUiL0GiNG07^G[P80UlG5102WYjL00`0`UiL0GiNG05nGU`02002GU`03001OU`2GUiL0Gjk5
0080YjNW00P0GiO505nGU`2WYjL0GiNG05n^U`1OUlD0GlFG05nGa@L0GiNG00L0Lg=c05nGU`1OaLD0
GiNG05nGa@1OaIL009O50080GiNG00@0GiO505n^[P2GaIL0UiNG101OUiL01@1kUiL0YjNW0:NWY`2G
UiL0GiO50080YjNW101OUiL01@19BDT0;2`/000/000/;2`0>aHF0080000/0`0/;2`04@00;000;2`/
000/0000;000000/02`/;000;000;2`/0000;000;000000/02`/;00002`00000000/000/5QH0000/
0080;2`/00H002`00000;00000005QH/02`/;00002`202`/;0060000;00/;2`0000/0000;000;000
;2`/0`00;0002@0F;1H0;2`/02`/;00004T0;2`/000/000/;2`09AH002`/;002000/000302`/;000
;000;2`/0080;2`/00<0000/02`/;00/;2`0200/;2`02000;000;2`/02`/;000B@00;2`/000/0019
BDT004T01@0/;2`00`00;000;2`/02`/;00202`/;080BDU92?ooool000Kooooo0P00Gel02`1OUiL0
Ujk50<G5k`2WYjL0][Jf0>7Qh@2WYjL0aLG507^BN`1OGel005mO0080BDU900<0GemO09NGU`23WkH0
0P2GUiL03`1cLg<0YjNW05nGG`2GUel0UYJF05mOG`00Gel0Gel004U9B@2GaIL0GemO031k<019BDT0
YjNW0<G_k`0205mOG`0H07=cL`25QHD0LXib04U9B@1OG`0005mO0:NWY`2GUiL0GiMO06UYJ@1OUel0
GiO50;Jf]P25QHD0GemO001OG`2=SHd0BDU905mOG`2WYjL0][Jf0<FGG`1OUel0<9Mk0P2f][H03@2G
Uel0GemO002GG`1OUiL0<5@`05mO001OGel0GiNG0:NWY`2GaLD0GemO08>3P`2GaLD00`2f][H0102W
YjL0UiNG05mkG`00G`0202`/;00I05mOG`2GUiL0UiNG09nOW`1cLg<0UemO05nGG`19BDT0GiMO05mO
000`Gel009MO001OG`1cLg<0BDU905nGU`2WYjL0GiO509nOW`2GaLD0UiO509O5a@1OaLD0UiO50:NW
Y`0305nGU`80QHF500D0GiNG0:NWY`2GUiL0UiNG0:NWY`0205o5a@0705nGa@1OUiL0GiN^0:NWY`2G
UiL0GiNG09NGU`0205nGU`03032GU`1OUiL0GiNG0080GiNG00D009NG05nGa@1OUiL0GiNG002GU`04
05nGU`0307^GU`1OUiL0GiNG0080GiNG00<0QHF505nGU`2WYjL01@2WYjL02`1OUiL0Ph>O05nGU`1O
UiL009NG04U9B@0/;2`0000/04T0000/;2`0000/0080;2`/00@0000/02`/;00000005QH/0`0/;2`0
2`00;000;2`/02`/;00k5QH0;2`/000/000/;2`0000/02`0000/;2`05R`F0080;2`/00`0;00002`/
;00/;2`002`001HF;00/;2`0000/0000000/;2`002`00000000U01H30000000;000/000/;2`0;2`/
02`/;0190000000/000/000/;2`002`002`/;0005QH00P0/;2`0200/0000000002`/;00/;2`05QHF
000/000/;2`002`00`0/;2`00`19BDT0;2`/02`/;00302`/;0050000;00004T0;2`/02`/;00004T0
100/;2`0100FATH0;2`/02`/;00002`502`/;080BDU92?ooool000Kooooo00/005mO05nGa@2WYjL0
[jn_0<G5k`35aLD0][Jf09NGG`35aLD0YjNW09MkN`0205mOG`0L05mO0000G`0005mO0:NWY`2^aLD0
QHF50<FGU`19BDT0UiMO04U9B@1OGel0Pin305mO001OGel0;2`/05mOG`2GUel005mO079bLP1OUiL0
UiMO0<FGU`2f][H005mO05nGU`35aLD0Ujj^08F5Q@80YjNW0100Lg=c09O5a@2WYjL0TY9k0;Jf]P35
aLD0][Jf09NGU`2WYjL0GiO50=?Cd`2f][H0UiMO0:NWY`1OUiL0UiNG0P2WYjL00`1OUel0YjNW0:NW
Y`0207=cL`0:08F5Q@1ONel0GemO05mOG`2f][H0GemO09NGU`1cLg<0Ujk50<G5a@<0][Jf00D0UiNG
04U9B@0UE2D0GemO02`/;00204U9B@80YjNW00L0WinO09MOG`1OGel0GemO09NGG`2GGel0GiMO00<0
05mO00H0GemO05nGU`1OUiL0UiNG05nGU`2;_ZL309O5a@040:NWY`1OaLD0YjNW05nGN`80GiNG00<0
GiMO05nGU`1OUiL00P2WYjL209NGa@0509O5a@2GUiL0YjNW0:NWY`2GUjh00`1OUiL20:NWY`0305nG
U`1OUg/0GiNG0080GiNG00@009MO05nGU`1OUiL0GiN^0P1OUiL01@00UlD0GiNG05nGU`1OUiL0WinO
00D0GiNG00D0GiO505nG[P2WYjL0][Jf09NGU`020:NWY`80GiO50P1OUiL00`1cLg<0GemO001OG`02
02`/;00303/F5P0/;2`0000/0080;2`/00<0000/02`/;00F;1H00P0/;2`00`0002`0;2`/000/0006
02`/;00502`00000;000;2`/02`0001900000P00;0001P0/;2`0000/02DF000/;2`0000/02`/;080
02`000@0B@0000005P00;000;0000P0/;2`010000000;2`/01HF;000;00302`/;080000/01005QH/
0000;00/;2`0;00002`/;00002`0;2`/000F5P0002`004T0000/000/;2`0BDU9000/000/;2`05S/F
1P0/;2`0100F5S/004T00019000/;2`20000B@0502`/;00F;1H0;2`/02`/;000;0000`0/;2`0101D
E2D0;2`/02`/;00/;2`8ooooo`001_ooool03P1OUiL0UlG50:NWY`1k[/<0][Jf0<G5U`1cLg<0GemO
0<G5a@2GUiL0NemO05mOG`19BDT0GemO0P19BDT04`1OG`00RjNW05nGU`19BDT0;2`/05nGG`19BDT0
04T005A`E000G`00UiNG08F5Q@2GUel0Lg=c05nGU`1YJFT0GemO0<G_k`2GaLD00P2GUiL02P25QHD0
][Jf09NGU`1OGel0Lg=c09NGG`2WYjL0UiNG0:NWY`2f]Yl20;Jf]P0@0:NWY`1OUel0aLG50<G5k`2W
YjL0][Jf0=CDe035aLD0GiNG0;Jf]P2WYjL0RjNW0:NWY`1OGel0YjNW09O5U`80GiNG01<0SXj>07=c
L`19BDT0GemO0;Jf]P2WYjL0aLG509O5a@35aLD0][Jf0<G5a@2f][H0GiNG07=cL`1bSW8005mO09NG
G`0/;2`0Gel00080GemO00@0Ng]k0<FGG`1OG`00UemO0P2GUel01@1OUel0<5mO05nGU`2GaIL0Lg=c
0080GiNG00<0YjNW05nGU`23WkH01@2WYjL00`1OUiL0<9NG05nGU`0405nGU`0309O5U`23Wil0UlG5
00@0YjNW00D0GiO509nOW`1OUlD0GiNG05nGa@0209NGU`0305nGU`1k[YL0GiNG00@0GiNG00<0UiNG
05mkU`1OUiL01P1OUiL00`2GUiL0GiNG05nGU`0205nGU`0>0:NWY`1O[Zh0YjNW0:NWY`1OUlD0UiNG
0:NWY`1OUlD0GiN^09NGU`1OUiL0GenG07=cL`19BDT202`/;008000F000/000002`0000/00190000
;2`/0000;00/;2`20000;00<02`/;00002`0;00002`/;00k5QH0;2`/0019000002`0B@000000;000
;0005R`F0P00;0001@190000000/0000;00/;2`09@0F0080;2`/00H002`00000000/000002`001H0
0000;00302`/;00304T0000/;2`05QHF008002`00P0/;2`03000;000000/02`/;00/;2`0000/02`/
;00002`002`002`/;00F;1H0;2`/0000;0P0;2`/00<004T002`/;00/00000`0/;2`2001900@0;2`/
00<002`002`/;00/;2`00P0/;2`01@00;000;2`/02`/;019BDT0GemO00Sooooo0006ooooo`040:NW
Y`2GUiL0GiNG08F5Q@80GemO00<0UiNG09O5a@35aIL00P2GUel405mOG`0J02`/;019BDT0E71D04U9
B@1OG`0007<004U9B@1OGel0Gel005iNGP1OGel0QHF505mO000/;2`0BDU908F5Q@1DL5@0UlG50<G5
U`35aLD0GiMO0:NWY`1OUiL0YjNW06UYJ@35aLD209NGU`0605nGU`2WYjL0YjNW07^G[P2f][H0GiMO
0P2f][H00`3De=@0][Jf07^^[P020<G5a@090:NWY`2f][H0YjNW07=cL`1DN5@0UiMO001O0019BDT0
QHF50080GiNG00<0YjNW05nGU`25QHD00P1cLg<00`2f][H0YjNW0:NW_P020;Jf]P0509O5a@2f][H0
][Jf09NGU`1YJFT00P1OUel02@00B@00UemO05mOG`1OG`00UiMO0:NWY`2f][H0GiNG002GG`0204U9
B@@005mO00d0GenG05nGa@2WYjL0GiO508>f]P2GUiL0][Jf0:NWY`2f][H0UlFG09NGU`2OWil0GlFG
0080GiNG00D0QHF505nGU`1OUiL0Pinf09NGU`030:NWY`0305nGU`1OaIL0Njj^0080UiNG0P2WYjL2
09NGU``0GiNG0P1OaIL00`1kUjh0UlFG05nGU`0305nGU`80YjNW00T0GiO50:NWY`1OaLD0UiO505nG
U`1OUlD0GiN^05nGU`1OGiL00P00UiL01019BDT0;2`/000/000/;2`2000/000702`/;000;00002`0
0000000U01H0;2`/000/000302`/;0040000;00/;2`0;2`/02`/;080000/00<002`002`/;00F5R`0
0P0/;2`01@00;000;2`/000/001900005QH0008002`0100000000`0U000002`002`/;00202`/;007
000/000/;2`0;1HF02`/;000;000;2`/000/000202`/;00300005P0/;2`0;2`/00<0;2`/00D002`0
000F5P0/;2`000000000;00;02`/;00301Hk5P00Gel0;2`/00`0;2`/00<002`004U9B@0/;2`02?oo
ool000Kooooo01D0Ng]k05mON`1ONg/0Ogn=05mkN`1kTZh0Ujj^0<G5a@2n_[h0[ZjB09NSN`3JaG/0
Ng/`05A`E00`Gel005h002ED9@0mE5@05TI602E99@1DE2D00P0k>c/01@0UE2D0KHU805AD9@1<Nc00
BDU90080Gg]O01P0WinO0:2^X02W_[h0RjN;0;Jf]P1DE2D0Gg]k08j>SP1`L5@0J8^I09:^[P2;YjL0
SHf=07^GU`25W9`0JFUY08>3M@2;Rh/0<5l`0=[JfP3Cdm/0fm_K0<G5fP36a/H20;Jf]P0Y031kN`2O
Wil0SXj>05mkG`1bLU/0WinO0;JfW`2>SW80Ng]k08F5J@13SXh0R8RF08j>SP2U^[X0SXj>0:j^[P2f
][H0YjNW0;Zj^P2O][H0[jn_09N^[P2WYjL0Ng]k069RAP1DHU@09DTU07]k001OGel0Gg/005mOG`1k
Gc00O6i^09JFUP23WkH0GjjG07:>LP1OGel0<5mO05mOG`0`Ng/00`0`UiL01@23]Yl0YjNW08>f]P29
[[X0YjNW0080WkJf0P2WYjL02`23]Yl0PkJf08>OW`1kUiL0PinO08>f]P23Wil0WinO076W/P2O][H0
PinO0080Ujj^0P2OWil02P2EXjl0WinO09N^a@2G[YL0UiNG05n^U`1YQHD0NiNG05nGU`1bSXh205nG
U`0;032GU`1O[YL0LI^K07^GU`23Wil0GiNG05n^U`1OUiL0PinO096[Z`2OWil00P1OUiL01P0`Ujh0
Gjk508>fW`2AZkH0PinO08>O]P80GiN^00d0NiN^09NGU`25WYh0GiNG05mkU`1OUiL0<9NG031OG`0k
>c/05QH/024/8@0/5QH05QH/0080;2`/00H0000/01HF5P0/;2`05QH/000/000/5QH202`/;00;01HF
5P0S>b<0;2`/01H/5P0F01H05QH/02`/;00/5QH0:AHQ02D05P0/;2`00P005P000`0k5QH05QH/00/;
2`0201H/5P0E01HF5P0F5P00000001H0000Q8AH05QH/01H/5P0U5P005QH/000F5P0F;1H05QH/01H/
5P0/5QH0;2`/01HF;00/;2`05R`F00/Q2`0F5R`0;2`/00805QH/00@001H001H/5P0/;2`05QH/0P0F
;1H01@0/;2`05QH/01H/5P0k>c/02bTF0080;2`/00D0>c/k01Hk5P16ATH0IfMW01i27P0602`/;00;
024/8@0/;2`05QH/01H/5P0/;2`0>c/k01H/5P0`<1h05S/F030`9@0/;2`02?ooool000Kooooo00H0
GemO001OG`1cLg<0YjNW07=cL`1OUiL30<G5a@0C09O5U`1kUel0UemO0<FGG`1OGel0GiMO04U9B@1O
Gel09E@U02`/;019BDT0GemO00190019000008D005ADE01OGel0YjNW001O000204U9B@0405nGG`2;
Rh/0aLG50<G5a@80BDU900L0GiNG05mOG`19BDT0WkJf0<G5k`2GaLD0UlFG0080YjNW00/0UiNG0<G5
a@2WYjL0QHF50<G5a@35aNl0][Jf0=CDe02fWkH0UlG50=CDe0020;Jf]P0=0=CDe02GUel0TW]k05mO
G`1OUel0YjNW09O5U`1OUiL0YjNW07=cL`2GUiL0QHF50:NWY`0209NGa@050:NWY`2f][H0UlG50;Jf
]P2GUiL00P1OGel0301OUel0LW9b04U9B@1OGel0GiL009NGG`2GGel0UiMO04>>SP00Gel0GemO001O
G`80BDU900`0GiMO001kG`1OUiL0GiNG05o5a@2WYjL0GlG50:NWY`2f][H0WkJf09O5a@2f][H30:NW
Y`080;Jf]P2_[jl0YjNW0:NWY`1OUiL0GlG509NGU`2GaLD30:NWY`<0UlG500T0YjNW09nf]P1OUiL0
UiNG05nGU`1OUlD0GiNG05nGa@1OUjh01P1OUiL01`1O[Zh0UiNG05nGU`1OaIL0GiNG09NGU`2WYjL0
0`1OUiL0302GUiL0GlG505nGa@1OUiL0UiNG05o5a@2WYjL0GiNG05o5a@1OUiL0GiO508>OW`<0GiNG
00H0GenG001OG`19BDT0;2`/02`F5P0002`202`/;0060000;00/0000000/01H/5P0/;2`002`00P0/
;2`0100002`0;2`/01HF5P00;00202`/;00500000019000002`001H05P00;0000`0/;2`02`0002`0
02`0000F5P0/;2`0000004T0000/;2`000000000;00/;2`0000/0080;2`/00@002`002`/;00002`0
;2`/0P00;0003P0/;2`0000/000/000/;2`05R`F02`0000002`00000000/0000000002`003/F5P00
;000;2`/0P00;0000`0/;2`005mO02`/;00502`/;00404U9B@0/;2`0;2`/04U9B@D0;2`/00<05R`F
02`/;00/;2`01`0/;2`00`0002coooooooooo`06ooooo`001_ooool03P2GUlD0GiNG09NGa@2^aLD0
UlG508F5Q@2GaLD0e=CD0;Jf]P2GaLD0Ng/`09NG002GUel0UemO1019BDT03@0/;2`005l004U9B@0/
;2`0Gel005nG001DE5@0GemO05nGG`1OUiL0;2`/05mOG`1OUiL00P2f][H04P1OGel0GenG09NGa@2f
][H0UiNG05nGG`2G[Zh0aLG50:NWY`1OGel0GiNG0;Jf]P3De=@0YjNW0<G5a@2GUlD0][Jf09O5a@80
aLG501P0Gjk50=CDe03De=@0klG50<G5a@3oklD0YjNW08^;F`1OGiL0Lg=c05nGU`25QHD0UlG50;Jf
]P2>SXh0Lg=c05nGa@35aLD0UiO50;Jf]P2GaLD0[Zk50:NWY`1OUiL20:NWY`0407=cL`1OUel0UiMk
0:NWY`80GemO00L0UiMO0<FGG`2WYjL0NjjG05mOG`00Gel0GemO008005mO00@0GemO032GN`00GiL0
GiNG0P2WYjL03`2GUiL0YjNW0:NWY`2WYjL0UlG50;Jf]P2GUlD0UlG50;Jf]P2GUlD0PkJf0:NWY`1O
aLD0GiO50:NWY`0209O5a@0508>f]P2WYjL0YjNW0:NWY`2GaLD00P2WYjL01@1bSZD0GiNG09NGU`1O
UiL0UlFG0080GiNG00L0Gjk505nGU`2GUiL0UiNG05nGU`2WYjL0UlG500@0GiNG00L0UiNG0:NWY`1O
UiL0GiNG09NGU`1OUiL0GlG500@0YjNW00d0UlG509NGU`1OaLD0GiNG05nGa@2GUiL0PinO09NGU`1O
UiL0QHF505nGU`1cLg<0BDU900@0;2`/0P00;000600/;2`0;00003/F5P00;000;0000000;0190000
;2`/0000;00/0000;2`/000/000/;2`0B@000000;00/;2`05QH/04T0000002`0;00000000000;000
;00001H/5P80;2`/00D0000/000/000/0000000003/00003000/0080;2`/00@0000/000/000002`0
;2`/0P00;00202`/;00300000019000002`000<000000`00;000100/0000000/0000000002`2000/
00<0;2`/00D0BDU90019000/;2`0;2`/01HF>`0=02`/;00403/k>`0/;2`002`002`/;0Sooooo0006
ooooo`0409NGU`1OGiL0aLG509nf]P<0aLG500`0e=CD0<G5a@1OUiL0GiMk09MOG`1OUel0GemO04U9
B@00L`00;2`/03/k>`00;00302`/;00I0019000/;2`05S/F05mO001cLg<0Gel007=cL`1OUel0][Jf
079bLP25QHD0Lg=c0<G5a@2GaNl0GiMO0;Jf]P1cLg<0_[jn05nGa@1cLg<0GiMO07=cL`1OUlD0YjNW
05n^[P030;Jf]P060:NWY`2f][H0aLG_0=CDe035aNl0aLG50P3QhN403P35klD0][Jf0820P01OUel0
Lg=c05nGU`2f][H0UlG50;Jf]P35aLD0UlG505nGa@2GaLD0UiNG0P35aLD0302OWil0QHF505nGU`25
QHD0YjNW09NGU`2GUel0Gg]O09NGU`2GaLD0UiMO09NGU`80aLG500D0Ykjn05nGU`1OUiL0GiNG001O
G`0205nGU`0305mON`00GiL009NG0080UlG500/0GlG50:NWY`2GaLD0Ujk50;Jf]P2WYjL0UlG50;Jf
]P2WYjL0UlG508>f]P060:NWY`0308>f]P1OaLD0UlG50080UlG50P2WYjL01@1OUiL0GiO50:NWY`1O
UlD0YjNW00<0GiNG00T0UiNG05nGU`1OUiL0GlFG05nGa@2GUiL0Njj^05nGa@2f][H00P2WYjL0101O
UiL0QHF505nGa@1OUlD205nGU`0;09NGU`2f][H0YjNW09nOW`2GUiL0GlG505nGU`1OUlD0YjNW05o5
a@2WYjL00`1OUiL00`00GiL0GenG04U9B@0202`/;00304T0000/;2`0B@000080000/00X0;2`/01HF
;000;000000/02`/;000;000;0000000;00F;1H002`00`0/;2`00`190000000/01HF;002000/0080
000/00L0;2`/000/0000;000;2`/0000000002`002`00080;2`/00<05R`F02`/;00/;2`00P0/;2`0
2`00;000;2`/000/000/;2`0000/000/000/;2`002`004U9B@0k5QH0;000008002`00`0/;2`0100F
;1H0;2`/000/000/0002000/0080;2`/00D05R`F02`/;00/0000;2`/0000B@0202`/;00603/k>`0/
;2`005mO000/000/;2`0BDU9200/;2`0100k>c/0BDU904U9B@19BDT8ooooo`001_ooool02`1OGel0
05mO05nGa@2B[]X0UlG_0<G5k`35aLD0][Jf09O5a@1OUiL0GiMk0080GiMO00<0aLFG05nGG`1OGel0
0P19BDT0100/;2`0Gel0001O0000L`0202`/;00G01H/5P00G`00Gel0001OG`19BDT0aLG505mOG`0/
;2`0UiNG0:NWY`3QhN40][Jf05nGU`1cLg<0GiNG0;Jf]P2GUlD0GiNG08F5Q@1cLg<0aLG_09O5a@2W
_[h00P35aLD01`2GaLD0UiNG05mOU`35aLD0cN;=0<G5a@3De=@00`3QhN401@3De=@0][Jf0:NWY`1O
UiL0YjNW0080][Jf0180aLG50;jn_P35knl0YjNW09NGa@2GaLD0UenG05nGU`2WYjL0UiNG09NGa@2f
][H0YjNW0;Jf]P2WYjL0SHf=05nGU`25QHD209NGU`030;Jf]P35aLD0aLG50080UiNG0`1OUiL0101c
Lg<0JHF505nGU`1OUiL20:NWY`0;05nGU`2WYjL0UiO50;jn_P35aLD0][Jf09NGa@2GaLD0UiO509O5
a@2G[/D00P2GaLD0302f][H0YjNW09O5a@2GaLD0Pinf0:NWY`2f][H0YjNW0;Jf]P2GaLD0GiO505BO
W`@0YjNW0P1OUiL02@1OUjh0GiO505nGU`1OUiL0YjNW05nGa@2GaLD0NiO505nGU`020:NWY`0305nG
a@1OUiL0GiNG0080GiNG01<0YjNW08F5Q@2WYjL0GiO509O5a@2O]Yl0YjNW05nGa@1OUiL0YjNW09NG
U`1OUlD0NiN^09MOU`1OUlD0GenG05nGU`1OUel005mO0080;2`/00L0;00002`/;000;00002`00000
;0190000;2`/008000000P0/;2`01000;000000/01H05P19000202`/;004000/000/;2`002`001HF
;0<0;2`/00`0B@000000;00/;2`05QH/0000;00/0000000/04T00000;000000/01HF;000;00202`/
;0070000;00/;2`0;2`/01HF;0000000;2`/0000;00202`/;00=0000;00F5P00000/0000;00/0000
;2`/0000;0190000;2`/0000000002`0;2`/02`0000202`/;0030000000F;1H0;2`/00D0;2`/00<0
05@`02`/;019BDT02P0/;2`00`00;000>c/k04U9B@0204U9B@Sooooo0006ooooo`0;05mOG`00GiL0
][Jf09:^``35aLD0e=CD0;Jf]P35aNl0UlG505nGa@2;YjL00P1OUel03P2WYjL0GiMO05nGG`00Gel0
BDU905mOG`19BDT0GemO001O001OGel0;2`/04U9B@1OG`00BDU90P1OUiL01`2GG`00BDU907^BN`1O
UiL0aLG50=CDe01OUlD00P00Gel0301OGiL0RjN;0;Jf]P2f][H0UlG50<G5a@2f][H0aLG50;jn_P2f
][H0e=CD0:NWY`<0aLG_00<0_[kC0>o_k`3_aNl00P3De=@03@35aLD0e=CD0;Jf]P3De=@0aLG50>o5
a@35aLD0][Jf0<G5a@35aNl0e=CD0<G5a@35aNl00P2GaLD00`2GUlD0Gjj^0<G5a@020;Jf]P<0aLG5
0140_[jn05nGU`2WYjL0YjNW05nGU`1OUlD0UiO509N^a@1OUlD0GlG509O5a@2WYjL0GiNG05nGa@23
Wil0YjNW05o5a@020:NWY`0409NGU`2GaLD0][Jf0<G5k`80UlG5102f][H209O5a@80][Jf00@0UlG5
0;Jf]P2GaLD0WkJf0P2GUlD209O5a@80][Jf00@0GiN^002GU`1OUlD0UiNG0P1OUiL01@1OUlD0NiNG
0:NWY`1OUiL0GlG50080GiNG00X0UiNG07^Ga@2WYjL0GiO505nGU`1OaLD0GiO505nGU`1OUjh0GiO5
0P2GUiL03P2WYjL0GlG509NGa@1kUiL0YjNW05o5a@2WYjL0GiO50:NWY`1OaLD0PinO05nGa@1OUiL0
GiO50P1OUiL00`00Gel0;2`/02`/;00302`/;0040000;00/;2`0;2`/02`/;080;0000P0/;2`00`00
0000;2`/01HF;00302`/;0040000000002`0;2`/01H/5PD0;2`/00H0000001I65P0/;2`000000000
;000;00202`/;00700000000;00002`0000/000/;2`0000/04T0000202`/;0030000;0190000;2`/
0080;2`/00<000000000;00/00000`0002`02`00;0005R`F000/000002`0B@000000;000;000000/
02`/;0005QH002`000L0;2`/00D005mO04U9B@19BDT0000/0019000202`/;0060019000/;2`0;2`/
02`/;019BDT0>c/k0P19BDT00`0/;2coooooooooo`06ooooo`001_ooool01019BDT0UlFG05nGU`2B
`mX20<G5k`050:NWY`2GaLD0QHF505mOU`1kUiL00P2GUel01@2GUiL0aIMO05mOG`19BDT0E5@U0080
BDU901l0GiL005mO0019BDT0Gel004U9B@1OG`00BDU905mOG`35aLD005mO05mOG`1hN7P0GiNG0<G5
k`2f][H0QHF507=cL`1OUiL0e=CD02EDE02WYjL0UiO509O5a@35aLD0UlG50;Jf]P23Wil0GiNG07=c
L`35aLD0][Jf0080aLG500D0UlG50<G5k`2GaNl0e=CD0<G_k`020=CDe0030<G5fP3De=@0klG50080
aLG500D0][Jf0<G5a@35aLD0e=CD0;Jf]P0209O5a@0509O5k`35aLD0Winf09O5a@35aLD00P2f][H2
0<G5a@050;Jf]P35aLD0YjNW09NGU`1OUlD00P1OUiL0202G[/D0][Jf0;Jf]P35aLD0UlG50:NWY`2G
UiL0Njj^0P2GaLD00`2GUlD0GiNG05nGa@030;Jf]P040:NWY`2f][H0][Jf0<G5a@80][Jf00@0Ujk5
09O5k`2GaLD0aIO50`2f][H01P2W_[h0YjNW0<FGa@2GaLD0][Jf0:NWY`@0GiNG00H0GiO505mOU`00
UiL0YjNW05nGa@1OaLD305nGa@0605nGU`2GaIL0PinO0:NWY`1OUiL0YjNW0`1OUiL04P23WkH0YjNW
0:NWY`2WYjL0UlG50;Jf]P1OaLD0Njk505o5a@1OUlD0UiNG05o5U`2GUiL0GiO5032G[P1OGiL0GiO5
05mOU`80GiNG00D0GemO02`/;00/;2`0;2`/0000;00202`/;00D0000;00000005QH/00000000;000
;2`/0000;000;000000/01HF;0190000000/02`/;000000002`002`/;000;000;2`/0000;0190002
02`/;00:001OG`0U>bD0000000000000;000000/02`/;000;0005P0002`000@0000/00@0;2`/03/F
5P0/;2`0000/0P0/;2`0200002`0;2`/01HF5P00000002`002`/;0000000;0000P0002`0200/;2`0
B@00000/00190000;000000/000/;2`05R`F0P0/;2`02@00Gel0;2`/02`/;00004T05QH/0019000/
;2`004T004U9B@0702`/;00604U9B@0/;2`0BDU907=cL`0/;2`0BDU92?ooool000Kooooo03d007]O
05^;R`1DPil0X<GJ0:k5a@2W_[h0YjNW08>f]P1ONg/0Ni:^09FSN`2BNel0JHEY05nGN`35aIL0UiMO
05mkG`12J1<09DTU05mO000U9E@0BDU9031k0016AQH0@T92031OG`1ONg/0[ZjB02EDE01IFET0QHF5
03e/E02>SZD0UIFE0<GJfP2>SXh0_[jn0=[5fP23Wil0P82002E`L01kGel0Ph>307^GG`23Ph<0WinO
096[Z`2>SXh0GemO05nGN`2;Ykh0aLG50:k5a@2b//P0aLG50:j^a@2n_[h0Ykjn0<g=c@3Rh^80_/WD
0080aLG500`0_[jn0<G5a@2fcLd0][Jf0;:n_P1k[/D0`lGJ0:Nn_P2B[]X0][Jf0:n_[`2MZj/20;jn
_P0<08>O]P2G[Zh0aLG50<g=c@2ja]00[Zk50;Jf]P2OWil0Pinf07^^a@35[/D0^/G50P35aLD03P2n
_[h0Njk50:NWY`2O][H0Xj>S08>fW`2OWil0NiNG07^^a@2_[jl0Ykjn0;jn_P32]/`0_[jn0P2^aLD0
302n_[h0[/G509O5a@2W_[h0][Jf0:Nn_P2f][H0Ykjn09O5a@2W_[h0Wl;209nO]P<0UlG500@0UiNG
08>OW`1OUjh0Gjj^0P1kUiL205nGU`0907_5a@2K/[80Ujj^08>OW`23WkH0<9NG05n^a@1kUiL0Pin[
0080PinO00T0GiN^07:>SP1OUiL0GiNG05nGX`1O[/D0WinO08>O]P1k[Zh00P2WYjL00`2OZj/0WinO
0:NWY`0208>O]P80GiN^00<0KINS05nG[P1OUlD00P1OUiL01P1YJHD0Lg=c03/k>`0/;2`0>aHF01H/
5P80;2`/0140;1HF02`/;00;8@00;1HF0000;00F5QH0;2`/01HF;00U5P00=24Q01HF;00F5P005P0F
03/F5P0F;1H05QH/024/8@0201H05P09000/000/5QH05QH001H/5P0`>b<05P0F02`F5P0F000001HF
00<05R`F00L001HF0000;00000005QHF01H/5P0F5R`05R`F00805QHF01<05P0F01HF0000;0009AH0
00/Q2`0/5QH0;2`/01H/5P00;0005P00000F000;2`005P000000;00F5QH002`001HF5P005QH05QH0
00@0;2`/0P0F;1H01@0/;2`08C@Q01HF>`0/;2`09DTU00H0;2`/00D05R`F01Hk5P0k>c/0;2`/03M9
=`0202`/;00303/k>ooooooooooo00Kooooo0006ooooo`0605nGU`00Gel009NG09NG[P2WYjL0UiO5
0P2GaLD02P1OaIL0GemO09N^G`1OU`00GiMO05mOG`2GUiL0aLFG05nGG`0k>c/205mOG`0@04U9B@00
Gel0GiMO05mO001DE5@0GemO0;Jf]P1OG`0005l00000G`1cLg<0<5mO0<G5a@2GaLD0][Jf0:NWY`80
GiNG00@0][Jf04aO<01OGiL0][Jf0`19BDT02P2GUlD0<5mO0:NWY`2GUlD0GiNG0:NWY`35aNl0aLG5
0>SCd`3_knl30=CDe0060>7Qh@35aLD0]/g=0<G5a@2GaLD0][Jf0P35aLD0102GaLD0cLg=0;Jf]P3Q
hN420<G5a@050>o_k`3_klD0][Jf0<G5a@3QhN400P35aLD02P2f][H0UlG50<G5a@2GaLD0GiO505nG
U`2GUiL0GlG509O5a@35aLD30:NWY`0609O5a@1OUiL0GiNG08>OW`1OUiL0YjNW0P2GaLD01035aLD0
][Jf09O5a@2W_[h20<G5a@050=CDe02GaLD0][Jf09O5a@2W_[h01P2f][H02@2_[jl0UlG509O5a@2W
YjL0GiNG09NGa@1OUiL0<:k509NGa@0305nGU`@0YjNW00H0GiO505o5a@1OUiL0GiNG05nGa@1OUjh2
05nGa@0505nGU`1OUlD0GiNG05o5a@2OWil00P1OUlD03@2WYjL0UiNG09O5a@2GaLD0WinO0:NWY`1O
aLD0GiO509NGU`1OUiL0YjNW09nOW`1OUlD01@1OUiL03019BDT0;2`/02`/;00002`002`002`/;000
02`0;2`/01HF;00/0000;2`/0000;080;2`/00D0;00001H/5P0002`0;0000000;00202`/;009000/
000/;2`000000000;0000000000/02`/;00002`0;2`/0080000/0P0000000`0002`0;2`/02`/;002
000000<0;2`/00<002`002`F5P0/;2`00P0/;2`0100002`0;2`/02`/;000;0020000;00802`/;000
02`002`00000;00F;1H0000/00000000;0020000;00302`/;00002`0;2`/00@0;2`/00<0000/02`/
;00/;2`01P0/;2`00`1RHTH0;2`/02`/;00302`/;00304U9B@0/;2`0;2`/0080;2`/2?ooool000Ko
oooo00`009MO05nGU`1OUlD0c<c<05nGU`1OaLD0UlG50:NWY`2GUiL0YjNW0:jGG`1OG`0205nGG`04
05mOG`2GUel0UiMO05ADE080BDU900T005l0001OG`19BDT0Gel002EN9@2f][H0BDU9001O0019BDT0
0P1OGel03@1hN7P0][Jf0;Jf]P2WYjL0UiNG04U9B@2WYjL0aLG_09jNWP1OUiL0aLG507=cL`1OGel0
0P19BDT02016ATH0GemO05mOG`2GaLD0ono50<G5a@35klD0h/g=1@3De=@00`3_aNl0cLgR0>7Qh@03
0<G5a@040;Jf]P2WYjL0UYJF05o5a@80YjNW00H0UlG50>7Qh@2GaLD0][Jf05o5a@35aLD20>7Qh@<0
aLG50`2WYjL03@2GaLD0UiO50;Jf]P2GaLD0GiNG0:NWY`2GUlD0YjNW09NGU`2WYjL0NiNG05nGa@2G
aLD00`35aLD209O5a@090;jW_P2GaLD0aLG50<G5a@2f][H0aLG509O5a@2W_[h0][Jf0080UlG500@0
UiO50;Jf]P2GaLD0Ykjn0P2GaLD01P1OUlD0GlFG002GU`00UiL0Gjj^09NGa@@0GiNG00@0GiO507^G
[P1OUiL0UlG50P1OUiL01@2WYjL0GiNG05nGU`1OUiL009NG00<0GiNG00D0UiNG05nG[P1OUiL0YjNW
09NGU`050:NWY`0905nGa@2WYjL0YjNW05nGa@2GUiL0WinO05nGU`1OGiL0GiNG0080GenG00<009NG
04U9B@0/;2`00`0/;2`01000;000;2`/02`0000F5R`502`/;0030000;00F01H0;2`/00<0;2`/00@0
02`002`0000001H0000/0P000000200/;2`0000/000/000F5R`0B@0002`00000;00000000P0/;2`0
100F5R`0;0000000000002`302`/;003000/000002`0;2`/0080000/00<0;2`/04T0000/5QH01000
02`202`/;00901H/5P0002`0000/0000;0000000;000000/000/;2`05QHF00H0;2`/00<05R`F02`/
;00/;2`00P0/;2`00`00;000B@0002`/;00202`/;003000/0019BDT0BDU900@0;2`/00<0BDU9oooo
ooooool01_ooool000Kooooo0P1OUiL02@3De=@0V[Jf05nGG`1OUiL0aLG_0;Jf]P1OUlD0UlFG07^G
N`0205nG000?05nGG`35aIL0UemO05nGG`1DE2D0BDU902`/;01OG`00BDU905mOG`00G`00TW^B05mO
G`00Gel0BDU90080;2`/00<0UiNG07QhN02WYjL00P2WYjL01@1OGel0BDU90<G5a@3QhN40Ykjn0080
][Jf0P2WYjL04P1cLg<0GenG08>3P`1OUiL0][Jf0=CDe02GaLD0][Jf0<G_k`3_kmX0aLG_0>7Qh@3D
e=@0hN7Q0>o5a@35aNl0aLG50=CDe080UlG500L0e=CD0;Jf]P2GaLD0NiNG05mOU`2GaLD0e=CD0080
aLG501@0][Jf0:Nn_P2f][H0][Jf0:NWY`3De=@0aLG50>7Qh@3De=@0aLG509NGa@2GaLD0][Jf09O5
k`2f][H0[jn_05nGa@2GaLD0][Jf0:NWY`80UiNG00H0WinO0;Jf]P35aLD0e=CD0;Jf]P35aLD20;Jf
]P030:Nnd`35aLD0UlG50080aLG_0P2GaLD01`2^aLD0][Jf0:NWY`2WYjL0UlG50:NWY`2f][H00P2W
YjL0202GUlD0UiNG07=cL`00GiL009NG08>O]P1OUiL0GiO50P1OUiL01`1cLg<0YjNW09nf]P1OUiL0
YjNW05nGU`00UiL00P1OUiL00`1O[Zh0GiNG05nGU`0205nGU`0405nGa@1OUiL0Pinf09O5a@<0YjNW
0P2GaLD0201kUiL0UiNG05nGa@2WYjL0GiO505nGU`2GUiL0Njk50P1OUiL01@1OGiL0GiNG05nGU`00
UiL005mO00<0;2`/00D002`002`/;000;000;2`/01HF;00502`/;0030000000F0000;2`/0080;2`/
00D0000/04T00000;0009@0F02`/;00200000080;2`/00T002`001H05P0002`002`00000;00/;2`0
02`00000000F5R`00P000000100002`00000000/0000;00300000080;2`/0P00;0000`0F5P00;2`/
0000;00202`/;0080000;00000009@0F02`/;00/0000000/02`0000002`20000000501HF5P0/;2`0
02`002`/;0000000200/;2`00`00;000;2`/02`/;00302`/;00304U9B@00;000;2`/00<0;2`/2?oo
ool000Kooooo01<0GenG05nGU`2GaLD0GiN^001OG`00UiL0aLG50;Jf]P00UiL0QHF506YZJP1OG`00
GiMO04U9B@2GUiL0YjNW09NGG`0`E000BDU9008005l000@0GiMO09NGG`1cLg<0GemO0P1OG`002P0/
;2`004T004U9B@19BDT0>c/k0;Jf]P2WYjL0GemO05mO0000Gel209O5a@0<0:NWY`35aLD0aNo50<G5
a@2GaLD0UiO50<G_a@2;YjL0ooo_0<G5a@3De=@0aLG50P2WYjL00`33aLD0aNo_0>7Qh@020>7Qh@0=
0>o_k`35aNl0[/GJ0=CDe02WYjL0UlG50:NWY`35aLD0QHF50:j^[P2GaLD0aLG50:NWY`030<G5a@0=
0;jn_P2f][H0UlG509O5a@2f][H0aLG50=CDe03Kfm/0aLG_0<G5a@35knl0aLG50<G5k`0209O5a@80
][Jf00d0aIO50:NWY`2GaLD0][Jf0:Nn_P2GUlD0e=CD0<G5a@3De=@0aLG50;Jf]P35aLD0][Jf00D0
aLG500@0UiO50:Nn_P2f][H0YjNW0P2GaLD01P2WYjL0UlG509nfW`1OaIL0YjNW05mOU`L0GiNG00H0
GenG05nGU`2WYjL0Ujk505nGU`2WYjL2002GU`0705o5U`00UlD0PinO08F5Q@00UiL0GiNG002GU`02
05nGU`0907^^[P1OUlD0GiO505nGU`2GaLD0YjNW05o5a@23][H0GlG50080GiO500D0GlG505nGa@2G
UlD0NiN^05nGa@0305nGU`0505mOU`1OUel005mO01Hk5P00;0000`0/;2`00`0002`0;2`/02`/;002
02`/;0080000;0000000000002`00000;000;2`/000/00000002000/000302`/;00F5R`002`00080
;00000@002`00000000/;2`05R`F0P0/;2`02`0002`002`0000/000/;2`0;1HF0000;00/0000000/
000/000/;2`002`00080;2`/0P00;00202`/;0040000;000;000;2`/0000;080;2`/0`0002`00`0/
;2`002`00000000202`/;0050000000/;2`001HF000/000/00000P0/;2`00`00;000;2`/000F5P06
02`/;00501H/5P0/0000;2`/02`/;000;0000P0/;2`0100F;1H0;2`/02`/;00/;2`8ooooo`001_oo
ool02`1OUiL0GiO505nGU`0`Ui8005mO05o5a@1OUiL0UlG5002GU`00Gel0[Zik00<0Gel001/0UemO
0<G5U`35Uel0Gel0001O001OG`0002`0001OG`1OUel0BDU907]OG`1OU`00Gel002`/;019BDT005l0
04U9B@1DL5@0QHF50;Jf]P1OGel005mO04U9B@1OUel0GemO07^GN`2GaLD00P35aLD0302GaLD0][Jf
09O5a@2^aLD0][Jf0>o_a@3QhN40][Jf09NGU`1OUlD0YjNW0>7Qh@80aLG500<0kno_0<G5a@35knl0
0P2f][H03P2GUiL0YjNW05mOG`1cLg<0UiMO08>OW`1OUiL0UiNG09O5a@2f][H0aLG50;Jf]P2n_[h0
aLG50`2f][H04P2GaLD0aLG50=[5a@35UlD0UlG509NGa@2GaLD0UlG_0;Jf]P2O][H0][Jf09O5a@1O
aIL0GiO50:NWY`1OUlD0[jn_0:NWY`@0aLG500<0][Jf0<G5a@35aLD00P2f][H209O5a@0;0<G5a@2f
][H0Ykjn0;Jf]P2GaLD0GiO50:NWY`1OUiL0YjNW09nOW`1OUlD00P1OUiL02`00UiL0GiO505nGU`0`
UiL0YjNW05nGU`1OGiL0GiNG09NGU`1OaLD0UlG500@0GiNG00<0YjNW09NGU`1kUjh00P1OUiL00`1O
UlD0GiNG05nGU`060:NWY`0409O5a@2WYjL0Gjj^09NGU`<0YjNW00<0GiO505nGU`1OUiL01@1OUiL0
0`1OGiL005mO01H/5P020000;007000/0019000002`002`/;00F5R`0;2`/0000000202`0000:0000
0000;000;2`/02`/;000;000;00002`/;000;000;2`/00005P80000/00<002`004T0000/;2`00`0/
;2`2000/000702`/;00002`0000/01HF;00/0000000/04T0000202`/;08002`000X0;2`/000/000/
;2`0000/02`0000/;2`05P0F000/000/;2`0000/0P000000100/;2`05QHF000/0000;00602`/;003
000/000/;2`0000/00@0;2`/00<002`002`/;00000000P0/;2`01@00;000000/02`/;00/;2`004T0
00H0;2`/00<00019ooooooooool01_ooool000Kooooo00l0YjNW05nGa@2GaLD0C:j^002GU`1OaLD0
05mO002GG`00Gel005l008>OW`1OG`00;2`/05nGG`2GGel00P35aIL02`1OG`00GemO001O000/;2`0
05l005nGG`1OGel0E5AD05nGG`1OU`00GiMO00<0BDU90240AV9605mOG`2GUiL0GemO08F5Q@2f][H0
BDU905mOG`1NGUh0YjNW0;Jf]P3_aLD0][Jf0<G5a@2GaLD0cLg=0<G5a@3_aLD0][Jf05nGU`1cLg<0
][Jf0:N^a@35aLD0YjNW09NGa@2f][H0aLG509NGU`1ONiL0QHF507=cL`1OGel00P00Gel0301OGel0
JHEY09NGU`2WYjL0e=CD0;Jf]P2WYjL0GiNG09nOW`3De=@0aLG50;Jf]P<0e=CD00@0_]?C09O5a@2W
YjL0][Jf0`2GaLD02P2GUlD0YjNW0:NWY`1OUiL0GiO508F5Q@1OaIL0YjNW0;Jf]P35aLD20=CDe004
0<G5k`35aLD0aLG50;jn_P<0aLG500l0][Jf0<G5a@2GaLD0_[jn0;Jf]P2GaLD0GiNG0:NWY`1OUiL0
GlFG08>OW`1OUiL009NG05nGU`00UiL00P1OUiL02P0`UiL0GiO505nGU`1OUiL009NG05nGU`1OUlD0
YjNW002GU`2WYjL205nGU`0309NGU`2WYjL0GiNG00D0GiNG00D0QHF509nOW`2WYjL0GiO509O5U`03
0:NWY`0407^G[P2GaLD0GiO505nGa@<0YjNW101OUiL205mOU`0305nGU`1OGel0;2`/00H0;2`/00@0
5QHF02`/;00/0000;2`/0P00;000100/00005R`F02`/;00/;2`2000/0080;2`/00`05P0F02`/;000
02`0000/02`/;000;000;2`/00005P00;000;2`/02`00000;00202`/;00800005P0/0000;2`/02`/
;00002`002`00000000F;1H2000/000502`/;00/0000;2`/02`/;00F;1H00P00;0001@0/000002`0
000/000/;2`05QHF0080000000T0000/02`/;00002`0;00007<0000U9C/0;2`/00000000;0000`0/
;2`00`0F5R`0;2`/000/000202`/;0040000;00/;2`0;2`/0000;0D0;2`/00@0>aHF02`/;00/;2`0
][Jf2?ooool000Kooooo00`0dnSX0:O3fP2^aLD0KJ?4032G[P0`Ng/0Gg]k03YYJ@1YJFT0BDU906B<
SP2^Uel207]kG`0805ADE01OTUl0aLF^0:bPB01kTT`0Ng]O05nGG`1ON`0205ADE00E05IOB01kGel0
E5AD07]kG`1OGc009E@U05mk<00mE5@0QHF509NGN`1ONel0[Zik09NGU`2WYh/0WYjN07IfG`23Ph<0
[YNG08>OP`2W_[h0WkJf0080_[jn00/0dm?C0:FUSP2n_ZL0WinO08>3P`2O][H0Ohf=08F5Q@23Ph<0
WinO08>OW`020;jn_P0P0:^[Z`2BTV<0E71D05A`E02W_X/0<5l`0820P02VYZH0bkJf0<G5fP1kUg/0
Gg]O07^GU`2>SXh0NiNG09NGU`2^[Zh0YjNW05o5a@1DWil0_[jn0:^f]P2G[/D0GiN^05nGU`1DWil0
NiN^09N^U`23Wil0E9nO031kU`23Wil205nGU`0=05nG[P2AWil0[jn_0:NWY`2f][H0[/G508>OW`2_
[jl0[/G50:nj^P2W_[h0WkJf0<G5a@020;Jf]P0=0:Nn_P2S^[X0Ujk509nf]P2OWil0PinO07^^[P23
Wil0TInO05nGU`23WkH0Ng^G032GU`0205nGU`08032GU`00UiL0LXj>07^GU`1OUjh0NiNG09O5[P1o
Yi/205nGU`03032GU`1YQHD0GiNG00D0GiNG0P1O[Zh0402OWil0TJ^f05o5a@1k[/D0NiNG0:NWY`23
Wil0Gjk507^S[P1OUjh0NiO507^GU`23Wil0NiNG05n^a@1OXj<205nGU`0?05mkU`1OUiL0Gg^G032G
N`1ONiL0:D0Y01H/5P0/;2`05R`F02D05P0F;1H0>aHF02`/;000;0005R`F0080;2`/00@05R`F02DF
000F5R`002`00P0F5P0050005P005R`F01H/5P0;2aH0000/01HF5P0/5QH001H001HF001DJU@08AHQ
000F5P0F;1H0;1HF0000000/;2`001HF00/F5P0F5P009BDk0P0002`03P005QH001H001HQ8@0F5QH0
5QH/00005P0F01H0;2`/01H/5P0F8@/002`001H/5P00;000;2`/0P0F5QH0100C024000000000000F
000201HF;0060000;00/;2`02aHF01HF;00/;2`05P000P0/;2`02@0F01H05R4Q01HF;00F5R`05R`F
02`/;00F5R`05R`F01HQ8@0202`/;00803/k>`0/;2`0;2`/02`/;00;;0/0;2`/0000;01RC308oooo
o`001_ooool0103De=@0][Jf0<G5a@2=SHd2002GU`0805mOU`2f][H0YjNW05mOG`1OUg/0UiNG0<FG
G`2GUel205nGG`0A08F5Q@3JfZh0klG505nGG`1OGel0GiL002`/;000Gel09E@U04U9B@00L`00GiMO
05mOG`1OG`0005l003/k>`00B@000P2GUiL03`2GGel0UiNG0<G5a@25QHD0E5AD05nGU`2GUiL0QHF5
0<G5a@2GUiL0GiNG09:G[P2f][H0UiNG05mOG`0204U9B@0;02`/;01DPh<0Lg=c05nGG`2GUel0UlG5
0<G5a@2WYjL0NiMk08F5Q@2WYjL00P2GUel204U9B@05031OG`1OUiL0UlG508F5Q@00Gel00P2WYjL0
2P2FUYH0aLG509NGa@35aLD0UiNG002GG`1OUiL0<7]k05nGU`2GUiL2002GU`H0GiNG00@0UiNG05nG
U`1OUiL0<9NG0`1OUiL01`1OUlD0UiNG05nGa@2GUlD0UlG50;Jf]P2GaLD00P2f][H0102GaLD0][Jf
0:n_[`2GaIL605nGU`0409NGU`1OUlD0GiNG0:NWY`<0GiNG00<009NG05nGU`1OaIL00P2WYjL00`1c
Lg<0GjjG0:NWY`0205nGU`0508F5Q@1OUiL0GiNG05nGU`25QHD00P1OUiL0102GUiL0GlFG0:NWY`1k
[Zh209NGU`80YjNW00<0UiNG05nGa@23]Yl00`1OUlD01@2WYjL0UiNG05nGU`1OUjh0GiNG0080GenG
00D009NG05nGU`1OUiL0Lg=c03/k>`0202`/;003000/000/;2`0;2`/00L0;2`/00<002`0000F5P25
QHD00P0/00001`0/;2`0000/04T0000F5P0002`00000;00/00000P00;0000`2GUiL0>c/k02`/;002
0000;00402`00000;000;000000F5P80;2`/00L0000002`0000002`0;2`/000/00000000000/0080
00000`0002`2000/00800000018002`00000000002`0000004T00000;000;2`/000/00000000;2`/
000F5P190000;2`/000/000/;2`0000/02`/;00F;1H20000000502`/;000;000;2`/02`/;000;000
0P0/;2`01000;000;2`/02`/;01900020000;080;2`/2?ooool000Kooooo01<0klG50>o_a@3De=@0
Ykjn09O5a@35knl009NG0:NWY`1OUiL009NG07^GU`1OUiL0UiNG0<FGG`2GUel0GiMO05mOG`2^[YL0
e=CD00<0UiMO00H0GemO05mO0019BDT0BDU9001O002GUel205nGG`0505mOG`0`Gc00BDU9001c001O
G`000P0/;2`04P2GUiL0GemO08M`E01OGel0UiNG05mOG`19BDT0UiMO05mOG`1ONel0UiMO05mOG`19
BDT0Gel0001OG`2WYjL0W8F50<G5G`80GemO00T0BDU905nGU`00G`00E5AD09NGG`35aEl0UlEO09NG
G`1OGel00P2GUel0202GUiL0][Jf0:NWY`1OGel0Uel009MOG`1kUg/0aLG50P2f][H01P35aLD0GiO5
09NGU`0`Uel0][Jf0:NWY`80GiNG00H0Lg=c05nGU`0`UiL009NG05nGU`1cLg<205nGU`0309NGU`1O
UiL0QHF500<0GiNG00D0GlFG0;Jf]P35aLD0[jn_05nGa@030;Jf]P0609O5a@2GUlD0YjNW05nGa@1O
UiL0GenG0`1OUiL00`1kUiL0YjNW05nGU`0305nGU`0505o5a@1kUiL009NG05nGa@2GUiL00P2WYjL2
05nGU`0509NGU`00Uel0GiNG05nGU`1OaIL0101OUiL02@1OUlD0UlG509NGU`2GUiL0PinO05o5a@1O
UiL0UiNG0:NWY`0205nGU`0407^G[P2GUiL0GlG505nGa@80YjNW00<0GiO507^GU`1OUiL01@1OUiL0
1@1OGel09C0`000/000/;2`0000000<0;2`/00<05R`F02`/;000;000100/;2`0201<C680;2`/02`/
;000;000B@00000/000/;2`05QH00P0002`03000;000000004T0000/;2`05R`F000/00000000;000
04T00000;000;2`/01H/5P80;2`/00D002`00000000002`0;2`/0000000202`000<0000000<002`0
000F5P00;0000P00;0001`0/;2`00000000000005QH0;2`/0000;00/00000P0/;2`01`00000002`0
01HF000002`00000000/001900000P0/;2`010005P00;2`/0000;000;00302`/;00301H/5P0/;2`0
;2`/0080;2`/00H002`002`/;00F;1H0;00002`/;00002`8ooooo`001_ooool01P3_klD0hN7Q0>o5
a@35aLD0UlG50:NWY`80GiNG00l009NG05nGU`0`Gel009MO05nGU`25QHD0UiMO0;Jf]P1OG`00WkJO
0;Jf]P2GUiL0aLFG07=cL`2WYjL00P1OGel204U9B@0505nGG`2GUel0GiMO09NG001DE5@00P19BDT0
5`1OG`00;2`/02`/;01OUel0;2`/07]O<02GUel0;2`/05mO001cLg<0GiMO05mO001NGUh0UiMO07=c
L`1OGel0B@0005nGG`1OGel0YjN;0<FGU`1OG`00BDU90080Gel000<0BDU90:jGG`2GUel00P2GUel2
05nGG`0=05mOG`1kNg/0UiMO0:NWY`1cLg<0UiMO05mOG`1OUiL0QHEY05nGa@2GaLD0YjNW0<G5a@02
0;Jf]P040:NWY`35aLD0YjNW002GU`80GiNG00<0GiMO002GU`1OUiL00P00UiL01@1OUiL0GlG509NG
U`2O][H0YjNW00<0GiNG00/0GiO50<G5a@35aLD0[jn_05nGU`2f][H0UiO509O5a@2WYjL0UlG507^^
[P0205nGU`80GiMO00d009MO08F5Q@1OUiL0UiNG05nGU`1OUlD0GiNG09NGU`1OUiL0PinO05nGU`2G
UiL0GiNG0080YjNW00D0GiNG07^GU`1OUiL0GiNG05nGG`0705nGU`080:NWY`1OUiL0GiNG09nOW`2W
YjL0GlG505nGU`1OUlD305nGU`030:NWY`1OUlD0GlFG0080YjNW00L0GiO507^GU`1OUiL0GiNG05mO
U`1OUiL0GenG0080Lg=c00@0>c/k02`/;00/;2`0;0000P0/;2`01P00;0005QHF04T00000;0000000
04T00080;00000X0000/02`/;00002`0B@000000;00/0000000001H0000/;2`002`00P0000001@00
;000000/00005P00000002`000<0000000<0;2`/0000000002`00`0000001P0002`0;2`/01HF0000
;0000000000/0080000000T0000/02`F5P00;000000002`/;00002`0000004T00000;0000P000000
1P0/0000000/0000000/;2`002`001H/5P80000000<0;2`/000/000/;2`00`0/;2`01P00;000;000
00000000;000;2`/01HF;0<0;2`/0P00;00502`/;0Sooooo0006ooooo`0<0<G5a@3QhN40aLG50;jn
_P2WYjL0UlG50;Jf]P2WYjL0GiO505nGU`00Nel0GiMO0P00UiL01P1OUiL0UiNG09NGU`1kUg/0aING
0;Jf]P80aLFG01/0aLEO0<G5U`1ONel0UiMO05mO002GUel0GemO05nGG`2GUel0E5AD04U9B@00Gel0
BDU905mO000/;2`0UemO05mOG`1kGel0GiMO05mOG`2GGel0GiNG09NGU`1cLg<0E5AD04U9B@1OG`00
0`1OGel05019BDT0GemO04U9B@35aIL0BDU90019000/;2`0Uel00:jGG`1OU`00GemO09NGG`2GU`00
Gel004U9B@25QFT0QHF50;Jf]P25QHD0Lg=c0P00UiL205nGU`0505nGa@2f][H0aNo509NGa@2f][H0
0P2GaLD00`1OUlD0GlFG05nGU`0205nGU`0505nG[P1OaLD0GiNG0:NWY`1OUlD00P2WYjL00`2O][H0
YjNW0:NWY`020:NWY`80][Jf00<0aLG507^^a@1OUlD00P2f][H02`2WYjL0GiO509NGU`1k[Zh0GiNG
002GU`1OUiL0GiMO05mOG`1cLg<0LXj>00@0GiNG00<0UiNG05nGU`1OUiL00P00UiL00`1OUlD0GiNG
08F5Q@0205nGU`05002GU`1cLg<0GiNG05nGU`1OUlD00P1OUiL00`1OUlD0GlG509NGU`0205nGU`03
0:NWY`23][H0YjNW0080GiO50P1OUiL02`1OUlD0GiN^09NGU`1OaLD0GiO509NGU`2WYjL0UiNG05nG
[P1OUiL0Lg=c00@0GiNG00<0QHF503/k>`0/;2`00P0/;2`02`00;000;2`/04T0000F;1H002`002`0
000/;2`0000/000/000/;2`05R`F00@0;2`/0P00;0000`005QH000000000000202`000030000000/
0000000F00<0;2`/0P0000000`0/;2`000000000000302`00080000/00<002`002`/;00000000P0/
;2`01@000000000/00005P0002`00000008002`00P0/;2`05P0F0000;000000/000/;2`0;00002`/
;000;000000000005P00000002`000000000;00000000000;00F5R`0Gel002`/;00002`0;2`/02`0
0000;00302`/;0050000B@19BDT002`00000000k5QH00P0/;2`00`0002coooooooooo`06ooooo`00
1_ooool01@2f][H0UlG509NGa@2BaLD0GlG50080GiNG01T009NG001OU`00Uel0<5mO001OU`2GUiL0
GiNG05mOU`1OUel0QHF508jULP2WYjL0][Jf09NGG`2f][H0aLEO09NGG`1kUg/0GiMO05mOG`0/;2`0
G`0009MOG`1OGel0Gg]O0080BDU901P0;2`/05mOG`19BDT0BDU909MOG`0U>bD0BDU909MOG`00;000
;2`/05mOG`19BDT0BBDU05mOG`1OG`00BDU9001OG`1OG`00BDU905AD9@1OG`00BDU902`/;01OG`02
05mOG`0305mk001cLg<0GemO0080Gel000L0GiL005mOG`2GU`00UiMO0<FGG`2WYjL0GiNG008009NG
00T0GiNG002Ga@1OUiL0GiNG09NGa@1OUiL0YjNW05n^U`1OUlD00P1OUiL03`2GUiL0GiNG0<G5a@2;
Ykh0UiNG0;Jf]P2GaLD0GlG505nGa@2GaLD0YjNW0;Jf]P2GaIL0GlG505nGU`020:NWY`0=05nGU`2G
Ujh0UlG50<G5a@2f][H0UlFG09NGU`2WYjL0WinO05nGG`00UiL009MO05mOG`0205nGG`04032GU`00
UiL0GiNG05mOU`<0GiNG00D0JHF5002GU`00UiL0GiNG05nGG`0505nGU`8009NG00<0GiNG0:NWY`1O
Ujh00P1OUiL04`1OUlD0GiNG05nGU`1OUiL0Pinf0:NWY`1OUlD0UiNG05nGU`2GUiL0GiNG08>fW`2W
YjL0GiNG05o5a@2WYjL0GlG505nGU`1kUiL0101OUiL02`25QHD0GiNG05mOG`16ATH0;2`/000/000/
;2`00000000/000/;2`0;1HF008002`000@0;2`/0000;00/;2`002`00P0/;2`03000;000;2`/000/
000002`0;2`/00005P00;000000002`/;000;000B@000000;0<0;2`/00L0000/0000000/;2`00000
01H05P000000;0000080000000h0;000000/00005P00000/000/0000000002`002`0000000009@00
0000;000;0000000000/0080000/00X001H0000000000000;2`/0000;000000002`002`0000F01H0
00000P0002`01@000000;00002`/;00F5QH002`00080;2`/0P00;00302`/;003000/000/;2`0000/
0080;2`/00@05QH002`/;000;00002`02?ooool000Kooooo00@0GlFG05nGU`1OUlD0PinO0P1cLg<0
1`2GUiL0UlG50:NWY`2WYjL0T/G505nGG`1OUiL00P1OGel0101OGiL0QHF5031kU`1OUiL20:NWY`05
09NGU`2GUel0UiMO05mO<01OGel00P1OUel205mOG`0>09NGG`1kUel0BDU904U9B@00G`0005mO04U9
B@250000Gel004I6AP19BDT0UiMO08F5Q@19BDT202`/;00401I6AP1OG`00BDU9001OG`<0BDU900@0
9DTU04U9B@0/;2`009MO0P1OGel02@1OG`00E5@U05mOG`1OG`0004T005mO0019BDT0Gel005mO<002
09NGG`80GiNG0P00UiL01@1OUjh0YjNW05nGa@2GUiL0YjNW0080GiNG00l0GiN^05nGa@1OaLD0GiO5
05o5U`1OUlD0YjNW09nf]P2WYjL0GiO509NGa@1OUlD0GiNG0:NWY`2_[jl00`1OUiL01P25QHD0GiNG
08F5Q@1OUiL0Ykjn09O5a@80YjNW00P0UlG50:NWY`2GUiL0PinO05nGU`00Gel0GemO002GG`8005mO
00H0JHEY05mOU`1OUiL005nG07=cL`1OUel205nGU`8009NG00P005nG002GU`1OUiL0GiNG07:>Y@1O
GiL005nG002GU`<0GiNG00D0Gjj^09NGa@2GaLD0UiNG0:NWY`0205nGa@0405n^a@2WYjL0GiNG05nG
a@80GiNG00D0GiO507^G[P2GUiL0YjNW05o5a@020:NWY`0305nGa@1OUiL0GiNG00D0GiNG00<005mO
03/k>`0/;2`00`0/;2`2000/000303/F5P0/;2`0;2`/00<0;2`/00H002`002`/;00/;2`002`002`/
;000;00202`/;080000000<0;2`/000/0000;0000P00;0000`0F;1H0;2`/02`/;00402`/;00@0000
;00/000002`00000000/000002`00000000F0000000/02`00000;000000002`0000/;2`0000/02`0
0080;2`/00D002`00000000/000001H0000/000200000080000/00H0;0000000000000000000000/
000/0003000/000501HF5P190000000/0000;00000000P0/;2`00`0F0000000/02`/;00202`/;006
000/000/;2`05QH/02`/;000;000;2`/2?ooool000Kooooo00D0GiO5002Ga@2GaLD0aLG50<FGa@02
0:NWY`040<G5k`2f][H0UiMO06V5Q@8005mO0P1OGel01@1OGiL0UiNG05nG[P1OUiL0YjNW0080][Jf
00`0BDU907=cL`2^[W/0GemO05nGG`1OGel0BDU9001OG`1OU`00Gel`05mOG`1OUel204U9B@0<02`/
;000Gel0Gel005mO<019BDT0001904U9B@0/;2`0Gel002`/;00k>c/005l00`19BDT06P0/;2`0Gel0
05AD9@00G`00;2`/05mOG`00Uel0GemO05mO000`JC00GemO04U9B@00G`00BDU9001OG`00G`00Nel0
05mOG`00Uel0GlFG05nGU`2GUiL0UiO508>O]P2GaLD0aLG50P2WYjL20<G5a@0:07_5a@2GUiL0YjNW
05nGa@1OUiL0UiNG0:NWY`2^aLD0GiNG09NGU`<0GiNG00D0GlG505nG[P1OUiL0GiNG05mOU`0405nG
U`0@0:NWY`35UlD0UlG509NGa@1OUiL0UiNG0:NWY`1OUg/009MO001OG`1OUel0GenG05nGU`1OGel0
Gg]k002GG`8009NG00@0GiNG002GG`00Uel007]k0`00UiL00`1OUiL0GlFG05nGU`0305nGU`08002G
U`1OUiL0GiNG0:NWY`1OUjh0UlG505o5a@1OUlD305nGU`0309nO]P2GUiL0YjNW00@0GiNG00H0GiN^
05o5a@1OUlD0GlG505nGa@1OaLD305nGU`0305nGa@1OUiL0GiNG0080GiNG00<0GenG04I6HP0/;2`0
0P0/;2`02`0002`0;2`/02`/;00/;2`0000/02`/;000;000;2`/0000;00/0000000/00<0;2`/00H0
Lg=c000/000/0000;1HF0000000/;2`20000000302`0000002`05P0F00@0;2`/00X002`000000000
00000000000/000/0000000002`0000002`000000P00;00202`00004000/000/;2`05QH00000;080
02`000T0000002`/;000;000000002`00000000002`00000000002`01@0000001@00;000000002`0
0000;0005R`F008002`000l0;2`/0000;00002`0000/01HF0000;000;2`/04U9B@00;000;2`/04U9
B@0/;2`0000002`0000/;2`02?ooool000Kooooo00@0<9N^07^^[P2GaLD0RJjj0P0`Gel0100UE5@0
E8>305mkN`0`Gg/205mkN`0N031kN`00Gel0JHF505nGU`1kUjh0Oi^W08>O]P1OUiL0Njj^0;Jf]P2n
Yh/0<8D`055YD@1bSW80JHEY07]kG`1DL5@0Gel0031Y001OGc00JFTj031D001DE5@0;2`/03/k>`0F
AQH09E@U06Qf@P1DE5@0E5@U0P19BDT03@0F>aH0BDU903M?=`19BDT0>c/k04I6AP0FAQH0>c/k04U9
B@1DHU@09EAD031D<01OGc000P1DE5@0501OG`00FUXZ05AD9@0FAQH09EAD032BC01ONel0TZiO05mk
<01OGc00GemO001kN`1bSXh0WkJf09nfb`1]XkX0Winf08>O]P23Wil0GiNG0P2J][H0201aVjL0Pinf
09nfW`1O[YL0GiNG05nG[P1OUiL0Gj>^0`1OUiL01P1OUjh0PinO05nGU`1ORIL009NG06V5Q@80GiNG
02@0E9nO07^^[P1DWkH0KIO508^WY`23][H0GiNG05nG[P1k[/D0GiNG04R9U`00Gg/007]k05nGN`1O
Ng/0JFV505mON`0`Ng/0>XEY001ON`0`NiL0>XF5002GN`00NiL068VG05nG[P1OUiL0GjjG08>OW`1k
[YL0GjjG04RGR@1OUiL009NG05nGU`1k[YL208>f]P0:096f]P1kaLD0Njk505nG[P1OUiL0GiN^05nG
a@1kUkX0[jn_08>OW`D0GiNG00P0Pinf07^G[P23Wil0Pinf07^^[P23WkH0GiNS05nG[P80NiNG0P1O
UiL03@1ONiL0GiNG01iKC@0F;1H05QH/02DF000F;1H05QH/01HF000Q8B405R`F000/000002`00P0/
;2`00`0F;1H05R4;02`/;00201H/5P0=02`/;00F5P00>aHF01H;2`0/5QH0000002DF000F;1H001H0
02`/;00Q8B`05QH/02`/;00201H/5P0W02`/;00F5R`07P0001HF;00/;2`001HF000F00005QH00000
00/;2`0F000001HF000F000F5QH002`001HF000;8@00000/01HF;00/5QH001HF01H/5P00;0002`/Q
02D0000F01H0;2`/0000000F0000000F02`/;00N2`005P0F01H/5P005P005P0002`/;00002`0;2`/
00805QH000l05QH/01H05P0F01H0000F01HQ8@0F;1H002`001HF000001H0;2`/04I65P0`<3/0;1HF
01HF000F5R`02?ooool000Kooooo00D0GiO509NGa@1OUiL007]k09MOG`02001OG`0704U9B@00Gel0
GiNG09NGU`2f][H009NG05nGU`0205nGa@0O05nGU`2GUlD0YjNW09O5a@2f][H0aLG505nGU`1OG`00
Gel`05nGG`2GUel0Gel005nG000/;2`005mO05mO<019BDT0;2`/001O000/;2`004T0001O0019BDT0
AV9602`/;01OG`0005l004U9B@00;000B@0005ADE00205nGG`80;2`/1019BDT00`1OUel0GemO04U9
B@0204U9B@05031Y<00/;2`007<0001OG`1OUiL00P1OUel01@0jQFT0GemO08F5Q@00Gel0Lg=c0080
GiNG00P0[/GJ0;Jf]P2GaLD0GlFG09NGU`1OUiL0GiO509nf]P80YjNW0P1OUiL01@1OGiL0GiNG032G
U`1OUiL0GiO50080GlG500<0UiNG05nGU`00UiL00P00UiL00`1OUlD0GiNG09O5a@020:NWY`0308>f
]P1OUiL0GiNG0080GiNG00<0UlG505nGU`1ONiL00P1OGiL03P1OGel0GenG002GU`00Gel0<9NG001O
U`00UiL0GemO05nGG`1OUiL009NG08>O]P2WYjL0GiO51P1OUiL01`2GaIL0UiNG0:NWY`2GUiL0YjNW
05n^a@2GUlD00P1OUiL01@2GUiL0GlG50:NWY`23Wil0UiO500L0GiNG00P0YjNW05o5a@1OUlD0GiNG
05mOU`1OUjh0GiO50:NWY`80GiO500H0Geo505nGU`1OGiL005mk02`/;00/000202`/;003000/000/
;2`05R`F00D0;2`/00<0000/02D05P0/;2`00P00;0002000000002`00000000k000002`002`/;000
0000;0000`0/;2`0100/000002`00000000002`202`/;004000/000/;2`002`0000/0080000/00D0
02`001H0000002`0000/000/000300000003000F0000000002`00080000/0P0000001`0F5R`0000/
00000000;000;2`/000/000/;2`00P00;000100/;2`0000/000/0000;00202`/;0<002`00P0002`0
1`000000;2`/01HF5P000000;2`/000/000000000P0/;2`0100F5R`0;2`/000/000/;2`8ooooo`00
1_ooool01@1OUiL0GlG5002GU`0jJFT0GemO00<005mO00H005nG09O5a@0`Ug/009MO002GU`2f][H2
05nGU`0:05nGa@1kUjh0UlG509NGa@2f][H0UlG50;Jf]P2GaEl0<4H`09NGG`80Gel000L005mO05mO
G`1OGel0<5@002`/;01OUel0BDU90080;2`/00d0BDU9001OG`00Gc00;2`/05mO0019BDT0;2`/04U9
B@1OUel0UiL`05mOG`2GUel0BDU90080;2`/00<005l005ADE01OUel00`1OGel2001OG`0<02EDE000
Uel005mO001OG`00UiL005mO002GG`00Ug/005mO05mOG`00Gel0GiMO0P1OUiL04@1k[/D0aLG509O5
a@2GaLD0UiO50;Jf]P2GaLD0NiNG002GU`2f][H0GiMO05nGU`1OUel009MO06V5Q@2GaIL0GiNG0080
YjNW1P1OUiL20;Jf]P0509O5a@1OUlD0GiNG05o5U`1OUiL00P1OUlD405nGU`0>001OG`00UiL009NG
002GU`00Uel0<7]k001OU`00UiL005nG05nGU`00UiL0GiNG07^Ga@1OUlD205nGU`0507=cL`00GiL0
GiMO05mkU`2WYjL00P1OUlD03@2GUlD0UlG505o5a@1kaLD0GiNG09NGU`1OUlD0GiNG0:NWY`2GUiL0
GiO509NGU`25QHD00P1OUiL00`1OUel0GiNG05nG[P030:NWY`0605nGa@1OUiL0GiO505nGU`2WYjL0
GiO50`1OUiL00`1OGiL009NG05ADL00302`/;0070000;00/0000000001HF;000;000;2`/0000;003
02`/;00301HF;019000002`000<0000000<002`00000;00/00000P0/00020000;00302`/;00F5P00
;2`/0080;2`/00h0000002`/;00002`0;2`/000/000/00000000000/000002`002`0000F5P00;000
;0000000;0<0000001005P0002`0000/;2`000000000;0000000;2`/01H/5P00;000;2`/0000000/
;2`002`002`/;00000005P0F0P0/00001P0/;2`002`0000/000/;2`00000000/0080;2`/0P0002`0
0`0/00005QH002`00002000/000700000000;000000001HF;00/;2`002`002`/;008ooooo`001_oo
ool01@1OGiL0GiNG001OU`0`Gg/009NG0080GemO0P1OUiL02@1OUel0>VUY001OG`00GiL005mO05mO
U`00Gel005nG031kU`020;Jf]P0:0<G5k`2f][H0YjNW05nGU`1ONg/0BDU905mOG`1OG`00GemO05mO
00<0GemO0P1OUel01@1OGel0;2`/0019000/;2`05U0F00D0;2`/00X0GiMO04I6AP00Gel005mO05mO
G`00B@00BDU9001OG`1DE2D0GiMO0`1OGel01P1OUel005mO031kG`00Gel0GiNG05mOG`8009MO00H0
05mO001ON`00GiL009NG05nGG`1OGel205nGU`0;05n^[P1OaLD0GiO505nGa@2WYjL0UiNG08F5Q@13
SXh009NG05nGU`1OGel00P00Uel00`00UiL0NiNG05nGU`0309O5a@0805nGU`25QHD0PinO05nGU`2W
YjL0][Jf05nGU`2GUiL205nGU`08032GU`1OUiL0GiNG05o5a@1OUiL0GiO505mOU`1OUlD2002GU`07
05nGU`00GiL009NG05mOU`0`Ug/009NG001OU`0205nGU`04002GU`1OUiL0Pinf08F5Q@<0GiNG00H0
Lg=c05nGU`1OUiL0UlG50:NWY`1OUlD309O5a@80GiO500H0YjNW09NGU`1OUlD0YjNW09O5a@1kUjh3
05nGU`8009NG00<0GiNG08>OW`1OUiL01@1OUiL00`1OUlD0GiNG0:NWY`0405nGU`0305mOU`0`Gg/0
;2`/00D0;2`/00@05QH/02`/;00/;2`0;2`/0P00;000100/;2`0>aHF000/000/;2`4000000040000
5P00000002`002`/;080000/00<0B@0001HF0000;0000`0002`00`00;0000000000F0002000/000=
02`0000002`002`0000/000F5P00000/000/000/0000000/02`0000000005P00000/000302`/;007
0000000/;2`0;2`/0000;00/;2`00000000/000202`/;006000/000F01H00000000/000002`0;000
0P00;0001@00000002`002`/;000;000000000<002`000L0000/02`/;00002`0;2`/0000;00/0000
000000<0;2`/2?ooool000Kooooo00h0GiMO05nGU`00UiL0<7^G05nGU`00Uel0GiMO05nGU`1OUel0
GemO031ON`00Uel005mO001OU`8005mO00D0GiNG06V5Q@1OUlD0UlG509NGa@020;Jf]P090<G5a@2W
YjL0UlFG05nGU`35aEl009MO05mOG`1OG`00E5AD0080GemO00T0Lg=c05nGG`0/;2`0BDU905mOG`0k
>c/0;2`/001O000/;2`00`00;0002@1OGc0005mO05mOG`19BDT004T004U9B@1OG`00<5l`05nGG`02
04U9B@0505mOG`1OUel0GiMO032GG`00Uel00P00GiL01`00Uel005nG001OG`00Ug/005mO002GG`1O
Uel00P1OGel04`00GiL0<7^G0:NWY`2GUlD0YjNW05nGU`00UiL0GiNG06V5Q@1OUel009MO04U9B@1O
UiL0GiMO08F5Q@2GUiL0UlG50;Jf]P2GaLD00`1OUiL01P1OUjh0GiO505nGU`2GUiL0GiO5002GU`80
GiNG00<0<9NG05nGU`00UiL00`1OUiL01P1OUlD0GiNG07=cL`1cLg<0GiNG05nGG`8009NG00@0<9NG
05nGU`1OUiL005nG0P1OUiL00`00UiL0GiN^05nGa@0405nGU`0:09NGU`1OUjh0GiO505o5a@2GaLD0
YjNW05o5a@1OUlD0GjjG05nGU`80GiO500L0GiNG09NGU`2GUiL0GiN^08F5Q@1OUiL0GiMO00<0GiNG
00P0GiN^05o5U`1OUlD0GiNG05nGa@1OUiL0YjNW05nG[P80GiO50P1OUiL0101cLg<0GiNG05mOU`0U
E70402`/;080000/00D05QHF02`/;00/;2`0;2`/04T0000202`/;00301H/5P0/;2`0;2`/00<00000
00<0;2`/02`0000/;2`00`0/;2`2000/000800005P00;000000/0000;000;000000/02`0000F5QH2
02`/;0080000;000000002`002`000000000000/0000000/00020000;005000000005QH0000/0000
;00/;2`00P0000001@0/;2`05QH/02`/;00002`0;00000<0;2`/00T002`001HF000002`002`002`0
0000;000;000000/00005P000P0002`5000000040000;00/;2`0000000000080;2`/00@05R`F04T0
000/0000000/2?ooool000Kooooo0`00UiL0201ONg/005nG001OG`1cLg<0GenG05mOG`1OUiL0GemO
0P00Gel03@00Uel005mO001OG`00Gel007^G002GU`2GaLD0GlG509NGa@2GUiL0UlG509nOW`1OGel0
0`2WYjL01019BDT0GemO031D001OG`0205mOG`80GiMO0P19BDT02P0UGRD002`0000/0000B@00;2`/
000/0000B@00E5AD05mOG`00GiL205mOG`05001c001OGel09EhU05mOG`00Gel00P1OUel01019BDT0
Lg=c031ON`00Uel2001OG`0B002GG`00Gel005mO031kG`1OGel009NG001OG`1OGel0GiMO05mOG`1Y
QFT0GiNG0:NWY`00GiL0QHF505nGG`1OGel0<5mO1@1OUiL04@1OUlD0YjNW0:NWY`2GaLD0QHF5002G
U`1OUiL0QHF508>OW`2GUiL0YjNW0;Jf]P1OUiL0UiNG001OU`1OUiL0<7^G00@0GiNG00P0GiO505nG
U`0`UiL0GiNG05mOG`1OUiL0GenG002GU`L0GiNG00<0UlG508>OW`1OUiL0101OUiL00`1OaLD0GlF^
05o5U`0205nGU`80YjNW00<0GiNG05nG[P1OUlD0101OUiL00`1OUlD0GiNG002GU`0:05nGU`80GiO5
00<0GiNG0:NWY`1OUiL00P1OUlD01P1OGiL0GiNG05mOU`00Gg/0BDU90000008002`00P0/;2`0200F
0000;2`/000/00190000;2`/0000000002`05QH00P0/;2`200000080;2`/00/05R`F02`0000002`0
;2`/000/000/0000000/000F000/0000000/02`/;0020000000:000/000F01H0;0000000000/;2`0
02`00000000002`05QHF00000080000/00@0;000000/000/;2`05QH/0`0002`02P0/000002`002`/
;00F5R`0;0000000;000;000;000000/0019BDT3000/000602`/;000;0000000000/000/0000;1HF
0P00;00010000000;2`/02`/;000;0020000000602`/;00/0000;00002`/;00002`09AH00`0/;2`8
ooooo`001_ooool02`1OGel009NG05nGU`0`NiL0GenG07=cL`1OUel005mO002GU`1OGel0<7]O00<0
05mO00<009MO05mOG`00Gel00P00Gel00`2f][H0QHF505nGU`0205nGU`0A07QhN000L`00GemO05mO
G`35aEl0aING09NGG`1OG`00BDU9001O001OG`00BDU9000/0000Gel0BDU902EDE00/;2`00P19BDT0
1@0/;2`005l005mOG`0`Ng/005mO0080GemO00l005l000190019BDT0ATI605mOG`19BDT0Gel005mO
G`00Uel0GiMO031OG`00Gel009NG002GG`1OUiL00P00Uel02000Ng/0GemO05nGU`1OGel0GiNG001O
G`1OUel0<5mO0`00Gel02@1OUiL0GiMO05mOG`0`Ng/0GiNG002GG`1OGel0GiNG002GU`0405nGU`09
05mOU`1OUiL0GiNG09O5a@1OUiL0UlG50<G5a@2GaLD0GiO500<0GiNG00<0Gg^G05nGU`00UiL00`1O
UiL01P00UiL0LXj>05mOG`1OUiL0GiMO002GU`80GiNG00<0GjjG0:NWY`1OUiL0101OUiL00`23Wil0
GiNG05nGU`0305nGU`060:NWY`23Wil0GiNG05nGU`2WYjL0GiO5101OUiL0201OaLD0GiNG05nGU`1O
UiL0GiMO032GU`00UiL009MO101OUiL00`1OUjh0GiNG05nGU`0205nGU`80GiO500@0Njj^09NGU`2W
YjL0GiO5101OUiL00`00Ng/0;2`/02`/;002000/0080;2`/00<09AH002`/;000;0000P0002`01000
0000B@0001HF;00/;2`3000/000302`/;00002`05QH/00@0;2`/00@0000/02`/;00F5QH0;2`/0P00
;0001`0/000002`002`/;0005QH00000000/000/;2`00P00000202`/;00802`00000000000000000
;000;000;2`/01H/5P0/;2`20000;00402`/;00002`0000/01HF;080;2`/0P00;000200/;2`00000
000/000U9C/0;2`/02`00000;000000/0P00;0001@0F000002`002`00000;000;2`/008002`00P00
00002@0/;2`0000/02`/;00/;2`002`001HF;00/;2`0B@000000;008ooooo`001_ooool03000Ujh0
<9NG002GN`0MLW80JHF505mkN`00Gel007]O031OG`0UE5@0?F9D02EDE08005mO00D007]O05mOG`0`
Nel0B5mO031OG`02031kG`0o06MWI`1KRh/0GemO05mkN`1k[Y80BDU9079bLP1k[Ul0UiMO09:BC01k
KC00Gg/`02ED9@19BDT0Gg/`05nGN`1ONel0E5@U0312<00UE2D05QHk02`/;00UE5@0Gg]O07^GG`0`
Nfd0<5mO001OG`0`Gel0<7/`02EDE01DE2D0:VQ205mkG`1OGel0E5AD05nGG`00Gel0Gg]k04RGN`0`
Nel0GiNG07^GU`1kUg/0NiNG032GN`1ATgL0Gg]k032GN`0`Gel007]O001ON`0`Gel0B8UO031kG`00
Nel005mk001OG`0jJFT005mO01Q]K@1ONg/007]O0080JFUY0140<5mk001kN`0eLXh0GiMk032GU`1k
UiL0Pinf05nGU`2WYjL0Xjn_08>O]P1OUjh0NiN^05nGU`0`UiL0GiNG032GU`0205nGU`0?032GN`1O
UiL0<9NG05nGU`1<UiL0GiNG05nGN`1YQHD0LXib05nGU`1OUjh0NiNG05nGX`23Wil0NiNG0080GiNG
00d0Gg^G05nGU`1OUiL0GiNG05mkU`1O[Y80Njk505nGU`23Wil0<9N9031kG`1OUiL0GiN^0080GiNG
00P0GenG056CT`0`UiL0Gg^G032GU`0`Ug/0Gg^G05nGN`80<9NG0`1OUiL03P1O[YL0PinO05nGU`1O
UiL0GiN^07^GU`1OUiL0GiO505nG[P1aYjL0Pinf05nG[P2OWil0LXj>0`1ONiL02@00KG/0;2`/01H/
5P0U5P005R`F01HF000F;1H05R4Q01H/5P0202`/;0809AH000X05QH/02TQ5P0F5QH05R`F01H0000F
01H05QH001HF;00F5QH05R`F0P0/;2`09@0F5R`0;1HF000/000U01H05QHF01HF00005QH001H00000
000001H0000;01H05P0001H05QH/01H05P0/5QH0000/01H02`00;0005P000000;00000005P000000
;00F;1H0;1HF000F5P00;0005QH/00005P0F01H02`//02`F5P00;0005QH/000F000F5P000P0F5R`0
100C2aH00000000F00005P0201H0000<00005P0;5QH001H0000F000000005QH0000/000F00008B`Q
01HF00005QH09AH00P0F5P001@0`<000:AHQ01HF;00F01H05P0000Sooooo0006ooooo`040<G5a@2W
YjL0UiNG07^^a@<005mO00<0GemO04U9B@00Gel01000Gel01000UiL0GemO05mOG`0`Gel4001OG`0;
05mOG`19BDT0Gg]k05nGG`1OUiL0GemO001OG`1OG`00GemO05A`9@00Uel00P1OUel02P00B@00Gel0
05nGG`1OG`00>VTj001OG`19BDT002`0001c0019BDT205nGG`8009MO00T0GiMO001OG`19BDT0Lg=c
05nGG`1OGel0GiMO002GG`1OUel00P1OUiL01@0`UiL005nG05mOU`1OUiL0GlFG0080GiNG00P0PkJO
05nGU`00UiL0GemO05nGG`00Uel005mO05mkG`80GiMO00`0GemO001OU`00Gel009MO031OG`1OUel0
09NG05nGG`1OUiL0GenG07=cL`00NiL209NGU`050=CDe02GaLD0UlFG0;Jf]P23]Yl00P1OUiL0201O
GiL0GiNG05nGG`1OUiL0YjNW032GU`00GiL009NG0`1OUiL02`1OaLD0<9NG05nGU`1OUiL0GlFG05nG
U`2GUiL0GiNG07_5U`1OGiL0UiNG0080GiNG00<0QHF505nGU`0`UiL0101OUiL00`2WYjL009MO05mk
U`0205nGU`0509NGU`1OUiL0GiNG08F5Q@0`UiL00P00UiL00`00Uel009NG05nGG`0205nGU`0605nG
G`00UiL0GiNG05o5U`1OUiL0YjNW0`1OUiL02P2GaLD0GiO505o5a@1OUiL0NiNG05nGa@2GUiL0GiO5
09NGU`1OGiL205nGU`05031kN`0/;2`0;2`/02`/;000;0000P0/;2`3000/00050000;000000002`0
02`000005P000`0/;2`0100002`0;2`/000/000F;1H302`/;00=0000000/;2`0;2`/01HF;0190000
02`000000019000002`002`/;000000002`002`000020000;00300000000;0005QH000<002`00P00
000202`/;004000/00000000;00002`/;08002`000<05R`F02`/;00/;2`00P0/;2`01@0002`00000
0000000F01H0000/008002`000X0000/0000000000005R`F000/000/;2`0000002`/;000;000;2`/
0P00;0002@0/;2`002`0000/000/0000000/01H/5P00;000000/00000008ooooo`001_ooool01@35
aLD0e=CD0=CDe01kUiL0GiNG008005mO00H0Gel004U9B@00Gel007]O001OG`00Uel2001OG`0305mO
G`00Gel005mO0080GemO00D005mO04U9B@00Gel0001O031O<00305mOG`0:001O0000Gel0BDU9001O
<000Uel005mO002GG`00G`0005mO05nG00<0BDU9010005mO04U9B@00Gel0;2`/001O000FHTH009MO
002GU`2GUel0aLEO09NGG`1OG`00Gg]O05nGG`00Gel0GemO0P1OUel01@1OGel005mk002GU`1OUiL0
GlFG00<0GiNG00<0GlG505nGU`1cLg<00`1OUel03000Gel0<7]O05mOG`00Gel0GemO05mOU`00Gel0
09MO05mkN`1OUel0GiNG002GG`80GiNG00@009NG07^GU`2WYjL0UlG50P2WYjL0101OUlD0GlFG05nG
U`2GUiL=05nGU`0807^GU`1OaLD0YjNW09NGU`1OUiL0GlFG0:NWY`1kUjh705nGU`090:NWY`1OUiL0
GiNG09O5U`00GiL0GiNG05mkU`1OUiL0GiO500<0GiNG00<0Lg=c002GN`00Uel00P00UiL01P00Uel0
09NG05nGU`0`UiL0GiNG002GU`80GiNG00/0GlFG05nGU`1OUiL0GiNG05o5a@1OaIL0UiNG05nGa@2G
UiL0NjjG05o5a@0205nGU`0@05nGa@1OUiL0GiNG05mOU`1DL5@0;2`/000/000002`0;2`/00000000
;0005P0F04T0000002`0;2`/02`0008002`000@05QH/02`/;00/;2`000000P0/;2`03000000001HF
02`/;00/;2`002`00000000/0000;2`/0000000/;2`002`002`/;08002`000`0000/01H/5P00;000
02`00000;000;0000000000/0000000002`002`/;000000202`000040000;00/5QH002`000000080
000/1`0/;2`02`0002`0000002`0000002`0;2`/0000000/;2`000000000;000;000000/008002`0
00<0000/000/000000000`00;0001P000000;2`/0000000/0000000/01HF;080;2`/00<00000oooo
ooooool01_ooool000Kooooo0P3De=@01035aLD0Ujj^002GU`00Uel3001OG`09001OU`0`Uel009NG
001OG`1OGel005mO05mOG`1OUel0E5AD00H005mO00P0ATI605nGG`00Gel0GemO001OG`1cLg<0Gel0
05ADE080GemO00/0BDU9001O0019BDT0GemO05mO000k>c/005l005mO001OGel007<005mO000204U9
B@08002GG`1OGiL0GiNG05nGU`00UiL0GiMO07^GG`1cLg<205nGU`0405nGG`00UiL0GenG032GU`80
GiNG00L0UiNG05nGU`1OUiL0GiNG0:NWY`35aIL0YjNW00<0GiNG00d0GemO001kG`1cLg<009NG05nG
G`1OGiL0Lg=c05nGG`0`Nc0005mO05nGU`00Gel009MO0080GiNG00@0PkJO05nGU`1OUiL0UiNG0P1O
UiL00`00UiL0WkJf05nGU`0605nGU`04002GU`1OUiL0GiNG07=cL`@0GiNG00L0GlG505o5U`1OaLD0
YjNW05nGU`2f][H0PkJf00D0GiNG00D0Lg=c05nGU`1OUiL0GiNG08F5Q@0205nGU`05002GU`1k[YL0
GlFG05o5a@1OGiL0101OUiL01P00UiL009MO002GU`00UiL005nG002GU`@0GiNG00D0YjNW05nGU`2G
UiL0GjjG05nGU`040:NWY`0509O5a@1OUiL0GiO509NGU`2WYjL0101OUiL01@0`Gg/0;2`/02`/;000
;000000/00<0;2`/00<002`002`/;00/;2`00`0/;2`01P0F;1H000000000000/0000B@0002`00080
000000@0;2`/000/0000;00002`00P0002`0100F000002`0000/000002`202`0000602`/;000;000
000002`0000002`0;0000P0000001@005P0002`000000000000002`000@0000000L0;0000000;000
02`0;2`/000/000F000000000080;2`/0P00;0002P19BDT0000/01HF0000;000;2`/000/000/0000
000/000/000F5QH2000/000?02`/;0000000000/000000005P0002`00000;000;000;2`/0000;00/
;2`05QH/0000;000000002`000Sooooo0006ooooo`040<G5a@2GaLD0GiO505mkU`80GemO01`005mO
05mOG`1OGel0GiNG08>OP`1OUiL0][Jf05nGU`25QHD009MO04U9B@0`Gel0BDU9001OG`00Uel005mO
02`/;000Gel0E71D04U9B@00Gel0BDU9001O001cLg<0GiMO031kG`1OGel0GiMO0P0/;2`00`1OG`00
04T004U9B@0202`/;00@001OG`19BDT0GemO02`/;000B@009E@U05mO0000Uel0GemO001OG`00UiL0
GiNG07]kG`1OUiL005nG05mOU`80GiMO00<0GemO05mkN`1OUiL00P1OUiL01`25QHD0GiNG05nGU`1k
[YL0UiO50:NWY`1OaIL00P1OUiL01P1OGel007]k05mOG`00Gel009MO05nGU`80GiMO00/005mO05nG
U`1OUel005mO09NGU`2WYjL0GiNG08>OW`1OUiL0UiNG05nGU`02002GU`0305nGG`1OUiL0GiNG0080
GiNG00D009NG05nGU`1OUiL0GiNG002GN`0205nGU`070:NWY`1OUiL0GiNG08F5Q@2OWil0GiO509NG
U`0205nGU`80YjNW00<0WinO09NGU`1OUiL00P1OUiL01@2GUiL0GlFG05nGU`1OUiL0YjNW00@0GiNG
00<0NiNG05nGU`1OUiL01P1OUiL01000UiL0Lg=c05nGG`00UiL405nGU`090:NWY`1OUiL0GiNG05nG
U`1kUiL0GiNG05o5a@1OUlD0YjNW0080GiO500@0<9NG05nGU`1OUiL0UiNG101OUiL01@1DE700BDU9
000/000/;2`0000/0080;2`/00T05R`F02`/;00/;2`0;00002`/;00002`002`001H/5P1900000P00
;0000`0/;2`002`00000000202`/;0030000000/0000000000<002`000<0;0000000000000000`00
;0000`0F0000000/000/00020000000302`0000/;2`0>aHF0080000/00<0;000000/000/00000`00
00001`0002`0;0000000000/;2`002`003/U9@00;0000`0/;2`02`000000;2`/000/000F;1H002`0
02`/;00/0000000/02`00000;00001HF0080;00000D0;2`/02`00000;000;00001HF5P02000/0080
;2`/00H0000/02`/;00F5R`0;2`/000/00000008ooooo`001_ooool01@1OUiL009NG05nGU`1OUiL0
Lg=c0080GemO00@0][Jf001OG`1OUel0LXib0P1OUiL02@00UiL005mO001OG`00Gel09EAD05mO0019
BDT005mO04U9B@0205mOG`0402ED9@1OGel004T000190080BDU9101OGel03P19BDT0GemO001O0019
BDT002`0000k0000G`00GiMO05mOG`0/;2`005mO05nGG`0`Nel0GiNG0`19BDT01@00GiL0UiNG07^^
U`1OUiL0GlFG0080UiNG00`009NG05nGU`0`UiL0GiNG05nGa@2GUiL0UlFG09NGU`1OUiL0GiN^05nG
U`2GUiL305nGU`0705nGG`0`Ug/0GemO05mOG`1OUiL0Lg=c002GU`0205nGU`0405mOG`00UiL0GiNG
05o5U`80YjNW00<0LXj>05mOU`1OUel00`1OUiL0101OGiL0GiNG05nGU`1OaIL205nGU`09002GU`1O
UiL0GiNG031kU`1OUlD0YjNW05nGa@1OUiL0QHF500L0GiNG0`2WYjL02@1OUlD0GiNG05nGU`1OUiL0
QHF5032GU`1OUiL009NG05mOG`0205nGU`030:NWY`2GUiL0GenG00L0GiNG00<009NG05nGU`1OGiL0
0P1OUiL0302OWil0QHF509NGU`2WYjL0GlFG08F5Q@2GUiL0WinO09O5U`2GaLD0YjNW09O5a@80GlG5
00@0PkJf09NGU`1OUlD0YjNW101OUiL00`0`Gg/004T002`/;00402`/;00303/F5P00;000;2`/0080
;2`/00@0000002`/;00/;2`0000/0P00;00202`/;00H000/00005QH0;2`/000/000/0000000002`0
000/;2`05QHF02`000000000;0000000;00/;2`002`002`0000002`0;0000000000/;2`0000/000/
000F5R`000000P00;0000`0/000002`002`00002000000030000;00000000000008002`000@05R`F
02`/;000000000000P0/;2`20000000?000F5P0/000002`00000000002`0;000000/000F0000000/
00000000;0000000000/000000005R`F008002`00P0/;2`01P0002`0;2`/02`/;00002`0;2`/0000
00Sooooo0006ooooo`80GiNG00d0GiO5032GU`1OUiL0GiNG05mOG`1cLg<0GemO05nGU`2=SHd0YjNW
05nGU`1OGel005mO0080GemO00<005mO05mOG`19BDT00P00G`001000Gel0GemO05mkG`00G`0202`/
;00>04U9B@1OUel005mO001OG`00Uel0Lg=c04U9B@0/;2`007<004U9B@00G`00;2`/001OG`1OGel3
04U9B@0907=cL`1OUg/0GiNG04U9B@1OGel005mO001OU`2WYjL0GiNG0080GlG500D0UiO50:NWY`1O
UiL0GiNG032GU`0205nGU`0505o5U`1OUlD0GiNG05nGU`0`UiL00P1OUiL0102GaLD0YjNW0:NWY`1O
UlD205nGU`0607=cL`1OUel0GiNG002GG`1OUel0E71`0P1OUiL0202GaIL0YjNW05nGU`1OaLD0YjNW
05nGU`1OUel005nG0P1OUiL0201cLg<0GiNG05nGU`1OUiL0GlFG002GU`1OUiL009NG0P1OUiL01`2G
UiL0GiNG05o5U`1OUiL0UlFG05nGU`1OUjh00P1OUlD205nGU`0609O5U`1OUiL0Gjj^0:NWY`2GUiL0
09NG1@1OUiL01@1OUel0GiNG05nGU`1OUiL0UiNG00<0GiNG0P00UiL01P1OUiL0GenG05nGU`1OUiL0
09NG07=cL`D0GiNG00<0GlG50:NWY`2GaIL00P2WYjL02P2G[Zh0][Jf0:NWY`2WYjL0UiNG09NGa@1O
aLD0PkJf05o5a@2WYjL209NGU`0405nGa@1OUiL0GiNG031kN`D0;2`/00<0000/000F00000000100/
;2`02@1900009@000000;00/;2`002`002`/;0190000;2`/00000002000/00050000;000;00002`0
0000000/00000P00000202`000030000;00/00005QH000<0000/00X002`002`/;00002`05QH/04T0
0000;000;2`/000/000/;2`0;0000P0000020000;0070000000/;2`0000/03/0000002`0;00002`/
;00200000080;2`/01T05R`F0000;00/;2`000000000;000;000000/00005P000000;2`/02`0000/
;2`0;000000/000F01H002`002`/;01OG`00000002`/;00/00005R`F02`/;00002`0;00000Sooooo
0006ooooo`0B0:k5fP2_[jl0Gjj^05JEU@2n_]<0Ykjn09N^U`2;RjL0PinO09Zf]P35dM40Ujk509JF
UP00Gel0<5mk002GG`00Gel0:eYJ0P19BDT0400/;2`0BDU9031O000UE5@0:VQJ001D000UE5@005l`
05ADE00`Nel0E5AD01QOG`00Gel0<5mO05mOG`0`Uel203/k>`0c02`/;00fCE/0GUiN05mkG`1DL700
Ujk509O5a@2OWil0VjNK05nGG`1kUg/0Ni9k032GN`1OUiL0<9NG0329R@1O[Zh0WkJf07_5a@2G[/D0
][Jf09nf]P1aYi/0GiN^09nO]P1DWil0GiMk05mkU`1ONg/0<8V906V5Q@1OUiL0Ni:^07^^a@1<[Zh0
E9nO07nVV`23Ph<0QHF505nGN`0`Ng/0<9Mk032GG`1TSW80<7^G032GU`1OUg/009NG05nGU`1DWil0
Oi^W0080GiNG00L0<9NG05nGU`1OUiL0GiNG05nGX`1OUiL0LXj>0080GiNG00D0<9NG05nGU`1OUiL0
GhVG05nG[P0405nGU`0:05nG[P1OUiL0GiN^05nGU`1<Ug/0<9NG05nGU`00Ug/0HhVG08>OW`80GiN^
00H0NiNG05mk[P1ONiL0KING032GU`1ONiL205nG[P0408>OW`1ONiL0GiNG032GU`80GiNG00D0<9Mk
032GU`0`NiL0<9FG05nGU`02032GU`<0GiNG01l0B9NG05nGU`2GUiL0NjjG0:NWY`23]Yl0Ujj^096[
W`1k[Zh0Njk505n^a@23][H0Gjk509NG[P1]Uj<0UiN^0:NWY`23Wil0GiN^05mkU`1OUiL0GenG01Qk
N`19BDT05R`F02`/;00F;1H0;2`/01HF;00;8AH002D000805QHF034002`001HF;00F5R`08B`Q01HF
;00U01H05R`F01HF;00F5QH05R`F00/F2`0k5QH05QH/01H/5P005P005R`F000/000;8@/05R`F0000
000F00005QH/000F5P0/5QH0000F0000;00F5R`0;2`/000/000F;1H0;2`/01HQ2`0F5R`001HF01HF
5P005P0001HF01H05P0F00/0000001H0000F5R`05R`F000F5P00;0002b4;01HF5P0/5QH0;2`/00<0
01H001<002`001H;5P0F000001H00000000F5P00000/0000000F0000000F02`/;00000005QH/01HF
000/5QH02aHQ000F5P0/5QH0;2`/00805R`F00D0;2`/024/8@0U5P005P0001HF0008ooooo`001_oo
ool01`2f][H0YjNW09NGU`1bLW80e=CD0:NWY`2f][H00P1OUiL02@1OUlD0Ujk505nGU`2WYjL005mO
08F5Q@1OUel005mO031OG`0205mOG`0904U9B@1OGel007<005mOG`00Gc00BDU9001c0019BDT0GemO
008005mO00<007]O001OG`1OGel00P00Gel05P1OGel0Lg=c001OG`0jJFT0GemO001OG`1OUiL0UlG5
0:NWY`2GUiL0<9Mk002GU`1OG`00GiMO002GG`00GiL005mO031kN`1OUiL0UlG50:NWY`2GaLD205o5
a@050:n_[`2GUiL0GiNG002GU`1OUiL00`00UiL03000GiL0GenG05nGU`1OUiL009MO05nGG`1OUlD0
e=CD08F5Q@1OUiL0Lg=c05mOG`8009NG0P1OUiL00`1OUlD0GiNG05nGU`0305nGU`05002GU`1OUiL0
GiNG09NGU`2WYjL0101OUiL01@1OUlD0GiNG0:NWY`2WYjL0<9NG00P0GiNG00H0GemO001OU`1OUiL0
GenG002GG`1ONiL505nGU`0305mOU`1kUiL0GiO500L0GiNG0P1OUlD01@1OUel0GiNG05mOU`1OUiL0
09NG0080GiNG00@009NG05nGU`1OUlD0GiN^0`1OUiL01`25QHD0UiNG09NGU`2OWil0YjNW05nGa@1O
UiL00P2GUiL01@2WYjL0PinO0:NWY`1OUiL0GiO500@0GiNG00X0E5A`02`/;00/;2`002`004T0000/
;2`0000/01H/5P0002`0;000100/;2`00`0F;1H0;2`/02`/;00202`/;00500000000;000000/0000
;000;0000`0002`00`00;0005QH/0000000202`0000302`/;00002`0000/008000000P190000100/
;2`002`00000;00F5R`202`/;080000000/0;2`/0000;00F5P0002`00000000/;2`0000002`00000
;0005QH/0000;002000/0080000000@0;2`/000/00000000000/0P00;002000000060000;0005QH0
;0000000;0000000000/0P00;0001P005P0002`0000/000002`0;2`/000/00@0;2`/00<0000/oooo
ooooool01_ooool000Kooooo0100][Jf09O5a@35aLD0Ph>30>o_a@3oknl0GiNG0<G_k`2GaLD0][Jf
04b^[P2WYjL0Lg=c05nGa@1OUel0BDU90P00Gel02P1OG`0005l005mOG`2GUel0GiMO02`/;01DE2D0
GemO001OG`00Uel4001OG`0305mOG`00Gel0UiNG00<0GiNG0180GemO08>OW`1OUiL0GiNG002GG`1O
UiL0Lg=c05mOU`0`Ng/009MO001OU`00Uel005mO001OU`1OGiL007^G05nGU`2WYjL205nGU`0<0:NW
Y`1OUlD0Pinf09O5a@2f][H0Lg=c05nGU`00UiL005mO032GU`1OUiL0GenG0P1OUiL0101cLg<0BDU9
031kN`00UiL205nGG`<009NG00X0<7]k05nGU`1OUiL0GiNG002GU`25QHD0GiO5032GU`1OUiL0UlG5
0P2WYjL0101OaIL0GiNG05nGU`1OUlD305nGU`0709NGU`2f][H0GiNG05nGU`00UiL0GiNG0:NWY`02
05nGU`0605nGa@1ONiL009NG05mOU`1OUiL0GenG0P1OUiL01P0`UiL0GiNG05nGU`1OGiL0GiNG05mO
U`<0GiNG00@0UiNG05nGa@2WYjL0GiO50P1OUiL01`1OUlD0GiNG05nGU`00UiL005nG05nGU`1ONg/0
1@1OUiL00`00UiL0UiNG05nGU`0205nGU`80GiO500H0GiNG08>O]P2WYjL0GlFG09O5a@1OUlD205nG
U`0408>OW`2GUiL0GiNG09NGU`80GiNG00<0GenG05nGU`0`Gg/00P0/;2`01P00;000000/02`/;000
;0005QH002`/;08002`000D0;2`/000/000000005R`F02`/;0020000;080000000H0;2`/01HF;000
0000;000000/000/;2`20000000901H/5P000000;0000000;00/;2`0B@000000;0000000B@000080
02`01@0/;2`01`000000;2`/000/000/;2`0000/01HF000/00000`00;0000`0/;2`002`00000;002
02`000060000;00/0000;2`/0000000002`0000F0P0000001P00;000;0000000000000005P000000
;0<000000P00;0002@000000;000000/000/;2`0UiMO02`/;000;000;2`/04T0000202`/;0Sooooo
0006ooooo`0=0;Jf]P2GUiL0UlG507^B[P00GiL0GenG09NGU`1OUiL0GiO505nGU`23Wil0GiNG002G
U`04001OG`0801I65P1OGel0GemO05mOG`00G`00GemO05nGG`1DE5@2001OG`80GemO0200BDU905mO
G`00Gel0GiNG07=cL`1OUiL0YjNW05nGU`00Gel0UiNG0:n_[`1OUel009NG05nGU`2WYjL009MO05mO
G`0`UiL009NG05nGU`1OGel005mO05mOU`00Gel005mk05mOU`00Gel0GiNG09NGU`2WYjL0GiNG09N^
[P80YjNW0100GiNG002GU`1OUiL0GiNG032GU`25QHD0GiNG002GU`1OUiL0GenG001OU`00Nel005nG
05mOU`00Gel009MO0P00UiL00`0`UiL0GiNG05nGU`0405nGU`0:001kU`2GUlD0GiNG05nGU`2GUiL0
YjNW05nGU`2;Ykh0YjNW09O5a@80YjNW0P2f][H02P2WYjL0Gjk505nGU`1OUlD0GiNG05mOU`1OUlD0
GiMO031kN`00UiL205nGU`0405mOU`1OUel0GiNG07:>SP<0GiNG00D009NG05nGU`1OUiL0GiNG05nG
a@0405nGU`0305nGa@1OUiL0GiNG0080GiNG00D005nG05nGU`00Uel0GiNG002GU`0205nGU`05002G
U`1OUiL0GiNG05nGU`25QHD00P1OUiL01@25QHD0GiNG05nGU`1kUiL0GlFG0080GiNG00@0GiO505nG
U`1OUlD0GjjG0`2WYjL02@2GUiL0GiNG05nGU`1OUiL007]k04U9B@00;000;2`/000/000202`/;00:
01H/5P0/;2`0;2`/02`0000/;2`002`004T00000;000000002`00080000000<002`002`/;0005QH0
0`0/;2`20000000402`0000F;1H0000002`000<0000/00<0;2`/000/0000;000100/;2`01P0002`0
5QH/0000;00/;2`0;000000/0080000/00<0;1HF000/0000;0000P0000001P00;000;00000005P00
;000000002`00080000000<0;2`/0000000F00001@0000001`0002`0000F00000000000002`00000
000002`00P0000000`0/;2`002`002`/;00302`/;00401H/5P0002`0000/000000Sooooo0006oooo
o`040<G5a@2GUlD0GiO505nG[P<0GiNG00@0aLG_0;Jf]P1OUiL0GiNG0P00UiL03000Uel005mO04U9
B@19BDT0AV9609NGG`0/;2`005mO002GG`00Gel0GemO04U9B@<005mO0P19BDT0101OGiL0C7]k05nG
U`1OUiL209O5a@0707=cL`00Uel0UlG50:k5a@1OaLD0UiNG05nGU`0305mOG`05031OG`1OGel0GenG
001OG`1OUiL00P00Uel01000NiL0GenG001OU`00UiL205nGU`0309NGU`1k[Zh0YjNW0080YjNW0P1O
Uel01`1OGiL0<9NG05nGU`1OUiL009NG05nGU`1OGel00P00Gel02@00GiL0GiMO001OG`1OUel005nG
05nGU`1ONg/0GiNG05nGG`0405nGU`0;05n^[P2GUiL0UiNG09NGU`2WYjL0UiNG002GU`2O][H0GiO5
0;Jf]P2GaLD00P2f][H00`2GaLD0YjNW08>O]P0205nGU`8009NG00<0GenG05nGU`1OUiL00`1OUiL0
0`00UiL0GiNG05nGa@0205nGU`04001OU`1OUiL0GiNG05mOG`<0GiNG00<0GiO505nGU`1OUiL00`1O
UiL00`2WYjL0GiNG05nGU`0205nGU`0605nGG`00Nel0GiNG002GU`1OUiL009NG2@1OUiL0400`UiL0
GiNG05nGU`1OUlD0GiNG05nGa@2WYjL0Pinf05nGa@2WYjL0GiNG09NGU`1OUiL009NG07=cL`00Gg/2
02`/;004000/000002`0GiNG0000;080;2`/0P0002`02`00;000B@0002`/;00F;1H0;2`/000/000/
0000000002`0000002`0;2`/008002`000H0;2`/0000;00002`0;2`/01H/5P0/0002000000<0;2`/
00H05QH/0000;00/;2`0;2`/0000;000;00202`/;0060000000002`0;2`/000/000/;2`000000P00
;0030000008002`000@0000F0000000/;2`0;2`/0`0000002P0002`001HF00000000;000;2`/02`0
000002`0000001HF5P00;0020000;00>0000000/;2`0;00002`F5P00;000;2`/000/000/000002`0
02`000005QH0000/02`/;00/0008ooooo`001_ooool20<G5a@0B05nGa@1OUiL0YjNW09NGU`1OUiL0
YjNW05o5a@35aLD0Pinf0:NWY`2GUiL0GiNG001OG`1OGel0GiMO01Hk5P1OGel004T00`00Gel0101O
Gel09EAD07=cL`1cLg<2001OG`0E04U9B@2WYjL0GiN^0:NWY`2f][H0UlG509NGU`1OUiL0GiO50<G5
a@2fcLd0GiO505nGU`00Uel009NG05nGU`1cLg<0>VUY05mOG`1OUel0GemO0080Lg=c00X009NG05mO
G`1OUiL0UiNG05mOG`1OUiL0UiNG0:NWY`2OWkH0UlG50P35klD00`35aLD0][Jf05nGU`0205nGU`08
05mOG`1cLg<0GenG05nGG`00Gel007]k05mOG`1OGiL2002GU`@0GiNG0P00UiL02@1OUiL009NG002G
U`2GUiL0YjNW05nGU`2GUiL0GlFG09NGU`030;Jf]P0C0<G5a@2f][H0UlG50<G5a@2f][H0aLG507^G
a@2WYjL0GiNG002GU`1OUiL0QHF507=cL`1OUiL009MO05nGU`00UiL0GiNG08F5Q@0405nGU`05002G
U`1OUiL0GiNG05nGU`1OUlD00P1OUiL01@25QHD0GiNG08F5Q@1OUiL0LXj>00@0GiNG00H009NG05nG
U`0`[Zh0GiNG05nGa@00UiL305nGU`0A032GU`1OUiL0Lg=c002GU`1OUiL009NG05nGU`1YQHD009NG
05nGU`25QHD0YjNW09NGa@2GaLD0GiN^05nGU`2GUiL00`1OUlD00`1OUiL009NG04IRHP0202`/;008
000/000/;2`0;2`/02`/;000;000B@000000;0000002000/00050000;000;000;2`/04T0000002`0
0P0000002@0/;2`001HF02`/;000;000;00002`/;00002`0;2`/000/00020000;005000/000/;2`0
000/000/000F;1H00P0000001`190000000/000/0000;00001H00000000/;2`00`00;0005@0002`0
5QH002`000000000;2`/0000;00/0000000000005P0002`002`00000;000;000000/02`/;00/0000
01HF000/000002`002`002`000020000000301H000000000000000@002`00P0002`02@0/0000;2`/
0000;00/;2`0;00001H/5P190000000/00000008ooooo`001_ooool30<G5a@050;Jfb`2GaNl0][Jf
05nGa@35aLD00P2GaLD00`1O[YL0GiNG05nGa@0205mOG`0604U9B@1OUel004T002`/;000Gel005nG
0P1OUiL01P1OGel0C9Mk05nGU`1OGel009MO001OU`8005mO01@0NiN^0;Jf]P2GaLD0QHF505nGU`2W
YjL0GiO509NGa@2O][H0GiO505nGU`2WYjL009MO05nGG`1OGiL0E5AD05mOG`00UiL0Lg=c05mOG`80
GenG00P0<5mk05mOG`1OGiL009NG05mOU`1OUiL0GenG08>OW`<0YjNW00D0UiNG0:NWY`1OUiL0JHF5
05nGU`0205mOU`80GiNG00<0GenG001kN`25QHD00P1OUiL01000Gel0GiNG002GU`0`Uel505nGU`03
05nGa@1OUiL0GiNG0080YjNW01<0UiNG0<G5a@2WYjL0UlG50;Jf]P35aLD0aING09NGU`1OUiL0UlG5
09NGU`2OWil0UiNG001OG`00GiL009MO002GU`1OGiL0<9Mk00<0GiNG00<009MO05nGU`1OUiL0101O
UiL0101cLg<009NG05mOU`1ONiL205nGU`0305nGa@1OUiL0GiNG00<0GiNG00H009NG05nGU`1OUiL0
YjNW05nGU`0`Ug/305nGU`0507=cL`1OUiL009NG05nGU`00UiL01@1OUiL0200`UiL0GiNG05nGU`1O
UlD0GiNG05o5a@2GUiL0PinO0P1OUiL00`1OUlD0GiNG09NGU`0205mOU`0505A`L00/;2`0;2`/02`0
000000000P0/;2`02P0F;1H0000/02`/;00/000002`00000000/000000000000;00/;2`20000;003
02`/;000;000000/00<0000/00<0;2`/000/0000;0000P0/;2`00`0002`002`00000000202`0000=
01H/5P000000;000000/00000000B@0002`/;00F;1H0000/02`/;000;000;000000/00020000;007
0000000002`0000/0000;00/;2`0000/02`F5P0202`/;00405mOG`00;00002`002`00080000000<0
02`00000;000;0000P0000001000;00001H000000000000202`0000700000000;0005P0F0000;000
0000;00002`/;0020000;00401H/5P0/000002`0000000Sooooo0006ooooo`0F0;jn_P2^aLD0Ujk5
0;K1`@3Cdm<0aLG509;5a@2Wdkh0Njj^0:NWY`1OUj<0Gg^G031kU`1OUjh0NiMk0325<00`Uel0ATI6
02`/;00`Ug/007^G031kN`80Gg^G02T0=Hj>031OG`00Ng/009Mk001kG`00Gel0JHF501R9R@2;Ykh0
Njk50:k5a@1OaLD0`lG507^^[P23][H0GhVG09:^[P2G[/D0Ykjn09JFUP1OUiL0Njj^08V/X01YQHD0
05mO031OG`0`Nel0<7]k05mkN`0VNg/0LXj>07^^U`1OUiL0<7]k002GN`0`Gel0FUY209NGU`23Wh<0
Win309nfW`0209N^[P0G07nKV`1OUiL0GiN^07^GU`2G[Zh0GiN^08>OW`2E^/@0cLg=08^WY`1OUiL0
GiN^07^GU`0`UiL0EYNG032GU`13SXh0Rkjn0:NWY`2OWil0PinO06fG[P2;YjL00P23Wil07@2GUiL0
Ykjn09nf]P27[j<0PinO0:NWY`1O[Zh0PinO05nGU`23Wil0Njk504REU@00Gel009MO002GN`0`Ug/0
<9NG05mkG`0`Ug/0<7]O031kU`00UiL0<9Mk05nGU`0`Uel008V9002GU`1OUiL0Gg]k0080<9Mk00D0
>XF506V5T`00UiL0<9NG05mkU`0205nGU`06032GU`1OUiL009NG05nGN`1OUiL0NiNG0P1OUiL00`18
UiL0GiNG05nGU`0205nGU`0506V5Q@1OUiL0LI^K05nGU`1kUiL00P1OUiL01@23Wil0<9Mk05nGR@1k
UiL0NiN^0080NiNG00/0Gjj^07^G[P1o_ZL0PkJO05n^[P1ONiL0GiNG05nG[P1OUiL0Gg^G049XFP02
02`/;00=000/000/;2`05R`F01H/5P0Q8B`05R`F02`/;00001H05R`F03/F5P005QH02`/;000F0003
02`/;0805R`F00D05QH;01H0000F5R`05P0F01HF;002000F000;000F2`0F5R`05R`F01HF0000;000
5QHF000/000F;1H0000001H/5P0/5QH00P0F5R`01P0F;1H05P/;000/00005P005QH0071<<0805R`F
01802b4;000F000F01H05QH/000F000000005QH0000;5P0`AS00][Jf082BTP0k>c/002DF01HF5P0F
;1H05P0;01H05P00000202`/;00<0000000001H02aH;01HF5P0000005P0F0000;00/000002`001hN
=0005P00;1HF0P0F01H01P0F;1H05P0001H/5P0/5QH002`001H000Sooooo0006ooooo`0709O5a@2f
][H0GiO509O5a@3QhN40klG50>7Qh@020<G5a@030;Jf]P1kUiL0GiO50080GiNG01T0YjNW04U9B@1O
Gel0E5AD02`/;01OUiL009MO001OG`00GiL0GiNG0:n_[`1OUiL0][Jf05nGG`00UiL0QHF505nGG`2f
]Yl0][Jf0<G5a@2WYjL0UiO50;Jf]P2GaLD0][Jf00<0GiNG01d0UiO509O5a@1OUel0QHF503YYJ@00
Uel005mO05mOG`00Uel005mO04U9B@0UE5@009MO001OU`00Gel009MO001O0019BDT09E@U04U9B@1c
Lg<0GiNG07=cL`1OUel0GiNG032GU`1OUiL0YjNW05nGa@0209O5U`0509NGU`2_[jl0][Jf0;Jf]P2G
UiL00P2WYjL02P1OaIL0WkJf05nGU`1OUlD0GiNG05nGa@1OaLD0GlFG05nGU`1OUlD305nGU`030:NW
Y`1OUiL0Gjj^00<0GiNG00P0GenG002GU`2WYjL0GemO07=cL`1OGel009MO001OU`8009NG00<009MO
032GG`1OUel00P00UiL01P00Uel009NG002GG`00UiL0GiNG002GU`80GiNG00H005nG05nGG`1OUg/0
05nG002GU`00Uel305nGU`03032GU`00UiL0GiNG00P0GiNG00X009NG05nGU`1OUiL0NiN^09O5U`2G
UiL0GiNG0:NWY`2GUiL0QHF50P1OUiL50:NWY`0407^G[P2GUiL0GiNG09NGU`80GiNG00@0GiO505nG
U`0UL700B@001@0/;2`00`0F5R`0;00002`0000202`0000;02`/;00000005QH/000/00190000;2`/
000/000/;2`0000001HF0000;0001P0/;2`0100/0000B@000000;00/;2`20000000302`F5P0002`0
02`00080;2`/00@0000002`0000F5R`002`00P0000001P1OG`00;2`/02`0000F5R`002`004T000<0
02`000D0;2`/0000;00/;2`00000000/000202`/;00500000000;000000F0000;00/00000P0002`2
0000000401H0000002`0000/000/00<0000000<001HF0000;00/;2`00P00;0000`0/;2`002`001HF
5P02000/000302`/;?oooooooooo00Kooooo0006ooooo`0505nGa@2GaLD0aLG50<GJfP3_aNl00P3Q
hN430;Jf]P0405nGU`2GaLD0GiNG05nGU`80][Jf00<0UlG50:jGU`1OUiL00P2WYjL01P1OUiL009MO
05nGU`2f][H0YjNW09O5U`80GiNG00<0aLG509NGU`2OWkH00`2f][H03P2WYjL0][Jf0=CDe02f][H0
PinO0<G5a@2WYjL0GiNG08F5Q@1OUel009MO031kG`1OGel005mO0P1OGel00`00Gel0GemO001kG`02
002GG`08001OG`0/;2`0BDU9001OG`25QHD0GiMO05mOG`00Gel205mOG`0505nGU`0`UiL0GiNG05nG
U`2GUiL00`1OUiL00`2_[jl0][Jf0;Jf]P020:NWY`0<05nGU`2f][H0RkjW0:NWY`2GaLD0UiNG05nG
U`1OUlD0GiNG07:>Y@1OUiL0UiNG0P1OUiL209O5a@0608>OW`1OUiL0GiMO05nGG`1OGiL0GiNG0P00
UiL00`00Gg/009MO002GG`03001OG`8009MO00<0GiMO002GG`00Uel00`00Uel00`0`UiL009MO05nG
G`0207=cL`0705nGU`00GiL0<9MO002GU`00GiL0GenG001OG`0205nGU`0309nOW`1OUiL0GlFG00@0
GiNG00<0<9NG002GU`1OUiL00`1OUiL04P2GUiL0WinO0:NWY`2WYjL0UiNG05nGa@1OUiL0YjNW08>O
W`1OUiL0GiO505nGU`2GUiL0GlFG05nGU`1k[Zh0GiNG09NGU`<0GiNG00<0GenG002GG`16AV800P0/
;2`01P0/0000;2`/02`/;00/;2`05R`F000000<0;2`/0P0002`00`0F5R`0;2`/000/000302`/;003
0000;00F;1H00000008000000`0/;2`00`005P00;2`/000/000402`/;00<01H/5P0002`002`0000/
000/;2`002`004T0000002`0B@0002`00000;00000000P0/;2`0300002`002`0000000000000;000
000/000/;2`0000002`/;00/000002`002`000D000000P0002`20000000602`/;00F5P00;0000000
000/000000000P19BDT00`0F5R`0;2`/02`/;002000/0080;2`/00@09AH0000/000/000000002?oo
ool000Kooooo00D0GiNG05nGa@2GaLD0WkJf0<G5a@030=CDe0090<G5a@2f][H0aLG50>7Qh@2GaLD0
GiMO05nGU`2GUiL0YjNW0080][Jf00L0aLG509NGU`25QHD0YjNW05nGU`2GaLD0YjNW00<0GiNG00/0
aLG_0:NWY`2WYjL0UiO50=CDe02f][H0aLG50=CDe035knl0][Jf08>OW`030;Jf]P0F05nGU`2GUiL0
Lg=c05ADE01OGel0GiMO05mOG`00Gel0BDU9001OG`0`Nc0009MO04U9B@1OG`00;2`/05mOG`00Gel0
E5@U0;Jf]P2GaIL0GemO07=cL`D0GiNG0180UlFG05nGU`1OaIL0][Jf0;jn_P2GUlD0UlG50:NWY`1O
UlD0UiNG002GU`2WYjL0UlG509O5U`1OaLD0UiNG05nGU`00UiL505nGU`0305nGa@2GUiL0<99k0080
GiMO0P00Uel01P1OGel009MO002GU`00Uel005mO001OU`@009MO00`0<7]O05nGG`1OUel0GemO001O
G`00UiL009MO032GG`00UiL0GiMO07=cL`1OGiL205nGU`04002GU`00Gel009MO002GG`D0GiNG00D0
QHF505nGU`1OUiL0GiNG08F5Q@0605nGU`0509O5U`1O[Zh0UlFG09NGU`2WYjL00P2GUiL00`2WYjL0
UiNG09NGU`030:NWY`80UiNG00<0WinO09NGU`1OUiL00`1OUiL00`1cLg<0GenG05ADE00202`/;003
02`0000/;2`0B@0000<0;2`/00X0;000000/000/;2`0000/02`/;0005P00000004T0000/;2`0000/
0P0/;2`0200F;1H0B@0002`0000/0000000002`/;000;0005P000`0002`202`/;0030000;00U01H0
02`0008002`000P0000002`0000002`09@0F0000;000;000;00002`/;080000/00/00000000/0000
;000;0000000;00/000002`0000F5P00;000000/000/00040000000;01H05P000000000/02`00000
02`000000000;00F0000000002`0000002`00`000000100F;1H002`00000;00/0002000/000502`0
00005QH00000000/000000002?ooool000Kooooo0P1OUiL07P00UiL0GiNG0>7Qh@3De=@0kno50<G_
k`35aLD0hN7Q0<g=c@35aLD0klG50;Jf]P25QHD0GiMO08F5Q@2_[jl0][Jf0:NWY`2GaLD0YjNW09O5
a@3oklD0j^;=0<G5a@2f][H0YjNW09NGa@2f][H0GiNG0:Nn_P80][Jf00<0hN7Q0<G_k`35aNl00P2f
][H04023Wil0UlG50<G5a@2GaLD0hN7Q0<G5a@2WYjL0<7]k05nGU`1OGel0Lg=c08F5Q@00Gel0Lg=c
02ED9@19BDT2001OG`80GemO00D0GiMO02EN9@00Gel005mO07=cL`0205nGU`0307=cL`2WYjL0GiNG
0080GiNG00@0GiO505nGU`1OaLD0WkJf0P35aLD20:NWY`0305o5U`2GaLD0WkJf00<0YjNW1@1OUiL0
0`25QHD0YjNW05nGa@020:NWY`0408F5Q@00UiL0GiNG002GU`80GiMO00H0GemO002GG`00Ug/005mO
002GG`1cLg<2001OG`0505mOU`1OGg/0UiNG05nGU`2GUiL00P1OUiL01@00Uel0Gg]O002GU`1OUiL0
GenG00<0GiMO00@0<9Mk002GG`00Uel009NG0P1OUiL01000UiL0<9NG05nGU`1OaIL305nGU`0505nG
G`0`UiL0GiNG05nGU`2WYjL00P1OUiL00`2GUiL0NjjG09NGU`020:NWY`040;Jf]P2GaLD0UlG507^^
[P<0YjNW0P2GUiL0102GaLD0NiNG05nGU`2GUiL305nGU`0305mOU`1OUiL0ATI60080B@0000`002`0
02`/;00/;2`0;2`/02DF0000;000B@00000/00190000;2`/000/000F5P02000/000<04T0000/;2`0
000/02`/;00F0000000/02`0000/;2`0;0000000;019BDT001HF1@0/;2`00`0002`05QH/02`/;002
02`/;0060000000/0000000/00005P0002`000000P0/00000`00;000;2`/01H05P0202`/;00802`0
000002`0;0000000000F0000;00002`/;000;00200000004000/000/;2`05P0F02`00080000/00h0
;000000/00000000000002`/;0000000;0000000000/;2`002`001H/5P0/;2`000000000;0<002`0
00@0;2`/0000000002`002`02?ooool000Kooooo00L0YjNW002GU`1OUiL0J[Jf0=CDe02f][H0GiO5
0080YjNW0P35aLD03P2GaLD0YjNW0<G5a@2GUel005mO09MOG`0UL5@0GiNG04U9B@25QHD0aLFG09O5
a@3De=@0cLg=0`3De=@20<G5a@050;Jf]P35aLD0UlG50<G5a@3De=@00P2f][H01035aNl0aNo_0<gR
hP2f][H20=CDe0060<G5a@2f][H0YjNW05nGG`25QHD0GiNG0P1OGel03P1OaLD0][Jf02EDE000UiL0
05mO05nGU`19BDT0GemO001OG`19BDT0QHF505nGG`1OUiL0QHF50P2WYjL0202n_[h0YjNW05nGa@1O
aIL0e=CD0;Jf]P35aLD0fm>n0`35aLD0102f][H0UiNG0:NWY`2OWkH20:NWY`80GiNG00@0UlFG05nG
U`1OUiL0QHF50P1OUiL04`1OaLD0YjNW08F5Q@0`Ug/0QHF505nGG`00Gel0Lg=c002GG`1cLg<0GiMO
05mOG`00Gel0GemO001OG`1OUiL0GenG05nGU`2G[YL00P2GUiL01P25QHD0GiNG05nGU`1OGiL0GiNG
002GU`80GiNG0P1OUel0101OUiL0Gg]k05nGG`00UiL205nGG`03002GU`1OUiL0LXj>0080GiNG00@0
UiNG05nGU`1OUiL0GiMO0`1OUiL0202GUiL0GiNG0:NWY`2WYjL0PinO09O5a@2WYjL0UlFG0P2WYjL0
2@2GaLD0PkJf09NGU`2WYjL0GlG505nGU`1OUlD0YjNW07^GU`0305nGU`0709NGU`1OUiL0QHF505nG
U`0FATH002`002`/;002000/0080;2`/0P00;00202`/;00602`0000/;2`0000/01H/5P0/;2`002`0
0P0/;2`01000;000000001H00000;0020000;004000/000/;2`002`001H/5P80;2`/0`00;0020000
;00302`/;000;000;2`/008000000140;00002`F5P19000000000000;000000002`00000;00001H0
000/0000000/000000000000;00/00005QH0000/000202`/;005000/000002`000000000000/0000
0P00;000400/;2`0000/0000;00/000001HF0000000/000002`000000000;000;2`/00005P000000
02`00000000002`202`/;004000/000/00000000000000Sooooo0006ooooo`0>002GU`1OUiL0YjNW
0<G5a@2GUiL0aLG50:NWY`1OaLD0GlFG05o5a@2W_[h0aLG50;Jf]P2GUlD209NGU`0<05mOG`1bLW80
05mO001OG`2f][H0hN7Q0;Jf]P2GaLD0aLG50=CDe035aLD0][Jf0`35aLD01@35f/D0][Jf0=CDe035
aLD0aNo50080aLG500@0][Jf09O5a@2f][H0][Jf0P35aLD00`2f][H0e=CD0:n_[`0209NGU`0509NG
G`00Uel005nG001OG`0`UiL00P00Gel03`1OUel007<004U9B@00Gel0Gg]O002GG`00Gel0GiO505o5
U`1OUiL0][Jf0=>n_P3QhN40][Jf09O5a@030<G5a@040>oJa@3De=@0][Jf0<G5a@80][Jf00@0GiO5
07_5a@2GaLD0UlG50P1OUiL00`00UiL0GiNG032GU`0305nGU`80UiNG00D0GlG509JFUP1OGel0GiNG
002GG`0405nGG`0805mOG`00UiL0GemO05mOG`1OUel0YjNW05o5U`2WYjL209NGU`<0GiNG00D0GiMO
05nGU`1OUiL0GiNG05nGG`0205nGU`0605nGG`00UiL009NG002GG`1OGel0Lg=c0P1OUiL00`0`Ug/0
GiNG05nGU`0305nGU`0:002GU`1OUiL0YjNW05nGU`1OaIL0GiNG0:NWY`1OUiL0YjNW0;Jf]P<0YjNW
00<0UlG50:NWY`2WYjL00P2WYjL00`1OUlD0GlG505nGU`0209NGU`80GiNG01@0UiNG05mOU`1OUiL0
GiNG05nGG`19BDT0;2`/0019000/0000;2`/0000;00/0000;1HF02`00000;000;2`/0000;0000000
B@0002`F5P80;2`/00H002`002`/;0000000000001H0000002`202`0000602`/;0000000;000000F
5P000000;0000P0/;2`04@0002`0;2`/01HF;019000002`00000;0000000;0000000;00F01H002`0
02`/;0000000;00002`/;000;0005QH00080;00000D0000002`/;0000000000/00005P02000/0003
02`/;000000002`0008002`000D001HF0000;000;000000/000000020000;00902`/;0000000000/
02`000000000;2`/05nGU`0F;1H000000080;2`/0P00;0000`0/;2`05R`F02`00002000000Sooooo
0006ooooo`0408F5Q@1OUiL0UiNG0:NWY`80GiNG01<0UiNG0:NWY`00UiL0QHF509:^[P2f][H0YjNW
09NGU`25QHD0][Jf05nGG`2WYjL0GiNG09O5a@2GaIL0UiNG0:NWY`2f][H0_[jn00D0aLG500<0hN7Q
0=CDe03De=@00P3De=@06`35aLD0UlG50;Jf]P2GaLD0Rkjn09O5a@1OaLD0UlG50;Jf]P1OUiL0UlG5
08>OW`1OUiL0GiMO002GG`1OUiL0YjNW05nGU`00Gel0GiMO002GU`1OUel0BDU905mO0000Gel007]k
05mOG`0205nGU`0609NGU`2f][H0aLG50<GJa@35aLD0e=CD0`2f][H20<G5a@060=CDe035aLD0aLG5
09O5U`2GaLD0][Jf0P2WYjL205nGU`0408F5Q@00UiL0GiNG002GU`@0GiNG00d0GlFG05nGU`23Wh<0
05nG05nGG`1OGiL005mO002GG`1OUel0Lg=c06UYQ@1OUel009MO0080GiNG00L0UiNG0:NWY`23][H0
GlFG09NGU`1OUiL0QHF50080GiNG00<0Gg^G05nGU`1OUiL00`1OUiL02`1OaIL0Gg]k002GG`00Uel0
09NG05nGU`25QHD009MO05nGN`1OUiL0GiO500@0GiNG00<0PinO05nGU`25QHD0101OUiL209NGU`03
05o5U`2GaIL0YjNW0080][Jf0P2GaLD0201OUlD0GiNG05nGa@2GUiL0GlG509NGU`1OUiL0GenG101O
UiL01@1OGel05TI60000;00/;2`002`000<0;2`/00L05R`F02`/;000;000;2`/00000000;000000/
0080;0000100;2`/000/00000000;2`/07=cL`0F;1H002`000000000;000;0000000;000;0005R`F
02`000190000000/0P00;0001@0/;2`05QH/0000;00/0000000/008002`000X00000000F5P00;000
02`002`00000;000;2`/000/00005P0002`0100000001`0/;2`0000F000/0000;000;000000/0000
00000P00;0020000;00<0000000/0000000002`0000002`001H002`000000000000/000/0019BDT0
aLFG0`00;000200/;2`00000000/000/;2`05QH/0000;00/;2`000002?ooool000Kooooo00L0TZjG
0:j^N`2G[Zh0DXEg001ON`0jQFT0Gg]k0080GiMk0100Gg]O07UiN@1`L700Ng]O06MWI`1ONc00<6T`
031D<01DHU@0<5l`001kG`1YJFT0RjNW0;Jf]P35aLD0c=O<0P35aLD01P3JaLD0cLgR0<g=c@3=cN80
dM_A0=CDe080fm_K01D0c<c<05n^U`0`UiL0][Jf05JGU@1kTY80GiNB05nGU`2n_[h0aLG507^^[P2E
^[X0Pin306UYJ@1kTYL0Gg^G05nGN`1lO7`0?W]k06UYJ@0jLcX00P0`Gc000`0`Gel007^G032GK@02
05nGN`0907:>SP23Pil0Pinf09N^[P2f`/80c<c<0;cCd`2^aLD0_[jn0080cLg=00X0f][50=[5a@3J
fZh0_[jW0;Jf]P2WYjL0GlF^09F_^P1k[Zh009NG0P1OUiL02000UiL0Gg^G0329U`1OUiL0Njj^05n^
[P1k[Zh0GiNG0P0`Ng/205mOG`0F032GN`0`Ng/007]O001kN`1OUg/0DWN5032GU`0`Ng/0C7^G05BO
W`23Wil0NiNG07^S[P23]Yl0SXj>05n^[P1O[YL0@hj>05nGU`1oYi/0Pinf032GU`80GiNG0P0`UiL0
101ORHT0GiNG032GU`1OUg/205mkN`08032GU`1ORJ<0PinO07^GU`23WkH0NiNG05nGU`23Wil209nO
W`0G08>OW`1k[YL0GiNG05nGU`1O[YL0KJ>G07:>SP1k[YL0GiNG07^^[P2W_[h0WkJO09^b/P2GaLD0
Njk505n^[P1OUlD0GiN^05nGU`1]UiL0NiNG05nGU`1kUiL00P1OUiL00`1ONiL0Lg=c0492@P0202`/
;00801H/5P0/;2`0;2`/01HF;00Q5P/0000/02D05P005P0201HF000>01H0000;8@/05QH000005P00
;0000000000F000k00004b4001H/5P005P009@0001H05P0/;2`201H/5P0:01H05P005P005QH002`/
;0005P0002`000//2`0/;2`05QH0000/00805QH/01<05P0F00/F2`0k000001HF000/000F01H05P00
000F00008@005QH002`/;00F5R`00000000F000F;1H05P/F000F000F5P00000000805R`F00@002`0
02`F5P0;;0/05QH00P0001H03`0000005QHF01HF000F00/001H00000000001H05QHF000/00000000
2aH;01HF5P005P00;2`/02DF000201HF;00401HF2`0F00009AH0000F00Sooooo0006ooooo`0N09O5
U`2GUiL0QHF507^GU`1OGel005l0001OG`19BDT0Gel004U9B@1OUel0Gel004U9B@00B@00Gel005mO
G`19BDT0<5@004U9B@00Gel0GemO07=cL`2GaLD0e=CD0<g=c@3QhN40][Jf05nGU`2GaLD0e=CD0P35
aLD0103_klD0hN7Q0<G5k`3De=@20:NWY`0309O5a@23Wil0GiNG008005mO00<0GiNG0:NWY`2WYjL0
0P1OUiL01P2GaIL0GemO002GU`00UiL005nG031kU`8009NG00H0GenG001OG`00Gel0GemO03YYJ@25
QHD505nGU`0305n^[P2GaLD0UlG50080aLG500`0aLG_0<G5a@3=cLd0klG50;Jf]P2WYjL0GlG505o5
U`1OUiL0NiNG05o5a@1OUlD605nGU`0605o5a@1OUiL0GiO505nGU`00UiL009Mk101OGel01000Uel0
05mO05nGU`1ONiL605nGU`0305mkU`1OUiL0GiNG0080YjNW0P1OUiL00`2WYjL0GiNG05nGU`0209NG
U`0305o5a@1OUiL0GiNG00H0GiNG00@0PkJO0:NWY`2GUiL0YjNW0P1OUiL0102WYjL0WinO05nGU`1O
aIL905nGU`0909O5a@1OUiL0GiN^09O5a@1OaLD0GiO509NGa@1OUiL0GiO50080GiNG0P1OUlD205nG
U`0408F5Q@1OUel0>c/k04T000@0;2`/0P0/00003P0/;2`0000/04T0000002`002`00000000F01H0
000/02`0000/;2`0;00002`/;000;0005R`F0P00;000300/;2`0000/000/000/;2`05R`F000/0019
BDT004T00000;0000000B@0001HF;080;2`/0`00;0000`0/;2`09@0F02`00002000/00060000;000
0000000001H/5P000000;0000P00;00202`/;080000000@002`00000000/;2`0;2`/0`00;00202`0
008002`000D0;000000/00005P0000000000;0040000000401HF000/;2`0;2`/02`/;08002`000D0
;2`/01HF5P0/;2`0;2`/0000;008ooooo`001_ooool01P2WYjL0][Jf001OG`2WYjL0GiMO001OG`80
Gel000H0GiL0001O000UGRD0BDU9001OG`0/;2`204U9B@09001O000k>c/0;2`/04U9B@1OG`0009NG
09NGU`2WYjL0h/g=0080aLG500@0UlG505nGU`3De=@0e=CD1035aLD01`3QhN40e=CD09O5a@1OUiL0
Pin304U9B@00Gel00P00UiL0302WYjL0UlG50:n_[`2WYjL0][Jf05nGU`1OGel0Gel0001OG`0UL5@0
05mO002GU`8005nG00@0GemO001OG`00GiL005mO0P1OGiL02@00UiL0GiNG05nGU`0`Ujh0UlG505nG
a@1OaLD0UlG50<G5a@020>o_a@060<G_a@2GaLD0YjNW09NGU`2WYjL0UiO50P2WYjL205nGU`0605nG
a@2WYjL0GiO507^^[P2GUiL0GiNG0P1OaLD0101OUiL0GemO05nGU`00Uel205mOG`060:NWY`00UiL0
GiNG002GG`1YQHD0GiNG0`00UiL02P00Uel009NG06V5Q@1OUiL0UiNG0:NWY`2GaLD0GiNG05o5a@1k
[Zh205mOU`05002GU`2WYjL0YjNW09NGU`1OUg/00`00UiL305nGU`0808>OW`2WYjL0YjNW09NGU`1O
aIL0GiO509NGa@2OWil605nGU`0:05nGN`1OUel0GiNG05nGU`1OUlD0UiNG05o5U`23WkH0GlG505nG
a@80GlG50P1OUlD00`1OUjh0UiNG05nGU`0305nGU`0305mOU`1OGel0>c/k00D0;2`/00L0000/02`/
;00/;2`0;2`/000/000002`0B@000080;2`/00P0000/02`/;0000000;000000/000/000001H002`/
;080;00000D002`002`/;00002`05R`F02`/;003000/00030000000002`05P0F0080000/0P00;000
0`0/;2`002`001HF0002000/000902`0000002`0000002`0000F5P00;000000/000/0000000/0080
02`000H05QHF0000;000;000;00002`/;00002`2000/0003000F5P00000002`0008002`00P0/0000
3P0001H0;0000000;000;000000/00000000;0005P0F0000;00/;2`0;00000000000;000000/0P0/
;2`00`000000;2`/ooooo`07ooooo`001_ooool01@25QHD0BDU9001OG`0`Ng/0UiNG0080Lg=c00@0
Gel004U9B@00B@005THF0P19BDT01000G`00GemO05mOG`1OGel304U9B@8005mO0P1OUiL30<G5a@05
09O5a@2f][H0][Jf09O5a@3=cLd01035aLD01@2f][H0e=CD0<G5a@2W_[h0GiNG008009MO0180GiMO
002GU`2GUiL0Ph>O0<G5a@35klD0klG508F5Q@1OGiL0BDU903/k>`1OUel009NG001OG`00UiL0GiMO
002GU`0`Gg/4001OG`0:07=cL`1OUiL0<7^^07=cL`1OUiL0YjNW0=CDe035aLD0klG50?O_[P80aLG5
00D0UlG505o5a@1OUiL0UiNG05nGU`02002GU`0309O5a@2f][H0GlG50080][Jf00<0UlG505nGU`1O
UiL00`1OUiL02P0`UiL0Lg=c001OU`00GiL009NG05nGG`1OGel0GiNG05nG[P1OUlD205nGU`8009NG
00@0GiNG07^^[P2WYjL0GiNG0P2GaLD00`1OUlD0GiNG032G[P0405nGU`80GiO50`1OUiL01P2GUiL0
GiNG05nGU`1OaIL0WinO09NGU`80YjNW0`1OUiL00`1O[Zh009NG05nGU`0805nGU`060:NWY`2GaLD0
GiNG08^W_P1OaIL0GlG50`1OUiL00`1OUlD0Gjk505nGU`0205nGa@0505mOU`1OUiL0GenG05mOG`0k
>c/0100/;2`00`00;000B@0001H05P0202`/;08002`000<0;2`/0000;00F5P00100/;2`01000;000
;0000000000/0003000/000:0000000/00005P0F02`00000000002`002`/;000;000;2`/01HF;080
;2`/00P002`00000;000;000;2`/01H/5P000000;2`/0000;080;00000D002`001H/5P00;000;2`/
02`00003000/000901H/5P0/;2`0;2`/000/000002`0;000000/000/0000000F0080000/00h002`0
02`0000002`002`001H000000000000/0000000/000002`00000;00F01H0;2`/000/00<0000000D0
;2`/03/F5P0/;2`0;2`/00000008ooooo`001_ooool03`1OGiL005mO001OG`0`Gel0][Jf09O5a@2G
aEl005mO07=cL`1OG`009DTU05mOG`19BDT0Gel00025000205mOG`0904U9B@00B@00BDU905nGU`00
Uel009NG05nGU`1S[/<0YjNW0080aLG500`0][Jf05nGa@1OUlD0T][J09O5a@2f][H0UiO509O5a@35
aLD0][Jf09O5a@2fcLd205nGU`0<002GU`1OUiL009NG05nGG`1ONel0UiO50<G5a@3_aLD0][Jf09NG
U`1OUel0JFV50P1OUiL01@1OGiL0GiMO05mOG`00Uel009Mk008009MO00T005mO002GG`00GiL005mO
001OU`00Uel009NG05mOU`1OaLD00P2GaLD0102f][H0UlG50;Jf]P2GaLD205nGU`0305mOG`1OUiL0
GiNG0080GiNG0P1OUlD04@35aLD0][Jf05nGU`1OUiL0GenG07=cL`00GiL009NG08^WY`1OGiL009NG
001OG`00GiL0Lg=c05nGU`00GiL0Gg^G008009NG00l0GenG05nGU`1OUiL0GiNG07^G[P1OUlD0UiNG
05nGa@2GaLD0YjNW05nGU`2WYjL0QHF505nGU`00UiL00`1OUiL01`0`UiL0QHF505nGU`1OUiL0UiNG
05o5a@2GUiL00P2WYjL205nGa@06002GU`1OUiL0GlFG032GU`1OUiL009NG0`1OUiL02@1OUel0NiNG
05nGU`1OUiL0UiNG0:NWY`2GaIL0GiNG07_5a@0205nGa@0505o5a@2WYjL0GiO505nGa@1bSXh00P2G
UiL305nGU`03001OU`19BDT0;2`/0080;2`/00L0B@00000/000/;2`0;2`/000F000/;2`002`00080
;2`/0P00;0000`0F5P00;2`/02`/;003000/000302`0000F5P00;00000<0;2`/00L0;0000000;00F
5R`0;00002`/;000;000000/008002`000@05QH/000/0000;000;0000P0002`00`00;00001H002`0
0003000/000302`/;000;0005P000080000/00H0;000000/000/;2`0BDU901HF;000;0020000;006
00000000;000;000000/000F0000000/0`000000200/000002`0000F5P0/000002`002`/;00002`0
02`00P0000002000;000;2`/02`0000/;2`0;0000000001D9BD002`00P000008ooooo`001_ooool2
05mOG`0405nGU`0k>c/0YjNW09NGG`<0GemO00/005l004U9B@00G`0007<0001OG`00Q@00GemO002G
G`0UE5@0Gel0002GG`03001OG`05002GG`1bLXh009NG0<G5k`2f][H00P2WYjL00`1OUlD0RjNn09O5
a@0205nGa@0909O5a@1OUlD0UlG50;Jf]P1OUjh0YjNW0<FGU`2WYjL009NG008005mO00l0JFUY07=c
L`2GaLD0aLG50=CDe035klD0][Jf07^GU`1OUlD0GiNG05mOG`1OGiL0GemO002GG`00Ng/00P00UiL0
1`00GiL009NG002GU`00GiL0<7]k05mOU`00UiL00P1OUiL0102WYjL0GiNG09nO]P35aLD20;Jf]P05
09O5a@2GUlD0YjNW09nOW`1OUiL00P1OUlD00`1OUiL0GiO50<G5a@0305nGU`0505nGG`1OUiL0GiNG
09NGU`1OUiL00P2GUiL01P25QHD0GiNG05mOG`1cLg<0GenG07^G[P80GiNG00h0GlG505nGa@2WYjL0
YjNW08^nY`1OUiL0GiO50;Jf]P2GUlD0aLG505nGU`2OWil0GlFG0:NWY`80GiNG0P1OUlD205nGU`07
05nGa@2WYjL0][Jf09O5U`2GaLD0YjNW09NGU`0305nGU`04002GU`1OUiL0GiNG002GU`<0GiNG00X0
09NG05nGU`1OUiL0GiNG09O5U`2WYjL0GiNG05nGa@1OaIL0PkJf0`1OUlD01P2WYjL0GiO50:NWY`1O
[/D0UiNG08F5Q@<0GiNG00<0GenG001OG`0FAQH0100/;2`20000;00301HF;000;00002`000<0;2`/
00<002`001HF5P0/;2`00`0/;2`00`00000002`00000000202`/;0070000;00/;2`0;0000000000/
;2`0000/000/000200000080;2`/00D0;1HF0000;00/000002`002`/;002000/000501H0000/0000
00000000000/00000P0/;2`00`005P00000/02`/;002000/0080000/00D000000000;00/;2`0;2`/
02`00003000/000=0000;000;00002`00000;0000000000/0000000/;2`0000/000/00000000;000
000/0003000000<0000/00@00000000/000/;2`002`00P000008ooooo`001_ooool0202WYjL0GiMO
09NGa@23Pe@0;2`/001OG`1OUel0GemO0P1cLg<0201ONel0GemO04U9B@1OG`00GiMO04U9B@00Gel0
<5mO1P00Gel01`0UL700GemO08F5Q@2WYjL0GiMO09O5a@1OUiL00P35aLD05`1OaIL0][Jf05nGa@1O
UlD0GiNG0:NWY`23Wil0UiNG09O5a@35aLD0][Jf0:NWY`1OGel09EAD05nG001OGiL0YjNW0<G5a@2f
][H0aLG50:n_[`2WYjL0UiNG00<0GiNG00H0Lg=c002GU`00UiL009NG001OU`1OUel205mOG`05031O
G`00GiL0GiNG05nGU`1OUlD00P1OUiL0402JcLd0aNo50=CDe02GaLD0UiNG09O5U`1OaIL0<9N^05nG
U`00UiL0GiNG09O5a@2f][H0UlG5032GU`00GiL305nGU`0?0:NWY`2GaLD0GiN^05nGU`00UiL0GiMO
05mOU`1OUel0GiNG05nGG`1OUiL0GenG002GU`1OUlD0YjNW0080GiO500<0][Jf0<G5a@2GaLD00P2G
aLD01`2f][H0UiO507_5a@1OUlD0YjNW05o5a@1OUlD01@1OUiL40:NWY`0708>f]P2WYjL0GlFG05nG
U`00UlD0GiNG002GU`0305nGU`05002GU`1cLg<0GiNG002GU`1ONiL00`1OUiL0101OaLD0YjNW0:NW
Y`1O[/D305nGa@0705o5a@1OUlD0GiO507^GU`2GUiL0GiNG09NGU`0205nGU`0405mOU`1OGel0>c/k
02`/;08002`00`0/;2`01`0F5QH002`000000000;000;2`/0000;00/00000P0/;2`01P00;000000/
000/0000;000B@00000/0080;2`/00D0;000000/00000000B@0001HF;00202`/;008000/00000000
;0000000000F5R`0000/000/000/000202`/;0050000000k5QH002`00000;00000000P00;00202`/
;004000/000002`0B@000000;080;00000T05R`F02`/;019BDT0000/0000000/000002`00000;000
5QH00P00;0000`0/;2`002`0000/0002000/0080000000P0;0000000000/;2`0;000000F5P0/;2`0
000002`/;08002`000<0B@00000/0000;0000P0/0008ooooo`001_ooool02P3JaMX0[Zk305nGU`1a
Vhd0YHib031Y<01DL5@0GiMO05ADE01ONc0205ADE00M04U9B@1DE2D0GemO05ADE00`Gel066e]001k
G`1DE5@0<7]O04U9B@0`Gel007]O01Q]K@0`Ng/0GenG08^WR`0`Gg/0<7^G06ZJ]P1Q[Zh0Njj^07^G
U`2=SHd009MO08^W_P1OUiL0Njj^05nS[P1OUiL00P0`UiL06@1kUiL0Gjj^09b5Q@1DHSd0Gg]O032G
N`1OUjh0GiO507^^[P2^aLD0UJj^0:k5a@1k[Zh0Njk50:NWY`2OWil0YjNW07V^[P23Wil0<7]k05nG
U`1kUg/0Gg]k05nGG`0HNiL00P1OUiL09023WkH0GiNG07^^[P2;YjL0Nj>j05n^[P23][H0][Jf08^n
_P23Wil0GiNG05nGX`1OUjh0Gjj^09:^[P1OUiL0Gjj^08>OW`0`RIL0E9nO08>OW`2OWkH0Njj^09:^
U`23Wil0LI^K05mkN`0`NiL0<7]k001kU`0`Ng/0LXj>032GU`0`RHT0Gg^G05nGU`80PinO00D0Njk5
0:Nn_P32`/80UlG50<G5a@020;jn_P0:09O5a@2f][H0UJ>S07^GU`23WkH0WinO07^G[P1OUiL0PinO
05nSX`<0GiNG00@0Pin309nOW`1kUjh0KJj^101OUiL00`0`UiL007]k05n9U`0305nGU`0D05mkU`0`
UiL0GiNG04RSU`1O[/D0PinO09nOW`1kUjh0GiN^08>f]P2E[j<0GiNG09NGU`1kUjh0GjjG05nGa@1k
UlD0KJ>j07^GU`2GUiL305nGU`0305mkN`0UE5@0@T9200805R`F0100>aHF01H/5P0F;1H05QH001H;
000F5P00>`0001HF;000;0005QH002`F5P0F2`/05QH/0000000U00005QH/0P0F;1H03`002`00000F
0000000002`09BD0000F000F;1H08B`Q01H05P0/000001H002`F5P0F5P005P0000/Q5P0201H/5P08
01H0000F5R`001H001H0000;00/09AH001H/5P0F5R`302`/;00=01HQ8@0002`0000/02`/;000;000
;0000000;00F2b405P0F01HF5P0F5R`05R`F01HF0002000/0003024Q5P0F;1H001H000<001H000`0
5P0001H;5P005P005P0001HF00005QH0000001HF000;5P/0000001HF5P0F;1H2000/000501H/5P0Q
2`/05P0000005P0F00002?ooool000Kooooo00@0e=CD0<G5a@1OGel0<5l00`0/;2`304U9B@0503/k
>`00G`00BDU9000/000/;2`00P1OGel4001OG`0:05mOG`1cLg<009MO05mOG`1OUiL009NG001OU`1O
Uel0GemO001OU`80GiNG00X009MO002GU`00GiL005nG002GG`00UiL0<7^G09O5a@00GiL005mO0P1O
Gel00`00Gel0<7]<05nGU`0505nGU`0509nOW`1OUiL0GiNG09O5a@2GaIL00P2GaLD02023Wil005nG
05nGU`25QHD0YjNW09NGU`1OUiL0GjjG0P1OUiL02`2WYjL0UlG505nGU`00UiL0YjNW0;Jf]P1OUlD0
YjNW05nGa@1OUiL005nG00L0GiNG00D0Rkjn09O5a@2GUlD0YjNW002GU`0305nGU`0308F5Q@1OUiL0
GiNG00<0GiNG00d005mO09nf]P2WYjL0YjNW09O5a@2f][H0UlG50;Jf]P2n_[h0][Jf09O5a@2f][H0
aLG50080][Jf00T0PkJf0:NWY`1OUlD0GlFG05nGa@2GaLD0UiNG05nG[P2GUiL00P1OUiL209O5a@03
05o5U`1bSXh0GiNG00<0GiNG00@009NG05nGU`1OUiL0QHF51P1OUiL03`2WYjL0GiNG05nGU`2GUiL0
GiNG05o5U`2OWil0GlFG05nGU`1OUlD0GiNG05nGa@1OUiL0GiN^0:NWY`0205nGU`0305nGa@1OUiL0
GemO00L0;2`/00X0000001H/5P0/;2`002`00000;000;000000/000/00005QH0;2`/0`0002`02P0/
;2`002`001HF5P0/;2`0;0000000;01cLg<0B@00000/000F;1H2000/00080000000002`0000002`0
000F;1H0;0000000000002`202`/;003000/000F0000000/00<0;2`/0P0002`010000000;2`/02`/
;00/;2`202`000070000;0000000000/0000000/;2`002`002`/;0020000000?02Dk9@0/;2`0;2`/
0000;000;000;0000000;0005P00;000000/000/;2`0000002`0000002`05P000080000000@0000/
000/000/;2`002`00P0002`00`0/00000000ooooo`07ooooo`001_ooool02P3De=@0][Jf04U9B@16
ATH0001902`/;01OG`00;2`/00190000L`0502`/;003001OG`1OGel005mO00<005mO00/0GemO04U9
B@1OGel0GiMO001OG`1OGel009MO04U9B@00GiL009MO05mkTP0205nGU`0D001OG`00UiL005nG002G
U`00Uel009NG05nGU`1cLg<0GemO001OG`19BDT0GemO05BOW`1OUiL009O5002GU`1OUiL0GemO05nG
G`1YQHD205nGU`0D07=cL`1OUlD0GiNG05mOU`1bSXh009NG05nGU`2GUiL0][Jf0:NWY`2GUiL0WinO
09NGU`2WYjL0UlG505nGU`1OUlD0GiNG07^^U`1OaLD405nGU`03002GU`13SXh0GiNG0080GiNG00H0
GlG50:NWY`1OUiL0_[jn0:NWY`1OUlD305nGU`030:NWY`2;YjL0GiNG0080GiNG00`0UiNG05nGU`2G
UiL0QHF50:NWY`2GaLD0aLG50>o_a@35aLD0klG50;Jf]P3=cLd20;Jf]P070=CDe035aLD0][Jf0<G5
a@2W_[h0YjNW09O5a@040:NWY`0409nOW`2WYjL0GiNG05nGU`80UlG500T0UiNG05nGU`1OUiL0GiNG
05nGa@1OUiL009NG05nGU`00UiL01@1OUiL00`1OUel0NiNG05nGU`0209NGU`0805nGa@2WYjL0GiNG
08>O]P2GUlD0UiNG05nGU`1OaIL205nGU`0605nG[P2GUiL0YjNW05nGU`1cLg<009NG0P19BDT00`0F
>aH002`002`/;00202`/;0060000;00/;2`05QH002`/;00002`0;2`/0`0002`02`00;000;00002`0
0000;000;00002`/;00000005QHF0000;0000000;00000<002`000<05QH/000/000000000P0/0000
1@00;000000000005P00000002`000@0;2`/00P05R`F04T0000002`002`00000;000;000;2`/0000
00<0000/0P0000020000;080;2`/0P0000030000;00:000F5P0/;2`0;2`/02`000000000;2`/0000
;00F0000;2`/0000;080;2`/00H002`0000000005P00;0000000000/0002000/00050000;00F;1H0
02`00000;00/00002?ooool000Kooooo00@0e=CD09O5a@1OUel09E@U0P0/;2`01@00G`00;2`/02`/
;00/;2`0BDU900<0;2`/00<004T005nGU`00Gel00`00Gel03`1OGel005mO001OG`1OGel0E5AD001O
G`00UiL005nG05mOG`00Gel009MO002GU`1OUiL0UiNG002GU`02001OG`80GemO00P0<9MO05mOG`1O
GiL0GiMO02`/;000Gel009NG032GU`80YjNW0100GiNG05mOG`00Gel0Lg=c032GU`1OUlD0UiNG05nG
U`1OUel0GiNG05mOG`00Nel005mO001OU`00Gel009NG0P1OUiL00`23Wil0GiNG05nGU`0205nGU`04
002GU`1OUiL0<9N^05o5U`D0GiNG00/0Gg^G002GU`1OUiL005nG05nGU`2GaLD0aLG_0:k5a@2GUiL0
GiNG05o5U`0305nGU`0305n^[P2GaIL0UiNG0080GiNG0P2GUiL00`1OaIL0Njj^0;Jf]P020;Jf]P<0
aLG500<0[/G50<G5a@35aLD00P35aLD0102GaLD0][Jf09nf]P2GaLD20:NWY`0809NGU`1OUlD0UiNG
07^^[P2f][H0UlG50;Jf]P1OUiL205nGa@X0GiNG00D0GiMO05nGU`1OaIL0GiMO07^GU`0209NGU`07
0:NWY`1OUiL0GiO509NGa@2OWil0GlG50:NWY`0209NGU`80YjNW00L0NiN^05nGU`1OUiL0GiNG05nG
a@00Gel0BDU900D0;2`/0P00;000200/;2`05QH/02`/;0190000;000000/000/;2`0000/0P00;000
200/;2`0;000000/000002`0000001H/5P0002`0;0000P0000001@0/000002`001H/5P0/00000000
0080;2`/0P0000001@0F000000000000000/;2`0000/0080;2`/00<05QHF00000000;0000P000000
0`00;000;2`/03/F5P020000;00602`/;000000002`002`0000001H002`00P0000003`0/0000000/
00000000;0005R`F02`/;00002`0;0000000;000000002`001HF;0000000;0000000;00202`/;00<
00000000;000;2`/0000;000;000000002`0000000005P000000000002`000002?ooool000Kooooo
00@0aLG50:NWY`1OGel0>c/k100/;2`00`1OGel0BDU902`/;00302`/;005001O0000Uel009MO031O
G`19BDT00P1OGel3001OG`0305mOG`00Gel005mO008005mO0P00UiL02@0`UiL0GiNG05o5a@1OUiL0
09MO07=cL`00Gel0GiMO031`<0020019000J02`/;02WYjL0GiMO05nGG`1ONg/0GiO509O5a@1OGiL0
GiNG05nGG`00UiL007]k001OG`1OGel0Lg=c05mOG`1OUiL0QHF505A`E01OGel005nG001OG`1cLg<0
GiNG002GU`1OUel405nGU`0505mOU`1OUiL0GiNG05nGU`2WYjL00P1OUiL01`1OaIL0GiNG07^^U`1O
UiL009NG05o5U`2GaLD00P2WYjL00`1k[Zh0YjNW05nGU`0205nGU`80aLG500<0[jn_0:NWY`2GaLD0
0`2WYjL00`1OaIL0YjNW0:Nn_P030<G5a@030;Jf]P35aLD0aLG50080aLG500<0][Jf0<G5a@3De=@0
0P2f][H00`2W_[h0][Jf0:NWY`020:NWY`0309O5a@2WYjL0GiNG0080YjNW00P0GlG50:NWY`2GUiL0
UiNG08>OW`1OUiL0UiNG0:NWY`<0GiNG00<0NjjG05nGG`1OUiL0101OUiL0101kUiL0UiNG05nGU`2G
UiL205nGU`0805o5U`1k[/D0GiNG05o5U`2GUiL0YjNW05nGa@1OaLD205nGU`0;05nGa@2GUiL0GiNG
05nGG`1OGel005l002`/;000;000;00002`/;000;0000P0/;2`02@0k5QH0000/0000;000;000B@00
02`/;000;0005QHF02`00003000/0080;2`/00/05QH0000/000002`000000000;0000000000/000/
00000000;0000000000302`/;00400005P00000000000000;080;2`/00H002`0000F000/;2`0;2`/
04T0000/;2`20000;00301H05P0/;2`0;2`/00<002`000<0000/01HF;00/;2`00P0002`2000/000;
00000000;00000000000000/000002`002`/;00/0000;2`/01H/5P0002`00P00;00202`/;0080000
000/;2`0000/02`/;000;000;00004U9B@0/00020000000302`00000003ooooo00Oooooo0006oooo
o`050;Jf]P2GUiL0QHF502E99@19BDT00`0/;2`00`00G`00;2`/02`/;00202`/;00604U9B@0/;2`0
BDU904U9B@0`Nel0GemO0P00Gel01000G`00GemO001OG`0`Nel2001OG`0=001O0000Gel005mO04U9
B@0`Ng/005mO05mOG`1cLg<0GiMO001OG`1OUel0Lg=c01H/5P0202`/;00C04T00000Gel0Lg=c05mO
G`1ONel0GiMO0:NWY`00Gel0GiMO001OG`00Uel0JFUY05mOG`1OUiL0GiMO04U9B@00Gel009MO07=c
L`0305nGU`0405mOG`00Uel009MO032GG`8009MO00<0GiMO05nGU`1OUiL00`1OUiL00`00UiL0GiNG
05nGU`020:NWY`0408j>SP1OUiL0UiNG05nGU`80aLG500@0][Jf0:Nn_P2GUiL0GlFG0`1OUiL02@2W
YjL0Ykjn09O5a@2GUiL0YjNW09NGa@2GaLD0YjNW09O5a@020:NWY`050<G5a@2f][H0aLG50;Jf]P3_
aLD00P35aLD0102f][H0aLG50<G5a@35aLD20:NWY`0309O5a@2f][H0YjNW0080][Jf00D0UlG50:NW
Y`2WYjL0GiO509NGU`020:NWY`0305nGU`2OWil0GiNG00H0GiNG00<009NG07=cL`1OUiL00P00UiL3
05nGU`80UlFG00`0UiMO05nGU`1OUlD0GiNG09NGU`1OUiL0UiNG0:NWY`2GUlD0GiNG08j>SP35UiL4
05nGU`0<04U9B@0/;2`0>c/k02`/;000;000;2`/0000B@190000;2`/0000;000;000;2`/0P00;000
1`0/;2`0000001H/5P0/;2`002`002`/;00002`00P00;0006@005QH002`0000000000000;2`/0000
000/;2`05R`F000/000002`002`002`0000002`0000000005P00000002`00000;00/;2`0000/000/
000U5P0002`002`00000;0000P0/;2`0100002`05R`F0000;00/;2`3000/00040000000F5P000000
04T000@002`000d0;2`/000/0000;00002`00000000002`0;2`/000/000F;1H0aING02`/;0000000
02`00080;2`/00T05QH/02`0000002`0;00000000000;000000002`F5P0002`00P0/0008ooooo`00
1_ooool0802WYjL0QHF505mO000`G`00Gel004U9B@3oool0aIMO0:NWY`3De=@0Y:BL0?ooo`3lo?`0
olFG0?ook`35Uel0Gel005ADE000Uel0oooo09NGU`3lo?`0kno50?clo03RmmX0GemO0?clo02GaNl0
ooo_0:NWY`3oool0bjnW0P35aLD05P3oknl0UiNG0?clo02GUiL0BDU901Hk5P0/;2`0e=CD0>o5a@2G
aLD0hN7Q0>o5U`2_[jl0oooo05o5a@3oool0aING07=cL`1OUiL0<7]O001OG`1OUel305mOG`07002G
U`1OGel0GiNG0:NWY`1OaIL0UlFG09NGU`0305nGU`<009NG00<0GiMO001OU`1OUiL00P1OUiL01P2G
UlD0UiNG09O5U`2GUlD0PinO05nGa@80UlG50`35aLD07P3=cLd0UlG509NGU`1OUiL0aLG50>7Qh@3_
klD0[jNW07=cL`3oolD005mO0?ook`3oknl0][Jf09O5a@3Kfm<0GemO0?o_a@3_aNl0][Jf0?ooa@2W
YjL0dm?;09O5U`3oonl0klG50=CDe02f][H0GemO0?kfmP80ooo_00D0e=CD0<G5a@3oonl0UemO0=_K
d`020?ook`0S0?ooa@2WYjL0YjNW04U9B@3oooL0UiNG0>7Qh@35aIL0UiNG09O5U`1OUlD0P:nW0?o_
a@1cLg<0ooo_05nGU`3_aLD0oooo0=?Cb`00Gel0ooo_09NGU`35aLD0ooo507=cL`2^aLD0YjNW05nG
U`3oonl0YjNW0?ook`2f][H0d];B0?ooo`25QHD00`1OUiL03P3_aLD0GemO09JFSP0/;2`0o?cl05mO
G`3oool0ooo_05mO000/;2`0ooo_0?ooo`35Uel0B@000P3oonl04@2OWh<0ooo_0?ook`3oolD0hN7Q
0019003oonl0UYIR0?o5k`0/;2`004T00?ook`2GUel0onnG050F5P3oolD0GemO0080oooo0P0/;2`0
:@2_P6<0BDU90?ooa@3lo?`0ooo_0?ooa@35GiL0o_kf09MOU`3oool0ono_001OG`3oonl0Gel00:BT
Y03ooiL0;2`/0?ooa@1OGel0oooo0?ooa@33aI80olG5001OG`0/;2`002`00;Jf]P3oknl0ooo_0;Vi
^@3lo?`0GiMO05mOG`3oool0oonG0?o5k`2_bjl0ooo_0>o_U`00;000oooo0080;2`/00<0P:AS04U9
B@00;0000`0/;2`01@00;000;1HF02`00000;000000000Sooooo0006ooooo`1:04bBH`2_[jl0_[jn
051X@P1kNc00<7/0031kN`3ofYL0kno504I65P2YZJT0ooog001Y<000J@00mn:_0?OgfP1kNc00UYJB
083;Y`1KRh/0`[[20?oom`1cLg<0ooog0:o;[`1ONg/0oooo082_``2_f]X0j>SX0;jnY`2^aHT0hOKQ
0?knoP35aMX0hN7Q0?ook`3;bjl0Hi9O01i==P2BTZL0j^[Z0?OJ[P3fm_H0[Jf]0?ogfP35cl40oooo
0:FUSP2W[Zh0ooog07^GU`1YJHD0NiNG04bGN`25JFT0GemO06UYQ@1OUel0<7]O031OK@00UiL0JHF5
06V5J@0`Gg/0JFV506UYJ@0`UhT0GiNG07:>SP0`NiL0Gg]k05nGU`1k[Zh20:NWY`0:08>OW`2f]Yl0
GjjG08>OW`2GaLD0PkJO09N^a@2n_[h0aLG50=CDe080cLg=0100dM7A0<g=c@35aLD0_[jn0:j^[P3o
ooL0km[50;Vi^@2f]Yl0oooo07=cL`3oonl0YJF>0<G5a@3=cLd0h^;R0`3oooL0203Xj=<0j^[Z0>;R
hP2e]KD0oooo09nOW`3;bl<0Njj^0P3oool09030`<00fm_K0=_Kd`3QhN40aM[50?ooo`3;bl<0[Zj^
0?ooo`2UYHh0YjNW05nG[P2O][H0ooO_0;jo/03gmmX0ooo_0>;R``2B[Zh0LXj>07^GU`2N[:P0bl^_
079bSP3oooL0WinO0?oom`25QHD0_MO70<_;``2i^K40bl^f0>;_a@3Cdm<0koOJ0:oGa`80GiNG06D0
JHFL0?ooo`3no_h0Gjj^0=?Cd`1k[Zh0LXj>05nGU`1YQHD0Ng]k0?OghP2_TV<0Y[600:BLW03oool0
E5AD0?oofP32^ZD0AQHF00/Y5P32`/80h/>W0>;;N`2TY:@0mn;307URHP2[]X<0oooo0>;3``3R[W/0
om[_0<;2`P1ZJVX0alNO0?ogo`2>SWT05R`F0?ook`2GUiL0oooR09VIOP3oolD0fm?C0>;RY`1aLG40
5P0F01H/5P2ZZX@0h^;;0:n_TP3no_H0mn;J0>;J[P1iAV80kO7C0<EkU`3oooL0mn;J03/k>`31`L40
bl_;06>3E03oon80mn;R0:o;TP3Rbl/0[jmh07R7C03ae;X0mn;R05A`E00/;2`05R`F099<N`3Rmn80
h^;R0>;C^@20UWP0h^:B0<^W[`3;hZl0SXii0?o5a@2B^:X0h_OR0<GJG`2DU9@0oooo09JFUP0FATH0
iLS4069RAP0F5P00;2`/01HF;000;0005QH/024Q;00F00005QH000000008ooooo`001_ooool02`19
BDT0Gel00:NWY`1k[W/0Gel004U9B@00L`00Gel004U9B@00Gel0BDU90080;2`/00X005l002`/;01O
G`00Gel000190000Gel0GenG001OU`00UiL0GiMO1@00Gel01P1OUel009NG05nGU`00NiL0GiMO001O
U`8005mO00@0Gel004U9B@00Gel0JFUY0P00Gel03@00UiL0GemO05nGU`00Gel0GenG05nGG`00Gel0
GiNG002GU`00Uel0GemO05mkN`1OaIL01P1OUiL02P00UiL009MO05nGU`1cLg<0QHF5002GG`00Gel0
09NG001OU`00UiL305nGU`0505n^U`1OUiL0UlG509O5a@2f][H00`35aLD00`2f][H0UlG509O5a@02
0<G5a@030=CDe03=cLd0klG50080e=CD00T0kno_0?clo03QhN40h][_0<G5a@3_onl0aLG50<G_k`3_
knl00P3De=@0403Jf^80aNo_0<G_k`35klD0e=CD0<G5a@3_knl0aLG50<G5k`3lo?`0aNo_09O5a@35
knl0aNo50=[JfP3QhN420=CDe00J0<G5a@35aNl0aNo_09O5a@2GaNl0aNo_0=CDe02WYjL0UlG50<FG
a@2^aLD0GiNG0<G5a@2GaLD0][Jf05nGU`1OUlD0Njj^09O5a@2WYjL0][Jf09NGU`2GaLD0aLG509N^
[P2GaIL20:NWY`0305o5U`1OUiL0YjNW00<0GiNG0100YjNW05nGU`2WYjL0YjNW09NGU`1OUiL0QHF5
05nGU`00Uel0GenG07=cL`19BDT0>c/k02`/;019BDT005mO0P19BDT01019000002`0000/0019BDT3
02`/;00504U9B@0F5R`0;2`/02`/;000;0000P0/;2`0300002`0;2`/02`/;00/;2`002`002`/;000
;000;2`/01H/5P0/;2`0000/04T00080;2`/00<0B@0001H/5P0/;2`0200/;2`02`0002`0;2`/02`/
;000;000;2`/04U9B@00;000;2`/0000;00/;2`0000/0080;2`/00<0;00002`/;000;0000P00;000
0`0/;2`002`0000/0002000/00060000;000000002`001HF;00/;2`002`00P0002`00`000000000/
01H/5P02000/000802`/;000;00002`00000;00001H0;0000000;00/;2`8ooooo`001_ooool0202W
YjL0GemO05mOU`1DE5@0Uel009MOG`00Gel0GemO0P19BDT01`0UL5@0BDU904U9B@0/;2`005l005mO
0000G`000P0/;2`0201OGel0GiMO001OG`1OUiL005mO031kN`00Gel009MO0`19BDT02@1OGel0E5AD
001OU`00Uel009NG05mOG`19BDT005mO05nGG`0205mOG`D005mO0P1OGiL01P00Gel0GemO05nGG`1O
Gel0GiMO06V5J@<0GiNG00D0UlG50;Jf]P1OUiL0PinO07=cL`0205nGU`0<0:NWY`1OUiL0GiNG031k
U`00GiL009NG05nGU`1cLg<0GiNG05mOU`23Wil0YjNW0P2GaLD01035aLD0UlG50<G5a@3<c<`40<G5
a@040;Jf]P35aLD0e=CD0<G5a@<0hN7Q00<0e=CD0<G5a@2n_[h00P3De=@01`3_klD0][Jf0=CDe02f
][H0e=CD0<g=c@35aLD00P3De=@01P2GaLD0aLG_0;Jf]P2^aLD0aLG509O5a@<0][Jf00X0YjNW0:n_
[`35aLD0aLG509NGa@2WYjL0][Jf09O5a@1k[/D0YjNW0`2GaLD01P2WYjL0UlG507^G[P1OUiL0][Jf
05nGa@80GiNG00<0UiNG05nGU`1OUiL00P1OUiL01`2GUiL0GiNG05nGU`1k[YL0GlFG05nGa@25QHD0
0`1OUiL00`1YQHD0GiNG05nGU`0405nGU`0305n^U`1OUiL0QHF50080GiNG00`0BDU902`/;00/;2`0
;2`/04T0000/;2`0000/02`/;00/000002`0000F0000;0020000000602`00000;000;2`/01HF;00/
;2`002`00P0/;2`20000;00301HF;00002`002`0008002`000L0000002`0000/0000;000000/0000
02`0;000008002`000<0;2`/000/0000;0000`0/;2`01@00;0005R`F000/0000;000;0000080;2`/
00D002`003/F5P0/0000;2`/0000;0020000008002`000<000000000;00002`00P0/;2`02P00;000
;000000/0000;000;2`/000/00000000;2`/000/000F5TH302`/;080000000@0;2`/01H/5P00;000
000/0`00;0001@0000005QH00000000002`002`000Sooooo0006ooooo`0=05nGU`1OUel009MO02E`
E025QHD0GiNG002GU`1OUiL0YjNW001OG`1DE5@0GiMO04U9B@0202`/;00405mO0000G`005THF0019
0080BDU90`1OGel0100`Gel0GemO05nGG`00Gel205mOG`0=0019000`G`00BDU9001O0000Uel0BDU9
001OG`00G`00GenG05nGU`00Uel005nG002GG`02001OG`0;05nGU`0`UiL005mO002GG`1cLg<0GiNG
05mOU`1OUiL0<9Mk05nGU`00UiL00P1OUiL00`1OUlD0GlG509nOW`0305nGU`0405nGa@2GaLD0UiO5
07:>SPH0GiNG00D0][Jf09O5a@2f][H0][Jf09O5a@020;Jf]P090>;_fP3oklD0klG50>7Qh@3De=@0
klG50<G_k`3Kfm/0aLG50080e=CD0P3_aLD01@35aNl0aM[50<G5a@35aLD0e=CD00D0aLG500<0aLG_
0=CDe035aLD00P35aLD01P2f][H0_[jn0<G5a@2f][H0aLG509NGa@80UlG500<0Ujk509NGa@2GaLD0
0P2GaLD03P1OaLD0YjNW09nOW`2GUlD0UlG50:NWY`2GaLD0UiO50:NWY`1k[/D0GiNG09NGU`1OUlD0
GlG5101OUiL00`1OaIL0GiNG05nGU`0305nGU`80UiNG2`1OUiL01P1ONiL0GiNG05nGU`00GiL0GemO
04U9B@80;2`/0`00;0002@0/;2`002`002`/;000;0005R`F000/00000000;2`/04T000020000;005
01H/5P00;000000/000/000/00000P0002`01@0/0000000/000/0000;000;0000080000/00/05QHF
0000;000;000;00002`/;000;000;2`/01H/5P0002`0;2`/0000;00202`/;0050000;00/;2`004T0
02`/;000;0000`0/;2`2000/00@0;2`/00@002`0000F0000;000;2`/0P0002`2000/00030000;00/
;2`0;2`/008002`000P0B@00000/000/;2`05QH/0000000/;2`0000/02`00080000000P05R`F02`0
00000000000/000/000002`0;0000000;080000000<002`0ooooooooool01_ooool000Kooooo0P2G
UiL02@2WYjL0UYJF05nGU`2GUiL0GiNG0<G5a@2GaLD0GiNG031kN`0204U9B@08001O0019BDT0BDU9
04U9B@0k>c/0Gel000190000Gel205mOG`0307=cL`0`Gel005nG008005mO00@0GiMO05mOG`19BDT0
<9MO0P1OGel01P1OUel0GemO001OU`00GiL0GenG079bSP8005mO0`00Uel00`1OUiL0<7^G05nGU`02
05nGU`0405nGG`1OGel0GiNG031kU`D0GiNG00<0GiO508>f]P2GUiL01@1OUiL04P1OUjh0GiNG09NG
U`1OUlD0GiNG09O5a@2WYjL0Njk30;Jf]P35aLD0UlG50>ooa@3QhN40kno50=?Cd`3_knl0hN7Q0>o5
k`80hN7Q00<0e=CD0>7Qh@3De=@00P35aLD0203QhN40aLG50<G5a@3=cLd0e=CD0<G5a@3De=@0klG5
0P35aLD20=CDe0090<G_a@3De=@0e=CD0<G5a@3De=@0aLG50;jn_P35aLD0aLG_00<0][Jf00X0UiO5
0:Nn_P35aLD0aLG50;Jf]P2GaLD0UiO505o5a@2W_[h0GiO50P2GaLD02@2f][H0YjNW09NGa@2O][H0
GiO509NGU`2WYjL0GiO50:NWY`0905nGU`030:NWY`1OUiL0GiNG00<0GiNG00<0Pinf05nGU`1OUiL0
0P1OUiL00`1OGiL0GiNG05nGU`0305nGU`05001OU`19BDT0;2`/02`/;00U5P000`0/;2`00`190000
;2`/000/0002000/000604T00000;000000/02`/;0000000;1HF0P0/;2`2000/000:0000000/;2`0
01H002`000000000;0000000;00/;2`0;00001H/5P80000000L0;00000000000;00002`001H/5P00
02`000000080;00000H002`002`/;00F;1H002`002`/;000;00302`/;00401HF;00002`0;2`/02`/
;080000/00<0000000005P0/;2`00P0/;2`3000/0080000/00<002`002`0000/00000`00;0000`0F
5R`0;00002`/;0020000;00=02`/;000000001HF0000000/0000000/000/000002`0;00000005P00
0000;2`/000/0008ooooo`001_ooool03P00UiL0UlG50<FGa@1OUiL0GiO50:NWY`2f][H0aLG50?o_
a@3De=@0[jn_0:NWY`00Gel005l00P19BDT00`0/;2`0<5l005mOG`03001OG`0305nGG`00Gel0<5mk
0080GemO00P005mO05nGU`00UiL009MO05nGU`1OUel009MO001OG`80GiNG00d0GenG05nGU`1OUiL0
GiNG001OG`00GiL005mO002GG`1OUiL0PinO07=cL`00UiL0GemO0080GiNG00D009NG05nGN`2GUlD0
YjNW09NGU`0305nGU`0;09NG[P2GaLD0GiO505nGa@35aNl0GiO508F5Q@1OUiL0UlG505nGU`2GUiL0
0P2GaLD02P2f][H0UlG50<G5a@3De=@0hN7Q0?o_k`3QhN40aNo50>SXj03QhN420?o_k`0:0>7Qh@3D
e=@0e=CD0>o5fP3oknl0kno50=CDe03QhN40ono50>o_a@80e=CD00<0aNo_0<G5a@35aLD00P35aLD0
203De=@0cLg=0=CDe03De=@0aLG_0;Jf]P3De=@0aNo50P35aLD0202f][H0aLG_09O5a@2f][H0UlG5
0;jn_P35aLD0][Jf0`2GaLD0101OUlD0Winf0;Jf]P2GaLD20;Jf]P0409O5a@2GUlD0NiN^09NGU`<0
GiO50P1OUiL00`1ONiL0GiNG05nGU`0205nGU`03002GU`1OUiL0NiNG0080GiNG00H0UiNG05nGU`1O
UiL0GiNG05nG[P1OUlD805nGU`0605nGG`00Gel0BDU902`/;000;0005R`F100/;2`01000;0000000
01H000000002000/0080;2`/00T0;00001H/5P00;000;2`/000/0000000002`00000;00F;1H00P00
00002P00;000000/000/0000;0005QH00000000/0000000/0000000/0002000/0080000000D0000/
02`/;00/000002`001HF;0020000000302`00000;000;0000080000/00X002`002`/;00/;2`0;2`/
0000000/;2`05QH/00000000;000;2`/0P00000202`/;00:00005P00;000000/0000;000;0000000
000/000F;1H0000/00000080000/00<002`002`0000F5QH00`0000001`0/0000000/0000;00F5R`0
000/02`0000/;2`02?ooool000Kooooo00H0GiNG09NGa@2GaLD0Njj^0=CDe02GaLD40<G5a@0808^W
_P1OUlD0GiMO001OG`1OGel005mO001O001OGel2001OU`0>001OG`1OGel0GemO07=cL`0`Gg/0GenG
05mOG`1OUiL009MO05nGG`1OUiL005nG002GU`1OGiL2002GU`0505nGU`1OGiL0GiNG07^GU`00UiL0
0`1OUiL06`1OUlD0YjNW05nGU`1OUiL0BDU905mOG`1OUiL0GiMO05nGU`1O[YL0GiNG09NGU`1OaLD0
UlG505o5U`2GUiL0YjNW09O5a@2GUlD0YjNW09O5a@2f][H0YjNW07^Ga@1OaIL0GiNG05o5a@020<G5
a@0;0;Jf]P2^[/D0aLG50?o_a@3_aLD0ono_0?o_a@3_aLD0hN7Q0<G_k`3De=@00`35aLD03035knl0
j=?C0=CDe03De=@0klG50=CDe035aLD0klG50=CDe035aLD0e=CD0<G5k`@0aLG500@0e=CD0<G5a@35
aLD0aLG50P35aNl40<G5a@80UlG500<0aLG50:NWY`2GaLD00P2GaLD20;Jf]P0<09NGa@2GaLD0WkJf
09O5a@1OUlD0YjNW0;Jf]P2GUlD0YjNW09nOW`2GUlD0GiNG0P2WYjL00`1OUiL0YjNW05nGU`0705nG
U`030:NWY`1OaLD0GlG50080GiNG00D0GiO505nG[P1OUiL0UiO505nGa@0505nGU`0605mOU`1OGel0
05mO04U9B@0/;2`002`00P0/;2`0200002`0;2`/000/0000;000;2`/01H05P0/000002`00P000000
1@0002`0;2`/01HF5P00000002`00080000000@002`00000;0005QH0B@000P00;0001`0002`002`0
02`0000F01H0000/000/000000000`00;0000`005P00000004T0000202`/;006000/000/;2`0;2`/
0000000/;2`002`0200/;2`00`00;000;2`/0000;002000000030000;000000000000080;2`/00H0
000002`/;00002`0;2`/02`00000000402`/;0090000000/0000;000000/000/5QH0000002`/;000
;000;0000080;2`/00@002`002`/;000000000002?ooool000Kooooo01h0GiNG07^G[P2WYkh0^[[6
0;Jf]P35aLD0cLgR0;jnd`2G[/D0Winf08NS^P2B[Zh0Njj^031Y<01ONg/0<7]<001OG`00Nfd0<5mO
001ON`00Gel0<5mO031kG`0jJFT006e]05mOU`00UiL0Gg^G031ON`0`NiL205nGU`04031kU`00NiL0
09Mk002GU`80Gg^G02l0<9:^05nGX`1OUiL0<9NG05n^U`1OUjh0NiNG05nGU`18RIL0GiNG031kG`1k
NiL0GiN^032GU`1YQHD0B8V9032GU`1OUiL0GjjG08>fW`2WYjL0Winf032GX`1OUjh0GiO509nf]P1k
[/D0[/GJ0<G5fP2[]//0[Zj^07^^a@2J][H0][K;0;jnd`2ldm<0hNGG0=_Kf`3=cLd0fm>n0>[Rc@3R
h^80l>SX0>c/gP3Zh/d0fm_K0=?Cd`020<g=hP080<g=c@3GemL0fm_K0>;Rc@3QhN40dm?C0=[5a@3<
c<`20<g=c@0[0<GJa@3=cLd0aLG50<gRhP3=cLd0cLgR0=O<c03=cLd0e=CD0<g=c@2n_[h0cLg=0<G5
a@2[c<80aLG50;Jf]P2W_[h0WkJf0:NW_P23][H0ZkK209O5a@2WYkh0[/G509O5a@2W_[h0WkJf096f
`P2;_[h0WinO07^Ga@2WYjL0Ykjn08>O]P23Zil0Njj^05n^[P1OUjh0WinO05n^[P23WkH0B9N^032G
U`0505nGU`08076bY`1O[Zh0GiO505nG[P2O][H0PinO032G[P1OUj<205nGU`0F05nG[P1OUiL0Gg^G
05nGU`1YTi<0JHF505mkU`0`Gel09EAD01H/5P0/;2`0>c/k024Q;00F;1H05P0002`F5P0/;2`05QH/
01H/5P0001H05P0F000/00805P000P005P005P0;8@/05QH002D0000/00005P0001H/5P0F5P002b40
01H0000001H05QH/01H000005P005P0002<S>@0F5R`05QHF02`F5P005P005P0001HF;00Q8B`201H/
5P0H02`/;00F5R`05QH/01HF;00Q;240;2`/01HF>`00;000;2`/000F5P0F5QH05P/Q000/000F5QH0
01H002`/;00F5QH0000F000;000F00005QHF01H/5P0F5P00;1HF0P0002`00`0;2`/0;2`/01HF0002
000/000:00005P1iC4`02`0;02`F5P0F0000000F01H05P0/5QH05R`F000F2`8001H000P002`002D0
000F;1H0>aHF00/Q5P0F;1H05QHF02`F5PSooooo0006ooooo`80GiNG00<0YjNW0:Nn_P2GaLD00P2G
aLD0201OUlD0UlG50:NWY`1<UiL0GlG5002GU`1OUiL005nG0P00UiL05000Gel0GemO002GG`1OGiL0
05nG002GG`00Gel0<5mO05mOG`1OUiL0GemO05mOU`1OUiL0Lg=c05nGN`1OGel0YjNW002GU`1OUiL0
GiMO0P00UiL01`0`UiL0GiNG09O5a@2GUiL0GlG50:NWY`2GUiL00P1OUiL01`1OGel0GenG05nGU`1O
UiL0GiO508^WY`2GUiL00P1OUiL01000UiL0YjNW002GU`1OUiL2002GU`090:NWY`1OUlD0YjNW09NG
a@2f][H0aIO50:NWY`1OaLD009NG0080UiO50P35aLD00`2GaLD0aLG50>o_k`020>7Qh@0>0=_Kf`3D
e=@0aLG_0>7Qh@35aNl0kno50>7Qh@3`dm<0e=CD0<G5a@3De=@0klG50=CDe03QhN420;Jf]P80aLG5
00`0e=CD0<G5k`3De=@0aLG50=CDe035aLD0UiNG07=cL`1OGel0YjNW0;Jf]P2^aLD30:NWY`0509O5
a@2WYjL0YjNW09O5a@2GUlD00P2f][H01P2GUlD0GiO50:NWY`1kUlD0GiO505nGU`80YjNW014009NG
0:NWY`1kUiL0GiNG08F5Q@1OUiL0UiNG05nGa@1OUiL0NiNG05nGa@1OaIL0UiNG05nGU`2GUiL0GiNG
001OG`0302`/;00604U9B@1OGiL0GiNG07^GU`1OUiL0GiO51@1OUiL0101OUlD005nG001OG`19BDT2
0000;004000/000F;1H002`00000;080000000D0;0000000000F0000;000000/000200000003000/
000/;2`05R`F00<0000/00<0000002`/;000;0000P0/000202`/;0070000000/0000;00000005P00
02`002`004U9B@020000;00502`/;0005P0002`0000/000/00000P0002`2000/0080;2`/01@0;000
000/000002`0;00002`/;000;000000002`0000/;2`002`002`/;00F00000000000/000/00000000
000/0000000002`000005P@0000000@0B@00000/000F5R`0000/0`0000001`00;000000/01H05P0/
000002`002`00000;0000P0002`0100F5QH0;000000/00000008ooooo`001_ooool02@1OUiL0GiO5
09NGa@1OUjh009NG0000B@1O05l0GemO0000L`0205mOG`0305mOU`00UiL0GiNG00<009NG00X0Gg^G
001OU`1OGel0GemO001OU`0/;2`0GemO05l`G`1OGel0G`1O0`1OGel01@1cLg<0JFUY05l0G`1O05l0
GemO0080G`1O00@0UemO002GU`13Id<0G`1O0`19BDT205l0G`0305l`G`1OUlD0GiNG0080GiNG00<0
04T004U9B@19BDT00P19BDT01`1O09L0GiNG05nGU`1OUlD0>SY@02`/;019BDT00P1OGel205l0G`03
04IRHP1OUlD0GiNG00<0G`1O00X0GemO05AD9@19BDT0G`1O05l0U`2f][H0UlG50<G5a@3=cLd0G`1O
0`1OGel0101O05l0BDU905mOG`2GGiL20=CDe00>0>o_a@2f][H0BDU90300E01cLg<0GenG05mOG`19
0000UiNG0<G5a@35aNl0[Jf]04U9B@1OGiL409MOU`050;jn_P0/;2`0G`1O05l0U`1OGel00P1O05l0
0`2GGg/0GemO05mOG`0205mOG`0905l0G`1OGiL0Nemk09NGU`1OUiL0GiO5002GU`1OGiL0GemO0080
G`1O00@0GemO09L0G`1OUiL0Geo50P1OUiL01`1OaLD0GiNG05nGU`0002`0000004U9B@1kGiL01@2G
GiL00`1cLg<0Gg]k05nGU`0405nGU`0307=cL`1OUiL0GenG0080;2`/00H0BDU905mOG`1cLg<0Lg=c
071DE000;00202`/;00504U9B@1OGiL0U`2G07/`N`1O09L00P2GGiL01`2GGel0;2`/000000005P00
;00005l0G`2GGel00P2GGiL02@1cLg<0Nemk05l0000002`002`009MOG`1cLg<0QHF508DjJ@0209MO
G`0309MOU`2GGel002`000<002`000T0UemO09MOU`1OGiL0UenG05mOU`1`9G00000002`/;02GGiL0
0P2GGel01@2GGiL09C/U02`/;01OGel0QHF50080Lg=c00D0UenG09L`U`2GGiL0UemO02`/;00209MO
U`0>09L0U`2GGiL0UenG09MOU`1OGel0;2`/04T00000;000;2`/000/000/0000G`1O09MOG`2G09L2
09MOU`0303/U9@190000;2`/0080000/0P0/;2`0100F5R`002`002`0000/0008ooooo`001_ooool0
1@00UiL0GiNG05nGU`1OUiL0UiO50080GenG0`2GGiL03P1kGiL0UenG09NGa@2f][H0GiNG002GU`1O
UlD0YjNn07=cL`1OUiL005nG001OG`00GiL0GenG1`2GGiL00`1kNiL0UenG09MOU`0209MOU`0405mO
U`1OGel009NG002GU`80UenG00<0QHF509MOU`25QHD00P2GGiL205nGa@0=05nGU`00GiL0000/05mO
U`1kGiL0UenG07=cL`00GiL0GenG05nGU`0/;2`0Uc1k07=cL`0209MOU`0D05mOU`2GGel0UenG07]O
N`25QHD0YjNW09NGU`1OUiL0UenG05mOU`2>LXh0UemO09MOU`2GUiL0UlG50;Jf]P35aNl0aLGJ0:NW
Y`1OGiL209MOU`0805mOU`2GGiL0Uen^0;Jf]P35klD0klG504U9B@0007<209MOU`0305l0G`2GGiL0
UenG0080UenG00@0GemO0<G5a@1aLG40Lg=c102GGiL02@2G09L0Yh^W001OG`2GGiL0GenG09MOG`1O
GiL0UenG0:NWY`0209MOU`0509L0G`2GGiL0UemO05mOU`2GUiL00P1OUiL01@2GUiL0GiNG05nGU`2G
GiL0JFV50080UenG00<0GenG05nGa@1OUiL00P1OUiL01`1OaLD0UlG502`/;02G05l0UenG09L0U`2G
<9L00P1OGiL01`1cLg<0GenG09MOU`1O09L0UenG04U9B@2GUiL01@1OUiL00`000000UenG09MOU`03
09MOU`0407=cL`1k<9L0GemO09MOG`<0;2`/00@0G`1O08DjQ@2GGiL0G`2G0P0/;2`01`000000;000
030F<01cLg<0UenG05mOG`2GGel00P2GGiL00`2G<9L0UenG09MOU`0202`/;00604U9B@1cLg<0QFV5
09L0U`19BDT0000/0P0/00002P0000005P00000/001OGiL0U`1O07=cL`2GGiL0G`0002`/;01O0002
09MOU`0405mOU`1OGel0GenG07]ON`8002`000D0000/05mOG`2GGel0GenG09MOU`020000000:02`/
;02GGiL0U`2G05l0G`0/;2`0>c/k05mOG`1OGiL0U`1O05mOG`80;2`/00@001HF05mOU`2GGiL0G`2G
0`2GGiL00`1DE70002`0000/000402`/;004000/000/;2`002`0000/00Sooooo0006ooooo`08002G
U`1OGiL009NG08>OW`2WYjL0UlG50:NWY`1OUiL209MOU`0409NB``2GaLD0GiNG0;Jf]P<0GiNG00P0
_[kC05nGa@1OUiL009NG05nGU`00GiL0GiNG04aON`<0UenG00H0GenG0:NWY`2GUiL0<7]k09MOU`2G
UiL209MOU`08002GU`1OUiL009NG08>OW`2WYjL0UiNG09MOU`25QHD209MOU`0907_5a@2WYjL0UiNG
05nGU`00UiL002`009MOU`2GGg/0GiMO00<0GiNG00<0;2`/09MOU`2GGg/00P2GGiL01`1OGel005mO
05mOU`00GiL0NenG05mOU`25QHD00P1OUiL0200/;2`0UenG07/`N`1cLg<0YjNW05o5U`2WYjL0][Jf
0P35aLD01035aNl0aLG505mOG`1OGiL209MOU`<0aLG500<0;2`/09MOU`2GGel00P2GGiL0102WYjL0
][Jf0<G5a@2f][H309MOU`03071DL02GGiL0GenG0080UenG00`0UiO509NGU`2GGiL0;2`/05mOG`2G
09L0UenG09O5a@2f][H0WkJf09NGU`0005l209MOU`0507=cL`2GUiL0YjNW05nGU`2WYjL00P1OUlD0
1@1OUiL0Lg=c09MOU`2GGiL0UiNG0080GiNG0140YjNW05nGa@2WYjL0GlG50:NWY`19BDT0Lg=c05mO
U`2GGiL0Gg^G05nGa@1OaLD0UiO505o5U`25QHD0GemO09L`U`0209MOU`060:NWY`2GUiL0GiNG05nG
U`0`HT`0GenG0P2GGiL0202G09L0UemO02`/;000;000>aHF04U9B@1OGiL0BDU90P0002`02@00;000
Lg=c09L0U`1OGel0;2`/0000000/0000000007]ON`0209MOU`0=09L0U`19BDT0;2`/001OG`0F;1H0
BDU905mOU`1OGel0;2`/000/001OGel0QCZ509MOU`020000000;0000;000;000000000000000;000
Lg=c09MOU`1OGiL0G`1O02`/;00F;1H00P2GGiL02@2G09L0GenG04U9B@0002`0ATI602`/;000;000
;2`/0000;00205mOU`06071DL000000000000000;01OGel0U`1O0P00;00202`/;00>04U9B@1OGiL0
GenG02`/;000;000;2`/05mOU`2G05l0UenG05mOG`190000;00003/k>`00;00202`/;007000/000/
;2`0;2`/03/F5P190000000/000/0008ooooo`001_ooool2002GU`0305nGG`1OUiL0GiNG0080UlG5
00@0GiO5001OG`2GGiL0Wh>O101OUiL02P2WYjL0GiO509:^a@2WYjL0][Jf0:NWY`00UiL0GiNG0:NW
Y`1kGiL309MOU`80YjNW00<0UiO505mkTP2GGiL00`2GGiL0101OUiL0YjNW05nGa@1kUiL205nGU`<0
UenG0100QHF507^G[P2WYjL0GiNG002GU`00GiL005mO09L0U`1kGg/0GiNG002GU`1OUiL0BDU905l0
G`2GGiL0Nemk0P1OGiL02P1OUiL0GiO505nGU`00UiL0Hjj^05mOU`1OUlD0UiNG05nGU`0/;2`209MO
U`0:05mOU`1OUiL0GiNG0:NWY`2GaLD0aLG50:k5a@2f][H0UlG502`/;0<0UenG00<0][Jf0>7Qh@19
BDT00P2G09L0101OGiL0UenG0<>B[P2f][H40=CDe00M0;Jf]P1OGiL0C31R09MOU`2GGel0UiO50<G5
a@35aNl0aLG508^;R`2GGiL0GenG09MOG`2GGiL0UiO509O5a@1k[/D0GiO502`0002GGiL0GemO09MO
U`1OUiL0PinO05nGU`1OaIL0GiNG09NGU`00UiL00P2GGiL03P2G05l0GiO505nGa@2GUiL0GiO505nG
U`23][H0YjNW05o5a@1OGel0G`2G09MOU`1OUiL0Gjj^0`1OUiL01`1OUlD0GiNG09NGU`1k<7/0Lg=c
09L0U`2GGiL00P2GUiL01P1OUiL0C5mO05mOU`2G05l0UenG05mOG`80;2`/00`002`002`/;000;000
000/09MOG`0/;2`0;000000/002G<9L0GenG07<0000/00020000000<04U9B@2G<9L0Lg=c09MOG`0/
;2`002`002`/;00002`0000F00000000;000UemO0P0/;2`02P1OGel0QFV509MOU`0/;2`0;0000000
;000;000;2`/0000000/000209MOU`0509L0U`19BDT0;2`/01HF5P1OGiL00P2G09L0102GGel0000/
0000;00F;1H202`/;0050000;0000000GemO09MOG`1<06800P0/00000`00;000GenG04U9B@0202`/
;00<01HF;00/0000;2`/05l0G`2G05l0UenG02`/;00F02D0GenG08F5Q@1OGiL002`00`0/;2`20000
;00802`/;00002`002`002`/;00U5P00;2`/0019000/0008ooooo`001_ooool03000GiL009NG05nG
U`0`Ng/0GiNG05nGa@2GaLD0GiNG05nGa@25QHD0NenG05nGa@<0GiNG00@005mO05nGU`1OUiL0UlG5
0`1OUlD00`1OUiL005mO09MkU`0209MOU`0509NGU`35aLD0UlG509O5a@2GNjh0102GGiL04P1OUiL0
UiNG05nGU`1OUg/0GiNG05nGG`2GGiL0Lg=c09MOU`1OUiL0GiN^09NGU`25QHD009NG05nGU`0/;2`0
GenG09MOU`80GiNG00T009MO0000B@1cLg<0GenG07]OU`1OUiL005nG001OG`00UiL00P00Uel02P0`
UiL0GiNG001OG`00GiL009NG02`/;02G09L0NenG05nGU`1OUlD305nGU`0509O5a@23Wil0UlG505o5
U`0/;2`00P2GGiL01P1OGiL0[Zk50;Jf]P19BDT0UemO07=cL`80UenG00D0e=CD0>7Qh@3_aLD0][Jf
0>o5a@020=CDe0060;Jf]P1<AT`0U`2G09MOU`35aLD0aLG_0P3De=@00`35aLD0UenG09MOU`0209MO
U`0609O5a@2f][H0NlG505nGU`000000UemO0P2GGiL00`2GUiL0PinO09NGU`0405nGU`0D09MOU`1k
Gg/0UenG05o5U`1OUiL0GlG50:NWY`2GaIL0YjNW05nGa@1OUiL0Lg=c09MOG`2GGiL0GiNG07^GU`1O
UiL0UiNG09O5U`2GUiL205nGU`08031k[P2GGiL0Lg=c05mOU`1OUiL0UiNG05nGU`1<068209MOU`06
05mOG`0/;2`0;2`/02`/;00002`001H00P0/;2`40000;00;05mOG`2GGiL0G`1O000/000/;2`002`0
09MOG`1k<9L0Lg=c0000;00000000`0/;2`0100F01H0;2`/000/000002`2000/000505l0G`1kGg/0
UemO000/000002`00`0/;2`02@0F;1H0000/05mOU`2GGel0UenG04U9B@190000;2`/09MOG`0209MO
U`0404U9B@0/00000000000F0080000/0P0/;2`209MOU`0504I6HP00;00002`002`/;02G09L00P00
02`00`0/;2`05R`F02`/;00202`/;00509MOU`25QHD0GemO000F5P1O05l00P2GGiL0200/;2`0000/
000/000/;2`0B@00000/000002`0;2`/0P00;00202`/;08002`02?ooool000Kooooo00D009NG002G
G`1OGiL0Gg^G05nGa@0209O5a@0<05nGa@00UiL0BDU909MOU`1OUiL0GenG05nGU`00GiL0GiNG05mO
U`1YQHD009NG0P1OUiL00`1OGiL0GiNG02`/;00309MOU`0605nGa@35aLD0aLG50<G5a@2_[jl0Ueo5
0`2GGiL01`2WYjL0UlG50;Jf]P2>SXh0GiMO001OG`1OGel00P2GGiL0301OUlD0GiMk09NGU`1OUiL0
09NG002GG`19BDT0UenG09L`U`1OUiL0QHF502`/;080UenG00T0GemO08EYQ@00UiL005mO05mOG`1O
UiL0GenG002GG`0`Ng/00P00Gel02000UiL009MO02`/;02GGiL0Nc1k05mOU`1OUiL009NG101OUiL0
201OUlD0UiNG0000;01cLg<0U`2G08F5Q@2f][H0BDU90P2GGiL0101O09L0UenG0;Jf]P2WYkh20;Jf
]P060?o_a@3QhN40kno50;Jf]P35aLD0SW:>0P2GGiL0502GaLD0aLG50=CDe03_aLD0aLG502`/;01O
Gel0GenG07=cL`2GaLD0UiO50;Jf]P2WYjL0000/09MOU`1cLg<0GenG05nGU`1O[Zh0UlG50P2GUiL0
0`1OUiL0YjNW09MOU`0209MOU`0805nGU`1OUlD0YjNW09NGU`25QHD0UiNG05o5a@1OaIL207=cL`0C
09MOU`2GUiL0Gjj^09NGU`1OUiL0UiNG08F5Q@1OaIL0GiNG07^G[P1OGiL0UenG09MOG`2GGiL0UiNG
05nGG`2G<7/0U`2G09MOU`0502`/;00301H00000;000;0000080;00000X0000/0000001kGiL0GenG
05l0G`0/0000;2`/0000;02GGel0UenG0P0002`01@0/;2`002`00000;00/00005R`F0080000/00T0
;000000/000/;2`0BDU909MON`2G05l0B@0002`00000;0000P0002`00`00;000;2`/09MOG`0209MO
U`0404U9B@0/;2`05R`F05mOU`80U`2G00/0BDU90000;00/;2`05R`F02`/;00002`0;2`/0000002G
GiL0U`2G04I6HP0302`/;0050000;00/;2`002`002`/;00F5QH00P0/;2`03@000000U`2G09MOU`2G
05l05QH/05mOU`2GGiL0U`2G0000;00/;2`002`001HF;000;0000P0/;2`2000/00@0;2`/00<0000/
ooooooooool01_ooool000Kooooo00h0GiN^031kN`0`NiL0GffG031kU`0`UiL0<:k508>O]P0`Ujh0
<5nG07IJQ00`NiL0<7]k031OU`80Gg^G00@0JHEY06B>P00`UiL0GiNG0P0`UiL02P1DL700Nemk09MO
U`2GGiL0NenG07_5[P35aMX0aLG50<G5fP2f]/8309MOU`0808ibSP1OUg/09G1`032GN`0eI3D09G1D
05ADE01OGiL209MOU`0305nG[P18RIL0<7^G0080<9NG0200<9Mk02E99@1kGg/0REn9031kN`1OUiL0
<00`07/`N`2GGiL0Uc2G05mOG`0`Gg/0Gemk001OG`00Gg/007]k031kU`0VNfd005mO001ON`00Ng/0
09Mk00190025JHD0RDRG05nGN`0`UiL0NiNG032GN`1ONiL0<9NG06fEX`80GiNG01P05R`F079bSP1k
Gg/0UenG0:NWY`0U9BD0Nc1k07]ON`2GGiL0Ug^G0<g=c@2iaM00_[jn0:k5a@2WYkh0aLG50:k5a@3=
cLd0e=CD0:6[[`2G<9L0NenG09FEU@2LW9`30;jn_P0O000U002GGiL0Nc2G09MOU`2n_[h0_ZNn0;>n
_P2^[/D001H008EYQ@2GGiL0Uemk0:NWY`2S[kX0WinO05n^U`23WkH0UjjG07^GU`25JHD0P6B>07/`
U`2WYjL0WkJf0:NWY`23Wil0YjNW06fSU`1kUiL0GiNG08j>SP0207]kU`0e07^^[P1]UiL0GjjG08>O
W`1OUiL0Gjj^07^^[P1OUjh0KIFS02E99@25JHD0UenG07/`N`23Pil05QHF09M8R@2GGg/0BDU902`/
;00k5QH0;2`/03/F5P0F;1H05QH001HF5P0/;2`05QH0000F000/;2`001H008U8N`1YJHD0Gel`02`/
;0000000Uc2G09MOU`1m>fl05P0F01H/5P0/;2`05QHF01HF;00000008B`Q00005P0F01H0000002`0
0000;000AQHF07]8U`2GGel00P00;0003P0F5P0002`0000/000F;1H0;2`/08DjJ@1kGiL0Gemk03/F
5P0/5QH05R`F07/`N`2GGiL0NemO0P0/;2`02`0F;1H08B`Q000F000001H0;2`/000U001YJHD0Nc2G
06U=J@0F;1H0;2`/00<05QHF00h05QH0000F00002`005R`F030F<01`04`0NenG07/`U`2GGiL001HC
05l`N`2G<9L0UenG02`/;0805QH/00/08B`Q01H/5P0/5QH05R`F01HF000/00005R`F03@Q8@0/5QH0
5R`F01HF5P08ooooo`001_ooool0102GaLD0GiNG002GU`1OUiL2002GU`80GiNG00D0GiO505nGU`1<
NiL0GenG05nGG`0205nGU`0405nGG`1OUiL0Fh^W05nGG`<0GiNG0180;00009MOU`1kNiL0QHF505nG
a@2GaLD0][Jf0<G5k`2GaLD0][K;09NGU`2GGiL0Ueo507=cL`1OUel0BDU9001OG`16ATH204U9B@0@
05mOG`2GGiL0UenG05nGU`23Pil0GiNG002GU`00Uel005mO04U9B@1OGiL0Nemk001OG`00Uel0UemO
07=cL`80UenG0P1OGel00`1OUiL005nG002GG`02002GG`0905mkN`1OUiL005mO001OG`1OGel00019
09MOU`2GGg/0GemO0080GiNG00P005nG002GU`1OUiL0GiNG09NGU`1OUlD002`009MOG`80UenG00<0
Ujj^05l0G`1OGiL00P2GGiL20:NWY`0I09nf]P2f][H0UiO50<G5a@35knl0aLG_09O5a@35aLD0dkjn
0:NWY`2G09L0UenG09MOG`2GGiL0;2`/0:n_[`0002`0UenG05mOG`2G09L0aLG50;Jf]P2n_[h0UlG5
0000;00209MOU`0;09L0U`35aLD0][Jf0;Jf]P2GaIL0YjNW09O5U`1OUiL0GemO08DjJ@2GGiL00P1O
UiL0302WYjL0GlFG05o5a@23Wil0UiNG05nGU`2WYjL0GiNG09NGU`1OUiL0PinO09NGU`<0GiNG00T0
GiO509NGU`1OUiL0B@0009MOU`1O05l0UenG05mOU`0/;2`00P2GGiL00`19BDT002`002`/;002000/
00040000;00k5QH002`000000080;00001@0;2`/0000;02GGg/0UenG04U9B@00000002`009MOU`1O
05l0L31<0000;00/;2`0000/02`00000;000;000000F5P0/;2`0000002`0008002`000D0000/08EY
Q@1OGiL0;2`/02`000030000;00604HF5P0002`0Lg=c07=cL`2GGiL0BDU90P0/;2`0102GGel0G`2G
09L0U`19BDT2000/000801HF5P00000002`002`0000002`0UenG09L0G`1RAV8202`/;00@0000;000
0000GemO05mOU`2GGiL0QFV509MOU`1cLg<0UenG09MOG`2GGiL0UemO01HF5P1cLg<0QHF509MOU`80
;2`/00@0000/02`/;000;00002`00P0002`402`/;0030000;00/003ooooo00Oooooo0006ooooo`04
05nGa@2GaLD0][Jf08>OW`<0GiNG00@0GiO505nGU`1OUiL007]k0P2GGiL01P1OGiL0GiO5002GU`35
UlD0NiN^05nGG`<0GiNG00X0GemO09MOU`2GGiL0GenG05nGU`1OUlD0YjNW0;Jf]P2GUiL0WkJf0`2G
GiL03@2GGel0UiNG05nGG`1OGel0Gel002`/;000B@00UenG07=cL`2GGiL0GiNG0:NWY`1OUiL00P1O
Uel01P00Gel0001909MOU`2GGiL005mO002GU`80UenG00<0GenG09MOU`0UE5@00P0/;2`01@1O05l0
BDU90019000005l0<7/`00@0GiNG00d005mO09MOG`2GGg/0GemO002GG`1OGiL009NG002GG`00Gel0
Gg^G0:NWY`35aLD002`000<0UenG00<0][Jf04U9B@2GGiL00P2GGiL00`2GUiL0YjNW05nGU`0205nG
a@030;Jf]P2GaLD0UlG50080aLG500D0_[jn0<G5a@35aLD0YjNW05mOU`0209MOU`0307]ON`000000
UenG0080UenG0P2WYjL0102f][H0UlG50000001cLg<209MOU`030<G5a@2n_[h0][Jf00@0YjNW00L0
UenG07/`U`2GGiL0UiNG0:NWY`1OaLD0UiNG0080GiNG00<0GlFG05nGU`1OUiL00P1OUiL00`25QHD0
GiNG05o5U`0405nGU`0=05nGa@1kUiL0;2`/05mOG`2GGiL0U`2G09MOU`0/0000Nemk09MOU`0/;2`0
B@00000/000302`/;00402DF0000;000;000000/0080000000T0;00007/`G`1OGiL0G`1O0000;00/
;2`0UenG07=cL`1<<6800P0002`04000000002`00000000/00005P000000;00/0000;2`/000/0000
0000;2`/07/`N`1cLg<0000/02`00000;0020000000801HF;00/;2`0U`2G09MOU`1O05l0;2`/000/
000F5QH209MOU`0709L0U`0/;2`000000000000k5QH002`000000002000/000305mOU`1cLg<0L5A`
0080;2`/00/0000009L0U`2GGiL0UenG05mOU`1k09L0UemO07=cL`1OGiL0UenG05mOG`0202`/;0<0
UenG00@0;00002`/;00/;2`001H01@0/;2`01@1900005R`F02`/;00/;2`002`000Sooooo0006oooo
o`0;0<G5a@2f][H0][Jf09nOW`2WYjL0UiNG0:NWY`2GUlD0GiO5002GU`1OUjh00P2GGiL01000GiL0
GiNG0;Jf]P2f][H205nGU`0705mOU`00UiL0;2`/09MOU`1OGiL0UenG05nGU`0205o5a@0409NGa@2G
aLD0e=CD08>O]P<0UenG00P0QHF505nGU`25QHD0GiMO01I6AP19BDT0;2`/05mOG`80UenG00L0GiNG
002GG`00Gel0GiMO001OG`00Uel0;2`/0080UenG00P0GiNG002GU`1OGel0GenG09MOU`2G05l0Uemk
05mOU`@0UenG00X0U`2G09L`N`0/;2`0GiNG05mOU`00GiL0;2`/09MOG`2GGiL0QHF50`1OUiL07000
UiL0GlG507^^U`1OUiL0UiNG02`/;02GGel0GenG09L0U`2WYjL0BDU909MOG`1OGiL0UenG0:NWY`1O
UlD0NjjG05nGa@1OaLD0GiO50:NWY`1OaLD0UlG50<G5a@2n_[h0aLG50=CDe02f][H20<G5a@0;0:NW
Y`2GGg/0UenG09MOG`1OGiL0UenG05nGU`2f][H0e=CD0<G5a@0/00000`2GGiL30;Jf]P80YjNW00L0
GlG50:NWY`2GGel0Uemk05l0U`1OUiL0GiO50080GiNG00<0YjNW05nGU`2GUiL01P1OUiL209NGU`@0
GiNG00@0<7]k09MOU`2GGiL0UenG0P1OGiL01P0/;2`0NenG09MOU`0/;2`002`00000;080;2`/00@0
000/000/00000000;2`/0P0000001@0/0000000/06UYQ@2GGel0;2`/008002`000@0U`2G05mOU`1k
<7/0QHF5102GGiL01@2GGel0NenG07=cL`2GGel000000080;2`/00<0001908ibSP2GGiL00P00;000
300/000000000000000F01H0;2`/09L0U`1OGiL0UenG04U9B@000000;2`/09MOG`80U`2G0100;2`/
000/000/;2`001HF000/000002`0;000000/001cLg<0UenG0696HP00;000000005l0G`2G09L0GemO
0P2GGiL0101O<5l0Lg=c05mOG`19BDT202`/;009000/000F5P00GenG09MOU`2GGel0000/02`/;000
;0005QHF00@0;2`/00<0B@0002`/;00F5QH00P0/;2`00`0002coooooooooo`06ooooo`001_ooool0
1@2f][H0aLG50=CDe02B[Zh0UlG50080][Jf00D0aLG505o5a@2GUiL0GiNG001OG`0209MOU`0404U9
B@0005l005mO05l`G`80G`1O00<0BDU905mOG`2GGiL00P2GGiL01`1OUiL0GiO50<G5a@2GaLD0][Jf
09NGU`2WYjL0102GGiL01`1OUiL0QHF505mOG`16AQH005l004U9B@1OGel00P2GGiL00`25QHD0<9NG
001OG`02001OG`04002GG`0/;2`0U`2G07]OU`8005nG00D0BDU905l0U`2GGiL0UenG06UYJ@03001O
G`0405mOG`1OGiL0GiNG030`G`80UemO0P1OUiL01000Gel0UenG09MON`1OGiL405nGU`0:0:NWY`1O
Ujh0GiO505nGU`0002`0GenG09MOG`2GGiL0Pinf04U9B@80UenG00D0GenG0;Jf]P2GUiL0RjNn09NG
U`0205nGU`0809NGU`1OUiL0GiO509O5a@2^aLD0aLG50;Jf]P2GUlD209O5a@040<G5a@2n_[h00019
09MOG`80UenG00d0][Jf0<G5a@35aMX0aLG50000;01OGiL0UemO09MOU`35aLD0_[jn0<G5a@2WYjL0
UlG50080YjNW00T0UenG07]OU`1OGiL0GiNG002GU`1OUlD0GiNG05nGa@1OUjh00P1OUiL02025QHD0
GlFG0:NWY`1OUiL0NiNG05o5U`1OUiL0UlFG0`1OUlD03@1NGUh0GemO09MOU`2G05l0Lg=c05nGU`00
UiL0JFUY09MOU`0/;2`0;00002`/;00002`00P0/;2`0100F5R`0000002`/;0000002000/000902`0
001k<9L0UenG04U9B@0/;2`002`005l0U`2GGiL0L5A`00<0;2`/00`0000/02`/;000;0005R`F09MO
G`2GGiL0U`2G02`/;000;000G`1O06UYQ@1cLg<3000/0080000000<05QHF02`/;01OGel00P2GGiL0
1P19BDT0;00001Hk5P2GGiL0G`2G09MOG`80;2`/00T002`002`/;00/;2`0000/000/000002`0GenG
09MOU`1R5V800P0000006`1OGel0UenG09MOU`1OGiL0;2`/000/000002`0;2`/04T0000/;2`002`0
02`/;00U5P00UenG05mOG`2GGiL0;2`/0000;00/;2`0000/02`/;0190000000/04T00000;000;000
01H/5P0202`/;0030000;?oooooooooo00Kooooo0006ooooo`0=09O5a@35aLD0aLG_0:k5a@2f][H0
aLG50;Jf]P2WYjL0UlG505nGU`1O[Zh0YjNW05mOU`0;09MOU`0907]kU`1OUiL0UlG509NGa@2GaLD0
YjNW0<G5a@1kUjh0UiNG0080UenG00<0GenG07=cL`25QHD00P1OG`000`1OGel0;2`/05mOU`0209MO
U`0A05nGG`1OGg/005mO002GU`00GiL005mO02`/;02G09L0UenG002GU`00GiL005mO09MOG`2GGiL0
UemO031kN`00Gel00P00GiL02`1OGiL009NG002GU`0`<7/0Lg=c09MOG`1OUiL0GiMO04U9B@2GGel0
GenG0080GemO0P00UiL04P1OUiL0GiO505nGa@00GiL009NG02`/;02G09L0UenG05mOG`1OUiL0][Jf
09L0U`2GGel0UenG08F5Q@1OUlD0][Jf0:NWY`80GiNG01D0YjNW05nGa@1OUiL0aLG_07UiN@1OGel0
aLG50;Jf]P2WYjL0][Jf09NGa@2n_ZL0000/09L0U`1OGiL0UenG0:NWY`2f][H0PkJf05o5a@000000
0`2GGiL00`2GaLD0_[jn0;Jf]P040:NWY`0309MOU`2GGg/0GenG0080GiO500P0YjNW05nGa@2GaLD0
Gjk505o5a@2WYjL0GiNG0:NWY`80GiNG00`0NiNG05nGU`1OUiL0QHF5001OG`0/;2`00000071DL02G
GiL0Lg=c09MOU`2GGel205nGU`0G07/`G`2GGiL0;2`/000/00190000;2`/000/000/;2`05QHF000/
000/0000000/02`/;00002`0000007]OU`2G09L0BDU902`/;00002`0G`0009MOU`1k<7/01P0/;2`0
300F;1H0U`1O05mOU`2GGiL0;2`/000/00190000Nemk09MOU`0/000002`002`00080;2`/0P000000
1`2G09L0UenG09L0U`1OGel0;2`/01H/5P1OGel00P2GGiL00`19BDT0;2`/02`/;00302`/;00=0000
;0000000Lg=c05mOU`165V80;00002`/;01OGel0UenG09L0G`19BDT0000001HF;00402`/;004000/
000002`0;1HF09L0U`80UenG00@0B@0002`/;00/;2`001HF0P0/;2`01@00;000;2`/02`/;00/;2`0
5R`F0080;2`/00<002`0ooooooooool01_ooool000Kooooo00H0YjNW05nGU`2GaLD0[jn_0=CDe02f
][H20<G5a@0=09O5a@2f][H0Ykjn0:NWY`19BDT0UenG05mOU`1OUiL0GenG05mkU`1cLg<005nG02`/
;00309MOU`0505mkU`2GUiL0GiNG0<G5a@1OUiL00P2GaLD02`2GTZh0UenG09MOU`2GGlD0QHF507=c
L`2GGel0UiMO05mk<019BDT0;2`/0080UenG00D0Lg=c09MOU`00Nel0GiMO05nGa@02001OG`060000
002GGel0Uc2G001OG`00Uel0Lg=c0P1OGel02`2GGiL0Gc1k05mOU`1OGiL005mO001OU`1OGel005nG
071DL01OGiL0GemO0080GiNG01<0;2`/05mOU`2GGg/0QHF505nGU`00Uel0GenG05nGU`0/;2`0<7^G
001OU`1OUiL0000009MOU`2GGel0UenG05nG[P2WYjL0001O0080UenG00d0U`1O05nGU`2^aLD0][Jf
0<G5a@2f][H0UiO50:NWY`2G05l0YjNW0820P02GGiL0][Jf0080UlG50P2f][H00`2^aLD0000009MO
U`0209MOU`060:NWY`1OUiL0GiNG05nGa@0002`0GenG0P2GGiL01@1OGiL0YjNW0:NWY`2WYjL0][Jf
0080UiNG00<0U`2G07/`U`2GGel00P1OUlD02`2GaLD0YjNW05nGa@2O][H0GiO50:NWY`1OUlD0UiNG
05o5a@25QHD05QHk0080G`1O0P2G09L0302GGiL0U`2G07]OU`2GGel0GemO09MOU`1OGiL0GiNG05mO
U`1<<7/0UenG09MOG`<0;2`/0P00;0003`0U5P00000005l0U`0002`0;2`/0000;00/0000JFUY09MO
U`1O05l0;000000/0000Gel0UemO09L`N`0202`/;00502`0000002`0;000000/000F5QH00`2GGiL0
1`0/;2`002`00000;02GGg/0U`2G000/000/;2`00`00;000200F5R`002`009MOU`1cLg<0UemO04U9
B@0/;2`001HF0P2G09L00`1OGiL0;2`/0000;00402`/;00=0000000/;2`0UenG09MOU`1R5V80;2`/
000/000/;2`0GemO07=cL`1OGel002`000000002000/000602`/;0000000UemO000/00005QH0UemO
0P2GGiL0200/;2`002`004T0000k5QH0B@0002`/;000;000B@000P0/;2`0100F000002`002`/;00/
0008ooooo`001_ooool05@2O][H0GiNG05nGU`1]Xjh0PinO08^WY`2ldm<0aLG_0<g=c@2W_[h0]/cG
05nG[P2^[Zh0Ng^G09MkU`23Wil0Njj^08Njd01kUjh0<9NG071DL00209MOU`0W07]OU`27UKT0Ykjn
0;Jf]P1O[Zh0TZj^07^G[P0`[YL0DhR809MkU`2GGiL0Ug^G09MOU`2OPil0Ph>307]kN`1OKEl0>c/k
030`C025JHD0UenG07]OU`25JHD0B6e]031OG`00Gg/0<5mk01I6AP16AV80UenG09MOR@00Gel009MO
001kN`00Gg/0C5nG07/`U`1FGfd005nG0080<5nG018007]k001kU`0`AS00NdQk09MOU`1OGiL0GiNB
05mkN`009@00UenG08UOR@0`GiL0QCYY04aON`1D<4`0<31O09L`U`0`RIL2001kN`08000U<02GGg/0
Nemk09MOU`2_[kX0NiNG05nGU`1ONg/209MOU`0>09MkU`2b/[80Ykjn09:^a@1k[/D0Njj^030`AP1k
Gg/0UenG08F@Q@1k<7/0Ng^B09bLW02;Rh/207]kTP0306=;H`2G<9L0Uemk0080NenG00/0Gjk508>O
]P25WYh0JHFL0300<02G<7/0NenG07]ON`1OGiL0R8FC07^^[P0205nG[P05069RHP16ATH0Nemk09MO
U`2GNg/00P1OUjh03P1kUiL0GiN^05nG[P23Wj/0SZFU07^^[P1OUlD0Ni:B030`G`1@D500Uen909L`
N`1kGiL0Uc2G0P1kGiL08`1k<5l0Uemk07]OU`1kGiL0Gg^B05mkU`0`UiL0Gemk058kDP2GGg/0Uc2G
05iNGP199BD05R`F02`F5P0F;1H07R4;01HF001kGg/0BBDU000F000F5QH0000F08U8K@2GGg/0E2ED
01H/5P0/;2`05R`F0300<029<8T0HTIR01H/5P005QH05QHF00805QH/04@0?2h^09L`U`2G<9L0HTI6
00005P005P00E2ED081=P02GGiL0Nc1O04``AP0k>c/05P0F00005P0F:AH0HTI609MOU`2G<9L0UenG
03/k>`005P00BAPn07/`N`1kGiL0Uc1k0680C01<AS00C31<05LHC00F5R`001HF0000;00F5QH0QCZ5
09L`N`1K8eL0;2`/000F5P0/;2`0HTIR09L`U`1kGel0ATI600/Q2`0F;1H002`001HF001@>SX0UemO
02DU9@19<4T0UenG07]ON`1YJFT0C31<04``<00`<4`0C3/n01H/5P005QH0;2`/01H/5P00;0005R`F
024F2`005QH0;1HF000F5PSooooo0006ooooo`0;09O5a@1OUlD0GiMO05nG[P1OUlD0GiNG05o5a@2G
aIL0UlG50<G5a@2^[]X00P2GUlD04P35aLD0UenG09MOU`2GUiL0NiN^09NGU`0/;2`0GenG09MOU`1O
GiL0UenG09nOW`2WYjL0UlG505nGU`2f][H0GiNG001OG`D0UenG00@0GenG08F5Q@2GGiL0QFV5102G
GiL01P1OGel005nG09MOU`19BDT0G`1O05mOG`80UenG00H0UemO07]ON`00GiL0Lg=c05nGU`00UiL2
05mOU`0;09MOU`19BDT005mO001OU`00Gel0;00005l0U`2GGiL0GemO05nGa@1OGel00`2GGiL02P1Y
>XD0GemO05mOU`2GGel0UenG09MOG`2GGiL0<7^G05mOG`2G09L309MOU`0409MOG`2_[jl0GiNG0:NW
Y`80UiNG00L0GenG09MOU`2GGg/0;2`/0000;00/0000G`1O00<0UenG00l0Pinf0:NWY`2G09L0QHF5
05mOU`1cLg<0UenG07/`N`2G09L0UenG05mOU`1OUlD0GiNG09NGU`1kNiL00P2GGiL0302G09L0UenG
09L0U`1cLg<0QCZ509MOU`1OGiL0Lg=c05mOG`2G09L0Lg=c08EYQ@80UlG500h0UiO505o5U`2GUiL0
GiO505nGU`2WYjL0GiNG05nGa@000000U`2G09MOU`2GGg/0U`2G09MOG`@0GenG0P1OUiL03`1OUlD0
GiNG05nGU`1OUiL0GemO01I6AP0002`0GenG09MOG`1OGel0Lg=c04U9B@00;000>c/k05l0G`0209MO
G`0805l0G`2GGel0GenG09MOU`1OGiL0U`1O0000;00/;2`20000000505@UE02G09L0UenG02`/;000
;0000P0000001@1kGiL0Lg=c05l0G`0002`0U`2G0080UenG00/0JCYY09MOU`0/;2`0BDU907=cL`2G
Gel0UenG09MON`2GGiL0GenG09MOU`0204U9B@8002`000X0GemO05mOU`1cLg<0GemO09L0G`1O09L0
Uc2G04U9B@1cLg<0UemO0P1OGiL0501cLg<0E2E`02`00000;000000/0000000/;2`0GenG09L0U`1k
Gel0BDU905l0G`2G09L0UemO09MOU`00;0009C/U09MOU`1OGel0UenG0`1OGel0101kGiL0;2`/02`/
;000;00402`/;003000/00190000;2`/00Sooooo0006ooooo`05001OU`1OUiL0GiNG05nG[P1OUiL0
0`2WYjL05035aIL0UlG50:NW_P35aLD0klG50<G5a@1cLg<0UenG0;Jf]P3C_[h0GiNG001OG`2GGiL0
GenG09MOU`1OGiL0[jn_0<G5k`2WYjL0GiNG0P1OUlD0101OUiL0GiN^09MOU`2GGlD209MOU`0308F5
Q@1OGel0UenG00@0UenG00@0GemO002GG`00GiL0<5mk102GGiL0101cLg<0UenG07]OU`00GiL205nG
G`04001OG`1OUiL0GenG07]OU`<0UenG00@0GenG09MOG`2GGel0QFV50P1OUiL01`1OGiL0GiNG05mO
U`1OGiL0Nemk09MOG`00GiL01@1OGiL00`1cLg<0GiNG05mOU`0309MOU`0805mkN`1OUiL0GenG05nG
U`00UiL0GiNG07=cL`1kGiL309MOU`80U`2G01<0UenG05mOU`2;YjL0aLG50;Jf]P2WYjL0UenG07=c
L`1OGiL0Uemk05mOG`1OGiL0GiNG05o5a@2WYjL0UiO50;jW_P2GUiL0Lg=c00<0UenG00@0GemO05mO
U`2GGiL0GenG0P2GGiL01`1OGiL0U`2G08>3W`1OaLD0GiO505nGU`2WYjL00P2GaLD02@2O][H0UiNG
05nGU`1OUiL0U`1O09MOU`2G05l0NenG09NGU`0209O5a@0409NGa@1OUlD0GlG507^^a@80GiO50100
GiNG05mOU`1OUiL0GemO02Dk9@0/;2`0000/02`/;01OGel0G`2G09MOU`1OGel0Nc1k09MOG`1OGiL0
000/0`0/;2`0201`E5@0U`2G09MOU`0/;2`0B@00000/000/000001HF0P1OGel03@2GGiL0GenG09MO
U`2GGiL0Gc2G04U9B@000000;00000000000;000000/05ADE02G09L00P0/;2`01`0/0000G`1O09MO
G`1kGiL0G`1O09MOU`1O05l00`0/;2`01@005P00UenG09MOU`2GGiL0BDU90080000/0`0/;2`01@00
;000000/04U9B@1OGel0Nemk008002`000L0000/02`0000002`0000/05l0G`2G<9L0UemO0080UenG
00/0Lg=c02`/;00002`05R`F09MOG`2G09L0UenG02`/;0000000;2`/01HF;00402`/;0060000;00/
;2`0;2`/000/0000000002`02?ooool000Kooooo00/005nG05nGa@00UiL0C:j^05nGU`1OUlD0aNo_
0>o5a@35aLD0][Jf0:kJhP020<G5k`080;Jf]P2GUlD0UenG09MOU`3Kfm/0YjNW09MOU`25QHD209MO
U`0305mOU`0`UlD0GiO50080GiO500`009O505nGG`1OUiL0E8>O002GU`1OUiL0GenG001OU`1OUiL0
GemO07=cL`0jJFT305mOG`8009NG00@009MO001OU`00Gel0GenG0P1cLg<01@1OGiL0GemO031kN`00
GiL0GiMO0080GiNG00@0GenG05nGU`1YQHD0Lg=c0`1OGiL02P25QHD0GiNG002GU`00UiL005nG05nG
U`1OUlD0YjNW05nGU`1ONjh207=cL`0405nGU`00UiL0GenG05mOG`80GenG00X0GiNG05nGa@1OUiL0
GiNG07=cL`1OUg/005nG05nGU`1OUel0GiNG0P00UiL0101YQHD0Lg=c05mOU`1cLg<205nGU`80GiO5
00<0RjNn0;Jf]P35aLD00`2f][H01P2GaLD0UiO50;Jf]P2f][H0YjNW05nGa@80UiO500T0YjNn09O5
a@2f][H0GiO505nGU`1OGiL0GiNG032GU`2WYjL0101OGiL00`1OUlD0PinO05nGU`0305nGa@0605nG
U`2WYjL0NiO509NGa@1OUlD005mO0`2GGiL0202GNjh0GlG50:NWY`1OUlD0YjNW05o5a@1OUlD0NiN^
101OUiL00`1OGiL005mO03/k>`020000;080;2`/00/0B@000000;00002`09@0F02`/;00002`0;2`/
0000000/0000000/01HF000302`/;0<002`000D05R`F000/000/;2`0000/02`/;00204U9B@800000
00<0;2`/0000;00/00000P0002`02@000000000/000/0000000002`00000;00/;2`0BDU902`/;003
0000008002`000H05QH/05mOU`2G09L0U`2G02`/;00/000302`/;008000/000/;2`0;2`/02`/;000
;000>aHF02`/;00002`202`/;0<0000/00@05P0F0000;00002`0;2`/0P0002`02P00000001HU09MO
U`2G09L0UemO04T00000;000000/000/000002`202`/;007000/000/;2`0;2`/02`/;0190000;2`/
00000008ooooo`001_ooool01000Gel005nG002GU`00NiL305nGU`80UlG500X0e=CD09NGa@35aNl0
aNo_0<G5k`2f][H0GemO09MOU`2n_[h0BDU9102GGiL01P1OUlD0aLG50;Jf]P1OUlD0][Jf0:NWY`80
GenG00X0LW:>05nGG`1cLg<0GiNG09NGa@00Uel0QHF505nGG`0UGRD0BDU90P00Gel01000UiL005mO
05nGG`1OGg/205mOG`0;001OG`1cLg<005mO05mOU`0`Nel009MO001OG`1OUiL0GiMO05nGU`00GiL0
0P1OUiL01000UiL005nG05nGU`2GUlD205nGU`03001OU`00UiL009NG008009NG0P1OUiL01`2GUlD0
GiNG05nGU`1OUiL0GemO05nGG`0`UiL00`1OUiL03000GiL0GiNG05nGU`0`UiL0GiMO05nGU`1cLg<0
09MO05mOG`1OUiL0Njj^002GU`<0GiNG00@0GiO505o5a@2GaLD0UiN^0P2f][H309O5a@040<G5k`2n
_[h0GlG505o5a@80UlG500H0GiO509O5a@2O][H0GiO509O5a@2WYjL405nGU`80YjNW101OUiL205nG
a@03002Ga@00UiL0GiNG0080GiO500T0WinO09NGa@2WYjL0GemO07=cL`2G09L0UenG09n3P`2GUlD0
0P2GaLD30:NWY`0808>f]P2WYjL0GiNG05nGU`00GiL0GemO04U9B@0F5R`602`/;00@0000;00F5R`0
000/0000000002`0;2`/0000000002`09@0F0000;000;00000000000;0000000;000000/0080;2`/
00D0000002`0000/0000000/01HF5P0202`/;080000/00<0;000000/000U5P001000;00202`/;004
01HF;000;000B@000000008002`000H0000001HF5P1O05l0GenG09MOU`19BDT2000/000601HF5P00
0000;00002`/;00002`000000P00;00020000000000/000/000/0000000002`/;00002`05QH/0P0/
;2`02000;000;2`/0000;00002`0<00009L0U`1OGiL0UenG0`0/;2`02`0F5P00;2`/000/000/0000
;2`/000/000002`05R`F02`/;000;000000000Sooooo0006ooooo`09001OU`00UiL005mO031kU`1O
GiL009NG05nGU`2GaLD0YjNW0080UlG500T0aLG_0<G5a@35knl0aLG_09O5a@2GGiL0[Y:^001OG`1O
GiL00`2GGiL01@2GaLD0a<C405nGU`1OUiL0YjNW00<0GiNG00`0Gi:^05mOG`1OGiL005mO0<G5a@00
Gel0GiMO04U9B@0UE5@005l0001OG`00UiL2001OU`0505mOU`0`Gg/005mO05mOG`1OUiL00P1OGiL0
1000GiL0<7]O05mOG`1OGel2001OU`0605nGG`1OUiL009NG05nGU`00GiL005mO0P00GiL01`1OUlD0
NiN^002GU`00Uel005nG05nGU`00UiL00P1OUiL01`2GUiL0GiO505nGU`00UiL0GiNG05mOU`1YQHD0
0P00UiL205mOU`@0GiNG00<0GenG001OG`00UiL00P00UiL00`0`Gel0GiNG05nGU`0305nGU`80GiO5
00<0PinO09NGa@2GaLD00`2f][H01035aLD0Ykjn09NGa@1OUlD209O5a@0:0;Jf]P1OUlD0Pinf05nG
a@2GUlD0GiO505nGU`2GUiL0GiNG05nG[P@0GiNG00<0UiNG05nGU`1kUiL00P1OUlD04`1OUiL0UiNG
05nGU`1OUiL0NiNG0:NWY`2GUlD0GiNG09L0U`2GGiL0U`2G09MkTP2GaLD0YjNW09O5a@1OUlD0GlG5
0:NWY`23WkH00P1OUiL00`1OGel005nG05l0G`0702`/;08002`000P0;2`/0000;00/0000B@000000
;0000000B@0002`/;080000/00D0;0000000;000000002`001H/5P0202`/;00804T0000/;2`0000/
02`/;00F;1H0;0000000;00/;2`20000;00502`000005P00000002`00000;0000P0/;2`00`00;000
5QHF0000;0020000;08002`000T0000001HF;01cLg<0G`1O07=cL`1OGel000000000;00000000P0/
;2`01@0002`00000000/000/;2`0000/0080;2`/00H002`00000000/000002`002`0000F5R`202`/
;080000/00L002`00000000F;1H0GenG07=cL`2GGiL0;2`/0080000000<0;1HF02`/;000;0000P0/
;2`01P0002`0B@0001H/5P00;000;2`/000/00Sooooo0006ooooo`<005mO01@0Ng]O05mOG`00Gel0
09NG002Ga@1OUiL0GiO505nG[P35aNl0aLG50<G5k`35aLD0e=CD07=cL`2WRjL0GenG09MOU`1OGiL0
UenG09NGa@80YjNW00d0aLG509O5a@2GUiL0UiNG05nGU`00GiL0Gemk05mOG`1OGiL0GiO505nGU`00
Gel0GiL00080BDU900<0Gel005mOG`1OGiL00P1OGiL02P1OUiL0<5nG05mOU`00GiL005mO002GU`00
Uel005mO06V5J@00Gel205mOG`0405mOU`1OUiL009NG032GU`D0GiNG0P2WYjL00`00UiL0GiNG002G
U`02002GU`80GiNG0P1OUlD01@2GUiL0GiO50:NWY`1OUiL0NiNG008009NG00L005nG002GU`1OUiL0
GenG032GU`1OUiL0Lg=c0080GemO00P0GiMO002GG`1YJFT0GenG07=cL`1OUiL0GenG002GU`<0GiNG
0`2WYjL01P2GaLD0YjNW0;Jf]P35aLD0][Jf09O5a@80YjNW00L0UlG50;Jf]P2WYjL0GiO509NGa@2W
YjL0UlG50080GiNG00<0WinO09O5a@2GUlD00P2GUiL205nGU`<0YjNW0P2GaLD02`2GUiL0YjNW07^G
U`1OUiL0UiNG05nGU`2GGel0GemO09MOU`1YW9`0UiO50080UlG50`1OUlD02P1O[Zh0GiNG0000;000
Gel005nG001OG`0/;2`05QH002`/;000;00502`/;009000F0000000002`00000;00/000002`002`/
;0005QH0;0000080;2`/00@0000/02`/;000;0005QHF0P00;00402`/;00301HF;00/;2`0;2`/0080
;2`/0P0002`01@0/5QH0;2`/02`/;00002`0;2`/008002`000<05R`F0000;00/00000P00;0020000
000501HF001cLg<0GemO05mOU`19BDT00P00000302`/;0<0000000L0000/02`/;00/;2`0;2`/000/
0000000002`00080;2`/00<05QHF0000000002`00P0000003@00;000;2`/04HFAP2G09L0GenG09MO
U`0/;2`002`002`000005QH002`002`/;00000000`0/;2`0100F5R`0;2`/02`/;00/;2`8ooooo`00
1_ooool0A`0`Gel005mO001OU`0HKFd0SHf=001OG`0`Ng/0>VV505mk[P00NiL0<8VS07^^[P1k[/D0
T/G50;Jfb`33aMX0[jn_08UOU`2GGiL0Ug^G08ibSP2GGiL0_[jn0;Jf]P2f`/80_[kC09nf]P2;YjL0
GiNG08^W_P1OUiL0<6f906UYQ@0`NiL0>VV5001kN`00Nel0<7]O01I65P0mE3d0BDU9001OG`00Ng/0
<9Mk001OU`1OGiL0B5nG05mOU`00Ng/007]O06UYJ@00NiL0Gg]k001]K@0`GiL0<7^G002GN`1OUg/0
<9Mk032GU`1YThD0<9NG002GN`00NiL0<9NG05mkU`1OUiL0HiNG05nG[P1OUiL0>XF50080<7^G00H0
GiNG05mkU`1OUiL0GiNG05nG[P1O[Zh208>OW`0907FOW`1k[Zh0RjNW02DUE01k<7/0Uemk05mON`0e
LW80>XEY00<0<9MO03H0<7]O002GN`0HGg/0<9Mk03Z5Q@0`Ug/0GiMk06UYJ@0`Ng/0GiNG04R9X`1O
Ujh0UiN^09nOW`23WkH0[jn_08^W_P2f`/80Ykjn0;jn_P2n_]<0_[jn09nf]P2W_ZL0YjNW08>O]P2O
][H0YjNn09nf]P2_[jl0Ujj^07^^[P1OUlD0Gjj^07^GU`2O]Yl0Gjj^07^G[P2EXjl0_ZNn0:Nn_P2_
[jl0Pinf09nf]P2GaLD0Vk:n08>O]P1k[Zh0[jn_05l`N`2GGiL0Uc2G08eoV`23WkH209N^a@0;08>f
]P2OWil0WinO07nKV`1OUiL0000/09MOU`00Gel0;2`/01H/5P0N5P/00P0F5R`0600k5QH05R`F02`/
;00F5R`0>aHF01H;5P005QH05R`F02DF000F;1H0000/01H/5P1T<7H0Uc1k07]O<00F5QH05QH/02D0
000001H05R4Q01H/5P0F5QH0000F01H05P805QH/00<001H002D05P0F5R`00P0/;2`0300F5QH00000
01H/5P0F;1H001HF01H00000;000000F01HF;00d=3@002`0000F0080;2`/014001H001H05P0F8b<0
GSXj05ADL01kGel0GemO000F5P005P008AHQ000F000/5QH05R`F000F001YJFT0Nc1O06mCH@02000F
5P0901H/5P005QH05QH/0000;00F01H08B`Q02`/;00F5R`0000F0080000000D0000F03/^>`1RAV80
L2E`09MON`0201H/5P0<01HF;00/8B4001HF00005P0/;2`05R`F01HF000F;1H05QH/01H/5P0/;2`0
01HF2?ooool000Kooooo0`00Gel00`00Gg/009MO05mOG`0205nGG`04002GU`19BDT0<7]k05nGa@80
GiNG00@0YjNW09NGU`1OUlD0UYJF0`2GGiL0202f][H0aLG50<G5a@35aLD0][Jf09O5a@2WYjL0UlG5
0P1OUiL01P1OGiL0Lg=c002GG`1OUel009NG002GG`8005l000D0E5AD001OG`00Gel009NG05nGU`02
05mOU`04032GU`1OUiL0GiNG05nGU`<0GenG00D0<7]k001OU`1OUel0GiNG07=cL`0305nGU`0407=c
L`00Uel005nG001OG`80GiNG00@0NiNG002GU`1OUiL0GenG0P1OUiL01P2WYjL0LXj>05nGU`25QHD0
GenG002GU`@0GiNG00l009NG05l0G`2GGel0UenG09L0U`1OGel0GiNG002GU`1OUiL009MO002GU`00
Uel005mO07=cL`1OGiL00P1OUiL02000GiL005mO05nGU`1OUiL0GiO505nGU`1OaLD0GiNG0P2GaLD0
2@1kaLD0UlG50:NWY`1OUlD0UlG50;Jf]P2GaLD0GiNG09NGa@0305nGa@H0GiNG00@0YjNW05nGU`1O
aIL0PkJf102WYjL0701OUiL0UiNG0:NW_P2f][H0UlG509NGa@1OUlD0G`1O05mOU`1k<9L0GlG505nG
a@1OaLD0GlFG05o5a@2GaIL0NiNG07=cL`0/;2`0UenG04U9B@00;0000000000/0019000002`002`0
0000;0020000;00;0000000002`0000/02`/;00002`002`00000000/;2`0Uc1O09MOG`2GGiL00P0/
;2`01`0002`0;2`/03/F5P0/;2`002`004T00000;0000P0000000`0/0000000/02`/;00202`/;080
02`000D05QHF02`/;00002`0;00002`/;00200000080000/00<000000000;00002`00P0/;2`0100F
01H000000000;00002`30000000301HF;00/0000000/0080000000H0UemO09MOU`2G<5l0;2`/000/
000000020000;00602`0000002`05P00000/00000000000/0`0000000`005P0002`0000/000402`/
;00501HF;000;00002`0000/000/;2`00P00;000100F9@00;2`/02`/;000;008ooooo`001_ooool0
1P00Gel005l0001OG`1ONel005mO07=cL`<0GemO00D009NG05nGU`00GiL0YjNW09O5a@020:NWY`03
05nGU`1OTZh0UenG0080UenG0P2GaLD01@35aNl0aLG50<G5a@2f][H0GiO500<0GiNG00<0JHF505nG
G`00Uel00P1OUel0301OU`00BDU902`/;01DE5@0Gel004U9B@00GiL0GiNG002GG`1OUiL007^G001O
U`80GiNG0P00UiL01P1OUiL0<9Mk05nGU`2GUiL0GiNG002GU`H0GiNG0100GenG002GU`00UiL0GiNG
05mOU`1OGel0GenG07=cL`1OUlD0YjNW08F5Q@1OUiL0GiMO002GU`1OUiL009NG0P1OUiL00`1OGiL0
GiNG05mOU`0209MOU`0505mOG`1OGiL0GiMO002GG`00UiL00P00Uel00`1OUel0>VV505nGU`0205nG
G`80GiNG00L0GiMO05nGU`1OUg/0QHF505nGU`2WYjL0UiNG0080YjNW00@0PkJf0:NWY`1OUiL0][Jf
0`2GaLD01P1k[/D0YjNW05nGa@1OaLD0GiNG0:NWY`<0GiNG0P2GUiL01P1OUiL0YjNW05nGU`2;Ykh0
UlG50;Jf]P80YjNW00<0GlG50:NWY`1kaLD0102GaLD01`2GUiL0UenG09L`U`1OGel0GiNG09NGU`2G
UlD00P2GUiL0200`Ng/0001909MOG`2GGiL0BDU90000000/00005R`F0P00;0002@19000002`0000/
000/;2`0000/03/k>`00000002`00000;00202`00009000/001kGel0U`1O05l0G`0/;2`0B@00000/
000/;2`05R`F008002`000H0;0000000;00002`0000/00005P00000202`/;007000/000/;2`00000
01H05P000000000/000/00030000000;000/000/0000B@0002`/;00002`0;2`/000/000F5QH0;2`/
0000000/0000100000002P0002`0000002`/;00002`0U`1O09MOU`1`E700;2`/04U9B@1O00020000
0080000/00P0000F0000;0000000;000000/000/;2`002`0000F5P@0;2`/0P0000001@0F01H00000
0000;00/0000000/0080;2`/00@0000/02`0000002`002`02?ooool000Kooooo0P00Gel01019BDT0
<5mO001OG`00Gel305mOG`04001OG`1OUiL009MO09NGU`80GiNG00<0UlG505nGU`0`NiL00P2GGiL0
1P1OUiL0GiO509O5a@35aLD0cLg=0<G5a@80][Jf00H0YjNW05nGU`00UiL0Gg]k07=cL`1OUel205nG
U`0905mOG`19BDT0Gel003/k>`19BDT005mO002GU`1OUiL009NG0080GiNG00X009NG05nGU`00Uel0
09NG001OG`00UiL0<9NG05nGU`00GiL009NG0P2GUiL03P2WYjL0<9Mk05nGU`1OUiL005nG05nGU`00
GiL0GenG05mkU`1OUiL005nG05mOG`1OUel009MO0P1OUiL01@1OaLD0UiNG09NGU`2GUiL0GlFG0080
GiNG00/0GlFG05nGU`1OUiL0GenG05mOG`25QHD0GiNG002GU`1OUiL0Lg=c05o5U`0205nGU`04002G
U`1OUiL0GiNG05nGU`@0GenG0`1OUiL00`1OaLD0YjNW0<G5U`020:NWY`0709NGU`2WYjL0UiO50;Jf
]P35aLD0][Jf0:NWY`0209NGU`0305nGa@2GUiL0GiNG0080GiNG0P2WYjL01P2f][H0YjNW09O5U`2W
YjL0[jn_05o5a@80GiNG00D0GiO505nGU`1OUlD0GiNG09NGU`0309O5a@0>09NGa@25QHD0QFV509MO
U`2GGel0BDU905l0G`00;000000004aOG`2GGel0UenG05mOG`1O05l200000005000F0000;000;2`/
0000;00/00000P0002`00`0/;2`09C/U02`/;003000/00060000;00/;2`05QH/02`/;0000000;000
0P0/;2`00`0/0000000/02`/;0030000;005000/000000005QHF000/000000001000;00200000006
04T00000;00000000000;00/00005QH00P0002`202`/;00904U9B@00;00002`0000000190000000/
02`/;000;000000/00<0000000`0;2`/0000;000;000;2`/01H/5P00;000;2`/0000000002`00000
0000;000;004000000<002`01@0/;2`02P00;0000000000000190000000/000/000/000002`002`/
;00F;1H202`/;00300000?oooooooooo00Kooooo0006ooooo`06001OG`1OGel0BDU902EDE000Gel0
09MO0P00Gel205mOG`04031k<01OGel0GiNG09NGG`8005mO00H0GiMO05mOG`1OGiL0UenG0:NWY`1O
Uel20:NWY`030;jn_P2WYjL0UlG50080aLG50P1OUiL00`1O[YL0GiNG08F5Q@0205nGG`<0BDU900@0
Gel`05mOG`00UiL005nG2@1OUiL00`00UiL0Gg]k002GU`0405nGU`8009NG00L0GiNG0:NWY`00UiL0
GiNG09NGU`1OUiL0GiN^0080GiNG00<009NG05nGU`1OUiL0101OUiL01`25QHD0GiNG05nGU`1OUiL0
LXjU05nGU`1OUlD00P1OUiL00`00UiL0GenG05nGU`0305nGU`09002GU`1OUiL0GiNG032GU`1OUiL0
GiO505nGU`1OUel0Lg=c00@0GiNG00<0GiO505o5a@2WYjL00P2WYjL01@2f][H0UiNG05nGU`1OUlD0
UlG50080][Jf00<0YjNW09NGU`1OUiL00P1OUiL0102WYjL0GiNG08>OW`2GaIL20:NWY`040;Jf]P2W
YjL0UlG507^GU`80GiNG00`0GlFG08F5Q@2GUiL0GlFG05BfW`1OUiL0GlG50;Jf]P2GaLD0][Jf09O5
a@23Pil209MOU`0709L0U`2GGiL0UenG09L0U`2GGiL0U`2G09MOU`0202`/;006000/000/;2`0;2`/
000/000/;2`002`00P0/;2`02P00;000;2`/03/F5P0002`0;000000/000/000002`002`0000F5QH2
00000080000/00<00000000/000/;2`00`0/;2`01`0002`002`002`0000U5P00;0000000000/0000
0`0000000`0001H002`0000/0002000000<002`00`0/;2`01@0002`00000000000005P00B@0000@0
000/00<0;2`/00005P0000000P000000300002`000000000;00002`002`00000;000;000000/0000
000002`00000000F0080000000D002`002`/;000;00002`002`/;005000/000<0000;00U5P00000/
000/000/;2`002`002`0000002`002`002`/;000;00000002?ooool000Kooooo00<005mO05mOG`00
Gel01`00Gel06@0FAQH0BDU905mO002WYjL005mO002GG`1OUel0Gg]k05nGa@2GUiL0][Jf09NGU`00
UiL0GiNG0:Nn_P2WYjL0UlG509NGU`1OUiL0UiNG08F5Q@1lO7`0GiNG09NGU`1OGel00P19BDT02P1O
Gel0BDU902ED9@1OUel009MO002GU`2WYjL0GiNG0:NWY`1O[Zh205nGU`0508F5Q@1OUiL005nG05nG
G`0`NiL00`1OUiL0101OUlD009NG05nGU`0`UiL305nGU`0608F5Q@2GUiL0GiNG05nGU`1OUlD0YjNW
0P1OUiL00`2GUiL0GiNG09nOW`0405nGU`0405nGa@1OUiL0GiNG05nGa@80GiNG00<005nG05mOU`1O
UiL01`1OUiL00`1kUiL0GiNG05nGU`0205nGU`8009NG101OUiL0102GUiL0UlG50:NWY`2GaLD20:NW
Y`060;Jf]P2GaLD0UiO50<G5a@2f][H0WkJf0P2GUiL0102GUlD0GiNG05nGU`1OUiL40:NWY`0?05o5
U`1OaLD0UiNG05nG[P2GUiL0GiNG0:NWY`2GaLD0GlG509O5a@2OWil0QHF505nGa@2GUlD0][Jf0080
YjNW00@0WinO0:NWY`1OUiL0Lg=c101OGiL00`1OUiL0BDU902`/;00202`/;003000/000/;2`0;000
0080000/0P0/;2`01@00;000;00002ED9@0/;2`0BDU9008002`00P0000000`005P0002`0000/0005
02`/;08002`000P0000/00000000;00002`002`F5P0/;2`0;0000000;080000000T0;00002`F5P0/
;2`002`002`00000;000000/0000000k00000P0/;2`01`0002`0;2`/0000000/;2`0>aHF02`00000
02`00P0/;2`00`00;000;00001H05P020000000702`0000002`000000000000F5R`0;2`/000/0005
00000004000/000/0000000000000080000/00@0;00002`/;000;00002`00P0/;2`20000;00302`/
;00002`0000/0080;2`/00H0000/04T000005QH0000/02`/;00/0008ooooo`001_ooool01P19BDT0
GemO05mOG`00Gel009MO001OG`<0GiNG00@009MO01IRAP1OUel0Gel00`1OGel00`2GUiL0JIb505nG
U`020:NWY`0;05nGU`00UiL0Lg=c05mkTP2WYjL0e=CD09O5U`2WYjL0QHF507=cL`25QHD00P1OGel0
1`1OUel0BDU9001OG`19BDT0GemO05mk<01OGel00P2GUiL0101OUiL0YjNW05nGU`1OUjh;05nGU`04
002GU`1OUel009NG05mOU`D0GiNG00P0PinO09NGU`2GaLD0UiNG05nGU`2GaLD0UiO50:n_[`80GiNG
00/009NG05nGU`1OUiL0GiNG07^GU`00UiL0GiNG002GU`1OUiL009NG05mOU`0905nGU`0305o5U`1O
UiL0GiNG00<0GiNG00P009NG05nGU`2WYjL0YjNW05nGU`1OUlD0UiNG0:Nn_P80YjNW00D0UiO50:NW
Y`2WYjL0GiO507^GU`0605nGU`0309nfW`2WYjL0GiNG0080GiO500<0UiO50:NWY`1OUiL00P1OUiL2
05nGa@0>05nGU`2GUiL0WinO0:NWY`2GaLD0][Jf09O5a@2GUlD0UlG508>O]P1OUiL0GiO509NGU`2W
YjL205nGU`0306UYQ@1OGel0BDU90080;2`/00L0000/02`/;00F5R`0;2`/0000;00/;2`0000/0080
;2`/00L0GemO07]kN`19BDT002`002`/;000000002`0008000001@00;0001P0/;2`05QHF000/000/
;2`002`004T00080;2`/00@05QH002`/;00002`0000/0`00;0000`0/;2`002`0000/000202`/;080
;00000@002`002`/;00/;2`0000/0P00;0000`0/;2`05R`F0000;0020000;0<0;2`/00D0000F0000
000/0000;0000000;00200000003000F5P000000;2`/00@0000000T0;2`/01H/5P0/00000000000/
000/;2`002`002`/;00F;1H01@0/;2`02P00;00001H00000000/0000000/02`000000000000/01H/
5P19000202`/;0Sooooo0006ooooo`0505mOG`00Gel0GemO031kG`00GiL00P00Gel03@1cLg<0GemO
002GG`0`Gel0BDU905mO001OUel005mO001O0019BDT0GiMk08F5Q@1OUiL00P2WYjL0301OUel0GiNG
09:^TP2f][H0UiNG08F5Q@2WYjL0GiNG07=cL`1YQFT0UiMO05nGU`80GemO0P00Gel03@1cLg<0O7al
05mOG`2GUiL0GiO509NGU`2WYjL0UiNG08>OW`1OUiL009NG05nGU`1OUlD00P1OUiL00`0`UiL0UiO5
0;Jf]P0305nGU`03002GU`0`Ujh0GiNG008009O50P1OUiL02`00UlD0GiNG0:NWY`1OUiL0GiO509NG
a@2f][H0YjNW07^^a@1OUiL0UiNG00<0GiNG00@0YjNW05nG[P1OUiL0QHF50P1OUiL01000UiL0YjNW
08>OW`25QHD305nGU`0405o5a@2GUiL0Gjj^05o5a@<0GiNG00@0GiO505nGU`1OUiL0NiNG1@1OUiL0
0`1OaLD0NiNG05o5a@0205o5a@0305nGU`2WYjL0UlG50080GiNG00H0GenG05nGU`1OUlD0UiNG0:NW
Y`1k[YL405nGU`0305o5a@1OUiL0GjjG0080GiO500P0GiNG05o5U`2WYjL0YjNW08>OW`2GaLD0YjNW
09O5a@80UiO50P2WYjL02P1OUlD0GlG505nGU`2WYjL0GiNG002GU`1bSXh0GemO02`/;000;00204T0
000602`/;00F00000000000/000/0000B@000P0/;2`01019BDT0>c/k02`/;00/;2`60000000:0000
;000;00002`002`00000;00001HF0000;0000000B@000000;080;2`/00@002`00000000002`00000
0`00;00202`/;00>0000000/;2`0;2`/0000;00/;2`05QH/02`/;000;000;2`/0000;00/000002`0
01HF5P00;003000000060000;00/;2`05QH/02`/;000000002`00`0000002@005P00000/000/0000
;000000/0000000/;2`00000000F5P020000000>000/000/;2`0;2`/02`/;00/5QH0;2`/0000;000
0000;2`/000/000/00005P00000/000/;2`20000;080000000@001HF000/000/;2`002`02?ooool0
00Kooooo02/0<7]O001kG`1ONel0GiMO05ADE00`Nel0E8>3031OG`0`Nel0<6T`049J@P0UGRD0Gg]O
031OG`1kUg/005mO05AD9@1JMUX0Gg]O08>3W`1kUg/0GiMk031kG`1ONel0L71n07^^[P1kTZh0SHf=
05nGN`25QFT0<7]O049XFP1bLT<0JFTj07]kN`1OUiL0JHF508f=S@2fbkH0ZkK10;Jf]P2G[/D0WkJf
0080GiN^00H0NiN^04RGX`0`UiL0GiNG032GU`1OUjh205nGU`0F032GU`2B[/D0PinO05nGU`1OUjh0
Njj^05nGU`1JVjL0<9NG07^GU`1OUlD0YjNn05nG[P1OUiL0GiNS07^^a@1k[YL0WkJf09N^a@2GaLD0
YjNn0;:W/P80WkJf00L0Ykjn0;jn_P1kaLD0Pinf076W/P1OUjh0Pinf0080PinO00d0Pinf09nO]P23
Zj/0[/G50:Nn_P2f][H0TZj^07^^U`1OUjh0SJNK08>OW`1OUjh0NjjG0080GiNG01@0NiN^05nGa@1o
Vk80GlG50:NWY`1O[/D0PkJf09nOW`2WYjL0Xj>S05nGU`1kUiL0GiNG08>fW`1OTYL0PinO05nGX`1O
UiL0Njj^05nG[P80YjNW00T0PinO05nGX`2OWil0NiN^07^^[P2WYjL0NiN^05nGU`1]Xj<00P1OUiL0
402WYjL0Gjj^08>OW`2WYjL0SK:n08>O]P2GaLD0Ykjn0;Jf]P2GaLD0WkJf09F_^P1OUlD0Gjk508>O
]P1kUiL205nGU`0404Q]N`0/;2`0;2`/01HF;0805R`F00L0>aHF000F5P00000001H001H05P0U5P00
5R`F0080;2`/00/05R4F01H00000;0005R`F01H0000001H000000240000F0000;2`/000F5P020000
0006000/000Q8B405QHF02DF000k5QH0;2`/0P0F;1H02P0;8@/05QHF000F000F00005P0F01H00000
01H04aH;01HF000F;1H201HF5P80;2`/00@0:B4F02`/;00/;2`05R`F0P0F5R`0100001H00000000/
000F5P0201HF;00301HF5P0U01H02`0Q008001H000D05QHF0000000000000000000;2`02000F0003
01H0000F01H000000080000000H05QHF01HF;000000002`0000F5P005P0201HF;00301H0000001H0
5QH000<001H000/000/;000000005QH05R`F0000000/5QH05QHF01HQ8@00;0005QH/01HF0008oooo
o`001_ooool02@1OGel0Gel005mO000`JC00GemO05nGG`1OU`0004T00025000205mOG`0605nGG`1O
Gel0YjNW04U9B@1OGel0BDU90P1cLg<07`2GUiL0GiMO09MOG`1OGel005mO02EN9@1cLg<0GiMO05mO
G`1OUel0GemO04U9B@0`JC00GemO07=cL`2GUiL0GiNG0:NWY`1OaLD0UlG507^^[P2GaIL0YjNW05nG
a@2GaLD0GiO505nGU`0`UiL0GiO505nGU`2WYjL00P1OUiL01P25QHD0PkJf05o5a@1OUlD0UiNG0:NW
Y`80GiNG00<0Gjk509NGU`1OUiL00P2GUiL20:NWY`0505nG[P1OUlD0GiO505nGa@2WYjL00P2f][H0
302O][H0YjNW09NGU`2WYjL0UiO509O5a@2WYjL0WkJf05o5a@2GUlD0YjNW0;Jf]P80aLG500<0aJk5
09O5a@2GaLD00P35aLD02`2f][H0UiNG09nOW`1OUlD0GiNG0:NWY`1OUlD0GlG5002GU`1OUiL0PkJf
0080UlG500D0][Jf0:NWY`2WYjL0UiNG07^^a@0205nGU`0>05nGa@2WYjL0GiNG05nGU`23WkH0UlG5
05nGa@2GaIL0YjNW05nGa@1OaIL0<9N^0:NWY`2GUlD405nGU`0408>OW`1OUlD0UiNG05nGa@<0YjNW
00@0Ujk509O5a@2GUlD0UiO50P2f][H01@2GaLD0WkJf0:NWY`1OUlD0UiO50080GiNG00H0QHF5031O
N`00;00002`002`/;0190002000/000903/F5P00000000000000;00/;2`002`00000;00/;2`05QH0
008002`000H0;2`/000/0000;000;2`/01H/5P0/;2`20000000402`00000;00002`001HF00@002`0
0P0/;2`0100F5QH0000/000/000/000202`/;00500000000;00002`002`0000000000P0/;2`02P00
;000;2`/02`/;00/;2`002`000000000;000000002`0000002`200000004000/000002`0;2`/01H0
00<002`00P0000000`0/0000;1HF0000;003000/000502`000000000000/000/000/;2`00P00;000
100/;2`000000000000F5R`2000/0080000000H002`0000000000000;000000/000002`2000/0005
02`/;0005P0000000000;00000002?ooool000Kooooo0`1OG`000`1DE5@0BDU9001OG`0304U9B@0<
07=cL`1`L5@0GemO05mOG`2GUiL0GiMO05mO0019BDT0IfMW08F5Q@2GUlD0GiNG0P1OGel04`1OUel0
<5mO09MOG`19BDT0GiNG04U9B@1OGel005mO05mOG`1OGiL0UlG50<G5a@2WYjL0UiNG05nGU`2f][H0
NiMk05nGU`25QHD00P1OUiL01`2GUlD0GiNG002GU`2GUiL0GiO505nGU`1OaIL00P1OUiL0101kUjh0
GiO505nGa@2GaLD205o5a@0305nGa@1OUiL0YjNW0080GiO500/0GlG505nGa@2GUlD0NiN^09NGU`00
UlD0GiNG09NGU`2WYjL0UlG50:Nn_P0209O5a@050;Jf]P2GaLD0UiO50:NWY`2B[/D00P2GaLD0202G
UlD0][Jf0;Jf]P2f][H0UlG50:NWY`2f][H0UlG50P2f][H00`1OUlD0Pinf09O5a@020:NWY`0>05o5
a@1OUlD0GlG505nGU`1OUjh0UiO509O5a@2WYjL0][Jf0:NWY`2GaLD0YjNW09NGU`2WYjL305nGa@04
05o5a@2G[/D0GiO509NGa@<0YjNW0P1OUiL00`2GaLD0][Jf0:NWY`0209NGU`0305nGU`1OUjh0UiNG
00<0YjNW00@0GiO509O5a@23WkH0UiO50`2GaLD00`2WYjL0UlG507^^a@0209NGU`0=0:NWY`1OUlD0
GiNG07=cL`1DE5@0;2`/000/000/;2`0000/000/000002`0>aHF000/0002000000080000;00/;2`0
;2`/000/00005P0002`002`000190002000/0004000000005P00000/02`0008002`000<0000002`/
;00F;1H00P00;00202`/;004000/000002`05QH/0000;08002`00P0002`02@0/;2`09AH0000/0000
;000000002`/;000;00005mO01HF;00202`/;00E000/00000000000002`/;00U9BD0000/02`00019
0000000/04T0000/;2`002`00000000/;2`000000000;0000000000/00005P000000;000008002`0
0P000000100002`05P0F0000;000;0040000000500005P0/;2`002`002`/;000;0000P0/00001@00
0000;2`/0000;00/;2`002`000<000000P00;0000`00003oooooooooo`06ooooo`001_ooool03`1O
Gel009MO04U9B@1ONc0005mO02`/;02GUel0BDU9001OG`2GaLD0Ni9k05mOU`1OUiL0UiO509NGG`02
05mOG`0407^^[P2WYjL0aLFG04U9B@80GemO00<005mO05mOG`1OGel00P1OGel01@1OUel0GemO07=c
L`1bLW80Lg=c00<0YjNW01<0Lg=c09NGU`2GUiL0QIbL05nGU`2GUiL0YjNW05o5a@2GaLD0YjNW05n^
[P1OUiL0GlFG05o5a@1OUiL0YjNW05nGU`2G[]X0][Jf00<0UlG50P1OUlD00`2>SXh0GiO505nGa@02
05nGU`0605nGa@2WYjL0_[jn0:NWY`1OUiL0YjNW0P1OUlD02P2GUiL0[/GJ0;Jf]P35aLD0UiO509O5
a@2f][H0GiO509N^fP35aNl309O5a@0;0;Jf]P2GaLD0UlF^0:NWY`1OUlD0GiNG05nGa@1OUiL0][Jf
0:k5a@2WYjL00P1OUlD08`2f][H0GiO505nGU`2GaLD0Winf09O5a@1OUiL0UiO509O5a@2WYjL0UiO5
09nOW`1OUiL0YjNW05nGU`1OUlD0GiNG09NGU`2OWil0UlG509NGa@1OaLD0GiNG05nGa@1OaLD0Njj^
09NGU`2WYjL0UiNG0:NWY`1OUiL0YjNW05nG[P1OUlD0YjNW0080UlG500D0YjNW09NGU`23][H0GiO5
0;Jf]P0409O5a@0<07_5a@1OUlD0YjNW0:NWY`1OUiL005nG05mOU`0k>c/002`004T0000/;2`0000/
0P0/;2`0100F5R`0000002`0000002`202`/;00902`00000000000000000000/;2`0000/02`/;000
;000;00000<0000000H0000/000000000000;2`/01HF5P0002`202`/;007000/00000000000/01HF
;00/0000;2`/00000002000/000A02`/;00F;1H0;2`/02`/;0000000;0000000;0000000000F02`/
;000000002`000000000;000;2`/0000000/;2`00P0002`01`000000000/0000;00001H00000000/
000/00000`0002`04@0F5QH0000/000/000/0000000/000/00000000000/01HF;00002`002`002`0
000002`0B@0002`000005QH00000008002`000D0;2`/0000;000;0005P00000/000202`/;005000/
000/00000000000F000000000P0/0008ooooo`001_ooool01019BDT0Gel005mO001OGc0304U9B@03
001OG`19BDT0GlG50080Lg=c00@0GiNG0:NWY`1OUiL0GiMO0P1OUiL02`1OGel0UemO09NGU`25QHD0
GiMO05mOG`1ONc0005mO04U9B@00Gel0GemO0080Lg=c00<0@g:>07=cL`1OUiL00P1OUiL0101cLg<0
UiNG05nGU`2f][H305nGU`0404U9B@1OGel0GiNG07^B[P80GiNG0P1OUlD02P1OUiL0UlG509NGa@2G
UlD0][Jf09NGa@1OUiL009NG05nGa@2OWkH305nGa@0?05o5a@2GUlD0GiO508>OW`2GUiL0YjNW05nG
U`2WYjL0UiNG05nGU`2;Ykh0aLG509O5a@35aLD0aIO50080UlG500D0_[kC0;Jf]P2GaLD0aLG509O5
a@020:NWY`0308>fW`2GUiL0GiNG0080GiO500P0UlG50;Jf]P1OaLD0YjNW05o5a@1OUiL0GiO509O5
a@80GiO50100GiN^05nGU`1OUlD0QHF50:NWY`2GUiL0UlG507^GU`1OUiL0GiO505o5a@1OUlD0GlG5
0:NWY`2O][H0GiO50P1OaLD0401OUlD0YjNW05nGU`1kUiL0GiO505nGU`25QHD0GiNG05nGa@1OUiL0
Pinf05o5a@2GaLD0UiO505nGa@2GUlD30:NWY`090;Jf]P2GaLD0UlG509O5a@2WYjL0WinO0:NWY`1O
UiL0GiO5008005nG00@005mO01H/5P0/;2`0000/0`0/;2`02`0002`001HF000/0000;00000000000
;0000000;000000/00000000;0000080;2`/00D00000000/000000005P00000/000202`/;0050000
;000;000;2`/000F000/00000P0002`03@0/;2`0B@000000;00U5P0002`002`/;0000000;2`/000/
000/;2`05QH00000000/0000100/;2`00`0F5QH0B@0002`0000302`/;0040000;00F5P00000/0000
;0<0;2`/0`0000001@0/0000000/02`/;00/;2`002`00080000/00<002`002`0000002`00P000000
0`0/;2`0000F0000;002000/00<0000/00@05P0F000/000/;2`002`00`0002`0100F01H002`0000/
0000;0020000000502`0000F0000000/07=cL`0002`02?ooool000Kooooo00/0GemO04U9B@19BDT0
Ph>307=cL`1OG`0005mO05nGa@1OGel005mO05A`E00205nGU`0707=cL`1OUlD0QHF505nGG`1OGc00
GiMO08F5Q@020:NWY`0305mOG`19BDT0Gg]O00<0GemO00H0UiNG05nGU`1OaLD0WinO0:NWY`2GUiL2
05nGU`80UlG501P0GiNG07]kG`1cLg<005mO05mO001OUel005mO05nGU`0`UiL0UiO50:NWY`1OaLD0
YjNW05o5a@1OUlD0Pinf0:NWY`1OaLD0GiNG001OU`00Uel005nG05nG[P1OUlD209O5a@040;Jf]P1O
UlD0GiNG05n^a@80UlG500T0][Jf05nGa@1OUlD0UlG509N^a@2WYjL0UiO50;Jf]P35aLD00P2GaLD0
402f][H0UiO509O5a@35UlD0][Jf0:NWY`1OUlD0NiN^05o5a@1OUiL0GiO509NGa@2f][H0UlG50:n_
[`2f][H209NGa@0<05nGa@00UlD0YjNW09NGa@1k[/D0GlG505nGU`2GaLD0GiO509O5a@1OUlD0Gjj^
0P1OUiL01@1OUlD0UlG50:NWY`2GUlD0YjNW00<0GiNG0P2WYjL01P1OaLD0Gjk505nGU`1OUiL0YjNW
05o5a@80UiNG0140Winf05o5a@2WYjL009O505nGa@1OUiL0GiO508>OW`2GaLD0UiO50;Jf]P2WYjL0
GiO509O5a@2G[Zh0YjNW05nGa@0205nGU`0:001OG`19BDT0;1HF0000;00/;2`0000/0000000/;2`0
0000000F5P8002`000<0;0000000000000000P0002`020005P0002`00000;00/;2`002`000000000
;0005R`F0`00;0030000000700005P000000000/0000;00/;2`0000/02`/;002000/000802`/;000
;000000/02`/;000;0009@0F02`0000002`302`/;003000/000F5R`002`000<0;2`/00D0000/04T0
00005QH0;2`/0000;00302`/;003000/000F0000;00000D0000/0P0000000`0/;2`0000/00000003
0000000301HF5P0002`000000080000/0P000000100002`0;00002`/;000;0020000000802`00000
01H002`0000/000/;2`002`00000000/0002000/000302`/;000;03ooooo00Oooooo0006ooooo`0M
05mO001cLg<0GemO08>3E02GUel0QHF507=cL`2GGiL0GenG05nGG`1<L4`0GenG07=cL`1OGel0UemO
001c0000G`00<5l`04U9B@1cLg<0GenG0:NWY`1OUel0GemO05ADE025QHD0Lg=c0:NWY`2GUiL00P1O
UiL02@2^aLD0GiNG05nGU`2GGiL0][Jf07=cL`19BDT0UiMO05ADE00204U9B@0607=cL`19BDT0GiNG
05nGG`0`Ng/0GiO5101OUiL02@1OaLD0GiNG05nGU`1OGiL009MO001OG`1cLg<0GenG032GU`0205nG
a@0409O5a@2GaNl0UlG509NGU`80GiNG00H0][Jf0:NWY`1OUiL0GlG505nGU`23]Yl20:NWY`0609NG
a@2GaLD0UlG509O5a@2O][H0UiO50`2f][H00`2WYjL0GiNG05BOW`0505nGU`0305nGa@2O][H0UlG5
0080UlG500X0YjNW05nGa@1OaLD0GlG508>OW`1OUlD0GlG505nGa@1OUiL0UiNG101OUiL01`2WYjL0
UlG509NGa@1OaLD0Gjj^05nGU`2WYjL00P1OUlD01P2GUiL0GiNG07^^U`2GaIL0YjNW09NGU`80GiNG
00@0GlG508>O]P1OUiL0YjNW0P1OUlD0201OaLD0GiNG07^GU`1OUiL0][Jf09O5a@2GUlD0UlG50P2W
YjL01`2GUiL0GenG07=cL`00UiL005mO04U9B@0/;2`00`00;0001@0/;2`002`00000;00/5QH0;2`/
008002`000H0000/02`/;00/;2`0;2`/01HF00000002000/000402`/;000;00002`001HF5P800000
00D0000/000000000000000/01HF;007000/000:0000;000;000;2`/04T0000002`0;2`/0000;000
0000000/02`/;0<002`000<001HF02`/;000;0000P0/;2`01P00000002`00000000/0000000/02`0
00<002`001005R`F02`/;000;000000002`/;00/0000000/01HF0000;000000/02`/;0000000;000
000/00000000000F0P0000004`0002`0;000000000000000000/02`/;000;000000002`00000;000
;2`/00000000;000000/00000000;000GemO02`000005P000P00;0000`00003oooooooooo`06oooo
o`001_ooool0900FD1H0<5mO05nGG`1RNWX0Ph>309nfW`25QHD0SHf=08^WY`1YQHD0GemO07alO01k
Ug/0E5AD05mOG`0UE5@0<5mO05YJ@P1bLW80Ng^G09nOW`1kUiL0Ph>305AD9@1TI6@0<5l`05ADE01b
SW80RjNW07^GU`25W9`0Zl;208FLW02=SHd0TYMk07]kC080E5AD02809EAD01i=7P19BDT0E5@U04U9
B@1DE5@0<5mO079bLP1XLfP0BDU9001OG`1ONg/0Gg^G05nGN`1OUiL0LJNK032GU`1OUjh0Ph>3031O
N`1OGel0Gemk04R9R@1OUiL009NG07^Ga@1k[/D0[jn_08^WY`1aVi/0LXj>07^G[P1kUlD0PinO0P1O
Ujh08`29Xj<0GiNG07^GU`1OUiL0TZjG09N^U`2_[jl0Zj^[09nf]P23WkH0UiN^05nG[P23WkH0GiNG
076KV`1OUiL0Gi:G05nGU`0`NiL0<9N^032GU`1FUjh0][Jf0:Nn_P2n_[h0Ykjn05n^a@1OUjh0Njj^
09^K/P2WYjL0GiN^05nGU`1kUjh0NiNG00<0GiNG02L0E9nO09nf]P1k[/D0Ujk508>OW`18RJ<0<7^G
032GU`1OUiL0GiN^05nGU`1OUjh0SI^W0:NWY`2OWil0NiN^07^GU`2OWil0UjjG05nGX`2>YJD0NiO5
05nGa@1O[Zh0Njk505nG[P1kXjh0WkJf09O5a@2O][H0Njk507^G[P23WkH0Oi^W07^G[P0`UiL0GiNG
05mkU`0UE5@00P0/;2`02`005P005QHF02D05P0F5P005QH/000/000Q8AH00000000F000F;1H05QH/
00805R`F02h002`001hQ2`005QH05QH001H/5P0/;2`0000F01H/5P0;01H05P000000000F00005QH0
000F000F5R`0000Q000/000U5P005P0F0000;00F000001H002<S000F;1H05QH001HF5P0001H002`0
02`/;00F5QH002`0000F000F;1H0;2`/0000;00/;2`05QH/01HF000F;1H00000000F5P0001H001HF
02TF8@0U01H05QH/0P0/;2`03@0F5QH05QH000/05P0F5R`001H000005P0F5R`0000/000F000;2`/0
01H001HF;00001H00P0F5QH06`005P00000F01H02`0F;1H0000000005P0002`05P000000;00001H0
JFUY000F0000;00001H001HF000001H02b4;01H/5P0000005P00000/000001H0000001HF;000;000
5QHF00000008ooooo`001_ooool0:`19BDT0GemO0;Jf]P23Ph<0GemO05nGU`2WYjL0UlG50:NWY`1O
UiL0UIFE09O5a@1cLg<0GemO0;Jf]P25QHD0UemO06MWI`1OGel0UemO05nGa@2GUiL0GiNG08F5Q@0j
JFT0Lg=c05mOG`19BDT0GemO001OG`2GUiL0<7]k04U9B@2WYjL0GemO04U9B@1OGel0BDU905mO001O
Nel0GemO05nG001OG`000`00Gel02P1DL5@0;2`/0019001OGel005l005nGG`00Gel0<9NG07=cL`1O
Uel2001OG`0405mOG`00Gel0GenG05mOG`80GiNG00@0GiO509NGa@35aLD0RjNW201OUiL0202GUiL0
GiNG05nGU`2WYjL0UiNG09nOW`2GaLD0GiO50P1OUiL00`1OUlD0GiNG05nGU`0405nGU`06002GG`00
UiL0GlG50:NWY`2GaLD0UiO50P2GaLD04`2f][H0YjNW0:NWY`1OUiL0YjNW09NGa@2GaLD0GlG505nG
U`1k[Zh0][Jf09O5a@2GUlD0GiO509NGU`00UiL0<9NG001OU`00UiL0101OUiL02P2GUjh0GiNG05nG
U`2GUiL0GlFG05nGa@1OUiL0PkJf09NGU`2GUlD20:NWY`0>09NGU`2WYjL0YjNW0:NWY`2f][H0UiO5
05nGa@1OaLD0YjNW05nG[P1OUiL0GenG05nGU`00Gel202`/;00501H/5P00;000;2`/000/000/0000
0P0002`02@0/;2`0;000000/00190000;2`/0000;00/000002`002`/;00202`00080000000d0;000
0000;00F01H0000/02`0000002`0;2`/000/000/;2`002`002`00000;000;00000<0000/0100000F
0000000/0000000/000/00000000;2`/02DF000002`002`002`/;00002`0B@00000/000F5R`0000/
0P0/;2`01@00;000000/02`/;00/;2`0000/00<0;2`/00<002`002`/;0005P000`0002`202`/;00;
0000000F;1H0000005mOG`0002`0001902`/;000000002`001H05P0/;2`00P0000004P0002`00000
0000;000;000;0000000;00/;2`002`00000000/00005QHF02`/;00002`0Gel00000;00/00000000
000F00<000002?ooool000Kooooo00`0GiMO05mOG`1OGel0UYJF05nGG`1OGel0UiO509NGU`1OUiL0
GemO08f=S@2GUel205mOG`0605nGG`00Gel0YjNW07:>SP1cLg<0GenG0`2WYjL02P2GUiL0>VUY05nG
G`00Gel0BDU905mO001OGel0BDU904I65P0/;2`204U9B@08001O0019BDT005l002`/;00`Nel0GemO
001O0000L`0305mOG`0404U9B@1OGel004T004U9B@8005mO00@0GiMO06UYJ@1OGel0GiMO0P1OGel2
001OG`0805mkN`1OUiL0GenG05nGU`2f][H0UiO505nGU`2;YjL605nGU`0:07^GU`2WYjL0GiNG05nG
U`1OaIL0GiNG05nGa@1k[YL0YjNW09NGU`L0GiNG00D0GiO505nGU`00UiL0GiNG05nGa@0209O5a@05
0<G5a@2f][H0UlG509O5a@2f][H00P2WYjL305nGU`0405nGa@1OUiL0Ykjn05o5a@80GiNG00@0GiO5
05nGU`1OUiL0<9NG1P1OUiL01`2O][H0YjNW0:NWY`1OUiL0UiNG05nGU`1OaLD0102WYjL08`2GUiL0
UlG50;Jf]P2_[jl0UiO509O5a@1OaLD0GlFG05nGa@2WYjL0GiNG05nGG`1OUiL0GemO04U9B@00;000
;00000005P190000000/04T0000002`0000002`000005QH0;000000/000002`0;2`/000/000/;2`0
02`001H/5P00;000000/00<0;00000L0000/01HF;00002`0000/02`/;000;000;2`/008002`000L0
000002`/;00002`0000/02`0000002`000000080;2`/0P0/000202`/;0050000;00/;2`0;2`/0000
;019BDT00`0/;2`0100002`0;2`/02`/;00/;2`2000/000301H/5P00;000;2`/0080000/00<002`0
0000000F;1H0100/;2`200000009000F0000000000000000002GUiL0aLFG000/000/000001HF0080
;00000P0000/0000000/;2`0;00000005P0/;2`002`00000;080000000L0000/00000000000002`0
0:NWY`0/;2`0000/00<0000000<0000/00000?ooool01oooool000Kooooo00d0GemO05nGG`2WYjL0
GiMk07=cL`1OUel0GiNG09NGU`1OUiL0GemO05A`L01OGel007<00080BDU900X0GemO001OG`2LW;40
GiNG0:NWY`1OGel0GiNG0:NWY`25QHD0LW9b0P19BDT03P00G`00GemO05mOG`0/;2`0<4H`05mOG`19
BDT0Gel005mOG`19BDT0Gel005mOG`00Gel007<00P1OGel01000Gel0GiL005mOG`1DE2D205mO0007
001c0000Gel0Gel004U9B@0UE5@005mO002GU`0205nGG`8005mO00D0Gemk08F5Q@1OUiL0GiNG05nG
a@020:NWY`0307^^a@2GUiL0GiNG00@0GiNG00d0NiO509O5U`2GaIL0GiO508F5Q@1OUiL005nG05nG
U`2GUiL0YjNW09NGU`1OUiL0GenG00@0GiNG00H0GiO5002GU`1OUel009NG08>OW`2WYjL20;Jf]P05
09NGa@2GaLD0UiO505o5a@2_[jl00P2f][H02@2WYjL0GlG505o5a@1OaLD0WkJf05o5U`2WYjL0UiNG
05mOU`0305nGU`03002GU`1OGiL0GiNG0080GiNG00d0YjNW08>OW`2WYjL0YjNW09NGU`1OaIL0GiO5
09NGU`2FUYH0GlG50:NWY`1OUlD0UlG50080][Jf00<0NiO509NGU`1OUlD00P2GUiL01`2WYjL0GiO5
06V5Q@1OUiL005nG001OG`19BDT00P0/;2`01@0/5QH002`0000/00000000;2`/0080000000D05P0F
0000;00002`002`00000000602`/;0050000;000000002`002`00000;0000`0/;2`0100/0000;2`/
0000000F01H20000;0030000000/0000;0000080000000<002`002`/;00/00000`00;0001P0F0000
;2`/000/0019000002`002`/;0<002`00`0/00000`0/;2`002`001HF000302`0000400000000;000
;00001HF008002`000H0;2`/000/0000;000;00001H00000000202`0000600000019BDT000000000
00005P0002`00P00000202`000060000;0005P0002`005mOG`0/;2`0;0000P000004000/00040000
0000;0000000000F0080000000<002`0ooooooooool01_ooool00?oooooo3oooool00?oooooo3ooo
ool00?oooooo3oooool00?oooooo3oooool00?oooooo3oooool00?oooooo3oooool00?oooooo3ooo
ool00?oooooo3oooool00001\
\>"],
  ImageRangeCache->{{{0, 269.125}, {358.812, 0}} -> {-7.30152, -9.89046, \
1.42407, 1.42407}}],

Cell["\<\
Fig. 3.6 Artist's depiction of a tether made of carbon nanotubes. \
Arist: D. M. Miller.\
\>", "Caption",
  CellTags->"Fig. 3.6"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Assuming that the mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " per unit length of the tether is  constant, show that the tension ",
  Cell[BoxData[
      \(TraditionalForm\`T(r)\)]],
  " as a function of distance ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " from the center of the earth is"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`T(r) = \[Rho]\ \(W(r)\)\  + \ T\_o\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`W(r) = 
        G\ M\_e/r\  + \ \(\[Omega]\^2\) \(\(r\^2/2\)\(\ \)\)\)]],
  "is  the potential energy per unit tether mass, including potential energy \
associated with centrifugal force,  ",
  Cell[BoxData[
      \(TraditionalForm\`M\_e\)]],
  " is the mass of the earth, ",
  Cell[BoxData[
      \(TraditionalForm\`T\_o\)]],
  " is an integration constant that depends on the load tension at the base \
of the tether, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = 2  \[Pi]/\((24\ hours)\)\)]],
  ". Evaluate and plot this tension versus  ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ", assuming that \[Rho]=50 kg/m, that the tether is carrying no load, and \
that it is not attached to the earth at its base. What is the maximum value \
of the tension (in newtons) and where does it occur? (Hint 1: There are two \
competing forces at play on a mass element ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]m\)]],
  " in the tether: the centrifugal force due to the earth's rotation, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[DifferentialD]m\), " ", \(\[Omega]\^2\), "r", " ", 
          StyleBox[
            OverscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "^"],
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", and the gravitational attraction of the tether to the earth ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(-\[DifferentialD]m\), " ", "G", " ", \(M\_e\), 
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"],
              FontWeight->"Bold"], "/", \(r\^2\)}]}], TraditionalForm]]],
  ". Neglect the attraction of the tether to itself and to the massive \
satellite. Hint 2: For the massive satellite, recall that for a point mass ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\)\(\ \)\)\)]],
  "the radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\_g\)]],
  " of geosynchronous orbit is given by the solution to the force balance \
equation ",
  Cell[BoxData[
      \(TraditionalForm\`G\ M\_e\ m/R\_g\^2 = m\ \[Omega]\^2\ R\_g\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", "=", 
          FormBox[\(2\ \[Pi]/\((24\ hours)\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  ". Here, neglect the effect of the tether mass on the satellite orbit. Hint \
3: Assuming that the tether is attached only to the satellite, not the earth, \
 the tension force applied to the tether by the satellite must  balance the \
total integrated centrifugal and gravitational forces on the tether.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " The previous design is not optimized: the tension in the tether varies \
considerably with altitude, but the force ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " required to break the tether does not because the tether has uniform \
cross section. It is better to design a tether where the ratio of the \
breaking force to the tension is constant: ",
  Cell[BoxData[
      \(TraditionalForm\`F/T\  = \ S\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " is the safety factor, taken to be around 2 or 3 in many engineering \
designs.  Now, the breaking force ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " of the tether is proportional to its  cross-sectional area ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  ", according to the equation ",
  Cell[BoxData[
      \(TraditionalForm\`F = \ \[Tau]\ A\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " is the tensile strength of the material (in ",
  Cell[BoxData[
      \(TraditionalForm\`newtons\ per\ square\ meter\)]],
  "). Also, the density per unit length, \[Rho], is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\  = \ \[ScriptCapitalM]\ A\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalM]\)]],
  " is the mass density (in kilograms per cubic meter).  "
}], "Text"],

Cell[TextData[{
  "\t Find the cross-sectional area ",
  Cell[BoxData[
      \(TraditionalForm\`A(r)\)]],
  " such that the safety factor ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " is constant with altitude. For a boundary condition, assume that there is \
a loading tension ",
  Cell[BoxData[
      \(TraditionalForm\`T\_l\)]],
  " applied at the base of the tether, at ",
  Cell[BoxData[
      \(TraditionalForm\`r = R\_e\)]],
  ", (",
  Cell[BoxData[
      \(TraditionalForm\`R\_e\)]],
  " being the radius of the earth). Show that"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`A(
          r)\  = \ \(\(S\ T\_l\)\/\[Tau]\) \[ExponentialE]\^\(\
\[ScriptCapitalM]S\/\[Tau]\)[W(r) - W(R\_e)]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Plot  the radius of the tether, ",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          RowBox[{
            FormBox[\(A(r)\),
              "TraditionalForm"], "/", "\[Pi]"}]], TraditionalForm]]],
  " (in meters), assuming that it is made out of the strongest and lightest \
commercially available material (as of the year 2000), ",
  "Spectra",
  " (a high molecular-weight form of polyethylene), with a mass density of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalM]", "=", 
          RowBox[{"970", " ", 
            RowBox[{"kg", "/", 
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "3"]}]}]}], TraditionalForm]]],
  " and a tensile strength of ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(\(\[Tau]\)\(=\)\),
              "TraditionalForm"], 
            FormBox[
              RowBox[{"3.5", "\[Times]", \(10\^9\), " ", 
                RowBox[{
                  StyleBox["N",
                    FontSlant->"Plain"], "/", 
                  SuperscriptBox[
                    StyleBox["m",
                      FontSlant->"Plain"], "2"]}]}],
              "TraditionalForm"]}]}], TraditionalForm]]],
  ". Take as the safety factor ",
  Cell[BoxData[
      \(TraditionalForm\`S = 2\)]],
  ".  Take ",
  Cell[BoxData[
      \(TraditionalForm\`T\_l = 10, 000\ Newtons\)]],
  ". What is the total mass of this tether?"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Redo the calculation and plot of part b) for a tether made of carbon \
nanotubes. Take the same parameters as before, but a tensile strength 40 \
times greater than that of Spectra. "
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Waves in shallow water: ",
    FontSlant->"Italic"],
  " Waves on the surface of water with long wavelength compared to the water \
depth are also described by the wave equation. In this problem you will \
derive the equation from first principles using the following method, \
analogous to that for a wave on a string. During the wave motion, a mass of \
fluid in an element of unit width into the paper, equilibrium height ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " and length ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " moves a distance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " and assumes a new height ",
  Cell[BoxData[
      \(TraditionalForm\`h + z(x, t)\)]],
  " and a length ",
  Cell[BoxData[
      FormBox[
        RowBox[{\((1 + \ \[PartialD]\[Eta]/\[PartialD]x)\), 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ", but remains of unit width into the paper. (See Fig. ",
  ButtonBox["3.7",
    ButtonData:>"Fig. 3.7",
    ButtonStyle->"Hyperlink"],
  ".)"
}], "Text",
  CellTags->"i:48"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P0001h2000`400?l00000o`00003oo`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3o
oonn0?ooo`040820P0000000000000000:00oooo003o0?ooool0ooooF`3oool30820P600oooo00@0
P8200000000000000000BP3oool30820P5<0oooo003o0?ooool0ooooFP3oool01020P80000000000
0020P81P0?ooo`040820P00000000000000004X0oooo00@0P8200000000000000000DP3oool00?l0
ooooo`3ooomJ0?ooo`<00000HP3oool4000004X0oooo0`0000000`20P800oooo0?ooo`1?0?ooo`00
o`3ooooo0?oooeX0oooo0`00001R0?ooo`@00000B`3oool300000540oooo003o0?ooool0ooooF@3o
ool3000006<0oooo1000001<0?ooo`040820P000000000000820P4l0oooo003o0?ooojP0oooo5`00
00000`3oool0P82000000002000000X0oooo00<0P8200000000000000P0000240?ooo`<00000I@3o
ool3000004d0oooo00@0P820000000000000P820CP3oool00?l0ooooZ@3ooolF00000080oooo1000
00090?ooo`040820P00000000000000008D0oooo0`00001U0?ooo`@00000C03oool01020P8000000
00000000001>0?ooo`00o`3ooonZ0?ooo`030000003oool0oooo00d0oooo100000040?ooo`@00000
203oool4000008@0oooo100000140?ooo`H000006`3oool4000000@0oooo0`00000J0?ooo`D00000
9`3oool4000004d0oooo003o0?ooojX0oooo00<0@41000000020P800303oool00`20P80000000000
0002000000D0oooo00D0@41000000000000000000<30`0050?ooo`050820P0000000000000000020
P800DP3oool00`20P80000000000000D000000030?ooo`10@40000000080000000<0`<300?ooo`3o
ool01`3oool4000000030<30`03oool0oooo00D0oooo0`0000000`20P800oooo0?ooo`0A0?ooo`@0
00005P3oool300000140oooo00<0P8200000000000001`0000020820P0`0oooo100000080?ooo`@0
0000103oool01@20P8000000000000000000`<3001@0oooo00<0`<30000000000000200000000`20
P800oooo0?ooo`080?ooo`040410@000000000000410@0X0oooo100000000`30`<00oooo0?ooo`06
0?ooo`<0000000<0P8200?ooo`3oool0BP3oool00?l0ooooZP3oool00`20P80000000000000<0?oo
o`D000001P3oool4000000D0oooo100000000`20P800oooo0?ooo`1B0?ooo`0300000020P800oooo
00d0oooo100000030?ooo`@00000203oool5000000L0oooo00D0P82000000000000000000820P00D
0?ooo`<000005P3oool01020P800000000000000000?0?ooo`h00000303oool4000000P0oooo1000
00040?ooo`@00000503oool>000000T0oooo100000080?ooo`D000002P3oool4000004/0oooo003o
0?oooj/0oooo0`00000;0?ooo`D000001`3oool3000000@0oooo1@00001E0?ooo`8000003P3oool4
000000@0oooo100000070?ooo`@00000203oool01@20P8000000000000000000P82001@0oooo1000
000E0?ooo`040820P00000000000000000l0oooo1P0000040?ooo`D000002`3oool4000000P0oooo
100000050?ooo`<00000503oool5000000@0oooo1P0000090?ooo`@000001`3oool4000000/0oooo
00@0P8200000000000000000B`3oool00?l0oooo[03oool2000000030<30`03oool0oooo00P0oooo
100000090?ooo`060820P000000000000820P03oool0P820100000000`20P800oooo0?ooo`1D0?oo
o`800000303oool00`20P800000000000002000000D0oooo00D0P82000000000000000000<30`004
0?ooo`D00000203oool01@20P8000000000000000000P82001@0oooo1000000E0?ooo`040820P000
00000000000000h0oooo00<0P8200000000000000P0000070?ooo`030820P0000000000000800000
00<0P8200?ooo`3oool01`3oool4000000P0oooo100000060?ooo`<0000000<0P8200?ooo`3oool0
3`3oool5000000L0oooo00D0@41000000000000000000410@0090?ooo`050410@000000000000000
0030`<00103oool5000000/0oooo00D0`<3000000000000000000820P01:0?ooo`00o`3ooon]0?oo
o`8000002@3oool00`20P800000000000002000000X0oooo0`0000000`20P8000000000000030000
05L0oooo00<0P8200000000000002`3oool00`20P800000000000002000000H0oooo00@0P8200000
00000000P8200`3oool00`20P800000000000002000000T0oooo00@0P82000000000000000005@3o
ool4000001D0oooo00@0P82000000000000000003P3oool01@20P8000000000000000000P82000T0
oooo00D0P82000000000000000000820P0080?ooo`@00000203oool4000000L0oooo0`00000A0?oo
o`@000002P3oool4000000T0oooo0`0000001020P800oooo0?ooo`3oool5000000d0oooo1000001:
0?ooo`00o`3ooon]0?ooo`8000002@3oool00`20P800000000000002000000X0oooo00<0P8200000
000000001@00001I0?ooo`8000002`3oool01@20P8000000000000000000P82000L0oooo0`000003
0?ooo`030820P00000000000008000002@3oool01020P800000000000000000E0?ooo`040820P000
00000000000001H0oooo0`0000000`20P800oooo0?ooo`0;0?ooo`050820P0000000000000000020
P8002@3oool00`20P800000000000002000000T0oooo100000070?ooo`050820P000000000000000
0020P8001P3oool01020P800000000000020P80@0?ooo`@000002P3oool5000000T0oooo0`000003
0?ooo`D000003P3oool3000004X0oooo003o0?ooojh0oooo0P0000080?ooo`030820P00000000000
008000002`3oool7000005T0oooo0P0000000`20P800oooo0?ooo`080?ooo`050820P00000000000
00000020P800203oool300000080oooo100000000`20P800oooo0?ooo`070?ooo`040820P0000000
0000000001D0oooo00D0P82000000000000000000820P00E0?ooo`<0000000<0P8200?ooo`3oool0
2`3oool01@20P8000000000000000000P82000X0oooo100000090?ooo`@000001`3oool01@20P800
0000000000000000P82000H0oooo00@0P8200000000000000000403oool4000000/0oooo1000000:
0?ooo`<0000000<0oooo0820P00000000`00000?0?ooo`@00000B@3oool00?l0oooo[P3oool00`20
P80000000820P0070?ooo`050820P0000000000000000020P800303oool00`20P800000000000002
000000030820P03oool0oooo05P0oooo0P00000:0?ooo`@0000000<0P8200?ooo`3oool01P3oool0
1@20P8000000000000000000P82000@0000000<0`<300?ooo`3oool01`3oool01@20P80000000000
00000000`<3001@0oooo00D0P82000000000000000000820P00E0?ooo`<0000000<0P8200?ooo`3o
ool02`3oool01@20P8000000000000000000P82000/0oooo00D0P82000000000000000000820P007
0?ooo`@000001`3oool01@20P8000000000000000000P82000L0oooo00@0P820000000000000P820
3`3oool4000000`0oooo00@0@410000000000000@4102@3oool01@20P8000000000000000000@410
00<0000000<0@4100?ooo`3oool03@3oool01@20P8000000000000000000P82004P0oooo003o0?oo
ojl0oooo0P0000000`20P800oooo0?ooo`040?ooo`@0000000<0P8200?ooo`3oool02`3oool40000
00030820P03oool0oooo05T0oooo0P0000090?ooo`@0000000<0P8200?ooo`3oool01`3oool00`20
P800000000000005000000X0oooo00D0P82000000000000000000820P00D0?ooo`050820P0000000
000000000020P8005@3oool3000000030820P03oool0oooo00/0oooo00D0P8200000000000000000
0820P00<0?ooo`@000001`3oool4000000030820P03oool0oooo00@0oooo00D0P820000000000000
00000820P0080?ooo`@000003P3oool4000000`0oooo00@0P82000000000000000002P3oool00`20
P800000000000004000000030820P03oool0oooo00h0oooo100000180?ooo`00o`3ooon`0?ooo`03
00000020P800oooo00D0oooo100000000`20P800oooo0?ooo`0:0?ooo`D0000000<0P8200?ooo`3o
ool0F@3oool00`20P80000000?ooo`080?ooo`@000002`3oool6000000/0oooo00D0P82000000000
000000000820P00E0?ooo`<0000000<0P8200?ooo`3oool02`3ooolE000000030820P03oool0oooo
0080oooo1000000=0?ooo`<0000000<0P8200?ooo`3oool01@3oool3000000030820P03oool0oooo
00D0oooo0`0000000`20P800oooo0?ooo`070?ooo`<000003`3oool4000000`0oooo1000000:0?oo
o`H000004@3oool4000004P0oooo003o0?oook00oooo00<0P8200000003oool01@3oool400000003
0<30`03oool0oooo00T0oooo00<0P820000000000000100000000`20P800oooo0?ooo`1H0?ooo`04
0<30`000000000000820P0H0oooo00<0P8200000000000000P00000<0?ooo`D000002`3oool01@20
P8000000000000000000P82001D0oooo1000000=0?oooaD0000000<0P8200?ooo`3oool00P3oool4
000000d0oooo00@0@410000000000000P8201`3oool4000000L0oooo100000090?ooo`050820P000
0000000000000030`<003@3oool4000000`0oooo00@0P82000000000000000002`3oool500000180
oooo0`0000000`20P800oooo0?ooo`150?ooo`00o`3ooona0?ooo`8000001@3oool4000000`0oooo
1@000000103oool0000000000000001K0?ooo`8000001P3oool5000000/0oooo1P00000;0?ooo`05
0820P0000000000000000020P8005@3oool4000000d0oooo5@0000000`20P800oooo0?ooo`030?oo
o`@00000303oool01020P80000000000000000020?ooo`030000003oool0oooo0080oooo0`000000
0`20P80000000?ooo`050?ooo`@000002P3oool3000000030820P03oool0oooo00/0oooo00D0P820
00000000000000000820P00<0?ooo`@000002@3oool600000180oooo0`0000000`20P800oooo0?oo
o`150?ooo`00o`3ooona0?ooo`030820P0000000000000<0oooo1@00000;0?ooo`030820P0000000
0000008000000P3oool3000000030820P03oool0oooo05P0oooo0P0000000`20P800oooo0?ooo`03
0?ooo`D000002`3oool7000000X0oooo00D0P82000000000000000000820P00E0?ooo`@000005P3o
ool3000000l0oooo1@00000;0?ooo`040820P0000000000000000080oooo00<000000?ooo`3oool0
0P3oool3000000030820P0000000oooo00D0oooo1000000;0?ooo`<000003@3oool00`20P8000000
00000002000000`0oooo100000090?ooo`H0000000<0P8200?ooo`3oool03`3oool3000000030820
P03oool0oooo04D0oooo003o0?oook80oooo0P0000030?ooo`D000002`3oool00`20P80000000000
000200000080oooo00@0P8200000000000000000F`3oool00`000000P8200?ooo`040?ooo`@00000
2`3oool00`20P800000000000005000000030820P03oool0oooo00P0oooo1000000F0?ooo`<00000
5`3oool3000000l0oooo1000000;0?ooo`040820P00000000000000000<0oooo00@0P8200?ooo`3o
ool0oooo0`0000000`20P800oooo000000050?ooo`@000002`3oool4000000d0oooo1000000<0?oo
o`@00000203oool00`20P80000000000000500000140oooo0`0000000`20P800oooo0?ooo`150?oo
o`00o`3ooonb0?ooo`030820P000000000000080oooo100000000`20P800oooo0?ooo`090?ooo`04
0410@00000000000000000@0oooo00D0P82000000000000000000820P01I0?ooo`030820P0000000
P82000<0oooo00<0P8200000000000000P00000;0?ooo`060410@0000000000000000010@400oooo
0`0000000`20P800oooo0?ooo`070?ooo`@000005P3oool4000001H0oooo0`00000@0?ooo`040410
@000000000000410@0/0oooo100000020?ooo`040820P03oool0oooo0?ooo`<0000000<0`<300?oo
o`3oool00P20P8020?ooo`050<30`0000000000000000010@400303oool01020P800000000000020
P80=0?ooo`050820P0000000000000000020P8002`3oool4000000L0oooo00H0@410000000000000
00000820P03oool3000000030820P03oool0oooo00d0oooo00@0P8200000000000000000A`3oool0
0?l0oooo/`3oool2000000030820P03oool0000000<00000303oool3000000030820P03oool0oooo
00@0oooo1000001I0?ooo`030820P0000000oooo0080oooo1@00000;0?ooo`@0000000<0P8200?oo
o`3oool0100000080?ooo`@000005P3oool4000001H0oooo0`00000@0?ooo`030820P00000000000
008000002P3oool400000080oooo00<0P820000000000000100000040?ooo`030820P00000000000
00@0000000<0P8200?ooo`3oool02`3oool4000000d0oooo100000000`20P800oooo0?ooo`080?oo
o`@000001`3oool4000000<0oooo1000000>0?ooo`040820P00000000000000004L0oooo003o0?oo
ok@0oooo1`00000;0?ooo`@0000000<0P8200?ooo`3oool0103oool01020P800000000000000001I
0?ooo`030820P000000000000080oooo1@00000;0?ooo`@00000103oool3000000030820P03oool0
oooo00H0oooo1000000E0?ooo`@000005P3oool300000140oooo1@0000080?ooo`030820P0000000
000000800000103oool4000000L0oooo1000000?0?ooo`040820P00000000000000000h0oooo1000
00090?ooo`D000001`3oool3000000050820P03oool0oooo0?ooo`20P8000`0000000`20P800oooo
0?ooo`0;0?ooo`040820P00000000000000004L0oooo003o0?oookD0oooo1P00000;0?ooo`@00000
00<0P8200?ooo`3oool01@3oool3000000030820P03oool0oooo05L0oooo0P0000020?ooo`@00000
2`3oool5000000@0oooo00@0P8200000000000000000203oool4000001H0oooo0`00000F0?ooo`<0
00004P3oool5000000L0oooo00<0P8200000000000000P00000S0?ooo`<0000000<0P8200?ooo`3o
ool02`3oool00`20P800000000000002000000P0oooo1@0000060?ooo`@0000000<0P8200?ooo`3o
ool00P3oool4000000d0oooo00@0P8200000000000000000A`3oool00?l0oooo]@3oool00`10@400
000000000002000000030820P03oool0oooo00P0oooo1@0000090?ooo`040820P000000000000820
P5P0oooo00@0P820000000000000P8201000000:0?ooo`030820P00000000000008000001P3oool0
1020P80000000000000000080?ooo`<0000000<0P8200?ooo`3oool04`3oool4000001H0oooo0`00
000B0?ooo`030820P0000000000000<000001020P806000002<0oooo00@0P8200000000000000000
3P3oool20820P0@0000000D0@4100820P020P800P8200410@006000000D0oooo00<0P82000000000
00000P0000060?ooo`040820P00000000000000000`0oooo00@0P8200000000000000000A`3oool0
0?l0oooo]@3oool00`20P800000000000002000007L0oooo1P00000:0?ooo`D00000203oool30000
00L0oooo1000000E0?ooo`@000005P3oool3000001@0oooo3P00000U0?ooo`<000003`3oool00`20
P80000000000000<000000D0oooo1@0000080?ooo`<000002`3oool01020P8000000000000000017
0?ooo`00o`3ooonf0?ooo`@00000M`3oool6000000T0oooo00<0P8200000000000000P0000090?oo
o`040820P00000000000000000L0oooo0`0000000`20P800oooo0?ooo`0B0?ooo`@000005P3oool3
000001H0oooo3000000U0?ooo`@00000403oool=000000@0oooo1@0000090?ooo`040820P0000000
00000820P0X0oooo00@0P8200000000000000000A`3oool00?l0oooo]`3oool2000000030820P03o
ool0oooo07H0oooo1000000:0?ooo`030<30`020P800P8200080P8202P3oool30820P0030<30`03o
ool0oooo00@0oooo00@0P820000000000000@4105@3oool3000000030<30`03oool0oooo01<0oooo
0`20P80H0?ooo`D0P82000<0oooo0000000000000P00000V0?ooo`040410@000000000000820P140
oooo00<0`<300820P020P8000P20P8020?ooo`@00000103oool50820P0X0oooo0`20P80:0?ooo`04
0820P000000000000410@4L0oooo003o0?oookP0oooo00<000000?ooo`3oool0M`3oool01020P800
000000000000000T0?ooo`<000005@3oool3000000030820P03oool0oooo03@0oooo1000000W0?oo
o`<00000603oool400000200oooo0`0000000`20P800oooo0?ooo`150?ooo`00o`3ooonh0?ooo`03
0820P03oool0oooo07P0oooo0`00000T0?ooo`@000003@3oool00`20P8000000000000040?ooo`<0
000000<0P8200?ooo`3oool0<`3oool01020P800000000000000000X0?ooo`@000005P3oool40000
0240oooo0`0000000`20P800oooo0?ooo`150?ooo`00o`3ooooo0?oooc@0oooo0P0000000`20P800
oooo0?ooo`0S0?ooo`@00000303oool01020P80000000000000000030?ooo`<0000000<0P8200?oo
o`3oool0<`3oool01020P800000000000000000Y0?ooo`<000005P3oool400000240oooo0`000000
0`20P800oooo0?ooo`150?ooo`00o`3ooooo0?ooocD0oooo0P20P80V0?ooo`040410@00000000000
0820P0`0oooo1P0000001010@400000000000010@40d0?ooo`050820P0000000000000000010@400
:P3oool3000000030820P03oool0oooo0100oooo00<0`<300000000000000P0000000`20P800oooo
0?ooo`0N0?ooo`040820P00000000000000004P0oooo003o0?ooool0ooooGP3oool3000000030820
P03oool0oooo00T0oooo2P00000c0?ooo`D00000:`3oool01020P800000000000000000B0?ooo`@0
00008P3oool3000004T0oooo003o0?ooool0ooooGP3oool4000000d0oooo2000000a0?ooo`L00000
;03oool3000000030820P03oool0oooo00`0oooo1`00000R0?ooo`<00000B@3oool00?l0ooooo`3o
oomO0?ooo`040820P00000000000000000h0oooo0P20P8001010@400000000000000000]0?ooo`03
0820P0000000000000D0000000<0@4100820P03oool0;03oool01020P800000000000000000:0?oo
o`030820P0000000000000H0000000<0P8200<30`03oool0803oool3000004X0oooo003o0?ooool0
ooooH@3oool300000440oooo1`00000a0?ooo`<000002P3oool7000002<0oooo0`0000000`20P800
oooo0?ooo`180?ooo`00o`3ooooo0?ooof80oooo0`0000000`20P800oooo0?ooo`0m0?ooo`<00000
00<0P8200?ooo`3oool0<P3oool4000000T0oooo1000000U0?ooo`040820P00000000000000004/0
oooo003o0?ooool0ooooH`3oool300000:d0oooo00<0P820000000000000C03oool00?l0ooooo`3o
oooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0
ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3o
ool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0
ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooH`3oool2000000040820P03o
ool0oooo0820P0800000m`3oool00?l0oooo[03oool00`20P800oooo0?ooo`0Q0?ooo`030820P03o
ool0oooo08`0oooo00D0P8200410@000000000000820P0040?ooo`050820P000000000000410@020
P800m03oool00?l0ooooZP3oool00`20P80000000?ooo`0T0?ooo`030000003oool0oooo08T0oooo
1@0000080?ooo`@0000000<0P8200?ooo`3oool0l03oool00?l0ooooZ03oool3000002H0oooo1000
00270?ooo`H000002@3oool500000?40oooo003o0?oooj@0oooo0P20P804000000030<30`03oool0
oooo02@0oooo00<0`<300000000000000`0000000`20P800`<300?ooo`1n0?ooo`80P8201P000000
0`10@400oooo0?ooo`080?ooo`030410@0000000000000@0000000<0@4100820P03oool0k03oool0
0?l0ooooX`3oool6000002X0oooo2000001k0?ooo`X00000303oool9000000030820P03oool0oooo
0>T0oooo003o0?oooj00oooo2000000/0?ooo`P0000000<0P8200?ooo`3oool0MP3oool;000000d0
oooo2`00003Y0?ooo`00o`3ooonO0?ooo`P0000000<0P8200?ooo`3oool0:`3oool9000007@0oooo
00<0P8200000000000002P00000>0?ooo``0000000<0P8200?ooo`3oool0i@3oool00?l0ooooV`3o
ool20820P0X0000000<0`<300?ooo`3oool0:`3oool00`20P800000000000008000000030410@020
P800oooo06`0oooo0P20P80=00000100oooo3@0000000`20P800`<300?ooo`3S0?ooo`00o`3ooonI
0?ooo`h00000;`3oool=000000030820P03oool0oooo06P0oooo3`00000A0?ooo`030820P0000000
000000d00000h`3oool00?l0ooooV03oool>00000340oooo3`00001V0?oooa4000004@3oool00`20
P80000000000000?00000>40oooo003o0?oooiD0oooo00<0P8200000000000003P00000a0?oooa00
000000<0P8200?ooo`3oool0H@3ooolf00000>00oooo003o0?oooi<0oooo0P20P80@000003<0P820
4@0000000`20P800oooo0?ooo`1K0?ooo`030<30`020P800000002D0000000<0P820000000000000
4@0000000`20P800`<300?ooo`3K0?ooo`00o`3ooonA0?ooo`030820P0000000000005L00000F`3o
oolY000000030?ooo`000000000001@00000f`3oool00?l0ooooT03ooomM000005X0oooo5@00000D
0?oooaD00000g03oool00?l0ooooSP3oool00`20P80000000000001M000000030<30`03oool0oooo
05P0oooo0P20P80A000000030820P03oool0oooo0100oooo4P0000020820P=h0oooo003o0?oooi40
oooo4`00000d0?ooo`030820P0000000000001000000H@3ooolA00000180oooo4@00003Q0?ooo`00
o`3ooonB0?oooa<00000<`3oool00`20P80000000000000?000006@0oooo00<0P820000000000000
3000000A0?ooo`030820P0000000000000`00000i03oool00?l0ooooU03ooolA000003<0oooo4000
001X0?ooo`h00000403oool00`20P80000000000000;00000>D0oooo003o0?oooiH0oooo0P20P80=
000000030820P03oool0oooo02l0oooo00<0P8200000000000002P0000030820P6/0oooo0P20P80:
000000030820P03oool0oooo00`0oooo00<0P820000000000000200000020820P>L0oooo003o0?oo
oiT0oooo3P00000`0?ooo``00000LP3oool00`20P800000000000007000000h0oooo2@00003[0?oo
o`00o`3ooonL0?ooo`/00000;`3oool;000007H0oooo2@00000<0?ooo`T00000k03oool00?l0oooo
W@3oool20820P0P0000000<0@4100?ooo`3oool0:`3oool00`10@400000000000005000000<0P820
N@3oool00`30`<00P82000000004000000030410@03oool0oooo00P0oooo00<0P820000000000000
0`0000000`20P800`<300?ooo`3]0?ooo`00o`3ooonQ0?ooo`P00000:`3oool800000800oooo00<0
P8200000000000000P00000:0?ooo`@00000lP3oool00?l0ooooX`3oool7000002X0oooo1P000025
0?ooo`<00000203oool300000?@0oooo003o0?oooj@0oooo1P00000Y0?ooo`D00000R03oool00`20
P8000000000000060?ooo`80000000<0P8200?ooo`3oool0l`3oool00?l0ooooY`3oool01020P800
000000000010@40V0?ooo`050<30`0000000000000000020P800S03oool20820P0040<30`03oool0
oooo0?ooo`80P820m`3oool00?l0ooooZP3oool2000002D0oooo0P00003o0?ooohl0oooo003o0?oo
oj`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooohl0oooo003o0?ooool0
ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o
0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0
oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo
0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0oooo
o`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool0
0?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0oooo
H`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?oo
ool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3o
oooo0?ooool0ooooH`3oool004`0oooo00<0P820000000000000o`00003o00000>40000000<0P820
0?ooo`3oool0;`3oool004`0oooo00<0P820000000000000o`00003o00000>40000000<0P8200?oo
o`3oool0;`3oool004`0oooo00<0P820000000000000o`00003o00000>40000000<0P8200?ooo`3o
ool0;`3oool004`0oooo00<0P820000000000000o`00003o00000>40000000<0P8200?ooo`3oool0
;`3oool004`0oooo00<0P820000000000000o`00003o00000>40000000<0P8200?ooo`3oool0;`3o
ool004`0oooo00<0P820000000000000o`00003o00000>40000000<0P8200?ooo`3oool0;`3oool0
04`0oooo00<0P820000000000000o`00003o00000>40000000<0P8200?ooo`3oool0;`3oool004`0
oooo00<0P820000000000000o`00003o00000>40000000<0P8200?ooo`3oool0;`3oool004`0oooo
00<0P820000000000000o`00003o00000>40000000<0P8200?ooo`3oool0;`3oool004`0oooo00<0
P820000000000000o`00003o00000>40000000<0P8200?ooo`3oool0;`3oool00?l0ooooQ03oool3
000006P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`030<30`000
0000000000<0000000<0P8200?ooo`3oool0T@3oool00?l0ooooQ03oool3000006P0oooo0`00001@
0?ooo`<00000>`3oool01020P80000000000000000130?ooo`030820P0000000000000@00000T`3o
ool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000
00130?ooo`L0000000<0P8200?ooo`3oool0T03oool00?l0ooooQ03oool3000006P0oooo0`00001@
0?ooo`<00000>`3oool01020P80000000000000000130?ooo`L0000000<0P8200?ooo`3oool0T03o
ool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000
00120?ooo`T00000TP3oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool0
1020P80000000000000000110?ooo`X00000TP3oool00?l0ooooQ03oool3000006P0oooo0`00001@
0?ooo`<00000>`3oool01020P80000000000000000110?ooo`/00000T@3oool00?l0ooooQ03oool3
000006P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000100?ooo`030<30`000
0000000000T0000000<0P8200?ooo`3oool0SP3oool00?l0ooooQ03oool3000006P0oooo0`00001@
0?ooo`<00000>`3oool01020P80000000000000000100?ooo`030820P0000000000000X00000T03o
ool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000
00100?ooo`h00000S`3oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool0
1020P80000000000000000100?ooo`h00000S`3oool00?l0ooooQ03oool3000006P0oooo0`00001@
0?ooo`<00000>`3oool01020P800000000000000000o0?ooo`l0000000<0`<300?ooo`3oool0S03o
ool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000
000o0?ooo`l0000000<0P8200?ooo`3oool0S03oool00?l0ooooQ03oool3000006P0oooo0`00001@
0?ooo`<00000>`3oool01020P800000000000000000n0?oooa400000SP3oool00?l0ooooQ03oool3
000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000000m0?ooo`030820P000
0000000000l0000000<0P8200?ooo`3oool0R`3oool00?l0ooooQ03oool3000006P0oooo0`00001@
0?ooo`<00000>`3oool01020P800000000000000000m0?oooa<00000S@3oool00?l0ooooQ03oool3
000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000000l0?ooo`030820P000
0000000001400000S@3oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool0
1020P800000000000000000l0?ooo`030820P0000000000001800000S03oool00?l0ooooQ03oool3
000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000000l0?ooo`H000000P20
P803000000<0oooo00<0P820000000000000100000000`20P800oooo0?ooo`290?ooo`00o`3ooon4
0?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000003/0oooo1@00
00001020P800oooo0?ooo`20P803000000H0oooo1@00002;0?ooo`00o`3ooon40?ooo`<00000J03o
ool300000500oooo0`00000k0?ooo`040820P00000000000000003/0oooo100000040?ooo`040820
P00000000000000000L0oooo00D0P82000000000000000000820P02:0?ooo`00o`3ooon40?ooo`<0
0000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000003X0oooo100000050?oo
o`040820P00000000000000000P0oooo0`0000000`20P800oooo0?ooo`280?ooo`00o`3ooon40?oo
o`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000003T0oooo00@0`<30
000000000000P8201P3oool01020P80000000000000000090?ooo`030820P0000000@41008X0oooo
003o0?oooh@0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000
>@3oool00`20P80000000?ooo`070?ooo`040820P00000000000000000/0oooo00<000000?ooo`3o
ool0R03oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P8000000
00000000000i0?ooo`030820P03oool0oooo00L0oooo00@0P82000000000000000002`3oool00`20
P80000000?ooo`280?ooo`00o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k0?ooo`04
0820P00000000000000003T0oooo00<0P8200?ooo`3oool01`3oool01020P800000000000000000<
0?ooo`80P820R03oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020
P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00001X
0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P80000000000
0000002F0?ooo`00o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P000
00000000000004<0oooo00@0P8200000000000000000UP3oool00?l0ooooQ03oool3000006P0oooo
0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P000000000000000
09H0oooo003o0?oooh@0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P82000000000
00000000@`3oool01020P800000000000000002F0?ooo`00o`3ooon40?ooo`<00000J03oool30000
0500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000UP3o
ool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000
00130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00001X0?ooo`<00000D03o
ool3000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00
o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0
oooo00@0P8200000000000000000UP3oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<0
0000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oo
oh@0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool0
1020P800000000000000002F0?ooo`00o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k
0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000UP3oool00?l0ooooQ03o
ool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820
P00000000000000009H0oooo003o0?oooh@0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo
00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00o`3ooon40?ooo`<0
0000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000
000000000000UP3oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020
P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00001X
0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P80000000000
0000002F0?ooo`00o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P000
00000000000004<0oooo00@0P8200000000000000000UP3oool00?l0ooooQ03oool3000006P0oooo
0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P000000000000000
09H0oooo003o0?oooh@0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P82000000000
00000000@`3oool01020P800000000000000002F0?ooo`00o`3ooon40?ooo`<00000J03oool30000
0500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000UP3o
ool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000
00130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00001X0?ooo`<00000D03o
ool3000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00
o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0
oooo00@0P8200000000000000000UP3oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<0
0000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oo
oh@0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool0
1020P800000000000000002F0?ooo`00o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k
0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000UP3oool00?l0ooooQ03o
ool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820
P00000000000000009H0oooo003o0?oooh@0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo
00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00o`3ooon40?ooo`<0
0000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000
000000000000UP3oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020
P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00001X
0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P80000000000
0000002F0?ooo`00o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P000
00000000000004<0oooo00@0P8200000000000000000UP3oool00?l0ooooQ03oool3000006P0oooo
0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P000000000000000
09H0oooo003o0?oooh@0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P82000000000
00000000@`3oool01020P800000000000000002F0?ooo`00o`3ooon40?ooo`<00000J03oool30000
0500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000UP3o
ool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000
00130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00001X0?ooo`<00000D03o
ool3000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00
o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0
oooo00@0P8200000000000000000UP3oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<0
0000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oo
oh@0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool0
1020P800000000000000002F0?ooo`00o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k
0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000UP3oool00?l0ooooQ03o
ool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820
P00000000000000009H0oooo003o0?oooh@0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo
00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00o`3ooon40?ooo`<0
0000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000
000000000000UP3oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020
P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00001X
0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P80000000000
0000002F0?ooo`00o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P000
00000000000004<0oooo00@0P8200000000000000000UP3oool00?l0ooooQ03oool3000006P0oooo
0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P000000000000000
09H0oooo003o0?oooh@0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P82000000000
00000000@`3oool01020P800000000000000002F0?ooo`00o`3ooon40?ooo`<00000J03oool30000
0500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000UP3o
ool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000
00130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00001X0?ooo`<00000D03o
ool3000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00
o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0
oooo00@0P8200000000000000000UP3oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<0
0000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oo
oh@0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool0
1020P800000000000000002F0?ooo`00o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k
0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000UP3oool00?l0ooooQ03o
ool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820
P00000000000000009H0oooo003o0?oooh@0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo
00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00o`3ooon40?ooo`<0
0000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000
000000000000UP3oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020
P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00001X
0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P80000000000
0000002F0?ooo`00o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P000
00000000000004<0oooo00@0P8200000000000000000UP3oool00?l0ooooQ03oool3000005<0oooo
1000000A0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P800
000000000000002F0?ooo`00o`3ooon40?ooo`<00000D`3oool400000140oooo0`00001@0?ooo`<0
0000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oo
oh@0oooo0`00001C0?ooo`@000004@3oool300000500oooo0`00000k0?ooo`040820P00000000000
000004<0oooo00@0P8200000000000000000UP3oool00?l0ooooQ03oool3000005@0oooo1000000@
0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P80000000000
0000002F0?ooo`00o`3ooon40?ooo`<00000E03oool400000100oooo0`00001@0?ooo`<00000>`3o
ool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo
0`00001D0?ooo`@00000403oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0
oooo00@0P8200000000000000000UP3oool00?l0ooooQ03oool3000005D0oooo0`00000@0?ooo`<0
0000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000002F
0?ooo`00o`3ooon40?ooo`<00000E@3oool4000000l0oooo0`00001@0?ooo`<00000>`3oool01020
P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`000019
0?ooo`@0P820203oool4000000l0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000
00130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`0000190?ooo`@00000203o
ool4000000l0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820
P00000000000000009H0oooo003o0?oooh@0oooo0`00001:0?ooo`@000001`3oool01@20P8000000
000000000000P82000h0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?oo
o`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00001:0?ooo`@000001`3oool01@20
P8000000000000000000P82000h0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000
00130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00001:0?ooo`@000001`3o
ool01@20P8000000000000000000P82000h0oooo0`00001@0?ooo`<00000>`3oool01020P8000000
0000000000130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00001:0?ooo`@0
00001`3oool01@20P8000000000000000000P82000h0oooo0`00001@0?ooo`<00000>`3oool01020
P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00001:
0?ooo`050820P0000000000000000020P8001`3oool4000000h0oooo0`00001@0?ooo`<00000>`3o
ool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo
0`00001:0?ooo`050820P0000000000000000020P8001`3oool4000000h0oooo0`00001@0?ooo`<0
0000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oo
oh@0oooo0`00001:0?ooo`050820P0000000000000000020P8001`3oool4000000h0oooo0`00001@
0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo
003o0?oooh@0oooo0`00001:0?ooo`030820P00000000000008000001`3oool4000000h0oooo0`00
001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0
oooo003o0?oooh@0oooo0`00001;0?ooo`@00000203oool3000000h0oooo0`00001@0?ooo`<00000
>`3oool01020P80000000000000000130?ooo`040820P00000000000000001P0oooo100000090?oo
o`@00000K@3oool00?l0ooooQ03oool3000004/0oooo1@0000070?ooo`@000003@3oool300000500
oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000603oool4
000000030<30`03oool0oooo00H0oooo00D0P82000000000000000000820P01/0?ooo`00o`3ooon4
0?ooo`<00000A`3oool01020P800oooo0?ooo`3oool4000000030?ooo`000000oooo00D0oooo1000
000=0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P8000000
00000000000I0?ooo`<0000000<0P8200?ooo`3oool01`3oool4000006`0oooo003o0?oooh@0oooo
0`0000170?ooo`040820P03oool0oooo0?ooo`@0000000<0oooo0000003oool01@3oool4000000d0
oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P00000000000
000001T0oooo0`0000000`20P800oooo0?ooo`070?ooo`@00000K03oool00?l0ooooQ03oool30000
04L0oooo00@0P8200?ooo`3oool0oooo100000020?ooo`030820P03oool0oooo00<0oooo1000000=
0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P80000000000
0000000I0?ooo`<0000000<0P8200?ooo`3oool01`3oool4000006`0oooo003o0?oooh@0oooo0`00
00170?ooo`040<30`020P800oooo0?ooo`<0000000@0@4100?ooo`3oool0`<300P20P8020?ooo`05
0820P0000000000000000020P8003@3oool300000500oooo0`00000k0?ooo`040820P00000000000
000004<0oooo00@0P82000000000000000006@3oool3000000030410@03oool0oooo00L0oooo00D0
P82000000000000000000820P01[0?ooo`00o`3ooon40?ooo`<00000B03oool6000000030820P03o
ool0oooo0080oooo1`00000>0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000
@`3oool01020P800000000000000000I0?ooo`040820P00000000000000000X0oooo1000001[0?oo
o`00o`3ooon40?ooo`<00000BP3oool4000000L0oooo1000000?0?ooo`<00000D03oool3000003/0
oooo00@0P8200000000000000000@`3oool01020P800000000000000000I0?ooo`040820P0000000
0000000000X0oooo1000001[0?ooo`00o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k
0?ooo`040820P00000000000000004<0oooo00@0P82000000000000000006@3oool01020P8000000
00000000000:0?ooo`@00000J`3oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000
>`3oool01020P80000000000000000130?ooo`040820P00000000000000001T0oooo00<0P8200000
000000000P0000090?ooo`050820P0000000000000000020P800JP3oool00?l0ooooQ03oool30000
01h0oooo00<000000?ooo`3oool0A`3oool3000002h0oooo00<0P8200?ooo`3oool07`3oool30000
03/0oooo00@0P8200000000000000000@`3oool01020P800000000000000000J0?ooo`@000002@3o
ool01@20P8000000000000000000P82006X0oooo003o0?oooh@0oooo0`00000L0?ooo`030820P000
0000000004T0oooo0`00000^0?ooo`030820P0000000oooo01l0oooo0`00000k0?ooo`040820P000
00000000000004<0oooo00@0P82000000000000000006P3oool4000000T0oooo00D0P82000000000
000000000820P01Z0?ooo`00o`3ooon40?ooo`<00000603oool20820P0<0000000<0P8200?ooo`3o
ool0B03oool3000002l0oooo00<0P8200000000000000`20P80K0?ooo`<00000>`3oool01020P800
00000000000000130?ooo`040820P00000000000000001X0oooo100000090?ooo`050820P0000000
000000000020P800JP3oool00?l0ooooQ03oool3000001H0oooo1P0000000`20P800oooo0?ooo`19
0?ooo`<00000<@3oool5000001X0oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0
P82000000000000000006P3oool5000000P0oooo00<0P8200000000000000P00001Z0?ooo`00o`3o
oon40?ooo`<000005@3oool7000004`0oooo0`00000a0?ooo`030820P0000000000000@0000000<0
P8200?ooo`3oool05@3oool3000003/0oooo00@0P8200000000000000000@`3oool01020P8000000
00000000000K0?ooo`@000002@3oool4000006X0oooo003o0?oooh@0oooo0`00000A0?ooo`030<30
`020P800000000H0000000<0P8200?ooo`3oool0B`3oool300000340oooo00<0`<30000000000000
1P0000020820P1@0oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P82000000000
000000006`3oool5000000P0oooo1000001Z0?ooo`00o`3ooon40?ooo`<00000403oool:000004h0
oooo0`00000c0?ooo`/000004P3oool3000003/0oooo00@0P8200000000000000000@`3oool01020
P800000000000000000K0?ooo`D0000000<0P8200?ooo`3oool01@3oool4000006X0oooo003o0?oo
oh@0oooo0`00000>0?ooo`/00000C`3oool3000003<0oooo3@00000@0?ooo`<00000>`3oool01020
P80000000000000000130?ooo`040820P00000000000000001/0oooo1P0000070?ooo`@00000JP3o
ool00?l0ooooQ03oool3000000`0oooo3@00001?0?ooo`<00000=03oool=000000l0oooo0`00000k
0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000703oool6000000D0oooo
00<0P8200000000000000P00001Z0?ooo`00o`3ooon40?ooo`<00000203oool20820P0030410@000
0000000000/0000000<0P8200?ooo`3oool0C@3oool3000003D0oooo3P0000000`10@400P8200?oo
o`0:0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P00000000000000001`0
oooo100000001010@40000000000000000030820P0D00000JP3oool00?l0ooooQ03oool3000000L0
oooo4@00001@0?ooo`<00000=@3oool00`20P80000000000000?000000T0oooo0`00000k0?ooo`04
0820P00000000000000004<0oooo00@0P8200000000000000000703oool400000080oooo2@000000
0`20P800oooo0?ooo`1X0?ooo`00o`3ooon40?ooo`<000001@3ooon]000000030820P03oool0oooo
00H0oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000703o
ool4000000030820P03oool0oooo00P00000J`3oool00?l0ooooQ03oool3000000<0oooo00<0P820
000000000000[P0000070?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P000
00000000000001`0oooo00D0P82000000000000000000820P0030?ooo`030820P000000000000080
0000K@3oool00?l0ooooQ03oool3000000030?ooo`20P800P8200;80000000<0@4100820P03oool0
0`3oool3000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000000L0?oo
o`050820P0000000000000000020P800M@3oool00?l0ooooQ03ooonk000000<0oooo0`00000k0?oo
o`040820P00000000000000004<0oooo00@0P8200000000000000000703oool01@20P80000000000
00000000P82007D0oooo003o0?oooh@0oooo0`0000000`3oool000000000000D00000540oooo0`00
000f0?oooaD000001@3oool3000003/0oooo00@0P8200000000000000000@`3oool01020P8000000
00000000000L0?ooo`030820P0000000000000800000M@3oool00?l0ooooQ03oool3000000<0oooo
00<0`<300820P00000004P00001@0?ooo`<00000=@3oool00`30`<0000000000000?000000030410
@020P800oooo00H0oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P82000000000
000000007@3oool4000007D0oooo003o0?oooh@0oooo0`0000070?oooa400000D03oool3000003D0
oooo00<0P8200000000000003P00000:0?ooo`<00000>`3oool01020P80000000000000000130?oo
o`040820P00000000000000001d0oooo1000001e0?ooo`00o`3ooon40?ooo`<000002@3oool?0000
00030820P03oool0oooo04d0oooo0`00000e0?ooo`l00000303oool3000003/0oooo00@0P8200000
000000000000@`3oool01020P800000000000000000M0?ooo`@00000M@3oool00?l0ooooQ03oool3
000000X0oooo00<0P8200000000000002`0000000`20P800oooo0?ooo`1=0?ooo`<00000=@3oool=
000000h0oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000
7@3oool5000007@0oooo003o0?oooh@0oooo0`00000<0?ooo`80P82000<0@4100000000000002000
001?0?ooo`<00000<`3oool00`20P800000000000009000000030820P030`<00oooo00h0oooo0`00
000k0?ooo`040820P00000000000000004<0oooo00@0P82000000000000000007P3oool4000007@0
oooo003o0?oooh@0oooo0`00000@0?ooo`X00000CP3oool300000380oooo2`00000C0?ooo`<00000
>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oooh@0
oooo0`00000A0?ooo`030820P0000000000000L00000C@3oool300000340oooo00<0P82000000000
00001`00000E0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P00000000000
000009H0oooo003o0?oooh@0oooo0`00000D0?ooo`030820P010@400000000D00000C03oool30000
0340oooo00<0@410000000000000100000000`20P800oooo0?ooo`0E0?ooo`<00000>`3oool01020
P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00000G
0?ooo`D0000000<0P8200?ooo`3oool0B@3oool300000300oooo1@0000000`20P800oooo0?ooo`0H
0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo
003o0?oooh@0oooo0`00000I0?ooo`@00000B`3oool3000002l0oooo1@00000L0?ooo`<00000>`3o
ool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo
0`00000K0?ooo`<00000BP3oool3000002h0oooo00@0P82000000000000000007P3oool3000003/0
oooo00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00o`3ooon40?oo
o`<00000703oool01@30`<00P8200820P0000000`<3004L0oooo0`00000]0?ooo`040820P010@400
P8200820P1l0oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P820000000000000
0000UP3oool00?l0ooooQ03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P8000000
0000000000130?ooo`040820P00000000000000009H0oooo003o0?oooh@0oooo0`00001X0?ooo`<0
0000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000002F
0?ooo`00o`3ooon40?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000
000004<0oooo00@0P8200000000000000000UP3oool00?l0ooooQ03oool3000006P0oooo0`00001@
0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo
001C0?ooo`030820P0000000oooo0?l0oooo;P3oool3000006P0oooo0`00001@0?ooo`<00000>`3o
ool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo001C0?ooo`<00000
o`3oool^0?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0
oooo00@0P8200000000000000000UP3oool00580oooo00H0P82000000000000000000410@020P83o
0?ooob`0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3o
ool01020P800000000000000002F0?ooo`00D@3oool800000?l0oooo:`3oool3000006P0oooo0`00
001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0
oooo001@0?ooo`X00000o`3ooolZ0?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820
P00000000000000004<0oooo00@0P8200000000000000000UP3oool004l0oooo00<0P82000000000
0000200000000`20P800oooo0?ooo`3o0?ooobL0oooo0`00001X0?ooo`<00000D03oool3000003/0
oooo00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00C`3oool00`10
@400000000000009000000030820P03oool0oooo0?l0oooo9P3oool3000006P0oooo0`00001@0?oo
o`<00000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo001>
0?ooo`l00000o`3ooolW0?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P0000000
0000000004<0oooo00@0P8200000000000000000UP3oool004l0oooo3`0000000`20P800oooo0?oo
o`3o0?ooob<0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000
@`3oool01020P800000000000000002F0?ooo`00C`3oool00`30`<0000000000000=000000030820
P03oool0oooo0?l0oooo8P3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P8000000
0000000000130?ooo`040820P00000000000000009H0oooo001B0?ooo`l00000o`3ooolS0?ooo`<0
0000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000
000000000000UP3oool005<0oooo3P0000000`20P800oooo0?ooo`3o0?ooob00oooo0`00001X0?oo
o`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000
002F0?ooo`00D`3oool00`20P80000000000000=00000?l0oooo8@3oool3000006P0oooo0`00001@
0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo
001D0?ooo`030820P0000000000000d0000000<0P8200?ooo`3oool0o`3ooolM0?ooo`<00000J03o
ool300000500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P820000000000000
0000UP3oool005H0oooo4000003o0?oooah0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo
00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00EP3oool00`20P800
00000000000>00000?l0oooo7@3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800
00000000000000130?ooo`040820P00000000000000009H0oooo001H0?oooa000000o`3ooolL0?oo
o`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P820
0000000000000000UP3oool005T0oooo00<0P820000000000000300000000`10@400P8200?ooo`3o
0?oooaT0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3o
ool01020P800000000000000002F0?ooo`00FP3oool00`20P80000000000000>00000?l0oooo6@3o
ool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820
P00000000000000009H0oooo001K0?oooa400000o`3ooolH0?ooo`<00000J03oool300000500oooo
0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000UP3oool005d0
oooo00<0P8200000000000003@0000000`20P800oooo0?ooo`3o0?oooa@0oooo0`00001X0?ooo`<0
0000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000002F
0?ooo`00G`3oool@00000?l0oooo5@3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020
P80000000000000000130?ooo`040820P00000000000000009H0oooo001P0?oooa000000o`3ooolD
0?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0
P8200000000000000000UP3oool00640oooo4000003o0?oooa<0oooo0`00001X0?ooo`<00000D03o
ool3000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00
HP3oool00`20P80000000000000>000000030<30`03oool0oooo0?l0oooo3P3oool3000006P0oooo
0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P000000000000000
09H0oooo001T0?oooa000000o`3oool@0?ooo`<00000J03oool300000500oooo0`00000k0?ooo`04
0820P00000000000000004<0oooo00@0P8200000000000000000UP3oool006D0oooo00<0P8200000
000000003P00003o0?ooo`h0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P8200000
000000000000@`3oool01020P800000000000000002F0?ooo`00IP3oool20820P0l0000000<0`<30
0?ooo`3oool0o`3oool:0?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P0000000
0000000004<0oooo00@0P8200000000000000000UP3oool006P0oooo00<0P8200000000000003P00
003o0?ooo`/0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000
@`3oool01020P800000000000000002F0?ooo`00J@3ooolA00000?l0oooo2P3oool3000006P0oooo
0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P000000000000000
09H0oooo001[0?oooa000000o`3oool90?ooo`<00000J03oool300000500oooo0`00000k0?ooo`04
0820P00000000000000004<0oooo00@0P8200000000000000000UP3oool006`0oooo00<0P8200000
000000003@0000000`20P800oooo0?ooo`3o0?ooo`D0oooo0`00001X0?ooo`<00000D03oool30000
03/0oooo00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00KP3oool@
000000030820P03oool0oooo0?l0oooo0`3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool0
1020P80000000000000000130?ooo`040820P00000000000000009H0oooo001_0?oooa000000o`3o
ool50?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0oooo
00@0P8200000000000000000UP3oool00700oooo4@00003o0?ooo`<0oooo0`00001X0?ooo`<00000
D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000002F0?oo
o`00L@3oool00`20P80000000000000=000000030410@020P800oooo0?l0oooo0`00001X0?ooo`<0
0000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000002F
0?ooo`00L`3oool00`20P80000000000000>00000?l0oooo0`00001X0?ooo`<00000D03oool30000
03/0oooo00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00M03ooolA
000000030820P03oool0oooo0?/0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P820
0000000000000000@`3oool01020P800000000000000002F0?ooo`00MP3oool00`20P80000000000
000=00000080P820n`3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000
000000130?ooo`040820P00000000000000009H0oooo001g0?ooo`030820P0000000000000h00000
00<0P8200?ooo`3oool0n03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P8000000
0000000000130?ooo`040820P00000000000000009H0oooo001i0?oooa400000n@3oool3000006P0
oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P00000000000
000009H0oooo001j0?oooa800000m`3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020
P80000000000000000130?ooo`040820P00000000000000009H0oooo001k0?ooo`030820P0000000
000000l0000000<0P8200?ooo`3oool0l`3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool0
1020P80000000000000000130?ooo`040820P00000000000000009H0oooo001n0?oooa40000000<0
P8200?ooo`3oool0l@3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000
000000130?ooo`040820P00000000000000009H0oooo001n0?ooo`030820P0000000000000l00000
l`3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`04
0820P00000000000000009H0oooo00200?ooo`030820P0000000000000l0000000<0P8200?ooo`3o
ool0kP3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?oo
o`040820P00000000000000009H0oooo00220?oooa800000k`3oool3000006P0oooo0`00001@0?oo
o`<00000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo0023
0?oooa800000kP3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000
00130?ooo`040820P00000000000000009H0oooo00250?oooa800000k03oool3000006P0oooo0`00
001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P00000000000000009H0
oooo00250?ooo`030<30`020P800000000l0000000<0@4100820P03oool0j@3oool3000006P0oooo
0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P000000000000000
09H0oooo00280?oooa800000j@3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800
00000000000000130?ooo`040820P00000000000000009H0oooo00290?oooa800000j03oool30000
06P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P0000000
0000000009H0oooo002:0?oooa<00000iP3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool0
1020P80000000000000000130?ooo`040820P00000000000000009H0oooo002<0?ooo`030820P000
0000000000l0000000<0P8200?ooo`3oool0hP3oool3000006P0oooo0`00001@0?ooo`<00000>`3o
ool01020P80000000000000000130?ooo`040820P00000000000000009H0oooo002>0?oooa<00000
hP3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`04
0820P00000000000000009H0oooo002?0?ooo`030820P0000000000001000000h@3oool3000006P0
oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`040820P00000000000
000009H0oooo002@0?ooo`80P8204P0000000`20P800`<300?ooo`3L0?ooo`<00000J03oool30000
0500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000UP3o
ool009<0oooo4`00003M0?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P0000000
0000000004<0oooo00@0P8200000000000000000UP3oool009@0oooo5000003K0?ooo`<00000J03o
ool300000500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P820000000000000
0000UP3oool009H0oooo4`00003J0?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820
P00000000000000004<0oooo00@0P8200000000000000000UP3oool009L0oooo00<0P82000000000
0000400000020820P=L0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P82000000000
00000000@`3oool01020P800000000000000002F0?ooo`00VP3ooolC00000=H0oooo0`00001X0?oo
o`<00000D03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000
002F0?ooo`00VP3oool00`20P80000000000000B00000=@0oooo0`00001X0?ooo`<00000D03oool3
000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000002F0?ooo`00W03o
ool20820P180000000<0@4100?ooo`3oool0d03oool3000006P0oooo0`00001@0?ooo`<00000>`3o
ool01020P800000000000000000i0?ooo`030410@03oool0oooo00L0oooo00@0P820000000000000
0000303oool20820P8P0oooo002N0?ooo`030820P0000000000001800000d03oool3000006P0oooo
0`00001@0?ooo`<00000>`3oool01020P800000000000000000i0?ooo`030820P03oool0oooo00L0
oooo00@0P82000000000000000002`3oool00`20P80000000?ooo`280?ooo`00X03ooolD00000<l0
oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000>@3oool00`20
P80000000?ooo`070?ooo`040820P00000000000000000/0oooo00<000000?ooo`3oool0R03oool0
0:40oooo00<0P8200000000000004P00003=0?ooo`<00000J03oool300000500oooo0`00000k0?oo
o`040820P00000000000000003T0oooo00<0P8200000000000001`3oool01020P800000000000000
000:0?ooo`800000RP3oool00:80oooo0P20P80C000000030410@020P800oooo0<T0oooo0`00001X
0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000>P3oool3000000030820P03o
ool0oooo00<0oooo00@0P8200000000000000000203oool01020P800000000000020P82:0?ooo`00
Y@3oool00`20P80000000000000B000000030820P03oool0oooo0<H0oooo0`00001X0?ooo`<00000
D03oool3000003/0oooo00@0P8200000000000000000>`3oool4000000@0oooo00@0P82000000000
000000001`3oool01@20P8000000000000000000P82008X0oooo002W0?oooaD00000a`3oool30000
06P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000000k0?ooo`D0000000@0P820
0?ooo`3oool0P8200`0000060?ooo`D00000R`3oool00:P0oooo00<0P8200000000000004`000035
0?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000003`0oooo1@00
00020?ooo`040820P00000000000000000@0oooo1`00002;0?ooo`00ZP3oool20820P1<000000P20
P8320?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000003`0oooo
00<0@410000000000000100000001010@40000000000000000030820P0L00000S03oool00:`0oooo
00<0P8200000000000004P0000000`20P800oooo0?ooo`2o0?ooo`<00000J03oool300000500oooo
0`00000k0?ooo`040820P00000000000000003`0oooo00<0P8200000000000004@00002=0?ooo`00
[P3ooolE00000<00oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P820000000000000
0000?@3ooolC000008d0oooo002`0?ooo`030820P000000000000180000000<0P8200?ooo`3oool0
^`3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000000m0?ooo`03
0820P0000000000000l0000000<0P8200?ooo`3oool0R`3oool00;<0oooo5@00002k0?ooo`<00000
J03oool300000500oooo0`00000k0?ooo`040820P00000000000000003h0oooo4@00002>0?ooo`00
]03ooolE000000030820P03oool0oooo0;L0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo
00@0P8200000000000000000?P3oool@000000030820P03oool0oooo08`0oooo002d0?oooaL00000
^03oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P800000000000000000o0?ooo`l0
000000<0P8200?ooo`3oool0S03oool00;H0oooo00<0P8200410@00000004`0000000`10@400P820
0?ooo`2d0?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000003l0
oooo00<0P8200000000000003000002?0?ooo`00^@3ooolG00000;<0oooo0`00001X0?ooo`<00000
D03oool3000003/0oooo00@0P8200000000000000000@03oool>000008l0oooo002j0?ooo`030820
P0000000000001@00000/P3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P8000000
0000000000100?ooo`030820P0000000000000X00000T03oool00;d0oooo00<0P8200410@0000000
4`0000000`20P800oooo0?ooo`2]0?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820
P0000000000000000400oooo00<0P8200000000000002@0000000`20P800oooo0?ooo`2>0?ooo`00
`03ooolF00000:d0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P820000000000000
0000@@3oool;00000940oooo00310?ooo`030820P0000000000001<0000000<0P8200?ooo`3oool0
Z@3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000110?ooo`X0
0000TP3oool00<<0oooo5P00002Z0?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820
P0000000000000000480oooo2@00002B0?ooo`00a@3oool00`20P80000000000000B000000030410
@020P800oooo0:H0oooo0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P820000000000000
0000@P3oool00`20P800000000000005000000030410@03oool0oooo0900oooo00380?oooaH00000
Y@3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P80000000000000000130?ooo`L0
000000<0P8200?ooo`3oool0T03oool00<T0oooo00<0P8200000000000005000002S0?ooo`<00000
J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004<0oooo00<0P82000000000
00001000002C0?ooo`00b`3ooolF000000030820P03oool0oooo09l0oooo0`00001X0?ooo`<00000
D03oool3000003/0oooo00@0P8200000000000000000@`3oool00`20P800000000000004000009<0
oooo003<0?ooo`030<30`020P800000001@000000P20P82N0?ooo`<00000J03oool300000500oooo
0`00000k0?ooo`040820P00000000000000004@0oooo1@00002D0?ooo`00d03ooolF000009d0oooo
0`00001X0?ooo`<00000D03oool3000003/0oooo00@0P8200000000000000000A@3oool4000009@0
oooo003A0?oooaP00000VP3oool3000006P0oooo0`00001@0?ooo`<00000>`3oool01020P8000000
0000000000150?ooo`<00000U@3oool003`0oooo1000002C0?ooo`030820P0000000000001@00000
0P20P82G0?ooo`<00000J03oool300000500oooo0`00000k0?ooo`040820P00000000000000004D0
oooo00<0P82000000010@400U@3oool003`0oooo1000002F0?oooaP00000U@3oool3000006P0oooo
0`00001@0?ooo`<00000>`3oool01020P80000000000000000160?ooo`0300000020P800oooo09@0
oooo000l0?ooo`@00000803ooolJ000001<0oooo6P00000J0?ooo`030820P0000000000004D00000
6P3ooolJ000001<0oooo00<0P8200000000000005`00000I0?oooa/0000000<0P8200?ooo`3oool0
4@3ooolJ000001X0oooo00<0P8200000000000005`00000D0?oooaT0000000<0P8200?ooo`3oool0
4@3oool3000000@0oooo6P00000C0?oooaX000006`3ooolI000000030820P03oool0oooo09X0oooo
000l0?ooo`@00000803ooolJ000001<0oooo6P00000J0?ooo`030820P0000000000004D000006P3o
oolJ000001<0oooo00<0P8200000000000005`00000I0?oooa/0000000<0P8200?ooo`3oool04@3o
oolJ000001X0oooo00<0P8200000000000005`00000D0?oooaT0000000<0P8200?ooo`3oool04@3o
ool3000000@0oooo6P00000C0?oooaX000006`3ooolI000000030820P03oool0oooo00<0oooo00<0
00000?ooo`3oool0U03oool003`0oooo1000000P0?oooaX000004`3ooolJ000001X0oooo00<0P820
0000000000005`0000020820P2`000006P3ooolJ000001<0oooo00<0P8200000000000005`00000I
0?ooo`80P8206@0000000`20P800oooo0?ooo`0A0?oooaX000006P3oool00`20P80000000000000G
000001@0oooo6@0000000`20P800oooo0?ooo`0A0?ooo`<00000103ooolJ000001<0oooo6P00000K
0?oooaT0000000<0P8200?ooo`3oool00`3oool00`000000P8200?ooo`2D0?ooo`00?03oool40000
0200oooo6P00000C0?oooaX000006P3oool00`20P80000000000000G000000@0oooo:P00000J0?oo
oaX000004`3oool00`20P80000000000000G000001/0oooo6@0000000`20P800oooo0?ooo`0A0?oo
oaX000006P3oool00`20P80000000000000G000001@0oooo6@0000000`20P800oooo0?ooo`0A0?oo
o`<00000103ooolJ000001<0oooo6P00000K0?oooaT0000000<0P8200?ooo`3oool00P3oool30000
09D0oooo000l0?ooo`@00000X@3ooolI00000?l0ooooB03oool3000003/0oooo00@0P82000000000
00000000A@3oool3000009D0oooo000M0?ooo`030<30`020P800P82000@0P8203`3oool40820P0D0
oooo1000000;0?ooo`@0P820<P3oool40820P0030<30`03oool0oooo02@0oooo00D0`<300820P020
P800P8200<30`00a0?ooo`80P8205`0000030820P?l0ooooA03oool3000003/0oooo00@0P8200000
000000000000A03oool00`20P800000000000002000009@0oooo000L0?ooo`X000002`3oool80000
00<0oooo100000090?ooo`L000000`3oool01020P80000000000000000060?ooo`@00000103oool0
1020P80000000000000000060?ooo`@000001@3oool400000080oooo00<0P8200000000000001P00
00080?ooo`050820P0000000000000000020P8002`3oool4000000P0oooo1`0000030?ooo`@00000
1P3oool4000000T0oooo00D0P82000000000000000000820P0090?ooo`@00000203ooolI00000?l0
oooo@`3oool3000003/0oooo00@0P8200000000000000000A03oool5000009@0oooo000J0?ooo`03
0820P0000000000000X000002@3oool:000000030820P03oool0000000<00000203oool:00000003
0?ooo`20P8000000008000001P3oool4000000@0oooo00@0P82000000000000000001P3oool40000
00D0oooo100000020?ooo`X000001`3oool01@20P8000000000000000000P82000/0oooo10000006
0?ooo`X0000000<0P8200?ooo`0000000`0000060?ooo`@000002@3oool01@20P800000000000000
0000P82000T0oooo1000000:0?oooaT00000o`3ooom10?ooo`<00000>`3oool01020P80000000000
000000130?ooo`030820P0000000000000@00000T`3oool001X0oooo3P0000070?ooo`030820P000
0000000000T0000000<0oooo0000000000000P0000070?ooo``0000000@0P8200000000000000000
1P3oool4000000@0oooo00@0P82000000000000000001P3oool4000000D0oooo100000000`3oool0
000000000009000000030820P03oool0oooo00@0oooo00D0P82000000000000000000820P00;0?oo
o`@000001@3oool00`20P800000000000009000000030?ooo`0000000000008000001P3oool40000
00T0oooo00D0P82000000000000000000820P0090?ooo`@000002`3oool00`20P80000000000000G
00000?l0oooo?`3oool3000003/0oooo00@0P8200000000000000000@`3oool00`20P80000000000
0004000009<0oooo000H0?ooo`030820P000000000000080000000<0@4100820P03oool0103oool0
1@20P8000000000000000000P82000D0oooo00<0P8200000000000000P0000000`20P800oooo0?oo
o`020?ooo`80P82000<000000820P00000000`0000070?ooo`@0000000H0P8200<30`03oool0oooo
0<30`020P802000000040410@00000000000000000H0oooo100000040?ooo`040820P00000000000
000000H0oooo100000050?ooo`@0000000@0P82000000010@400P820103oool00`20P800@4100000
0002000000030820P03oool0oooo00<0oooo00D0P82000000000000000000820P00;0?ooo`@00000
1@3oool01P20P8000000000000000000@4100820P0<0oooo0P20P8000`000000P820000000030000
00H0oooo100000090?ooo`050820P0000000000000000020P8002@3oool4000000h0oooo00<0P820
0000000000005P0000000`10@400P8200?ooo`3o0?ooocX0oooo0`00000k0?ooo`040820P0000000
0000000004<0oooo1`0000000`20P800oooo0?ooo`2@0?ooo`00603oool5000000P0oooo00@0P820
00000000000000001@3oool4000000P0oooo00<0P8200000000000000`0000060?ooo`D000001`3o
ool5000000H0oooo100000040?ooo`040820P00000000000000000H0oooo100000050?ooo`H00000
203oool4000000D0oooo00D0P82000000000000000000820P00;0?ooo`@000001@3oool400000003
0820P03oool0oooo00@0oooo00<0P8200000000000000`0000060?ooo`@000002@3oool01@20P800
0000000000000000P82000T0oooo1000000A0?oooaX0000000<0P8200?ooo`3oool0o`3ooolf0?oo
o`<00000>`3oool01020P80000000000000000120?ooo`T00000TP3oool001L0oooo1@0000090?oo
o`040820P00000000000000000@0oooo1@0000080?ooo`030820P0000000000000<000001P3oool4
000000P0oooo1@0000060?ooo`@00000103oool01020P80000000000000000060?ooo`@000001@3o
ool6000000P0oooo1@0000040?ooo`050820P0000000000000000020P8002`3oool4000000D0oooo
100000070?ooo`030820P0000000000000<000001P3oool4000000T0oooo00D0P820000000000000
00000820P0090?ooo`@000004`3ooolK00000?l0oooo=P3oool3000003/0oooo00@0P82000000000
00000000@P3oool900000980oooo000G0?ooo`@000004P3oool4000000X0oooo1@0000060?ooo`@0
00002@3oool4000000H0oooo100000040?ooo`040820P00000000000000000H0oooo100000050?oo
o`D000002P3oool4000000@0oooo00D0P82000000000000000000820P00;0?ooo`@000001@3oool4
000000P0oooo1@0000060?ooo`@000002@3oool01@20P8000000000000000000P82000T0oooo1000
000E0?oooaX00000o`3ooole0?ooo`<00000>`3oool01020P80000000000000000110?ooo`X00000
TP3oool001H0oooo00D0`<3000000000000000000410@00A0?ooo`050<30`0000000000000000020
P8002P3oool5000000H0oooo100000090?ooo`040410@00000000000000000H0oooo100000040?oo
o`040820P00000000000000000H0oooo100000050?ooo`D000002P3oool01@20P800000000000000
0000P82000<0oooo00D0P82000000000000000000820P00;0?ooo`@000001@3oool4000000P0oooo
00<0P8200000000000000P0000060?ooo`@000002@3oool01@20P8000000000000000000P82000T0
oooo1000000F0?ooo`80P8206P0000020820P?l0oooo<03oool3000003/0oooo00@0P82000000000
00000000@03oool00`30`<0000000000000900000300oooo0`20P80J0?ooo`030<30`03oool0oooo
01T0oooo0P20P80V0?ooo`005P3oool01@20P8000000000000000000P8200140oooo00@0P8200000
000000000000303oool4000000H0oooo100000090?ooo`040820P00000000000000000H0oooo1000
00040?ooo`040820P00000000000000000H0oooo100000050?ooo`@00000303oool4000000<0oooo
00D0P82000000000000000000820P00;0?ooo`@000001@3oool4000000T0oooo100000060?ooo`@0
00002@3oool01@20P8000000000000000000P82000T0oooo1000000J0?oooa/0000000<0P8200?oo
o`3oool0o`3oool/0?ooo`<00000>`3oool01020P80000000000000000100?ooo`030820P0000000
000000X00000;P3oool3000001`0oooo0P00000J0?ooo`8000009@3oool001H0oooo00D0P8200000
0000000000000820P00A0?ooo`040820P00000000000000000`0oooo100000060?ooo`@000002@3o
ool01020P80000000000000000060?ooo`@00000103oool01020P80000000000000000060?ooo`@0
00001@3oool4000000`0oooo100000030?ooo`050820P0000000000000000020P8002`3oool40000
00D0oooo100000090?ooo`@000001P3oool4000000T0oooo00D0P82000000000000000000820P009
0?ooo`@00000703ooolL00000?l0oooo;03oool3000003/0oooo00@0P8200000000000000000@03o
ool=000002d0oooo0`00000M0?ooo`80000000<0P8200?ooo`3oool0603oool2000002@0oooo000F
0?ooo`050820P0000000000000000010@4003P20P8030?ooo`040820P00000000000000000`0oooo
100000060?ooo`@000002@3oool01020P80000000000000000060?ooo`@00000103oool01020P800
00000000000000060?ooo`@000001@3oool4000000`0oooo100000030?ooo`050820P00000000000
00000020P8002`3oool4000000D0oooo100000090?ooo`@000001P3oool4000000T0oooo00D0P820
00000000000000000820P0090?ooo`@000007P3oool20820P1X000000P20P83o0?ooobP0oooo0`00
000k0?ooo`040820P00000000000000003l0oooo00<0P8200000000000003000000[0?ooo`040<30
`000000000000410@1h0oooo00<0P82000000020P8006P3oool00`20P80000000820P00R0?ooo`00
5P3oool00`20P80000000000000@000000<0oooo00@0P8200000000000000000303oool4000000H0
oooo100000090?ooo`040820P00000000000000000H0oooo100000040?ooo`040820P00000000000
000000H0oooo100000050?ooo`@00000303oool4000000<0oooo00D0P82000000000000000000820
P00;0?ooo`@000001@3oool4000000T0oooo100000060?ooo`@000002@3oool01@20P80000000000
00000000P82000T0oooo1000000R0?oooa`00000o`3ooolV0?ooo`<00000>`3oool01020P8000000
00000000000o0?ooo`l00000:`3oool01020P800000000000020P80O0?ooo`030820P00000000000
01X0oooo00<0P8200000003oool08@3oool001H0oooo00<0P820000000000000400000030?ooo`04
0820P00000000000000000`0oooo100000060?ooo`@000002@3oool01020P8000000000000000006
0?ooo`@00000103oool01020P80000000000000000060?ooo`@000001@3oool4000000`0oooo1000
00030?ooo`050820P0000000000000000020P8002`3oool4000000D0oooo100000090?ooo`@00000
1P3oool4000000T0oooo00D0P82000000000000000000820P0090?ooo`@00000903ooolL00000003
0820P03oool0oooo0?l0oooo8@3oool3000003/0oooo00@0P8200000000000000000?`3oool?0000
00030820P03oool0oooo02P0oooo0`00000P0?ooo`030820P0000000000001/0oooo0P00000Q0?oo
o`005P3oool00`20P80000000000000@000000<0oooo00@0P8200000000000000000303oool40000
00H0oooo100000090?ooo`040820P00000000000000000H0oooo100000040?ooo`040820P0000000
0000000000H0oooo100000050?ooo`@00000303oool4000000<0oooo00D0P8200000000000000000
0820P00;0?ooo`@000001@3oool4000000T0oooo100000060?ooo`@000002@3oool01@20P8000000
000000000000P82000T0oooo1000000V0?oooa`00000o`3ooolR0?ooo`<00000>`3oool01020P800
000000000000000n0?oooa00000000<0P8200?ooo`3oool0:03oool300000240oooo0P00000K0?oo
o`<00000803oool001H0oooo00D0`<3000000000000000000410@00:0?ooo`040820P00000000000
000000<0oooo00@0P8200000000000000000303oool4000000H0oooo100000090?ooo`040820P000
00000000000000H0oooo100000040?ooo`040820P00000000000000000H0oooo100000050?ooo`@0
000000<0P8200?ooo`3oool02@3oool4000000<0oooo00D0P82000000000000000000820P00;0?oo
o`@000001@3oool4000000T0oooo100000060?ooo`@0000000<0P8200?ooo`3oool01P3oool01@20
P8000000000000000000P82000T0oooo1000000W0?ooo`030<30`020P800P82001X0000000<0@410
0820P03oool0o`3ooolM0?ooo`<00000>`3oool01020P800000000000000000m0?ooo`030820P000
0000000000l000003`3ooolA0820P0T0oooo0`0000000`20P800oooo0?ooo`060?ooo`<0P82000<0
`<300?ooo`3oool0203oool40820P0D0oooo0P20P803000000`0oooo0P20P804000000030410@020
P800oooo00H0oooo00<0P82000000020P8007`3oool001L0oooo1000000:0?ooo`040820P0000000
0000000000@0oooo1000000:0?ooo`D000001P3oool4000000T0oooo00@0P8200000000000000000
1P3oool4000000@0oooo00@0P82000000000000000001P3oool4000000D0oooo1@00000:0?ooo`@0
0000103oool00`20P800000000000002000000/0oooo100000050?ooo`@000002@3oool4000000H0
oooo1@0000080?ooo`030820P00000000000008000002@3oool4000002/0oooo00<0P82000000000
00006P00003o0?oooa`0oooo0`00000k0?ooo`040820P00000000000000003d0oooo4`00000>0?oo
oa4000002@3oool3000000T0oooo00@0P82000000000000000002P3oool3000000030820P03oool0
oooo00<0oooo1@00000;0?ooo`030820P0000000000000H00000203oool2000001l0oooo000G0?oo
o`@000002P3oool3000000030820P03oool0oooo0080oooo1000000:0?ooo`D000001P3oool40000
00T0oooo00@0P82000000000000000001P3oool4000000@0oooo00@0P82000000000000000001P3o
ool4000000D0oooo1@00000:0?ooo`@00000103oool00`20P800000000000002000000/0oooo1000
00050?ooo`@000002@3oool4000000H0oooo1@0000080?ooo`030820P00000000000008000002@3o
ool4000002h0oooo7@00003o0?oooaT0oooo0`00000k0?ooo`040820P00000000000000003`0oooo
00<0P8200000000000004@00000>0?oooa400000203oool4000000X0oooo100000080?ooo`@00000
00<0P8200?ooo`3oool0103oool4000000/0oooo2@0000090?ooo`8000007P3oool001P0oooo1000
00000`20P800oooo0?ooo`050?ooo`050820P0000000000000000020P800103oool00`20P8000000
00000002000000P0oooo00<0P8200000000000000`0000060?ooo`@000002@3oool01020P8000000
0000000000060?ooo`@00000103oool01020P80000000000000000060?ooo`@000001@3oool60000
00P0oooo00D0P82000000000000000000820P0040?ooo`030820P000000000000080000000<0P820
0?ooo`3oool0203oool4000000D0oooo100000090?ooo`@000001P3oool6000000030<30`03oool0
oooo00@0oooo00<0@4100000000000000`0000000`20P800oooo0?ooo`040?ooo`030820P0000000
000000800000<03oool20820P1`000000P20P83o0?oooa@0oooo0`00000k0?ooo`040820P0000000
0000000003`0oooo00<0P8200000000000001P0000030820P0P0000000<0P8200?ooo`3oool0303o
ool4000000030410@020P800P82000X0P8201`3oool4000000/0oooo00D0P8200000000000000000
0820P0050?ooo`030820P00000000000008000001`3oool4000000030820P03oool0oooo00L0oooo
00D0P82000000000000000000410@0050?ooo`030820P03oool0oooo00H0oooo0P0000000`20P800
oooo0?ooo`0K0?ooo`006@3oool4000000030820P03oool0oooo00@0oooo100000060?ooo`D00000
1`3oool6000000H0oooo100000090?ooo`040820P00000000000000000H0oooo100000040?ooo`04
0820P00000000000000000H0oooo100000050?ooo`H0000000<0P8200?ooo`3oool0103oool00`20
P800000000000002000000D0oooo00<0P820000000000000100000090?ooo`@000001@3oool40000
00T0oooo100000060?ooo`L000001P3oool7000000030820P03oool0oooo00<0oooo1000000e0?oo
oah0000000<0P8200?ooo`3oool0o`3oool?0?ooo`<00000>`3oool01020P800000000000000000l
0?ooo`L0000000@0P82000000000000000000`3oool7000000l0oooo1000000C0?ooo`@00000303o
ool01@20P8000000000000000000P82000@0oooo1@0000070?ooo`@0000000<0P8200?ooo`3oool0
1`3oool4000000030820P03oool0oooo00`0oooo00<0P8200000000000007@3oool001T0oooo1@00
00040?ooo`H000001`3oool5000000@0oooo0`0000000`3oool0000000000002000000H0oooo1000
00090?ooo`040820P00000000000000000H0oooo100000040?ooo`040820P00000000000000000H0
oooo100000050?ooo`@0000000@0oooo0000000000000000103oool5000000H0oooo00<0P8200000
000000001@0000001020P800oooo0?ooo`20P8040?ooo`@000001@3oool4000000T0oooo10000006
0?ooo`@0000000@0oooo00000000000000000`3oool6000000040?ooo`0000000000000000<0oooo
00<0P8200000000000000`00000g0?oooal00000o`3oool?0?ooo`<00000>`3oool01020P8000000
00000000000l0?ooo`H0000000<0oooo0820P00000000P0000040?ooo`L000003P3oool00`20P800
00000000000200000180oooo0`00000>0?ooo`<0000000@0P8200?ooo`3oool0oooo1@00000F0?oo
o`@0000000<0P8200?ooo`3oool0303oool01020P800000000000020P80L0?ooo`006P3oool=0000
00P0oooo00<0P820000000000000200000000`20P800oooo00000003000000H0oooo100000090?oo
o`040820P00000000000000000H0oooo100000040?ooo`040820P00000000000000000H0oooo1000
00050?ooo`@000000P3oool:000000030820P03oool0oooo00@0oooo00D0P8200000000000000000
0820P007000000@0oooo100000050?ooo`@000002@3oool4000000H0oooo100000000`3oool00000
0000000:000000030?ooo`000000000000T00000>P3ooolO00000?l0oooo3@3oool3000003/0oooo
00@0P8200000000000000000>`3oool5000000040820P03oool0oooo0820P0<000001P3oool50000
00l0oooo1@00000A0?ooo`<000003`3oool3000000<0oooo1@00000G0?ooo`<0000000<0P8200?oo
o`3oool0303oool01020P800000000000020P80L0?ooo`006P3oool00`30`<00P820000000080000
00030410@03oool0oooo00P0oooo00<0P8200000000000001P0000000`20P800`<300?ooo`040000
00H0oooo100000090?ooo`040820P00000000000000000H0oooo100000040?ooo`040820P0000000
0000000000H0oooo100000050?ooo`@000000P3oool00`20P800000000000006000000030820P03o
ool0oooo00D0oooo00L0P82000000000000000000820P03oool0P82000D00000103oool4000000D0
oooo100000090?ooo`@000001P3oool400000080oooo00<0P8200000000000001P0000001P20P800
oooo0?ooo`3oool0P8200410@0L0000000<0P8200?ooo`3oool0>P3oool30820P1`0000000<0@410
0820P020P800o`3oool80?ooo`<00000>`3oool01020P800000000000000000j0?ooo`050820P000
0000000000000020P800103oool01020P80000000000000000070?ooo`050<30`000000000000000
0020P8003`3oool00`20P800000000000002000000030<30`03oool0oooo00d0oooo0`00000@0?oo
o`<000000P20P804000001P0oooo0`0000000`20P800oooo0?ooo`0=0?ooo`80000000<0@4100?oo
o`3oool06P3oool001d0oooo00<0P8200000000000000`00000@0?ooo`@00000;P3oool01020P800
000000000000000?0?ooo`@000001@3oool4000000030820P03oool0oooo00l0oooo00@0P8200000
000000000000;@3oool4000000030820P03oool0oooo00H0oooo1@0000110?ooo`030820P0000000
000001h00000o`3oool60?ooo`<00000>`3oool01020P800000000000000000j0?ooo`<000001P3o
ool01020P80000000000000000090?ooo`80000000<0P8200?ooo`3oool03P3oool00`20P8000000
00000002000000l0oooo1000000@0?ooo`L0000000<0P8200?ooo`3oool05P3oool3000000030820
P03oool0oooo00d0oooo0`00000L0?ooo`00I@3oool01020P800000000000000000?0?ooo`@00000
W`3oool00`20P80000000000000Q00000?l0oooo0`3oool3000003/0oooo00@0P820000000000000
0000>@3oool00`20P8000000000000070?ooo`040820P00000000000000000X0oooo0P00000A0?oo
o`D000003P3oool400000100oooo00<0P820000000000000100000000`20P800oooo0?ooo`0F0?oo
o`<0000000<0P8200?ooo`3oool03@3oool3000001`0oooo001U0?ooo`040820P000000000000000
00l0oooo1000002O0?ooo`040820P0000000000000000080oooo8@00003o0?ooo`<00000>`3oool0
1020P800000000000000000i0?ooo`030820P0000000oooo00L0oooo00@0P8200000000000000000
2`3oool00`000000oooo0?ooo`0@0?ooo`D000003@3oool400000140oooo1P00000I0?ooo`<00000
00<0P8200?ooo`3oool03@3oool3000001`0oooo001U0?ooo`040820P00000000000000000l0oooo
1000002O0?ooo`<0000000<0P8200?ooo`3oool00P3oool20820P0030410@0000000000001`00000
0P20P83k0?ooo`<00000>`3oool01020P800000000000000000i0?ooo`030820P03oool0oooo00L0
oooo00@0P82000000000000000002`3oool00`30`<0000000?ooo`0A0?ooo`030820P00000000000
0080000000<0`<300?ooo`3oool02@3oool400000180oooo1@00000I0?ooo`040820P00000000000
00000100oooo0`00000K0?ooo`00I@3oool01020P800000000000000000?0?ooo`@00000WP3oool4
000000030820P03oool0oooo00P0oooo8000003h0?ooo`<00000>`3oool01020P800000000000000
00130?ooo`040820P00000000000000000d0oooo00<000000?ooo`3oool0403oool00`20P8000000
00000002000000/0oooo1000000A0?ooo`H000006@3oool01020P800000000000000000@0?ooo`<0
00006`3oool005d0oooo100000040?ooo`040820P00000000000000000H0oooo100000050?ooo`@0
00008`3oool4000007L0oooo1000000;0?ooob800000mP3oool3000003/0oooo00@0P82000000000
00000000@`3oool01020P800000000000000000Q0?ooo`D000002P3oool400000140oooo1P000000
0`20P800oooo0?ooo`0F0?ooo`040820P0000000000000000100oooo0`00000K0?ooo`00G@3oool4
000000@0oooo00@0P82000000000000000001P3oool4000000D0oooo1000000S0?ooo`@00000MP3o
ool00`20P800000000000002000000X0oooo00@0P82000000000000000001020P80M000000<0P820
00<0`<300?ooo`3oool0kP3oool3000003/0oooo00@0P8200000000000000000@`3oool01020P800
000000000000000R0?ooo`030820P000000000000080000000<0`<300?ooo`3oool01`3oool40000
00l0oooo00<0P8200000000000000P0000001020P800000000000020P80G0?ooo`050<30`0000000
000000000020P8003`3oool00`20P80000000000000K0?ooo`00G@3oool4000000@0oooo00@0P820
00000000000000001P3oool4000000D0oooo1000000S0?ooo`@00000MP3oool4000000/0oooo1000
00060?ooob800000k@3oool3000003/0oooo00@0P8200000000000000000@`3oool01020P8000000
00000000000T0?ooo`@000002@3oool4000000l0oooo100000020?ooo`@000005`3oool400000100
oooo0P00000K0?ooo`00G@3oool4000000@0oooo00@0P82000000000000000001P3oool4000000D0
oooo1000000S0?ooo`@00000MP3oool4000000/0oooo100000060?ooobD00000jP3oool3000003/0
oooo00@0P8200000000000000000@`3oool01020P800000000000000000T0?ooo`030820P0000000
000000800000203oool4000000l0oooo100000030?ooo`<0000000<0P8200?ooo`3oool0503oool4
00000100oooo0P00000K0?ooo`00I@3oool01020P800000000000000000?0?ooo`@00000W03oool5
000000X0oooo1@0000050?ooo`D0000000<0oooo0000000000008000003X0?ooo`<00000>`3oool0
1020P80000000000000000130?ooo`040820P00000000000000002D0oooo1@0000080?ooo`<00000
00<0P8200?ooo`3oool0303oool3000000050820P03oool0oooo0?ooo`20P8000`00000F0?ooo`@0
0000403oool2000001/0oooo003o0?oooaT0oooo1000000;0?ooo`@000001P3oool4000000@0oooo
0`20P80P000000<0P820hP3oool3000003/0oooo00@0P8200000000000000000@`3oool01020P800
000000000000000V0?ooo`030820P000000000000080000000<0`<300?ooo`3oool0103oool01010
@400000000000020P80=0?ooo`@0000000<0`<300?ooo`3oool00P3oool01@20P800000000000000
0000P82001@0oooo00D0P82000000000000000000820P00?0?ooo`8000006`3oool00?l0oooo603o
ool00`20P800000000000002000000X0oooo1@0000060?ooo`@00000203ooolU00000=l0oooo0`00
000k0?ooo`040820P00000000000000004<0oooo00@0P82000000000000000006`3ooolA000000H0
oooo00@0P8200000000000000000303oool5000000L0oooo0`00000A0?ooo`h000002@3oool00`00
0000oooo0?ooo`0J0?ooo`00o`3ooolE0?ooo`<0000000D0P82000000000000000000820P00:0?oo
o`@000001P3oool01020P800000000000000000:0?ooobL00000g03oool3000003/0oooo00@0P820
0000000000000000@`3oool01020P800000000000000000K0?oooa4000001P3oool01020P8000000
00000000000<0?ooo`D000001`3oool01020P800000000000000000@0?ooo`h00000203oool20000
01`0oooo003o0?oooa@0oooo00<0P8200000000000001@0000000`20P800oooo0?ooo`070?ooo`03
0<30`00000000000008000001P3oool01020P800000000000000000:0?ooo`@000000`20P8000`10
@40000000000000O000000<0P820e`3oool3000003/0oooo00@0P8200000000000000000@`3oool0
1020P800000000000000000K0?oooa4000001`3oool01020P800000000000000000:0?ooo`D00000
2@3oool01020P800000000000010@40?0?ooo`h00000203oool00`000000@4100?ooo`0K0?ooo`00
o`3ooolD0?ooo`030820P0000000000000P000001`3oool01@20P8000000000000000000P82000H0
oooo1000000:0?ooo`@000001@3ooolV00000=@0oooo0`00000k0?ooo`040820P000000000000000
04<0oooo00@0P8200000000000000000=03oool4000002l0oooo1000000<0?ooo`80000000<0P820
0?ooo`3oool06P3oool00?l0oooo5`3oool9000000H0oooo00D0P82000000000000000000820P006
0?ooo`<0000000<0P8200?ooo`3oool0203oool4000000D0oooo;000003>0?ooo`<00000>`3oool0
1020P80000000000000000130?ooo`040820P00000000000000003D0oooo0`00000_0?ooo`@00000
303oool2000000030820P03oool0oooo01X0oooo003o0?oooaL0oooo2`0000040?ooo`@000001`3o
ool3000000030820P03oool0oooo00P0oooo100000050?ooo`@000000`3ooolX00000</0oooo0`00
000k0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000=@3oool4000002h0
oooo1000000<0?ooo`8000007@3oool00?l0oooo5`3oool4000000030?ooo`20P800P82000<00000
00D0P8200?ooo`3oool0oooo0820P004000000H0oooo100000000`30`<00oooo0?ooo`070?ooo`@0
00001@3oool01@20P8000000000000000000P82000D0oooo:@0000020820P0030<30`03oool0oooo
0<<0oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000=@3o
ool01@30`<000000000000000000P82002d0oooo1000000;0?ooo`030410@0000000oooo01d0oooo
003o0?oooaH0oooo1@0000050?ooo`030000003oool0oooo0080oooo100000070?ooo`@000002P3o
ool4000000D0oooo100000040?ooo`H000000P3ooolX000000030820P03oool0oooo0<00oooo0`00
000k0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000=`3oool3000002d0
oooo00D0P82000000000000000000820P0090?ooo`8000007`3oool00?l0oooo5P3oool4000000/0
oooo100000070?ooo`@000002@3oool5000000D0oooo100000040?ooo`@000001`3ooolY00000;l0
oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000>03oool3
000003/0oooo00<0P8200?ooo`3oool07@3oool00?l0oooo5P3oool4000000X0oooo1@0000060?oo
o`@000002P3oool4000000D0oooo00<0P8200000000000000P0000040?ooo`@000002P3ooolY0000
0;`0oooo0`00000k0?ooo`040820P00000000000000004<0oooo00@0P8200000000000000000>03o
ool4000005X0oooo003o0?oooaH0oooo0`0000000`20P800oooo0?ooo`080?ooo`@000001`3oool4
000000T0oooo00<0`<300000000000000P0000050?ooo`050820P0000000000000000020P8000`3o
ool4000000030820P03oool0oooo00T0oooo:`0000030820P;H0oooo0`00000k0?ooo`040820P000
00000000000004<0oooo00@0P8200000000000000000>@3oool01010@400000000000000001I0?oo
o`00o`3ooolG0?ooo`@00000203oool00`20P800000000000002000000H0oooo1@0000090?ooo`04
0820P00000000000000000H0oooo100000001020P800oooo0?ooo`3oool4000000`0oooo1@000003
0?ooobX00000/P3oool3000003/0oooo00@0P8200000000000000000@`3oool01020P80000000000
0000000j0?ooo`<0000000<0P8200?ooo`3oool0EP3oool00?l0oooo5P3oool5000000P0oooo00@0
P82000000000000000001`3oool4000000X0oooo00@0P82000000000000000001P3oool4000000<0
oooo00<0P8200000000000000P00000<0?ooo`D000001P3ooolZ00000:l0oooo0`00000k0?ooo`04
0820P00000000000000004<0oooo00@0P8200000000000000000?03oool3000005L0oooo003o0?oo
oaP0oooo100000000`10@400P8200820P0040?ooo`040410@00000000000000000L0oooo0`20P800
0`10@400oooo0?ooo`080?ooo`040410@000000000000410@0H0oooo100000030?ooo`050820P000
0000000000000020P800303oool4000000T0oooo0`20P8000`10@40000000000000V000000<0P820
Z03oool3000003/0oooo00@0P8200000000000000000@`3oool01020P800000000000000000m0?oo
o`<0P820EP3oool00?l0oooo603oool00`20P800000000000004000000@0oooo0`0000000`20P800
oooo0?ooo`0C0?ooo`<0000000<0P8200?ooo`3oool00`3oool5000000@0oooo0`0000000`20P800
oooo0?ooo`090?ooo`D00000403oool/00000:@0oooo0`00000k0?ooo`040820P000000000000000
04<0oooo00@0P82000000000000000003@3oool00`000000oooo0?ooo`260?ooo`00o`3ooolJ0?oo
o`@000001@3oool3000000030820P03oool0oooo01<0oooo0`0000000`20P800oooo0?ooo`030?oo
o`@00000103oool01@20P8000000000000000000P82000/0oooo1000000D0?ooo`030820P0000000
000002/00000W`3oool3000003/0oooo00@0P8200000000000000000>@3oool00`20P800oooo0?oo
o`070?ooo`040820P00000000000000000`0oooo0P0000280?ooo`00o`3ooolL0?ooo`030820P000
0000oooo00<0oooo100000000`20P800oooo0?ooo`0B0?ooo`@0000000<0P8200?ooo`3oool00`3o
ool4000000@0oooo00D0P82000000000000000000820P00;0?ooo`@00000603oool^000009/0oooo
0`00000k0?ooo`040820P00000000000000003T0oooo00<0P8200?ooo`3oool01`3oool01020P800
000000000000000;0?ooo`030820P0000000oooo08P0oooo003o0?ooob80oooo1000000F0?ooo`80
P82000<000000?ooo`3oool00`3oool4000000030820P03oool0oooo0080oooo00D0`<3000000000
000000000410@00:0?ooo`050<30`0000000000000000020P8006`3oool01030`<00P8200820P010
@40[000000@0P820T`3oool3000003/0oooo00@0P8200000000000000000>@3oool00`20P8000000
0820P0070?ooo`040820P00000000000000000X0oooo00<0P82000000020P800R@3oool00?l0oooo
8`3oool00`20P80000000000000N0?ooo`@000001P3oool3000000030820P03oool0oooo00P0oooo
00@0P82000000000000000007`3ooold000008l0oooo0`00000k0?ooo`040820P000000000000000
03X0oooo0`0000060?ooo`040820P00000000000000000T0oooo0`00002:0?ooo`00o`3ooom60?oo
o`8000001P3oool4000000X0oooo1000000O0?ooo`@000000`3oool00`20P80000000000000_0000
08X0oooo0`00000k0?ooo`040820P00000000000000003X0oooo100000050?ooo`040820P0000000
0000000000P0oooo0`0000000`20P800oooo0?ooo`280?ooo`00o`3ooom?0?ooo`@0000000<0P820
0?ooo`3oool0103oool5000000030410@03oool0oooo01<0oooo00@0`<300820P020P800`<301@20
P805000000D0oooo100000020820P2h000001020P8000`30`<00oooo0?ooo`1o0?ooo`<00000>`3o
ool01020P800000000000000000k0?ooo`@0000000D0P8200<30`03oool0oooo0820P003000000H0
oooo00<0P8200410@00000000P0000000`20P800oooo0?ooo`280?ooo`00o`3ooom@0?ooo`H00000
0P3oool00`20P800000000000004000000030820P03oool0oooo0140oooo400000050?ooo`@00000
1@3ooolc000007h0oooo0`00000k0?ooo`040820P00000000000000003`0oooo1@0000020?ooo`04
0820P00000000000000000@0oooo1`00002;0?ooo`00o`3ooom@0?ooo`X0000000<0oooo00000000
00000P0000000`20P800oooo0?ooo`0@0?ooo`l000001`3oool4000000T0oooo=@00001h0?ooo`<0
0000>`3oool01020P800000000000000000l0?ooo`L0000000@0P82000000000000000000`3oool8
000008/0oooo003o0?oooe40oooo00<0P8200000000000001P0000000`3oool00000000000020000
0180oooo3`0000070?ooo`D000002@3ooolj000007<0oooo0`00000k0?ooo`040820P00000000000
000003`0oooo2`0000000`3oool0000000000007000008`0oooo003o0?oood80oooo00D0P8200000
00000000P8200<30`00<0?ooo`80P82000@0@4100820P020P800P8200P3oool400000180oooo1000
00000`10@400P8200820P0030820P0050?ooo`20P800oooo0?ooo`30`<001`3oool4000000X0oooo
100000030?ooo`030<30`020P800P82003H000001@20P81X0?ooo`<00000>`3oool01020P8000000
00000000000l0?ooo`030820P000000000000140000000<0P8200?ooo`3oool0RP3oool00?l0oooo
@P3oool4000001@0oooo1@00000B0?ooo`@000004P3oool4000000X0oooo0`0000000`20P800oooo
0?ooo`040?ooo`@000000P3ooolk00000680oooo0`00000k0?ooo`040820P00000000000000003d0
oooo4`00002=0?ooo`00o`3ooom20?ooo`@00000503oool400000180oooo1@00000B0?ooo`@00000
2P3oool3000000030820P03oool0oooo00@0oooo100000070?oooc/00000G@3oool3000003/0oooo
00@0P8200000000000000000?@3ooolB000008h0oooo003o0?oood80oooo1000000D0?ooo`@00000
4`3oool300000180oooo00<0P8200000000000000P00000:0?ooo`<0000000<0P8200?ooo`3oool0
103oool4000000/0oooo?00000000`20P800oooo0?ooo`1E0?ooo`<00000>`3oool01020P8000000
00000000000n0?oooa400000SP3oool00?l0ooooA03oool00`20P800oooo0?ooo`0B0?ooo`@00000
00<0P8200?ooo`3oool04@3oool01010@400000000000000000A0?ooo`050820P000000000000000
0020P8002@3oool01@20P8000000000000000000`<3000D0oooo1000000=0?ooo`@000000`20P80j
000000L0P820B`3oool3000003/0oooo00@0P8200000000000000000?P3oool@000000030410@03o
ool0oooo08`0oooo003o0?oooeT0oooo1000000D0?ooo`030820P00000000000008000001P3oool0
0`20P80000000?ooo`070?ooo`050820P0000000000000000020P8002@3oool4000000H0oooo1000
000=0?ooo`@000001`3ooom5000004<0oooo0`00000k0?ooo`040820P00000000000000003l0oooo
3`0000000`20P800oooo0?ooo`2<0?ooo`00o`3ooomI0?ooo`@00000503oool00`20P80000000000
0003000000D0oooo100000060?ooo`050820P0000000000000000020P8002@3oool4000000H0oooo
1000000=0?ooo`@000002@3ooom:000003`0oooo0`00000k0?ooo`040820P00000000000000003l0
oooo3`00002?0?ooo`00o`3ooomH0?ooo`050820P0000000000000000020P8005@3oool20820P0/0
000000<0P8200?ooo`3oool0103oool4000000030<30`03oool0oooo00L0oooo100000050?ooo`05
0820P0000000000000000020P8003@3oool4000000T0oooo100000000`30`<00oooo0?ooo`040820
P0030410@0000000000004@000001`20P80]0?ooo`<00000>`3oool01020P8000000000000000010
0?ooo`d0000000<0P8200?ooo`3oool0S@3oool00?l0ooooF03oool01@20P8000000000000000000
P82001P0oooo2P0000070?ooo`@000002@3oool4000000H0oooo1000000=0?ooo`030820P0000000
0000008000002@3oool01@20P8000000000000000000P82000H0oooo00<0P8200000000000000P00
00020?ooodh0000000<0P8200?ooo`3oool08`3oool3000003/0oooo00@0P8200000000000000000
@03oool00`20P80000000000000:00000900oooo003o0?oooeP0oooo100000000`20P800oooo0?oo
o`0H0?ooo`L00000203oool4000000T0oooo100000060?ooo`@000003@3oool01020P80000000000
0000000:0?ooo`050820P0000000000000000020P8001`3oool4000000D0oooo00<0P82000000000
0000E000000J0?ooo`<00000>`3oool01020P80000000000000000100?ooo`030820P00000000000
00T00000T@3oool00?l0ooooF03oool4000001h0oooo00<000000?ooo`3oool02@3oool4000000T0
oooo100000060?ooo`@000003@3oool01020P800000000000000000;0?ooo`D000001P3oool40000
00D0oooo00<0P8200000000000000P0000020?ooo`030820P0000000000005P000003`3oool30000
03/0oooo00@0P8200000000000000000@@3oool;00000940oooo003o0?oooeT0oooo0`20P80Y0?oo
o`@000002P3oool4000000D0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0:0?oo
o`040820P00000000000000000`0oooo1@0000000`10@400oooo0?ooo`020?ooo`@00000103oool0
0`20P800@41000000002000000030<30`03oool0oooo00H0oooo0P20P8001010@400000000000010
@41K000000<0P8200`0000050820P3H0oooo00@0P8200000000000000000@@3oool00`20P8000000
00000007000000030820P03oool0oooo08l0oooo003o0?ooohP0oooo00<000000?ooo`3oool01`3o
ool4000000H0oooo00<0P8200000000000000P00000=0?ooo`040820P00000000000000000h0oooo
1P0000000`3oool0P82000000002000000D0oooo1000000C0?ooogX000007`3oool01020P8000000
0000000000120?ooo`T00000TP3oool00?l0ooooTP3oool4000000H0oooo00<0P820000000000000
0`00000<0?ooo`@000003P3oool00`20P800000000000008000000D0oooo1000000C0?ooo`@00000
0`3oool00`20P800000000000028000000L0oooo00@0P82000000000000000008`3oool00`20P800
00000000000E000000P0oooo1`0000000`20P800oooo0?ooo`2@0?ooo`00o`3ooonB0?ooo`040820
P00000000000000000H0oooo00<0@4100000000000001000000;0?ooo`<0000000<0P8200?ooo`3o
ool03`3oool00`20P800000000000005000000D0oooo1000000A0?ooo`060820P000000000000000
0020P800`<302@3oool20820P0<0000000<0P820000000000000``0000080?ooo`030410@0000000
000000@0000000<0`<300?ooo`3oool0T03oool00?l0ooooW03oool3000000050820P00000000000
00000020P8002P3oool3000000030820P03oool0oooo0180oooo1@0000050?ooo`@000004@3oool4
000001L0oooo_`0000080?ooo`030820P0000000000000@00000T`3oool00?l0ooooW03oool30000
00030820P03oool0000000@0000000<0oooo0820P03oool01@3oool3000000030820P03oool0oooo
01<0oooo00@0P82000000000000000001@3oool400000140oooo1000000L0?oookX000002@3oool6
000009<0oooo003o0?oooih0oooo00@000000820P03oool0oooo1@0000001020P800oooo0?ooo`20
P802000000050?ooo`000000000000000020P8005@3oool3000000030820P03oool0oooo00<0oooo
1000000A0?ooo`@00000:03ooon_000000P0oooo1@00002D0?ooo`00o`3ooonR0?ooo`030820P010
@40000000080000000<0P8200?ooo`3oool01`0000000`10@400P8200820P0020820P0@0oooo1000
00090?ooo`<0000000<0P8200?ooo`3oool00P3oool400000180oooo100000060820P2d0oooo1`20
P8000`10@40000000000002J000000T0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00o`3ooonV
0?ooo`0400000020P800oooo0?ooo`d00000103oool4000000P0oooo0`0000000`20P800oooo0?oo
o`030?ooo`<000004P3oool@000000030820P03oool0oooo0380oooo00<0P820000000000000T`00
00090?ooo`<00000U@3oool00?l0oooo[@3oool:000000@0oooo100000080?ooo`<0000000<0P820
0?ooo`3oool00`3oool400000100oooo5000000j0?ooo`030820P0000000000008/000002P3oool0
0`000000P8200?ooo`2D0?ooo`00o`3ooon]0?ooo`@0000000<0P8200000000000000`0000040?oo
o`D000001P3oool4000000030820P03oool0oooo00<0oooo1000000@0?ooo`@0000000<0oooo0000
000000003@0000160?oooh8000002P3oool00`000000P8200?ooo`2D0?ooo`00o`3ooon/0?ooo`03
0820P00000000000008000001@3oool00`20P800oooo0?ooo`030?ooo`030410@0000000000000X0
000000<0P8200?ooo`3oool01@3oool4000000P0oooo0`20P8050?ooo`@000001P3oool40820P0@0
0000DP3ooolG0820P0030410@0000000000004@0000000<0@4100820P020P8005P20P80:0?ooo`03
0820P03oool0oooo09@0oooo003o0?oooj`0oooo1000000?0?ooo`X00000203oool01@20P8000000
000000000000P82000L0oooo100000040?ooo`@000002P3oool400000840oooo6000003A0?ooo`00
o`3ooon/0?ooo`@000003`3oool8000000030820P03oool0oooo00L0oooo00<0P820000000000000
0P0000060?ooo`030820P00000000000008000001@3oool3000000X0oooo1000003o0?ooof/0oooo
003o0?oooj`0oooo00D0P82000000000000000000820P00B0?ooo`030<30`020P800oooo00`0oooo
00<0P820000000000000100000020820P0@0000000<0P8200<30`03oool0103oool01@20P8000000
000000000000`<3000L0oooo100000000`20P800oooo0?ooo`3o0?ooofT0oooo003o0?ooojd0oooo
1000000R0?ooo`/00000203oool5000000H0oooo00<0P8200000000000000P00003o0?ooof`0oooo
003o0?ooojd0oooo100000000`20P800oooo0?ooo`0Q0?ooo`030820P0000000000000D000002P3o
ool4000000H0oooo1@00003o0?ooof`0oooo003o0?ooojd0oooo200000000`20P800oooo0?ooo`0Q
0?ooo`<000002`3oool00`20P80000000000000;00000?l0ooooK@3oool00?l0oooo[P3oool00`30
`<00P82000000004000000030820P03oool0oooo0340oooo2P0000000`20P800oooo0?ooo`3o0?oo
of`0oooo003o0?oook40oooo100000000`20P800oooo0?ooo`0b0?ooo`030820P0000000000000D0
0000o`3ooom`0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o
0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0
oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo
0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0oooo
o`3ooooo0?ooof<0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{261.312, 145.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fig. 3.7. A wave in shallow water, with motion greatly exaggerated.\
\
\>", "Caption",
  CellTags->"Fig. 3.7"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using the incompressibility of the fluid (the volume of the element \
remains fixed during its motion) show that, to lowest approximation, "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`z = \(-h\) \[PartialD]\[Eta]/\[PartialD]x\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Neglecting surface tension, the net force in the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-direction on the element face of height ",
  Cell[BoxData[
      \(TraditionalForm\`h + z\)]],
  " arises from the difference in hydrostatic pressure on each face of the \
element due to elements on the right and left of different heights. The \
hydrostatic pressure is a function of distance ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " from the bottom: ",
  Cell[BoxData[
      \(TraditionalForm\`p\  = \ \[ScriptCapitalM]\ g\ \((h + z(x, t) - 
              y)\)\)]],
  ", where \[ScriptCapitalM] is the mass density of the water and g is the \
acceleration of gravity. Show that the net force in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction, ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["F",
                FontSlant->"Italic"]}]], "x"], TraditionalForm]]],
  ", is given by "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["F",
                  FontSlant->"Italic"]}]], "x"], "=", 
          
          RowBox[{\(-\[ScriptCapitalM]\), " ", "g", " ", "h", 
            " ", \(\[PartialD]z\/\[PartialD]x\), 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Using the results from part (a) and (b), and Newton's 2nd law for the \
mass element,  show that shallow water waves satisfy the wave equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 \[Eta]\/\[PartialD]t\^2 = \(c\^2\) \
\[PartialD]\^2 \[Eta]\/\[PartialD]x\^2\)]],
  ", or alternately, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 z\/\[PartialD]t\^2 = \(c\^2\) \
\[PartialD]\^2 z\/\[PartialD]x\^2\)]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.78)"],

Cell[TextData[{
  "where the wave speed ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is given by "
}], "Text",
  CellTags->"i:50"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`c = \@\(g\ h\)\)]]], "NumberedEquation",
  CellTags->"(3.1.79)"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " A typical ocean depth is on the order of 4 km. Tidal waves have \
wavelengths that are considerably larger than this, and are therefore well \
described by the shallow-water wave equation. Calculate the wave speed (in ",
  Cell[BoxData[
      \(TraditionalForm\`kilometers\ per\ hour\)]],
  ") for a tidal wave."
}], "Text",
  CellTags->"i:97"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " In this problem we consider shallow-water waves, sloshing in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction in a long channel of width ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction.  Boundary conditions on the waves  are that the horizontal \
fluid displacement in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - direction\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " (defined in the previous problem), equals zero at the channel boundaries \
(at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  "). "
}], "Text",
  CellTags->"i:98"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the eigenmodes and eigenfrequencies for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta](x, t)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Plot the wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " vs ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " for the first three sloshing modes. "
}], "Text"],

Cell[TextData[{
  StyleBox["(6)(a)",
    FontWeight->"Bold"],
  " The high ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(E\)\(\ \)\)\)]],
  "-string of a steel string guitar is about ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(L\)\(=\)\),
            "TraditionalForm"], "0.7", " ", "m"}], TraditionalForm]]],
  " long from the fret to the post.  It has a mass per unit length of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Rho]", "=", 
          RowBox[{"5.3", "\[Times]", \(10\^\(-4\)\), " ", 
            RowBox[{"kg", "/", 
              StyleBox["m",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". Find the tension ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " required to properly tune the string, given that a high ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " has a frequency of ",
  Cell[BoxData[
      FormBox[Cell[TextData[{
          " ",
          StyleBox["f ",
            FontSlant->"Italic"],
          "= 1318.51 hertz"
        }]], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Assuming that the ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " string is under the same tension as the ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " string, is made of the same material,  and is about the same length, what \
is the ratio of the thickness of this string to that of the ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " string? An ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " tone has a frequency of  440 hertz."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " Using separation of variables, find the solution for the motion of a \
string that is governed by the following wave equation:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\^2\/\(\(\[PartialD]t\^2\)\(\ \)\)\), 
            RowBox[{"y", 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox[\(x, t\),
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}], 
          StyleBox["=",
            
            FontWeight->
              "Plain"], \(\(\[PartialD]\^2\/\[PartialD]x\^2\) \(y(x, t)\) + \ 
            f(x)\)}], TraditionalForm]]],
  ", "
}], "Text"],

Cell[TextData[{
  "with boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`y(0, t) = \(0 = y(\[Pi], t)\)\)]],
  ", and initial conditions"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y(x, 0) = x(\[Pi] - x)\)\(,\)\)\)]],
  "   ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\/\(\(\[PartialD]t\)\(\ \)\)\), 
            RowBox[{"y", 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox[\(x, 0\),
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". Take ",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = 0. \)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, 0) = 0\)]],
  ",   ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\/\(\(\[PartialD]t\)\(\ \)\)\), 
            RowBox[{"y", 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox[\(x, 0\),
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\(x\^2\ sin\ x\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". Take ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\  = \ \(\(x\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " Transverse oscillations on a uniform string under uniform tension ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " and with mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " need not be only in the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "- direction - the oscillations can occur in any direction in a plane \
transverse to the equilibrium string. Call this plane the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-",
  StyleBox["y",
    FontSlant->"Italic"],
  " plane, and the line of the equilibrium string the ",
  StyleBox["z-",
    FontSlant->"Italic"],
  "axis. Then, neglecting gravity effects,  a  displacement vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", \(z, t\), ")"}], 
          "=", \((x(z, t), y(z, t))\)}], TraditionalForm]]],
  " of a mass element away from equilibrium satisfies the ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " wave equation,"
}], "Text",
  CellTags->"i:51"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\^2\/\[PartialD]t\^2\), 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox[\(z, t\),
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[\(c\^2\),
              FontWeight->"Plain"], \(\[PartialD]\^2\/\[PartialD]z\^2\), 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox[\(z, t\),
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(3.1.80)"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the spatial eigenmodes of this wave equation for boundary conditions \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          StyleBox["0",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z = L\)]],
  ". Show that there are two independent plane polarizations for the \
eigenmodes: an eigenmode involving motion only in the ",
  StyleBox["y",
    FontSlant->"Italic"],
  "-direction,  and one only in the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-direction. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Using the eigenmodes of part a) write down a solution ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(z, t\),
            FontWeight->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " for a ",
  StyleBox["rotating",
    FontSlant->"Italic"],
  " mode  with no nodes except at the ends (think of the motion of a skipping \
rope. ) (Hint: the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-motion is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]/2\)]],
  " out of phase with the y motion.) Over one period, make an animation of \
the motion using ",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This is an example of ",
  StyleBox["circular ",
    FontSlant->"Italic"],
  " polarization."
}], "Text",
  CellTags->"i:52"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " A rope that is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(2  L\_1\),
            "TraditionalForm"], "=", \(12\ meters\)}], TraditionalForm]]],
  " long is attached to posts at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\[PlusMinus]L\_2\)\)]],
  "that are at the same level, but are only ",
  Cell[BoxData[
      \(TraditionalForm\`2  L\_2 = 10\ meters\)]],
  " apart. Find and plot the equilibrium shape of the rope. (Hint: the \
element of length is "
}], "Text",
  CellTags->"i:96"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]s = \(\@\(\[DifferentialD]x\^2 + \
\[DifferentialD]y\^2\) = \[DifferentialD]x \@\( 1 + \((\[DifferentialD]y/\
\[DifferentialD]x)\)\^2\) \[TildeTilde] \[DifferentialD]x\ [
                1 + \(1\/2\) \
\((\[DifferentialD]y/\[DifferentialD]x)\)\^2]\)\)]],
  ", "
}], "Text"],

Cell[TextData[{
  "assuming small perturbations away from a straight rope. Use the linear \
wave equation to determine the equilibrium solution for ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  ". [Answer to lowest order in ",
  Cell[BoxData[
      \(TraditionalForm\`\((L\_1 - L\_2)\)/L\_1\)]],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`y(
          x)\  = \(\(-\(\(g\ \[Rho]\)\/\(2  T\)\)\) \((L\_2\^2 - 
              x\^2)\)\(\ \)\)\)]],
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`T = \ \[Rho]\ g\ L\_2\ \@\(L\_2\/\(6 \((L\_1 - L\_2)\
\)\)\)\)]],
  " is the rope tension. ]"
}], "Text"],

Cell[TextData[{
  StyleBox["(10) ",
    FontWeight->"Bold"],
  "A heavy string of length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " and mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " per unit length is spliced to a light string with equal length",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(L\)\)\)]],
  " and mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]/4\)]],
  " per unit length. The combined string is fixed to posts and placed under \
tension ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ". The posts are both at the same height, so the string would be straight \
and horizontal if there were no gravity. Find and plot the shape of the \
string in the presence of gravity (assuming small displacement from \
horizontal). Take ",
  Cell[BoxData[
      FormBox[
        RowBox[{"L", "=", 
          RowBox[{"1", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Rho]", "=", 
          RowBox[{"0.5", " ", 
            RowBox[{"kg", "/", 
              StyleBox["m",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", "=", 
          RowBox[{"25", " ", 
            StyleBox["N",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". Plot the shape."
}], "Text"],

Cell[TextData[{
  StyleBox["(11)",
    FontWeight->"Bold"],
  " A mass of ",
  Cell[BoxData[
      \(TraditionalForm\`m = 5\ kg\)]],
  " is attached to the center of a rope that has a length of ",
  Cell[BoxData[
      \(TraditionalForm\`2  L\_1 = 10\ meters\)]],
  ". The rope is attached to posts ",
  Cell[BoxData[
      FormBox[
        RowBox[{"at", 
          FormBox[\(x = \(\[PlusMinus]L\_2\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  "that are at the same level but are only  ",
  Cell[BoxData[
      \(TraditionalForm\`2  L\_2 = \ 7\ meters\)]],
  " apart. The mass of the rope is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(=\)\)\)]],
  " 5 kg. Find the shape of the rope and the tension applied to the posts. \
[Use the linear wave equation to determine the equilibrium solution for ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  ", assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(y\)\(|\)\(<< \(L\_1\)\)\)\)]],
  ".] Plot the shape. [Answer to lowest order in ",
  Cell[BoxData[
      \(TraditionalForm\`\((L\_1 - L\_2)\)/L\_1\)]],
  ":  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y(
          x)\  = \(-\(\(\(g\)\(\ \)\)\/\(2  T\)\)\) \((L\_2 - x)\) \((\ 
            m + M + \[Rho]\ x)\)\)\(,\)\(\ \)\(x > 0\)\(,\)\(\ \)\)\)]],
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`T = \ \ g\ \ \@\(\(\(L\_2\)(3\ m\^2 + \ 3\ m\ M\  + \
\ M\^2)\)\/\(24 \((L\_1 - L\_2)\)\)\)\)]],
  " is the rope tension and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = M/2  L\_1\)]],
  " is the mass density. ]"
}], "Text"],

Cell[TextData[{
  StyleBox["(12)(a)",
    FontWeight->"Bold"],
  " In the presence of gravity, the vector wave equation for a rope, Eq. ",
  ButtonBox["(3.1.80)",
    ButtonData:>"(3.1.80)",
    ButtonStyle->"Hyperlink"],
  ", is modified to read"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\^2\/\[PartialD]t\^2\), 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox[\(z, t\),
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox[\(c\^2\),
                FontWeight->"Plain"], \(\[PartialD]\^2\/\[PartialD]z\^2\), 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                StyleBox[\(z, t\),
                  FontWeight->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}], 
            StyleBox["-",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["g",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox[
                OverscriptBox[
                  StyleBox["y",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Bold"]}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "In equilibrium, the rope hangs with a parabolic shape given by Eq. ",
  ButtonBox["(3.1.32)",
    ButtonData:>"(3.1.32)",
    ButtonStyle->"Hyperlink"],
  ". It is possible to oscillate the hanging rope back and forth like a \
pendulum. (Think of a footbridge swaying back and forth.) Find the frequency \
of this swaying motion, assuming that the length of the rope is ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ". (Hint: Apply the principle of superposition to take care of the source \
term, and determine the eigenmodes of the system.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " If one ",
  StyleBox["assumes ",
    FontSlant->"Italic"],
  " that the rope oscillates like a rigid pendulum, show that the frequency \
of small oscillations  is ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(10  T/\[Rho]\ L\^2\)\)]],
  ". (Recall that a rigid pendulum has frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(M\ g/I\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is the mass and ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  " is the ",
  StyleBox["moment of inertia",
    FontSlant->"Italic"],
  " about the pivot.) Why does this answer differ from the result of part a)? \
 Which answer is right?"
}], "Text"],

Cell[TextData[{
  StyleBox["(13)",
    FontWeight->"Bold"],
  " A quantum particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", moving in one dimension in a potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  ",  is described by ",
  ButtonBox["Schr\[ODoubleDot]dinger's equation",
    ButtonData:>{
      URL[ "http://www.nobel.se/physics/laureates/1933/schrodinger-bio.html"],
       None},
    ButtonStyle->"Hyperlink"],
  ","
}], "Text",
  CellTags->"i:53"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\ \[HBar] \
\(\[PartialD]\/\(\(\[PartialD]t\)\(\ \)\)\) \[CapitalPsi] = \(H\&^\) \
\[CapitalPsi]\)]],
  ", "
}], "NumberedEquation",
  CellTags->"(3.1.81)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPsi](x, t)\)]],
  " is the particle's wave function, the Hamiltonian operator ",
  Cell[BoxData[
      \(TraditionalForm\`H\&^\)]],
  " is given by "
}], "Text",
  CellTags->"i:111"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`H\&^ = \(-\(\[HBar]\^2\/\(2\ m\)\)\) \
\[PartialD]\^2\/\[PartialD]x\^2 + \ V(x)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(3.1.82)"],

Cell[TextData[{
  "and  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[HBar]", "=", 
          RowBox[{\(1.055\ \[Cross]10\^\(-34\)\), " ", 
            StyleBox["N",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontSlant->"Plain"], 
            StyleBox["m",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontSlant->"Plain"], 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " is Planck's constant divided by ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  ". A quantum particle moves in a box of width ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ". Boundary conditions on the wave function are therefore ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Psi]\)\(=\)\(0\)\(\ \)\)\)]],
  "at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ". Use separation of variables to solve the following initial-value \
problem:",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(\(\[CapitalPsi](0, x)\)\(\ \)\(=\)\),
              "TraditionalForm"], " ", 
            RowBox[{
              FormBox[\(x\^3\),
                "TraditionalForm"], "(", \(L - x\), ")"}]}]}], 
        TraditionalForm]]],
  ". Animate the result for the probability density ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[CapitalPsi]\)\( | \^2\)\)\)]],
  " over a time ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 20  \[HBar]/m\ L\^2\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(14)",
    FontWeight->"Bold"],
  " In a slab with uniform conductivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\)]],
  ", find the equilibrium temperature distribution ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_eq\)(x)\)]],
  " under the listed conditions. Show directly that in each case Eq. ",
  ButtonBox["(3.1.51)",
    ButtonData:>"(3.1.51)",
    ButtonStyle->"Hyperlink"],
  " is satisfied."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`S(x) = S\_o\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`T(0) = T\_1, \ \ T(L) = T\_2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`S(x) = x, \ \(\[PartialD]T\/\[PartialD]x\) \((0)\) = 
        0, T(L) = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(S(x) = \ \[Alpha]\ \(\[Delta](x - L/3)\)\), 
          ",", \(\(\[PartialD]T\/\[PartialD]x\) \((0)\) = T(0)\), ",", Cell[
          TextData[Cell[BoxData[
              \(TraditionalForm\`\(\[PartialD]T\/\[PartialD]x\) \((L)\) = 
                0\)]]]], "  "}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " The ceiling  of a Scottish castle consists of  1/4-meter-thick  material \
with thermal conductivity ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Kappa]", "=", 
          RowBox[{"0.5", " ", 
            RowBox[{
              StyleBox["W",
                FontSlant->"Plain"], "/", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontSlant->"Plain"], " ", 
                  StyleBox["K",
                    FontSlant->"Plain"]}], ")"}]}]}]}], TraditionalForm]]],
  " Most of the heat is lost through the ceiling.  The exterior temperature \
is, on average,   0 \[Degree]C, and the interior is kept at a chilly 15 \
\[Degree]C. The surface area of the ceiling is 2000 ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["m",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  ".  The cost per kilowatt-hour of heating power is 3 Pence. How much does \
it cost (in pounds) to heat the castle for one month (30 days)? (Note: One \
British pound equals 100 Pence.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(16)",
    FontWeight->"Bold"],
  " Solve the following heat equation problem on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1\)]],
  ", with given boundary and initial conditions, and plot the solution for \
0<t<2 by making a table of plots at a sequence of 40 times:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\(T(x, t)\)\), \(\[PartialD]t\),
            MultilineFunction->None], "=", " ", 
          RowBox[{
            FractionBox[\(\[PartialD]\^2\( T(x, t)\)\), \(\[PartialD]x\^2\),
              MultilineFunction->None], "+", \(S(x)\)}]}], 
        TraditionalForm]]],
  ". "
}], "Text"],

Cell["Boundary conditions, initial conditions, and source:", "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t) = 0, \ T(1, t) = 3\)]],
  "; initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S(x) = 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Insulated at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`T(1, t) = 1\)]],
  "; initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = \ x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S(x) = 1\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Insulated on both faces, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(T(x, 0) = 0\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`S(x)\  = \ sin\ 2  \[Pi]\ x\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(17)(a)",
    FontWeight->"Bold"],
  " A slab of fat, thickness 2 cm, thermal diffusivity ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", " ", "=", " ", 
          RowBox[{\(10\^\(-6\)\), " ", 
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "2"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", and initially at temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T = 5\ \[Degree]C\)]],
  ", is dropped into a pot of hot water at ",
  Cell[BoxData[
      \(TraditionalForm\`T = 60  \[Degree]C\)]],
  ". Find ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " within the slab. Find the time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  " needed for the center of the fat to reach a temperature of ",
  Cell[BoxData[
      \(TraditionalForm\`55  \[Degree]C\)]],
  ". Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " up to this time."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Over very long times, the behavior of ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  "is dominated by the eigenmode with the lowest decay rate. Keeping only \
this mode in the evolution, use this approximate solution for ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " to rederive ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  " ",
  StyleBox["analytically",
    FontSlant->"Italic"],
  ", and compare the result with that found using the exact answer from part \
(a). "
}], "Text"],

Cell[TextData[{
  StyleBox["(18)",
    FontWeight->"Bold"],
  " A cold steak, initially at uniform temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = 8\ \[Degree]C\)]],
  ", and of thickness ",
  Cell[BoxData[
      \(TraditionalForm\`L = \ 3\ cm\)]],
  ", is placed on a griddle (at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ") at temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T = 250\ \[Degree]C\)]],
  ". The steak will be cooked medium rare when its minimum internal \
temperature reaches ",
  Cell[BoxData[
      \(TraditionalForm\`T = 65\ \[Degree]C\)]],
  ".  How long does this take? Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " up to this time. (The boundary condition on the upper face of the meat at \
",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  " can be taken to be approximately insulating. The thermal diffusivity of \
meat is about ",
  Cell[BoxData[
      FormBox[
        RowBox[{"3", "\[Times]", \(10\^\(-7\)\), " ", 
          RowBox[{
            SuperscriptBox[
              StyleBox["m",
                FontSlant->"Plain"], "2"], "/", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". )"
}], "Text"],

Cell[TextData[{
  StyleBox["(19)",
    FontWeight->"Bold"],
  " A sheet of copper has thickness ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\)\(\ \)\)\)]],
  ", thermal diffusivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  ", and specific heat ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  ".   It is heated uniformly with a constant power density ",
  Cell[BoxData[
      \(TraditionalForm\`S = j\^2\ \[Rho]\)]],
  " due to a current density ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " running through the sheet, where \[Rho] is the resistivity of the copper. \
The faces of the sheet, each with area ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and at temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_o\)]],
  " (to be determined), radiate into free space with a heat flux given by the \
Stefan-Boltzmann law for black-body radiation: ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma] = \((1 - r)\) \[Sigma]\ T\_o\^4\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Sigma]", "=", 
          RowBox[{"5.67", " ", "\[Times]", \(10\^\(-8\)\), " ", 
            RowBox[{
              StyleBox["W",
                FontSlant->"Plain"], "/", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox["m",
                      FontSlant->"Plain"], \(\(2\)\(\ \)\)], 
                  SuperscriptBox[
                    StyleBox["K",
                      FontSlant->"Plain"], "4"]}], ")"}], " "}]}]}], 
        TraditionalForm]]],
  "is the Stefan -Boltzmann constant, and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(r\)\(\ \)\)\)]],
  "is the reflectivity of the material, equal to zero for a blackbody and 1 \
for a perfect reflector."
}], "Text",
  CellTags->"i:55"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find and plot the equilibrium temperature ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_eq\)(x)\)]],
  " in the sheet. What is the maximum temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_max\)]],
  " as a function of the current density ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  "? "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " If the temperature varies by an amount ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  " from equilibrium, the radiated power out of the face at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " changes by an amount "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"\[CapitalDelta]\[CapitalGamma]", "=", 
            RowBox[{
              RowBox[{\((1 - r)\), 
                RowBox[{"{", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"[", 
                        RowBox[{\(T\_o\), "+", 
                          RowBox[{
                            StyleBox[
                              RowBox[{"\[CapitalDelta]", 
                                StyleBox["T",
                                  FontSlant->"Italic"]}]], "(", \(0, t\), 
                            ")"}]}], " ", "]"}], "4"], "-", \(T\_o\^4\)}], 
                  "}"}]}], "\[TildeEqual]", 
              RowBox[{"4", \((1 - r)\), "\[Sigma]", " ", \(T\_o\%3\), 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["T",
                        FontSlant->"Italic"]}]], "(", \(0, t\), ")"}]}]}]}]}],
         TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "(assuming that ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_o\), " ", ">>", " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  "), and similarly for the face at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ".  Thus, the boundary condition for small temperature deviations is mixed. \
Find the first three eigenmodes and their rate of decay. Take ",
  Cell[BoxData[
      \(TraditionalForm\`L = 1\ cm, \ r = 0.8, \)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["S",
            FontSlant->"Italic"], " ", "=", 
          RowBox[{
            FormBox[\(10\^3\),
              "TraditionalForm"], 
            RowBox[{
              StyleBox["W",
                FontSlant->"Plain"], "/", 
              FormBox[
                SuperscriptBox[
                  StyleBox["m",
                    FontSlant->"Plain"], "3"],
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  ". "
}], "Text",
  CellTags->"i:56"],

Cell[TextData[{
  StyleBox["(20)",
    FontWeight->"Bold"],
  " Damped waves on a string of length ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  " in gravity satisfy the wave equation\n\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[PartialD]\^2 y\/\[PartialD]t\^2 + \ \(1\/4\) \[PartialD]y\
\/\[PartialD]t = \[PartialD]\^2 y\/\[PartialD]x\^2 - 1\), " ", ",", "  ", 
          RowBox[{\(y(\(-\[Pi]\)/2, t)\), "=", 
            RowBox[{\(y(\[Pi]/2, t)\), "=", 
              RowBox[{"0", Cell[""]}]}]}]}], TraditionalForm]]],
  ".\n For initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, 0) = \(\(\[Pi]/2\)\(-\)\) | x | \)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\& . \)(x, 0) = 0\)]],
  ",  plot ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 20\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2 Laplace's Equation in Some Separable Geometries", "Subtitle",
  CellTags->"c:24"],

Cell[" ", "Text"],

Cell[TextData[{
  "\tIn a region of space that is charge-free, the electrostatic potential ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  "  satisfies Poisson's equation without sources:"
}], "Text",
  CellTags->"i:112"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Del]\^2\), 
            RowBox[{"\[Phi]", "(", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}]}], "=", "0"}], TraditionalForm]]],
  ", "
}], "NE2",
  CellTags->"(3.2.1)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", \((x, y, z)\)}], TraditionalForm]]],
  " is the position vector,  and the Laplacian operator ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  "is defined by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\(\(=\)\(\[PartialD]\^2\/\[PartialD]x\^2 + \
\[PartialD]\^2\/\[PartialD]y\^2 + \[PartialD]\^2\/\[PartialD]z\^2\)\)\)]],
  "."
}], "NE2",
  CellTags->"(3.2.2)"],

Cell[TextData[{
  "This PDE is called ",
  StyleBox[ButtonBox["Laplace",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Laplace.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox["'s equation",
    FontSlant->"Italic"],
  ".  To solve for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " within a specified volume ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " we require boundary conditions to be given on the surface ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  "  of the volume (see Fig. ",
  ButtonBox["3.8",
    ButtonData:>"Fig. 3.8",
    ButtonStyle->"Hyperlink"],
  "). We will consider boundary conditions that fall into three categories:"
}], "Text",
  CellTags->"i:57"],

Cell[TextData[{
  "\t ",
  StyleBox["Dirichlet,",
    FontSlant->"Italic"],
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[Phi]\)\( | \_S\)\), "=", 
          RowBox[{\(\[Phi]\_o\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  "for some potential ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\_o\), "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  "applied to the surface ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ";"
}], "Text",
  CellTags->"i:58"],

Cell[TextData[{
  "\t ",
  StyleBox["von Neumann",
    FontSlant->"Italic"],
  ", where the directional derivative of \[Phi] normal to the surface is \
determined: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox[
                OverscriptBox[
                  StyleBox["n",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Bold",
                FontSlant->"Plain"], "\[CenterDot]", 
              StyleBox[\(\[Del]\[Phi]\),
                FontWeight->"Plain"]}], 
            StyleBox[\( | \_S\),
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[\(E\_o\),
              FontWeight->"Plain"], "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  " where, ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            StyleBox["n",
              FontWeight->"Bold",
              FontSlant->"Plain"], "^"],
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " is a unit vector perpendicular to the surface ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ", or "
}], "Text",
  CellTags->"i:59"],

Cell[TextData[{
  "\t ",
  StyleBox["mixed",
    FontSlant->"Italic"],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{\(f\ \[Phi]\), "+", 
                RowBox[{"g", 
                  RowBox[{
                    StyleBox[
                      OverscriptBox[
                        StyleBox["n",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "^"],
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "\[CenterDot]", 
                    StyleBox[\(\[Del]\[Phi]\),
                      FontWeight->"Plain"]}]}]}], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox[\( | \_S\),
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{\(u\_o\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  " for some function ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(u\_o\), "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " and (nonnegative) functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  "  . The functions ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " cannot both vanish at the same point on ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  "."
}], "Text",
  CellTags->"i:60"],

Cell[TextData[{
  "\t  These three boundary conditions are straightforward generalizations of \
the conditions of the same name, considered previously for one-dimensional \
PDEs. Physically, Dirichlet conditions can occur in the case where the \
surface",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(S\)\)\)]],
  " is a set of one or more conductors that are held at fixed potentials. Von \
Neumann conditions are less common in electrostatics problems, applying to \
the case where the normal component of the electric field is determined at \
the surface.  Mixed conditions rarely occur in electrostatics problems, but \
can sometimes be found in applications of Poisson's equation to other areas \
of physics, such as thermal physics [see Eq. ",
  ButtonBox["(3.1.47)",
    ButtonData:>"(3.1.47)",
    ButtonStyle->"Hyperlink"],
  ", for example] "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P000392000`400?l00000o`00003oo`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3o
oooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooong0?ooo`030<30`020P800P820
01l0oooo00<0`<300?ooo`3oool0o`3ooon60?ooo`00o`3ooonG0?ooo`<0P82000<0`<300?ooo`3o
ool06`3oool01010@400000000000030`<0M0?ooo`050<30`0000000000000000030`<00o`3ooon4
0?ooo`00o`3ooonG0?ooo`040820P00000000000000001h0oooo0`00000O0?ooo`<00000o`3ooon4
0?ooo`00o`3ooonH0?ooo`040410@000000000000410@1d0oooo00@0`<30000000000000@4107P3o
ool01@30`<000000000000000000`<300?l0ooooPP3oool00?l0ooooN03oool20820P0030410@030
`<00oooo01`0oooo00@0P820000000000000@4107P3oool00`10@40000000410@00N0?ooo`050<30
`0000000000000000030`<00o`3ooon10?ooo`00o`3ooomh0?ooo`050<30`0000000000000000030
`<007@3oool01@30`<000000000000000000`<3001d0oooo00@0@410000000000000`<307@3oool0
1@30`<000000000000000000`<3001d0oooo00<0P8200<30`03oool0o`3ooomP0?ooo`00o`3ooomj
0?ooo`<000007P3oool01020P800000000000000000N0?ooo`<000007`3oool3000001h0oooo0P00
00000`20P800oooo0?ooo`3o0?oooed0oooo003o0?oooe/0oooo0P20P80M0?ooo`050<30`0000000
000000000030`<007@3oool01010@400000000000010@40M0?ooo`040<30`000000000000410@1h0
oooo00D0`<3000000000000000000<30`00L0?ooo`050<30`0000000000000000030`<00o`3ooomM
0?ooo`00o`3ooomJ0?ooo`040410@000000000000410@1d0oooo00D0`<3000000000000000000<30
`00M0?ooo`040820P000000000000410@1h0oooo00<0@41000000010@4007P3oool01@30`<000000
000000000000`<3001`0oooo00D0`<3000000000000000000<30`03o0?oooe`0oooo003o0?oooe/0
oooo00@0@410000000000000@4107@3oool01@30`<000000000000000000`<3001d0oooo00D0`<30
00000000000000000<30`00M0?ooo`040410@000000000000<30`1d0oooo00D0`<30000000000000
00000<30`00L0?ooo`050<30`0000000000000000030`<00o`3ooomK0?ooo`00o`3ooomL0?ooo`<0
000000<0P8200?ooo`3oool0703oool3000001h0oooo00@0P82000000000000000007P3oool30000
01l0oooo0`00000N0?ooo`<00000o`3ooomK0?ooo`00o`3ooolk0?ooo`040<30`020P80000000410
@1h0oooo00@0@410000000000000P8207@3oool01@30`<000000000000000000`<3001d0oooo00@0
@410000000000000@4107@3oool01030`<00000000000010@40N0?ooo`050<30`000000000000000
0030`<00703oool01@30`<000000000000000000`<300?l0ooooF@3oool00?l0oooo?03oool01020
P800000000000010@40N0?ooo`040410@000000000000410@1d0oooo00D0`<300000000000000000
0<30`00M0?ooo`040820P000000000000410@1h0oooo00<0@41000000010@4007P3oool01@30`<00
0000000000000000`<3001`0oooo00D0`<3000000000000000000<30`03o0?oooeP0oooo003o0?oo
ocd0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@000000000000410@1d0oooo00D0
`<3000000000000000000<30`00M0?ooo`050<30`0000000000000000030`<007@3oool01010@400
000000000030`<0M0?ooo`050<30`0000000000000000030`<00703oool01@30`<00000000000000
0000`<300?l0ooooE`3oool00?l0oooo?P3oool01020P800000000000000000N0?ooo`<0000000<0
P8200?ooo`3oool0703oool3000001h0oooo00@0P82000000000000000007P3oool3000001l0oooo
0`00000N0?ooo`<00000o`3ooomG0?ooo`00o`3ooolN0?ooo`040<30`020P800P8200<30`1d0oooo
00@0@410000000000000@4107P3oool01010@400000000000020P80M0?ooo`050<30`00000000000
00000030`<007@3oool01010@400000000000010@40M0?ooo`040<30`000000000000410@1h0oooo
00@0`<30000000000000@4107@3oool01@30`<000000000000000000`<300?l0ooooE@3oool00?l0
oooo7P3oool01@30`<000000000000000000`<3001d0oooo00@0P820000000000000@4107P3oool0
1010@400000000000010@40M0?ooo`050<30`0000000000000000030`<007@3oool01020P8000000
00000010@40N0?ooo`030410@0000000@41001h0oooo00D0`<3000000000000000000<30`00L0?oo
o`050<30`0000000000000000030`<00o`3ooomD0?ooo`00o`3ooolP0?ooo`040410@00000000000
0820P1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@000000000000410@1d0oooo
00D0`<3000000000000000000<30`00M0?ooo`050<30`0000000000000000030`<007@3oool01010
@400000000000030`<0M0?ooo`050<30`0000000000000000030`<00703oool01@30`<0000000000
00000000`<300?l0ooooD`3oool00?l0oooo8@3oool3000000030820P03oool0oooo01/0oooo00@0
P82000000000000000007P3oool3000000030820P03oool0oooo01`0oooo0`00000N0?ooo`040820
P00000000000000001h0oooo0`00000N0?ooo`040820P00000000000000001h0oooo0`00003o0?oo
oe<0oooo003o0?ooob40oooo00D0`<3000000000000000000<30`00M0?ooo`040410@00000000000
0410@1h0oooo00@0@410000000000000P8207@3oool01@30`<000000000000000000`<3001d0oooo
00@0@410000000000000@4107@3oool01030`<00000000000010@40N0?ooo`040820P00000000000
0410@1d0oooo00D0`<3000000000000000000<30`00N0?ooo`030<30`03oool0oooo0?l0oooo<03o
ool00?l0oooo0@3oool01030`<00P8200820P020P80M0?ooo`050<30`0000000000000000030`<00
7@3oool01020P800000000000010@40N0?ooo`040410@000000000000410@1d0oooo00D0`<300000
0000000000000<30`00M0?ooo`040820P000000000000410@1h0oooo00<0@41000000010@4007P3o
ool01@30`<000000000000000000`<3001`0oooo00D0`<3000000000000000000<30`00M0?ooo`04
0<30`0000000@4100820P?l0oooo;`3oool00?l0oooo0P3oool01010@400000000000010@40N0?oo
o`040410@000000000000820P1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@000
000000000410@1d0oooo00D0`<3000000000000000000<30`00M0?ooo`050<30`000000000000000
0030`<007@3oool01010@400000000000030`<0M0?ooo`050<30`0000000000000000030`<00703o
ool01@30`<000000000000000000`<3001h0oooo00<0@41000000010@400o`3oool^0?ooo`00o`3o
ool30?ooo`<0000000<0P8200?ooo`3oool0703oool3000000030820P03oool0oooo01/0oooo00@0
P82000000000000000007P3oool3000000030820P03oool0oooo01`0oooo0`00000N0?ooo`040820
P00000000000000001h0oooo0`00000N0?ooo`040820P00000000000000001h0oooo0`00000O0?oo
o`<00000o`3oool]0?ooo`00o`3oool40?ooo`040410@000000000000820P1d0oooo00D0`<300000
0000000000000<30`00M0?ooo`040410@000000000000410@1h0oooo00@0@410000000000000P820
7@3oool01@30`<000000000000000000`<3001d0oooo00@0@410000000000000@4107@3oool01030
`<00000000000010@40N0?ooo`040820P000000000000410@1d0oooo00D0`<300000000000000000
0<30`00M0?ooo`040<30`000000000000410@?l0oooo;03oool00?l0oooo1@3oool01010@4000000
00000010@40M0?ooo`050<30`0000000000000000030`<007@3oool01020P800000000000010@40N
0?ooo`040410@000000000000410@1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040820
P000000000000410@1h0oooo00<0@41000000010@4007P3oool01@30`<000000000000000000`<30
01`0oooo00D0`<3000000000000000000<30`00M0?ooo`040<30`000000000000410@?l0oooo:`3o
ool00>@0oooo00@0`<300820P020P800`<307@3oool01010@400000000000010@40N0?ooo`040410
@000000000000820P1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@00000000000
0410@1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040<30`000000000000410@1h0oooo
00@0@410000000000000`<307@3oool01@30`<000000000000000000`<3001`0oooo00D0`<300000
0000000000000<30`00N0?ooo`030410@0000000@4100?l0oooo:P3oool00>@0oooo00@0P8200000
0000000000007P3oool3000000030820P03oool0oooo01`0oooo0`0000000`20P800oooo0?ooo`0K
0?ooo`040820P00000000000000001h0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`<000007P3o
ool01020P800000000000000000N0?ooo`<000007P3oool01020P800000000000000000N0?ooo`<0
00007`3oool300000?l0oooo:@3oool00>D0oooo00@0P820000000000000@4107P3oool01010@400
000000000020P80M0?ooo`050<30`0000000000000000030`<007@3oool01010@400000000000010
@40N0?ooo`040410@000000000000820P1d0oooo00D0`<3000000000000000000<30`00M0?ooo`04
0410@000000000000410@1d0oooo00@0`<30000000000000@4107P3oool01020P800000000000010
@40M0?ooo`050<30`0000000000000000030`<007@3oool01030`<00000000000010@43o0?ooobP0
oooo003V0?ooo`050<30`0000000000000000030`<007@3oool01010@400000000000010@40M0?oo
o`050<30`0000000000000000030`<007@3oool01020P800000000000010@40N0?ooo`040410@000
000000000410@1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@000000000000410
@1h0oooo00<0@41000000010@4007P3oool01@30`<000000000000000000`<3001`0oooo00D0`<30
00000000000000000<30`00M0?ooo`040<30`000000000000410@?l0oooo9`3oool00>L0oooo00D0
`<3000000000000000000<30`00M0?ooo`040410@000000000000410@1h0oooo00@0@41000000000
0000P8207@3oool01@30`<000000000000000000`<3001d0oooo00@0@410000000000000@4107@3o
ool01@30`<000000000000000000`<3001d0oooo00@0P820000000000000@4107P3oool01010@400
000000000030`<0M0?ooo`050<30`0000000000000000030`<00703oool01@30`<00000000000000
0000`<3001h0oooo00<0@41000000010@400o`3ooolV0?ooo`00j03oool01020P800000000000000
000N0?ooo`<0000000<0P8200?ooo`3oool0703oool3000000030820P03oool0oooo01/0oooo00@0
P82000000000000000007P3oool3000000030820P03oool0oooo01`0oooo0`00000N0?ooo`040820
P00000000000000001h0oooo0`00000N0?ooo`040820P00000000000000001h0oooo0`00000O0?oo
o`<00000o`3ooolU0?ooo`00j@3oool01020P800000000000010@40N0?ooo`040410@00000000000
0820P1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@000000000000410@1h0oooo
00@0@410000000000000P8207@3oool01@30`<000000000000000000`<3001d0oooo00@0@4100000
00000000@4107@3oool01030`<00000000000010@40N0?ooo`040820P000000000000410@1d0oooo
00D0`<3000000000000000000<30`00M0?ooo`040<30`000000000000410@?l0oooo903oool00<`0
oooo00<0`<300?ooo`3oool06`3oool01@30`<000000000000000000`<3001d0oooo00@0@4100000
00000000@4107@3oool01@30`<000000000000000000`<3001d0oooo00@0P820000000000000@410
7P3oool01010@400000000000010@40M0?ooo`050<30`0000000000000000030`<007@3oool01010
@400000000000010@40N0?ooo`030410@0000000@41001h0oooo00D0`<3000000000000000000<30
`00L0?ooo`050<30`0000000000000000030`<007@3oool01030`<00000000000010@43o0?ooob<0
oooo003:0?ooo`040820P000000000000820P1d0oooo00D0`<3000000000000000000<30`00M0?oo
o`040410@000000000000410@1h0oooo00@0@410000000000000P8207@3oool01@30`<0000000000
00000000`<3001d0oooo00@0@410000000000000@4107@3oool01@30`<000000000000000000`<30
01d0oooo00@0P820000000000000@4107P3oool01010@400000000000030`<0M0?ooo`050<30`000
0000000000000030`<00703oool01@30`<000000000000000000`<3001h0oooo00<0@41000000010
@400o`3ooolR0?ooo`00b`3oool3000000030820P03oool0oooo01/0oooo00@0P820000000000000
00007P3oool3000000030820P03oool0oooo01`0oooo0`0000000`20P800oooo0?ooo`0K0?ooo`04
0820P00000000000000001h0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`<000003P3oool00`20
P80000000000000j000000030820P03oool0oooo01<0oooo00@0P82000000000000000007P3oool3
000001l0oooo0`00003o0?ooob40oooo003;0?ooo`050<30`0000000000000000030`<007@3oool0
1020P800000000000010@40N0?ooo`040410@000000000000820P1d0oooo00D0`<30000000000000
00000<30`00M0?ooo`040410@000000000000410@1h0oooo00@0@410000000000000`<307@3oool0
1030`<0000000000000000060820P0030410@0000000000004P000000`20P8000`30`<00oooo0?oo
o`0:0?ooo`040820P000000000000410@1d0oooo00D0`<3000000000000000000<30`00M0?ooo`04
0<30`000000000000410@?l0oooo803oool00<`0oooo00D0`<3000000000000000000<30`00M0?oo
o`050<30`0000000000000000030`<007@3oool01010@400000000000010@40M0?ooo`050<30`000
0000000000000030`<007@3oool01020P800000000000010@40N0?ooo`040410@000000000000820
P140oooo00<0`<300820P020P8001020P8000`10@40000000000000P000002l0P8203P0000001010
@400P8200820P020P8060?ooo`050<30`0000000000000000030`<00703oool01@30`<0000000000
00000000`<3001d0oooo00@0`<30000000000000@410o`3ooolO0?ooo`00cP3oool01010@4000000
00000020P80M0?ooo`050<30`0000000000000000030`<007@3oool01010@400000000000010@40N
0?ooo`040410@000000000000820P1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410
@000000000000410@0D0oooo1P20P80H000000030410@020P800P82000H0P82000<0`<300?ooo`3o
ool0@03oool01@30`<00P8200820P020P800@41000X0000000D0@4100820P020P800oooo0<30`003
000000030<30`03oool0oooo01X0oooo00D0`<3000000000000000000<30`00N0?ooo`030410@000
0000@41001h0oooo0P20P83m0?ooo`00c`3oool01010@400000000000010@40M0?ooo`050<30`000
0000000000000030`<007@3oool01020P800000000000010@40N0?ooo`040410@000000000000410
@1d0oooo00D0`<3000000000000000000<30`00J0?ooo`<0P8204`0000000`10@400P8200820P007
0820P5d0oooo1020P80<000000030<30`03oool0oooo01/0oooo00@0@410000000000000P8207P3o
ool01010@400000000000030`<0M0?ooo`040410@0000000P8200820P?X0oooo003@0?ooo`<00000
00<0P8200?ooo`3oool0703oool3000001h0oooo00@0P82000000000000000007P3oool300000003
0820P03oool0oooo01/0oooo00@0P8200000000000000000503ooolG000007<0oooo2P00000N0?oo
o`<0000000<0P8200?ooo`3oool0703oool3000001h0oooo0`0000000`20P800oooo0?ooo`3g0?oo
o`00d03oool01@30`<000000000000000000`<3001d0oooo00D0`<3000000000000000000<30`00M
0?ooo`040410@000000000000410@1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040820
P000000000000410@0T0oooo00<0`<300820P020P8000P20P8000`10@40000000000000=00000003
0410@020P800P82000<0P820N`3oool30820P0P000000P20P8000`30`<00oooo0?ooo`0F0?ooo`05
0<30`0000000000000000030`<007@3oool01030`<00000000000010@40M0?ooo`050<30`0000000
000000000030`<00n03oool00=80oooo00@0@410000000000000P8207@3oool01@30`<0000000000
00000000`<3001d0oooo00@0@410000000000000@4107P3oool01010@400000000000030`<0M0?oo
o`040<30`00000000000000000@0P8203P0000060820P8/0oooo00<0`<300820P010@4001`000000
0`10@400P8200<30`00E0?ooo`050<30`0000000000000000030`<007P3oool00`10@40000000410
@00N0?ooo`040410@000000000000820P?L0oooo002c0?ooo`030<30`020P800`<3001d0oooo00@0
@410000000000000@4107@3oool01@30`<000000000000000000`<3001d0oooo00@0P82000000000
0000@4107P3oool01010@400000000000020P80E0?ooo`030<30`020P800P8200080P8203P000000
0`10@400P8200820P0020820P0030<30`03oool0oooo09P0oooo00<0`<300820P020P8001P000000
0`10@400P8200820P00C0?ooo`040410@000000000000<30`1h0oooo00@0@410000000000000`<30
7@3oool01010@400000000000010@43f0?ooo`00/P3oool01020P800000000000000000N0?ooo`<0
000000<0P8200?ooo`3oool0703oool3000001h0oooo00@0P82000000000000000007P3oool30000
00030820P03oool0oooo00h0oooo00<0P8200000000000004000002Y0?ooo`T000004P3oool30000
01l0oooo0`00000N0?ooo`<0000000<0P8200?ooo`3oool0l`3oool00;<0oooo00@0@41000000000
0000@4107@3oool01@30`<000000000000000000`<3001d0oooo00D0`<3000000000000000000<30
`00M0?ooo`040410@000000000000410@1d0oooo00D0`<3000000000000000000<30`0070?ooo`05
0<30`020P800P8200820P010@400300000050820P;00oooo0P20P80700000080P8203P3oool01@30
`<000000000000000000`<3001d0oooo00@0`<30000000000000@4107@3oool01@30`<0000000000
00000000`<300?@0oooo002d0?ooo`040820P000000000000410@1h0oooo00@0@410000000000000
P8207@3oool01@30`<000000000000000000`<3001d0oooo00@0@410000000000000@4107@3oool0
1030`<0000000000000000030820P0030410@0000000000000T0000000D0@4100820P020P800P820
0<30`02m0?ooo`030<30`020P800@41000H000000P20P80;0?ooo`050<30`0000000000000000030
`<007P3oool00`10@40000000410@00N0?ooo`040410@000000000000820P?<0oooo002e0?ooo`05
0<30`0000000000000000030`<007@3oool01010@400000000000010@40M0?ooo`050<30`0000000
000000000030`<007@3oool01020P800000000000010@40G0?ooo`050<30`020P800P8200820P010
@400300000030820P0030<30`03oool0oooo0<L0oooo00<0`<300820P010@4001P0000000`20P800
`<300?ooo`070?ooo`050<30`0000000000000000030`<007P3oool01010@400000000000030`<0M
0?ooo`040410@000000000000410@?80oooo002f0?ooo`040820P00000000000000001h0oooo0`00
00000`20P800oooo0?ooo`0L0?ooo`<000007P3oool01020P800000000000000000C0?oooa000000
e@3oool00`20P800000000000005000000030820P03oool0oooo00H0oooo0`00000O0?ooo`<00000
7P3oool3000000030820P03oool0oooo0>l0oooo002g0?ooo`040410@000000000000410@1d0oooo
00D0`<3000000000000000000<30`00M0?ooo`050<30`0000000000000000030`<007@3oool01010
@400000000000010@40;0?ooo`040<30`020P800P8200820P0/000001020P83K0?ooo`030<30`020
P800@41000D0000000<0@4100820P030`<00103oool01@30`<000000000000000000`<3001d0oooo
00@0`<30000000000000@4107@3oool01@30`<000000000000000000`<300?00oooo002h0?ooo`04
0820P000000000000410@1h0oooo00@0@410000000000000P8207@3oool01@30`<00000000000000
0000`<3001d0oooo00@0@410000000000000@410103oool30820P0030410@0000000000000P00000
0`20P83W0?ooo`80P8201P0000001@20P800`<300?ooo`3oool0`<3000<0000000<0`<300?ooo`3o
ool0703oool00`10@40000000410@00N0?ooo`040410@000000000000820P>l0oooo002i0?ooo`05
0<30`0000000000000000030`<007@3oool01010@400000000000010@40M0?ooo`050<30`0000000
000000000030`<007@3oool>000000<0P82000<0`<300?ooo`3oool0k`3oool20820P0D0000000<0
@4100820P030`<000`0000000`30`<00oooo0?ooo`0L0?ooo`040410@000000000000<30`1d0oooo
00@0@410000000000000@410kP3oool00;X0oooo00@0P82000000000000000007P3oool300000003
0820P03oool0oooo01`0oooo0`00000J0?ooo`h00000n`3oool00`20P800000000000008000001l0
oooo0`00000N0?ooo`<0000000<0P8200?ooo`3oool0j`3oool00;/0oooo00@0@410000000000000
@4107@3oool01@30`<000000000000000000`<3001d0oooo00@0`<30000000000000@4104P3oool0
1030`<00P8200820P020P80:000000<0P82000<0`<300?ooo`3oool0oP3oool20820P0P0000000<0
`<300?ooo`3oool06`3oool01030`<00000000000010@40M0?ooo`050<30`0000000000000000030
`<00k03oool00;`0oooo00@0P820000000000000@4107P3oool01010@400000000000020P80M0?oo
o`050<30`0000000000000000030`<002P3oool30820P0030410@0000000000000L0000000@0@410
0820P020P800P820o`3oool;0?ooo`030820P010@400000000D0000000<0P8200?ooo`3oool0703o
ool00`10@40000000410@00N0?ooo`040410@000000000000820P>/0oooo002m0?ooo`050<30`000
0000000000000030`<007@3oool01010@400000000000010@40M0?ooo`050<30`000000000000000
0030`<000`3oool30820P0030410@0000000000000L000000`20P8000`30`<00oooo0?ooo`3o0?oo
oa80oooo00<0`<300820P00000001@0000000`20P800`<300?ooo`0J0?ooo`040410@00000000000
0<30`1d0oooo00@0@410000000000000@410jP3oool009h0oooo00<0P8200000003oool07@3oool0
1020P800000000000000000N0?ooo`<0000000<0P8200?ooo`3oool06`3oool00`20P80000000000
000>00000?l0oooo7P3oool7000000030820P03oool0oooo01T0oooo0`00000N0?ooo`<0000000<0
P8200?ooo`3oool0i`3oool009h0oooo00@0@410000000000000`<307@3oool01010@40000000000
0010@40M0?ooo`050<30`0000000000000000030`<006P3oool00`30`<00P8200410@00:000000<0
P820o`3ooolS0?ooo`030820P010@400000000@0000000<0@4100820P03oool05`3oool01030`<00
000000000010@40M0?ooo`050<30`0000000000000000030`<00j03oool009l0oooo00@0@4100000
00000000`<307@3oool01020P800000000000010@40N0?ooo`040410@000000000000820P1@0oooo
00<0`<300820P010@400200000001010@400P8200820P030`<3o0?ooob`0oooo00<0`<300820P000
0000100000020820P1L0oooo00<0@41000000010@4007P3oool01010@400000000000020P83W0?oo
o`00X03oool01020P800000000000030`<0M0?ooo`040<30`000000000000410@1h0oooo00@0@410
000000000000@4103P3oool30820P0P000000P20P83o0?ooocH0oooo0P20P805000000030410@020
P800oooo01@0oooo00@0@410000000000000`<307@3oool01010@400000000000010@40N0?ooo`03
0820P03oool0oooo0<D0oooo002Q0?ooo`030820P0000000000001h0oooo00@0P820000000000000
00007P3oool3000000030820P03oool0oooo00T0oooo2P00003o0?oooch0oooo00<0P82000000000
0000100000000`20P800oooo0?ooo`0B0?ooo`<000007P3oool3000000030820P03oool0oooo01`0
oooo00<000000?ooo`3oool0a03oool00:80oooo00@0@410000000000000`<307@3oool01010@400
000000000010@40M0?ooo`050<30`0000000000000000030`<001P3oool00`30`<00P82000000006
000000030410@020P800P8200?l0oooo@P3oool00`30`<00@4100000000400000080P8204@3oool0
1030`<00000000000010@40M0?ooo`050<30`0000000000000000030`<007@3oool00`30`<000000
0820P0340?ooo`00X`3oool01010@400000000000030`<0M0?ooo`040410@000000000000410@1h0
oooo00@0@410000000000000P8200P3oool20820P0D0000000<0@4100820P020P800o`3ooom:0?oo
o`80P8201@0000000`10@400P8200<30`00?0?ooo`030410@0000000@41001h0oooo00@0@4100000
00000000P8207@3oool01@30`<000000000000000000`<300<40oooo002T0?ooo`040820P0000000
00000<30`1d0oooo00@0P820000000000000@4107P3oool00`10@40000000000000600000080P820
o`3ooomA0?ooo`030<30`020P800@41000D000000P20P80=0?ooo`040410@000000000000<30`1d0
oooo00@0@410000000000000@4107@3oool01@30`<000000000000000000`<300<00oooo002U0?oo
o`030820P0000000000001h0oooo00@0P82000000000000000007@3oool7000000030820P03oool0
oooo0?l0ooooEP3oool7000000030820P03oool0oooo00X0oooo0`00000N0?ooo`<0000000<0P820
0?ooo`3oool06`3oool01020P80000000000000000300?ooo`00YP3oool01010@400000000000030
`<0M0?ooo`040410@000000000000410@1T0oooo00<0P820000000000000100000000`20P800`<30
0?ooo`3o0?oooe/0oooo00<0P8200410@0000000100000020820P0T0oooo00@0`<30000000000000
@4107@3oool01@30`<000000000000000000`<3001d0oooo00@0P820000000000000@410_`3oool0
0:L0oooo00@0@410000000000000`<307@3oool01010@400000000000010@40E0?ooo`030820P010
@400000000<0000000<0@4100820P03oool0o`3ooomR0?ooo`80P8201@0000000`10@400P8200<30
`0070?ooo`030410@0000000@41001h0oooo00@0@410000000000000P8207@3oool01@30`<000000
000000000000`<300;d0oooo002X0?ooo`040820P000000000000<30`1d0oooo00@0P82000000000
0000@4104@3oool00`30`<00@41000000004000000030820P030`<00oooo0?l0ooooI`3oool00`30
`<00P8200410@00500000080P8201@3oool00`10@40000000410@00N0?ooo`040410@00000000000
0410@1d0oooo00D0`<3000000000000000000<30`02l0?ooo`00Z@3oool00`20P80000000000000N
0?ooo`040820P00000000000000000h0oooo00<0P820000000000000100000000`20P800oooo0?oo
o`3o0?ooofd0oooo1`0000000`20P800oooo0?ooo`020?ooo`<000007P3oool3000000030820P03o
ool0oooo01/0oooo00@0P8200000000000000000_03oool00:X0oooo00@0@410000000000000`<30
7@3oool01010@400000000000010@40;0?ooo`030<30`010@400000000<0000000<0@4100820P03o
ool0o`3ooomb0?ooo`030820P0000000000000<0000000D0@4100820P030`<00oooo0<30`0020000
00030410@03oool0oooo01/0oooo00D0`<3000000000000000000<30`00M0?ooo`040820P0000000
00000410@;/0oooo002[0?ooo`040410@000000000000<30`1d0oooo00@0@410000000000000@410
1`3oool00`30`<00@41000000004000000030820P03oool0oooo0?l0ooooMP3oool00`30`<00P820
0410@00500000080P8200P0000000`10@400oooo0?ooo`0L0?ooo`040410@000000000000820P1d0
oooo00D0`<3000000000000000000<30`02i0?ooo`00R`3oool00`30`<0000000410@00N0?ooo`04
0820P000000000000<30`1d0oooo00@0P820000000000000@410103oool00`20P800@41000000003
000000030820P03oool0oooo0?l0ooooO@3oool20820P0L0000000<0@4100?ooo`3oool0703oool0
1010@400000000000010@40M0?ooo`050<30`0000000000000000030`<00^03oool008/0oooo0`00
00000`20P800oooo0?ooo`0L0?ooo`030820P0000000000001h0oooo00@0P8200000000000000000
0P3oool4000000030820P03oool0oooo0?l0ooooP`3oool00`20P800000000000005000001h0oooo
0`0000000`20P800oooo0?ooo`0K0?ooo`040820P0000000000000000;P0oooo002;0?ooo`050<30
`0000000000000000030`<007P3oool01010@400000000000030`<0M0?ooo`040410@00000000000
0410@0<0000000<0@4100<30`03oool0o`3ooon60?ooo`030<30`020P800000000D0000000<0@410
0<30`03oool06P3oool01@30`<000000000000000000`<3001d0oooo00@0P820000000000000@410
]`3oool008d0oooo00@0@410000000000000P8207P3oool01010@400000000000030`<0L0?ooo`03
0820P000000000000080000000<0@4100?ooo`3oool0o`3ooon<0?ooo`030820P010@400000000@0
000000<0@4100<30`03oool06@3oool01010@400000000000020P80M0?ooo`050<30`00000000000
00000030`<00]@3oool008h0oooo00@0@410000000000000@4107P3oool01020P800000000000030
`<0H0?ooo`030<30`020P800000000<0000000<0@4100<30`03oool0o`3ooonA0?ooo`030<30`010
@400000000@0000000<0P8200<30`03oool05`3oool01010@400000000000010@40M0?ooo`050<30
`0000000000000000030`<00]03oool008l0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`030820
P0000000000001L0oooo00<0P8200000000000000`00003o0?oooiP0oooo1`00000H0?ooo`<00000
00<0P8200?ooo`3oool06`3oool01020P800000000000000002d0?ooo`00S`3oool01@30`<000000
000000000000`<3001h0oooo00@0@410000000000000`<30503oool00`20P8000000000000020000
00030820P03oool0oooo0?l0ooooV@3oool00`20P800@4100000000300000080P8205@3oool01@30
`<000000000000000000`<3001d0oooo00@0P820000000000000@410/`3oool00940oooo00@0@410
000000000000P8207P3oool01010@400000000000030`<0A0?ooo`060820P0000000000000000010
@400P820o`3ooonP0?ooo`030820P010@400000000<000000P20P80D0?ooo`040410@00000000000
0820P1d0oooo00D0`<3000000000000000000<30`02a0?ooo`00TP3oool01010@400000000000010
@40N0?ooo`040820P000000000000<30`0h0oooo00<0`<300410@00000000P0000000`20P800oooo
0?ooo`3o0?oooj<0oooo00<0P8200410@00000000`0000000`20P800`<300?ooo`0A0?ooo`040410
@000000000000410@1d0oooo00D0`<3000000000000000000<30`02`0?ooo`00T`3oool01010@400
000000000010@40N0?ooo`040<30`000000000000820P0/0oooo00H0`<3000000000000000000410
@020P83o0?ooojX0oooo0P20P804000000030820P030`<00oooo00l0oooo00@0@410000000000000
@4107@3oool01@30`<000000000000000000`<300:l0oooo002D0?ooo`<0000000<0P8200?ooo`3o
ool0703oool01020P800000000000020P8090?ooo`030820P0000000000000800000o`3ooon_0?oo
o`030820P000000000000080000000<0P8200?ooo`3oool03P3oool3000000030820P03oool0oooo
01`0oooo0`00002_0?ooo`00U@3oool01010@400000000000020P80N0?ooo`040410@00000000000
0<30`0L0oooo00D0P82000000000000000000820P03o0?oook40oooo00<0`<300820P010@4000`00
00000`10@400`<300?ooo`0=0?ooo`040410@000000000000820P1d0oooo00D0`<30000000000000
00000<30`02]0?ooo`00UP3oool01010@400000000000010@40N0?ooo`040820P000000000000<30
`0@0oooo00D0P8200410@000000000000820P03o0?oookH0oooo00<0`<300410@00000000P000000
0`10@400P8200<30`00<0?ooo`040410@000000000000410@1d0oooo00D0`<300000000000000000
0<30`02/0?ooo`00U`3oool01010@400000000000010@40N0?ooo`040<30`000000000000820P080
oooo00@0@410000000000000@410o`3ooonk0?ooo`030<30`010@40000000080000000<0@4100<30
`03oool02P3oool01010@400000000000010@40M0?ooo`050<30`0000000000000000030`<00Z`3o
ool009P0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`040820P000000000000820P0<0000000<0
P8200?ooo`3oool0o`3ooonl0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0203o
ool3000000030820P03oool0oooo01`0oooo0`00002[0?ooo`00V@3oool01010@400000000000020
P80N0?ooo`030410@000000000000080000000<0P8200?ooo`3oool0o`3ooono0?ooo`030820P000
000000000080000000<0@4100<30`03oool0203oool01010@400000000000020P80M0?ooo`050<30
`0000000000000000030`<00Z@3oool007`0oooo00<0`<300?ooo`3oool06`3oool01010@4000000
00000010@40M0?ooo`050410@000000000000410@030`<00o`3oooo40?ooo`80P820100000000`20
P800`<300?ooo`060?ooo`040410@000000000000410@1d0oooo00D0`<3000000000000000000<30
`02X0?ooo`00N`3oool00`20P80000000410@00M0?ooo`040410@000000000000410@1X0oooo00D0
`<3000000000000000000410@03o0?ooolT0oooo00<0P8200000000000000P0000000`10@400P820
0?ooo`050?ooo`040410@000000000000410@1d0oooo00D0`<3000000000000000000<30`02W0?oo
o`00N`3oool3000000030820P03oool0oooo01/0oooo0`0000000`20P800oooo0?ooo`0F0?ooo`@0
0000o`3oooo=0?ooo`H0000000<0P8200?ooo`3oool00`3oool3000000030820P03oool0oooo01`0
oooo0`00002W0?ooo`00O03oool01010@400000000000020P80M0?ooo`040410@000000000000820
P1H0oooo00D0@41000000000000000000<30`03o0?ooolh0oooo00<0`<300410@00000000`000000
0`10@400P8200?ooo`030?ooo`040410@000000000000820P1d0oooo00D0`<300000000000000000
0<30`02U0?ooo`00O@3oool01010@400000000000010@40M0?ooo`040410@000000000000410@1@0
oooo00@0@410000000000000@410o`3ooooC0?ooo`030820P010@400000000<0000000D0P8200?oo
o`3oool0oooo0410@002000000030410@03oool0oooo01/0oooo00D0`<3000000000000000000<30
`02T0?ooo`00OP3oool01010@400000000000010@40M0?ooo`040410@000000000000410@140oooo
00D0P82000000000000000000820P03o0?ooomH0oooo00<0`<300410@00000000`0000001020P800
oooo0?ooo`10@402000000030410@03oool0oooo01/0oooo00D0`<3000000000000000000<30`02S
0?ooo`00O`3oool3000000030820P03oool0oooo01/0oooo0`0000000`20P800oooo0?ooo`0=0?oo
o`040820P0000000000000000?l0oooof`3oool500000080oooo0`0000000`20P800oooo0?ooo`0L
0?ooo`<00000X`3oool00800oooo00@0@410000000000000P8207@3oool01010@400000000000020
P80=0?ooo`050<30`0000000000000000030`<00o`3ooooL0?ooo`030820P0000000000000800000
00<0P8200?ooo`10@4000P0000000`30`<00oooo0?ooo`0K0?ooo`050<30`0000000000000000030
`<00X@3oool00840oooo00@0@410000000000000@4107@3oool01010@400000000000010@40;0?oo
o`050<30`0000000000000000030`<00o`3ooooN0?ooo`030<30`020P800000000<0000000D0@410
00000000000000000820P00M0?ooo`050<30`0000000000000000030`<00X03oool00880oooo00@0
@410000000000000@4107@3oool01010@400000000000010@4080?ooo`050<30`000000000000000
0030`<00o`3ooooS0?ooo`030820P0000000000000D0000000<0@4100?ooo`3oool06`3oool01@30
`<000000000000000000`<3009l0oooo00230?ooo`<0000000<0P8200?ooo`3oool06`3oool30000
00030820P03oool0oooo00D0oooo0`0000000`20P800oooo0?ooo`3o0?ooon@0oooo1`0000000`20
P800oooo0?ooo`0L0?ooo`<00000W`3oool008@0oooo00@0@410000000000000P8207@3oool01010
@400000000000020P8050?ooo`040410@000000000000820P?l0ooooj03oool00`30`<00@4100000
0004000000030<30`03oool0oooo01/0oooo00D0`<3000000000000000000<30`02M0?ooo`00Q@3o
ool01010@400000000000010@40M0?ooo`040410@000000000000410@0<0oooo00<0@41000000000
0000o`3oooo/0?ooo`030<30`010@400000000<0000000<0P8200?ooo`3oool06`3oool01@30`<00
0000000000000000`<3009`0oooo00260?ooo`040410@000000000000410@1d0oooo00D0@4100000
00000000@4100<30`003000000030<30`03oool0oooo0?l0ooook@3oool00`10@400000000000002
000000030820P03oool0oooo01X0oooo00D0`<3000000000000000000<30`02K0?ooo`00Q`3oool3
000000030820P03oool0oooo01/0oooo1P0000000`20P800oooo0?ooo`3o0?ooonl0oooo00<0P820
0000000000000`00000M0?ooo`<00000V`3oool008P0oooo00@0@410000000000000`<307@3oool0
1@10@4000000000000000000@4100?l0ooool`3oool00`30`<00P82000000003000000030820P03o
ool0oooo01T0oooo00D0`<3000000000000000000<30`02I0?ooo`00R@3oool01010@40000000000
0020P80K0?ooo`050820P0000000000000000020P800o`3oooog0?ooo`060820P000000000000000
0010@400`<306P3oool01@30`<000000000000000000`<3009P0oooo002:0?ooo`040410@0000000
00000410@1T0oooo00D0@410000000000000@4100<30`03o0?ooooT0oooo00<0`<300820P0000000
0P0000000`20P800`<300?ooo`0H0?ooo`050<30`0000000000000000030`<00U`3oool008/0oooo
0`0000000`20P800oooo0?ooo`0E0?ooo`040820P0000000000000000?l0oooooP3oool400000003
0820P03oool0oooo01P0oooo0`00002G0?ooo`00K@3oool00`30`<00oooo0?ooo`0K0?ooo`050<30
`0000000000000000030`<005@3oool01@30`<000000000000000000`<300?l0oooooP3oool00`30
`<00@41000000002000000030820P03oool0oooo01L0oooo00D0`<3000000000000000000<30`02E
0?ooo`00K03oool00`10@40000000<30`00N0?ooo`040410@000000000000820P1<0oooo00@0P820
000000000000@410o`3ooooo0?ooo`@0oooo00D0P82000000000000000000820P00H0?ooo`050<30
`0000000000000000030`<00U03oool006`0oooo00@0`<30000000000000P8207P3oool01010@400
000000000010@40A0?ooo`040820P000000000000<30`?l0ooooo`3oool60?ooo`060<30`010@400
000000000010@400`<305`3oool01@30`<000000000000000000`<3009<0oooo001]0?ooo`040820
P000000000000820P1h0oooo0`0000000`20P800oooo0?ooo`0>0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooooo0?ooo`P0oooo1000000H0?ooo`<00000T`3oool006h0oooo00@0@410000000000000
`<307@3oool01@30`<000000000000000000`<3000h0oooo00@0@410000000000000`<30o`3ooooo
0?ooo`X0oooo00H0`<300410@000000000000410@030`<0F0?ooo`050<30`0000000000000000030
`<00T@3oool006l0oooo00@0P820000000000000`<307P3oool01010@400000000000020P80<0?oo
o`030410@0000000@4100?l0ooooo`3oool>0?ooo`050820P0000000000000000020P8005P3oool0
1@30`<000000000000000000`<300900oooo001`0?ooo`040<30`000000000000820P1h0oooo00@0
@410000000000000@4102@3oool01030`<00000000000010@43o0?ooool0oooo4@3oool01@20P800
0000000000000000P82001D0oooo00D0`<3000000000000000000<30`02?0?ooo`00L@3oool01020
P800000000000020P80N0?ooo`<0000000<0P8200?ooo`3oool01P3oool01020P800000000000020
P83o0?ooool0oooo4P3oool01@20P8000000000000000000P82001H0oooo0`00002?0?ooo`00LP3o
ool01010@400000000000030`<0M0?ooo`050<30`0000000000000000030`<001P3oool01030`<00
000000000010@43o0?ooool0oooo503oool01@30`<000000000000000000@41001D0oooo00D0`<30
00000000000000000<30`02=0?ooo`00L`3oool01020P800000000000030`<0N0?ooo`040410@000
000000000820P0@0oooo00@0`<30000000000000P820o`3ooooo0?oooaL0oooo00D0P82000000000
000000000410@00D0?ooo`050<30`0000000000000000030`<00S03oool007@0oooo00@0`<300000
00000000P8207P3oool01010@400000000000010@4020?ooo`040820P000000000000<30`?l0oooo
o`3ooolI0?ooo`030<30`010@40000000080000000<0`<300?ooo`3oool04@3oool01@30`<000000
000000000000`<3008/0oooo001e0?ooo`040<30`000000000000410@1h0oooo00D0@41000000000
0000@4100820P002000000030410@03oool0oooo0?l0ooooo`3ooolJ0?ooo`030820P010@4000000
0080000000<0`<300?ooo`3oool04@3oool01010@400000000000030`<2:0?ooo`00MP3oool01020
P800000000000020P80N0?ooo`H00000o`3ooooo0?oooal0oooo1000000D0?ooo`<00000RP3oool0
07L0oooo00@0P820000000000000`<307P3oool01@10@4000000000000000000`<300?l0ooooo`3o
oolO0?ooo`030<30`010@40000000080000000<0`<300?ooo`3oool0403oool01@30`<0000000000
00000000`<3008P0oooo001h0?ooo`040<30`000000000000820P1d0oooo00<0@410000000000000
o`3ooooo0?ooob<0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`0?0?ooo`050<30
`0000000000000000030`<00Q`3oool007T0oooo00@0`<30000000000000@4106P3oool01@30`<00
0000000000000000`<300?l0ooooo`3ooolT0?ooo`030<30`010@40000000080000000<0P8200?oo
o`3oool03`3oool01@30`<000000000000000000`<3008H0oooo001j0?ooo`040820P00000000000
0820P1T0oooo00@0P820000000000000P820o`3ooooo0?ooobL0oooo100000000`20P800oooo0?oo
o`0@0?ooo`<00000QP3oool007/0oooo00@0P820000000000000`<305`3oool01030`<0000000000
0010@43o0?ooool0oooo:03oool00`30`<00P82000000002000000030820P030`<00oooo00l0oooo
00D0`<3000000000000000000<30`0240?ooo`00O03oool01030`<00000000000020P80E0?ooo`04
0<30`0000000000000000?l0ooooo`3oool[0?ooo`030<30`000000000000080000000<0`<300?oo
o`3oool03P3oool01@30`<000000000000000000`<3008<0oooo001N0?ooo`80P8207@3oool01030
`<00000000000010@40D0?ooo`80000000<0@4100?ooo`3oool0o`3ooooo0?ooob/0oooo00<0`<30
0410@00000000P0000000`30`<00oooo0?ooo`0>0?ooo`050<30`0000000000000000030`<00PP3o
ool005h0oooo0P0000000`20P800oooo0?ooo`0K0?ooo`040820P000000000000820P180oooo0`00
003o0?ooool0oooo<@3oool400000140oooo0`0000220?ooo`00GP3oool3000000030<30`03oool0
oooo01/0oooo00@0P820000000000000`<30403oool01010@400000000000020P83o0?ooool0oooo
<@3oool01@30`<000000000000000000@4100100oooo00D0`<3000000000000000000<30`0200?oo
o`00GP3oool01@30`<000000000000000000`<3001d0oooo00@0`<30000000000000P8203P3oool0
1030`<00000000000010@43o0?ooool0oooo=03oool01010@400000000000010@40@0?ooo`050<30
`0000000000000000030`<00O`3oool00600oooo00@0@410000000000000P8207@3oool01030`<00
000000000010@40=0?ooo`<00000o`3ooooo0?ooocH0oooo00@0P820000000000000@410403oool0
1@30`<000000000000000000`<3007h0oooo001Q0?ooo`<0000000<0P8200?ooo`3oool06`3oool0
1020P800000000000020P80;0?ooo`030820P000000000000?l0ooooo`3ooolh0?ooo`050820P000
0000000000000020P800403oool3000007h0oooo001Q0?ooo`050<30`0000000000000000030`<00
7@3oool01020P800000000000030`<090?ooo`040820P000000000000<30`?l0ooooo`3oooli0?oo
o`050410@0000000000000000030`<003`3oool01@30`<000000000000000000`<3007`0oooo001R
0?ooo`050<30`0000000000000000030`<007@3oool01030`<00000000000020P8070?ooo`040<30
`000000000000410@?l0ooooo`3ooolk0?ooo`050<30`0000000000000000030`<003`3oool01@30
`<000000000000000000`<3007/0oooo001T0?ooo`040410@000000000000820P1d0oooo00@0`<30
000000000000@4101@3oool01030`<00000000000010@43o0?ooool0oooo?P3oool01010@4000000
00000020P80?0?ooo`050<30`0000000000000000030`<00NP3oool006D0oooo0`0000000`20P800
oooo0?ooo`0K0?ooo`040820P000000000000820P0@0oooo00@0P820000000000000P820o`3ooooo
0?ooocl0oooo0`0000000`20P800oooo0?ooo`0>0?ooo`<00000NP3oool006D0oooo00D0`<300000
0000000000000<30`00M0?ooo`040820P000000000000<30`080oooo00@0`<30000000000000P820
o`3ooooo0?oood00oooo00D0`<3000000000000000000<30`00?0?ooo`050<30`000000000000000
0030`<00N03oool006H0oooo00D0`<3000000000000000000<30`00M0?ooo`080<30`00000000000
0<30`03oool0@41000000020P83o0?ooool0oooo@P3oool01@30`<000000000000000000@41000l0
oooo00D0`<3000000000000000000<30`01g0?ooo`00J03oool01010@400000000000020P80M0?oo
o`030<30`000000000000080000000<0@4100?ooo`3oool0o`3ooooo0?oooch0oooo00<0P8200<30
`03oool00P3oool01020P800000000000010@40?0?ooo`050<30`0000000000000000030`<00MP3o
ool006T0oooo0`0000000`20P800oooo0?ooo`0K0?ooo`040820P0000000000000000?l0ooooo`3o
oolo0?ooo`030820P0000000000000D0oooo00@0P8200000000000000000403oool3000007H0oooo
001Y0?ooo`050<30`0000000000000000030`<00703oool01030`<00000000000010@43o0?ooool0
oooo?P3oool00`20P8000000000000070?ooo`040410@000000000000410@0l0oooo00D0`<300000
0000000000000<30`01d0?ooo`00JP3oool01@30`<000000000000000000`<3001/0oooo00<0@410
00000020P800o`3ooooo0?ooocd0oooo00D0@41000000000000000000820P0080?ooo`040410@000
000000000410@0l0oooo00D0`<3000000000000000000<30`01c0?ooo`00K03oool01010@4000000
00000020P80I0?ooo`030410@0000000@4100?l0ooooo`3oooll0?ooo`030820P0000000000000<0
00002P3oool01020P800000000000010@40?0?ooo`050<30`0000000000000000030`<00LP3oool0
06d0oooo0`0000000`20P800oooo0?ooo`0F0?ooo`800000o`3ooooo0?oooc/0oooo00<0P8200000
00000000100000000`20P800oooo0?ooo`090?ooo`040820P0000000000000000100oooo0`00001b
0?ooo`00K@3oool01@30`<000000000000000000`<3001H0oooo00<0@41000000020P800o`3ooooo
0?ooocT0oooo00<0`<300410@00000001P0000000`30`<00oooo0?ooo`0:0?ooo`040410@0000000
00000410@0l0oooo00D0`<3000000000000000000<30`01`0?ooo`00KP3oool01@30`<0000000000
00000000`<3001@0oooo0P0000000`10@400oooo0?ooo`3o0?ooool0oooo=P3oool00`30`<00P820
00000007000000030410@03oool0oooo00`0oooo00@0@410000000000000P8203`3oool01@30`<00
0000000000000000`<3006l0oooo001A0?ooo`030<30`03oool0oooo01`0oooo00@0@41000000000
0000P8204P3oool01010@400000000000030`<3o0?ooool0oooo=P3oool00`30`<00@41000000009
000000030<30`03oool0oooo00d0oooo00@0P820000000000000`<303`3oool01@30`<0000000000
00000000`<3006h0oooo001A0?ooo`80P8207P3oool3000000030820P03oool0oooo00l0oooo0P00
00000`20P800oooo0?ooo`3o0?ooool0oooo=03oool=00000140oooo0`00000A0?ooo`<00000KP3o
ool00500oooo00@0`<30000000000000P8207@3oool01@30`<000000000000000000`<3000l0oooo
00<0@410000000000000o`3ooooo0?ooocD0oooo00<0`<300000000000002`00000B0?ooo`050<30
`0000000000000000030`<003`3oool01@30`<000000000000000000`<3006`0oooo001A0?ooo`04
0410@000000000000410@1d0oooo00D0`<3000000000000000000<30`00=0?ooo`030<30`0000000
@4100?l0ooooo`3ooold0?ooo`030820P010@400000000`0000000<0P8200?ooo`3oool04@3oool0
1@30`<000000000000000000`<3000l0oooo00D0`<3000000000000000000<30`01[0?ooo`00DP3o
ool01010@400000000000010@40N0?ooo`040410@000000000000820P0`0oooo0P0000000`30`<00
oooo0?ooo`3o0?ooool0oooo<03oool00`20P80000000000000>000001D0oooo00D0`<3000000000
000000000<30`00?0?ooo`050<30`0000000000000000030`<00JP3oool005<0oooo0`0000000`20
P800oooo0?ooo`0L0?ooo`<0000000<0P8200?ooo`3oool0203oool300000?l0ooooo`3ooolb0?oo
oa40000000<0P8200?ooo`3oool05@3oool2000000030820P03oool0oooo00l0oooo0`00001Z0?oo
o`00E03oool01010@400000000000020P80M0?ooo`050<30`0000000000000000030`<00203oool0
1020P800000000000030`<3o0?ooool0oooo<03oool00`20P80000000000000@000000030<30`03o
ool0oooo01D0oooo00@0`<30000000000000P820403oool01@30`<000000000000000000`<3006P0
oooo001E0?ooo`040410@000000000000410@1d0oooo00D0`<3000000000000000000<30`0060?oo
o`040<30`000000000000410@?l0ooooo`3oool_0?ooo`030820P000000000000140000000<0@410
0?ooo`3oool05`3oool01010@400000000000010@40@0?ooo`050<30`0000000000000000030`<00
I`3oool005H0oooo00@0@410000000000000@4107P3oool01010@400000000000020P8050?ooo`03
0410@000000000000?l0ooooo`3oool^0?ooo`030410@0000000000001<0000000<0`<300?ooo`3o
ool0603oool01010@400000000000010@40@0?ooo`050<30`0000000000000000030`<00IP3oool0
05L0oooo00@0P820000000000000@4107P3oool01010@400000000000010@4030?ooo`030820P000
000000000?l0ooooo`3oool]0?ooo`030820P0000000000001@0000000<0P8200?ooo`3oool06P3o
ool01020P800000000000030`<0A0?ooo`040410@000000000000820P6D0oooo001H0?ooo`040820
P00000000000000001h0oooo0`0000000`20P800oooo0?ooo`02000000030820P03oool0oooo0?l0
ooooo`3ooolY0?ooo`030820P0000000000001H000007P3oool00`20P80000000000000B0?ooo`<0
000000<0P8200?ooo`3oool0HP3oool005T0oooo00@0@410000000000000@4107@3oool01P30`<00
0000000000000000`<300820P0800000o`3ooooo0?ooob/0oooo00<0@4100000000000005P000000
0`20P800oooo0?ooo`0L0?ooo`050<30`0000000000000000030`<00403oool01@30`<0000000000
00000000`<3006<0oooo001J0?ooo`040410@000000000000410@1h0oooo00<0@410000000000000
0P0000000`30`<00oooo0?ooo`3o0?ooool0oooo:03oool30820P0X0oooo0P20P80;00000200oooo
00@0`<3000000000000000004@3oool01@30`<000000000000000000`<300680oooo001K0?ooo`04
0820P000000000000410@1h0oooo00@0@410000000000000@410o`3ooooo0?ooocT0oooo00<0@410
000000000000200000000`20P800oooo0?ooo`0O0?ooo`040820P000000000000410@180oooo00@0
@410000000000000P820H@3oool005`0oooo00@0P82000000000000000007@3oool00`20P8000000
0000003o0?ooool0oooo>@3oool00`20P800000000000009000002<0oooo0`0000000`20P800oooo
0?ooo`0@0?ooo`<0000000<0P8200?ooo`3oool0GP3oool005d0oooo00@0@410000000000000@410
6`3oool01030`<00000000000020P83o0?ooool0oooo>03oool01P30`<000000000000000000`<30
0410@0H0000000<0@4100?ooo`3oool08P3oool00`10@40000000000000B0?ooo`050<30`0000000
000000000030`<00G`3oool005h0oooo00@0@410000000000000@4106P3oool00`10@40000000410
@03o0?ooool0oooo>03oool01020P800000000000010@4020?ooo`030820P0000000000000@00000
00<0`<300?ooo`3oool08P3oool01@30`<000000000000000000`<300140oooo00D0`<3000000000
000000000<30`01N0?ooo`00G`3oool01020P800000000000010@40H0?ooo`<00000o`3ooooo0?oo
ocP0oooo00@0@410000000000000@410103oool5000000030820P03oool0oooo02@0oooo00@0P820
00000000000000004`3oool01010@400000000000020P81M0?ooo`00H03oool01020P80000000000
0000000F0?ooo`040820P000000000000820P?l0ooooo`3ooolg0?ooo`040820P000000000000000
00D0oooo1@00000X0?ooo`<0000000<0P8200?ooo`3oool04@3oool3000000030820P03oool0oooo
05X0oooo001Q0?ooo`040410@000000000000410@1D0oooo0`00003o0?ooool0oooo=`3oool01@30
`<000000000000000000`<3000D0oooo100000000`20P800oooo0?ooo`0V0?ooo`040<30`0000000
0000000001<0oooo00D0`<3000000000000000000<30`01K0?ooo`00HP3oool01010@40000000000
0010@40C0?ooo`040410@000000000000820P?l0ooooo`3ooolf0?ooo`040820P000000000000410
@0L0oooo1000000Z0?ooo`040820P000000000000820P1<0oooo00D0`<3000000000000000000<30
`01J0?ooo`00A@3oool00`30`<00oooo0?ooo`0K0?ooo`040820P000000000000410@140oooo00@0
`<30000000000000P820o`3ooooo0?ooocH0oooo00@0@410000000000000@410203oool300000003
0820P03oool0oooo02T0oooo00@0P820000000000000P820503oool01010@400000000000020P81I
0?ooo`00A03oool00`20P80000000?ooo`0M0?ooo`040820P0000000000000000100oooo0`00003o
0?ooool0oooo=P3oool01020P80000000000000000090?ooo`<00000;@3oool3000001D0oooo0`00
00000`20P800oooo0?ooo`1F0?ooo`00A03oool3000000030<30`03oool0oooo01/0oooo00@0@410
000000000000@4103P3oool01020P800000000000030`<3o0?ooool0oooo=P3oool01010@4000000
00000030`<090?ooo`80000000<0@4100?ooo`3oool0:`3oool01020P800000000000010@40D0?oo
o`050<30`0000000000000000030`<00E`3oool004@0oooo00D0`<3000000000000000000<30`00M
0?ooo`040410@000000000000410@0`0oooo00@0`<30000000000000@410o`3ooooo0?ooocH0oooo
00<0@4100000000000002P3oool01030`<00000000000030`<0^0?ooo`040410@000000000000<30
`1@0oooo00D0`<3000000000000000000<30`01F0?ooo`00A@3oool01@30`<000000000000000000
`<3001d0oooo00@0P820000000000000@4102`3oool3000000030<30`03oool0oooo0?l0ooooo`3o
oolb0?ooo`050<30`0000000000000000030`<002P3oool00`20P80000000820P00_0?ooo`040<30
`000000000000410@1H0oooo00@0@410000000000000P820E@3oool004L0oooo0`00000N0?ooo`04
0820P00000000000000000T0oooo00@0P820000000000000P820o`3ooooo0?ooocD0oooo0`000000
0`20P800oooo0?ooo`090?ooo`030820P0000000oooo0300oooo0`0000000`20P800oooo0?ooo`0D
0?ooo`<0000000<0P8200?ooo`3oool0DP3oool004L0oooo00D0`<3000000000000000000<30`00M
0?ooo`040410@000000000000410@0P0oooo0`0000000`30`<00oooo0?ooo`3o0?ooool0oooo<P3o
ool01010@400000000000010@40<0?ooo`80P820<P3oool00`10@40000000410@00F0?ooo`050<30
`0000000000000000030`<00D`3oool004P0oooo00D0`<3000000000000000000<30`00M0?ooo`04
0410@000000000000410@0H0oooo00@0P820000000000000P820o`3ooooo0?oooc@0oooo00@0@410
000000000000P8203@3oool00`20P800oooo0?ooo`0a0?ooo`040<30`00000000000000001H0oooo
00D0`<3000000000000000000<30`01B0?ooo`00B@3oool01@30`<000000000000000000`<3001d0
oooo00@0P820000000000000@410103oool01020P800000000000020P83o0?ooool0oooo<`3oool0
1@30`<000000000000000000`<3000h0oooo00<0P8200?ooo`3oool0<P3oool01020P80000000000
0020P80G0?ooo`040410@000000000000820P540oooo001;0?ooo`<000007P3oool01020P8000000
0000000000030?ooo`<00000o`3ooooo0?oooc@0oooo0`0000000`20P800oooo0?ooo`130?ooo`<0
0000603oool3000000030820P03oool0oooo04h0oooo001;0?ooo`040<30`000000000000410@1h0
oooo00H0@410000000000000@4100?ooo`20P802000000030410@03oool0oooo0?l0ooooo`3ooola
0?ooo`040410@000000000000410@4H0oooo00@0@410000000000000`<305`3oool01@30`<000000
000000000000`<3004l0oooo001<0?ooo`050<30`0000000000000000030`<007@3oool01010@400
000000000010@40300000?l0ooooo`3ooolc0?ooo`040410@000000000000820P4L0oooo00@0`<30
0000000000000000603oool01@30`<000000000000000000`<3004h0oooo001=0?ooo`050<30`000
0000000000000030`<007@3oool00`20P800000000000002000000030820P03oool0oooo0?l0oooo
o`3oool_0?ooo`050<30`0000000000000000030`<00BP3oool2000000030820P03oool0oooo01L0
oooo00@0@410000000000000`<30C@3oool004h0oooo00@0P82000000000000000007P3oool01020
P800000000000000003o0?ooool0oooo<P3oool01020P800000000000020P81;0?ooo`030820P000
0000000001X0oooo0`00001=0?ooo`00C`3oool01020P800000000000010@40M0?ooo`030410@000
000000000?l0ooooo`3ooolb0?ooo`040<30`000000000000410@4`0oooo00@0`<30000000000000
P8206@3oool01@30`<000000000000000000`<3004/0oooo001@0?ooo`050<30`000000000000000
0030`<006P3oool01020P800000000000020P83o0?ooool0oooo<@3oool01@30`<00000000000000
0000`<3004d0oooo00@0@410000000000000`<306@3oool01@30`<000000000000000000`<3004X0
oooo001A0?ooo`050<30`0000000000000000030`<00603oool01020P800000000000010@43o0?oo
ool0oooo<@3oool01020P800000000000010@41?0?ooo`040<30`000000000000410@1X0oooo00D0
`<3000000000000000000<30`0190?ooo`00DP3oool01020P800000000000000000H0?ooo`<00000
00<0P8200?ooo`3oool0o`3ooooo0?ooobh0oooo00@0P8200000000000000000D@3oool3000001`0
oooo0`0000190?ooo`00D`3oool01020P800000000000010@40F0?ooo`040<30`000000000000000
0?l0ooooo`3oool`0?ooo`050<30`0000000000000000030`<00D@3oool01020P800000000000030
`<0K0?ooo`050<30`0000000000000000030`<00A`3oool005@0oooo00D0`<300000000000000000
0<30`00D0?ooo`<0000000<0`<300?ooo`3oool0o`3ooooo0?ooobd0oooo00D0`<30000000000000
00000<30`01C0?ooo`80000000<0@4100?ooo`3oool06P3oool01@30`<000000000000000000`<30
04H0oooo000f0?ooo`030820P010@400oooo01`0oooo00D0`<3000000000000000000<30`00B0?oo
o`040410@000000000000820P?l0ooooo`3oool_0?ooo`040820P000000000000410@5H0oooo0P00
000M0?ooo`040<30`000000000000820P4H0oooo000e0?ooo`040820P000000000000820P1d0oooo
00@0P82000000000000000004P3oool300000?l0ooooo`3oool_0?ooo`040820P000000000000000
05L0oooo00<0P82000000020P8007P3oool2000004H0oooo000e0?ooo`050<30`000000000000000
0030`<007@3oool01020P800000000000010@40@0?ooo`<0000000<0`<300?ooo`3oool0o`3ooooo
0?ooob`0oooo00D0`<3000000000000000000<30`01G0?ooo`040<30`000000000000820P1d0oooo
00<0`<300000003oool0A@3oool003L0oooo00@0@410000000000000P8207@3oool01@30`<000000
000000000000`<3000d0oooo00@0@410000000000000@410o`3ooooo0?ooobh0oooo00D0`<300000
0000000000000<30`01I0?ooo`040410@000000000000410@1d0oooo0P30`<150?ooo`00>03oool0
1010@400000000000010@40M0?ooo`050<30`0000000000000000030`<002`3oool01@30`<000000
000000000000`<300?l0ooooo`3oool^0?ooo`80000000<0@4100?ooo`3oool0F@3oool400000003
0410@03oool0oooo0640oooo000i0?ooo`<0000000<0P8200?ooo`3oool06`3oool01020P8000000
00000000000;0?ooo`040820P000000000000820P?l0ooooo`3oool^0?ooo`030820P00000000000
05`0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`1P0?ooo`00>@3oool01@30`<00
0000000000000000`<3001d0oooo00@0P820000000000000@4102@3oool01@30`<00000000000000
0000`<300?l0ooooo`3oool]0?ooo`040820P000000000000820P5`0oooo00<0`<30000000000000
0`0000000`20P800oooo0?ooo`1O0?ooo`00>`3oool01010@400000000000020P80M0?ooo`050<30
`0000000000000000030`<001`3oool00`10@40000000410@03o0?ooool0oooo;P3oool01010@400
000000000010@41N0?ooo`040410@000000000000410@080000000<0@4100?ooo`3oool0GP3oool0
03`0oooo00@0@410000000000000@4107@3oool01@30`<000000000000000000`<3000D0oooo00@0
P820000000000000`<30o`3ooooo0?ooobd0oooo00@0@410000000000000@410G`3oool01@20P800
000000000020P800@4100080000000<0@4100?ooo`3oool0G@3oool003d0oooo00@0@41000000000
0000@4107@3oool01@30`<000000000000000000`<3000<0oooo00@0P820000000000000`<30o`3o
oooo0?ooobd0oooo00@0@410000000000000P820H@3oool2000000030410@03oool0P82000800000
00<0@4100?ooo`3oool0G03oool003h0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`<000000`3o
ool300000?l0ooooo`3oool]0?ooo`<0000000<0P8200?ooo`3oool0H@3oool200000080oooo00@0
P8200000000000000000G@3oool003l0oooo00@0@410000000000000P8207@3oool01P30`<000000
000000000000`<300410@080000000<0`<300?ooo`3oool0o`3ooooo0?ooob`0oooo0P10@41T0?oo
o`030410@0000000P8200080oooo00@0@410000000000000@410G03oool00400oooo00@0@4100000
00000000@4107@3oool00`30`<00000000000002000000030410@03oool0oooo0?l0ooooo`3ooonD
0?ooo`030820P0000000@41000<0oooo00@0@410000000000000@410F`3oool00440oooo00@0@410
000000000000@4107@3oool01030`<00000000000010@43o0?ooool0ooooV03oool2000000@0oooo
00@0P820000000000000@410FP3oool00480oooo0`0000000`20P800oooo0?ooo`0J0?ooo`040820
P000000000000820P?l0ooooo`3ooonH0?ooo`<00000103oool01020P800000000000000001I0?oo
o`00@`3oool01010@400000000000020P80J0?ooo`040<30`000000000000410@?l0ooooo`3ooonI
0?ooo`030820P0000000000000D0oooo00@0@410000000000000@410F03oool002D0oooo00<0`<30
0?ooo`3oool0703oool01010@400000000000010@40H0?ooo`040820P000000000000820P?l0oooo
o`3ooonJ0?ooo`040820P000000000000<30`0D0oooo00@0@410000000000000@410E`3oool002@0
oooo00@0`<30000000000000`<307@3oool01010@400000000000010@40E0?ooo`050<30`0000000
000000000030`<00o`3ooooo0?oooi`0oooo0P0000000`20P800oooo0?ooo`040?ooo`040820P000
000000000410@5H0oooo000T0?ooo`040820P00000000000000001h0oooo0`0000000`20P800oooo
0?ooo`0B0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooo0?oooi/0oooo0`0000070?ooo`040820
P00000000000000005D0oooo000U0?ooo`040410@000000000000410@1h0oooo00@0@41000000000
0000P8204P3oool01030`<00000000000010@43o0?ooool0ooooWP3oool00`20P800000000000008
0?ooo`040410@000000000000410@5@0oooo000V0?ooo`040820P000000000000410@1h0oooo00@0
@410000000000000@410403oool01030`<00000000000000003o0?ooool0oooo=`3oool20820P6H0
oooo00@0`<30000000000000P820203oool01010@400000000000010@41C0?ooo`009`3oool01@30
`<000000000000000000`<3001d0oooo00@0@410000000000000@4103P3oool01020P80000000000
0010@43o0?ooool0oooo9P3oool4000000030<30`03oool0oooo00T0oooo00<0`<30000000000000
0`0000000`30`<00oooo0?ooo`1R0?ooo`80000000<0P8200?ooo`3oool01`3oool01020P8000000
00000010@41B0?ooo`00:03oool01020P800000000000000000N0?ooo`<0000000<0P8200?ooo`3o
ool02P3oool01020P800000000000000003o0?ooool0oooo9`3oool01@20P8000000000000000000
P82000/0oooo00<0P8200000000000001000001T0?ooo`<000002P3oool01020P800000000000000
001A0?ooo`00:@3oool01010@400000000000010@40N0?ooo`040410@000000000000<30`0X0oooo
00D0`<3000000000000000000<30`03o0?ooool0oooo9`3oool01@20P8000000000000000000@410
00/0oooo00<0P8200000000000000P0000000`20P800@4100410@01T0?ooo`8000002`3oool01010
@400000000000010@41@0?ooo`00:P3oool01020P800000000000010@40N0?ooo`040410@0000000
00000820P0P0oooo00D0`<3000000000000000000<30`03o0?ooool0oooo:@3oool4000000/0oooo
00<0P8200000000000000P0000020?ooo`030<30`010@400oooo0680oooo00<0@41000000020P800
2`3oool01010@400000000000010@41?0?ooo`00:`3oool01@30`<000000000000000000`<3001d0
oooo00@0@410000000000000@4101P3oool01020P800000000000010@43o0?ooool0oooo:`3oool4
000000030820P03oool0oooo00T0oooo100000001@20P800oooo0?ooo`20P800@4100680oooo00<0
P82000000010@400303oool01020P800000000000010@41>0?ooo`00;03oool01020P80000000000
0000000N0?ooo`<0000000<0P8200?ooo`3oool00P3oool01020P800000000000000003o0?ooool0
oooo;@3oool4000000/0oooo1@0000030?ooo`800000HP3oool2000000d0oooo00@0P82000000000
0000P820C@3oool002d0oooo00@0@410000000000000@4107@3oool01@30`<000000000000000000
`<300080oooo00D0`<30000000000000@4100<30`03o0?ooool0oooo;@3oool4000000030<30`03o
ool0oooo00T0oooo100000001030`<00oooo0?ooo`30`<1S0?ooo`8000003P3oool01010@4000000
00000020P81<0?ooo`00;P3oool01020P800000000000010@40N0?ooo`050410@000000000000820
P030`<000P0000000`20P800oooo0?ooo`3o0?ooool0oooo;@3oool01@20P8000000000000000000
@41000/0oooo00D0@41000000000000000000820P01V0?ooo`030410@0000000000000h0oooo00@0
@410000000000000@410B`3oool002l0oooo00D0`<3000000000000000000<30`00M0?ooo`030410
@000000000000080000000<0P8200?ooo`3oool0o`3ooooo0?ooobh0oooo00<0`<30000000000000
0P0000000`30`<00oooo0?ooo`080?ooo`030820P0000000000000800000IP3oool00`20P8000000
0000000?0?ooo`040410@000000000000410@4X0oooo000`0?ooo`040820P00000000000000001h0
oooo1000003o0?ooool0oooo<P3oool4000000030820P03oool0oooo00T0oooo1000001V0?ooo`04
0820P000000000000820P0l0oooo0`0000000`20P800oooo0?ooo`170?ooo`00<@3oool01010@400
000000000010@40L0?ooo`050<30`0000000000000000030`<00o`3ooooo0?oooc80oooo1@000000
0`30`<00oooo0?ooo`080?ooo`@0000000<0`<300?ooo`3oool0I03oool2000000030820P03oool0
oooo00h0oooo00@0@410000000000000P820B03oool00380oooo00@0P820000000000000@4106P3o
ool01@30`<000000000000000000`<300?l0ooooo`3ooolc0?ooo`030820P0000000000000800000
00<0@4100?ooo`3oool0203oool01@20P8000000000000000000P82006H0oooo0P0000000`20P800
oooo0?ooo`0?0?ooo`040410@000000000000410@4L0oooo000c0?ooo`050<30`000000000000000
0030`<005`3oool01020P800000000000010@43o0?ooool0oooo=@3oool00`30`<00000000000003
000000030820P03oool0oooo00L0oooo00<0`<300000000000000P00001V0?ooo`030410@0000000
00000180oooo00@0@410000000000000@410AP3oool003@0oooo00@0P82000000000000000005P3o
ool01020P800000000000000003o0?ooool0oooo=`3oool4000000030820P0000000P82000T0oooo
1000001V0?ooo`030820P0000000000001<0oooo0`0000000`20P800oooo0?ooo`130?ooo`00=@3o
ool01010@400000000000010@40E0?ooo`<0000000<0`<300?ooo`3oool0o`3ooooo0?ooocD0oooo
100000000`20P8000000000000090?ooo`050410@0000000000000000020P800I@3oool00`20P800
00000000000D0?ooo`040410@000000000000820P4@0oooo000H0?ooo`030<30`03oool0oooo01/0
oooo00@0P820000000000000@4104`3oool01010@400000000000030`<3o0?ooool0oooo>03oool0
2020P8000000000000000000P8200?ooo`000000@410203oool01@20P8000000000000000000@410
06D0oooo00@0`<30000000000000P820503oool01010@400000000000010@4130?ooo`005`3oool0
0`20P80000000<30`00M0?ooo`050<30`0000000000000000030`<00403oool00`10@40000000410
@03o0?ooool0oooo>P3oool00`30`<00000000000002000000040?ooo`30`<0000000<30`0P0oooo
1000001V0?ooo`80000000<0P8200?ooo`3oool04`3oool01010@400000000000010@4120?ooo`00
5`3oool00`20P80000000000000N0?ooo`040820P0000000000000000100oooo0P0000000`20P800
oooo0?ooo`3o0?ooool0oooo>@3oool400000080oooo00<0P8200000003oool01`3oool400000003
0820P03oool0oooo06<0oooo0P0000000`20P800oooo0?ooo`0D0?ooo`<0000000<0P8200?ooo`3o
ool0?`3oool001L0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@000000000000410
@0h0oooo00<0@41000000010@400o`3ooooo0?oooc`0oooo100000000`20P800oooo0?ooo`020000
00030<30`03oool0oooo00D0oooo0`0000000`20P800oooo0?ooo`1S0?ooo`80000000<0@4100?oo
o`3oool05@3oool01010@400000000000020P8100?ooo`00603oool01@30`<000000000000000000
`<3001d0oooo00@0P820000000000000@4102`3oool01030`<00000000000010@43o0?ooool0oooo
?P3oool400000080oooo00@0`<30000000000000`<301P3oool4000006H0oooo0P00000H0?ooo`04
0410@000000000000410@3l0oooo000I0?ooo`050<30`0000000000000000030`<007@3oool01@30
`<000000000000000000`<3000T0oooo00<0@41000000010@400o`3ooooo0?ooocl0oooo00D0@410
00000000000000000820P0030?ooo`030410@0000000`<3000D0oooo00@0P8200000000000000000
IP3oool2000001T0oooo00@0@410000000000000@410?P3oool001/0oooo0`00000N0?ooo`040820
P00000000000000000P0oooo00@0P820000000000000P820o`3ooooo0?ooocl0oooo00D0P8200000
0000000000000820P0040?ooo`8000001@3oool00`20P800000000000002000006D0oooo0P000000
0`20P800oooo0?ooo`0G0?ooo`<0000000<0P8200?ooo`3oool0>`3oool001/0oooo00D0`<300000
0000000000000<30`00M0?ooo`040410@000000000000410@0L0oooo00<0@410000000000000o`3o
oooo0?oood00oooo00D0P82000000000000000000410@0040?ooo`050<30`000000000000410@030
`<000P3oool00`10@400000000000002000006D0oooo00<0P82000000020P8006P3oool00`10@400
00000820P00m0?ooo`00703oool01@30`<000000000000000000`<3001d0oooo00@0P82000000000
0000@4101@3oool00`20P80000000000003o0?ooool0oooo?@3oool01030`<00P8200820P020P805
000000D0oooo00<0`<300000000000001`0000000`20P800oooo0?ooo`1S0?ooo`030820P0000000
P82001/0oooo00<0@4100820P03oool0?03oool001d0oooo00D0`<3000000000000000000<30`00M
0?ooo`050<30`0000000000000000030`<000P3oool01020P800000000000030`<3o0?ooool0oooo
?@3oool00`20P800@41000000006000000030820P03oool0oooo00@0oooo00<0@410000000000000
100000000`10@400oooo0?ooo`1T0?ooo`030<30`0000000000001`0oooo00<0P8200?ooo`3oool0
>`3oool001l0oooo00@0@410000000000000P8207@3oool01030`<0000000000000000020<30`080
000000<0@4100?ooo`3oool0o`3ooooo0?oood40oooo0`20P8000`10@400P8200?ooo`060?ooo`03
0<30`020P80000000080000000<0@4100<30`03oool0IP3oool2000005X0oooo000P0?ooo`<00000
00<0P8200?ooo`3oool06`3oool01@20P8000000000000000000P8200080000000<0P8200?ooo`3o
ool0o`3ooooo0?oook/0oooo0P00001J0?ooo`00803oool01@30`<000000000000000000`<3001d0
oooo00<0P8200000000000000`00003o0?oooaP0oooo0P20P83o0?oooj@0oooo0`0000000`30`<00
oooo0?ooo`1F0?ooo`008@3oool01@30`<000000000000000000`<3001d0oooo00D0`<3000000000
000000000820P03o0?oooaP0oooo0P0000000`30`<00oooo0?ooo`3o0?oooj40oooo00D0P8200000
0000000000000<30`01G0?ooo`008`3oool01010@400000000000020P80M0?ooo`040820P0000000
00000<30`?l0oooo6@3oool2000000030<30`03oool0oooo0?l0ooooX03oool00`20P80000000000
0002000000030<30`03oool0oooo05@0oooo000T0?ooo`<0000000<0P8200?ooo`3oool06P3oool3
00000?l0oooo6P3oool2000000030820P03oool0oooo0?l0ooooX03oool01020P800000000000020
P802000005H0oooo000T0?ooo`050<30`0000000000000000030`<006`3oool2000000030820P03o
ool0oooo0?l0oooo603oool3000000030820P03oool0oooo0?l0ooooW`3oool01@20P80000000000
003oool0@4100080000000<0`<300?ooo`3oool0DP3oool002D0oooo00D0`<300000000000000000
0<30`00I0?ooo`030820P0000000@4100?l0oooo6`3oool4000000030820P03oool0oooo0?l0oooo
7`3oool00`30`<00P8200820P00C0?ooo`040<30`020P800P8200<30`6D0oooo00H0`<3000000000
0000P8200?ooo`10@402000000030<30`03oool0oooo0540oooo000W0?ooo`040410@00000000000
0820P1P0oooo0P0000000`20P800oooo0?ooo`3o0?oooaT0oooo1@0000000`30`<00oooo0?ooo`3o
0?oooal0oooo0`00000B0?ooo`<00000I`3oool2000000040820P03oool0oooo0820P080000000<0
`<300?ooo`3oool0D03oool002P0oooo0`0000000`20P800oooo0?ooo`0E0?ooo`800000o`3ooolL
0?ooo`D0000000<0P8200?ooo`3oool0o`3ooolO0?ooo`040820P000000000000820P100oooo00<0
P820000000000000J03oool2000000050820P03oool0oooo0?ooo`20P8000P00001B0?ooo`00:03o
ool01@30`<000000000000000000`<3001H0oooo0P00003o0?oooa`0oooo00<0P820000000000000
0`0000000`30`<00oooo0?ooo`3o0?oooal0oooo0`00000@0?ooo`80000000<0P8200?ooo`3oool0
IP3oool2000000030820P03oool0oooo0080oooo00@0@410000000000000`<30D03oool002T0oooo
00D0`<3000000000000000000<30`00D0?ooo`80000000<0@4100?ooo`3oool0o`3ooolJ0?ooo`03
0820P0000000000000@00000o`3ooolQ0?ooo`040820P000000000000820P0h0oooo00<0P8200000
00000000J@3oool2000000030410@03oool0oooo00<0oooo00@0@410000000000000`<30C`3oool0
02/0oooo00@0@410000000000000P8204`3oool2000000030820P03oool0oooo0?l0oooo6P3oool0
0`20P800000000000005000000030<30`03oool0oooo0?l0oooo7P3oool01020P800000000000030
`<0<0?ooo`040820P000000000000<30`6T0oooo00<0P8200000000000001P3oool01020P8000000
00000030`<1>0?ooo`00;03oool3000000030820P03oool0oooo0100oooo0P0000000`20P800oooo
0?ooo`3o0?oooaX0oooo00<0P8200000000000000P0000001020P800000000000000003o0?ooob40
oooo0P0000000`20P800oooo0?ooo`0:0?ooo`<00000JP3oool00`20P8000000000000070?ooo`03
0820P0000000000004h0oooo000/0?ooo`050<30`0000000000000000030`<00403oool01020P800
000000000030`<3o0?oooa`0oooo00<0P8200000000000000P0000001@20P800`<30000000000000
`<300?l0oooo803oool00`20P80000000000000;0?ooo`040820P000000000000820P6X0oooo00<0
P820000000000000203oool00`10@40000000410@01=0?ooo`00;@3oool01@30`<00000000000000
0000`<3000l0oooo00<0P820000000000000o`3ooolN0?ooo`D0000000D0oooo0820P00000000000
0<30`03o0?ooob00oooo0`0000090?ooo`040<30`00000000000000006/0oooo00<0P82000000000
00002@3oool01010@400000000000030`<1;0?ooo`00;`3oool01010@400000000000020P80>0?oo
o`030820P000000000000?l0oooo7P3oool500000080oooo00<0`<3000000010@400o`3ooolP0?oo
o`040<30`000000000000410@0P0oooo00@0@410000000000000`<30J`3oool01030`<0000000000
0020P8090?ooo`040410@000000000000<30`4X0oooo000`0?ooo`<0000000<0P8200?ooo`3oool0
2`3oool00`20P80000000000003o0?oooah0oooo1@0000030?ooo`<00000o`3ooolP0?ooo`<00000
203oool3000006d0oooo0P0000000`20P800oooo0?ooo`080?ooo`<00000BP3oool00300oooo00D0
`<3000000000000000000<30`00<0?ooo`030410@0000000@4100?l0oooo7P3oool5000000<0oooo
00@0`<30000000000000P820o`3ooolO0?ooo`040820P000000000000820P0H0oooo00<0@4100000
00000000KP3oool2000000030820P03oool0oooo00T0oooo00<0@41000000010@400B@3oool00340
oooo00D0`<3000000000000000000<30`00;0?ooo`80000000<0P8200?ooo`3oool0o`3ooolL0?oo
o`D00000103oool01020P800000000000030`<3o0?oooal0oooo00<0P8200000000000001@3oool0
1020P800000000000030`<1^0?ooo`80000000<0P8200?ooo`3oool02P3oool01010@40000000000
0030`<170?ooo`00<`3oool01010@400000000000020P80:0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolL0?ooo`030410@000000000000080000000<0P8200?ooo`3oool00P3oool00`20P8000000
0000003o0?ooob00oooo00<0@41000000010@4000`3oool01030`<00000000000010@41_0?ooo`80
000000<0P8200?ooo`3oool02`3oool01010@400000000000030`<160?ooo`005@3oool00`20P800
oooo0?ooo`0L0?ooo`<0000000<0P8200?ooo`3oool01`3oool2000000030820P03oool0oooo0?l0
oooo703oool00`20P800000000000002000000030820P03oool0oooo00<0oooo00<0P82000000020
P800o`3ooolO0?ooo`030820P0000000000000<0oooo00@0P820000000000000P820K`3oool20000
00030820P03oool0oooo00`0oooo0`0000160?ooo`005@3oool00`000000P8200?ooo`0L0?ooo`05
0<30`0000000000000000030`<00203oool2000000030820P03oool0oooo0?l0oooo703oool00`20
P800000000000002000000030820P03oool0oooo00<0oooo00@0`<30000000000000P820o`3ooolO
0?ooo`<0000000<0oooo0<30`00000000P00001`0?ooo`80000000<0P8200?ooo`3oool03@3oool0
0`10@40000000410@0150?ooo`005@3oool2000000030410@03oool0oooo01/0oooo00D0`<300000
0000000000000<30`0070?ooo`80000000<0P8200?ooo`3oool0o`3ooolL0?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool0103oool01030`<00000000000030`<3o0?oooah0oooo00<0
`<300000000000000P10@402000000030<30`03oool0oooo06h0oooo0P0000000`10@400oooo0?oo
o`0>0?ooo`040410@000000000000<30`4<0oooo000E0?ooo`040410@000000000000410@1h0oooo
00@0@410000000000000P8201P3oool00`20P80000000000003o0?oooah0oooo00<0P82000000000
00000P0000000`20P800oooo0?ooo`050?ooo`040410@000000000000<30`?l0oooo7P3oool00`10
@400000000000002000000030820P03oool0oooo0700oooo0P00000A0?ooo`040410@00000000000
0<30`480oooo000F0?ooo`<0000000<0P8200?ooo`3oool0703oool3000000030820P03oool0oooo
00<0oooo00<0P820000000000000o`3ooolN0?ooo`030820P000000000000080000000<0P8200?oo
o`3oool01P3oool2000000030820P03oool0oooo0?l0oooo703oool00`20P8000000000000020000
07<0oooo0P00000B0?ooo`<00000@P3oool001L0oooo00@0@410000000000000P8207@3oool01@30
`<000000000000000000`<3000@0oooo00<0P820000000000000o`3ooolO0?ooo`D000002@3oool2
000000030<30`03oool0oooo0?l0oooo703oool01020P800000000000030`<1c0?ooo`8000004`3o
ool00`10@40000000410@0110?ooo`00603oool01010@400000000000010@40M0?ooo`050<30`000
0000000000000030`<000`3oool00`20P80000000000003o0?oooal0oooo1@0000090?ooo`030<30
`000000000000?l0oooo7`3oool20410@7@0oooo0P00000D0?ooo`040410@000000000000<30`3l0
oooo000I0?ooo`040410@000000000000410@1h0oooo00@0@410000000000000P8200P3oool00`20
P80000000000003o0?oooal0oooo1@00000:0?ooo`040820P000000000000<30`?l0ooooT`3oool2
000001D0oooo00@0@410000000000000`<30?P3oool001X0oooo0`0000000`20P800oooo0?ooo`0L
0?ooo`<0000000<0P8200?ooo`20P8000P0000000`20P800oooo0?ooo`3o0?oooa`0oooo1@00000;
0?ooo`<00000o`3ooonC0?ooo`8000005P3oool3000003h0oooo000K0?ooo`040410@00000000000
0820P1d0oooo00H0`<3000000000000000000<30`03oool2000000030820P03oool0oooo0?l0oooo
703oool5000000/0oooo00@0`<30000000000000`<30o`3ooonB0?ooo`8000005`3oool00`10@400
00000410@00m0?ooo`00703oool01010@400000000000010@40M0?ooo`050<30`000000000000000
0030`<000P0000000`20P800oooo0?ooo`3o0?oooa`0oooo00<0@4100000000000000`00000;0?oo
o`040820P000000000000<30`?l0ooooT@3oool2000001P0oooo00@0@410000000000000`<30>`3o
ool001d0oooo00@0@410000000000000@4107P3oool00`10@400000000000002000000030410@03o
ool0oooo0?l0oooo703oool00`20P800000000000003000000`0oooo00<0`<3000000010@400o`3o
oonA0?ooo`80000000<0`<300?ooo`3oool05P3oool01010@400000000000030`<0j0?ooo`007P3o
ool3000000030820P03oool0oooo01`0oooo1@00003o0?oooah0oooo00<0P8200000000000000`00
000=0?ooo`80000000<0P8200?ooo`3oool0o`3ooon>0?ooo`030820P0000000P82001T0oooo0`00
000j0?ooo`007`3oool01010@400000000000020P80M0?ooo`030<30`0000000000000800000o`3o
oolN0?ooo`030820P0000000000000<000003@3oool00`30`<0000000000003o0?oooi00oooo00<0
P82000000020P8006P3oool00`10@40000000?ooo`0i0?ooo`00803oool01010@400000000000010
@40M0?ooo`040<30`0000000000000000?l0oooo7P3oool00`20P800000000000003000000h0oooo
00@0@410000000000000`<30o`3ooon>0?ooo`030820P0000000P82001/0oooo00<0@4100?ooo`3o
ool0>03oool00240oooo00@0@410000000000000@4107P3oool00`10@40000000820P03o0?oooad0
oooo00<0P8200000000000000`0000000`30`<00oooo0?ooo`0<0?ooo`<0000000<0`<300?ooo`3o
ool0o`3ooon;0?ooo`030820P0000000P82005H0oooo000R0?ooo`040820P000000000000410@1d0
oooo00<0P82000000020P800o`3ooolN0?ooo`D0000000<0P8200?ooo`3oool0303oool01@20P800
0000000000000000`<300?l0ooooS03oool00`20P80000000820P01F0?ooo`008`3oool01020P800
000000000000000L0?ooo`030820P000000000000?l0oooo7@3oool00`20P8000000000000030000
00030820P03oool0oooo00d0oooo1000003o0?oooh`0oooo00<0P82000000020P800EP3oool002@0
oooo00@0@410000000000000@410703oool200000?l0oooo7@3oool00`20P8000000000000040000
00h0oooo00<0`<300000000000000`0000000`30`<00oooo0?ooo`3o0?ooohP0oooo00@0P8200000
00000000P820E@3oool002D0oooo00@0@410000000000000@4106`3oool200000?l0oooo703oool0
0`20P800000000000005000000030410@030`<00oooo00X0oooo00<0`<300410@00000001@000000
0`10@400`<300?ooo`3o0?ooohL0oooo00D0P82000000000000000000410@01D0?ooo`009P3oool0
1020P800000000000010@40J0?ooo`030820P000000000000?l0oooo603oool?000000030820P03o
ool0oooo00D0oooo00<0@4100000000000002@0000000`20P800oooo0?ooo`3o0?oooh@0oooo00<0
P8200000000000000P0000000`10@400oooo0?ooo`1A0?ooo`009`3oool01020P800000000000000
000I0?ooo`030820P000000000000?l0ooooo`3oooo30?ooo`D0000000<0P8200?ooo`3oool0D03o
ool002P0oooo00@0@410000000000000@410603oool01020P800000000000030`<3o0?ooool0oooo
`P3oool2000000050?ooo`10@400000000000020P800D@3oool002T0oooo00@0@410000000000000
@410603oool2000000030820P03oool0oooo0?l0ooooo`3oooo00?ooo`8000000P3oool01010@400
000000000010@41@0?ooo`00:P3oool01020P800000000000010@40G0?ooo`80000000<0P8200?oo
o`3oool0o`3ooooo0?oool00oooo0P0000030?ooo`040410@000000000000410@4l0oooo000[0?oo
o`040820P00000000000000001H0oooo00<0P820000000000000o`3ooooo0?oool80oooo0P000004
0?ooo`<0000000<0P8200?ooo`3oool0C03oool002`0oooo00@0@410000000000000@4105@3oool0
0`20P80000000000003o0?ooool0oooo`P3oool2000000D0oooo00@0@410000000000000`<30C@3o
ool002d0oooo00@0@410000000000000@410503oool01030`<00000000000030`<3o0?ooool0oooo
`@3oool2000000H0oooo00@0@410000000000000P820C03oool002h0oooo00@0P820000000000000
@410503oool2000000030820P03oool0oooo0?l0ooooo`3ooono0?ooo`8000001`3oool01010@400
000000000010@41;0?ooo`00;`3oool01020P800000000000000000C0?ooo`<00000o`3ooooo0?oo
ol40oooo0P0000080?ooo`<0000000<0P8200?ooo`3oool0B03oool00300oooo00@0@41000000000
0000@4104P3oool00`20P80000000000003o0?ooool0oooo`@3oool2000000P0oooo00D0`<300000
0000000000000<30`0190?ooo`00<@3oool01010@400000000000010@40B0?ooo`80000000<0`<30
0?ooo`3oool0o`3ooooo0?oookh0oooo00<0@4100000000000002@3oool01010@400000000000020
P8180?ooo`00<P3oool01020P800000000000010@40A0?ooo`030410@0000000P8200?l0ooooo`3o
ooo00?ooo`030820P0000000000000X0oooo00@0@410000000000000@410A`3oool003<0oooo00@0
P8200000000000000000403oool00`20P80000000000003o0?ooool0oooo`03oool00`20P8000000
0000000;0?ooo`<0000000<0P8200?ooo`3oool0A03oool003@0oooo00@0@410000000000000@410
3`3oool00`30`<0000000000003o0?ooool0oooo`03oool00`20P80000000000000;0?ooo`050<30
`0000000000000000030`<00A@3oool003D0oooo00@0@410000000000000@4103`3oool200000003
0820P03oool0oooo0?l0ooooo`3ooonm0?ooo`030820P0000000000000d0oooo00@0@41000000000
0000P820A03oool003H0oooo00@0P820000000000000@4103P3oool00`20P80000000000003o0?oo
ool0oooo_`3oool00`20P80000000000000>0?ooo`040410@000000000000410@4<0oooo000g0?oo
o`040820P00000000000000000d0oooo00@0P820000000000000P820o`3ooooo0?oookh0oooo00<0
P8200000000000003`3oool3000000030820P03oool0oooo0400oooo000h0?ooo`040410@0000000
00000410@0`0oooo00@0`<30000000000000P820o`3ooooo0?oookh0oooo00<0P820000000000000
3`3oool01@30`<000000000000000000`<300440oooo000i0?ooo`040410@000000000000410@0`0
oooo0P0000000`10@400oooo0?ooo`3o0?ooool0ooooV`3oool00`20P800oooo0?ooo`070?ooo`03
0<30`020P800P82000<0P82000<0`<300?ooo`3oool03P3oool01030`<00000000000020P80@0?oo
o`040410@000000000000820P400oooo000j0?ooo`040820P000000000000410@0/0oooo00<0P820
000000000000o`3ooooo0?oooid0oooo0P10@4040?ooo`030<30`020P800@41000T0000000<0@410
0820P03oool03@3oool2000000030820P03oool0oooo00l0oooo00@0@410000000000000@410?`3o
ool003/0oooo00@0P82000000000000000002P3oool01020P800000000000020P83o0?ooool0oooo
W03oool00`20P80000000820P0020?ooo`D0000000<0P8200?ooo`3oool00`3oool5000000d0oooo
0P0000000`20P800oooo0?ooo`0@0?ooo`<0000000<0P8200?ooo`3oool0?03oool003`0oooo00@0
@410000000000000@4102P3oool2000000030820P03oool0oooo0?l0ooooo`3ooonJ0?ooo`030820
P0000000000000D0000000<0@4100?ooo`3oool01P3oool01P20P8000000000000000000@4100<30
`0/0oooo0P0000000`20P800oooo0?ooo`0@0?ooo`050<30`0000000000000000030`<00?@3oool0
03d0oooo00@0@410000000000000@4102@3oool2000000030410@03oool0oooo0?l0ooooo`3ooonJ
0?ooo`030<30`0000000000000<0000000<0@4100?ooo`3oool02@3oool00`30`<00000000000002
000000/0oooo0P0000000`20P800oooo0?ooo`0B0?ooo`040410@000000000000820P3`0oooo000n
0?ooo`040820P000000000000410@0T0oooo0P00003o0?ooool0ooooW@3oool5000000h0oooo1000
00000`30`<00oooo0?ooo`070?ooo`80000000<0P8200?ooo`3oool04`3oool01010@40000000000
0010@40k0?ooo`00?`3oool01020P80000000000000000080?ooo`80000000<0P8200?ooo`3oool0
o`3ooooo0?oooiX0oooo100000000`20P800oooo0?ooo`0<0?ooo`050820P0000000000000000020
P8002@3oool2000000030820P03oool0oooo01@0oooo0`0000000`20P800oooo0?ooo`0h0?ooo`00
@03oool01010@400000000000010@4070?ooo`030410@0000000@4100?l0ooooo`3ooonL0?ooo`04
0820P00000000000000000l0oooo00<0P8200000000000000P0000090?ooo`030410@00000000000
01H0oooo00D0`<3000000000000000000<30`00i0?ooo`008P3oool00`000000`<300?ooo`0L0?oo
o`040410@000000000000410@0H0oooo00<0`<30000000000000o`3ooooo0?oooi`0oooo00@0P820
000000000000@410403oool4000000030820P03oool0oooo00H0oooo00<0P820000000000000603o
ool01010@400000000000020P80h0?ooo`008`3oool00`000000`<300?ooo`0L0?ooo`040820P000
000000000410@0H0oooo0P0000000`20P800oooo0?ooo`3o0?ooool0ooooVP3oool2000000030820
P03oool0oooo00h0oooo100000000`10@400oooo0?ooo`060?ooo`030820P0000000000001T0oooo
00<0@410000000000000>03oool002<0oooo0P00000N0?ooo`040820P00000000000000000D0oooo
00<0P820000000000000o`3ooooo0?oooi`0oooo0P0000000`20P800oooo0?ooo`0>0?ooo`D00000
203oool00`20P80000000000000J0?ooo`800000>03oool002<0oooo00<0P82000000010@4007P3o
ool01010@400000000000010@4040?ooo`030<30`000000000000?l0ooooo`3ooonL0?ooo`800000
00<0P8200?ooo`3oool03P3oool5000000P0oooo00<0P8200000000000006P3oool00`30`<000000
0?ooo`0g0?ooo`008`3oool01@30`<000000000000000000`<3001d0oooo00@0@410000000000000
@410103oool300000?l0ooooo`3ooonK0?ooo`030820P0000000P82000l0oooo00<0P82000000000
00000`0000080?ooo`030820P0000000000005@0oooo000T0?ooo`050<30`0000000000000000030
`<007@3oool01020P800000000000010@4030?ooo`040820P000000000000820P?l0ooooo`3ooonJ
0?ooo`030820P0000000P82000l0oooo00<0@4100000000000000`0000080?ooo`040820P0000000
00000<30`5<0oooo000U0?ooo`050<30`0000000000000000030`<007@3oool01@30`<0000000000
00000000`<300080oooo0`00003o0?ooool0ooooV`3oool00`000000P8200?ooo`0=0?ooo`H00000
00<0P8200?ooo`3oool01`3oool2000000030410@03oool0oooo0540oooo000W0?ooo`<000007P3o
ool01020P80000000000000000020?ooo`030820P000000000000?l0ooooo`3ooonZ0?ooo`030820
P0000000000000@0000000<0P8200?ooo`3oool01`3oool3000000030820P03oool0oooo0500oooo
000W0?ooo`050<30`0000000000000000030`<007@3oool01P10@400000000000010@400oooo0820
P080000000<0P8200?ooo`3oool0o`3ooooo0?ooojH0oooo00<0`<300000000000001@00000:0?oo
o`@0000000<0P8200?ooo`3oool0C`3oool002P0oooo00D0`<3000000000000000000<30`00M0?oo
o`050820P000000000000410@03oool00`00003o0?ooool0ooooY`3oool00`30`<00000000000005
000000030<30`03oool0oooo00P0oooo1@0000000`10@400oooo0?ooo`1>0?ooo`00:@3oool01@30
`<000000000000000000`<3001d0oooo00D0`<30000000000000@4100?ooo`02000000030<30`03o
ool0oooo0?l0ooooo`3ooonT0?ooo`L0000000<0P8200?ooo`3oool02@3oool2000000050820P010
@400000000000010@400C`3oool002/0oooo0`00000N0?ooo`030820P0000000000000<0000000<0
P8200?ooo`3oool0o`3ooooo0?oooj<0oooo1`0000000`20P800oooo0?ooo`0:0?ooo`80000000<0
P8200?ooo`0000000P0000000`20P800oooo0?ooo`1<0?ooo`00:`3oool01@30`<00000000000000
0000`<3001d0oooo00<0@4100000000000000`00003o0?ooool0ooooY03oool00`10@40000000000
0004000000030410@03oool0oooo00/0oooo0P0000001020P800oooo0?ooo`10@402000000030<30
`03oool0oooo04/0oooo000/0?ooo`050<30`0000000000000000030`<007@3oool00`10@4000000
00000002000000030820P03oool0oooo0?l0ooooo`3ooonP0?ooo`030410@0000000000000@00000
00<0@4100?ooo`3oool03@3oool2000000<0oooo00@0@410000000000000P820C03oool002d0oooo
00D0`<3000000000000000000<30`00M0?ooo`030820P000000000000080000000<0`<300?ooo`3o
ool0o`3ooooo0?oooih0oooo00<0@410000000000000100000000`20P800oooo0?ooo`0>0?ooo`80
0000103oool01010@400000000000010@41;0?ooo`00;`3oool3000001h0oooo00D0P82000000000
000000000820P03o0?ooool0ooooW`3oool7000000030820P03oool0oooo00l0oooo0P0000050?oo
o`<0000000<0P8200?ooo`3oool0B03oool002l0oooo00D0`<3000000000000000000<30`00M0?oo
o`040410@0000000000000000?l0ooooo`3ooonN0?ooo`030410@0000000000000D000004P3oool2
000000D0oooo00D0`<3000000000000000000<30`0190?ooo`00<03oool01@30`<00000000000000
0000`<3001d0oooo00@0@410000000000000`<30o`3ooooo0?oooi`0oooo00<0P820000000000000
1@0000000`30`<00oooo0?ooo`0@0?ooo`8000001`3oool01010@400000000000020P8180?ooo`00
<@3oool01@30`<000000000000000000`<3001`0oooo00@0`<30000000000000@410o`3ooooo0?oo
oi`0oooo1`0000000`30`<00oooo0?ooo`0A0?ooo`800000203oool01010@400000000000010@417
0?ooo`00<`3oool3000001d0oooo0`00003o0?ooool0ooooV`3oool00`20P8000000000000040000
01D0oooo0P0000090?ooo`<0000000<0P8200?ooo`3oool0A03oool003<0oooo00D0`<3000000000
000000000<30`00L0?ooo`80000000<0P8200?ooo`3oool0o`3ooooo0?oooiP0oooo00<0P8200000
000000000`0000000`30`<00oooo0?ooo`0:0?ooo`0300000020P800oooo00H0oooo00<0P8200000
0020P800203oool01@30`<000000000000000000`<3004D0oooo000d0?ooo`050<30`00000000000
00000030`<006`3oool00`20P80000000410@03o0?ooool0ooooVP3oool5000000030410@03oool0
oooo00/0oooo0P0000070?ooo`030820P0000000P82000X0oooo00@0@410000000000000P820A03o
ool003D0oooo00D0`<3000000000000000000<30`00J0?ooo`040<30`000000000000820P?l0oooo
o`3ooonI0?ooo`D0000000<0`<300?ooo`3oool02`3oool2000000L0oooo00<0P82000000020P800
2`3oool01010@400000000000010@4130?ooo`00=`3oool3000001/0oooo0`00003o0?ooool0oooo
V@3oool5000000h0oooo0P0000000`20P800oooo0?ooo`040?ooo`030820P0000000P82000`0oooo
0`0000000`20P800oooo0?ooo`100?ooo`00=`3oool01@30`<000000000000000000`<3001T0oooo
00@0P820000000000000`<30o`3ooooo0?oooiP0oooo1@00000>0?ooo`80000000<0P8200?ooo`3o
ool0103oool00`20P80000000820P00<0?ooo`050<30`0000000000000000030`<00@@3oool003P0
oooo00D0`<3000000000000000000<30`00H0?ooo`040<30`000000000000410@?l0ooooo`3ooonH
0?ooo`030410@00000000000008000003@3oool01030`<00000000000010@4060?ooo`030820P000
0000P82000h0oooo00@0@410000000000000P820@03oool003T0oooo00D0`<300000000000000000
0<30`00H0?ooo`040410@000000000000<30`?l0ooooo`3ooonG0?ooo`030820P000000000000080
000000<0`<300?ooo`3oool02P3oool01010@40000000000000000060?ooo`030<30`0000000@410
00l0oooo00@0@410000000000000@410?`3oool003/0oooo0`00000H0?ooo`040820P00000000000
0820P?l0ooooo`3ooonH0?ooo`@0000000<0P8200?ooo`3oool02P3oool4000000030820P03oool0
oooo00@0oooo0P00000@0?ooo`<0000000<0P8200?ooo`3oool0?03oool003/0oooo00D0`<300000
0000000000000<30`00G0?ooo`<00000o`3ooooo0?oooiP0oooo00<0P8200000000000000P000000
0`30`<00oooo0?ooo`080?ooo`030410@000000000000080000000<0P8200?ooo`3oool0103oool2
00000100oooo00D0`<3000000000000000000<30`00m0?ooo`00?03oool01@30`<00000000000000
0000`<3001L0oooo0P0000000`20P800oooo0?ooo`3o0?ooool0ooooUP3oool00`10@40000000000
0002000000030820P03oool0oooo00D0oooo00<0P8200410@0000000100000000`10@400oooo0?oo
o`040?ooo`8000004P3oool01010@400000000000020P80l0?ooo`00?@3oool01@30`<0000000000
00000000`<3001H0oooo00<0P820000000000000o`3ooooo0?oooiT0oooo00<0P820000000000000
0`0000001@10@400P8200820P020P800@41000@0000000<0@4100820P020P8000P0000060?ooo`80
00004`3oool01010@400000000000010@40k0?ooo`00?`3oool3000001L0oooo0`00003o0?ooool0
ooooVP3oool<000000@0oooo00<0P8200000003oool01@3oool2000001@0oooo0`0000000`20P800
oooo0?ooo`0h0?ooo`00?`3oool01@30`<000000000000000000`<3001D0oooo00@0@41000000000
0000`<30o`3ooooo0?oooiX0oooo0P20P805000000030410@020P800oooo00H0oooo00<0@4100000
003oool0103oool00`10@40000000000000C0?ooo`050<30`0000000000000000030`<00>@3oool0
0400oooo00D0`<3000000000000000000<30`00D0?ooo`040<30`000000000000410@?l0ooooo`3o
oona0?ooo`030820P0000000000001D0oooo00@0@410000000000000P820>03oool00440oooo00D0
`<3000000000000000000<30`00D0?ooo`040410@000000000000<30`?l0ooooo`3ooon`0?ooo`03
0820P0000000000001H0oooo00@0@410000000000000@410=`3oool004<0oooo0`00000D0?ooo`04
0820P000000000000820P?l0ooooo`3ooon`0?ooo`030820P0000000000001L0oooo0`0000000`20
P800oooo0?ooo`0d0?ooo`00@`3oool01@30`<000000000000000000`<3001<0oooo0`00003o0?oo
ool0oooo/03oool01020P800000000000030`<0F0?ooo`050<30`0000000000000000030`<00=@3o
ool004@0oooo00D0`<3000000000000000000<30`00C0?ooo`80000000<0P8200?ooo`3oool0o`3o
oooo0?ooojh0oooo0P0000000`20P800oooo0?ooo`0F0?ooo`040410@000000000000820P3@0oooo
00150?ooo`050<30`0000000000000000030`<004P3oool00`20P80000000000003o0?ooool0oooo
/03oool2000000030820P03oool0oooo01L0oooo00<0@410000000000000=03oool004L0oooo0`00
000C0?ooo`<00000o`3ooooo0?ooojl0oooo0P0000000`20P800oooo0?ooo`0H0?ooo`800000=03o
ool004L0oooo00D0`<3000000000000000000<30`00A0?ooo`040410@000000000000<30`?l0oooo
o`3ooon^0?ooo`80000000<0P8200?ooo`3oool0603oool00`30`<0000000?ooo`0c0?ooo`00B03o
ool01@30`<000000000000000000`<300100oooo00@0`<300000000000000000o`3ooooo0?ooojh0
oooo00<0P820000000000000703oool00`30`<00oooo0?ooo`0a0?ooo`00B@3oool01@30`<000000
000000000000`<300100oooo00@0P820000000000000P820o`3ooooo0?ooojd0oooo00<0P8200000
00000000D03oool004/0oooo0`00000A0?ooo`<00000o`3ooooo0?ooojd0oooo00<0P82000000000
0000D03oool004/0oooo00@0`<30000000000000@4104@3oool2000000030<30`03oool0oooo0?l0
ooooWP3oool20820P0030<30`03oool0oooo0?l0oooo1`3oool01020P800000000000030`<1?0?oo
o`00C03oool01@30`<000000000000000000`<3000l0oooo00<0`<3000000010@400o`3ooon>0?oo
o`050820P0000000000000000010@400303oool00`10@400000000000002000000030820P03oool0
oooo0?l0oooo1@3oool01@30`<000000000000000000`<3004h0oooo001=0?ooo`050<30`0000000
000000000030`<003`3oool00`10@40000000000003o0?ooohh0oooo1000000<0?ooo`H0000000<0
@4100?ooo`3oool0o`3oool50?ooo`@0000000<0`<300?ooo`3oool0B`3oool004h0oooo00D0`<30
00000000000000000<30`00?0?ooo`80000000<0@4100?ooo`3oool0o`3ooon;0?ooo`050410@000
0000000000000020P8002`3oool4000000040820P03oool0P8200410@?l0oooo1P3oool200000004
0410@000000000000820P4`0oooo001@0?ooo`<000003`3oool00`20P80000000000003o0?ooohd0
oooo00D0P82000000000000000000820P00;0?ooo`@0000000<0P8200?ooo`3oool00P20P83o0?oo
o`D0oooo0P0000020820P080000000<0P8200?ooo`3oool0B@3oool00500oooo00D0`<3000000000
000000000<30`00=0?ooo`040<30`000000000000410@?l0ooooS03oool01@20P800000000000000
0000@41000/0oooo00D0P82000000000000000000410@0030?ooo`0300000020P800oooo0?l0oooo
0`3oool2000000030820P03oool0@4100080000000<0`<300?ooo`3oool0B03oool00540oooo00D0
`<3000000000000000000<30`00=0?ooo`040820P000000000000<30`?l0ooooS03oool4000000/0
oooo00<0`<300000000000000P0000030?ooo`030<30`0000000`<300?l0oooo103oool200000080
oooo00@0P820000000000000`<30B@3oool00580oooo00D0`<3000000000000000000<30`00=0?oo
o`030410@000000000000?l0ooooS03oool00`20P800000000000002000000/0oooo1@00003o0?oo
o`T0oooo0P0000030?ooo`040<30`000000000000820P4P0oooo001D0?ooo`<000003P3oool30000
0?l0ooooS03oool4000000030820P03oool0oooo00T0oooo1000003o0?ooo`T0oooo0P0000040?oo
o`040820P000000000000820P4L0oooo001D0?ooo`050<30`0000000000000000030`<00303oool0
1010@400000000000020P83o0?oooh/0oooo00D0@41000000000000000000410@00;0?ooo`@00000
00<0P8200?ooo`3oool0o`3oool60?ooo`030410@0000000`<3000@0oooo00@0@410000000000000
`<30AP3oool005D0oooo00D0`<3000000000000000000<30`00<0?ooo`<00000o`3ooon;0?ooo`03
0820P000000000000080000000<0`<300?ooo`3oool0203oool01@20P8000000000000000000P820
0?l0oooo203oool00`20P80000000820P0050?ooo`040820P000000000000<30`4D0oooo001F0?oo
o`050<30`0000000000000000030`<002`3oool01030`<00000000000010@43o0?ooohX0oooo00<0
`<300000000000000`00000:0?ooo`030<30`0000000000000800000o`3oool80?ooo`030820P000
0000P82000H0oooo00@0`<30000000000000P820A03oool005P0oooo0`00000<0?ooo`<00000o`3o
oon;0?ooo`D0000000<0P8200?ooo`3oool0203oool400000?l0oooo2@3oool2000000L0oooo00@0
P820000000000000P820@`3oool005P0oooo00D0`<3000000000000000000<30`00;0?ooo`030410
@0000000@4100?l0ooooRP3oool00`10@400000000000002000000030410@03oool0oooo00P0oooo
00D0@41000000000000000000820P03o0?ooo`P0oooo0P0000080?ooo`040410@000000000000<30
`480oooo001I0?ooo`050<30`0000000000000000030`<002`3oool2000000030820P03oool0oooo
0?l0ooooQ`3oool01@20P8000000000000000000P8200080000000<0`<300?ooo`3oool01P3oool0
1@20P8000000000000000000@4100?l0oooo203oool2000000T0oooo00@0P820000000000000`<30
@@3oool005X0oooo00D0`<3000000000000000000<30`00:0?ooo`040<30`000000000000820P?l0
ooooR03oool00`30`<00000000000002000000030<30`0000000@41000T0oooo1000003o0?ooo`P0
oooo00<0P82000000020P8002@3oool01030`<00000000000020P8100?ooo`00G03oool3000000/0
oooo0`00003o0?ooohT0oooo10000000103oool0000000000020P8080?ooo`@0000000<0P8200?oo
o`3oool0o`3oool50?ooo`030820P0000000P82000X0oooo00@0P820000000000000P820?`3oool0
05`0oooo00D0`<3000000000000000000<30`0090?ooo`040<30`000000000000<30`?l0ooooR03o
ool01P10@4000000000000000000P8200?ooo`80@410203oool01@20P8000000000000000000P820
0?l0oooo1`3oool00`20P80000000820P00;0?ooo`040410@000000000000<30`3h0oooo001M0?oo
o`050<30`0000000000000000030`<002@3oool00`20P80000000000003o0?ooohP0oooo00D0P820
00000000000000000820P0020?ooo`80@4101`3oool00`30`<0000000000000200000?l0oooo203o
ool2000000`0oooo00@0P820000000000000`<30?@3oool005h0oooo00D0`<300000000000000000
0<30`0090?ooo`030820P0000000@4100?l0ooooQ`3oool00`30`<0000000000000200000080oooo
00@0`<30000000000000`<301P3oool4000000030820P03oool0oooo0?l0oooo1@3oool2000000d0
oooo00@0`<30000000000000P820?03oool00600oooo0`00000:0?ooo`800000o`3ooon80?ooo`@0
00000`3oool00`20P8000000000000060?ooo`D00000o`3oool70?ooo`8000003P3oool01020P800
000000000020P80k0?ooo`00H03oool01@30`<000000000000000000`<3000P0oooo00@0P8200000
00000000`<30o`3ooon60?ooo`030820P00000000000008000000`3oool00`20P80000000410@006
0?ooo`@00000o`3oool70?ooo`030820P0000000000000h0oooo00@0@410000000000000`<30>P3o
ool00640oooo00D0`<3000000000000000000<30`0080?ooo`030410@0000000@4100?l0ooooQ`3o
ool4000000@0oooo00@0`<3000000010@400P820103oool4000000030820P03oool0oooo0?l0oooo
103oool00`20P80000000000000?0?ooo`040820P000000000000<30`3T0oooo001R0?ooo`050<30
`0000000000000000030`<001`3oool01030`<00000000000030`<3o0?ooohD0oooo00<0P8200000
000000000P0000000`20P800oooo0?ooo`020?ooo`040<30`0000000000000000080P8201@000000
0`20P800oooo0?ooo`3o0?ooo`@0oooo00@0`<30000000000000`<303`3oool01030`<0000000000
0020P80h0?ooo`00I03oool3000000P0oooo0`00003o0?oooh80oooo200000000`20P800oooo0?oo
o`030?ooo`030820P0000000000000L00000o`3oool80?ooo`80000000<0P8200?ooo`3oool03P3o
ool01020P800000000000020P80g0?ooo`00I03oool01@30`<000000000000000000`<3000L0oooo
00<0@41000000030`<00o`3ooon00?ooo`80P820200000060?ooo`030820P0000000000000D00000
00<0P8200?ooo`3oool0o`3oool60?ooo`80000000<0P8200?ooo`3oool03`3oool01010@4000000
00000030`<0f0?ooo`00I@3oool01@30`<000000000000000000`<3000H0oooo00<0`<3000000000
0000o`3ooon50?ooo`050<30`020P800P8200820P0000000203oool00`20P800@410000000020000
00030820P03oool0oooo0?l0oooo1`3oool00`10@40000000410@00B0?ooo`040820P00000000000
0<30`3D0oooo001V0?ooo`050<30`0000000000000000030`<001P3oool00`20P80000000000003o
0?oooe/0oooo00<0`<300410@010@400o`3ooom20?ooo`030820P0000000000001<0oooo00@0`<30
000000000000P820=03oool004T0oooo00<0P8200?ooo`3oool0703oool3000000L0oooo0P000000
0`20P800oooo0?ooo`3o0?oooeT0oooo0`00003o0?oood40oooo00<0P820000000000000503oool0
1020P800000000000020P80c0?ooo`00B@3oool20820P1d0oooo00D0`<3000000000000000000<30
`0050?ooo`030410@000000000000?l0ooooF`3oool01030`<00000000000010@43o0?oood00oooo
00@0`<30000000000000`<30503oool01010@400000000000030`<0b0?ooo`00BP3oool00`20P800
@4100?ooo`0L0?ooo`050<30`0000000000000000030`<001@3oool2000000030410@03oool0oooo
0?l0ooooF@3oool01030`<00000000000030`<3o0?oood00oooo0P0000000`20P800oooo0?ooo`0C
0?ooo`040820P000000000000<30`340oooo001;0?ooo`80@4107@3oool01@30`<00000000000000
0000`<3000D0oooo00<0@41000000030`<00o`3ooomK0?ooo`040820P000000000000<30`?l0oooo
?`3oool2000000030410@03oool0oooo01@0oooo00@0`<30000000000000P820<03oool004`0oooo
00<000000820P03oool07@3oool3000000D0oooo00<0P82000000020P800o`3ooomL0?ooo`030820
P000000000000?l0oooo@03oool2000001L0oooo00@0P820000000000000P820;`3oool004`0oooo
00<0@41000000030`<007@3oool01@30`<000000000000000000`<3000@0oooo0P0000000`20P800
oooo0?ooo`3o0?oooeX0oooo00@0@410000000000000`<30703oool01030`<00000000000020P80B
0?ooo`040410@000000000000<30`?l0oooo203oool2000001P0oooo00@0@410000000000000`<30
;P3oool004d0oooo0P0000000`20P800oooo0?ooo`0K0?ooo`050<30`0000000000000000030`<00
0`3oool01030`<00000000000030`<3o0?oooe`0oooo00@0@410000000000000`<30703oool01010
@400000000000030`<0@0?ooo`040<30`000000000000410@?l0oooo2@3oool00`10@40000000820
P00H0?ooo`040820P000000000000<30`2d0oooo001=0?ooo`040<30`000000000000410@1d0oooo
00D0`<3000000000000000000<30`0030?ooo`030410@000000000000?l0ooooG@3oool00`20P800
00000000000M0?ooo`<00000403oool300000?l0oooo2P3oool00`20P80000000820P00I0?ooo`03
0<30`0000000@41002d0oooo001>0?ooo`<0000000<0P8200?ooo`3oool0703oool3000000@0oooo
0P0000000`20P800oooo0?ooo`3o0?oooe/0oooo00<0P82000000020P800703oool01020P8000000
00000020P80>0?ooo`030820P000000000000?l0oooo2`3oool00`20P80000000000000J0?ooo`03
0820P0000000oooo02`0oooo001>0?ooo`050<30`0000000000000000030`<007@3oool01@30`<00
0000000000000000`<300080oooo00<0P820000000000000o`3ooomM0?ooo`040<30`00000000000
0820P1/0oooo00@0`<30000000000000@4103P3oool00`10@40000000410@03o0?ooo``0oooo0P00
000K0?ooo`030410@03oool0oooo02/0oooo001@0?ooo`040410@000000000000820P1d0oooo00D0
`<3000000000000000000<30`0020?ooo`030410@0000000@4100?l0ooooG@3oool01030`<000000
00000010@40L0?ooo`80000000<0P8200?ooo`3oool02P3oool300000?l0oooo3@3oool200000003
0820P03oool0oooo01T0oooo00<0P8200?ooo`3oool0:P3oool00540oooo00@0@410000000000000
@4107@3oool01@30`<000000000000000000`<300080oooo0P0000000`20P800oooo0?ooo`3o0?oo
oe/0oooo00@0`<30000000000000@4106`3oool00`20P80000000000000;0?ooo`040820P0000000
00000820P5d0oooo00<000000<30`03oool01@3oool00`30`<00P8200820P005000000030410@020
P800P82009`0oooo00<0P820000000000000B03oool00580oooo00@0@410000000000000@4107P3o
ool01P10@400000000000020P800oooo0<30`080000000<0P8200?ooo`3oool0o`3ooomL0?ooo`03
0410@0000000@41001/0oooo0`0000090?ooo`040<30`00000000000000005h0oooo00<0P8200000
0020P8000P3oool20820P0@000001@20P804000000030820P03oool0oooo09P0oooo00@0`<300000
00000000P820A`3oool005<0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`<0000000<0P8200?oo
o`0000000P00003o0?oooel0oooo0P00000K0?ooo`040820P000000000000820P0P0oooo00@0P820
000000000000P820GP3oool00`20P800000000000006000000P0oooo100000000`20P800oooo0?oo
o`2H0?ooo`80000000<0P8200?ooo`3oool0A@3oool005@0oooo00@0@410000000000000P8207@3o
ool01030`<0000000000000000020<30`080000000<0P8200?ooo`3oool0o`3ooomL0?ooo`040820
P000000000000<30`1X0oooo0`0000080?ooo`<00000G`3oool00`20P80000000000000400000003
0410@030`<00oooo00P0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`2F0?ooo`<0
000000<0`<300?ooo`3oool0A03oool005D0oooo00@0@410000000000000@4107@3oool01P30`<00
0000000000000000`<300820P080000000<0`<300?ooo`3oool0o`3ooomL0?ooo`040410@0000000
00000<30`1T0oooo00@0P820000000000000P8201P3oool00`10@40000000000001Q0?ooo`D00000
00<0P8200?ooo`3oool02P3oool01@30`<000000000000000000@41009P0oooo00D0P82000000000
000000000<30`0150?ooo`00EP3oool01010@400000000000010@40N0?ooo`030410@00000000000
0080P82000<000000410@03oool0o`3ooomN0?ooo`040820P000000000000<30`1T0oooo00<0P820
0000000000001@3oool01020P800000000000030`<1Q0?ooo`@0000000<0@4100?ooo`3oool0303o
ool01@10@4000000000000000000P82009L0oooo00<0P8200000000000000P0000000`20P800oooo
0?ooo`120?ooo`00E`3oool3000000030820P03oool0oooo01`0oooo0`0000001020P80000000000
0000003o0?oooel0oooo00<0P8200000000000006P3oool2000000030820P03oool0oooo0080oooo
0`00001R0?ooo`040820P00000000000000000l0oooo00<0P8200000000000000P00002H0?ooo`D0
000000<0P8200?ooo`3oool0@@3oool005P0oooo00@0@410000000000000P8207@3oool00`30`<00
000000000004000000030<30`03oool0oooo0?l0ooooG@3oool01010@400000000000030`<0H0?oo
o`030820P0000000000000<0oooo00@0P820000000000000P820HP3oool01020P800000000000000
000?0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0U@3oool6000000030<30`03o
ool0oooo0400oooo001I0?ooo`040410@000000000000410@1d0oooo00<0`<300000000000001000
003o0?ooof00oooo00<0@4100000000000006@3oool3000000030?ooo`30`<00000000800000H`3o
ool01030`<00000000000020P80@0?ooo`@0000000<0P8200?ooo`3oool0UP3oool2000000050<30
`0000000000000000030`<00@@3oool005X0oooo00@0@410000000000000@4107P3oool00`10@400
000000000002000000030820P03oool0oooo0?l0ooooGP3oool2000000030410@03oool0oooo01H0
oooo00<0`<300000000000000P10@402000000030<30`03oool0oooo0680oooo0P0000000`20P800
oooo0?ooo`0>0?ooo`D00000V03oool2000000030<30`03oool0@4100080000000<0P8200?ooo`3o
ool0?P3oool005/0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`D00000o`3ooomQ0?ooo`800000
00<0P8200?ooo`3oool05P3oool6000006D0oooo0P0000000`20P800oooo0?ooo`0>0?ooo`D00000
V03oool00`20P80000000820P0020?ooo`<0000000<0P8200?ooo`3oool0?@3oool005`0oooo00@0
@410000000000000P8207@3oool00`30`<00000000000002000000030820P03oool0oooo0?l0oooo
GP3oool01030`<00000000000020P80G0?ooo`030820P0000000000000800000IP3oool00`20P800
00000820P00?0?ooo`030<30`0000000000000<00000V03oool00`20P80000000820P0020?ooo`05
0<30`0000000000000000030`<00?P3oool005d0oooo00@0@410000000000000@4107@3oool00`30
`<00000000000002000000030820P03oool0oooo0?l0ooooGP3oool01030`<00000000000010@40>
0?ooo`030<30`03oool0oooo00H0oooo00@0P820000000000000`<30I`3oool00`000000P8200?oo
o`0>0?ooo`030820P0000000000000<00000V03oool00`30`<000000000000030?ooo`050<30`000
0000000000000030`<00?@3oool005h0oooo00@0@410000000000000@4107P3oool01@10@4000000
000000000000`<300?l0ooooH03oool01030`<00000000000010@40=0?ooo`80P820203oool20410
@6P0oooo00<0@4100820P03oool03@3oool00`30`<00000000000003000000030410@03oool0oooo
09L0oooo0P0000050?ooo`040410@000000000000820P3`0oooo001O0?ooo`<0000000<0P8200?oo
o`3oool0703oool3000000030820P03oool0oooo0?l0ooooH03oool2000000h0oooo00<000000?oo
o`3oool0L03oool20820P0h0oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`2G0?oo
o`<000001@3oool3000000030820P03oool0oooo03T0oooo001P0?ooo`040410@000000000000820
P1d0oooo00D0`<3000000000000000000<30`03o0?ooof40oooo00<0P82000000010@4003@3oool0
0`000000P8200?ooo`1o0?ooo`030820P0000000000000@0000000<0`<300?ooo`3oool0U`3oool0
0`20P8000000000000050?ooo`050<30`0000000000000000030`<00>P3oool00640oooo00@0@410
000000000000@4107@3oool01030`<00000000000010@43o0?ooof80oooo00<0@41000000010@400
303oool2000007l0oooo00<0@410000000000000100000000`10@400oooo0?ooo`2H0?ooo`040<30
`000000000000820P0D0oooo00D0`<3000000000000000000<30`00i0?ooo`00HP3oool01010@400
000000000010@40N0?ooo`030410@0000000`<300?l0ooooHP3oool01010@400000000000030`<0:
0?ooo`80000000<0P8200?ooo`3oool0N`3oool00`10@400000000000005000009`0oooo0P000000
0`20P800oooo0?ooo`050?ooo`040410@000000000000820P3P0oooo001S0?ooo`<0000000<0P820
0?ooo`3oool06`3oool00`20P80000000000003o0?ooof<0oooo0`00000:0?ooo`<00000O@3oool7
000000030820P03oool0oooo09X0oooo0`0000080?ooo`<0000000<0P8200?ooo`3oool0=@3oool0
06@0oooo00@0@410000000000000P8207@3oool00`10@40000000820P03o0?ooof80oooo00@0`<30
000000000000@4102@3oool3000000030<30`03oool0oooo07T0oooo00<0@4100000000000001000
00000`20P800oooo0?ooo`2K0?ooo`030820P0000000000000P0oooo00D0`<300000000000000000
0<30`00f0?ooo`00I@3oool01010@400000000000010@40L0?ooo`040<30`000000000000820P?l0
ooooH`3oool00`10@40000000820P0080?ooo`<0000000<0@4100?ooo`3oool0M`3oool00`30`<00
000000000005000000030<30`03oool0oooo09`0oooo00@0`<30000000000000P820203oool01@30
`<000000000000000000`<3003D0oooo001V0?ooo`040410@000000000000410@1`0oooo00<0@410
000000000000o`3ooomT0?ooo`80000000<0P8200?ooo`3oool01@3oool4000000030820P03oool0
oooo07D0oooo00<0`<300000000000001@0000000`30`<00oooo0?ooo`2N0?ooo`80000000<0@410
0?ooo`3oool0203oool01010@400000000000020P80d0?ooo`00I`3oool3000000030820P03oool0
oooo01X0oooo0P0000000`20P800oooo0?ooo`3o0?ooof40oooo00@0P820000000000000P8201P3o
ool5000007L0oooo1`0000000`20P800oooo0?ooo`2O0?ooo`<000002`3oool3000000030820P03o
ool0oooo0340oooo001X0?ooo`040410@000000000000820P1/0oooo00<0P820000000000000o`3o
oomT0?ooo`040410@000000000000<30`0D0oooo1@0000000`20P800oooo0?ooo`1c0?ooo`030410
@0000000000000@0000000<0P8200?ooo`3oool0X@3oool2000000/0oooo00D0`<30000000000000
00000<30`00b0?ooo`00J@3oool01010@400000000000010@40K0?ooo`030820P0000000@4100?l0
ooooI03oool01020P800000000000030`<040?ooo`H00000L`3oool00`30`<000000000000050000
00030410@03oool0oooo0:80oooo0P0000000`20P800oooo0?ooo`090?ooo`050<30`00000000000
00000030`<00<@3oool006X0oooo00@0@410000000000000@4106`3oool00`10@40000000<30`03o
0?ooof@0oooo00@0`<30000000000000P8200P3oool00`20P800000000000004000000030820P03o
ool0oooo0700oooo00<0@410000000000000100000000`10@400oooo0?ooo`2S0?ooo`030820P000
0000@41000d0oooo00@0@410000000000000P820<03oool006/0oooo0`0000000`20P800oooo0?oo
o`0H0?ooo`030820P000000000000?l0ooooI@3oool00`20P8000000000000020?ooo`030820P000
0000000000D00000LP3oool700000:H0oooo00<0P8200000000000003P3oool3000000030820P03o
ool0oooo02d0oooo001/0?ooo`040410@000000000000820P1X0oooo00<0@41000000020P800o`3o
oomU0?ooo`80000000<0@4100?ooo`10@4001`0000000`30`<00oooo0?ooo`1^0?ooo`030820P000
0000000000@0000000<0`<300?ooo`3oool02@3oool20<30`9X0oooo0P00000>0?ooo`050<30`000
0000000000000030`<00;P3oool006d0oooo00@0@410000000000000@4106@3oool01030`<000000
00000020P83o0?ooof@0oooo00@0`<30000000000000@410200000000`10@400oooo0?ooo`1^0?oo
o`030410@0000000000000<000003@3oool00`20P800@4100?ooo`2I0?ooo`<000003P3oool01@30
`<000000000000000000`<3002d0oooo001^0?ooo`040410@000000000000410@1T0oooo00@0P820
000000000000`<30o`3ooomF0?ooo`030410@020P800P82000`0oooo2`0000000`20P800oooo0?oo
o`1]0?ooo`D0000000<0P8200?ooo`3oool02`3oool00`20P80000000?ooo`2I0?ooo`030820P000
000000000100oooo00@0@410000000000000P820;03oool006l0oooo0`0000000`20P800oooo0?oo
o`0G0?ooo`80000000<0P8200?ooo`3oool0o`3ooomF0?ooo`H000001@3oool>000006l0oooo1@00
000>0?ooo`030820P0000000oooo09T0oooo00@0P820000000000000P820403oool3000000030820
P03oool0oooo02T0oooo001`0?ooo`040410@000000000000820P1T0oooo0P00003o0?oooeT0oooo
00<0@4100000000000005@0000000`20P800oooo0?ooo`1/0?ooo`D000003P3oool00`20P8000000
0820P02J0?ooo`80000000<0P8200?ooo`3oool03P3oool01@30`<000000000000000000`<3002X0
oooo001a0?ooo`040410@000000000000410@1P0oooo00<0P82000000010@400o`3ooomI0?ooo`03
0<30`010@400000001@0000000<0@4100?ooo`3oool0K03oool5000000h0oooo00<0P82000000020
P800VP3oool2000000030820P03oool0oooo00l0oooo00D0`<3000000000000000000<30`00Y0?oo
o`00LP3oool01010@400000000000010@40H0?ooo`030410@0000000P8200?l0ooooFP3oool00`20
P800@4100000000C000000030<30`03oool0oooo06/0oooo00<0P8200000000000000P00000>0?oo
o`<00000VP3oool00`10@40000000000000C0?ooo`040410@000000000000820P2P0oooo001c0?oo
o`<0000000<0P8200?ooo`3oool05@3oool01020P800000000000020P83o0?oooe/0oooo00<0P820
0000000000004@0000000`20P800oooo0?ooo`1[0?ooo`030820P000000000000080000000<0P820
0?ooo`3oool02P3oool4000009X0oooo00<0P820000000000000503oool3000000030820P03oool0
oooo02D0oooo001d0?ooo`040410@000000000000820P1L0oooo00<0@41000000010@400o`3ooomL
0?ooo`030820P000000000000100000000<0@4100?ooo`3oool08@3oool01030`<00P8200820P020
P80F000000@0P82000<0`<300?ooo`3oool0:P3oool01@10@4000000000000000000@41000/0oooo
00<0`<300000000000000`00002I0?ooo`040820P000000000000<30`1<0oooo00D0`<3000000000
000000000<30`00V0?ooo`00M@3oool01010@400000000000010@40F0?ooo`040<30`00000000000
0820P?l0ooooG@3oool00`30`<0000000000000?000000030<30`03oool0oooo01/0oooo00<0`<30
0820P00000009P0000040820P0030<30`03oool0oooo0200oooo00<0`<300000000000000`000000
0`30`<00oooo0?ooo`060?ooo`030<30`0000000000000@00000VP3oool2000000030820P03oool0
oooo0180oooo00D0`<3000000000000000000<30`00U0?ooo`00MP3oool01010@400000000000010
@40G0?ooo`80000000<0`<300?ooo`3oool0o`3ooomL0?ooo`030820P0000000000000d0000000<0
@4100?ooo`3oool05`3oool20820P0P000000`20P8001030`<00oooo0?ooo`20P802000000030410
@03oool0oooo00d0oooo1020P8000`10@40000000000000<000000@0P820703oool00`10@4000000
00000002000000030820P030`<00oooo0080oooo00<0`<300820P010@4001`0000000`20P800oooo
0?ooo`2G0?ooo`80000000<0P8200?ooo`3oool0503oool01010@400000000000020P80T0?ooo`00
M`3oool01020P800000000000010@40F0?ooo`030<30`0000000@4100?l0ooooH03oool00`20P800
00000000000<000000030820P03oool0oooo0180oooo0P20P807000000030820P030`<00oooo00T0
oooo00D0`<3000000000000000000<30`00F0?ooo`D0P820300000001@10@400P8200820P020P800
`<3001D0oooo00<0P8200000000000002P0000020820P080oooo00<0@41000000020P800V@3oool0
0`20P80000000000000G0?ooo`040410@000000000000410@2<0oooo001h0?ooo`040820P0000000
0000000001H0oooo0`00003o0?ooof40oooo3P00000C0?ooo`L0000000<0P8200?ooo`3oool03@3o
ool01020P800000000000000000M0?ooo`030820P0000000000000h0000000<0P8200?ooo`3oool0
4P3oool9000000030820P03oool0oooo00@0oooo0P00002J0?ooo`800000603oool3000000030820
P03oool0oooo0200oooo001i0?ooo`040410@000000000000410@1D0oooo00@0`<30000000000000
`<30o`3ooomP0?ooo`030<30`020P800000000/0000000<0P8200?ooo`3oool03P3oool00`20P800
000000000002000000030410@020P800`<300180oooo00@0@410000000000000@4107@3oool01P20
P800000000000010@400oooo0<30`0<0P8202`0000001010@400P8200820P020P80?0?ooo`D0P820
00<0`<300?ooo`3oool01`3oool00`20P800oooo0?ooo`2H0?ooo`800000603oool01@30`<000000
000000000000`<300240oooo001j0?ooo`040410@000000000000410@1D0oooo00<0@41000000000
0000o`3ooomS0?ooo`030410@0000000000000P0000000<0@4100?ooo`3oool02`3oool00`30`<00
P82000000002000000030820P030`<00oooo01H0oooo00@0P820000000000000@4107@3oool01@30
`<000000000000000000`<3000L0oooo0`20P80<000000<0P82000<0`<300?ooo`3oool0[`3oool0
0`10@40000000820P00I0?ooo`030410@000000000000240oooo001k0?ooo`040820P00000000000
0410@1D0oooo0P0000000`10@400oooo0?ooo`3o0?ooof40oooo00<0`<300820P000000020000000
0`30`<00oooo0?ooo`080?ooo`030820P000000000000080000000<0P8200?ooo`3oool06@3oool0
1@30`<000000000000000000`<3001`0oooo00D0`<3000000000000000000<30`00=0?ooo`<0P820
00<0@4100000000000002@0000001010@400P8200820P020P82Z0?ooo`030820P0000000P82001X0
oooo00<0@4100000003oool0803oool007`0oooo00@0P82000000000000000005@3oool200000?l0
ooooI@3oool00`20P800000000000006000000030820P03oool0oooo00H0oooo00<0P82000000000
00000`0000000`20P800oooo0?ooo`0K0?ooo`040820P00000000000000001d0oooo00@0P8200000
000000000000503oool00`20P80000000000000<000000030820P03oool0oooo0:@0oooo00<0P820
00000020P8006`3oool200000200oooo001m0?ooo`040410@000000000000410@1@0oooo00<0P820
00000010@400o`3ooomU0?ooo`030<30`010@400000000H000001`3oool00`20P800000000000004
000000030410@03oool0oooo01`0oooo00@0@410000000000000@4107@3oool01020P80000000000
0010@40G0?ooo`@0P820400000000`10@400P8200820P0020820P0030<30`03oool0oooo09H0oooo
00<0`<300000000000006`3oool00`30`<0000000?ooo`0O0?ooo`00OP3oool01010@40000000000
0010@40D0?ooo`030410@0000000P8200?l0ooooIP3oool00`20P800@41000000004000000030820
P03oool0oooo00<0oooo00L0P82000000000000000000820P03oool0@4100080000000<0@4100?oo
o`3oool0703oool01020P800000000000010@40M0?ooo`050<30`0000000000000000030`<00703o
ool00`30`<00P8200000000D000000<0P820TP3oool2000003d0oooo001o0?ooo`040820P0000000
00000410@1<0oooo00@0`<30000000000000`<30o`3ooomW0?ooo`030<30`0000000000000<00000
0`3oool01@20P8000000000000000000`<3000@0oooo00@0P820000000000000@4107P3oool01@30
`<000000000000000000`<3001`0oooo00D0`<3000000000000000000<30`00M0?ooo`040<30`000
000000000410@0L0oooo1@20P80:000000030820P030`<00oooo08d0oooo00<0@410000000000000
?03oool00800oooo00@0P82000000000000000004`3oool300000?l0ooooJ@3oool5000000030?oo
o`20P8000000008000001`3oool01020P800000000000000000N0?ooo`040820P000000000000000
01d0oooo00@0P82000000000000000007`3oool2000000030820P03oool0oooo00h0oooo1`000000
0`20P800oooo0?ooo`2;0?ooo`030820P0000000000003`0oooo00210?ooo`040410@00000000000
0410@180oooo00@0`<30000000000000`<30o`3ooomY0?ooo`050<30`0000000000000000010@400
0`0000000`30`<00oooo0?ooo`060?ooo`040410@000000000000410@1h0oooo00@0@41000000000
0000@4107@3oool01020P800000000000010@40N0?ooo`040<30`000000000000820P140oooo00<0
`<300820P0000000100000000`20P800oooo0?ooo`290?ooo`040820P000000000000410@3/0oooo
00220?ooo`040410@000000000000410@180oooo00<0P820000000000000o`3ooom[0?ooo`@00000
00<0`<300?ooo`3oool02@3oool01010@400000000000010@40N0?ooo`040820P000000000000410
@1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@000000000000410@1<0oooo00<0
`<300820P00000000`0000000`30`<00oooo0?ooo`280?ooo`<0000000<0@4100?ooo`3oool0>03o
ool008<0oooo00@0P820000000000000@4104P3oool00`20P80000000410@03o0?ooofP0oooo00H0
`<300410@000000000000410@030`<0=0?ooo`040820P000000000000410@1h0oooo00D0`<300000
0000000000000<30`00L0?ooo`050<30`0000000000000000030`<007@3oool01010@40000000000
0010@40E0?ooo`040820P010@4000000000008X0oooo100000000`10@400oooo0?ooo`0g0?ooo`00
Q03oool01020P800000000000000000B0?ooo`800000o`3ooomX0?ooo`@00000403oool01020P800
000000000000000N0?ooo`040820P00000000000000001d0oooo00@0P82000000000000000007P3o
ool3000000030820P03oool0oooo01@0oooo0`0000290?ooo`H00000>03oool008D0oooo00@0@410
000000000000@4104@3oool01020P800000000000030`<3o0?ooof@0oooo00D0`<30000000000000
00000<30`00B0?ooo`040410@000000000000410@1h0oooo00@0@410000000000000@4107@3oool0
1020P800000000000010@40N0?ooo`040410@000000000000820P1D0oooo00@0`<30000000000000
`<30R03oool01020P800000000000010@402000000030410@03oool0oooo03D0oooo00260?ooo`04
0410@000000000000410@140oooo0P0000000`10@400oooo0?ooo`3o0?ooof40oooo00D0`<300000
0000000000000<30`00D0?ooo`040410@000000000000410@1h0oooo00@0P820000000000000@410
7@3oool01030`<00000000000010@40N0?ooo`040410@000000000000410@1D0oooo00@0@4100000
00000000`<30Q`3oool01@20P800000000000030`<00@4100080000000<0@4100?ooo`3oool0=03o
ool008L0oooo00@0P820000000000000@410403oool01020P800000000000020P83o0?ooof40oooo
00D0`<3000000000000000000<30`00F0?ooo`040820P000000000000410@1h0oooo00D0`<300000
0000000000000<30`00L0?ooo`050<30`0000000000000000030`<007@3oool01010@40000000000
0010@40D0?ooo`040<30`000000000000410@8P0oooo0P0000000`20P800oooo0820P00200000003
0410@03oool0oooo03<0oooo00280?ooo`040820P000000000000820P100oooo0`00003o0?ooof40
oooo0`00000I0?ooo`040820P00000000000000001h0oooo00@0P82000000000000000007@3oool0
1020P800000000000000000N0?ooo`<0000000<0P8200?ooo`3oool04`3oool2000000030820P03o
ool0oooo08D0oooo0P0000001020P800oooo0?ooo`20P803000003@0oooo00290?ooo`040410@000
000000000820P100oooo0P0000000`20P800oooo0?ooo`3o0?oooe`0oooo00D0`<30000000000000
00000<30`00J0?ooo`040410@000000000000410@1h0oooo00@0@410000000000000@4107@3oool0
1010@400000000000010@40N0?ooo`040410@000000000000820P1@0oooo00<0@41000000010@400
Q`3oool2000000050410@03oool0oooo0?ooo`10@4000P0000000`10@400oooo0?ooo`0a0?ooo`00
RP3oool01010@400000000000010@40?0?ooo`040<30`000000000000820P?l0ooooG03oool01@30
`<000000000000000000`<3001`0oooo00@0@410000000000000@4107P3oool01020P80000000000
0010@40M0?ooo`040820P000000000000410@1h0oooo00@0@410000000000000@4104`3oool01030
`<00000000000030`<270?ooo`800000103oool01010@400000000000010@40b0?ooo`00R`3oool0
1010@400000000000010@40?0?ooo`040820P000000000000<30`?l0ooooFP3oool00`30`<000000
00000002000000030410@03oool0oooo01/0oooo00@0P820000000000000@4107P3oool01@30`<00
0000000000000000`<3001`0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@0000000
00000410@1<0oooo00<0@41000000010@400Q`3oool2000000D0oooo00@0P820000000000000@410
<@3oool008`0oooo0`0000000`20P800oooo0?ooo`0=0?ooo`<00000o`3ooomJ0?ooo`H0000000<0
P8200?ooo`3oool06`3oool01020P800000000000000000N0?ooo`040820P00000000000000001d0
oooo00@0P82000000000000000007P3oool3000000030820P03oool0oooo0100oooo00<0P8200000
00000000Q`3oool2000000H0oooo00@0P8200000000000000000<03oool008d0oooo00@0@4100000
00000000P8203P3oool01020P800000000000020P83o0?oooeP0oooo00H0P820000000000000`<30
0?ooo`10@402000000030820P03oool0oooo01/0oooo00@0@410000000000000@4107P3oool01010
@400000000000010@40M0?ooo`040410@000000000000410@1h0oooo00@0@410000000000000P820
4P3oool3000008H0oooo00<0P82000000020P8001P3oool01010@400000000000010@40_0?ooo`00
SP3oool01010@400000000000010@40>0?ooo`040820P000000000000<30`?l0ooooEP3oool01010
@400000000000020P8030?ooo`040410@000000000000410@1d0oooo00@0@410000000000000@410
7P3oool01020P800000000000010@40M0?ooo`040820P000000000000410@1h0oooo00@0@4100000
00000000@4104@3oool01020P800000000000020P8250?ooo`030820P0000000P82000L0oooo00@0
@410000000000000@410;P3oool008l0oooo00@0@410000000000000@4103P3oool00`10@4000000
0410@03o0?oooeD0oooo00@0`<30000000000000@4101@3oool01010@400000000000010@40M0?oo
o`040820P000000000000410@1h0oooo00D0`<3000000000000000000<30`00L0?ooo`050<30`000
0000000000000030`<007@3oool01010@400000000000010@40A0?ooo`<00000Q@3oool00`20P800
00000410@0080?ooo`040820P000000000000410@2d0oooo002@0?ooo`<0000000<0P8200?ooo`3o
ool0303oool300000?l0ooooE03oool3000000L0oooo0`0000000`20P800oooo0?ooo`0K0?ooo`04
0820P000000000000820P1h0oooo00@0P82000000000000000007@3oool01020P800000000000000
000N0?ooo`<0000000<0P8200?ooo`3oool03P3oool00`20P8000000000000260?ooo`8000002@3o
ool01020P800000000000000000/0?ooo`00T@3oool01010@400000000000020P80=0?ooo`040410
@000000000000<30`?l0ooooDP3oool01020P800000000000020P8080?ooo`040410@00000000000
0820P1d0oooo00@0@410000000000000P8207P3oool01010@400000000000010@40M0?ooo`050410
@0000000000000000030`<007@3oool01010@400000000000020P80?0?ooo`040820P00000000000
0<30`8D0oooo0P00000:0?ooo`040410@000000000000410@2/0oooo002B0?ooo`040410@0000000
00000410@0d0oooo00<0@410000000000000o`3ooomA0?ooo`040820P000000000000<30`0X0oooo
00@0@410000000000000@4107@3oool01010@400000000000010@40N0?ooo`040820P00000000000
0410@1d0oooo00D0P8200410@000000000000820P00M0?ooo`040410@000000000000410@0l0oooo
0P0000000`20P800oooo0?ooo`230?ooo`8000002`3oool01010@400000000000010@40Z0?ooo`00
T`3oool01010@400000000000010@40<0?ooo`040<30`000000000000410@?l0ooooC`3oool01020
P800000000000010@40<0?ooo`040410@000000000000410@1d0oooo00@0@410000000000000@410
7P3oool01@30`<000000000000000000`<3001d0oooo00@0@410000000000000@4107@3oool01010
@400000000000010@40>0?ooo`80000000<0@4100?ooo`3oool0P`3oool00`20P80000000000000;
0?ooo`040820P000000000000410@2T0oooo002D0?ooo`<0000000<0P8200?ooo`3oool02`3oool2
00000?l0ooooC`3oool3000000h0oooo0`0000000`20P800oooo0?ooo`0K0?ooo`<0000000<0P820
0?ooo`3oool0703oool01020P800000000000000000N0?ooo`<0000000<0P8200?ooo`3oool06`3o
ool3000000030820P03oool0oooo00`0oooo0P0000250?ooo`030820P0000000000000`0oooo00@0
P8200000000000000000:03oool009D0oooo00@0@410000000000000P820303oool00`10@4000000
0410@03o0?ooodd0oooo00@0P820000000000000@4103`3oool01010@400000000000020P80M0?oo
o`040410@000000000000820P1h0oooo00@0@410000000000000@4107@3oool01@30`<0000000000
00000000`<3001d0oooo00@0@410000000000000P8203@3oool2000008D0oooo00<0P82000000000
00003@3oool01010@400000000000010@40W0?ooo`00UP3oool01010@400000000000010@40<0?oo
o`80000000<0P8200?ooo`3oool0o`3ooom:0?ooo`<000004@3oool01010@400000000000010@40M
0?ooo`040410@000000000000410@1h0oooo00@0P820000000000000@4107P3oool01010@4000000
00000020P80M0?ooo`040410@000000000000410@0`0oooo00<0@41000000020P800Q03oool00`20
P80000000000000>0?ooo`040410@000000000000410@2H0oooo002G0?ooo`040410@00000000000
0410@0/0oooo00@0`<30000000000000P820o`3ooom:0?ooo`030820P0000000@41001<0oooo00@0
@410000000000000@4107@3oool01010@400000000000010@40N0?ooo`050<30`000000000000000
0030`<007@3oool01010@400000000000010@40M0?ooo`040410@000000000000410@0/0oooo00<0
P82000000020P800Q@3oool2000000030820P03oool0oooo00`0oooo00@0P820000000000000@410
9@3oool009P0oooo0`0000000`20P800oooo0?ooo`090?ooo`<00000o`3ooom:0?ooo`80000000<0
P8200?ooo`3oool04P3oool3000000030820P03oool0oooo01/0oooo0`0000000`20P800oooo0?oo
o`0L0?ooo`040820P00000000000000001h0oooo0`0000000`20P800oooo0?ooo`0K0?ooo`<00000
00<0P8200?ooo`3oool0203oool00`20P80000000820P0250?ooo`80000000<0P8200?ooo`3oool0
3@3oool01020P800000000000000000T0?ooo`00V@3oool01010@400000000000020P80:0?ooo`04
0<30`000000000000820P?l0ooooB03oool00`20P80000000000000F0?ooo`040410@00000000000
0820P1d0oooo00@0@410000000000000P8207P3oool01010@400000000000010@40M0?ooo`050<30
`0000000000000000030`<007@3oool01010@400000000000020P8090?ooo`030820P0000000P820
08D0oooo0P0000000`20P800oooo0?ooo`0>0?ooo`040410@000000000000410@2<0oooo002J0?oo
o`040410@000000000000410@0/0oooo0P0000000`30`<00oooo0?ooo`3o0?oood@0oooo00@0`<30
000000000000P8205`3oool01010@400000000000010@40M0?ooo`040410@000000000000410@1h0
oooo00@0P820000000000000@4107P3oool01010@400000000000020P80M0?ooo`040410@0000000
00000410@0P0oooo00<0P82000000020P800Q@3oool2000000030820P03oool0oooo00l0oooo00@0
@410000000000000@4108P3oool009/0oooo00@0@410000000000000@4102P3oool00`30`<000000
0410@03o0?ooodH0oooo00<0@4100000000000006@3oool01010@400000000000010@40M0?ooo`04
0410@000000000000410@1h0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@0000000
00000410@1d0oooo00@0@410000000000000@4101`3oool00`30`<0000000410@0250?ooo`030410
@0000000@4100180oooo00@0P820000000000000@4108@3oool009`0oooo0`0000000`20P800oooo
0?ooo`080?ooo`<00000o`3ooom50?ooo`80000000<0P8200?ooo`3oool0603oool3000000030820
P03oool0oooo01/0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`040820P00000000000000001h0
oooo0`0000000`20P800oooo0?ooo`0K0?ooo`<0000000<0P8200?ooo`3oool01@3oool2000008D0
oooo00<0P8200000000000004`3oool01020P800000000000000000P0?ooo`00W@3oool01010@400
000000000020P8090?ooo`040<30`000000000000820P?l0oooo@`3oool01020P800000000000030
`<0K0?ooo`040410@000000000000820P1d0oooo00@0@410000000000000P8207P3oool01010@400
000000000010@40M0?ooo`050<30`0000000000000000030`<007@3oool01010@400000000000020
P8060?ooo`800000Q@3oool00`20P80000000000000D0?ooo`040410@000000000000410@1l0oooo
002N0?ooo`040410@000000000000410@0T0oooo00@0@410000000000000`<30o`3ooom20?ooo`03
0410@0000000P82001d0oooo00@0@410000000000000@4107@3oool01010@400000000000010@40N
0?ooo`040820P000000000000410@1h0oooo00@0@410000000000000P8207@3oool01010@4000000
00000010@4050?ooo`800000Q@3oool00`20P80000000000000E0?ooo`040410@000000000000410
@1h0oooo002O0?ooo`040410@000000000000410@0T0oooo0P0000000`10@400oooo0?ooo`3o0?oo
ocl0oooo00@0@410000000000000P8207P3oool01010@400000000000010@40M0?ooo`040410@000
000000000410@1h0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@000000000000410
@1d0oooo00@0@410000000000000@410103oool2000008D0oooo00<0P8200000000000005P3oool0
1020P800000000000010@40M0?ooo`00X03oool01020P800000000000010@4090?ooo`030410@000
0000P8200?l0oooo@03oool4000000030410@03oool0oooo01`0oooo00@0P820000000000000@410
7@3oool01020P800000000000010@40N0?ooo`050<30`0000000000000000030`<007@3oool01010
@400000000000010@40M0?ooo`040820P000000000000410@0<0oooo0P0000260?ooo`80000000<0
P8200?ooo`3oool0503oool01@30`<000000000000000000`<3001/0oooo002Q0?ooo`040820P000
00000000000000T0oooo0P00003o0?oood00oooo1@0000000`20P800oooo0?ooo`0L0?ooo`040820
P00000000000000001d0oooo00@0P82000000000000000007P3oool01020P800000000000000000N
0?ooo`<0000000<0P8200?ooo`3oool06`3oool01020P800000000000020P8020?ooo`800000QP3o
ool2000000030820P03oool0oooo01D0oooo00@0P82000000000000000006`3oool00:80oooo00@0
@410000000000000@410203oool00`10@40000000000003o0?oooch0oooo0P0000000`10@400`<30
00000002000000030<30`03oool0oooo01`0oooo00@0@410000000000000@4107@3oool01010@400
000000000010@40N0?ooo`040820P000000000000<30`1h0oooo00@0@410000000000000P8207@3o
ool01@10@400000000000020P800oooo00800000QP3oool2000000030820P03oool0oooo01H0oooo
00@0@410000000000000@4106P3oool00:<0oooo00@0@410000000000000@410203oool200000003
0410@03oool0oooo0?l0oooo>`3oool2000000040820P03oool0oooo0410@080000000<0P8200?oo
o`3oool0703oool01010@400000000000010@40M0?ooo`040410@000000000000410@1h0oooo00@0
P820000000000000P8207P3oool01010@400000000000010@40M0?ooo`040410@000000000000410
@0<00000Q@3oool2000000030820P03oool0oooo01L0oooo00@0P820000000000000@4106@3oool0
0:@0oooo00@0P820000000000000@4101`3oool01030`<00000000000030`<3o0?oooc/0oooo00@0
P820000000000000`<300`3oool01010@400000000000010@40N0?ooo`040820P000000000000410
@1d0oooo00@0P820000000000000@4107P3oool01010@400000000000010@40N0?ooo`040410@000
000000000410@1d0oooo00<0@4100000000000000`0000250?ooo`80000000<0@4100?ooo`3oool0
603oool00`30`<0000000000000I0?ooo`00Y@3oool01020P80000000000000000070?ooo`<00000
o`3ooolk0?ooo`030820P0000000000000D0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`040820
P00000000000000001d0oooo00@0P82000000000000000007P3oool3000000030820P03oool0oooo
01`0oooo0`0000000`20P800oooo0?ooo`0K0?ooo`D00000QP3oool2000001/0oooo00<0P8200000
003oool0603oool00:H0oooo00@0@410000000000000@4101`3oool00`10@40000000820P03o0?oo
ocX0oooo0P0000000`10@400oooo0?ooo`030?ooo`050<30`0000000000000000030`<007P3oool0
1010@400000000000010@40M0?ooo`040410@000000000000410@1d0oooo00D0`<30000000000000
00000<30`00N0?ooo`040410@000000000000820P1d0oooo00@0@4100000000000000000QP3oool2
000001`0oooo00<0@4100000003oool05`3oool008T0oooo00<0`<300?ooo`3oool06`3oool01010
@400000000000010@4060?ooo`040<30`000000000000820P?l0oooo>@3oool2000000030820P03o
ool0oooo00D0oooo00@0@410000000000000P8207P3oool01010@400000000000010@40M0?ooo`04
0410@000000000000410@1h0oooo00@0@410000000000000`<307P3oool01010@400000000000010
@40M0?ooo`<00000QP3oool2000001d0oooo00<0P8200?ooo`3oool05P3oool008T0oooo0P30`<0M
0?ooo`040820P000000000000410@0H0oooo00@0`<30000000000000P820o`3ooolg0?ooo`040820
P000000000000<30`0P0oooo00@0@410000000000000@4107P3oool01020P800000000000010@40M
0?ooo`040820P000000000000410@1h0oooo00@0@410000000000000P8207P3oool01010@4000000
00000010@40L0?ooo`<00000QP3oool2000000030<30`03oool0oooo03<0oooo002:0?ooo`030000
003oool0oooo01`0oooo00@0P82000000000000000001P3oool300000?l0oooo=`3oool00`20P800
00000000000:0?ooo`<0000000<0P8200?ooo`3oool0703oool01020P800000000000000000M0?oo
o`040820P00000000000000001h0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`<0000000<0P820
0?ooo`3oool06@3oool3000008H0oooo0`00000e0?ooo`00RP3oool00`30`<00@4100?ooo`0M0?oo
o`040410@000000000000410@0D0oooo00@0`<30000000000000@410o`3ooolf0?ooo`030820P000
0000000000X0oooo00D0`<3000000000000000000<30`00N0?ooo`040410@000000000000410@1d0
oooo00@0@410000000000000@4107@3oool01@30`<000000000000000000`<3001h0oooo00@0@410
000000000000P8206P3oool2000008L0oooo00D0P82000000000000000000<30`00c0?ooo`00R`3o
ool00`10@40000000<30`00M0?ooo`040410@000000000000410@0D0oooo00@0P820000000000000
`<30o`3ooole0?ooo`030820P0000000000000`0oooo00@0@410000000000000P8207P3oool01010
@400000000000010@40M0?ooo`040410@000000000000410@1d0oooo00D0`<300000000000000000
0<30`00N0?ooo`040410@000000000000410@1P0oooo00<0`<30000000000000Q`3oool00`20P800
000000000002000000030<30`03oool0oooo0300oooo002<0?ooo`80000000<0`<300?ooo`3oool0
6`3oool01020P800000000000010@4050?ooo`030820P000000000000?l0oooo=@3oool200000003
0820P03oool0oooo00/0oooo00@0@410000000000000@4107P3oool01020P800000000000010@40M
0?ooo`040820P000000000000410@1h0oooo00@0@410000000000000P8207P3oool01010@4000000
00000010@40G0?ooo`030820P0000000000008L0oooo00<0P82000000010@4000`0000000`30`<00
oooo0?ooo`0_0?ooo`00S@3oool2000001h0oooo00@0P82000000000000000001@3oool300000?l0
oooo=03oool2000000l0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`040820P000000000000000
01d0oooo00@0P82000000000000000007P3oool3000000030820P03oool0oooo01`0oooo0`000000
0`20P800oooo0?ooo`0D0?ooo`030820P0000000000008L0oooo00@0P82000000020P800oooo0`00
000a0?ooo`00S@3oool00`20P80000000410@00N0?ooo`040410@000000000000410@0@0oooo00@0
P820000000000000@410o`3ooolc0?ooo`8000003`3oool01@30`<000000000000000000`<3001h0
oooo00@0@410000000000000@4107@3oool01010@400000000000010@40M0?ooo`050<30`0000000
000000000030`<007P3oool01010@400000000000020P80E0?ooo`030820P0000000P82008L0oooo
00D0P82000000020P800oooo0<30`003000000030<30`03oool0oooo02d0oooo002>0?ooo`040410
@000000000000<30`1d0oooo00@0@410000000000000@410103oool01010@400000000000030`<3o
0?oooc80oooo0P00000A0?ooo`040410@000000000000820P1h0oooo00@0@410000000000000@410
7@3oool01010@400000000000010@40M0?ooo`050<30`0000000000000000030`<007P3oool01010
@400000000000010@40D0?ooo`030820P0000000P82008L0oooo00<0P82000000020P8000P3oool0
1@30`<000000000000000000`<3002h0oooo002?0?ooo`040410@000000000000<30`1d0oooo00@0
P820000000000000@410103oool3000000030<30`03oool0oooo0?l0oooo;`3oool200000180oooo
00@0@410000000000000@4107P3oool01020P800000000000010@40M0?ooo`040820P00000000000
0410@1h0oooo00@0@410000000000000P8207P3oool01010@400000000000010@40C0?ooo`030820
P0000000P82008L0oooo00<0P82000000020P8000`3oool01@30`<000000000000000000`<3002d0
oooo002@0?ooo`<000007P3oool01020P80000000000000000040?ooo`80000000<0P8200?ooo`3o
ool0o`3oool_0?ooo`8000004`3oool3000000030820P03oool0oooo01`0oooo00@0P82000000000
0000P8207@3oool01020P800000000000000000N0?ooo`<0000000<0P8200?ooo`3oool0703oool3
000000030820P03oool0oooo0100oooo00<0P82000000020P800Q`3oool00`20P80000000820P005
0?ooo`<00000;@3oool00940oooo00<0@41000000010@4007P3oool01010@400000000000010@403
0?ooo`040820P000000000000820P?l0oooo<03oool2000001<0oooo00D0`<300000000000000000
0<30`00N0?ooo`040410@000000000000820P1d0oooo00D0@410000000000000@4100<30`00L0?oo
o`050<30`0000000000000000030`<007P3oool01010@400000000000020P80A0?ooo`80000000<0
`<300?ooo`3oool0QP3oool2000000D0oooo00D0`<3000000000000000000<30`00[0?ooo`00TP3o
ool01010@400000000000030`<0M0?ooo`040410@000000000000410@0<0oooo0`0000000`30`<00
oooo0?ooo`3o0?ooobd0oooo0P00000E0?ooo`040410@000000000000820P1h0oooo00@0@4100000
00000000@4107@3oool01@10@4000000000000000000`<3001`0oooo00D0`<300000000000000000
0<30`00N0?ooo`040410@000000000000410@100oooo0P0000290?ooo`8000001P3oool01@30`<00
0000000000000000`<3002X0oooo002C0?ooo`040410@000000000000<30`1d0oooo00@0P8200000
00000000@4100P3oool01@30`<000000000000000000`<300?l0oooo;P3oool2000001H0oooo00@0
@410000000000000@4107P3oool01010@400000000000010@40N0?ooo`040410@000000000000820
P1d0oooo00@0@410000000000000P8207P3oool01010@400000000000010@40?0?ooo`800000R@3o
ool2000000L0oooo00D0`<3000000000000000000<30`00Y0?ooo`00U03oool3000001h0oooo00@0
P82000000000000000000P3oool3000000030820P03oool0oooo0?l0oooo;03oool2000001L0oooo
0`0000000`20P800oooo0?ooo`0L0?ooo`<0000000<0P8200?ooo`3oool0703oool3000000030820
P03oool0oooo01/0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`<0000000<0P8200?ooo`3oool0
303oool2000008T0oooo0P0000090?ooo`<00000:@3oool009D0oooo00<0@41000000010@4007P3o
ool01P10@400000000000010@400oooo0<30`0<0000000<0`<300?ooo`3oool0o`3oool[0?ooo`03
0410@0000000P82001H0oooo00D0`<3000000000000000000<30`00N0?ooo`040410@00000000000
0820P1d0oooo00D0`<3000000000000000000<30`00L0?ooo`050<30`0000000000000000030`<00
7P3oool01010@400000000000020P80<0?ooo`80000000<0@4100?ooo`3oool0Q`3oool2000000T0
oooo00D0`<3000000000000000000<30`00W0?ooo`00UP3oool01010@400000000000030`<0M0?oo
o`040410@000000000000410@080oooo0`00003o0?ooobd0oooo00<0P820000000000000603oool0
1010@400000000000020P80N0?ooo`040410@000000000000410@1d0oooo00D0`<30000000000000
00000<30`00L0?ooo`050<30`0000000000000000030`<007P3oool01010@400000000000010@40;
0?ooo`80000000<0P8200?ooo`3oool0Q`3oool2000000X0oooo00D0`<3000000000000000000<30
`00V0?ooo`00U`3oool01010@400000000000030`<0M0?ooo`060820P000000000000410@03oool0
`<300`0000000`30`<00oooo0?ooo`3o0?ooobT0oooo00<0P8200000000000006@3oool01010@400
000000000010@40N0?ooo`040410@000000000000410@1h0oooo00@0@410000000000000P8207@3o
ool01010@400000000000020P80N0?ooo`040410@000000000000410@0T0oooo00@0`<3000000000
0000P820R@3oool2000000/0oooo00D0`<3000000000000000000<30`00U0?ooo`00V03oool30000
01h0oooo00H0P82000000000000000000?ooo`20P80300000?l0oooo:`3oool00`20P80000000000
000J0?ooo`<0000000<0P8200?ooo`3oool0703oool3000000030820P03oool0oooo01`0oooo0`00
00000`20P800oooo0?ooo`0K0?ooo`<0000000<0P8200?ooo`3oool0703oool3000000030820P03o
ool0oooo00H0oooo00<0P820000000000000RP3oool2000000d0oooo0`00000U0?ooo`00V@3oool0
0`10@40000000410@00N0?ooo`050410@000000000000410@030`<000`0000000`30`<00oooo0?oo
o`3o0?ooobP0oooo00@0P820000000000000`<306@3oool01@30`<000000000000000000`<3001h0
oooo00@0@410000000000000P8207@3oool01@30`<000000000000000000`<3001`0oooo00D0`<30
00000000000000000<30`00N0?ooo`040410@000000000000820P0L0oooo00<0P820000000000000
RP3oool2000000d0oooo00D0`<3000000000000000000<30`00S0?ooo`00VP3oool01010@4000000
00000030`<0M0?ooo`050410@000000000000410@030`<000`00003o0?ooob/0oooo0P0000000`20
P800oooo0?ooo`0I0?ooo`040410@000000000000820P1h0oooo00@0@410000000000000@4107@3o
ool01@30`<000000000000000000`<3001`0oooo00D0`<3000000000000000000<30`00N0?ooo`04
0410@000000000000410@0H0oooo0P0000000`10@400oooo0?ooo`280?ooo`8000003P3oool01@30
`<000000000000000000`<300280oooo002K0?ooo`040410@000000000000<30`1d0oooo00D0P820
000000000000@4100820P002000000030410@03oool0oooo0?l0oooo:03oool2000000030820P03o
ool0oooo01X0oooo00@0@410000000000000@4107P3oool01010@400000000000010@40N0?ooo`04
0410@000000000000820P1d0oooo00@0@410000000000000P8207P3oool01010@400000000000010
@4040?ooo`040<30`000000000000820P8X0oooo0P00000?0?ooo`050<30`0000000000000000030
`<008@3oool009`0oooo0`00000N0?ooo`050820P0000000000000000020P8000P0000000`20P800
oooo0?ooo`3o0?ooobL0oooo00<0P8200000000000007@3oool3000000030820P03oool0oooo01`0
oooo0`0000000`20P800oooo0?ooo`0L0?ooo`<0000000<0P8200?ooo`3oool06`3oool300000003
0820P03oool0oooo01`0oooo0`0000001@20P800oooo0?ooo`3oool0P82000800000R`3oool00`20
P80000000000000@0?ooo`<000008@3oool009d0oooo00<0@41000000010@4007P3oool01010@400
000000000010@402000000030410@03oool0oooo0?l0oooo9`3oool01020P800000000000030`<0L
0?ooo`050<30`0000000000000000030`<007P3oool01010@400000000000020P80M0?ooo`050<30
`0000000000000000030`<00703oool01@30`<000000000000000000`<3001h0oooo00@0@4100000
00000000P8200P3oool00`20P80000000000002;0?ooo`030820P000000000000100oooo00D0`<30
00000000000000000<30`00O0?ooo`00WP3oool01010@400000000000030`<0M0?ooo`030410@000
0000000000@0000000<0`<300?ooo`3oool0o`3ooolU0?ooo`050820P0000000000000000030`<00
7@3oool01010@400000000000020P80N0?ooo`040410@000000000000410@1d0oooo00D0`<300000
0000000000000<30`00L0?ooo`050<30`0000000000000000030`<007P3oool01@10@40000000000
0010@400oooo0080000000<0P8200?ooo`3oool0R@3oool00`20P80000000000000A0?ooo`050<30
`0000000000000000030`<007P3oool009l0oooo00@0@410000000000000`<307@3oool00`20P800
000000000003000000030410@030`<00oooo0?l0oooo9P3oool4000000030820P03oool0oooo01/0
oooo00@0@410000000000000@4107P3oool01010@400000000000010@40N0?ooo`040410@0000000
00000820P1d0oooo00@0@410000000000000P8207P3oool01010@400000000000010@402000008`0
oooo00<0P8200000000000004P3oool01@30`<000000000000000000`<3001d0oooo002P0?ooo`<0
00007P3oool00`20P80000000000000400000?l0oooo:03oool4000000030820P03oool0oooo01/0
oooo0`0000000`20P800oooo0?ooo`0L0?ooo`<0000000<0P8200?ooo`3oool0703oool300000003
0820P03oool0oooo01/0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`@0000000<0P8200?ooo`3o
ool0RP3oool00`20P80000000000000D0?ooo`<000007@3oool00:40oooo00<0@41000000010@400
7P3oool00`10@400000000000003000000030<30`03oool0oooo0?l0oooo9@3oool00`10@4000000
00000002000000030<30`03oool0oooo01X0oooo00D0`<3000000000000000000<30`00N0?ooo`04
0410@000000000000820P1d0oooo00D0`<3000000000000000000<30`00L0?ooo`050<30`0000000
000000000030`<007P3oool01010@400000000000020P82<0?ooo`030820P0000000000001@0oooo
00D0`<3000000000000000000<30`00K0?ooo`00XP3oool01010@400000000000030`<0M0?ooo`03
0410@0000000000000<0000000<0P8200?ooo`3oool0o`3ooolT0?ooo`030<30`0000000000000<0
000000<0`<300?ooo`3oool06`3oool01010@400000000000020P80N0?ooo`040410@00000000000
0820P1d0oooo00D0`<3000000000000000000<30`00L0?ooo`050<30`0000000000000000030`<00
7@3oool00`30`<0000000000002=0?ooo`030820P0000000000001D0oooo00D0`<30000000000000
00000<30`00J0?ooo`00X`3oool01010@400000000000030`<0M0?ooo`030410@0000000000000<0
000000<0`<300?ooo`3oool0o`3ooolT0?ooo`040410@000000000000410@080000000<0P8200?oo
o`3oool06`3oool01010@400000000000010@40N0?ooo`040410@000000000000<30`1h0oooo00@0
@410000000000000P8207@3oool01010@400000000000020P80L0?ooo`030410@0000000P82008d0
oooo00<0P8200000000000005P3oool01@30`<000000000000000000`<3001T0oooo002T0?ooo`04
0820P000000000000<30`1d0oooo00<0P8200000000000000`0000000`30`<00oooo0?ooo`3o0?oo
ob<0oooo00D0`<30000000000000P8200410@002000000030410@03oool0oooo01/0oooo00@0@410
000000000000@4107@3oool01@30`<000000000000000000`<3001h0oooo00@0@410000000000000
@4107@3oool01010@400000000000010@40K0?ooo`80000000<0`<300?ooo`3oool0R`3oool00`20
P80000000000000H0?ooo`040410@000000000000820P1P0oooo002U0?ooo`030820P00000000000
01h0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`3o0?ooob@0oooo0P0000000`20
P800oooo00000002000000030820P03oool0oooo01/0oooo0`0000000`20P800oooo0?ooo`0L0?oo
o`<000007`3oool3000000030820P03oool0oooo01/0oooo0`0000000`20P800oooo0?ooo`0G0?oo
o`<00000SP3oool00`20P80000000000000I0?ooo`<0000000<0P8200?ooo`3oool05@3oool00:H0
oooo00@0@410000000000000`<307@3oool00`10@400000000000002000000030<30`03oool0oooo
0?l0oooo8`3oool01@20P80000000000003oool0`<3000<0000000<0`<300?ooo`3oool06`3oool0
1010@400000000000020P80M0?ooo`050<30`0000000000000000030`<007@3oool01@30`<000000
000000000000`<3001`0oooo00D0`<3000000000000000000<30`00H0?ooo`80000000<0P8200?oo
o`3oool0S03oool00`20P80000000000000I0?ooo`050<30`0000000000000000030`<005P3oool0
0:L0oooo00@0@410000000000000`<307@3oool00`10@40000000000000200000?l0oooo9P3oool2
000000040820P03oool0oooo0410@080000000<0P8200?ooo`3oool06`3oool01010@40000000000
0010@40M0?ooo`050<30`0000000000000000030`<007P3oool01010@400000000000030`<0M0?oo
o`040410@000000000000820P1H0oooo00@0P820000000000000`<30SP3oool00`20P80000000000
000J0?ooo`040<30`00000000000000001H0oooo002X0?ooo`040820P000000000000<30`1d0oooo
00<0P8200000000000000P0000000`30`<00oooo0?ooo`3o0?ooob<0oooo0P0000030?ooo`040410
@000000000000410@1d0oooo00@0@410000000000000@4107@3oool01@30`<000000000000000000
`<3001h0oooo00@0@410000000000000P8207@3oool01010@400000000000010@40E0?ooo`<00000
S`3oool00`20P80000000000000L0?ooo`030410@0000000oooo01D0oooo002Y0?ooo`030820P000
0000000001h0oooo00<0P8200000000000000P00003o0?ooobD0oooo00<0P82000000020P8000`3o
ool3000000030820P03oool0oooo01/0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`<000007`3o
ool3000000030820P03oool0oooo01/0oooo0`0000000`20P800oooo0?ooo`0B0?ooo`80000000<0
P8200?ooo`3oool0S@3oool00`20P80000000000000M0?ooo`030000003oool0oooo01@0oooo002Z
0?ooo`040410@000000000000<30`1d0oooo00D0@41000000000000000000<30`03o0?ooob@0oooo
00<0`<300000000000000`3oool01@30`<000000000000000000`<3001d0oooo00@0@41000000000
0000P8207@3oool01@30`<000000000000000000`<3001d0oooo00D0`<3000000000000000000<30
`00L0?ooo`050<30`0000000000000000030`<004P3oool01020P800000000000030`<2?0?ooo`03
0820P0000000000001d0oooo00<0`<300?ooo`3oool0503oool00:/0oooo00@0@410000000000000
`<307@3oool01@10@4000000000000000000`<300?l0oooo903oool01020P800000000000030`<03
0?ooo`040410@000000000000820P1d0oooo00@0@410000000000000@4107@3oool01@30`<000000
000000000000`<3001d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@00000000000
0820P140oooo0`00002@0?ooo`040820P000000000000410@3<0oooo002/0?ooo`040820P0000000
00000<30`1d0oooo00@0P820000000000000@410o`3ooolU0?ooo`030410@0000000@41000@0oooo
00@0@410000000000000@4107@3oool01010@400000000000010@40M0?ooo`050<30`00000000000
00000030`<007P3oool01010@400000000000020P80M0?ooo`040410@000000000000410@0l0oooo
00<0`<30000000000000T@3oool01@20P8000000000000000000@4100380oooo002]0?ooo`030820
P0000000000001h0oooo00@0P8200000000000000000o`3ooolT0?ooo`040820P000000000000820
P0@0oooo0`0000000`20P800oooo0?ooo`0K0?ooo`<0000000<0P8200?ooo`3oool0703oool30000
01l0oooo0`0000000`20P800oooo0?ooo`0K0?ooo`<0000000<0P8200?ooo`3oool0303oool00`20
P80000000000002A0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0;`3oool00:h0
oooo00@0@410000000000000`<307@3oool01010@400000000000010@43o0?ooob@0oooo00@0P820
000000000000`<300`3oool01@30`<000000000000000000`<3001d0oooo00@0@410000000000000
P8207@3oool01@30`<000000000000000000`<3001d0oooo00D0`<3000000000000000000<30`00L
0?ooo`050<30`0000000000000000030`<003@3oool2000000030820P03oool0oooo08l0oooo00@0
@41000000020P800@4100P0000000`20P800oooo0?ooo`0^0?ooo`00[`3oool01010@40000000000
0030`<0M0?ooo`040410@000000000000820P?l0oooo903oool00`20P8000000000000050?ooo`04
0410@000000000000820P1d0oooo00@0@410000000000000@4107@3oool01@30`<00000000000000
0000`<3001d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@000000000000820P0/0
oooo0`00002B0?ooo`8000000P3oool01010@400000000000010@40_0?ooo`00/03oool01020P800
000000000030`<0M0?ooo`040820P000000000000<30`?l0oooo903oool01010@400000000000030
`<040?ooo`040410@000000000000410@1d0oooo00@0@410000000000000@4107@3oool01@30`<00
0000000000000000`<3001h0oooo00@0@410000000000000P8207@3oool01010@400000000000010
@4090?ooo`040820P000000000000820P980oooo0P0000030?ooo`040410@000000000000410@2h0
oooo002a0?ooo`030820P0000000000001h0oooo0`00003o0?ooobD0oooo0`0000050?ooo`<00000
00<0P8200?ooo`3oool06`3oool3000000030820P03oool0oooo01`0oooo0`00000O0?ooo`<00000
00<0P8200?ooo`3oool06`3oool3000000030820P03oool0oooo00H0oooo0`00002C0?ooo`800000
103oool3000000030820P03oool0oooo02/0oooo002b0?ooo`040410@000000000000<30`1`0oooo
00D0`<3000000000000000000<30`03o0?ooob<0oooo00@0@410000000000000@410103oool01@30
`<000000000000000000`<3001d0oooo00@0@410000000000000`<307@3oool01@30`<0000000000
00000000`<3001d0oooo00D0`<3000000000000000000<30`00L0?ooo`050<30`000000000000000
0030`<001P3oool01030`<00000000000010@42C0?ooo`8000001@3oool01010@400000000000020
P80/0?ooo`00/`3oool01010@400000000000030`<0L0?ooo`040<30`000000000000410@?l0oooo
903oool01020P800000000000010@4050?ooo`040410@000000000000820P1d0oooo00D0@4100000
0000000000000<30`00L0?ooo`050<30`0000000000000000030`<007@3oool01@30`<0000000000
00000000`<3001d0oooo00@0@410000000000000P8201@3oool01010@400000000000030`<2C0?oo
o`8000001P3oool01010@400000000000010@40[0?ooo`00]03oool01020P800000000000030`<0L
0?ooo`040<30`000000000000410@?l0oooo903oool01@30`<000000000000000000`<3000@0oooo
00@0@410000000000000@4107@3oool01@20P8000000000000000000`<3001`0oooo00D0`<300000
0000000000000<30`00N0?ooo`040410@000000000000820P1d0oooo00@0@410000000000000@410
0`3oool01020P800000000000020P82D0?ooo`8000001`3oool01010@400000000000010@40Z0?oo
o`00]@3oool00`20P80000000000000N0?ooo`80000000<0P8200?ooo`3oool0o`3ooolR0?ooo`04
0820P00000000000000000D0oooo0`0000000`20P800oooo0?ooo`0K0?ooo`040820P00000000000
000001h0oooo0`00000O0?ooo`<0000000<0P8200?ooo`3oool06`3oool3000000030820P03oool0
oooo0080000000<0P8200?ooo`3oool0T`3oool2000000P0oooo0`0000000`20P800oooo0?ooo`0W
0?ooo`00]P3oool01010@400000000000030`<0L0?ooo`030410@000000000000?l0oooo9@3oool0
1010@400000000000010@4040?ooo`050<30`0000000000000000030`<007@3oool01020P8000000
00000010@40M0?ooo`050<30`0000000000000000030`<007@3oool01@30`<000000000000000000
`<3001`0oooo00H0`<3000000000000000000<30`020P802000000030<30`03oool0oooo09<0oooo
0P0000090?ooo`040410@000000000000820P2P0oooo002g0?ooo`040410@000000000000<30`1`0
oooo00@0@410000000000000`<30o`3ooolT0?ooo`040820P000000000000410@0D0oooo00@0@410
000000000000P8207@3oool01@30`<000000000000000000`<3001`0oooo00D0`<30000000000000
00000<30`00M0?ooo`050<30`0000000000000000030`<007@3oool00`10@4000000000000020000
00030410@03oool0oooo09@0oooo0P00000:0?ooo`040410@000000000000410@2L0oooo002h0?oo
o`040820P000000000000<30`1`0oooo00@0@410000000000000`<30o`3ooolT0?ooo`050<30`010
@400000000000010@400103oool01010@400000000000010@40M0?ooo`050<30`000000000000000
0030`<00703oool01@30`<000000000000000000`<3001h0oooo00@0@410000000000000P8207@3o
ool01@10@4000000000000000000`<3009H0oooo0P00000;0?ooo`040410@000000000000410@2H0
oooo002i0?ooo`030820P0000000000001d0oooo0`00003o0?ooobH0oooo0`0000000`20P800oooo
0?ooo`020?ooo`<0000000<0P8200?ooo`3oool06`3oool01020P800000000000000000N0?ooo`<0
00007`3oool3000000030820P03oool0oooo01X0oooo00@0P8200000000000000000U`3oool20000
00`0oooo0`0000000`20P800oooo0?ooo`0S0?ooo`00^P3oool01010@400000000000030`<0L0?oo
o`80000000<0`<300?ooo`3oool0o`3ooolS0?ooo`050<30`0000000000000000020P8000`3oool0
1@30`<000000000000000000`<3001d0oooo00@0P820000000000000@4107@3oool01@30`<000000
000000000000`<3001d0oooo00D0`<3000000000000000000<30`00K0?ooo`040410@00000000000
0<30`9L0oooo0P00000=0?ooo`040410@000000000000820P2@0oooo002k0?ooo`040410@0000000
00000<30`1/0oooo00@0`<30000000000000P820o`3ooolV0?ooo`050<30`0000000000000000020
P8000`3oool01010@400000000000020P80M0?ooo`050<30`0000000000000000030`<00703oool0
1@30`<000000000000000000`<3001d0oooo00D0`<3000000000000000000<30`00I0?ooo`040<30
`000000000000820P9P0oooo0P00000>0?ooo`040410@000000000000410@2<0oooo002l0?ooo`04
0820P000000000000<30`1/0oooo00@0P820000000000000@410o`3ooolV0?ooo`030<30`0000000
00000080000000@0`<300?ooo`3oool0@4100P0000000`10@400oooo0?ooo`0K0?ooo`050<30`000
0000000000000030`<00703oool01@30`<000000000000000000`<3001h0oooo00@0@41000000000
0000P820603oool00`10@40000000410@02I0?ooo`8000003`3oool01010@400000000000010@40R
0?ooo`00_@3oool00`20P80000000000000L0?ooo`<0000000<0P8200?ooo`3oool0o`3ooolT0?oo
o`030820P00000000000008000000`3oool3000000030820P03oool0oooo01/0oooo00@0P8200000
0000000000007P3oool3000001l0oooo0`0000000`20P800oooo0?ooo`0D0?ooo`<0000000<0P820
0?ooo`3oool0U`3oool200000100oooo0`0000000`20P800oooo0?ooo`0O0?ooo`00_P3oool01010
@400000000000030`<0J0?ooo`040<30`0000000000000000?l0oooo:03oool01`10@40000000000
00000000@4100?ooo`30`<000`0000000`30`<00oooo0?ooo`0K0?ooo`040820P000000000000410
@1d0oooo00D0`<3000000000000000000<30`00M0?ooo`050<30`0000000000000000030`<00503o
ool01030`<00000000000010@42J0?ooo`8000004@3oool01010@400000000000020P80P0?ooo`00
_`3oool01010@400000000000030`<0K0?ooo`030410@0000000@4100?l0oooo:03oool02030`<00
0000000000000000@4100<30`03oool0@4100P0000000`20P800oooo0?ooo`0K0?ooo`050<30`000
0000000000000030`<00703oool01@30`<000000000000000000`<3001d0oooo00D0`<3000000000
000000000<30`00B0?ooo`040<30`00000000000000009X0oooo00<0`<3000000010@4004P3oool0
1010@400000000000010@40O0?ooo`00`03oool01020P800000000000030`<0J0?ooo`050<30`000
0000000000000030`<00o`3ooolX0?ooo`070820P0000000000000000020P800`<300410@0020000
00030410@03oool0oooo01/0oooo00D0`<3000000000000000000<30`00L0?ooo`050<30`0000000
000000000030`<007P3oool01010@400000000000020P80A0?ooo`040410@000000000000<30`9X0
oooo00<0P82000000020P8004`3oool01010@400000000000010@40N0?ooo`00`@3oool00`20P800
00000000000K0?ooo`040820P0000000000000000?l0oooo:P3oool4000000050820P00000000000
00000020P8007@3oool01020P800000000000000000N0?ooo`<000007`3oool3000000030820P03o
ool0oooo00d0oooo00<0P820000000000000W03oool00`20P80000000820P00D0?ooo`<0000000<0
P8200?ooo`3oool06`3oool00<80oooo00<0@41000000010@4006`3oool01010@400000000000010
@43o0?ooobT0oooo00<0`<300410@00000001P0000000`30`<00oooo0?ooo`0K0?ooo`040820P000
000000000410@1d0oooo00D0`<3000000000000000000<30`00M0?ooo`050<30`000000000000000
0030`<003P3oool00`10@40000000820P02L0?ooo`030820P0000000P82001D0oooo00@0@4100000
00000000P820703oool00<<0oooo00@0@410000000000000`<306P3oool01020P800000000000010
@43o0?ooob/0oooo00<0@410000000000000100000000`20P800oooo0?ooo`0K0?ooo`050<30`000
0000000000000030`<00703oool01@30`<000000000000000000`<3001d0oooo00D0`<3000000000
000000000<30`00;0?ooo`040<30`000000000000410@9d0oooo00<0P82000000020P8005P3oool0
1010@400000000000010@40K0?ooo`00a03oool01010@400000000000030`<0J0?ooo`040<30`000
0000000000000?l0oooo:`3oool00`30`<00@41000000004000000030<30`03oool0oooo01/0oooo
00D0`<3000000000000000000<30`00L0?ooo`050<30`0000000000000000030`<007P3oool01010
@400000000000020P8090?ooo`040<30`000000000000410@9h0oooo00<0P82000000020P8005`3o
ool01010@400000000000010@40J0?ooo`00a@3oool3000001/0oooo00@0P820000000000000P820
o`3oool]0?ooo`D000007P3oool01020P800000000000000000N0?ooo`<000007`3oool300000003
0820P03oool0oooo00H0oooo0`00002O0?ooo`030820P0000000P82001P0oooo0`0000000`20P800
oooo0?ooo`0G0?ooo`00aP3oool00`10@40000000410@00K0?ooo`<0000000<0`<300?ooo`3oool0
o`3ooolZ0?ooo`030<30`010@400000000<0000000<0P8200?ooo`3oool06`3oool01020P8000000
00000010@40M0?ooo`050<30`0000000000000000030`<007@3oool01@30`<000000000000000000
`<3000H0oooo00<0@41000000010@400X03oool00`20P80000000820P00I0?ooo`040410@0000000
00000820P1P0oooo00370?ooo`040410@000000000000<30`1T0oooo00D0`<300000000000000000
0<30`03o0?ooobd0oooo00<0`<300820P010@4000`0000000`10@400`<300?ooo`0J0?ooo`050<30
`0000000000000000030`<00703oool01@30`<000000000000000000`<3001d0oooo00D0`<300000
0000000000000<30`0030?ooo`050<30`0000000000000000030`<00X03oool00`20P80000000820
P00J0?ooo`040410@000000000000410@1L0oooo00380?ooo`040410@000000000000<30`1X0oooo
00@0@410000000000000P820o`3oool_0?ooo`030<30`010@40000000080000000<0@4100820P03o
ool06@3oool01@30`<000000000000000000`<3001`0oooo00D0`<3000000000000000000<30`00N
0?ooo`060410@000000000000820P03oool0`<300`0000000`30`<00oooo0?ooo`2O0?ooo`030820
P0000000P82001/0oooo00@0@410000000000000@4105P3oool00<T0oooo00@0P820000000000000
`<306P3oool01010@400000000000010@43o0?oooc40oooo00<0P8200410@00000000P0000000`10
@400P8200?ooo`0G0?ooo`050<30`0000000000000000030`<007@3oool01010@400000000000030
`<0N0?ooo`040410@000000000000410@0<0000000<0`<300?ooo`3oool0X03oool00`20P8000000
0820P00L0?ooo`030820P0000000000001H0oooo003:0?ooo`030820P0000000000001/0oooo0`00
00000`20P800oooo0?ooo`3o0?oooc00oooo00<0P8200000000000001000000H0?ooo`<000007P3o
ool3000001l0oooo1@00002T0?ooo`030820P0000000P82001d0oooo00<0P8200000003oool05@3o
ool00</0oooo00@0@410000000000000`<306@3oool01@30`<000000000000000000`<300?l0oooo
<`3oool00`20P800@41000000003000000030820P030`<00oooo01@0oooo00D0`<30000000000000
00000<30`00L0?ooo`050<30`0000000000000000030`<007@3oool01@10@4000000000000000000
`<300:@0oooo00<0@41000000010@4007P3oool00`10@400oooo0?ooo`0D0?ooo`00c03oool01010
@400000000000030`<0J0?ooo`040410@000000000000820P?l0oooo=03oool00`30`<00P8200410
@004000000030410@020P800oooo0180oooo00D0`<3000000000000000000<30`00L0?ooo`050<30
`0000000000000000030`<006`3oool01@10@400000000000010@400`<300:D0oooo100000000`30
`<00oooo0?ooo`0a0?ooo`00c@3oool01020P800000000000030`<0J0?ooo`040410@00000000000
0820P?l0oooo=P3oool00`30`<00P8200000000400000080P8204@3oool01@30`<00000000000000
0000`<3001`0oooo00D0`<3000000000000000000<30`00H0?ooo`050820P0000000000000000020
P800Y`3oool5000000030<30`03oool0oooo0300oooo003>0?ooo`030820P0000000000001/0oooo
0`00003o0?ooocT0oooo1`0000000`20P800oooo0?ooo`0?0?ooo`<000007P3oool3000001L0oooo
100000000`20P800oooo0?ooo`2V0?ooo`80000000@0P8200000000000000000<P3oool00<l0oooo
00@0@410000000000000`<306@3oool01020P800000000000010@43o0?ooocX0oooo00<0`<300410
@0000000100000000`10@400`<300?ooo`0=0?ooo`050<30`0000000000000000030`<00703oool0
1@30`<000000000000000000`<3001<0oooo00H0`<3000000000000000000410@030`<2Y0?ooo`80
000000D0oooo0820P000000000000410@00a0?ooo`00d03oool01010@400000000000030`<0I0?oo
o`040820P000000000000410@?l0oooo?03oool00`30`<00P8200000000400000080P82000<0`<30
0?ooo`3oool02@3oool01@30`<000000000000000000`<3001`0oooo00D0`<300000000000000000
0<30`00?0?ooo`030820P000000000000080000000<0@4100820P03oool0ZP3oool200000080oooo
00D0`<3000000000000000000<30`00_0?ooo`00d@3oool01020P800000000000030`<0I0?ooo`05
0<30`0000000000000000030`<00o`3oooln0?ooo`030820P0000000000000@000000P20P8000`30
`<00oooo0?ooo`060?ooo`050<30`0000000000000000030`<00703oool01@30`<00000000000000
0000`<3000X0oooo00<0`<300820P00000001@0000000`20P800oooo0?ooo`2[0?ooo`8000000`3o
ool01@30`<000000000000000000`<3002h0oooo003B0?ooo`030820P0000000000001X0oooo00@0
P8200000000000000000o`3ooom00?ooo`030820P0000000000000H000002@3oool3000001h0oooo
0`0000070?ooo`030820P0000000000000H00000/03oool2000000@0oooo00@0P820000000000000
0000;P3oool00=<0oooo00@0@410000000000000`<306@3oool01010@400000000000010@43o0?oo
od80oooo00<0P8200410@00000001@0000000`10@400P8200820P0020820P1<000004020P8001010
@40000000000000000030820P0T0000000<0@4100<30`03oool0/03oool2000000D0oooo00@0P820
000000000000@410;@3oool00=@0oooo00@0@410000000000000`<306@3oool01020P80000000000
0010@43o0?ooodD0oooo00<0P8200410@0000000<`0000001@10@400P8200820P020P800`<300;@0
oooo0P0000060?ooo`050<30`0000000000000000030`<00:`3oool00=D0oooo00@0P82000000000
0000`<306@3oool01@30`<000000000000000000`<300?l0ooooA`3oool00`20P800@4100820P005
0820P0030<30`03oool0oooo00d0oooo5`20P82l0?ooo`8000001`3oool01@30`<00000000000000
0000`<3002X0oooo003F0?ooo`030820P0000000000001X0oooo00D0P82000000000000000000820
P03o0?ooool0oooo<P3oool2000000P0oooo00@0P8200000000000000000:P3oool00=L0oooo00@0
@410000000000000`<306@3oool01@10@4000000000000000000`<300?l0ooooo`3ooola0?ooo`80
00002@3oool01020P800000000000010@40Y0?ooo`00f03oool01010@400000000000030`<0J0?oo
o`040410@000000000000820P?l0ooooo`3oool_0?ooo`80000000<0P8200?ooo`3oool0203oool0
1@30`<000000000000000000`<3002L0oooo003I0?ooo`040820P000000000000<30`1X0oooo00@0
@410000000000000@410o`3ooooo0?ooobh0oooo0P0000000`20P800oooo0?ooo`090?ooo`050<30
`0000000000000000030`<009P3oool00=X0oooo00<0P8200000000000006`3oool3000000030820
P03oool0oooo0?l0ooooo`3oool[0?ooo`80000000<0P8200?ooo`3oool02P3oool01020P8000000
00000000000V0?ooo`00f`3oool01010@400000000000030`<0I0?ooo`050<30`000000000000000
0030`<00o`3ooooo0?ooob`0oooo0P0000000`20P800oooo0?ooo`0;0?ooo`040820P00000000000
0410@2D0oooo003L0?ooo`040410@000000000000<30`1X0oooo00D0@41000000000000000000<30
`03o0?ooool0oooo:P3oool2000000030820P03oool0oooo00`0oooo00D0`<300000000000000000
0<30`00S0?ooo`00g@3oool01020P800000000000030`<0J0?ooo`050820P0000000000000000030
`<00o`3ooooo0?ooobT0oooo0P0000000`20P800oooo0?ooo`0=0?ooo`050<30`000000000000000
0030`<008P3oool00=h0oooo00<0P8200000000000006`3oool01020P800000000000000003o0?oo
ool0oooo:@3oool2000000030820P03oool0oooo00h0oooo00@0P82000000000000000008P3oool0
0=l0oooo00@0@410000000000000`<306P3oool01020P800000000000010@43o0?ooool0oooo:03o
ool2000000030820P03oool0oooo00l0oooo00@0P820000000000000@4108@3oool00>00oooo00@0
@410000000000000`<306P3oool01@30`<000000000000000000P8200?l0ooooo`3ooolV0?ooo`80
000000<0P8200?ooo`3oool0403oool01@30`<000000000000000000`<3001l0oooo003Q0?ooo`04
0820P000000000000<30`1X0oooo00D0`<300410@000000000000410@03o0?ooool0oooo903oool0
1030`<00000000000030`<0C0?ooo`050<30`0000000000000000030`<007P3oool00>80oooo00<0
P820000000000000703oool3000000030820P03oool0oooo0?l0ooooo`3ooolQ0?ooo`030820P000
0000000001D0oooo00@0P82000000000000000007P3oool00><0oooo00@0@410000000000000`<30
6P3oool01@30`<000000000000000000P8200?l0ooooo`3ooolR0?ooo`030820P0000000000001H0
oooo00@0P820000000000000@4107@3oool00>@0oooo00@0@410000000000000`<306`3oool01@10
@4000000000000000000`<300?l0ooooo`3ooolP0?ooo`030820P0000000000001L0oooo00D0`<30
00000000000000000<30`00K0?ooo`00i@3oool01020P800000000000030`<0K0?ooo`050<30`000
0000000000000030`<00o`3ooooo0?oooal0oooo00<0P820000000000000603oool01@30`<000000
000000000000`<3001X0oooo003V0?ooo`030820P0000000000001`0oooo00@0P820000000000000
0000o`3ooooo0?oooal0oooo00<0P8200000000000006@3oool01020P800000000000000000J0?oo
o`00i`3oool01010@400000000000030`<0K0?ooo`050820P0000000000000000020P800o`3ooooo
0?oooad0oooo00<0P8200000000000006P3oool01020P800000000000010@40I0?ooo`00j03oool0
1010@400000000000030`<0K0?ooo`060<30`010@400000000000010@400`<30o`3ooooo0?oooa/0
oooo0P0000000`20P800oooo0?ooo`0I0?ooo`050<30`0000000000000000030`<005`3oool00>T0
oooo00@0P820000000000000`<30703oool01@10@4000000000000000000@4100?l0ooooo`3ooolJ
0?ooo`80000000<0P8200?ooo`3oool06P3oool01030`<00000000000000000G0?ooo`00jP3oool0
0`20P80000000000000M0?ooo`D0000000<0P8200?ooo`3oool0o`3ooooo0?oooaH0oooo0P000000
0`20P800oooo0?ooo`0K0?ooo`030820P0000000000001L0oooo003[0?ooo`040410@00000000000
0<30`1`0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`3o0?ooool0oooo5@3oool3
000000030<30`03oool0oooo01/0oooo00<0P8200000003oool05P3oool00>`0oooo00@0@4100000
00000000`<307@3oool01P10@4000000000000000000@4100820P?l0ooooo`3ooolE0?ooo`@00000
00<0`<300?ooo`3oool06`3oool00`30`<00oooo0?ooo`0E0?ooo`00k@3oool01020P80000000000
0030`<0M0?ooo`030820P000000000000080000000<0@4100?ooo`3oool0o`3ooooo0?oooa80oooo
1@0000000`20P800oooo0?ooo`0b0?ooo`00kP3oool00`20P80000000000000N0?ooo`030820P000
0000000000<00000o`3ooooo0?oooa<0oooo0P0000001@20P8000000000000000000P82003<0oooo
003_0?ooo`040410@000000000000<30`1d0oooo00<0@4100000000000000P0000000`10@400P820
0?ooo`3o0?ooool0oooo3`3oool01@20P80000000000003oool0`<3000<0000000<0`<300?ooo`3o
ool0<03oool00?00oooo00@0@410000000000000`<307@3oool00`10@40000000000000300000003
0410@030`<00oooo0?l0ooooo`3oool=0?ooo`030820P000000000000080oooo00D0`<3000000000
000000000<30`00a0?ooo`00l@3oool01020P800000000000030`<0M0?ooo`030820P00000000000
00@0000000<0P8200?ooo`3oool0o`3ooooo0?ooo`/0oooo00<0P820000000000000103oool01010
@400000000000020P80`0?ooo`00lP3oool01030`<00000000000020P80M0?ooo`050<30`0000000
000000000010@4000`0000000`10@400`<300?ooo`3o0?ooool0oooo2@3oool00`20P80000000000
00050?ooo`040410@000000000000410@2l0oooo003c0?ooo`040820P000000000000820P1d0oooo
00D0P82000000000000000000?ooo`04000000030820P03oool0oooo0?l0ooooo`3oool70?ooo`03
0820P0000000000000H0oooo0`0000000`20P800oooo0?ooo`0/0?ooo`00m03oool01010@4000000
00000030`<0M0?ooo`070410@000000000000410@03oool0P8200410@003000000030820P030`<00
oooo0?l0ooooo`3oool50?ooo`030820P0000000000000H0oooo00D0`<3000000000000000000<30
`00]0?ooo`00m@3oool01020P800000000000030`<0M0?ooo`040820P000000000000410@080oooo
00<0`<300410@00000000P0000000`10@400P8200?ooo`3o0?ooool0oooo0`3oool00`10@4000000
0820P0080?ooo`040410@000000000000820P2`0oooo003f0?ooo`040<30`000000000000820P1d0
oooo00D0`<3000000000000000000<30`0030?ooo`030410@000000000000080000000<0P8200?oo
o`3oool0o`3ooooo0?ooo`8000002P3oool01010@400000000000010@40[0?ooo`00m`3oool01020
P800000000000020P80M0?ooo`040820P00000000000000000@0oooo00<0P8200000000000000`00
003o0?ooool0oooo0@3oool2000000/0oooo0`0000000`20P800oooo0?ooo`0X0?ooo`00n03oool0
1010@400000000000030`<0M0?ooo`040410@000000000000410@0@0oooo00<0`<300820P0000000
0`0000000`10@400`<300?ooo`3o0?oooo`0oooo0P00000;0?ooo`050<30`0000000000000000030
`<00:@3oool00?T0oooo00@0P820000000000000`<307@3oool01020P800000000000010@4060?oo
o`030820P0000000000000<0000000<0P8200<30`03oool0o`3ooooi0?ooo`8000003@3oool01010
@400000000000020P80X0?ooo`00nP3oool01030`<00000000000020P80M0?ooo`050<30`0000000
000000000030`<001P3oool20820P0@0000000<0@4100820P03oool0o`3oooog0?ooo`8000003P3o
ool01010@400000000000010@40W0?ooo`00n`3oool01020P800000000000020P80M0?ooo`040820
P00000000000000000T0oooo1P0000000`20P800oooo0?ooo`3o0?oooo@0oooo0P00000?0?ooo`<0
000000<0P8200?ooo`3oool0903oool00?`0oooo00@0@410000000000000`<307@3oool01010@400
000000000010@40:0?ooo`030820P010@400000000<0000000<0P8200?ooo`3oool0o`3ooooa0?oo
o`030<30`0000000000000l0oooo00D0`<3000000000000000000<30`00U0?ooo`00o@3oool01020
P800000000000030`<0M0?ooo`040820P000000000000410@0`0oooo00<0P8200410@00000000P00
00000`10@400P8200?ooo`3o0?ooonl0oooo00<0P8200000000000004@3oool01010@40000000000
0020P80T0?ooo`00oP3oool01030`<00000000000030`<0M0?ooo`050<30`0000000000000000030
`<003@3oool20820P0<000000P20P83o0?ooond0oooo00<0P8200000000000004P3oool01010@400
000000000010@40S0?ooo`00o`3oool00`20P80000000000000N0?ooo`040820P000000000000000
0100oooo1@0000000`20P800oooo0?ooo`3o0?ooonT0oooo00<0P8200000000000004`3oool30000
00030820P03oool0oooo0200oooo003o0?ooo`40oooo00@0@410000000000000`<307@3oool01010
@400000000000010@40@0?ooo`030<30`020P800@41000<000000P20P83o0?ooonP0oooo00<0P820
00000010@4004`3oool01@30`<000000000000000000`<300240oooo003o0?ooo`80oooo00@0@410
000000000000`<307@3oool01020P800000000000010@40B0?ooo`030<30`020P800000000<00000
00<0@4100820P030`<00o`3ooooT0?ooo`030820P0000000P82001D0oooo00@0@410000000000000
P820803oool00?l0oooo0`3oool01020P800000000000030`<0M0?ooo`050<30`000000000000000
0030`<00503oool00`20P800@4100000000300000080P820o`3ooooQ0?ooo`030820P0000000P820
01H0oooo00@0@410000000000000@4107`3oool00?l0oooo103oool00`20P80000000000000N0?oo
o`040820P00000000000000001H0oooo00<0P820000000000000100000000`20P800oooo0?ooo`3o
0?ooomd0oooo00<0P82000000020P8005`3oool3000000030820P03oool0oooo01`0oooo003o0?oo
o`D0oooo00@0@410000000000000`<307@3oool01010@400000000000010@40G0?ooo`030<30`020
P800000000@0000000<0P8200<30`03oool0o`3ooooK0?ooo`80000000<0P8200?ooo`3oool05@3o
ool01@30`<000000000000000000`<3001d0oooo003o0?ooo`H0oooo00@0@410000000000000`<30
7@3oool01020P800000000000010@40I0?ooo`80P8201@0000020820P?l0oooof@3oool200000003
0820P03oool0oooo01L0oooo00@0@410000000000000P820703oool00?l0oooo1`3oool01020P800
000000000030`<0M0?ooo`050<30`0000000000000000030`<006P3oool00`30`<00P82000000004
000000030410@030`<00oooo0?l0ooooe@3oool2000000030820P03oool0oooo01P0oooo00@0@410
000000000000@4106`3oool00?l0oooo203oool00`20P80000000000000N0?ooo`040820P0000000
0000000001d0oooo00<0P820000000000000100000000`20P800oooo0?ooo`3o0?ooom80oooo00<0
P82000000020P8006`3oool3000000030820P03oool0oooo01P0oooo003o0?ooo`T0oooo00@0@410
000000000000`<307@3oool01010@400000000000010@40M0?ooo`030<30`0000000000000D00000
00<0P8200?ooo`3oool0o`3oooo@0?ooo`80000000<0`<300?ooo`3oool06@3oool01@30`<000000
000000000000`<3001T0oooo003o0?ooo`X0oooo00@0@410000000000000`<307@3oool01020P800
000000000010@40N0?ooo`030410@0000000000000H0000000<0P8200?ooo`3oool0o`3oooo=0?oo
o`8000007P3oool00`10@40000000820P00I0?ooo`00o`3oool;0?ooo`040820P000000000000<30
`1d0oooo00D0`<3000000000000000000<30`00M0?ooo`050410@000000000000410@020P8001P00
00000`20P800oooo0?ooo`3o0?ooolT0oooo00@0P820000000000000@4107P3oool00`10@400P820
0?ooo`0H0?ooo`00o`3oool<0?ooo`030820P0000000000001h0oooo00@0P8200000000000000000
7P3oool3000000030820P03oool0oooo00H00000o`3oooo:0?ooo`D000007P3oool00`20P800oooo
0?ooo`0G0?ooo`00o`3oool=0?ooo`040410@000000000000<30`1d0oooo00@0@410000000000000
@4107@3oool01@30`<000000000000000000`<300080oooo00<0P8200410@0000000100000000`20
P800oooo0?ooo`3o0?ooolD0oooo1@0000000`10@400oooo0?ooo`0e0?ooo`00o`3oool>0?ooo`04
0410@000000000000<30`1d0oooo00@0P820000000000000@4107P3oool01010@400000000000020
P8040?ooo`030820P010@400000000<0000000<0@4100820P03oool0o`3oooo20?ooo`050<30`000
000000000820P010@4000P0000000`10@400oooo0?ooo`0d0?ooo`00o`3oool?0?ooo`040820P000
000000000<30`1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@000000000000410
@0D0oooo00<0`<300820P010@400100000000`20P800`<300?ooo`3o0?oookl0oooo00<0P8200000
000000000P3oool01020P800000000000010@40e0?ooo`00o`3oool@0?ooo`030820P00000000000
01h0oooo00@0P82000000000000000007P3oool3000000030820P03oool0oooo00D0oooo00<0P820
0000000000001000003o0?oookl0oooo00<0P8200000000000000`3oool01020P800000000000000
000d0?ooo`00o`3ooolA0?ooo`040410@000000000000<30`1d0oooo00@0@410000000000000@410
7@3oool01@30`<000000000000000000`<3000P0oooo00<0P8200410@00000000`0000000`20P800
oooo0?ooo`3o0?oook/0oooo0P0000000`10@400oooo0?ooo`020?ooo`040410@000000000000410
@3<0oooo003o0?oooa80oooo00@0`<300820P010@400`<307@3oool01020P800000000000010@40N
0?ooo`040410@000000000000820P0X0oooo00<0@4100000000000000P0000000`20P800`<300?oo
o`3o0?oookT0oooo0P0000000`20P800oooo0?ooo`030?ooo`040410@000000000000410@380oooo
003o0?oooaD0oooo00<0`<300?ooo`3oool0703oool01@30`<000000000000000000`<3001d0oooo
00@0@410000000000000@4102`3oool00`20P800000000000002000000030410@030`<00oooo0?l0
oooo]P3oool01030`<00000000000020P8060?ooo`040820P000000000000410@340oooo003o0?oo
ocD0oooo00@0P82000000000000000007P3oool3000000030820P03oool0oooo00X0oooo1@00003o
0?oookL0oooo00<0P820000000000000203oool01020P800000000000000000`0?ooo`00o`3ooolf
0?ooo`040410@000000000000410@1d0oooo00D0`<3000000000000000000<30`00<0?ooo`030820
P010@40000000080000000<0@4100<30`03oool0o`3ooonc0?ooo`030820P0000000000000T0oooo
00@0@410000000000000@410;`3oool00?l0oooo=`3oool01020P800000000000010@40N0?ooo`04
0410@000000000000820P0h0oooo00H0P82000000000000000000410@020P83o0?oook80oooo0P00
00000`20P800oooo0?ooo`080?ooo`040410@000000000000410@2h0oooo003o0?ooocP0oooo00@0
`<30000000000000@4107P3oool01010@400000000000010@40?0?ooo`030<30`010@40000000080
000000<0P8200?ooo`3oool0o`3ooon^0?ooo`800000303oool01020P800000000000010@40]0?oo
o`00o`3oooli0?ooo`050<30`0000000000000000030`<007@3oool01010@400000000000010@40@
0?ooo`030<30`020P80000000080000000<0P8200?ooo`3oool0o`3ooon[0?ooo`030<30`0000000
000000d0oooo00D0`<3000000000000000000<30`00[0?ooo`00o`3ooolj0?ooo`040820P0000000
0000000001h0oooo0`0000000`20P800oooo0?ooo`0@0?ooo`@00000o`3ooon/0?ooo`030820P000
0000P82000h0oooo00@0P8200000000000000000:`3oool00?l0oooo>`3oool01010@40000000000
0010@40N0?ooo`040410@000000000000820P140oooo00H0`<300410@000000000000410@030`<3o
0?ooojX0oooo00<0P82000000020P8003`3oool01010@400000000000010@40Z0?ooo`00o`3oooll
0?ooo`040820P000000000000410@1h0oooo00@0@410000000000000@4104P3oool01@20P800@410
000000000000P8200?l0ooooZ@3oool2000000030<30`03oool0oooo00h0oooo00@0P82000000000
0000@410:@3oool00?l0oooo?@3oool01@30`<000000000000000000`<3001d0oooo00@0@4100000
00000000@4104`3oool01@20P8000000000000000000P8200?l0ooooY`3oool200000180oooo00D0
`<3000000000000000000<30`00W0?ooo`00o`3oooln0?ooo`040820P00000000000000001h0oooo
0`0000000`20P800oooo0?ooo`0A0?ooo`050820P0000000000000000020P800o`3ooonU0?ooo`<0
00004`3oool01020P800000000000000000W0?ooo`00o`3ooolo0?ooo`040410@000000000000410
@1h0oooo00@0@410000000000000P8204`3oool01@30`<000000000000000000@4100?l0ooooX`3o
ool01030`<00000000000020P80D0?ooo`040410@000000000000410@2H0oooo003o0?oood00oooo
00@0P820000000000000@4107P3oool01010@400000000000010@40D0?ooo`050820P00000000000
00000010@400o`3ooonQ0?ooo`030820P0000000000001H0oooo00@0P820000000000000@4109@3o
ool00?l0oooo@@3oool01@30`<000000000000000000`<3001d0oooo00@0@410000000000000@410
503oool00`30`<00@41000000002000000030820P03oool0oooo0?l0ooooW@3oool2000000030410
@03oool0oooo01D0oooo00D0`<3000000000000000000<30`00S0?ooo`00o`3ooom20?ooo`040820
P00000000000000001h0oooo0`0000000`20P800oooo0?ooo`0C0?ooo`D00000o`3ooonM0?ooo`04
0820P000000000000820P1P0oooo00@0P82000000000000000008`3oool00?l0oooo@`3oool01010
@400000000000010@40N0?ooo`040410@000000000000820P1D0oooo00D0`<300000000000000000
0410@03o0?oooi`0oooo00<0P8200000000000006P3oool01010@400000000000010@40R0?ooo`00
o`3ooom40?ooo`040820P000000000000410@1h0oooo00@0@410000000000000@4105@3oool01@30
`<000000000000000000@4100?l0ooooV`3oool2000000030820P03oool0oooo01T0oooo00@0P820
000000000000@4108@3oool00?l0ooooA@3oool01@30`<000000000000000000`<3001d0oooo00@0
@410000000000000@4105@3oool01P30`<00P820000000000000@4100820P?l0ooooV03oool00`20
P80000000410@00M0?ooo`050<30`0000000000000000030`<007`3oool00?l0ooooAP3oool01020
P800000000000000000N0?ooo`<0000000<0P8200?ooo`3oool0503oool01@20P800000000000000
0000P8200?l0ooooU`3oool3000001h0oooo00@0P82000000000000000007`3oool00?l0ooooA`3o
ool20820P00300000010@400oooo01d0oooo00@0@410000000000000P8205P3oool01@10@4000000
000000000000`<300?l0ooooUP3oool01@10@4000000000000000000`<3001d0oooo00@0@4100000
00000000@4107P3oool00?l0ooooBP3oool00`30`<00P8200?ooo`0M0?ooo`040410@00000000000
0410@1H0oooo00D0@41000000000000000000<30`03o0?oooi@0oooo00<0P82000000010@4000`00
00000`30`<00oooo0?ooo`0K0?ooo`040820P000000000000410@1d0oooo003o0?ooof/0oooo00@0
@410000000000000@4105P3oool01@20P8000000000000000000P8200?l0ooooTP3oool00`30`<00
0000000000020<30`0<0000000<0`<300?ooo`3oool06`3oool01030`<00000000000000000L0?oo
o`00o`3ooom/0?ooo`<0000000<0P8200?ooo`3oool05@3oool3000000030820P03oool0oooo0?l0
ooooS`3oool00`20P8000000000000030?ooo`<000007P3oool00`20P80000000000000L0?ooo`00
o`3ooom]0?ooo`040410@000000000000820P1H0oooo00D0`<3000000000000000000<30`03o0?oo
oi00oooo0P0000001@20P800oooo0?ooo`3oool0`<3000<0000000<0`<300?ooo`3oool06`3oool0
0`10@40000000?ooo`0K0?ooo`00o`3ooom^0?ooo`040410@000000000000410@1H0oooo00D0`<30
00000000000000000<30`03o0?ooohh0oooo00@0P820000000000000`<30103oool01@30`<000000
000000000000`<3003X0oooo003o0?ooofl0oooo00@0@410000000000000@4105`3oool01010@400
000000000020P83o0?ooohd0oooo0P0000000`20P800oooo0?ooo`040?ooo`050<30`00000000000
00000030`<00>@3oool00?l0ooooL03oool3000000030820P03oool0oooo01D0oooo0`0000000`20
P800oooo0?ooo`3o0?ooohT0oooo00<0P8200000000000002@3oool3000003T0oooo003o0?ooog40
oooo00@0@410000000000000P8205P3oool01@30`<000000000000000000@4100?l0ooooRP3oool0
0`10@40000000820P0090?ooo`050<30`0000000000000000030`<00=`3oool00?l0ooooLP3oool0
1010@400000000000010@40F0?ooo`050<30`020P800000000000010@400o`3ooon80?ooo`030820
P0000000000000/0oooo00D0`<3000000000000000000<30`00f0?ooo`00o`3ooomc0?ooo`040410
@000000000000410@1L0oooo00D0`<3000000000000000000<30`03o0?ooohD0oooo00@0P8200000
00000000P820303oool01@30`<000000000000000000`<3003D0oooo003o0?ooog@0oooo0`000000
0`20P800oooo0?ooo`0E0?ooo`040820P0000000000000000?l0ooooQ@3oool3000000l0oooo0`00
000e0?ooo`00o`3ooome0?ooo`040410@000000000000<30`1L0oooo00@0@410000000000000@410
o`3ooon30?ooo`040<30`000000000000410@0l0oooo00D0`<3000000000000000000<30`00c0?oo
o`00o`3ooomf0?ooo`040410@000000000000820P1L0oooo00@0P820000000000000@410o`3ooon2
0?ooo`030410@000000000000140oooo00D0`<3000000000000000000<30`00b0?ooo`00o`3ooomg
0?ooo`040410@000000000000410@1L0oooo00@0`<300000000000000000o`3ooon00?ooo`030<30
`0000000000001<0oooo00D0`<3000000000000000000<30`00a0?ooo`00o`3ooomh0?ooo`<00000
00<0P8200?ooo`3oool05@3oool01020P800000000000020P83o0?ooogl0oooo00<0P82000000020
P8005@3oool300000340oooo003o0?ooogP0oooo00D0`<3000000000000000000<30`00G0?ooo`<0
000000<0`<300?ooo`3oool0o`3oooml0?ooo`8000005P3oool01@30`<000000000000000000`<30
02l0oooo003o0?ooogX0oooo00@0@410000000000000P8205P3oool01@30`<000000000000000000
`<300?l0ooooN`3oool01030`<00000000000020P80G0?ooo`050<30`0000000000000000030`<00
;P3oool00?l0ooooN`3oool01010@400000000000010@40G0?ooo`040410@000000000000820P?l0
ooooNP3oool00`10@40000000410@00I0?ooo`050<30`0000000000000000030`<00;@3oool00?l0
ooooO03oool3000000030820P03oool0oooo01D0oooo0`00003o0?ooogT0oooo00@0P82000000000
0000P8206`3oool3000002d0oooo003o0?ooog`0oooo00D0`<3000000000000000000<30`00F0?oo
o`040<30`000000000000410@?l0ooooN03oool2000000030820P03oool0oooo01X0oooo00D0`<30
00000000000000000<30`00[0?ooo`00o`3ooomn0?ooo`040410@000000000000820P1H0oooo00@0
@410000000000000@410o`3ooomf0?ooo`040410@000000000000820P1d0oooo00D0`<3000000000
000000000<30`00Z0?ooo`00o`3ooomo0?ooo`040410@000000000000410@1H0oooo00@0P8200410
@0000000@410o`3ooomd0?ooo`030<30`000000000000080000000<0@4100?ooo`3oool06`3oool0
1@30`<000000000000000000`<3002T0oooo003o0?oooh00oooo00@0@410000000000000@4105`3o
ool2000000030820P03oool0oooo0?l0ooooL03oool01@20P800000000000030`<00@41000800000
00<0@4100?ooo`3oool0703oool01010@400000000000020P80X0?ooo`00o`3ooon10?ooo`<00000
00<0P8200?ooo`3oool0503oool01020P800000000000020P83o0?ooog40oooo0P0000000`20P800
oooo0?ooo`03000000030820P03oool0oooo01`0oooo0`0000000`20P800oooo0?ooo`0U0?ooo`00
o`3ooon20?ooo`040410@000000000000820P1H0oooo00@0@410000000000000`<30o`3ooom_0?oo
o`030410@0000000000000@0oooo00@0@410000000000000P8207@3oool01@30`<00000000000000
0000`<3002H0oooo003o0?oooh<0oooo00@0@410000000000000@4105P3oool01020P80000000000
0030`<3o0?ooofd0oooo00@0P820000000000000`<301@3oool01010@400000000000010@40M0?oo
o`050<30`0000000000000000030`<009@3oool00?l0ooooQ03oool01010@400000000000010@40F
0?ooo`030410@000000000000?l0ooooK03oool00`30`<000000000000080?ooo`040410@0000000
00000410@1h0oooo00@0@410000000000000P820903oool00?l0ooooQ@3oool3000000030820P03o
ool0oooo01@0oooo0`00003o0?ooof/0oooo0P0000000`20P800oooo0?ooo`070?ooo`<0000000<0
P8200?ooo`3oool0703oool3000000030820P03oool0oooo0240oooo003o0?ooohH0oooo00@0@410
000000000000P8205@3oool01030`<00000000000010@43o0?ooofP0oooo00@0`<30000000000000
@4102`3oool01010@400000000000020P80M0?ooo`040<30`000000000000<30`2<0oooo003o0?oo
ohL0oooo00@0@410000000000000@4105@3oool01010@400000000000010@43o0?ooofL0oooo0P00
00000`10@400oooo0?ooo`0;0?ooo`040410@000000000000410@1d0oooo00<0`<300820P03oool0
8`3oool00?l0ooooR03oool01010@400000000000010@40E0?ooo`040820P000000000000<30`?l0
ooooI@3oool00`10@40000000000000?0?ooo`040410@000000000000410@480oooo003o0?ooohT0
oooo0`0000000`20P800oooo0?ooo`0C0?ooo`030820P000000000000?l0ooooI03oool00`20P800
00000000000A0?ooo`<0000000<0P8200?ooo`3oool0?`3oool00?l0ooooRP3oool01010@4000000
00000020P80D0?ooo`040<30`0000000000000000?l0ooooHP3oool01020P800000000000030`<0B
0?ooo`040410@000000000000820P400oooo003o0?oooh/0oooo00@0@410000000000000@410503o
ool01030`<00000000000010@43o0?ooof00oooo00@0@410000000000000@410503oool01010@400
000000000010@40o0?ooo`00o`3ooon<0?ooo`040410@000000000000410@1@0oooo00@0P8200000
00000000@410o`3ooomN0?ooo`040410@000000000000410@1H0oooo00@0@410000000000000@410
?P3oool00?l0ooooS@3oool3000000030820P03oool0oooo0180oooo0`00003o0?oooed0oooo00@0
P8200000000000000000603oool3000000030820P03oool0oooo03/0oooo003o0?ooohh0oooo00@0
@410000000000000P820503oool00`10@40000000410@03o0?oooe/0oooo00@0P820000000000000
@4106P3oool01010@400000000000020P80l0?ooo`00o`3ooon?0?ooo`040410@000000000000410
@1@0oooo0`00003o0?oooeT0oooo00@0@410000000000000@410703oool01010@400000000000010
@40k0?ooo`00o`3ooon@0?ooo`040410@000000000000410@1<0oooo00@0`<30000000000000@410
o`3ooomG0?ooo`050410@0000000000000000030`<007@3oool01010@400000000000010@40j0?oo
o`00o`3ooonA0?ooo`<0000000<0P8200?ooo`3oool04@3oool01020P800000000000020P83o0?oo
oeD0oooo1P00000N0?ooo`<0000000<0P8200?ooo`3oool0=`3oool00?l0ooooTP3oool01010@400
000000000020P80C0?ooo`80000000<0@4100?ooo`3oool0o`3ooomA0?ooo`090<30`00000000000
00000010@400oooo0410@0000000@41001h0oooo00@0@410000000000000P820>03oool00?l0oooo
T`3oool01010@400000000000010@40C0?ooo`030410@0000000@4100?l0ooooD@3oool01@20P800
0000000000000000`<3000<0oooo00@0@410000000000000`<307@3oool01010@400000000000010
@40g0?ooo`00o`3ooonD0?ooo`040410@000000000000410@1<0oooo00<0@410000000000000o`3o
oom?0?ooo`050410@0000000000000000030`<001@3oool01010@400000000000030`<0M0?ooo`04
0410@000000000000410@3H0oooo003o0?oooiD0oooo0`0000000`20P800oooo0?ooo`0@0?ooo`04
0820P000000000000820P?l0ooooC03oool01@20P8000000000000000000P82000P0oooo0`00000N
0?ooo`<0000000<0P8200?ooo`3oool0<`3oool00?l0ooooUP3oool01010@400000000000020P80B
0?ooo`040410@000000000000<30`?l0ooooBP3oool01@30`<000000000000000000@41000X0oooo
00<0@41000000010@4007P3oool01010@400000000000020P80d0?ooo`00o`3ooonG0?ooo`040410
@000000000000410@180oooo00<0P82000000010@400o`3ooom90?ooo`050820P000000000000000
0030`<00303oool01010@400000000000030`<0M0?ooo`040410@000000000000410@3<0oooo003o
0?oooiP0oooo00@0@410000000000000@4104P3oool00`10@40000000410@03o0?ooodH0oooo00D0
`<3000000000000000000410@00?0?ooo`040410@000000000000<30`1d0oooo00@0@41000000000
0000@410<P3oool00?l0ooooV@3oool3000000030820P03oool0oooo0100oooo0P0000000`20P800
oooo0?ooo`3o0?oood80oooo00D0P82000000000000000000820P00A0?ooo`<000007P3oool30000
00030820P03oool0oooo02l0oooo003o0?oooiX0oooo00@0@410000000000000P8204@3oool01030
`<00000000000020P83o0?oood80oooo00D0`<3000000000000000000410@00C0?ooo`030410@000
0000@41001h0oooo00@0@410000000000000P820<03oool00?l0ooooV`3oool01010@40000000000
0010@40A0?ooo`040410@000000000000<30`?l0oooo?`3oool01@30`<00P820000000000000@410
01H0oooo00@0@410000000000000`<307@3oool01010@400000000000020P80_0?ooo`00o`3ooonL
0?ooo`040410@000000000000410@140oooo00@0@410000000000000`<30o`3ooolm0?ooo`050820
P0000000000000000010@400603oool01010@400000000000030`<0M0?ooo`030410@020P800oooo
02l0oooo003o0?oooid0oooo0`0000000`20P800oooo0?ooo`0?0?ooo`<00000o`3oooll0?ooo`05
0820P0000000000000000020P8006P3oool3000004l0oooo003o0?oooih0oooo00@0@41000000000
0000P8204@3oool2000000030410@03oool0oooo0?l0oooo=`3oool00`20P8000000000000030000
01`0oooo00<0@41000000010@400CP3oool00?l0ooooW`3oool01010@400000000000010@40@0?oo
o`050<30`0000000000000000030`<00o`3ooole0?ooo`030<30`010@400000000<0000000<0P820
0?ooo`3oool0703oool00`10@40000000410@01=0?ooo`00o`3ooonP0?ooo`040410@00000000000
0410@100oooo00@0`<30000000000000@410o`3ooolc0?ooo`030<30`0000000000000<0000000@0
@410000000000000P8207P3oool01010@400000000000030`<1;0?ooo`00o`3ooonQ0?ooo`<00000
00<0P8200?ooo`3oool03P3oool01020P800000000000020P83o0?oooc40oooo00<0P82000000000
00000P0000000`20P800oooo0?ooo`03000000030820P03oool0oooo01`0oooo0`00001;0?ooo`00
o`3ooonR0?ooo`040410@000000000000820P0l0oooo00D0`<3000000000000000000<30`03o0?oo
obl0oooo00<0@4100000000000000P0000001@20P800oooo0?ooo`3oool0`<3000<0000000<0`<30
0?ooo`3oool06`3oool01030`<00000000000010@41:0?ooo`00o`3ooonS0?ooo`040410@0000000
00000410@100oooo00@0@410000000000000P820o`3oool[0?ooo`030<30`010@400000000<00000
00<0P8200?ooo`3oool0103oool01@30`<000000000000000000`<3001h0oooo00<0@41000000010
@400B@3oool00?l0ooooY03oool01010@400000000000010@40@0?ooo`<0000000<0@4100?ooo`3o
ool0o`3ooolW0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0203oool01010@400
000000000020P80N0?ooo`040410@000000000000<30`4L0oooo003o0?ooojD0oooo00@0P8200000
00000000@4103`3oool01@30`<000000000000000000`<300?l0oooo9P3oool00`10@40000000000
0002000000030820P03oool0oooo00/0oooo00@0@410000000000000@4107P3oool01010@4000000
00000030`<160?ooo`00o`3ooonV0?ooo`040820P00000000000000000l0oooo00@0P82000000000
00000000o`3ooolU0?ooo`D00000403oool3000000030820P03oool0oooo01`0oooo0`0000160?oo
o`00o`3ooonW0?ooo`040410@000000000000410@0l0oooo00@0P820000000000000@410o`3ooolQ
0?ooo`030<30`020P800000000<0000000<0P8200?ooo`3oool03`3oool01@30`<00000000000000
0000`<3001h0oooo00<0@41000000010@400A@3oool00?l0ooooZ03oool01010@400000000000010
@40?0?ooo`040410@000000000000820P?l0oooo7P3oool00`30`<00@41000000003000000030820
P03oool0oooo01<0oooo00@0@410000000000000P8207P3oool01010@400000000000030`<130?oo
o`00o`3ooonY0?ooo`040820P000000000000410@0l0oooo00@0@410000000000000@410o`3ooolK
0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool05P3oool01010@400000000000010
@40N0?ooo`040410@000000000000<30`480oooo003o0?ooojX0oooo00@0P8200000000000000000
3`3oool3000000030820P03oool0oooo0?l0oooo5`3oool5000000030820P03oool0oooo01T0oooo
0`0000000`20P800oooo0?ooo`0L0?ooo`<00000@P3oool00?l0ooooZ`3oool01010@40000000000
0010@40>0?ooo`050<30`0000000000000000030`<00o`3ooolE0?ooo`80P8201@0000000`20P800
oooo0?ooo`0J0?ooo`050<30`0000000000000000030`<007P3oool00`10@40000000410@0110?oo
o`00o`3ooon/0?ooo`040410@000000000000410@0l0oooo00@0@410000000000000P820o`3ooolB
0?ooo`030820P0000000000000<0000000D0P82000000000000000000<30`00M0?ooo`040410@000
000000000820P1h0oooo00@0@410000000000000`<30?`3oool00?l0oooo[@3oool01020P8000000
00000010@40?0?ooo`040410@000000000000410@?l0oooo3P3oool00`30`<00P820000000030000
0080P8200`3oool01010@400000000000020P80M0?ooo`040410@000000000000410@1h0oooo00<0
@410000000000000?`3oool00?l0oooo[P3oool01020P800000000000020P80?0?ooo`<0000000<0
P8200?ooo`3oool0o`3oool:0?ooo`030820P0000000000000<000001`3oool3000000030820P03o
ool0oooo01/0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`030000003oool0oooo03h0oooo003o
0?ooojl0oooo00@0@410000000000000P8203P3oool01@30`<000000000000000000`<300?l0oooo
2@3oool00`20P800@41000000003000000030820P03oool0oooo00H0oooo00D0`<30000000000000
00000<30`00L0?ooo`050<30`0000000000000000030`<00GP3oool00?l0oooo/03oool01010@400
000000000010@40?0?ooo`050410@000000000000820P030`<00o`3oool40?ooo`030<30`020P800
000000<0000000<0@4100820P03oool02P3oool01@30`<000000000000000000`<3001d0oooo00@0
@410000000000000P820G@3oool00?l0oooo/@3oool01010@400000000000010@40?0?ooo`050410
@0000000000000000030`<00o`3oool00`20P800@41000000004000000030410@030`<00oooo00h0
oooo00@0@410000000000000P8207@3oool01010@400000000000010@41L0?ooo`00o`3ooonb0?oo
o`<0000000<0P8200?ooo`3oool03@3oool01020P800000000000000003m0?ooo`L0000000<0P820
0?ooo`3oool04@3oool3000000030820P03oool0oooo01/0oooo0`0000000`20P800oooo0?ooo`1I
0?ooo`00o`3ooonc0?ooo`040410@000000000000820P0l0oooo00@0P820000000000000@410n@3o
ool00`20P800@4100000000400000080P8205@3oool01@30`<000000000000000000`<3001`0oooo
00D0`<3000000000000000000<30`01J0?ooo`00o`3ooond0?ooo`040410@000000000000410@0l0
oooo00D0`<3000000000000000000410@03c0?ooo`030<30`020P800000000D0000000<0P8200<30
`03oool0603oool01@30`<000000000000000000`<3001d0oooo00@0@410000000000000P820F@3o
ool00?l0oooo]@3oool01010@400000000000010@40?0?ooo`050<30`010@400000000000010@400
k`3oool00`20P800@41000000006000000030820P03oool0oooo01`0oooo00@0@410000000000000
P8207@3oool01010@400000000000010@41H0?ooo`00o`3ooonf0?ooo`<0000000<0P8200?ooo`3o
ool03P3oool400000>`0oooo20000000103oool0P82000000000000O0?ooo`<0000000<0P8200?oo
o`3oool06`3oool3000000030820P03oool0oooo05D0oooo003o0?oookL0oooo00@0@41000000000
0000P820403oool01@10@4000000000000000000`<300>L0oooo00<0P8200410@00000001@000000
0`20P800`<300?ooo`020?ooo`040410@000000000000<30`1d0oooo00D0`<300000000000000000
0<30`00L0?ooo`050<30`0000000000000000030`<00EP3oool00?l0oooo^03oool01010@4000000
00000010@40@0?ooo`050<30`0000000000000000010@400hP3oool00`20P800@410000000050000
00030410@020P800oooo00L0oooo00@0@410000000000000`<307@3oool01@30`<00000000000000
0000`<3001d0oooo00@0@410000000000000P820E@3oool00?l0oooo^@3oool01010@40000000000
0010@40A0?ooo`050820P0000000000000000020P800g03oool20820P0H0000000<0@4100820P030
`<00303oool01020P800000000000030`<0N0?ooo`040410@000000000000820P1d0oooo00@0@410
000000000000@410E03oool00?l0oooo^P3oool3000000030820P03oool0oooo0100oooo0`000000
0`20P800oooo0?ooo`3G0?ooo`P0000000<0P8200?ooo`3oool03`3oool00`20P80000000000000O
0?ooo`<0000000<0P8200?ooo`3oool06`3oool3000000030820P03oool0oooo0540oooo003o0?oo
ok/0oooo00@0@410000000000000P8204@3oool01P30`<00@410000000000000@4100820P=<0oooo
00<0`<300820P010@4001@0000000`10@400P8200820P00D0?ooo`040410@000000000000<30`1d0
oooo00D0`<3000000000000000000<30`00L0?ooo`050<30`0000000000000000030`<00DP3oool0
0?l0oooo_03oool01010@400000000000010@40B0?ooo`030820P010@40000000080000000<0@410
0<30`03oool0b`3oool00`30`<00P8200410@00600000080P8206@3oool01010@400000000000030
`<0M0?ooo`050<30`0000000000000000030`<007@3oool01010@400000000000020P81A0?ooo`00
o`3ooonm0?ooo`040410@000000000000410@1<0oooo00<0P8200000000000000P0000000`10@400
oooo0?ooo`340?ooo`030<30`020P800P82000T0000000<0`<300?ooo`3oool06`3oool01020P800
000000000030`<0N0?ooo`040410@000000000000820P1d0oooo0P10@4000`20P800oooo0?ooo`1?
0?ooo`00o`3ooonn0?ooo`<0000000<0P8200?ooo`3oool04P3oool5000000030820P03oool0oooo
0;l0oooo00<0P820000000000000200000000`3oool0P82000000002000001h0oooo00<0P8200000
000000007`3oool3000000030820P03oool0oooo06h0oooo003o0?oookl0oooo00@0@41000000000
0000P820503oool00`30`<00@41000000002000000030410@030`<00oooo0;T0oooo0`20P8080000
00030410@020P800P82000@0oooo00@0P820000000000000@4107P3oool01010@400000000000030
`<0M0?ooo`050<30`0000000000000000030`<00K`3oool00?l0oooo`03oool01010@40000000000
0010@40E0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0/@3oool30820P0L00000
00@0@4100820P020P800`<302P3oool01@30`<000000000000000000`<3001d0oooo00@0@4100000
00000000`<307@3oool01@30`<000000000000000000`<3006h0oooo003o0?oool40oooo00@0@410
000000000000@4105P3oool00`30`<00@4100000000300000080P820Z@3oool01030`<00P8200820
P020P808000000040410@020P800P8200<30`100oooo00D0`<3000000000000000000<30`00M0?oo
o`040820P000000000000<30`1h0oooo00@0@410000000000000P820K@3oool00?l0oooo`P3oool3
000000030820P03oool0oooo01D0oooo00<0P820000000000000100000000`20P800oooo0?ooo`2Q
0?ooo`030820P0000000000000/000005`3oool01020P800000000000000000N0?ooo`030820P000
0000000001l0oooo0`0000000`20P800oooo0?ooo`1Z0?ooo`00o`3oooo30?ooo`040410@0000000
00000820P1P0oooo00<0`<300410@0000000100000000`20P800`<300?ooo`2H0?ooo`@0P8202`00
00000`10@400P8200820P00K0?ooo`040820P000000000000410@1h0oooo00@0@410000000000000
`<307@3oool01@30`<000000000000000000`<3006/0oooo003o0?oool@0oooo00@0@41000000000
0000@4106P3oool20820P0D000000P20P82?0?ooo`@0P8202P0000001`10@400P8200820P020P800
`<300?ooo`10@4000P0000000`20P800oooo0?ooo`0K0?ooo`050<30`0000000000000000030`<00
7@3oool01010@400000000000030`<0M0?ooo`050<30`0000000000000000030`<00JP3oool00?l0
ooooa@3oool01010@400000000000010@40L0?ooo`030<30`020P800000000D000000P20P8200?oo
o`D0P82000<0@4100000000000002`0000030820P0X0oooo00@0@410000000000000@4107@3oool0
1@30`<000000000000000000`<3001d0oooo00@0P820000000000000`<307P3oool01010@4000000
00000020P81Y0?ooo`00o`3oooo60?ooo`<0000000<0P8200?ooo`3oool0703oool9000007T0oooo
5000000B0?ooo`<0000000<0P8200?ooo`3oool06`3oool01020P800000000000000000N0?ooo`03
0820P0000000000001l0oooo0`0000000`20P800oooo0?ooo`1V0?ooo`00o`3oooo70?ooo`040410
@000000000000820P1d0oooo00<0`<30000000000000200000020820P6P0oooo1`20P80@00000003
0410@020P800P82000<0P82000<0`<300?ooo`3oool04`3oool01@30`<000000000000000000`<30
01d0oooo00@0P820000000000000@4107P3oool00`10@40000000410@00N0?ooo`050<30`0000000
000000000030`<00I`3oool00?l0oooob03oool01010@400000000000010@40M0?ooo`040<30`000
0000000000000080`<3000<0P8200410@00000001`0000000`10@400P8200820P0020820P500oooo
1`20P8000`10@40000000000000B000000D0P82000D0`<300410@000000000000410@00N0?ooo`04
0410@000000000000820P1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@0000000
00000<30`1d0oooo00D0`<3000000000000000000<30`01V0?ooo`00o`3oooo90?ooo`040410@000
000000000410@1d0oooo00D0`<3000000000000000000<30`0030?ooo`030<30`020P800@41000d0
000000<0@4100820P020P8003@20P80W0?ooo`X0P82000<0@4100000000000005`0000000`10@400
P8200820P0040820P0d0oooo00@0P820000000000000@4107P3oool01010@400000000000010@40M
0?ooo`050<30`0000000000000000030`<007@3oool01010@400000000000030`<0N0?ooo`030410
@0000000000006H0oooo003o0?ooolX0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`<000002P3o
oomM000001`0oooo00@0P82000000000000000007P3oool3000000030820P03oool0oooo01/0oooo
00@0P82000000000000000007P3oool3000001l0oooo00<000000?ooo`3oool0I@3oool00?l0oooo
b`3oool01010@400000000000020P80M0?ooo`050<30`0000000000000000030`<00303oool00`30
`<00P8200820P0020820P48000002P20P8001030`<00oooo0?ooo`30`<03000000030<30`03oool0
oooo01/0oooo00@0@410000000000000@4107@3oool01@30`<000000000000000000`<3001d0oooo
00@0P820000000000000@4107P3oool00`10@40000000410@0260?ooo`00o`3oooo<0?ooo`040410
@000000000000410@1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040820P00000000000
000001h0P82000@0@41000000000000000001020P8000`30`<00oooo0?ooo`0F0?ooo`050<30`000
0000000000000030`<007@3oool01010@400000000000010@40N0?ooo`040410@000000000000820
P1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@000000000000<30`8@0oooo003o
0?ooold0oooo00@0@410000000000000@4107@3oool01@30`<000000000000000000`<3001d0oooo
00D0`<3000000000000000000<30`00M0?ooo`040410@000000000000410@1d0oooo00D0`<300000
0000000000000<30`00M0?ooo`040820P000000000000410@1h0oooo00@0@410000000000000@410
7@3oool01@30`<000000000000000000`<3001d0oooo00@0@410000000000000`<30P`3oool00?l0
oooocP3oool01020P800000000000010@40N0?ooo`040410@000000000000820P1d0oooo00D0`<30
00000000000000000<30`00M0?ooo`040410@000000000000410@1h0oooo00@0@410000000000000
P8207@3oool01@30`<000000000000000000`<3001d0oooo00@0@410000000000000@4107@3oool0
1@30`<000000000000000000`<3001d0oooo00@0P820000000000000`<30PP3oool00?l0ooooc`3o
ool01020P800000000000000000N0?ooo`<0000000<0P8200?ooo`3oool06`3oool01020P8000000
00000000000N0?ooo`<0000000<0P8200?ooo`3oool0703oool3000000030820P03oool0oooo01/0
oooo00@0P82000000000000000007P3oool3000000030820P03oool0oooo01`0oooo0`00000N0?oo
o`030820P000000000000880oooo003o0?ooom00oooo00@0@410000000000000@4107@3oool01@30
`<000000000000000000`<3001d0oooo00@0P820000000000000@4107P3oool01010@40000000000
0020P80M0?ooo`050<30`0000000000000000030`<007@3oool01010@400000000000010@40N0?oo
o`040410@000000000000<30`1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@000
000000000<30`800oooo003o0?ooom40oooo00@0@410000000000000@4107@3oool01@30`<000000
000000000000`<3001d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@00000000000
0410@1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040820P000000000000410@1h0oooo
00@0@410000000000000P8207@3oool01@30`<000000000000000000`<3001d0oooo00@0@4100000
00000000`<30O`3oool00?l0oooodP3oool01020P800000000000010@40N0?ooo`040410@0000000
00000820P1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@000000000000410@1h0
oooo00@0@410000000000000P8207@3oool01@30`<000000000000000000`<3001d0oooo00@0@410
000000000000@4107@3oool01@30`<000000000000000000`<3001d0oooo00@0P820000000000000
`<30OP3oool00?l0ooood`3oool01020P800000000000000000N0?ooo`<0000000<0P8200?ooo`3o
ool06`3oool01020P800000000000000000N0?ooo`<0000000<0P8200?ooo`3oool0703oool30000
00030820P03oool0oooo01/0oooo00@0P82000000000000000007P3oool3000000030820P03oool0
oooo01`0oooo0`00000N0?ooo`030820P0000000000007h0oooo003o0?ooom@0oooo00@0@4100000
00000000@4107@3oool01@30`<000000000000000000`<3001d0oooo00@0P820000000000000@410
7P3oool01010@400000000000020P80M0?ooo`050<30`0000000000000000030`<007@3oool01010
@400000000000010@40M0?ooo`050<30`0000000000000000030`<007@3oool01@30`<0000000000
00000000`<3001d0oooo00@0@410000000000000`<30O03oool00?l0ooooe@3oool01010@4000000
00000010@40M0?ooo`050<30`0000000000000000030`<007@3oool01@30`<000000000000000000
`<3001d0oooo00@0@410000000000000@4107@3oool01@30`<000000000000000000`<3001d0oooo
00@0P820000000000000@4107P3oool01010@400000000000020P80M0?ooo`050<30`00000000000
00000030`<007@3oool20820P7d0oooo003o0?ooomH0oooo00@0P820000000000000@4107P3oool0
1010@400000000000020P80M0?ooo`050<30`0000000000000000030`<007@3oool01010@4000000
00000010@40N0?ooo`040410@000000000000<30`1d0oooo00D0`<3000000000000000000<30`00M
0?ooo`040410@000000000000410@1d0oooo00D0`<3000000000000000000<30`02K0?ooo`00o`3o
oooG0?ooo`040820P00000000000000001h0oooo0`0000000`20P800oooo0?ooo`0K0?ooo`040820
P00000000000000001h0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`<000007P3oool01020P800
000000000000000N0?ooo`<0000000<0P8200?ooo`3oool0703oool3000009/0oooo003o0?ooomP0
oooo00@0@410000000000000@4107@3oool01@30`<000000000000000000`<3001d0oooo00@0P820
000000000000@4107P3oool01010@400000000000020P80M0?ooo`050<30`0000000000000000030
`<007@3oool01010@400000000000010@40M0?ooo`050<30`0000000000000000030`<007@3oool0
1@30`<000000000000000000`<3009T0oooo003o0?ooomT0oooo00@0@410000000000000@4107@3o
ool01@30`<000000000000000000`<3001d0oooo00D0`<3000000000000000000<30`00M0?ooo`04
0410@000000000000410@1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040820P0000000
00000410@1h0oooo00@0@410000000000000P8207@3oool01@30`<000000000000000000`<3009P0
oooo003o0?ooomX0oooo00@0P820000000000000@4107P3oool01010@400000000000020P80M0?oo
o`050<30`0000000000000000030`<007@3oool01010@400000000000010@40M0?ooo`050<30`000
0000000000000030`<007@3oool01@30`<000000000000000000`<3001d0oooo00@0@41000000000
0000@4107@3oool01@30`<000000000000000000`<3009L0oooo003o0?ooom/0oooo00@0P8200000
0000000000007P3oool3000000030820P03oool0oooo01/0oooo00@0P82000000000000000007P3o
ool3000000030820P03oool0oooo01`0oooo0`00000N0?ooo`040820P00000000000000001h0oooo
0`0000000`20P800oooo0?ooo`0L0?ooo`<00000U`3oool00?l0oooog03oool01010@40000000000
0010@40M0?ooo`050<30`0000000000000000030`<007@3oool01020P800000000000010@40N0?oo
o`040410@000000000000820P1d0oooo00D0`<3000000000000000000<30`00M0?ooo`040410@000
000000000410@1d0oooo00D0`<3000000000000000000<30`00M0?ooo`050<30`000000000000000
0030`<00U@3oool00?l0oooog@3oool01010@400000000000010@40M0?ooo`050<30`00000000000
00000030`<007@3oool01@30`<000000000000000000`<3001d0oooo00@0@410000000000000@410
7@3oool01@30`<000000000000000000`<3001d0oooo00@0P820000000000000@4107P3oool01010
@400000000000020P80M0?ooo`040<30`000000000000410@9D0oooo003o0?ooomh0oooo00@0P820
000000000000@4107P3oool01010@400000000000020P80M0?ooo`050<30`0000000000000000030
`<007@3oool01010@400000000000010@40M0?ooo`050<30`0000000000000000030`<007@3oool0
1@30`<000000000000000000`<3001d0oooo00@0@410000000000000@410]@3oool00?l0oooog`3o
ool01020P800000000000000000N0?ooo`<0000000<0P8200?ooo`3oool06`3oool01020P8000000
00000000000N0?ooo`<0000000<0P8200?ooo`3oool0703oool3000001h0oooo00@0P82000000000
000000007P3oool3000000030820P03oool0oooo0;80oooo003o0?ooon00oooo00@0@41000000000
0000@4107@3oool01@30`<000000000000000000`<3001d0oooo00@0P820000000000000@4107P3o
ool01010@400000000000020P80M0?ooo`050<30`0000000000000000030`<007@3oool01010@400
000000000010@40M0?ooo`050<30`0000000000000000030`<00/`3oool00?l0ooooh@3oool01010
@400000000000010@40M0?ooo`050<30`0000000000000000030`<007@3oool01030`<0000000000
0010@40N0?ooo`040410@000000000000410@1d0oooo00D0`<3000000000000000000<30`00M0?oo
o`040820P000000000000410@1h0oooo00@0@410000000000000P820/P3oool00?l0oooohP3oool0
1020P800000000000010@40N0?ooo`040410@000000000000820P1d0oooo00D0`<30000000000000
00000<30`00M0?ooo`040410@000000000000410@1d0oooo00D0`<3000000000000000000<30`00M
0?ooo`050<30`0000000000000000030`<007@3oool01010@400000000000010@42a0?ooo`00o`3o
oooS0?ooo`040820P00000000000000001h0oooo0`0000000`20P800oooo0?ooo`0K0?ooo`040820
P00000000000000001h0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`<000007P3oool01020P800
000000000000000N0?ooo`<0000000<0P8200?ooo`3oool0[P3oool00?l0ooooi03oool01010@400
000000000010@40M0?ooo`050<30`0000000000000000030`<007@3oool01010@400000000000010
@40N0?ooo`040410@000000000000820P1d0oooo00D0`<3000000000000000000<30`00M0?ooo`04
0410@000000000000410@1d0oooo00@0`<30000000000000P820/03oool00?l0ooooi@3oool01010
@400000000000010@40M0?ooo`050<30`0000000000000000030`<007@3oool01020P80000000000
0010@40N0?ooo`040410@000000000000410@1d0oooo00D0`<3000000000000000000<30`00M0?oo
o`040820P000000000000410@=00oooo003o0?ooonH0oooo00@0P820000000000000@4107P3oool0
1010@400000000000020P80M0?ooo`050<30`0000000000000000030`<007@3oool01010@4000000
00000010@40M0?ooo`050<30`0000000000000000030`<007@3oool01@30`<000000000000000000
`<300<h0oooo003o0?ooonL0oooo00@0P820000000000000P8207P3oool3000000030820P03oool0
oooo01/0oooo00@0P82000000000000000007P3oool3000000030820P03oool0oooo01`0oooo0`00
000N0?ooo`040820P0000000000000000<h0oooo003o0?ooonP0oooo00@0@410000000000000P820
7@3oool01@30`<000000000000000000`<3001d0oooo00@0@410000000000000@4107P3oool01010
@400000000000020P80M0?ooo`050<30`0000000000000000030`<007@3oool01010@40000000000
0010@43=0?ooo`00o`3ooooY0?ooo`040410@000000000000410@1d0oooo00D0`<30000000000000
00000<30`00M0?ooo`040820P000000000000410@1h0oooo00@0@410000000000000@4107@3oool0
1@30`<000000000000000000`<3001d0oooo00@0P820000000000000@410c03oool00?l0oooojP3o
ool01010@400000000000010@40N0?ooo`040410@000000000000820P1d0oooo00D0`<3000000000
000000000<30`00M0?ooo`040410@000000000000410@1d0oooo00D0`<3000000000000000000<30
`03/0?ooo`00o`3oooo[0?ooo`<0000000<0P8200?ooo`3oool0703oool3000000030820P03oool0
oooo01/0oooo00@0P82000000000000000007P3oool3000000030820P03oool0oooo01`0oooo0`00
003/0?ooo`00o`3oooo/0?ooo`040410@000000000000820P1d0oooo00D0`<300000000000000000
0<30`00M0?ooo`040410@000000000000410@1h0oooo00@0@410000000000000P8207@3oool01@30
`<000000000000000000`<300>X0oooo003o0?ooond0oooo00@0`<300820P020P800@4107@3oool0
1@30`<000000000000000000`<3001d0oooo00@0P820000000000000@4107P3oool01010@4000000
00000010@40M0?ooo`040<30`0000000P8200820P>X0oooo003o0?ooool0oooo4@3oool01010@400
000000000020P80M0?ooo`050<30`0000000000000000030`<007@3oool01010@400000000000010
@43o0?ooo`/0oooo003o0?ooool0oooo4P3oool3000000030820P03oool0oooo01/0oooo00@0P820
00000000000000007P3oool3000000030820P03oool0oooo0?l0oooo203oool00?l0ooooo`3ooolB
0?ooo`050<30`0000000000000000030`<007@3oool01010@400000000000010@40N0?ooo`030410
@0000000P8200?l0oooo2P3oool00?l0ooooo`3ooolC0?ooo`050<30`020P800@41000000030`<00
7@3oool30820P0030<30`03oool0oooo0?l0oooo:03oool00?l0ooooo`3ooooo0?ooof<0oooo003o
0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0
oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo
0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0oooo
o`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool0
0?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0oooo
H`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?oo
ool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{182.875, 170.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 3.8: Region ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " (unshaded) for solution of Poisson's equation. The surface of this region \
is ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]]
}], "Caption",
  CellTags->"Fig. 3.8"],

Cell[CellGroupData[{

Cell["3.2.1 Existence and Uniqueness of the Solution", "Subsubtitle",
  CellTags->"c:26"],

Cell["\<\
For the above boundary conditions, can one always find a solution \
to Laplace's equation? And is this solution unique? \
\>", "Text"],

Cell["\<\
\tWe will answer the second question first. If a solution exists, \
it is unique for Dirichlet or mixed boundary conditions. For von Neumann \
boundary conditions, the solution is unique only up to an additive constant. \
This can be proven through the following argument. \
\>", "Text",
  CellTags->"i:61"],

Cell[TextData[{
  "\tSay that two solutions exist with the same  boundary conditions. Call \
these solutions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_2\)]],
  ". We will prove that these solutions must in fact be the same (up to an \
additive constant for ",
  "von Neumann",
  " boundary conditions). "
}], "Text"],

Cell[TextData[{
  "\tThe difference between the solutions, \[CapitalPhi] = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_1 - \[Phi]\_2\)]],
  ", also satisfies the Laplace equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[CapitalPhi] = 0\)]],
  ", and has ",
  StyleBox["homogeneous ",
    FontSlant->"Italic"],
  " boundary conditions.  To find the solution to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[CapitalPhi] = 0\)]],
  " with homogeneous boundary conditions, multiply this equation by ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)]],
  " and integrate over the volume of the domain. Then apply Green's first \
identity:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "=", 
          
          RowBox[{\(\[Integral]\_V \[CapitalPhi] \[Del]\^2 \[CapitalPhi] \
\[DifferentialD]\^3 r\), "=", 
            RowBox[{
              RowBox[{\(\[Integral]\_S\), 
                RowBox[{"\[CapitalPhi]", 
                  RowBox[{\(\[Del]\[CapitalPhi]\), "\[CenterDot]", 
                    StyleBox[
                      OverscriptBox[
                        StyleBox["n",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "^"],
                      FontWeight->"Bold"]}], \(\[DifferentialD]\^2 r\)}]}], 
              "-", \(\[Integral]\_V\[Del]\[CapitalPhi]\[CenterDot]\[Del]\
\[CapitalPhi] \[DifferentialD]\^3 r\)}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Now, for Dirichlet or von Neumann boundary conditions, either ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi] = 0\)]],
  " or ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Del]\[CapitalPhi]\), "\[CenterDot]", 
            StyleBox[
              OverscriptBox[
                StyleBox["n",
                  FontWeight->"Bold"], "^"],
              FontWeight->"Bold"]}], "=", "0"}], TraditionalForm]]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ", so the surface integral vanishes, and we are left with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_V\(\((\(|\)\(\[Del]\[CapitalPhi]\)\(|\))\
\)\^2\) \[DifferentialD]\^3 r = 0\)]],
  ". Furthermore, since ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(|\)\(\[Del]\[CapitalPhi]\)\(|\))\)\^2\)]],
  " is always nonnegative, the only way this integral can be zero is if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\[CapitalPhi] = 0\)]],
  " throughout the domain. Therefore, \[CapitalPhi]=constant  is the only \
solution. This implies that \[CapitalPhi]=0 for Dirichlet boundary \
conditions, because ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi] = 0\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  "; but for von Neumann conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi] = constant\)]],
  " satisfies the boundary conditions."
}], "Text"],

Cell[TextData[{
  " \tFor mixed boundary conditions,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)]],
  " satisfies ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{\(f\ \[CapitalPhi]\), "+", 
                RowBox[{"g", 
                  RowBox[{
                    StyleBox[
                      OverscriptBox[
                        StyleBox["n",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "^"],
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "\[CenterDot]", 
                    StyleBox[\(\[Del]\[CapitalPhi]\),
                      FontWeight->"Plain"]}]}]}], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox[\( | \_S\),
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], "0"}], TraditionalForm]]],
  ". Assuming that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is nonzero over the some part of the surface ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " ( call this portion ",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\)]],
  "), and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  " is nonzero over the remainder of the surface (call it ",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\^c\)]],
  " ), Greens  first identity becomes"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "=", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{\(\[Integral]\_\(S\_1\)\), 
                RowBox[{\(g\/f\), 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{\(\[Del]\[CapitalPhi]\), "\[CenterDot]", 
                        StyleBox[
                          OverscriptBox[
                            StyleBox["n",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], "^"],
                          FontWeight->"Bold"]}], ")"}], 
                    "2"], \(\[DifferentialD]\^2 r\)}]}]}], 
            "-", \(\[Integral]\_S\_1\%\(\(\ \ \)\(c\)\)\ \ \(f\/g\) \(\((\
\[CapitalPhi])\)\^2\) \[DifferentialD]\^2 r\), 
            "-", \(\[Integral]\_V\[Del]\[CapitalPhi]\[CenterDot]\[Del]\
\[CapitalPhi] \[DifferentialD]\^3 r\)}]}], TraditionalForm]]],
  ".\nEach integral is nonnegative (since both ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " are nonnegative by assumption)",
  ",",
  " and therefore by the same argument as before the only possible solution \
is ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi] = 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  " \tTherefore,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_2\)]],
  " are equal for Dirichlet or mixed boundary conditions, and for von Neumann \
conditions  they differ at most by a constant. We have shown that the \
solution to the Laplace equation is unique  for Dirichlet and mixed \
conditions, and unique up to an additive constant for von Neumann conditions. \
"
}], "Text"],

Cell[TextData[{
  "\tOne can also show that for Dirichlet and mixed boundary conditions, a \
solution can always be found. (We will later prove this by construction of \
the solution). For von Neumann boundary conditions, however, a solution for \
the potential ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " only exists provided that the boundary conditions satisfy the following \
integral constraint:"
}], "Text",
  CellTags->"i:62"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Integral]\_S\), 
            RowBox[{
              RowBox[{\(\[Del]\[Phi]\), "\[CenterDot]", 
                StyleBox[
                  OverscriptBox[
                    StyleBox["n",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "^"],
                  FontWeight->"Bold"]}], \(\[DifferentialD]\^2 r\)}]}], "=", 
          "0"}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(3.2.3)"],

Cell[TextData[{
  "This constraint on the normal derivative of the potential  at the domain \
surface follows from Laplace's equation through an application of  the \
divergence  theorem : ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "=", 
          
          RowBox[{\(\[Integral]\_V\[Del]\^2 \[Phi] \[DifferentialD]\^3 r\), 
            "=", 
            RowBox[{\(\[Integral]\_S\), 
              RowBox[{
                RowBox[{\(\[Del]\[Phi]\), "\[CenterDot]", 
                  StyleBox[
                    OverscriptBox[
                      StyleBox["n",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "^"],
                    FontWeight->"Bold"]}], \(\[DifferentialD]\^2 r\)}]}]}]}], 
        TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tStudents with some training in electrostatics will recognize Eq. ",
  ButtonBox["(3.2.3)",
    ButtonData:>"(3.2.3)",
    ButtonStyle->"Hyperlink"],
  " as a special case of ",
  ButtonBox["Gauss",
    ButtonData:>{
      URL[ 
      "http://turnbull.dcs.st-and.ac.uk/~history/Mathematicians/Gauss.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  "'s law, which states that the integral of the normal component to the \
electric field  over a closed surface must equal the charge enclosed in the \
surface (which in this case is zero)."
}], "Text",
  CellTags->"i:63"],

Cell[TextData[{
  "\tIf Eq. ",
  ButtonBox["(3.2.3)",
    ButtonData:>"(3.2.3)",
    ButtonStyle->"Hyperlink"],
  " is not satisfied, then there is no solution.  This only constrains von \
Neumann boundary conditions, since only ",
  "von Neumann",
  "  conditions directly specify the normal derivative of \[Phi].  For \
Dirichlet and mixed conditions, which do not directly specify ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Del]\[Phi]\), "\[CenterDot]", 
          StyleBox[
            OverscriptBox[
              StyleBox["n",
                FontWeight->"Bold",
                FontSlant->"Plain"], "^"],
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", one can always find a solution that satisfies Eq. ",
  ButtonBox["(3.2.3)",
    ButtonData:>"(3.2.3)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell["\<\
\tWe now consider several geometries  where the solution to \
Laplace's equation can be found analytically, using the method of separation \
of variables.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2.2 Rectangular Geometry", "Subsubtitle",
  CellTags->"c:27"],

Cell[CellGroupData[{

Cell["General Solution", "Section",
  CellTags->{"i:64", "c:28"}],

Cell[TextData[{
  "\t  In rectangular coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  ",  a solution to Laplace's equation for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  " can be found using separation of variables. Following the by now familiar \
argument, we write"
}], "Text",
  CellTags->"i:76"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi](x, y) = \(X(x)\) \(Y(y)\)\)]]], "NE2",
  CellTags->"(3.2.4)"],

Cell[TextData[{
  "for some functions ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  ". If we substitute Eq. ",
  ButtonBox["(3.2.4)",
    ButtonData:>"(3.2.4)",
    ButtonStyle->"Hyperlink"],
  "  into the Laplace equation and divide the result by \[Phi], we obtain"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(X(
                  x)\)\) \[DifferentialD]\^2 X\/\[DifferentialD]x\^2 + \
\(1\/\(Y(y)\)\) \[DifferentialD]\^2 Y\/\[DifferentialD]y\^2 = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "As usual, this equation can be separated into two ODEs, one for  ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  " and the other for ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  ": "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(1\/\(X(
              x)\)\) \[DifferentialD]\^2 X\/\[DifferentialD]x\^2 = \[Lambda], \
\[IndentingNewLine]\(1\/\(Y(
              y)\)\) \[DifferentialD]\^2 Y\/\[DifferentialD]y\^2 = \(-\
\[Lambda]\), \)]]], "NE2",
  CellTags->"(3.2.5)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " is the separation constant. The general solution to each ODE can be found \
easily:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`X(x) = 
      C\_1\ \[ExponentialE]\^\(\(\@\[Lambda]\) x\) + 
        C\_2\ \[ExponentialE]\^\(\(-\@\[Lambda]\) x\), \[IndentingNewLine]Y(
        y) = C\_3\ \[ExponentialE]\^\(\[ImaginaryI] \(\@ \[Lambda]\) y\) + 
        C\_4\ \(\(\[ExponentialE]\^\(\(-\[ImaginaryI]\) \(\@\[Lambda]\) 
                  y\)\)\(.\)\)\)]]], "NE2",
  CellTags->"(3.2.6)"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1: Dirichlet Boundary Conditions", "Section",
  CellTags->"c:29"],

Cell[TextData[{
  "\tThe general solution given by Eq. ",
  ButtonBox["(3.2.6)",
    ButtonData:>"(3.2.6)",
    ButtonStyle->"Hyperlink"],
  " is useful for  boundary conditions specified on a rectangle, as shown in \
Fig. ",
  ButtonBox["3.9",
    ButtonData:>"Fig. 3.9",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008m0002]2000`400?l00000o`00003oo`3ooooo
0?ooocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo
003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0
oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo?`3oool0
0?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3o
oolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00
o`3ooooo0?ooocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?oo
ocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o
0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo
?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003a0?oooa80P820o`3ooolk0?oo
o`00l@3oool00`20P80000000000000B00000?l0oooo>03oool00?@0oooo00<0P820000000000000
0`0000000`10@400P8200820P0040820P0030410@0000000000000<0000000<0@4100820P030`<00
o`3ooold0?ooo`00m@3oool00`20P800000000000002000000X0oooo0P20P804000000030410@03o
ool0oooo0?l0oooo<@3oool00?H0oooo100000000`30`<00oooo0?ooo`0:0?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool0o`3oool_0?ooo`00gP3oool01@20P8000000000000000000
P82001<0oooo00D0P82000000000000000000820P00>0?ooo`030820P0000000000000800000o`3o
ool`0?ooo`00gP3oool01@20P8000000000000000000P82001<0oooo00D0P8200000000000000000
0410@00?0?ooo`050410@0000000000000000010@400o`3oool_0?ooo`00gP3oool01@30`<000000
000000000000@41001@0oooo1000000@0?ooo`050410@0000000000000000010@400o`3oool^0?oo
o`00g`3oool4000001@0oooo00D0@41000000000000000000<30`00@0?ooo`@0000000<0@4100?oo
o`3oool0o`3oool[0?ooo`00g`3oool4000001@0oooo00D0P82000000000000000000820P00A0?oo
o`@0000000<0P8200?ooo`3oool0o`3ooolZ0?ooo`00h03oool4000001<0oooo00<0P82000000000
00000P00000A0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0o`3ooolY0?ooo`00
h03oool4000001@0oooo1000000A0?ooo`030<30`000000000000080000000<0@4100?ooo`3oool0
o`3ooolY0?ooo`00h03oool4000001@0oooo00D0P82000000000000000000820P00A0?ooo`030410
@0000000000000800000o`3oool[0?ooo`00h03oool01@20P8000000000000000000P82001@0oooo
1000000A0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0o`3ooolX0?ooo`00h03o
ool01@20P8000000000000000000P82001@0oooo100000000`20P800oooo0?ooo`0?0?ooo`@00000
00<0P8200?ooo`3oool0o`3ooolX0?ooo`00h03oool01@20P8000000000000000000P82001@0oooo
00D0P82000000000000000000820P00A0?ooo`D00000D03oool00`20P800@4100000000200000003
0820P030`<00oooo00H0oooo00D0@410000000000000@4100<30`0360?ooo`00h@3oool4000001@0
oooo00<0`<300000000000000P00000A0?ooo`D00000CP3oool00`30`<0000000000000600000003
0410@03oool0oooo00@0oooo1@0000000`30`<00oooo0?ooo`330?ooo`00g@3oool20820P0L00000
00<0@4100820P020P8004@3oool400000140oooo00<0P8200000000000000P0000000`20P800oooo
0?ooo`1;0?ooo`030410@0000000000000P0000000<0@4100?ooo`3oool00P3oool4000000030820
P010@400`<300<@0oooo003L0?ooo`030820P0000000000000/00000403oool4000000030820P03o
ool0oooo00h0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`1;0?ooo`H000000`3o
ool3000000040820P03oool0oooo0?ooo`@0000000<0oooo0820P0000000a03oool00480oooo1020
P82E0?ooo`070410@0000000000000000020P800`<300820P003000000030820P030`<00P82000<0
000000<0P8200<30`03oool0303oool01@20P8000000000000000000P8200100oooo00<0P8200000
000000000P0000000`20P800oooo0?ooo`1:0?ooo`030820P0000000000000<0000000<0`<300?oo
o`3oool00`3oool00`10@40000000<30`0020?ooo`@000000P3oool00`10@40000000?ooo`320?oo
o`00?`3oool00`30`<00000000000005000000030410@030`<00oooo08l0oooo00<0`<3000000000
00000P0000001030`<00oooo0?ooo`20P803000000050820P03oool0oooo0?ooo`10@4000`000000
0`30`<00oooo0?ooo`0:0?ooo`030<30`0000000000000800000403oool00`20P800000000000002
000000030820P03oool0oooo04X0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`05
0?ooo`050<30`0000000P8200?ooo`10@4000`0000001@20P800oooo0<30`0000000`<300<80oooo
000n0?ooo`050410@000000000000820P030`<000P3oool01@20P800@410000000000000P82008l0
oooo00D0@41000000000000000000410@0040?ooo`<0000000<0@4100?ooo`3oool00P3oool01@10
@4000000000000000000`<3000`0oooo1000000@0?ooo`030820P000000000000080000000<0P820
0?ooo`3oool0BP3oool00`20P800000000000002000000030820P03oool0oooo00H0oooo00@0`<30
00000010@400P8200`0000000`10@400oooo0?ooo`340?ooo`00?@3oool01020P800000000000020
P8060?ooo`@00000S@3oool00`20P800000000000002000000030820P03oool0oooo0080oooo1000
00050?ooo`@00000303oool01@20P8000000000000000000P82000l0oooo00<0P820000000000000
0P0000000`20P800oooo0?ooo`1:0?ooo`030820P00000000000008000002`3oool00`000000P820
0000000300000<H0oooo000m0?ooo`<000001`3oool01@30`<000000000000000000P82008`0oooo
00<0P8200000000000000P0000000`30`<00oooo0?ooo`020?ooo`@000001@3oool00`20P8000000
00000002000000030<30`03oool0oooo00P0oooo00D0P82000000000000000000820P00?0?ooo`03
0820P0000000000000800000C@3oool00`20P800000000000002000000030820P03oool0oooo00P0
oooo00<0P8200000000000000`0000360?ooo`00>`3oool01@30`<000000000000000000P82000P0
oooo00D0P82000000000000000000<30`02;0?ooo`D000001@3oool01020P8000000000000000006
0?ooo`050820P0000000000000000010@4002P3oool00`30`<00000000000002000000l0oooo1@00
001>0?ooo`@0000000<0P8200?ooo`3oool02@3oool00`10@400000000000002000000030820P03o
ool0oooo0<<0oooo000k0?ooo`040410@00000000000000000X0oooo0`0000000`10@400oooo0?oo
o`290?ooo`D000001@3oool01@20P8000000000000000000P82000H0oooo100000000`20P800oooo
0?ooo`080?ooo`@000003`3oool4000000030820P03oool0oooo04`0oooo100000000`20P800oooo
0?ooo`090?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0``3oool003/0oooo1000
000:0?ooo`@00000R`3oool5000000H0oooo0`0000000`20P800oooo0?ooo`040?ooo`030820P000
00000000008000002`3oool4000000d0oooo00<0P8200000000000000P00001?0?ooo`030820P000
0000000000800000303oool500000<D0oooo000j0?ooo`050820P0000000000000000020P8002`3o
ool4000008X0oooo1@0000060?ooo`<0000000<0P8200?ooo`3oool0103oool00`20P80000000000
0002000000/0oooo1000000=0?ooo`050410@0000000000000000010@400C`3oool00`20P8000000
00000002000000`0oooo00<0P8200000000000000P0000350?ooo`00>P3oool4000000030820P03o
ool0oooo00T0oooo100000000`20P800oooo0?ooo`270?ooo`D000001P3oool01020P80000000000
0010@4070?ooo`@0000000<0P8200?ooo`3oool0203oool01@10@4000000000000000000P82000/0
oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`1>0?ooo`@0000000<0`<300?ooo`3o
ool02P3oool4000000030820P03oool0oooo0<80oooo000i0?ooo`030820P0000000000000800000
303oool00`20P800000000000002000008T0oooo00<0@4100000000000000P0000000`30`<00oooo
0?ooo`040?ooo`<000001`3oool4000000030820P03oool0oooo00P0oooo00D0P820000000000000
00000410@00:0?ooo`050820P0000000000000000010@400DP3oool01@20P8000000000000000000
@41000d0oooo0`0000000`20P800oooo0?ooo`320?ooo`00>@3oool00`20P8000000000000020000
00`0oooo00<0P8200000000000000P0000290?ooo`030820P000000000000080000000<0P8200?oo
o`3oool0103oool3000000L0oooo00<0P8200000000000000P00000:0?ooo`030820P00000000000
00800000203oool00`20P800000000000002000000030410@03oool0oooo0580oooo100000000`20
P800oooo0?ooo`0:0?ooo`040410@0000000000000000<@0oooo000i0?ooo`D00000303oool00`20
P800000000000002000000030820P03oool0oooo08H0oooo00<0P8200000000000000P0000000`20
P800oooo0?ooo`040?ooo`040820P00000000000000000H0oooo00<0P8200000000000000P00000:
0?ooo`D000001P3oool6000000030820P03oool0oooo05@0oooo1000000<0?ooo`040820P0000000
000000000<@0oooo000i0?ooo`@0000000<0@4100?ooo`3oool02P3oool00`20P800000000000002
000000030820P03oool0oooo08L0oooo100000000`10@400oooo0?ooo`040?ooo`040820P0000000
0000000000H0oooo00<0P8200000000000000P0000070?ooo`80P820400000020820P5L0oooo00D0
P82000000000000000000820P00;0?ooo`030820P0000000000000800000``3oool003T0oooo1000
00000`20P800oooo0?ooo`0;0?ooo`@0000000<0P8200?ooo`3oool0Q`3oool00`10@40000000000
0002000000H0oooo00@0`<3000000000000000001P3oool00`20P800000000000002000000L0oooo
3`20P8000`30`<00oooo0?ooo`1J0?ooo`040410@00000000000000000/0oooo00<0P82000000000
00000P0000330?ooo`00>03oool5000000030820P03oool0oooo00/0oooo100000000`10@400oooo
0?ooo`270?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0103oool3000000030<30
`03oool0oooo00<0oooo00<0P8200000000000000P00001d0?ooo`<0000000<0@4100?ooo`3oool0
203oool00`20P800000000000002000000030820P03oool0oooo0<00oooo000h0?ooo`D0000000<0
P8200?ooo`3oool02`3oool5000008X0oooo1@0000060?ooo`<0000000<0P8200?ooo`3oool00`3o
ool00`20P800000000000002000007@0oooo00D0P82000000000000000000820P0090?ooo`030820
P000000000000080000000<0P8200?ooo`3oool0`03oool003P0oooo1@0000000`20P800oooo0?oo
o`0;0?ooo`D00000R`3oool4000000030820P03oool0oooo00<0oooo00@0@410000000000000P820
1@3oool01@20P8000000000000000000@41007D0oooo00@0P820000000000000@4102@3oool00`20
P800@4100000000300000<80oooo000h0?ooo`D0000000<0P8200?ooo`3oool02`3oool5000008/0
oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`020?ooo`040820P000000000000820
P0D0oooo100000000`20P800oooo0?ooo`1e0?ooo`040410@000000000000<30`0L0oooo0P20P804
00000<80oooo000h0?ooo`D0000000<0P8200?ooo`3oool02`3oool5000008`0oooo00<0`<300000
000000000P0000001@30`<00oooo0?ooo`3oool0`<3000<00000103oool00`20P800000000000002
000007T0oooo00@0P820000000000000@4101@3oool01020P80000000?ooo`10@403000000030820
P03oool0oooo0;l0oooo000h0?ooo`D0000000<0P8200?ooo`3oool02`3oool5000008d0oooo00<0
P8200000000000000P0000040?ooo`<00000103oool4000000030820P03oool0oooo07T0oooo0`00
00030?ooo`050820P0000000P8200?ooo`20P8000`0000000`20P800oooo0?ooo`2o0?ooo`00>03o
ool5000000030820P03oool0oooo00/0oooo1@00002>0?ooo`060410@0000000000000000010@400
P8200P3oool3000000<0oooo00D0@41000000000000000000410@01m0?ooo`030820P010@4000000
0080000000<0@4100820P03oool00P3oool01030`<00P8200820P00000310?ooo`00>03oool50000
00030820P03oool0oooo00/0oooo1@00002@0?ooo`030820P000000000000080000000H0P8200000
0000000000000820P010@404000000030820P03oool0oooo0?l0ooooC03oool003P0oooo1@000000
0`20P800oooo0?ooo`0;0?ooo`D00000TP3oool20820P0030410@0000000000000D000000P20P83o
0?oooe00oooo000i0?ooo`@0000000<0P8200?ooo`3oool02`3oool5000009H0oooo00@0P8200000
00000000P820o`3ooomD0?ooo`00>@3oool5000000d0oooo100000000`20P800oooo0?ooo`2E0?oo
o`80000000<0@4100?ooo`3oool0o`3ooomB0?ooo`00>@3oool5000000d0oooo100000000`20P800
oooo0?ooo`2E0?ooo`<00000o`3ooomD0?ooo`00>@3oool00`10@400000000000002000000`0oooo
00<0P8200000000000000P0000000`30`<00oooo0?ooo`2E0?ooo`030820P000000000000?l0oooo
E03oool003T0oooo00<0P8200000000000000P00000<0?ooo`030820P0000000000000800000V@3o
ool200000?l0ooooE03oool003T0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`09
0?ooo`030820P0000000000000800000V@3oool2000000030820P03oool0oooo0?l0ooooD@3oool0
03X0oooo100000000`20P800oooo0?ooo`090?ooo`050410@0000000000000000020P800V@3oool0
0`20P80000000820P03o0?oooe<0oooo000j0?ooo`050820P0000000000000000020P8002`3oool4
000009X0oooo00<0P82000000020P800o`3ooomC0?ooo`00>`3oool4000000/0oooo1000002K0?oo
o`800000o`3ooomC0?ooo`00>`3oool01010@400000000000000000:0?ooo`<0000000<0@4100?oo
o`3oool0VP3oool200000?l0ooooD`3oool003/0oooo00D0`<3000000000000000000820P0080?oo
o`050820P0000000000000000030`<00W03oool200000?l0ooooD`3oool003d0oooo00@0@4100000
00000000`<301`3oool3000000030820P03oool0oooo09/0oooo00<0`<300820P020P800o`3ooomB
0?ooo`00?P3oool01010@400000000000020P8050?ooo`040410@000000000000410@?l0ooool`3o
ool003l0oooo100000030?ooo`<00000o`3ooooe0?ooo`00?`3oool00`30`<00@410000000050000
00030410@030`<00oooo0?l0oooom03oool00480oooo00D0`<300820P020P800P8200<30`03o0?oo
ooL0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooo`P0oooo0`20
P80d0?ooo`00o`3ooooo0?ooo`L0oooo00<0P8200000000000000P0000020820P340oooo001B0?oo
o`030<30`020P800P8200?l0P8207020P82E0?ooo`030410@0000000000000D000000P20P8000`30
`<00oooo0?ooo`0[0?ooo`00DP3oool00`20P80000000000003o000001`00000U@3oool<000002`0
oooo001B0?ooo`030820P000000000000?l000007000002E0?ooo`h0000000<0P8200?ooo`3oool0
9`3oool00580oooo00<0P820000000000000o`00000L000009@0oooo00<0`<300000000000003P00
00000`10@400P8200?ooo`0U0?ooo`00DP3oool00`20P80000000000003o000001`00000U03oool0
0`20P80000000000000A000000030410@020P800oooo0280oooo001B0?ooo`030820P00000000000
0?l000007000002D0?ooo`030820P0000000000001D000008@3oool00580oooo00<0P82000000000
0000o`00000L000009@0P82000<0@4100000000000005P0000000`10@400`<300?ooo`0M0?ooo`00
DP3oool00`20P80000000000003o00000</0000000<0P8200?ooo`3oool06`3oool00580oooo00<0
P820000000000000o`00000L000009@0P82000<0@4100000000000005@0000000`20P800`<300?oo
o`0N0?ooo`00DP3oool00`20P80000000000003o000001`00000U03oool00`20P80000000000000C
000002<0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000U03oool00`20
P80000000000000?000000030410@020P800`<3002@0oooo001B0?ooo`030820P0000000000000L0
0000o`3oool<0?ooo`T00000U03oool00`30`<0000000000000=000000030820P03oool0oooo02H0
oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000U@3oool;000000030410
@020P800oooo02X0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000U@3o
ool00`10@40000000000000500000080P820;P3oool00580oooo00<0P8200000000000001`00003o
0?ooo``0oooo2@00002E0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0;`3oool0
0580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00002F0?ooo`80000000<0P8200<30
`03oool0<P3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00
DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P000
0000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o
0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool90000
0<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo
00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000
000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<
0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?oo
o`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820
P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00
003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool9
00000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580
oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00002T0?ooo`80P820303oool20820P003
0<30`03oool0oooo01H0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000
X`3oool01@20P8000000000000000000P82000T0oooo00D0@41000000000000000000410@00G0?oo
o`00DP3oool00`20P80000000000000700000?l0oooo303oool900000:<0oooo00<0P82000000000
00000P0000000`10@400oooo0?ooo`050?ooo`030<30`0000000000000<0000000<0@4100?ooo`3o
ool0503oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00002S0?ooo`030820
P000000000000080P82000<000000410@03oool01@3oool01P20P8000000000000000000@4100820
P080000000<0`<300?ooo`3oool04P3oool00580oooo00<0P8200000000000001`00003o0?ooo``0
oooo2@00002S0?ooo`030820P0000000P8200080oooo00<0P8200000003oool01@3oool400000005
0820P03oool0P82000000020P800503oool00580oooo00<0P8200000000000001`00003o0?ooo``0
oooo2@00002S0?ooo`030<30`020P800oooo00<0oooo00<000000410@03oool0103oool400000006
0<30`03oool0oooo0820P0000000`<304`3oool00580oooo00<0P8200000000000001`00003o0?oo
o``0oooo2@00002Y0?ooo`030<30`0000000P82000<0oooo00<0P8200000000000000P0000040?oo
o`030<30`010@400oooo0180oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T0
0000ZP3oool00`20P80000000820P0020?ooo`@0000000<0P8200?ooo`3oool00`3oool00`30`<00
oooo0?ooo`0A0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000:/0oooo
0P0000020?ooo`@000006P3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00
002/0?ooo`0300000030`<00P82000<0000000<0@4100?ooo`3oool0603oool00580oooo00<0P820
0000000000001`00003o0?ooo``0oooo2@00002/0?ooo`030820P010@400P82000<0000000<0P820
0?ooo`3oool0603oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00002]0?oo
o`030410@000000000000080000000<0`<300?ooo`3oool0603oool00580oooo00<0P82000000000
00001`00003o0?ooo``0oooo2@00002]0?ooo`030820P00000000000008000006`3oool00580oooo
00<0P8200000000000001`00003o0?ooo``0oooo2@00002]0?ooo`030<30`0000000000000800000
6`3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00002]0?ooo`050820P000
0000000000000020P8006`3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00
002]0?ooo`@0000000<0`<300?ooo`3oool06@3oool00580oooo00<0P8200000000000001`00003o
0?ooo``0oooo2@00002]0?ooo`@0000000<0P8200?ooo`3oool06@3oool00580oooo00<0P8200000
000000001`00003o0?ooo``0oooo2@00002/0?ooo`030<30`0000000000000<000006`3oool00580
oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00002/0?ooo`050820P000000000000000
0020P8000P10@40J0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000:`0
oooo100000001020P800`<3000000020P80I0?ooo`00DP3oool00`20P80000000000000700000?l0
oooo303oool900000:`0oooo100000020?ooo`030820P0000000P82001P0oooo001B0?ooo`030820
P0000000000000L00000o`3oool<0?ooo`T00000Z`3oool500000080oooo00@0`<30000000000000
`<300`3oool20820P180oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000
ZP3oool00`10@400000000000002000000D0oooo00@0@41000000020P800P820100000000`30`<00
oooo0?ooo`0>0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000:D0oooo
00@0`<300820P020P800P8201@0000000`10@400oooo0?ooo`030?ooo`030<30`0000000000000D0
000000<0P8200?ooo`3oool03P3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo
2@00002U0?ooo`030<30`010@400000000H0000000<0`<300?ooo`3oool0103oool00`30`<00@410
00000004000000030820P03oool0oooo00h0oooo001B0?ooo`030820P0000000000000L00000o`3o
ool<0?ooo`T00000Z@3oool01@20P8000000000000000000P82000T0oooo1@00000A0?ooo`00DP3o
ool00`20P80000000000000700000?l0oooo303oool900000:`0oooo00<0P8200<30`03oool02@3o
ool00`30`<00P8200820P00B0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool9
00000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580
oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P8000000
0000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3o
ool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=
0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`03
0820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P820000000000000
1`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303o
ool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool0
0580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P800
00000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000
o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00
003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?oo
o`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P82000000000
00001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo
303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3o
ool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20
P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L0
0000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo
2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B
0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000
000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0
oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000
c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool0
0`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P00000000000
00L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0
oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo
001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P820
0000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P8000000000000070000
0?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T0
0000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3o
ool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000
000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?oo
o``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0
oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0
P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P800000000000007
00000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?oo
o`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00
DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P000
0000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o
0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool90000
0<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo
00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000
000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<
0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?oo
o`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820
P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00
003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool9
00000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580
oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P8000000
0000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3o
ool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=
0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`03
0820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P820000000000000
1`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303o
ool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool0
0580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P800
00000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000
o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00
003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?oo
o`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P82000000000
00001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo
303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3o
ool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20
P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L0
0000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo
2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B
0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000
000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0
oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000
c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool0
0`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P00000000000
00L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0
oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo
001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P820
0000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P8000000000000070000
0?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T0
0000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3o
ool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000
000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?oo
o``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0
oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0
P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P800000000000007
00000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?oo
o`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00
DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P000
0000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o
0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool90000
0<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo
00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000
000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<
0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?oo
o`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820
P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00
003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool9
00000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580
oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P8000000
0000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3o
ool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=
0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`03
0820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P820000000000000
1`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303o
ool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool0
0580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P800
00000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000
o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00
003=0?ooo`00DP3oool00`20P800000000000007000005l0oooo00D0`<300820P020P800P8200<30
`02W0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00001O0?ooo`050820P0000000
000000000020P800Y`3oool900000<d0oooo001B0?ooo`030820P0000000000000L00000G`3oool0
1@20P8000000000000000000P8200:L0oooo2@00003=0?ooo`00DP3oool00`20P800000000000007
00000600oooo1000002W0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00001P0?oo
o`@00000Y`3oool900000<d0oooo001B0?ooo`030820P0000000000000L00000H03oool400000:L0
oooo2@00003=0?ooo`00=`3oool60820P0030<30`03oool0oooo0180oooo00<0P820000000000000
1`00001P0?ooo`050820P0000000000000000020P800YP3oool900000<d0oooo000c0?ooo`030<30
`020P800000000T0000000<0@4100<30`03oool0403oool00`20P80000000000000700000600oooo
00D0P82000000000000000000820P02V0?ooo`T000008P3oool00`20P800000000000005000000H0
oooo00<0`<300000000000002P0000000`20P800oooo0?ooo`2=0?ooo`00<P3oool00`10@4000000
00000002000000030410@020P800`<3000@0oooo00D0`<300820P010@40000000820P00?0?ooo`03
0820P0000000000000L00000H03oool01@30`<000000000000000000@4100:H0oooo2@00000R0?oo
o`030<30`0000000000000<0000000<0`<300?ooo`3oool0203oool00`30`<00@410000000040000
00030820P030`<00oooo0900oooo000a0?ooo`D0000000<0P8200?ooo`3oool02@3oool00`000000
P8200?ooo`0=0?ooo`030820P0000000000000L00000H@3oool400000:H0oooo2@00000T0?ooo`<0
000000<0P8200?ooo`3oool02`3oool4000000030820P03oool0oooo0940oooo000_0?ooo`030<30
`0000000000000<0000000<0P8200?ooo`3oool02P3oool00`30`<00@4100<30`00=0?ooo`030820
P0000000000000L00000H@3oool400000:H0oooo2@00000T0?ooo`040<30`000000000000820P0d0
oooo100000000`20P800oooo0?ooo`2A0?ooo`00603oool40820P1<0oooo00<0@410000000000000
0P00000@0?ooo`030410@020P800oooo00/0oooo00<0P8200000000000001`00001Q0?ooo`050820
P0000000000000000020P800Y@3oool900000100oooo1020P80A0?ooo`030<30`0000000000000d0
oooo00D0P82000000000000000000820P02C0?ooo`00603oool400000180oooo00<0P82000000000
00000P0000000`30`<00oooo0?ooo`0?0?ooo`030820P010@400oooo00X0oooo00<0P82000000000
00001`00001P0?ooo`80P820100000000`20P800`<300?ooo`1?0?ooo`050<30`020P80000000000
0020P800CP3oool900000100oooo1000000C0?ooo`80@410303oool01@20P8000000000000000000
P82009<0oooo000H0?ooo`@000004P3oool5000001<0oooo0P20P80:0?ooo`030820P00000000000
00L00000GP3oool;000000030820P03oool0oooo04`0oooo00<0P8200000000000000P00001>0?oo
o`T00000403oool4000001<0oooo00<0P8200000003oool02`3oool01@20P8000000000000000000
P82009<0oooo000H0?ooo`050820P0000000000000000020P800403oool00`30`<00000000000002
000000030820P03oool0oooo01d0oooo00<0P8200000000000001`00001L0?ooo`030820P0000000
00000080000000<0P8200410@00000000P0000020410@0<0000000<0P8200?ooo`3oool0BP3oool6
000004d0oooo2@00000@0?ooo`050820P0000000000000000020P8004`3oool20410@0/0oooo00D0
P82000000000000000000820P02C0?ooo`00603oool01@20P8000000000000000000P8200100oooo
00<0P8200000000000000P0000000`20P800oooo0?ooo`0M0?ooo`030820P0000000000000L00000
F`3oool01@10@4000000000000000000@4100080oooo00P0P82000000000000000000820P03oool0
`<300410@0<0000000<0`<300?ooo`3oool0B03oool6000004d0oooo2@00000@0?ooo`050820P000
0000000000000020P800503oool2000000X0oooo00D0P82000000000000000000820P02C0?ooo`00
603oool01@30`<000000000000000000@4100100oooo00<0@4100000000000000P00000P0?ooo`03
0820P0000000000000L00000FP3oool00`20P800000000000002000000<0oooo00D0`<3000000000
000000000820P0030?ooo`050820P0000000000000000020P800B@3oool00`20P800000000000002
000004h0oooo2@00000@0?ooo`050<30`0000000000000000010@400503oool00`30`<0000000410
@00:0?ooo`@00000T`3oool001T0oooo1000000@0?ooo`D00000803oool00`20P800000000000007
000005T0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`020?ooo`@00000103oool0
1@30`<000000000000000000@41004X0oooo0P20P81?0?ooo`T000004@3oool4000001H0oooo00<0
00000410@020P8002020P804000009<0oooo000I0?ooo`@00000403oool500000200oooo00<0P820
0000000000001`00001I0?ooo`D0000000<0P8200?ooo`3oool00P3oool4000000D0oooo10000000
0`20P800oooo0?ooo`2H0?ooo`T000004@3oool4000001H0oooo00<0P8200000000000003000002C
0?ooo`006@3oool01@10@4000000000000000000`<3000l0oooo1@00000P0?ooo`030820P0000000
000000L00000F03oool00`30`<00000000000003000000D0oooo00@0@41000000000000000001@3o
ool00`30`<00000000000002000009X0oooo2@00000A0?ooo`050820P0000000000000000020P800
5P3oool00`10@40000000820P0070820P0@00000T`3oool001T0oooo00D0P8200000000000000000
0820P00?0?ooo`D00000803oool00`20P800000000000007000005P0oooo00<0P820000000000000
0`0000050?ooo`050820P0000000000000000030`<001@3oool01@10@4000000000000000000@410
09T0oooo2@00000B0?ooo`@000005P3oool00`30`<0000000820P0070?ooo`@00000T`3oool001T0
oooo00D0P82000000000000000000820P00?0?ooo`D00000803oool00`20P8000000000000070000
05P0oooo00<0P8200000000000000`0000050?ooo`050<30`0000000000000000020P8001@3oool0
0`30`<00000000000002000000030820P03oool0oooo09H0oooo2@00000B0?ooo`@000005`3oool0
0`20P80000000410@0060?ooo`030820P0000000000000800000TP3oool001X0oooo1000000?0?oo
o`030820P000000000000080000000<0P8200?ooo`3oool07@3oool00`20P8000000000000070000
05P0oooo00<0P8200000000000000`0000060?ooo`<0000000<0P8200?ooo`3oool0103oool50000
04P0oooo0P20P81>0?ooo`T000004P3oool01@20P8000000000000000000P82001L0oooo0P000007
0?ooo`@00000TP3oool001P0oooo00<0`<300820P00000000`0000020820P0d0oooo00<0P8200000
000000000P0000000`20P800oooo0?ooo`0M0?ooo`030820P0000000000000L00000F03oool00`20
P800000000000003000000H0oooo0`0000000`20P800oooo0?ooo`040?ooo`030820P00000000000
0080000000<0`<300?ooo`3oool0A@3oool00`20P800@4100?ooo`1=0?ooo`T00000403oool00`30
`<00P8200410@003000000030410@020P800oooo01H0oooo0P10@4060?ooo`@00000TP3oool001D0
oooo00<0`<300000000000002P0000000`20P800oooo0?ooo`080?ooo`030820P000000000000080
000000<0P8200?ooo`3oool07@3oool00`20P800000000000007000005P0oooo00<0P82000000000
00000`0000060?ooo`040820P00000000000000000L0oooo100000000`20P800oooo0?ooo`160?oo
o`030000003oool0oooo04`0oooo2@00000>0?ooo`030410@0000000000000T0000000<0@4100<30
`03oool04P3oool00`30`<0000000<30`0050?ooo`@00000TP3oool001@0oooo00L0@41000000000
000000000410@030`<00P82000<0000000<0P8200?ooo`20P8000`0000000`10@400`<300?ooo`07
0?ooo`D000007`3oool00`20P800000000000007000005T0oooo1@0000000`20P800oooo0?ooo`03
0?ooo`040820P00000000000000000L0oooo00D0@41000000000000000000410@00@0?ooo`030<30
`020P800P82001/0P8206P3oool2000004d0oooo2@00000<0?ooo`070410@0000000000000000010
@400P8200?ooo`04000000030?ooo`20P80000000080000000<0@4100820P03oool04@3oool00`30
`<0000000820P0040?ooo`@00000TP3oool001<0oooo1@0000020?ooo`050820P000000000000000
0020P8000`3oool4000000P0oooo1@00000O0?ooo`030820P0000000000000L00000F@3oool50000
00030820P03oool0oooo00<0oooo00@0P82000000000000000001`3oool00`20P800000000000002
00000100oooo00<0P8200000000000006`00000J0?ooo`030820P0000000P82004`0oooo2@00000;
0?ooo`030820P00000000000008000000`3oool4000000<0oooo00D0P82000000000000000000820
P00B0?ooo`800000103oool400000980oooo000B0?ooo`030820P00000000000008000000`3oool0
1@30`<000000000000000000P82000<0oooo00D0`<3000000000000000000410@0070?ooo`030820
P000000000000080000000<0P8200?ooo`3oool0703oool00`20P800000000000007000005T0oooo
00<0P8200000000000000P0000000`20P800oooo0?ooo`040?ooo`<0000000<0P8200?ooo`3oool0
103oool00`20P80000000000000200000100oooo00<0`<300820P020P8006`20P80J0?ooo`030820
P0000000@41004`0oooo2@00000;0?ooo`@0000000D0P8200?ooo`3oool0oooo0410@003000000@0
oooo00D0@41000000000000000000<30`00A0?ooo`030<30`0000000@41000<0oooo00D0P8200000
0000000000000820P02A0?ooo`004@3oool00`30`<00000000000002000000030820P03oool0oooo
0080oooo100000050?ooo`040410@000000000000410@0L0oooo100000000`10@400oooo0?ooo`0L
0?ooo`030820P0000000000000L00000FP3oool5000000H0oooo0`0000000`20P800oooo0?ooo`04
0?ooo`030820P0000000000000800000B@3oool2000000030<30`03oool0oooo04T0oooo2@00000:
0?ooo`030410@0000000000000800000103oool01@20P8000000000000000000P82000@0oooo00D0
@41000000000000000000<30`00B0?ooo`0500000020P800oooo0?ooo`20P8000`0000000`20P800
oooo0?ooo`2?0?ooo`004@3oool00`20P800000000000002000000030<30`03oool0oooo0080oooo
100000050?ooo`030<30`000000000000080000000<0`<300?ooo`3oool00`3oool00`20P8000000
00000002000000030820P03oool0oooo0140oooo00<0P8200?ooo`3oool01`3oool00`20P8000000
00000007000005X0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`040?ooo`800000
00<0P8200?ooo`3oool0103oool00`20P800000000000002000004X0oooo00<0@41000000030`<00
BP3oool9000000X0oooo100000000`10@400oooo0?ooo`020?ooo`050820P0000000000000000020
P800103oool00`30`<00000000000002000000030820P03oool0oooo00l0oooo00D0`<3000000030
`<00oooo0820P003000000030820P03oool0oooo08l0oooo000A0?ooo`D000001P3oool3000000H0
oooo00D0P82000000000000000000820P0060?ooo`D000004`3oool00`000000oooo0?ooo`070?oo
o`030820P0000000000000L00000F`3oool4000000030820P03oool0oooo00@0oooo0`0000060?oo
o`030820P0000000000000800000BP3oool00`20P80000000000001:0?ooo`T000002@3oool50000
00030820P03oool0oooo00<0oooo0`0000000`20P800oooo0?ooo`040?ooo`@000004P3oool01020
P80000000?ooo`20P803000000030820P03oool0oooo08l0oooo000A0?ooo`D000001P3oool30000
00030820P03oool0oooo00<0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`040?oo
o`@0000000<0P8200?ooo`3oool0403oool2000000P0oooo00<0P8200000000000001`00001K0?oo
o`030410@00000000000008000001P3oool3000000H0oooo00<0P8200000000000000P00001;0?oo
o`040410@000000000000<30`4P0oooo2@0000090?ooo`D0000000<0P8200?ooo`3oool00`3oool3
000000030410@03oool0oooo00@0oooo00D0@41000000000000000000410@00A0?ooo`040<30`000
0000P8200820P0<0000000<0P8200?ooo`3oool0S`3oool00140oooo1@0000060?ooo`040410@000
00000000000000H0oooo00D0@41000000000000000000410@0060?ooo`030<30`000000000000080
000000<0`<300?ooo`3oool03`3oool2000000P0oooo00<0P8200000000000001`00001K0?ooo`03
0<30`000000000000080000000<0@4100?ooo`3oool00`3oool00`20P8000000000000060?ooo`05
0410@0000000000000000020P800C03oool01010@400000000000020P8170?ooo`T000002@3oool5
000000030820P03oool0oooo00<0oooo00@0@41000000000000000001P3oool00`30`<0000000000
0002000000030<30`03oool0oooo00l0oooo00<0P8200000000000000`0000000`10@400oooo0?oo
o`2?0?ooo`004@3oool5000000H0oooo00@0P82000000000000000001P3oool00`20P80000000000
0002000000L0oooo00D0`<3000000000000000000410@00A0?ooo`80000000<0P8200?ooo`3oool0
1@3oool00`20P800000000000007000005`0oooo00<0`<300000000000000P0000000`20P800oooo
0?ooo`020?ooo`040820P000000000000<30`0@0oooo00<0P8200000000000000P0000000`30`<00
oooo0?ooo`1:0?ooo`060<30`0000000000000000010@400P820A@3oool9000000T0oooo1@000000
0`20P800oooo0?ooo`030?ooo`040820P00000000000000000L0oooo100000000`20P800oooo0?oo
o`0@0?ooo`030820P0000000000000<00000T@3oool00140oooo1@0000060?ooo`040820P0000000
0000000000L0oooo100000000`20P800oooo0?ooo`050?ooo`050820P0000000000000000020P800
3`3oool01020P800000000000020P8070?ooo`030820P0000000000000L00000GP3oool400000003
0820P03oool0oooo0080oooo0P0000000`20P800oooo0?ooo`020?ooo`D000004@3oool00`20P800
00000000000K00000200oooo100000000`20P800oooo0?ooo`120?ooo`T000002@3oool500000003
0820P03oool0oooo00<0oooo00@0P82000000000000000001`3oool00`20P8000000000000020000
01<0oooo00<0P8200000000000000P00002A0?ooo`004@3oool5000000L0oooo0`0000000`20P800
oooo0?ooo`040?ooo`@0000000<0P8200?ooo`3oool01P3oool01@20P8000000000000000000P820
00h0oooo00@0P82000000000000000001`3oool00`20P800000000000007000005h0oooo00<0`<30
0000000000000P0000001030`<00oooo0?ooo`3oool2000000050820P03oool0oooo0?ooo`10@400
0`0000000`10@400oooo0?ooo`0@0?ooo`030820P0000000000001/00000803oool00`30`<000000
00000002000000030820P03oool0oooo0440oooo2@0000090?ooo`D0000000<0P8200?ooo`3oool0
103oool3000000030820P03oool0oooo00@0oooo00<0P8200000000000000P00000C0?ooo`030<30
`0000000000000800000T@3oool00140oooo00<0P8200000000000000P0000000`20P800oooo0?oo
o`040?ooo`<0000000<0P8200?ooo`3oool0103oool01@10@4000000000000000000@41000T0oooo
00D0`<3000000000000000000410@00=0?ooo`@000001`3oool00`20P800000000000007000005l0
oooo00<0`<300410@00000000P0000000`10@400P8200?ooo`02000000040820P03oool0`<300410
@0<0000000<0@4100?ooo`3oool0D03oool00`30`<00000000000002000000030410@03oool0oooo
0400oooo2@00000:0?ooo`D000001P3oool3000000030820P03oool0oooo00@0oooo00<0`<300000
000000000P0000000`30`<00oooo0?ooo`0A0?ooo`040<30`0000000000000000940oooo000A0?oo
o`030820P000000000000080000000<0P8200?ooo`3oool0103oool01010@400000000000010@406
0?ooo`030820P00000000000008000002`3oool01@20P800000000000010@400`<3000X0oooo00<0
@4100000000000000P0000000`20P800oooo0?ooo`040?ooo`030820P0000000000000L00000HP3o
ool00`20P80000000000000:000000030820P03oool0oooo0580oooo00<0P8200000000000000`00
00000`30`<00oooo0?ooo`0n0?ooo`T000002P3oool5000000H0oooo00@0P820000000000000@410
1`3oool4000000030820P03oool0oooo0180oooo00@0@410000000000000`<30T03oool00180oooo
100000000`10@400oooo0?ooo`040?ooo`040820P00000000000000000H0oooo00<0P82000000000
00000P00000=0?ooo`060<30`010@400000000000020P800`<30103oool01@30`<00@41000000000
0000@4100080P82000<000000820P03oool01@3oool00`20P800000000000007000006D0oooo0P20
P8000`10@4000000000000020820P0030<30`03oool0oooo05H0oooo00<0P8200000000000000`00
00000`30`<00oooo0?ooo`0m0?ooo`T000002P3oool00`20P800000000000002000000030<30`03o
ool0oooo00@0oooo0`0000070?ooo`@0000000<0P8200?ooo`3oool04`3oool00`20P80000000820
P02@0?ooo`004P3oool5000000H0oooo00@0P82000000000000000001P3oool00`20P80000000000
000200000100oooo2P0000040?ooo`030820P0000000oooo00D0oooo00<0P8200000000000001`00
001X0?ooo`800000G03oool00`20P800000000000002000000030820P03oool0oooo03d0oooo2@00
000:0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0103oool3000000L0oooo1000
00000`20P800oooo0?ooo`0D0?ooo`0300000020P800oooo08l0oooo000B0?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool0103oool3000000H0oooo00<0P8200000000000000P00000B
0?ooo`030<30`020P800P8200080P82000<0`<300?ooo`3oool01@3oool00`20P800oooo0?ooo`04
0?ooo`030820P0000000000000L00000J03oool3000005/0oooo00<0`<300000000000000`00000o
0?ooo`T000002`3oool4000000030410@03oool0oooo00@0oooo00<0P8200000000000001`3oool4
000000030820P03oool0oooo01@0oooo0P30`<2@0?ooo`004`3oool5000000030<30`03oool0oooo
00<0oooo0`0000000`20P800oooo0?ooo`030?ooo`030820P00000000000008000009P3oool00`20
P800000000000007000006P0oooo0`00001L0?ooo`030410@000000000000080000000<0P8200?oo
o`3oool0?03oool9000000/0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`030?oo
o`040820P00000000000000000H0oooo100000000`20P800oooo0?ooo`2V0?ooo`00503oool40000
00030410@03oool0oooo00<0oooo00@0@410000000000000P8201@3oool01@20P800000000000000
0000@41002H0oooo00<0P8200000000000001`00001X0?ooo`030820P000000000000500oooo00@0
@410000000000000`<30203oool00`30`<00000000000002000000030820P03oool0oooo03`0oooo
2@00000<0?ooo`@0000000<0@4100?ooo`3oool00`3oool01030`<0000000000000000060?ooo`@0
000000<0`<300?ooo`3oool0YP3oool001@0oooo00<0P8200000000000000P0000000`20P800oooo
0?ooo`020?ooo`040820P000000000000820P0D0oooo100000000`20P800oooo0?ooo`0T0?ooo`03
0820P0000000000000L00000J03oool01020P800000000000020P81>0?ooo`030820P00000000000
008000002@3oool4000000030820P03oool0oooo03`0oooo2@00000<0?ooo`030820P00000000000
00<000001@3oool3000000D0oooo00<0P8200000000000000P00002Y0?ooo`005@3oool01@10@400
0000000000000000@41000@0oooo00@0P820000000000000@410103oool00`30`<00000000000002
000000030<30`03oool0oooo02@0oooo00<0P8200000000000001`00001X0?ooo`040<30`0000000
00000820P4h0oooo00<0P8200000000000000P0000090?ooo`@0000000<0P8200?ooo`3oool0?03o
ool9000000d0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`020?ooo`<0000000<0
`<300?ooo`3oool00P3oool01@10@4000000000000000000@4100:T0oooo000F0?ooo`050410@000
0000000000000010@400103oool3000000@0oooo00D0@41000000000000000000410@00W0?ooo`03
0820P0000000000000L00000J@3oool2000000030820P03oool0oooo04`0oooo00D0P82000000000
000000000410@0090?ooo`@0000000<0`<300?ooo`3oool0?03oool9000000h0oooo00<0`<300000
000000000P0000001@30`<00oooo0?ooo`3oool0P8200080000000D0P8200?ooo`3oool0oooo0<30
`004000000030<30`03oool0oooo0:L0oooo000G0?ooo`030820P000000000000080000000<0P820
0?ooo`3oool00`0000030?ooo`050410@0000000000000000010@400:03oool00`20P80000000000
0007000006T0oooo00<0@41000000010@400C`3oool3000000030<30`03oool0oooo00H0oooo00D0
`<3000000000000000000410@00o0?ooo`T000003`3oool00`30`<00000000000002000000040820
P03oool0oooo0820P080000000@0P8200?ooo`3oool0P820100000000`30`<00oooo0?ooo`2X0?oo
o`006@3oool5000000040?ooo`000000000000000080oooo1@00000Y0?ooo`030820P00000000000
00L00000J@3oool00`20P80000000000001?0?ooo`030820P0000000000000T0oooo00D0P8200000
0000000000000820P00o0?ooo`T000004@3oool500000080P8200P0000000`20P800oooo00000004
00000:`0oooo000J0?ooo`030820P0000000000000X0000000<0P8200?ooo`3oool0:03oool00`20
P800000000000007000006T0oooo00<0P820000000000000C`3oool01030`<00000000000030`<07
0?ooo`050<30`0000000000000000010@400@03oool900000180oooo00<0`<300410@00000002P00
00000`10@400`<300?ooo`2[0?ooo`007@3oool00`30`<00P8200820P002000000030410@020P800
P82002d0oooo00<0P8200000000000001`00001Y0?ooo`040<30`000000000000<30`4l0oooo00@0
`<300820P0000000P820103oool01P30`<00P820000000000000@4100820P440oooo2@00000F0?oo
o`80P8200`0000020820P;00oooo000P0?ooo`030820P0000000@41002l0oooo00<0P82000000000
00001`00002n0?ooo`030<30`020P800000000D0000000<0P8200<30`03oool0@P3oool9000001P0
oooo00@0P820000000000000`<30/@3oool00200oooo00<0P820000000000000;`3oool00`20P800
00000000000700000?l0oooo303oool9000001P0oooo00@0P820000000000000P820/@3oool00200
oooo00<0P820000000000000;`3oool00`20P80000000000000700000?l0oooo303oool9000001P0
oooo00@0P820000000000000P820/@3oool00240oooo0P00000_0?ooo`030820P0000000000000L0
0000o`3oool<0?ooo`T000006@3oool2000000030820P03oool0oooo0:l0oooo000Q0?ooo`<00000
;P3oool00`20P80000000000000700000?l0oooo303oool9000001T0oooo0`00002a0?ooo`008@3o
ool00`20P80000000000000^0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T000006P3o
ool200000;40oooo000Q0?ooo`030820P0000000000002h0oooo00<0P8200000000000001`00003o
0?ooo``0oooo2@00000J0?ooo`800000/@3oool00240oooo00@0`<30000000000000`<30;@3oool0
0`20P80000000000000700000?l0oooo303oool9000001X0oooo00<0@41000000030`<00/03oool0
0280oooo0P0000000`20P800oooo0?ooo`0[0?ooo`030820P0000000000000L00000o`3oool<0?oo
o`T000006P3oool00`20P80000000820P02`0?ooo`008P3oool2000000030820P03oool0oooo02/0
oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00000J0?ooo`030820P0000000P8200;00
oooo000R0?ooo`030410@0000000@41002d0oooo00<0P8200000000000001`00003o0?ooo``0oooo
2@00000J0?ooo`030<30`0000000@4100;00oooo001B0?ooo`030820P0000000000000L00000o`3o
ool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=
0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`03
0820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P820000000000000
1`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303o
ool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool0
0580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P800
00000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000
o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00
003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?oo
o`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P82000000000
00001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo
303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3o
ool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20
P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L0
0000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo
2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B
0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000
000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0
oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000
c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool0
0`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P00000000000
00L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0
oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo
001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P820
0000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P8000000000000070000
0?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T0
0000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3o
ool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000
000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?oo
o``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0
oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0
P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P800000000000007
00000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?oo
o`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00
DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P000
0000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o
0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool90000
0<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo
00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000
000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<
0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?oo
o`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820
P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00
003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool9
00000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580
oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P8000000
0000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3o
ool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=
0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`03
0820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P820000000000000
1`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303o
ool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool0
0580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P800
00000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000
o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00
003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?oo
o`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P82000000000
00001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo
303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3o
ool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20
P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L0
0000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo
2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B
0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000
000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0
oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000
c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool0
0`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P00000000000
00L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0
oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo
001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P820
0000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P8000000000000070000
0?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T0
0000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3o
ool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000
000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?oo
o``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0
oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0
P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P800000000000007
00000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?oo
o`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00
DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P000
0000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o
0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool90000
0<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo
00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000
000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<
0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?oo
o`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820
P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00
003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool9
00000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580
oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P8000000
0000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3o
ool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=
0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`03
0820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P820000000000000
1`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303o
ool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool0
0580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P800
00000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000
o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00
003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?oo
o`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P82000000000
00001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo
303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3o
ool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20
P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L0
0000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo
2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo001B
0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000
000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0
oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000
c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool0
0`20P80000000000000700000?l0oooo303oool900000<d0oooo001B0?ooo`030820P00000000000
00L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0
oooo2@00003=0?ooo`00DP3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo
001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool00580oooo00<0P820
0000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00DP3oool00`20P8000000000000070000
0?l0oooo303oool900000<d0oooo001B0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T0
0000c@3oool00580oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00<P3o
ool40820P0030<30`03oool0oooo01T0oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00
003=0?ooo`00;`3oool01020P800000000000010@4030820P08000000P20P80H0?ooo`030820P000
0000000000L00000o`3oool<0?ooo`T00000c@3oool002d0oooo00D0P820000000000000P8200<30
`0050?ooo`050<30`020P80000000410@030`<005P3oool00`20P80000000000000700000?l0oooo
303oool900000<d0oooo000/0?ooo`<0000000<0P8200?ooo`3oool01`3oool00`20P80000000000
000F0?ooo`030820P0000000000000L00000o`3oool<0?ooo`T00000c@3oool002/0oooo00D0`<30
00000000000000000410@00:0?ooo`040410@000000000000410@1@0oooo00<0P820000000000000
1`00003o0?ooo``0oooo2@00003=0?ooo`00;03oool4000000/0oooo00@0@410000000000000@410
4`3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo000]0?ooo`@000002`3o
ool3000000030<30`03oool0oooo0100oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00
003=0?ooo`00;@3oool4000000`0oooo0`00000B0?ooo`030820P0000000000000L00000o`3oool<
0?ooo`T00000c@3oool002d0oooo00D0@41000000000000000000<30`00;0?ooo`040410@0000000
00000820P140oooo00<0P8200000000000001`00003o0?ooo``0oooo2@00003=0?ooo`00;@3oool0
1@20P8000000000000000000P82000/0oooo00D0`<3000000000000000000820P00@0?ooo`030820
P0000000000000L00000o`3oool<0?ooo`T00000c@3oool002h0oooo1000000<0?ooo`@0000000<0
`<300?ooo`3oool03@3oool00`20P80000000000000700000?l0oooo303oool900000<d0oooo000^
0?ooo`@00000303oool01@20P8000000000000000000P82000l0oooo00<0P8200000000000001`00
003o0?ooo``0oooo2@00003=0?ooo`00;P3oool01@10@4000000000000000000`<3000/0oooo00D0
P82000000000000000000410@00?0?ooo`030820P000000000000?l000007000003=0?ooo`00;P3o
ool01@20P8000000000000000000P82000`0oooo100000000`30`<00oooo0?ooo`0<0?ooo`030820
P000000000000?l000007000003=0?ooo`00;`3oool4000000`0oooo100000000`20P800oooo0?oo
o`0<0?ooo`030820P000000000000?l000007000003=0?ooo`00;`3oool4000000`0oooo10000000
0`20P800oooo0?ooo`0<0?ooo`030820P000000000000?l000007000003=0?ooo`00;`3oool01@10
@4000000000000000000P82000/0oooo1@00000>0?ooo`030820P000000000000?l000007000003=
0?ooo`00;`3oool01@20P8000000000000000000@41000/0oooo00<0@4100000000000000P00000>
0?ooo`030820P000000000000?l000007000003=0?ooo`00<03oool4000000030820P03oool0oooo
00P0oooo1@00000>0?ooo`030820P000000000000?l000007000003=0?ooo`00<03oool500000003
0<30`03oool0oooo00L0oooo1@00000>0?ooo`030820P000000000000?l000007000003=0?ooo`00
<@3oool5000000T0oooo1@00000>0?ooo`030820P000000000000?l000007000003=0?ooo`00<@3o
ool400000080@4101`3oool00`10@400000000000002000000030410@03oool0oooo0100oooo0P00
003o0?ooonH0oooo000a0?ooo`090820P0000000000000000020P800@41000000020P800`<3000<0
oooo00<0@4100000000000000`0000000`20P800oooo0?ooo`0@0?ooo`800000o`3ooooV0?ooo`00
<@3oool01`20P8000000000000000000@4100?ooo`10@4002P0000000`10@400oooo0?ooo`0A0?oo
o`800000o`3ooooV0?ooo`00<P3oool400000080oooo2P0000000`20P800oooo0?ooo`0A0?ooo`80
0000o`3ooooV0?ooo`00<P3oool4000000<0oooo00<0P820000000000000100000000`10@400oooo
0?ooo`0C0?ooo`800000o`3ooooV0?ooo`00<P3oool01@20P8000000000000000000P82000@0oooo
00D0`<300820P020P800P8200<30`00F0?ooo`800000o`3ooooV0?ooo`00<P3oool01@20P8000000
000000000000@41001l0oooo0P00003o0?ooonH0oooo000c0?ooo`@000007`3oool200000?l0oooo
iP3oool003<0oooo1000000O0?ooo`800000o`3ooooV0?ooo`00<`3oool01@20P800000000000000
0000P82001h0oooo0P0000260?ooo`030820P0000000000000l000000P20P83o0?oood`0oooo000c
0?ooo`050820P0000000000000000010@4007P3oool2000008T0oooo00<0P8200000000000000`00
00060820P0030410@0000000000000@0000000<0P8200?ooo`3oool0o`3ooom70?ooo`00=03oool4
000001h0oooo0P00002:0?ooo`030820P0000000000000800000203oool6000000030820P03oool0
oooo0?l0ooooAP3oool003@0oooo100000000`20P800oooo0?ooo`0K0?ooo`800000RP3oool00`30
`<00000000000002000000T0oooo00<0`<300000000000000`0000000`30`<00oooo0?ooo`3o0?oo
odD0oooo000e0?ooo`@000007@3oool2000007@0oooo1020P80C0?ooo`030820P000000000000080
00002P3oool00`10@400000000000002000000030<30`03oool0oooo0?l0ooooA03oool003D0oooo
100000000`30`<00oooo0?ooo`0J0?ooo`800000M03oool4000001@0oooo100000000`30`<00oooo
0?ooo`070?ooo`030<30`0000000000000<00000o`3ooom60?ooo`00=@3oool01@20P80000000000
00000000P82001`0oooo0P00001d0?ooo`@00000503oool01@20P8000000000000000000P82000/0
oooo1@00003o0?ooodD0oooo000e0?ooo`@0000000<0@4100?ooo`3oool06P3oool2000007@0oooo
00D0P82000000000000000000820P00C0?ooo`050820P0000000000000000020P8002`3oool50000
0?l0ooooA@3oool00340oooo2@00000L0?ooo`800000M03oool01@20P8000000000000000000P820
01<0oooo00<0`<300000000000000P00000;0?ooo`030820P000000000000080000000<0P8200?oo
o`3oool0o`3ooom20?ooo`00<P3oool01030`<00P8200820P020P804000000030<30`03oool0oooo
01T0oooo0P00001d0?ooo`050<30`0000000000000000010@400503oool4000000030<30`03oool0
oooo00P0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`3o0?oood80oooo000i0?oo
o`0300000020P800oooo01X0oooo0P00001e0?ooo`@00000503oool01@20P8000000000000000000
P82000X0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`3o0?oood80oooo001F0?oo
o`800000M@3oool4000001@0oooo00D0P82000000000000000000410@00:0?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool0o`3ooom20?ooo`00EP3oool2000007D0oooo00D0@4100000
0000000000000<30`00D0?ooo`@000002P3oool00`10@40000000000000200000?l0ooooA@3oool0
05H0oooo0P00001e0?ooo`050820P0000000000000000020P800503oool4000000030<30`03oool0
oooo00H0oooo00D0P82000000000000000000410@03o0?ooodH0oooo001F0?ooo`800000M@3oool0
1@20P8000000000000000000P82001@0oooo00D0P82000000000000000000820P0070?ooo`060<30
`0000000000000000010@400`<30o`3ooom60?ooo`00EP3oool2000007H0oooo1000000D0?ooo`03
0820P00000000000008000001P3oool00`20P80000000000000200000?l0ooooB03oool005H0oooo
0P00001d0?ooo`030<30`020P800000000<000000P20P80C0?ooo`@000001@20P804000000030820
P03oool0oooo0?l0ooooA`3oool005H0oooo0P00001a0?ooo`030<30`0000000000000X0000000<0
P8200<30`03oool03P3oool5000000030410@020P800P8200080P8200`0000000`10@400P8200?oo
o`3o0?ooodL0oooo001F0?ooo`800000L03oool01`10@4000000000000000000@4100<30`03oool0
100000000`3oool0P82000000002000000030410@030`<00oooo00d0oooo100000060?ooo`030<30
`020P80000000080000000<0P8200?ooo`3oool0o`3ooom40?ooo`00EP3oool2000006l0oooo00<0
P8200000000000000P0000030?ooo`@000000`3oool4000000h0oooo100000000`20P800oooo0?oo
o`050?ooo`030820P0000000000000800000o`3ooom50?ooo`00EP3oool2000006l0oooo10000000
1@20P800oooo0?ooo`3oool0@41000<00000103oool01@10@4000000000000000000`<3000`0oooo
00D0P82000000000000000000820P0080?ooo`030410@000000000000080000000<0`<300?ooo`3o
ool0o`3ooom10?ooo`00EP3oool2000006d0oooo00<0`<300000000000000`0000040?ooo`050820
P0000000000000000020P800103oool01@10@4000000000000000000`<3000/0oooo00D0`<300000
0000000000000410@0090?ooo`@0000000<0@4100?ooo`3oool0o`3ooom10?ooo`00EP3oool20000
06d0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`020?ooo`050820P00000000000
00000020P800103oool00`30`<00000000000002000000030<30`03oool0oooo00T0oooo10000009
0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0o`3ooom00?ooo`00EP3oool20000
06d0oooo1@0000060?ooo`<0000000<0P8200?ooo`3oool00`3oool01@20P8000000000000000000
P82000/0oooo100000000`20P800oooo0?ooo`070?ooo`@0000000<0P8200?ooo`3oool0o`3ooom0
0?ooo`00EP3oool2000006d0oooo1@0000060?ooo`<0000000<0@4100?ooo`3oool00`3oool00`30
`<00000000000002000000030<30`03oool0oooo00P0oooo00D0P82000000000000000000820P009
0?ooo`D00000o`3ooom20?ooo`00EP3oool2000006d0oooo1@0000060?ooo`040410@00000000000
000000H0oooo00D0P82000000000000000000410@00:0?ooo`050<30`0000000000000000010@400
2@3oool500000?l0oooo@P3oool005H0oooo0P00001]0?ooo`D000001P3oool01020P80000000000
000000070?ooo`@000002`3oool4000000T0oooo1@00003o0?oood80oooo001F0?ooo`800000K@3o
ool5000000H0oooo00@0P82000000000000000001`3oool00`20P800000000000002000000X0oooo
100000000`20P800oooo0?ooo`060?ooo`D00000o`3ooom20?ooo`00EP3oool2000006d0oooo1@00
00070?ooo`<0000000<0P8200?ooo`3oool0103oool00`20P800000000000002000000X0oooo00D0
P82000000000000000000820P0070?ooo`030820P000000000000080000000<0P8200?ooo`3oool0
o`3ooom00?ooo`00EP3oool2000006d0oooo00<0P8200000000000000`0000060?ooo`<0000000<0
P8200?ooo`3oool0103oool00`30`<00000000000002000000030<30`03oool0oooo00L0oooo00<0
P8200000000000000P0000070?ooo`@0000000<0@4100?ooo`3oool0o`3ooom10?ooo`00EP3oool2
000006d0oooo00<0P8200000000000000`0000060?ooo`040410@000000000000410@0L0oooo1000
00000`20P800oooo0?ooo`070?ooo`030820P00000000000008000001@3oool00`20P80000000000
0002000000030410@03oool0oooo0?l0oooo@P3oool005H0oooo0P00001^0?ooo`D000001P3oool0
1020P80000000000000000070?ooo`@0000000<0P8200?ooo`3oool01P3oool00`20P80000000000
000=00000?l0ooooA@3oool005H0oooo0P00001^0?ooo`D0000000<0P8200?ooo`3oool00`3oool0
1020P80000000000000000070?ooo`@0000000<0P8200?ooo`3oool00`3oool00`30`<0000000000
000<000000030410@020P800`<300?l0ooooAP3oool005H0oooo0P00001_0?ooo`@0000000<0@410
0?ooo`3oool0103oool3000000L0oooo100000000`20P800oooo0?ooo`3o0?oooe/0oooo001F0?oo
o`800000K`3oool00`20P800000000000002000000030<30`03oool0oooo00<0oooo0`0000000`20
P800oooo0?ooo`040?ooo`@0000000<0P8200?ooo`3oool0o`3ooomK0?ooo`00EP3oool200000700
oooo100000000`10@400oooo0?ooo`030?ooo`040820P000000000000820P0H0oooo100000000`30
`<00oooo0?ooo`3o0?oooe/0oooo001F0?ooo`800000L03oool00`20P80000000000000200000003
0820P03oool0oooo00<0oooo0P0000000`20P800oooo0?ooo`030?ooo`030820P000000000000080
0000o`3ooomN0?ooo`00EP3oool200000740oooo00D0@41000000000000000000410@0050?ooo`80
000000<0@4100?ooo`3oool00`3oool01@10@4000000000000000000P8200?l0ooooGP3oool005H0
oooo0P00001b0?ooo`030820P000000000000080000000D0`<300?ooo`3oool0oooo0820P0020000
00@0oooo00D0P82000000000000000000410@03o0?oooel0oooo001F0?ooo`800000L`3oool00`30
`<00000000000002000000040820P03oool0oooo0820P08000000`3oool01@10@400000000000000
0000@4100?l0ooooH03oool005H0oooo0P00001e0?ooo`D0000000@0oooo0820P000000000000P3o
ool500000?l0ooooH@3oool005H0oooo0P00001f0?ooo`030820P010@400000000X0000000<0@410
0<30`03oool0o`3ooomP0?ooo`00EP3oool2000007T0oooo00<0`<300820P020P8000`0000020820
P?l0ooooI@3oool005H0oooo0P00001l0?ooo`040820P000000000000<30`?l0ooooIP3oool005H0
oooo0P00001l0?ooo`040820P000000000000820P?l0ooooIP3oool005H0oooo0P00001l0?ooo`04
0820P000000000000820P?l0ooooIP3oool005H0oooo0P00001m0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooomT0?ooo`00EP3oool2000007d0oooo0`00003o0?ooofH0oooo001F0?ooo`800000O@3o
ool00`20P80000000000003o0?ooofH0oooo001F0?ooo`800000O@3oool00`20P80000000000003o
0?ooofH0oooo001F0?ooo`800000O@3oool01030`<00000000000030`<3o0?ooofD0oooo001F0?oo
o`800000OP3oool2000000030820P03oool0oooo0?l0ooooH`3oool005H0oooo0P00001n0?ooo`80
000000<0P8200?ooo`3oool0o`3ooomS0?ooo`00EP3oool2000007h0oooo00<0P82000000010@400
o`3ooomU0?ooo`00EP3oool200000?l0ooooiP3oool005H0oooo0P00003o0?ooonH0oooo001F0?oo
o`800000o`3ooooV0?ooo`00EP3oool200000?l0ooooiP3oool005H0oooo0P00003o0?ooonH0oooo
001F0?ooo`800000o`3ooooV0?ooo`00EP3oool200000?l0ooooiP3oool005H0oooo0P00003o0?oo
onH0oooo001F0?ooo`800000o`3ooooV0?ooo`00EP3oool200000?l0ooooiP3oool005H0oooo0P00
003o0?ooonH0oooo001F0?ooo`800000o`3ooooV0?ooo`00EP3oool200000?l0ooooiP3oool005H0
oooo0P00003o0?ooonH0oooo001F0?ooo`800000o`3ooooV0?ooo`00EP3oool200000?l0ooooiP3o
ool005H0oooo0P00003o0?ooonH0oooo001F0?ooo`800000o`3ooooV0?ooo`00EP3oool200000?l0
ooooiP3oool005H0oooo0P00003o0?ooonH0oooo001F0?ooo`800000o`3ooooV0?ooo`00EP3oool2
00000?l0ooooiP3oool005H0oooo0P00003o0?ooonH0oooo001F0?ooo`800000o`3ooooV0?ooo`00
EP3oool200000?l0ooooiP3oool005H0oooo0P00003o0?ooonH0oooo001F0?ooo`800000o`3ooooV
0?ooo`00EP3oool200000180oooo00<000000410@03oool0o`3ooooA0?ooo`00EP3oool200000180
oooo0`00003o0?ooom40oooo001F0?ooo`8000004P3oool3000000030410@03oool0oooo0?l0oooo
cP3oool005H0oooo0P00000B0?ooo`030000003oool0P8200080000000<0`<300?ooo`3oool0o`3o
ooo<0?ooo`00EP3oool2000001D0oooo00@0`<30000000000000`<30o`3oooo=0?ooo`00EP3oool2
000001L0oooo0P00003o0?ooold0oooo001F0?ooo`8000005`3oool00`30`<0000000410@03o0?oo
ol`0oooo001F0?ooo`800000603oool01030`<00000000000030`<3o0?ooolX0oooo001F0?ooo`80
00006@3oool01030`<00000000000030`<3o0?ooolT0oooo001F0?ooo`8000006`3oool00`000000
P8200?ooo`3o0?ooolP0oooo001F0?ooo`8000006`3oool00`20P80000000<30`03o0?ooolP0oooo
001F0?ooo`8000006`3oool01020P800000000000030`<3o0?ooolL0oooo001F0?ooo`8000006`3o
ool01@20P8000000000000000000P8200?l0ooooaP3oool005H0oooo0P00000K0?ooo`D0000000<0
P8200?ooo`3oool0o`3oooo30?ooo`00EP3oool2000001/0oooo1@0000000`10@400oooo0?ooo`3o
0?oool<0oooo001F0?ooo`8000006`3oool4000000030?ooo`10@400@4100?l0ooooa03oool005H0
oooo0P00000K0?ooo`@0000000@0oooo0<30`0000000P820o`3oooo30?ooo`00EP3oool2000001/0
oooo100000020?ooo`030820P0000000oooo0?l0oooo`P3oool005H0oooo0P00000K0?ooo`<00000
00@0P8200?ooo`3oool0oooo0P0000000`30`<00oooo0?ooo`3o0?oookl0oooo001F0?ooo`800000
6`3oool3000000070820P03oool0oooo0?ooo`30`<0000000410@03o0?oool40oooo001F0?ooo`80
00006P3oool4000000030820P03oool0oooo00<0oooo00<000000820P03oool0o`3ooono0?ooo`00
EP3oool2000001X0oooo100000000`20P800oooo0?ooo`030?ooo`030<30`0000000`<300?l0oooo
_`3oool005H0oooo0P00000J0?ooo`@0000000<0P8200?ooo`3oool0103oool00`000000P8200?oo
o`3o0?oookh0oooo001?0?ooo`030<30`020P800000000X0000000<0@4100820P03oool04`3oool4
000000030820P03oool0oooo00@0oooo00<0`<3000000020P800o`3ooonn0?ooo`00CP3oool00`10
@40000000000000?00000180oooo100000080?ooo`030410@0000000`<300?l0oooo_@3oool004h0
oooo00<0P8200000000000003`00000B0?ooo`@000002@3oool200000?l0oooo_@3oool004h0oooo
00<0P8200000000000003P0000000`20P800oooo0?ooo`0?0?ooo`030820P0000000000000800000
2P3oool00`000000P8200?ooo`3o0?oook/0oooo001?0?oooa00000000<0P8200?ooo`3oool03`3o
ool00`20P800000000000002000000X0oooo0P10@43o0?oook`0oooo001?0?ooo`030410@0000000
000000d000004P3oool00`20P800000000000002000000X0oooo00<0`<3000000020P800o`3ooonk
0?ooo`00C`3oool00`20P80000000000000<000000030820P03oool0oooo0100oooo00<0P8200000
000000000P00000;0?ooo`030820P010@400oooo0?l0oooo^P3oool00500oooo3P00000C0?ooo`03
0820P00000000000008000002`3oool00`20P80000000?ooo`3o0?oookX0oooo001@0?ooo`d00000
00<0@4100?ooo`3oool04@3oool01@10@4000000000000000000P82000/0oooo00<0@41000000020
P800o`3ooonj0?ooo`00D03oool00`20P80000000000000:000000030820P03oool0oooo0140oooo
100000000`20P800oooo0?ooo`080?ooo`040410@0000000000000000?l0oooo^P3oool00500oooo
00<0`<300000000000002P00000C0?ooo`030410@000000000000080000000<0P8200?ooo`3oool0
1`3oool500000?l0oooo^P3oool00540oooo2`0000000`20P800oooo0?ooo`0=0?ooo`T000002P3o
ool500000?l0oooo^P3oool00540oooo00<0P820000000000000200000000`20P800oooo0?ooo`0=
0?ooo`030820P0000000000000H000002P3oool4000000030820P03oool0oooo0?l0oooo^03oool0
0580oooo2P00000D0?ooo`<0P82000<000000820P03oool02P3oool00`10@40000000<30`03o0?oo
ok/0oooo001B0?ooo`030820P0000000000000H0000000<0@4100?ooo`3oool0o`3ooooP0?ooo`00
D`3oool8000000030820P03oool0oooo0?l0ooooh03oool005<0oooo2000003o0?ooon<0oooo001C
0?ooo`030820P0000000000000@0000000<0@4100?ooo`3oool0o`3ooooQ0?ooo`00D`3oool00`30
`<00000000000004000000030<30`03oool0oooo0?l0ooooh@3oool005@0oooo1P00003o0?ooon@0
oooo001D0?ooo`030820P0000000000000800000o`3ooooU0?ooo`00E03oool00`20P80000000000
000200000?l0ooooi@3oool005D0oooo0`0000000`20P800oooo0?ooo`3o0?ooon<0oooo001E0?oo
o`040820P000000000000<30`?l0ooooi@3oool005H0oooo0P00003o0?ooonH0oooo001F0?ooo`03
0410@0000000oooo0?l0ooooi@3oool005H0oooo0P20P83o0?ooonH0oooo001G0?ooo`030<30`03o
ool0oooo0?l0ooooi03oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0
oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo?`3oool0
0?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3o
oolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00
o`3ooooo0?ooocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?oo
ocl0oooo003o0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o
0?ooool0oooo?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo
?`3oool00?l0ooooo`3ooolo0?ooo`00o`3ooooo0?ooocl0oooo003o0?ooool0oooo?`3oool00001
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{145.25, 175.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 3.9", "Caption",
  CellTags->"Fig. 3.9"],

Cell[TextData[{
  "The potential on the sides of the rectangle is specified by the four \
functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_A\)(y)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_B\)(x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Phi]\_C\)(y)\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_D\)(x)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t We first consider the special case where only ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_A\)(y)\)]],
  " is nonzero.  Then the homogeneous boundary conditions on the bottom and \
the top imply that ",
  Cell[BoxData[
      \(TraditionalForm\`Y(0) = \(Y(b) = 0\)\)]],
  ".  We again confront an eigenvalue problem for ",
  Cell[BoxData[
      \(TraditionalForm\`Y(y)\)]],
  ". The condition ",
  Cell[BoxData[
      \(TraditionalForm\`Y(0) = 0\)]],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(\(4\)\(\ \)\) = \(-C\_3\)\)]],
  " in Eq. ",
  ButtonBox["(3.2.6)",
    ButtonData:>"(3.2.6)",
    ButtonStyle->"Hyperlink"],
  ", so that ",
  Cell[BoxData[
      \(TraditionalForm\`Y(y)\  = \ 
        2\ \[ImaginaryI]\ C\_3\ sin\ \(\@\[Lambda]\) y\)]],
  ". The condition that ",
  Cell[BoxData[
      \(TraditionalForm\`Y(L) = 0\)]],
  " then implies that either ",
  Cell[BoxData[
      \(TraditionalForm\`C\_3 = 0\)]],
  " (trivial) or ",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Lambda]\ b = n\ \[Pi]\)]],
  ". Thus, we find that"
}], "Text",
  CellTags->"i:104"],

Cell[TextData[{
  "\t ",
  Cell[BoxData[
      \(TraditionalForm\`Y(y)\  = \ D\ sin\ n\ \[Pi]\ y/b\)]],
  ","
}], "NE2",
  CellTags->"(3.2.7)"],

Cell[" where", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = \(\[Lambda]\_n = \ \((n\ \[Pi]/b)\)\^2\)\
\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n\  = \ 1, 2, 3,  .. \)]]
}], "NE2",
  CellTags->"(3.2.8)"],

Cell["\<\
Since there are many solutions, we can superimpose them in order to \
match boundary conditions on the other two sides:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, 
          y) = \[Sum]\+n\((C\_\(1  n\)\ \[ExponentialE]\^\(n\ \[Pi]\ x/b\) + 
                C\_\(\(2\)  \(n\)\(\ \)\)\ \[ExponentialE]\^\(\(-n\)\ \[Pi]\ \
x/b\))\) sin\ \((n\ \[Pi]\ y/b)\)\)]],
  ","
}], "NE2",
  CellTags->"(3.2.9)"],

Cell[TextData[{
  "where, as usual, we have absorbed the constant ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " into the constants ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(1  n\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(2  n\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(3.2.9)",
    ButtonData:>"(3.2.9)",
    ButtonStyle->"Hyperlink"],
  " has an oscillatory form in the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-direction, and an exponential  form in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction.   This is because Laplace's equation implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 \[Phi]/\[PartialD]x\^2 = \(-\
\[PartialD]\^2 \[Phi]\)/\[PartialD]y\^2\)]],
  ".  Therefore, a solution that oscillates sinusoidally in ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ", satisfying ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 \[Phi]/\[PartialD]y\^2 = \(-\[Lambda]\
\_n\)\ \ \[Phi]\)]],
  ", must be exponential in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".  By the same token, one can also construct a solution that consists of \
sinusoids in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and exponentials in ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ". That solution does not match the given boundary conditions in this \
problem, but is required for other boundary conditions such as those for \
which ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_A = \(\[Phi]\_C = 0\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tTo find the constants ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(1  n\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(2\ n\)\)]],
  ", we now satisfy the remaining two boundary conditions. The potential is \
zero along the boundary specified by ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", which requires that we take ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(2\ n\) = \(-C\_\(1\ n\)\)\)]],
  " in Eq. ",
  ButtonBox["(3.2.9)",
    ButtonData:>"(3.2.9)",
    ButtonStyle->"Hyperlink"],
  ". We then obtain"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[Phi](x, 
        y) = \[Sum]\+n\( A\_n\) \(sinh(
            n\ \[Pi]\ x/b)\)\ sin\ \((n\ \[Pi]\ y/b)\)\)\(,\)\)\)]]], "NE2",
  CellTags->"(3.2.10)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`A\_\(\(n\)\(\ \)\) = 2\ C\_\(1\ n\)\)]],
  ".   The constants ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " in Eq. ",
  ButtonBox["(3.2.10)",
    ButtonData:>{"Chapter3.nb", "(3.2.10)"},
    ButtonStyle->"Hyperlink"],
  "  are determined by the boundary condition that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](a, y) = \(\[Phi]\_A\)(y)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_A\)(
          y) = \[Sum]\+\(n = 1\)\%\[Infinity]\( A\_n\) 
            sinh\ \((n\ \[Pi]\ a/b)\) \(\(sin(n\ \[Pi]\ y/b)\)\(.\)\)\)]]
}], "NE2",
  CellTags->"(3.2.11)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(3.2.11)",
    ButtonData:>"(3.2.11)",
    ButtonStyle->"Hyperlink"],
  " is a Fourier sine series for the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_A\)(y)\)]],
  " defined on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < y < b\)]],
  ". The Fourier coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`\(A\_n\) sinh\ \((n\ \[Pi]\ a/b)\)\)]],
  " is then determined by Eq. ",
  ButtonBox["(2.2.11)",
    ButtonData:>{"Chapter2.nb", "(2.2.11)"},
    ButtonStyle->"Hyperlink"],
  ", "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`A\_n\ sinh\ \((n\ \[Pi]\ a/
              b)\) = \(2\/b\) \(\[Integral]\_0\%b\(\( \[Phi]\_A\)(y)\) \(sin(
              n\ \[Pi]\ y/b)\) \(\(\[DifferentialD]y\)\(.\)\)\)\)]]], "NE2",
  CellTags->"(3.2.12)"],

Cell[TextData[{
  "Equations ",
  ButtonBox["(3.2.10)",
    ButtonData:>"(3.2.10)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.2.12)",
    ButtonData:>"(3.2.12)",
    ButtonStyle->"Hyperlink"],
  " provide the solution for the potential within a rectangular enclosure for \
which the potential is zero on three sides, and equals ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_A\)(y)\)]],
  " on the fourth side. \n\tFor instance, if ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_A\)(y)\  = \ sin\ \((n\ \[Pi]\ y/b)\)\)]],
  ", then the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  " consists of only a single term, "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, 
          y)\  = \ \(sinh(n\ \[Pi]\ x/b)\)\/\(sinh(n\ \[Pi]\ a/b)\)\ \(sin(
            n\ \[Pi]\ y/b)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "This solution is plotted in Cell ",
  ButtonBox["3.18",
    ButtonData:>"Cell 3.18",
    ButtonStyle->"Hyperlink"],
  " for the case ",
  Cell[BoxData[
      \(TraditionalForm\`n = 3\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`a = \(b = 1\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(a = \(b = 1\); \ n = 3;\), "\n", 
    \(\(\(\[Phi][x_, 
          y_]\  = \(\(\(\ \)\(Sinh[n\ Pi\ x/b]\)\)\/Sinh[n\ Pi\ a/b]\) 
          Sin[n\ Pi\ y/b];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Plot3D[\[Phi][x, y], {x, 0, a}, {y, 0, b}, 
        PlotLabel \[Rule] "\<Potential in a box\>", 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, PlotRange \[Rule] All, 
        PlotPoints \[Rule] 30];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.18"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -56 0 ]
[.5 .82364 56 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.02433 .26373 -12 -2.74115 ]
[.02433 .26373 0 6.25885 ]
[.01585 .31692 -24 -2.78612 ]
[.01585 .31692 0 6.21388 ]
[.00706 .37198 -6 -2.83283 ]
[.00706 .37198 0 6.16717 ]
[-0.00204 .42901 -18 -2.88139 ]
[-0.00204 .42901 0 6.11861 ]
[-0.01147 .48813 -6 -2.93191 ]
[-0.01147 .48813 0 6.06809 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Potential) show
123.000 13.000 moveto
(in) show
141.000 13.000 moveto
(a) show
153.000 13.000 moveto
(box) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03656 .25895 m
.04267 .25656 L
s
[(-1)] .02433 .26373 1 -0.39085 Mshowa
.02811 .31225 m
.03424 .30991 L
s
[(-0.5)] .01585 .31692 1 -0.38086 Mshowa
.01937 .36742 m
.02552 .36514 L
s
[(0)] .00706 .37198 1 -0.37048 Mshowa
.01031 .42457 m
.01648 .42235 L
s
[(0.5)] -0.00204 .42901 1 -0.35969 Mshowa
.00092 .48381 m
.00712 .48165 L
s
[(1)] -0.01147 .48813 1 -0.34846 Mshowa
.125 Mabswid
.03489 .26947 m
.03856 .26804 L
s
.03321 .28005 m
.03688 .27863 L
s
.03152 .29071 m
.0352 .2893 L
s
.02982 .30144 m
.0335 .30004 L
s
.02639 .32313 m
.03007 .32174 L
s
.02465 .33409 m
.02833 .3327 L
s
.0229 .34512 m
.02659 .34374 L
s
.02114 .35623 m
.02483 .35486 L
s
.01758 .37869 m
.02127 .37733 L
s
.01578 .39004 m
.01948 .38869 L
s
.01397 .40147 m
.01767 .40012 L
s
.01215 .41298 m
.01585 .41164 L
s
.00846 .43625 m
.01217 .43492 L
s
.0066 .44801 m
.0103 .44669 L
s
.00472 .45986 m
.00843 .45855 L
s
.00283 .47179 m
.00654 .47049 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.656 .751 .92 r
.39084 .69176 .40171 .70126 .41989 .69613 .4091 .68657 Metetra
.656 .751 .92 r
.4091 .68657 .41989 .69613 .4382 .69097 .42748 .68135 Metetra
.656 .751 .92 r
.42748 .68135 .4382 .69097 .45662 .68577 .44599 .67609 Metetra
.656 .751 .92 r
.44599 .67609 .45662 .68577 .47518 .68054 .46462 .67079 Metetra
.656 .751 .92 r
.46462 .67079 .47518 .68054 .49386 .67527 .48339 .66546 Metetra
.656 .752 .92 r
.48339 .66546 .49386 .67527 .51267 .66996 .50228 .66009 Metetra
.656 .752 .921 r
.50228 .66009 .51267 .66996 .53161 .66462 .5213 .65469 Metetra
.656 .752 .921 r
.5213 .65469 .53161 .66462 .55068 .65924 .54046 .64925 Metetra
.655 .752 .921 r
.54046 .64925 .55068 .65924 .56988 .65382 .55975 .64378 Metetra
.655 .752 .921 r
.55975 .64378 .56988 .65382 .58922 .64837 .57918 .63827 Metetra
.655 .752 .921 r
.57918 .63827 .58922 .64837 .60869 .64288 .59875 .63273 Metetra
.655 .753 .922 r
.59875 .63273 .60869 .64288 .6283 .63735 .61845 .62717 Metetra
.655 .754 .923 r
.61845 .62717 .6283 .63735 .64805 .63178 .6383 .62158 Metetra
.654 .754 .924 r
.6383 .62158 .64805 .63178 .66794 .62617 .65828 .61596 Metetra
.653 .756 .925 r
.65828 .61596 .66794 .62617 .68797 .62052 .67842 .61034 Metetra
.652 .757 .927 r
.67842 .61034 .68797 .62052 .70814 .61483 .69869 .60471 Metetra
.651 .759 .929 r
.69869 .60471 .70814 .61483 .72845 .6091 .71913 .59909 Metetra
.649 .763 .932 r
.71913 .59909 .72845 .6091 .74892 .60333 .73971 .59351 Metetra
.646 .767 .937 r
.73971 .59351 .74892 .60333 .76952 .59752 .76045 .58799 Metetra
.641 .773 .943 r
.76045 .58799 .76952 .59752 .79028 .59166 .78136 .58256 Metetra
.634 .782 .952 r
.78136 .58256 .79028 .59166 .81119 .58576 .80245 .57729 Metetra
.622 .793 .964 r
.80245 .57729 .81119 .58576 .83225 .57982 .82372 .57224 Metetra
.601 .808 .979 r
.82372 .57224 .83225 .57982 .85346 .57384 .8452 .56753 Metetra
.562 .826 .995 r
.8452 .56753 .85346 .57384 .87483 .56781 .8669 .5633 Metetra
.478 .834 .995 r
.8669 .5633 .87483 .56781 .89636 .56174 .88887 .55975 Metetra
.291 .776 .911 r
.88887 .55975 .89636 .56174 .91805 .55563 .91115 .55717 Metetra
.047 0 0 r
.91115 .55717 .91805 .55563 .93989 .54946 .93381 .55596 Metetra
.359 0 0 r
.93381 .55596 .93989 .54946 .9619 .54326 .95696 .55668 Metetra
.516 .074 .137 r
.95696 .55668 .9619 .54326 .98408 .537 .98075 .56011 Metetra
.656 .751 .92 r
.37983 .68215 .39084 .69176 .4091 .68657 .39816 .6769 Metetra
.656 .751 .92 r
.39816 .6769 .4091 .68657 .42748 .68135 .41662 .6716 Metetra
.656 .751 .92 r
.41662 .6716 .42748 .68135 .44599 .67609 .43521 .66628 Metetra
.656 .751 .92 r
.43521 .66628 .44599 .67609 .46462 .67079 .45393 .66092 Metetra
.656 .751 .92 r
.45393 .66092 .46462 .67079 .48339 .66546 .47278 .65552 Metetra
.656 .751 .92 r
.47278 .65552 .48339 .66546 .50228 .66009 .49176 .65009 Metetra
.656 .752 .921 r
.49176 .65009 .50228 .66009 .5213 .65469 .51087 .64462 Metetra
.655 .752 .921 r
.51087 .64462 .5213 .65469 .54046 .64925 .53011 .63912 Metetra
.655 .752 .921 r
.53011 .63912 .54046 .64925 .55975 .64378 .54949 .63359 Metetra
.655 .752 .921 r
.54949 .63359 .55975 .64378 .57918 .63827 .56901 .62803 Metetra
.655 .752 .922 r
.56901 .62803 .57918 .63827 .59875 .63273 .58867 .62244 Metetra
.654 .753 .922 r
.58867 .62244 .59875 .63273 .61845 .62717 .60847 .61684 Metetra
.654 .753 .923 r
.60847 .61684 .61845 .62717 .6383 .62158 .62841 .61122 Metetra
.653 .754 .924 r
.62841 .61122 .6383 .62158 .65828 .61596 .6485 .6056 Metetra
.652 .754 .925 r
.6485 .6056 .65828 .61596 .67842 .61034 .66873 .59998 Metetra
.65 .756 .927 r
.66873 .59998 .67842 .61034 .69869 .60471 .68912 .5944 Metetra
.647 .757 .929 r
.68912 .5944 .69869 .60471 .71913 .59909 .70966 .58888 Metetra
.644 .76 .933 r
.70966 .58888 .71913 .59909 .73971 .59351 .73037 .58345 Metetra
.639 .763 .938 r
.73037 .58345 .73971 .59351 .76045 .58799 .75124 .57818 Metetra
.631 .767 .944 r
.75124 .57818 .76045 .58799 .78136 .58256 .7723 .57313 Metetra
.62 .772 .953 r
.7723 .57313 .78136 .58256 .80245 .57729 .79355 .56841 Metetra
.602 .779 .965 r
.79355 .56841 .80245 .57729 .82372 .57224 .81503 .56417 Metetra
.571 .787 .981 r
.81503 .56417 .82372 .57224 .8452 .56753 .83674 .5606 Metetra
.515 .792 .996 r
.83674 .5606 .8452 .56753 .8669 .5633 .85876 .55799 Metetra
.405 .779 .993 r
.85876 .55799 .8669 .5633 .88887 .55975 .88113 .55673 Metetra
.18 .688 .903 r
.88113 .55673 .88887 .55975 .91115 .55717 .90395 .55738 Metetra
.18 0 0 r
.90395 .55738 .91115 .55717 .93381 .55596 .92735 .56071 Metetra
.482 0 0 r
.92735 .56071 .93381 .55596 .95696 .55668 .95154 .56781 Metetra
.624 .154 .117 r
.95154 .56781 .95696 .55668 .98075 .56011 .9768 .58027 Metetra
.656 .751 .92 r
.36868 .67241 .37983 .68215 .39816 .6769 .38709 .66709 Metetra
.656 .751 .92 r
.38709 .66709 .39816 .6769 .41662 .6716 .40563 .66174 Metetra
.656 .751 .92 r
.40563 .66174 .41662 .6716 .43521 .66628 .4243 .65634 Metetra
.656 .751 .92 r
.4243 .65634 .43521 .66628 .45393 .66092 .4431 .65092 Metetra
.656 .751 .92 r
.4431 .65092 .45393 .66092 .47278 .65552 .46203 .64545 Metetra
.656 .751 .92 r
.46203 .64545 .47278 .65552 .49176 .65009 .4811 .63995 Metetra
.655 .751 .921 r
.4811 .63995 .49176 .65009 .51087 .64462 .50029 .63442 Metetra
.655 .752 .921 r
.50029 .63442 .51087 .64462 .53011 .63912 .51963 .62886 Metetra
.655 .752 .921 r
.51963 .62886 .53011 .63912 .54949 .63359 .5391 .62326 Metetra
.655 .752 .921 r
.5391 .62326 .54949 .63359 .56901 .62803 .55871 .61764 Metetra
.654 .752 .921 r
.55871 .61764 .56901 .62803 .58867 .62244 .57846 .612 Metetra
.654 .752 .922 r
.57846 .612 .58867 .62244 .60847 .61684 .59835 .60634 Metetra
.653 .752 .923 r
.59835 .60634 .60847 .61684 .62841 .61122 .61839 .60069 Metetra
.652 .753 .924 r
.61839 .60069 .62841 .61122 .6485 .6056 .63858 .59504 Metetra
.65 .753 .925 r
.63858 .59504 .6485 .6056 .66873 .59998 .65892 .58942 Metetra
.648 .754 .926 r
.65892 .58942 .66873 .59998 .68912 .5944 .67941 .58385 Metetra
.645 .754 .929 r
.67941 .58385 .68912 .5944 .70966 .58888 .70006 .57839 Metetra
.64 .756 .932 r
.70006 .57839 .70966 .58888 .73037 .58345 .72089 .57307 Metetra
.634 .757 .937 r
.72089 .57307 .73037 .58345 .75124 .57818 .74189 .56797 Metetra
.625 .759 .943 r
.74189 .56797 .75124 .57818 .7723 .57313 .76308 .5632 Metetra
.61 .761 .951 r
.76308 .5632 .7723 .57313 .79355 .56841 .78449 .5589 Metetra
.589 .763 .962 r
.78449 .5589 .79355 .56841 .81503 .56417 .80614 .55527 Metetra
.553 .763 .975 r
.80614 .55527 .81503 .56417 .83674 .5606 .82807 .55258 Metetra
.492 .757 .989 r
.82807 .55258 .83674 .5606 .85876 .55799 .85034 .55123 Metetra
.379 .731 .99 r
.85034 .55123 .85876 .55799 .88113 .55673 .87304 .55177 Metetra
.165 .64 .929 r
.87304 .55177 .88113 .55673 .90395 .55738 .8963 .55495 Metetra
0 .405 .696 r
.8963 .55495 .90395 .55738 .92735 .56071 .9203 .56188 Metetra
.515 0 0 r
.9203 .56188 .92735 .56071 .95154 .56781 .94532 .57409 Metetra
.688 .177 .015 r
.94532 .57409 .95154 .56781 .9768 .58027 .97177 .59382 Metetra
.656 .751 .92 r
.35739 .66256 .36868 .67241 .38709 .66709 .37588 .65717 Metetra
.656 .751 .92 r
.37588 .65717 .38709 .66709 .40563 .66174 .3945 .65174 Metetra
.656 .751 .92 r
.3945 .65174 .40563 .66174 .4243 .65634 .41325 .64628 Metetra
.656 .751 .92 r
.41325 .64628 .4243 .65634 .4431 .65092 .43213 .64078 Metetra
.656 .751 .92 r
.43213 .64078 .4431 .65092 .46203 .64545 .45115 .63525 Metetra
.655 .751 .92 r
.45115 .63525 .46203 .64545 .4811 .63995 .4703 .62968 Metetra
.655 .751 .92 r
.4703 .62968 .4811 .63995 .50029 .63442 .48958 .62408 Metetra
.655 .751 .921 r
.48958 .62408 .50029 .63442 .51963 .62886 .509 .61844 Metetra
.655 .751 .921 r
.509 .61844 .51963 .62886 .5391 .62326 .52857 .61278 Metetra
.655 .751 .921 r
.52857 .61278 .5391 .62326 .55871 .61764 .54827 .6071 Metetra
.654 .751 .921 r
.54827 .6071 .55871 .61764 .57846 .612 .56811 .60139 Metetra
.653 .751 .922 r
.56811 .60139 .57846 .612 .59835 .60634 .5881 .59567 Metetra
.653 .751 .922 r
.5881 .59567 .59835 .60634 .61839 .60069 .60824 .58996 Metetra
.651 .751 .923 r
.60824 .58996 .61839 .60069 .63858 .59504 .62852 .58426 Metetra
.649 .751 .924 r
.62852 .58426 .63858 .59504 .65892 .58942 .64896 .57861 Metetra
.647 .751 .925 r
.64896 .57861 .65892 .58942 .67941 .58385 .66956 .57303 Metetra
.644 .751 .927 r
.66956 .57303 .67941 .58385 .70006 .57839 .69032 .56756 Metetra
.639 .751 .93 r
.69032 .56756 .70006 .57839 .72089 .57307 .71126 .56228 Metetra
.632 .751 .934 r
.71126 .56228 .72089 .57307 .74189 .56797 .73238 .55726 Metetra
.621 .75 .939 r
.73238 .55726 .74189 .56797 .76308 .5632 .75369 .55263 Metetra
.607 .749 .945 r
.75369 .55263 .76308 .5632 .78449 .5589 .77523 .54855 Metetra
.584 .746 .954 r
.77523 .54855 .78449 .5589 .80614 .55527 .79703 .54527 Metetra
.549 .739 .964 r
.79703 .54527 .80614 .55527 .82807 .55258 .81913 .5431 Metetra
.493 .726 .975 r
.81913 .5431 .82807 .55258 .85034 .55123 .8416 .5425 Metetra
.397 .694 .98 r
.8416 .5425 .85034 .55123 .87304 .55177 .86455 .54411 Metetra
.228 .62 .955 r
.86455 .54411 .87304 .55177 .8963 .55495 .88811 .54885 Metetra
0 .451 .835 r
.88811 .54885 .8963 .55495 .9203 .56188 .91252 .558 Metetra
.407 0 0 r
.91252 .558 .9203 .56188 .94532 .57409 .93808 .57339 Metetra
.67 .119 0 r
.93808 .57339 .94532 .57409 .97177 .59382 .96528 .59769 Metetra
.656 .751 .92 r
.34595 .65257 .35739 .66256 .37588 .65717 .36452 .64711 Metetra
.656 .751 .92 r
.36452 .64711 .37588 .65717 .3945 .65174 .38322 .64162 Metetra
.656 .751 .92 r
.38322 .64162 .3945 .65174 .41325 .64628 .40205 .63608 Metetra
.656 .751 .92 r
.40205 .63608 .41325 .64628 .43213 .64078 .42102 .63052 Metetra
.656 .751 .92 r
.42102 .63052 .43213 .64078 .45115 .63525 .44012 .62491 Metetra
.655 .751 .92 r
.44012 .62491 .45115 .63525 .4703 .62968 .45936 .61927 Metetra
.655 .751 .92 r
.45936 .61927 .4703 .62968 .48958 .62408 .47873 .61359 Metetra
.655 .751 .92 r
.47873 .61359 .48958 .62408 .509 .61844 .49824 .60789 Metetra
.655 .751 .921 r
.49824 .60789 .509 .61844 .52857 .61278 .51789 .60215 Metetra
.655 .751 .921 r
.51789 .60215 .52857 .61278 .54827 .6071 .53769 .59639 Metetra
.654 .751 .921 r
.53769 .59639 .54827 .6071 .56811 .60139 .55763 .59061 Metetra
.653 .751 .921 r
.55763 .59061 .56811 .60139 .5881 .59567 .57771 .58482 Metetra
.652 .751 .922 r
.57771 .58482 .5881 .59567 .60824 .58996 .59794 .57903 Metetra
.651 .75 .922 r
.59794 .57903 .60824 .58996 .62852 .58426 .61833 .57326 Metetra
.649 .75 .923 r
.61833 .57326 .62852 .58426 .64896 .57861 .63887 .56754 Metetra
.647 .749 .924 r
.63887 .56754 .64896 .57861 .66956 .57303 .65957 .56189 Metetra
.644 .748 .925 r
.65957 .56189 .66956 .57303 .69032 .56756 .68044 .55637 Metetra
.639 .747 .927 r
.68044 .55637 .69032 .56756 .71126 .56228 .70148 .55103 Metetra
.632 .745 .929 r
.70148 .55103 .71126 .56228 .73238 .55726 .7227 .54598 Metetra
.622 .742 .933 r
.7227 .54598 .73238 .55726 .75369 .55263 .74413 .54132 Metetra
.608 .738 .937 r
.74413 .54132 .75369 .55263 .77523 .54855 .76579 .53725 Metetra
.588 .731 .942 r
.76579 .53725 .77523 .54855 .79703 .54527 .7877 .53399 Metetra
.558 .719 .949 r
.7877 .53399 .79703 .54527 .81913 .5431 .80993 .5319 Metetra
.512 .701 .955 r
.80993 .5319 .81913 .5431 .8416 .5425 .83253 .53144 Metetra
.44 .668 .959 r
.83253 .53144 .8416 .5425 .86455 .54411 .85562 .5333 Metetra
.326 .609 .951 r
.85562 .5333 .86455 .54411 .88811 .54885 .87934 .5384 Metetra
.144 .501 .908 r
.87934 .5384 .88811 .54885 .91252 .558 .90391 .54809 Metetra
0 .317 .791 r
.90391 .54809 .91252 .558 .93808 .57339 .92968 .5643 Metetra
0 .068 .576 r
.92968 .5643 .93808 .57339 .96528 .59769 .95715 .58983 Metetra
.656 .751 .92 r
.33436 .64245 .34595 .65257 .36452 .64711 .35302 .63693 Metetra
.656 .751 .92 r
.35302 .63693 .36452 .64711 .38322 .64162 .3718 .63136 Metetra
.656 .751 .92 r
.3718 .63136 .38322 .64162 .40205 .63608 .39071 .62575 Metetra
.656 .751 .92 r
.39071 .62575 .40205 .63608 .42102 .63052 .40976 .62011 Metetra
.656 .751 .92 r
.40976 .62011 .42102 .63052 .44012 .62491 .42895 .61443 Metetra
.656 .751 .92 r
.42895 .61443 .44012 .62491 .45936 .61927 .44827 .60871 Metetra
.655 .751 .92 r
.44827 .60871 .45936 .61927 .47873 .61359 .46773 .60296 Metetra
.655 .751 .92 r
.46773 .60296 .47873 .61359 .49824 .60789 .48733 .59717 Metetra
.655 .751 .92 r
.48733 .59717 .49824 .60789 .51789 .60215 .50708 .59136 Metetra
.655 .751 .92 r
.50708 .59136 .51789 .60215 .53769 .59639 .52697 .58551 Metetra
.654 .751 .921 r
.52697 .58551 .53769 .59639 .55763 .59061 .547 .57965 Metetra
.654 .75 .921 r
.547 .57965 .55763 .59061 .57771 .58482 .56718 .57377 Metetra
.653 .75 .921 r
.56718 .57377 .57771 .58482 .59794 .57903 .58751 .56789 Metetra
.652 .749 .921 r
.58751 .56789 .59794 .57903 .61833 .57326 .60799 .56203 Metetra
.65 .748 .922 r
.60799 .56203 .61833 .57326 .63887 .56754 .62863 .5562 Metetra
.648 .747 .922 r
.62863 .5562 .63887 .56754 .65957 .56189 .64944 .55044 Metetra
.645 .746 .923 r
.64944 .55044 .65957 .56189 .68044 .55637 .6704 .5448 Metetra
.64 .743 .923 r
.6704 .5448 .68044 .55637 .70148 .55103 .69155 .53932 Metetra
.634 .74 .924 r
.69155 .53932 .70148 .55103 .7227 .54598 .71287 .5341 Metetra
.626 .735 .926 r
.71287 .5341 .7227 .54598 .74413 .54132 .7344 .52925 Metetra
.614 .729 .927 r
.7344 .52925 .74413 .54132 .76579 .53725 .75615 .52493 Metetra
.598 .719 .929 r
.75615 .52493 .76579 .53725 .7877 .53399 .77816 .52138 Metetra
.574 .704 .93 r
.77816 .52138 .7877 .53399 .80993 .5319 .80046 .51891 Metetra
.54 .683 .931 r
.80046 .51891 .80993 .5319 .83253 .53144 .82312 .51796 Metetra
.491 .651 .929 r
.82312 .51796 .83253 .53144 .85562 .5333 .84625 .51916 Metetra
.421 .602 .921 r
.84625 .51916 .85562 .5333 .87934 .5384 .86997 .52338 Metetra
.321 .529 .901 r
.86997 .52338 .87934 .5384 .90391 .54809 .8945 .53187 Metetra
.183 .423 .857 r
.8945 .53187 .90391 .54809 .92968 .5643 .92013 .5464 Metetra
.011 .28 .779 r
.92013 .5464 .92968 .5643 .95715 .58983 .94734 .56957 Metetra
.656 .751 .92 r
.32263 .63221 .33436 .64245 .35302 .63693 .34136 .62661 Metetra
.656 .751 .92 r
.34136 .62661 .35302 .63693 .3718 .63136 .36022 .62096 Metetra
.656 .751 .92 r
.36022 .62096 .3718 .63136 .39071 .62575 .37922 .61528 Metetra
.656 .751 .92 r
.37922 .61528 .39071 .62575 .40976 .62011 .39836 .60956 Metetra
.656 .751 .92 r
.39836 .60956 .40976 .62011 .42895 .61443 .41763 .60381 Metetra
.656 .751 .92 r
.41763 .60381 .42895 .61443 .44827 .60871 .43704 .59801 Metetra
.655 .751 .92 r
.43704 .59801 .44827 .60871 .46773 .60296 .45659 .59218 Metetra
.655 .751 .92 r
.45659 .59218 .46773 .60296 .48733 .59717 .47628 .58631 Metetra
.655 .751 .92 r
.47628 .58631 .48733 .59717 .50708 .59136 .49612 .5804 Metetra
.655 .751 .92 r
.49612 .5804 .50708 .59136 .52697 .58551 .5161 .57447 Metetra
.655 .75 .92 r
.5161 .57447 .52697 .58551 .547 .57965 .53623 .56851 Metetra
.654 .75 .92 r
.53623 .56851 .547 .57965 .56718 .57377 .5565 .56254 Metetra
.653 .749 .92 r
.5565 .56254 .56718 .57377 .58751 .56789 .57693 .55655 Metetra
.652 .749 .92 r
.57693 .55655 .58751 .56789 .60799 .56203 .59752 .55056 Metetra
.651 .747 .92 r
.59752 .55056 .60799 .56203 .62863 .5562 .61826 .5446 Metetra
.649 .746 .92 r
.61826 .5446 .62863 .5562 .64944 .55044 .63916 .53868 Metetra
.647 .744 .92 r
.63916 .53868 .64944 .55044 .6704 .5448 .66022 .53285 Metetra
.644 .741 .919 r
.66022 .53285 .6704 .5448 .69155 .53932 .68146 .52715 Metetra
.639 .736 .919 r
.68146 .52715 .69155 .53932 .71287 .5341 .70289 .52165 Metetra
.633 .731 .918 r
.70289 .52165 .71287 .5341 .7344 .52925 .7245 .51644 Metetra
.624 .722 .917 r
.7245 .51644 .7344 .52925 .75615 .52493 .74633 .51167 Metetra
.612 .711 .915 r
.74633 .51167 .75615 .52493 .77816 .52138 .7684 .50751 Metetra
.595 .695 .912 r
.7684 .50751 .77816 .52138 .80046 .51891 .79074 .50423 Metetra
.572 .672 .907 r
.79074 .50423 .80046 .51891 .82312 .51796 .8134 .50219 Metetra
.542 .642 .898 r
.8134 .50219 .82312 .51796 .84625 .51916 .83648 .5019 Metetra
.5 .6 .885 r
.83648 .5019 .84625 .51916 .86997 .52338 .86007 .50407 Metetra
.447 .545 .863 r
.86007 .50407 .86997 .52338 .8945 .53187 .88434 .50971 Metetra
.381 .476 .832 r
.88434 .50971 .8945 .53187 .92013 .5464 .90955 .52027 Metetra
.304 .395 .79 r
.90955 .52027 .92013 .5464 .94734 .56957 .93606 .53781 Metetra
.656 .751 .92 r
.31074 .62183 .32263 .63221 .34136 .62661 .32955 .61615 Metetra
.656 .751 .92 r
.32955 .61615 .34136 .62661 .36022 .62096 .3485 .61043 Metetra
.656 .751 .92 r
.3485 .61043 .36022 .62096 .37922 .61528 .36758 .60467 Metetra
.656 .751 .92 r
.36758 .60467 .37922 .61528 .39836 .60956 .3868 .59888 Metetra
.656 .751 .92 r
.3868 .59888 .39836 .60956 .41763 .60381 .40616 .59304 Metetra
.656 .751 .92 r
.40616 .59304 .41763 .60381 .43704 .59801 .42566 .58716 Metetra
.656 .751 .92 r
.42566 .58716 .43704 .59801 .45659 .59218 .4453 .58124 Metetra
.656 .751 .92 r
.4453 .58124 .45659 .59218 .47628 .58631 .46508 .57529 Metetra
.655 .751 .92 r
.46508 .57529 .47628 .58631 .49612 .5804 .48501 .56929 Metetra
.655 .75 .92 r
.48501 .56929 .49612 .5804 .5161 .57447 .50509 .56326 Metetra
.655 .75 .92 r
.50509 .56326 .5161 .57447 .53623 .56851 .52531 .5572 Metetra
.655 .75 .92 r
.52531 .5572 .53623 .56851 .5565 .56254 .54568 .55111 Metetra
.654 .749 .919 r
.54568 .55111 .5565 .56254 .57693 .55655 .56621 .545 Metetra
.654 .748 .919 r
.56621 .545 .57693 .55655 .59752 .55056 .58689 .53887 Metetra
.653 .747 .919 r
.58689 .53887 .59752 .55056 .61826 .5446 .60773 .53275 Metetra
.652 .745 .918 r
.60773 .53275 .61826 .5446 .63916 .53868 .62873 .52664 Metetra
.65 .742 .917 r
.62873 .52664 .63916 .53868 .66022 .53285 .6499 .52056 Metetra
.648 .739 .916 r
.6499 .52056 .66022 .53285 .68146 .52715 .67123 .51457 Metetra
.645 .734 .914 r
.67123 .51457 .68146 .52715 .70289 .52165 .69274 .50869 Metetra
.641 .728 .911 r
.69274 .50869 .70289 .52165 .7245 .51644 .71444 .503 Metetra
.636 .719 .908 r
.71444 .503 .7245 .51644 .74633 .51167 .73634 .49758 Metetra
.628 .707 .903 r
.73634 .49758 .74633 .51167 .7684 .50751 .75845 .49256 Metetra
.618 .69 .895 r
.75845 .49256 .7684 .50751 .79074 .50423 .7808 .48812 Metetra
.604 .669 .885 r
.7808 .48812 .79074 .50423 .8134 .50219 .80342 .4845 Metetra
.587 .64 .871 r
.80342 .4845 .8134 .50219 .83648 .5019 .82638 .48204 Metetra
.564 .604 .852 r
.82638 .48204 .83648 .5019 .86007 .50407 .84974 .48121 Metetra
.536 .56 .827 r
.84974 .48121 .86007 .50407 .88434 .50971 .87361 .4827 Metetra
.503 .51 .796 r
.87361 .4827 .88434 .50971 .90955 .52027 .89816 .48744 Metetra
.468 .455 .761 r
.89816 .48744 .90955 .52027 .93606 .53781 .92363 .49679 Metetra
.656 .751 .92 r
.29869 .61131 .31074 .62183 .32955 .61615 .31759 .60555 Metetra
.656 .751 .92 r
.31759 .60555 .32955 .61615 .3485 .61043 .33662 .59976 Metetra
.656 .751 .92 r
.33662 .59976 .3485 .61043 .36758 .60467 .35578 .59392 Metetra
.656 .751 .92 r
.35578 .59392 .36758 .60467 .3868 .59888 .37509 .58804 Metetra
.656 .751 .92 r
.37509 .58804 .3868 .59888 .40616 .59304 .39453 .58212 Metetra
.656 .751 .92 r
.39453 .58212 .40616 .59304 .42566 .58716 .41412 .57616 Metetra
.656 .751 .92 r
.41412 .57616 .42566 .58716 .4453 .58124 .43385 .57016 Metetra
.656 .751 .92 r
.43385 .57016 .4453 .58124 .46508 .57529 .45373 .56411 Metetra
.656 .751 .92 r
.45373 .56411 .46508 .57529 .48501 .56929 .47375 .55802 Metetra
.656 .75 .92 r
.47375 .55802 .48501 .56929 .50509 .56326 .49392 .55189 Metetra
.656 .75 .919 r
.49392 .55189 .50509 .56326 .52531 .5572 .51424 .54572 Metetra
.655 .75 .919 r
.51424 .54572 .52531 .5572 .54568 .55111 .53472 .53951 Metetra
.655 .749 .919 r
.53472 .53951 .54568 .55111 .56621 .545 .55534 .53326 Metetra
.655 .748 .918 r
.55534 .53326 .56621 .545 .58689 .53887 .57612 .52698 Metetra
.655 .747 .917 r
.57612 .52698 .58689 .53887 .60773 .53275 .59706 .52067 Metetra
.654 .745 .916 r
.59706 .52067 .60773 .53275 .62873 .52664 .61817 .51434 Metetra
.654 .742 .915 r
.61817 .51434 .62873 .52664 .6499 .52056 .63943 .50799 Metetra
.653 .739 .913 r
.63943 .50799 .6499 .52056 .67123 .51457 .66086 .50165 Metetra
.652 .734 .91 r
.66086 .50165 .67123 .51457 .69274 .50869 .68246 .49533 Metetra
.65 .728 .906 r
.68246 .49533 .69274 .50869 .71444 .503 .70423 .48906 Metetra
.648 .719 .9 r
.70423 .48906 .71444 .503 .73634 .49758 .72618 .48287 Metetra
.645 .707 .892 r
.72618 .48287 .73634 .49758 .75845 .49256 .74833 .47681 Metetra
.641 .691 .882 r
.74833 .47681 .75845 .49256 .7808 .48812 .77067 .47097 Metetra
.635 .671 .868 r
.77067 .47097 .7808 .48812 .80342 .4845 .79323 .46543 Metetra
.627 .646 .849 r
.79323 .46543 .80342 .4845 .82638 .48204 .81603 .46035 Metetra
.616 .614 .827 r
.81603 .46035 .82638 .48204 .84974 .48121 .83911 .45591 Metetra
.603 .578 .799 r
.83911 .45591 .84974 .48121 .87361 .4827 .86249 .45239 Metetra
.587 .538 .767 r
.86249 .45239 .87361 .4827 .89816 .48744 .88627 .45017 Metetra
.57 .497 .734 r
.88627 .45017 .89816 .48744 .92363 .49679 .91052 .44978 Metetra
.656 .751 .92 r
.28649 .60065 .29869 .61131 .31759 .60555 .30546 .59482 Metetra
.656 .751 .92 r
.30546 .59482 .31759 .60555 .33662 .59976 .32458 .58894 Metetra
.656 .751 .92 r
.32458 .58894 .33662 .59976 .35578 .59392 .34383 .58303 Metetra
.656 .751 .92 r
.34383 .58303 .35578 .59392 .37509 .58804 .36322 .57707 Metetra
.656 .751 .92 r
.36322 .57707 .37509 .58804 .39453 .58212 .38275 .57106 Metetra
.656 .751 .92 r
.38275 .57106 .39453 .58212 .41412 .57616 .40243 .56501 Metetra
.656 .751 .92 r
.40243 .56501 .41412 .57616 .43385 .57016 .42225 .55892 Metetra
.656 .751 .92 r
.42225 .55892 .43385 .57016 .45373 .56411 .44222 .55278 Metetra
.656 .751 .92 r
.44222 .55278 .45373 .56411 .47375 .55802 .46234 .54659 Metetra
.656 .75 .919 r
.46234 .54659 .47375 .55802 .49392 .55189 .48261 .54035 Metetra
.656 .75 .919 r
.48261 .54035 .49392 .55189 .51424 .54572 .50302 .53407 Metetra
.656 .75 .919 r
.50302 .53407 .51424 .54572 .53472 .53951 .5236 .52773 Metetra
.656 .749 .918 r
.5236 .52773 .53472 .53951 .55534 .53326 .54432 .52134 Metetra
.656 .748 .917 r
.54432 .52134 .55534 .53326 .57612 .52698 .56521 .5149 Metetra
.657 .747 .916 r
.56521 .5149 .57612 .52698 .59706 .52067 .58625 .5084 Metetra
.657 .745 .915 r
.58625 .5084 .59706 .52067 .61817 .51434 .60745 .50183 Metetra
.657 .743 .913 r
.60745 .50183 .61817 .51434 .63943 .50799 .62881 .4952 Metetra
.658 .74 .91 r
.62881 .4952 .63943 .50799 .66086 .50165 .65034 .48849 Metetra
.659 .735 .906 r
.65034 .48849 .66086 .50165 .68246 .49533 .67202 .4817 Metetra
.66 .73 .901 r
.67202 .4817 .68246 .49533 .70423 .48906 .69388 .4748 Metetra
.66 .722 .894 r
.69388 .4748 .70423 .48906 .72618 .48287 .71589 .46778 Metetra
.661 .711 .885 r
.71589 .46778 .72618 .48287 .74833 .47681 .73807 .46062 Metetra
.662 .697 .872 r
.73807 .46062 .74833 .47681 .77067 .47097 .76041 .45327 Metetra
.662 .679 .856 r
.76041 .45327 .77067 .47097 .79323 .46543 .7829 .44568 Metetra
.662 .657 .835 r
.7829 .44568 .79323 .46543 .81603 .46035 .80554 .43779 Metetra
.66 .63 .809 r
.80554 .43779 .81603 .46035 .83911 .45591 .82831 .4295 Metetra
.656 .6 .78 r
.82831 .4295 .83911 .45591 .86249 .45239 .8512 .42066 Metetra
.651 .567 .748 r
.8512 .42066 .86249 .45239 .88627 .45017 .87418 .4111 Metetra
.644 .534 .715 r
.87418 .4111 .88627 .45017 .91052 .44978 .89719 .40056 Metetra
.656 .751 .92 r
.27412 .58985 .28649 .60065 .30546 .59482 .29318 .58394 Metetra
.656 .751 .92 r
.29318 .58394 .30546 .59482 .32458 .58894 .31237 .57798 Metetra
.656 .751 .92 r
.31237 .57798 .32458 .58894 .34383 .58303 .33171 .57198 Metetra
.656 .751 .92 r
.33171 .57198 .34383 .58303 .36322 .57707 .35119 .56594 Metetra
.656 .751 .92 r
.35119 .56594 .36322 .57707 .38275 .57106 .37081 .55985 Metetra
.656 .751 .92 r
.37081 .55985 .38275 .57106 .40243 .56501 .39058 .55371 Metetra
.656 .751 .92 r
.39058 .55371 .40243 .56501 .42225 .55892 .41049 .54752 Metetra
.656 .751 .92 r
.41049 .54752 .42225 .55892 .44222 .55278 .43056 .54129 Metetra
.656 .751 .92 r
.43056 .54129 .44222 .55278 .46234 .54659 .45077 .535 Metetra
.656 .751 .919 r
.45077 .535 .46234 .54659 .48261 .54035 .47113 .52866 Metetra
.657 .75 .919 r
.47113 .52866 .48261 .54035 .50302 .53407 .49165 .52226 Metetra
.657 .75 .919 r
.49165 .52226 .50302 .53407 .5236 .52773 .51232 .5158 Metetra
.657 .749 .918 r
.51232 .5158 .5236 .52773 .54432 .52134 .53315 .50927 Metetra
.658 .749 .917 r
.53315 .50927 .54432 .52134 .56521 .5149 .55414 .50266 Metetra
.659 .748 .916 r
.55414 .50266 .56521 .5149 .58625 .5084 .57528 .49597 Metetra
.66 .746 .914 r
.57528 .49597 .58625 .5084 .60745 .50183 .59659 .48917 Metetra
.661 .744 .912 r
.59659 .48917 .60745 .50183 .62881 .4952 .61805 .48225 Metetra
.663 .742 .909 r
.61805 .48225 .62881 .4952 .65034 .48849 .63967 .47519 Metetra
.665 .738 .905 r
.63967 .47519 .65034 .48849 .67202 .4817 .66145 .46792 Metetra
.668 .733 .899 r
.66145 .46792 .67202 .4817 .69388 .4748 .68339 .46042 Metetra
.672 .727 .891 r
.68339 .46042 .69388 .4748 .71589 .46778 .70547 .4526 Metetra
.677 .718 .88 r
.70547 .4526 .71589 .46778 .73807 .46062 .72769 .44435 Metetra
.682 .707 .867 r
.72769 .44435 .73807 .46062 .76041 .45327 .75004 .43554 Metetra
.687 .692 .849 r
.75004 .43554 .76041 .45327 .7829 .44568 .77248 .42597 Metetra
.693 .674 .827 r
.77248 .42597 .7829 .44568 .80554 .43779 .79498 .41538 Metetra
.698 .652 .8 r
.79498 .41538 .80554 .43779 .82831 .4295 .81749 .40338 Metetra
.702 .626 .77 r
.81749 .40338 .82831 .4295 .8512 .42066 .83993 .38948 Metetra
.704 .599 .737 r
.83993 .38948 .8512 .42066 .87418 .4111 .86219 .37297 Metetra
.704 .572 .704 r
.86219 .37297 .87418 .4111 .89719 .40056 .88411 .35293 Metetra
.656 .751 .92 r
.26158 .57891 .27412 .58985 .29318 .58394 .28072 .57291 Metetra
.656 .751 .92 r
.28072 .57291 .29318 .58394 .31237 .57798 .3 .56687 Metetra
.656 .751 .92 r
.3 .56687 .31237 .57798 .33171 .57198 .31943 .56079 Metetra
.656 .751 .92 r
.31943 .56079 .33171 .57198 .35119 .56594 .33899 .55466 Metetra
.656 .751 .92 r
.33899 .55466 .35119 .56594 .37081 .55985 .35871 .54848 Metetra
.656 .751 .92 r
.35871 .54848 .37081 .55985 .39058 .55371 .37856 .54226 Metetra
.656 .751 .92 r
.37856 .54226 .39058 .55371 .41049 .54752 .39857 .53598 Metetra
.656 .751 .92 r
.39857 .53598 .41049 .54752 .43056 .54129 .41873 .52965 Metetra
.656 .751 .92 r
.41873 .52965 .43056 .54129 .45077 .535 .43904 .52326 Metetra
.657 .751 .919 r
.43904 .52326 .45077 .535 .47113 .52866 .4595 .51681 Metetra
.657 .751 .919 r
.4595 .51681 .47113 .52866 .49165 .52226 .48012 .5103 Metetra
.658 .75 .918 r
.48012 .5103 .49165 .52226 .51232 .5158 .50089 .50372 Metetra
.658 .75 .918 r
.50089 .50372 .51232 .5158 .53315 .50927 .52182 .49705 Metetra
.659 .75 .917 r
.52182 .49705 .53315 .50927 .55414 .50266 .54291 .49029 Metetra
.66 .749 .916 r
.54291 .49029 .55414 .50266 .57528 .49597 .56416 .48342 Metetra
.662 .748 .914 r
.56416 .48342 .57528 .49597 .59659 .48917 .58557 .47641 Metetra
.664 .747 .912 r
.58557 .47641 .59659 .48917 .61805 .48225 .60714 .46923 Metetra
.667 .745 .909 r
.60714 .46923 .61805 .48225 .63967 .47519 .62887 .46183 Metetra
.671 .742 .904 r
.62887 .46183 .63967 .47519 .66145 .46792 .65075 .45415 Metetra
.676 .739 .898 r
.65075 .45415 .66145 .46792 .68339 .46042 .67277 .44611 Metetra
.682 .735 .89 r
.67277 .44611 .68339 .46042 .70547 .4526 .69494 .43757 Metetra
.69 .728 .88 r
.69494 .43757 .70547 .4526 .72769 .44435 .71722 .42838 Metetra
.699 .72 .866 r
.71722 .42838 .72769 .44435 .75004 .43554 .73959 .4183 Metetra
.709 .709 .848 r
.73959 .4183 .75004 .43554 .77248 .42597 .76201 .40701 Metetra
.721 .695 .825 r
.76201 .40701 .77248 .42597 .79498 .41538 .78443 .39408 Metetra
.732 .678 .798 r
.78443 .39408 .79498 .41538 .81749 .40338 .80676 .3789 Metetra
.742 .658 .767 r
.80676 .3789 .81749 .40338 .83993 .38948 .82887 .36067 Metetra
.751 .636 .733 r
.82887 .36067 .83993 .38948 .86219 .37297 .85057 .33829 Metetra
.758 .613 .699 r
.85057 .33829 .86219 .37297 .88411 .35293 .87162 .31029 Metetra
.656 .751 .92 r
.24888 .56781 .26158 .57891 .28072 .57291 .2681 .56174 Metetra
.656 .751 .92 r
.2681 .56174 .28072 .57291 .3 .56687 .28747 .55562 Metetra
.656 .751 .92 r
.28747 .55562 .3 .56687 .31943 .56079 .30698 .54945 Metetra
.656 .751 .92 r
.30698 .54945 .31943 .56079 .33899 .55466 .32663 .54323 Metetra
.656 .751 .92 r
.32663 .54323 .33899 .55466 .35871 .54848 .34643 .53697 Metetra
.656 .751 .92 r
.34643 .53697 .35871 .54848 .37856 .54226 .36638 .53065 Metetra
.656 .751 .92 r
.36638 .53065 .37856 .54226 .39857 .53598 .38648 .52428 Metetra
.656 .751 .92 r
.38648 .52428 .39857 .53598 .41873 .52965 .40674 .51785 Metetra
.657 .751 .92 r
.40674 .51785 .41873 .52965 .43904 .52326 .42714 .51137 Metetra
.657 .751 .919 r
.42714 .51137 .43904 .52326 .4595 .51681 .4477 .50482 Metetra
.657 .751 .919 r
.4477 .50482 .4595 .51681 .48012 .5103 .46842 .4982 Metetra
.658 .751 .919 r
.46842 .4982 .48012 .5103 .50089 .50372 .4893 .4915 Metetra
.659 .751 .918 r
.4893 .4915 .50089 .50372 .52182 .49705 .51033 .48471 Metetra
.66 .751 .917 r
.51033 .48471 .52182 .49705 .54291 .49029 .53153 .4778 Metetra
.661 .75 .916 r
.53153 .4778 .54291 .49029 .56416 .48342 .55289 .47077 Metetra
.663 .75 .914 r
.55289 .47077 .56416 .48342 .58557 .47641 .5744 .46358 Metetra
.666 .749 .912 r
.5744 .46358 .58557 .47641 .60714 .46923 .59608 .45618 Metetra
.67 .749 .909 r
.59608 .45618 .60714 .46923 .62887 .46183 .61792 .44851 Metetra
.675 .747 .905 r
.61792 .44851 .62887 .46183 .65075 .45415 .6399 .4405 Metetra
.681 .746 .9 r
.6399 .4405 .65075 .45415 .67277 .44611 .66203 .43203 Metetra
.689 .744 .893 r
.66203 .43203 .67277 .44611 .69494 .43757 .68429 .42294 Metetra
.7 .741 .883 r
.68429 .42294 .69494 .43757 .71722 .42838 .70665 .41302 Metetra
.713 .736 .87 r
.70665 .41302 .71722 .42838 .73959 .4183 .72909 .40197 Metetra
.728 .73 .853 r
.72909 .40197 .73959 .4183 .76201 .40701 .75155 .38939 Metetra
.744 .722 .831 r
.75155 .38939 .76201 .40701 .78443 .39408 .77395 .37472 Metetra
.762 .711 .804 r
.77395 .37472 .78443 .39408 .80676 .3789 .79619 .35719 Metetra
.779 .697 .772 r
.79619 .35719 .80676 .3789 .82887 .36067 .81812 .33579 Metetra
.796 .68 .737 r
.81812 .33579 .82887 .36067 .85057 .33829 .83949 .30913 Metetra
.809 .662 .7 r
.83949 .30913 .85057 .33829 .87162 .31029 .86 .27538 Metetra
.656 .751 .92 r
.236 .55657 .24888 .56781 .2681 .56174 .25531 .55041 Metetra
.656 .751 .92 r
.25531 .55041 .2681 .56174 .28747 .55562 .27476 .5442 Metetra
.656 .751 .92 r
.27476 .5442 .28747 .55562 .30698 .54945 .29436 .53795 Metetra
.656 .751 .92 r
.29436 .53795 .30698 .54945 .32663 .54323 .3141 .53165 Metetra
.656 .751 .92 r
.3141 .53165 .32663 .54323 .34643 .53697 .33399 .52529 Metetra
.656 .751 .92 r
.33399 .52529 .34643 .53697 .36638 .53065 .35403 .51889 Metetra
.656 .751 .92 r
.35403 .51889 .36638 .53065 .38648 .52428 .37423 .51242 Metetra
.656 .751 .92 r
.37423 .51242 .38648 .52428 .40674 .51785 .39458 .50591 Metetra
.657 .751 .92 r
.39458 .50591 .40674 .51785 .42714 .51137 .41508 .49932 Metetra
.657 .751 .919 r
.41508 .49932 .42714 .51137 .4477 .50482 .43574 .49268 Metetra
.658 .751 .919 r
.43574 .49268 .4477 .50482 .46842 .4982 .45656 .48595 Metetra
.658 .751 .919 r
.45656 .48595 .46842 .4982 .4893 .4915 .47754 .47915 Metetra
.659 .752 .918 r
.47754 .47915 .4893 .4915 .51033 .48471 .49868 .47224 Metetra
.66 .752 .918 r
.49868 .47224 .51033 .48471 .53153 .4778 .51998 .46522 Metetra
.662 .752 .917 r
.51998 .46522 .53153 .4778 .55289 .47077 .54145 .45805 Metetra
.664 .752 .916 r
.54145 .45805 .55289 .47077 .5744 .46358 .56308 .45071 Metetra
.667 .752 .914 r
.56308 .45071 .5744 .46358 .59608 .45618 .58487 .44315 Metetra
.671 .752 .911 r
.58487 .44315 .59608 .45618 .61792 .44851 .60682 .43529 Metetra
.677 .753 .908 r
.60682 .43529 .61792 .44851 .6399 .4405 .62892 .42705 Metetra
.684 .753 .904 r
.62892 .42705 .6399 .4405 .66203 .43203 .65116 .4183 Metetra
.694 .754 .898 r
.65116 .4183 .66203 .43203 .68429 .42294 .67353 .40886 Metetra
.706 .754 .889 r
.67353 .40886 .68429 .42294 .70665 .41302 .696 .3985 Metetra
.722 .755 .878 r
.696 .3985 .70665 .41302 .72909 .40197 .71854 .38688 Metetra
.741 .754 .863 r
.71854 .38688 .72909 .40197 .75155 .38939 .74108 .37356 Metetra
.763 .753 .844 r
.74108 .37356 .75155 .38939 .77395 .37472 .76356 .3579 Metetra
.788 .75 .818 r
.76356 .3579 .77395 .37472 .79619 .35719 .78584 .33907 Metetra
.813 .744 .787 r
.78584 .33907 .79619 .35719 .81812 .33579 .80775 .31592 Metetra
.838 .735 .75 r
.80775 .31592 .81812 .33579 .83949 .30913 .82905 .28694 Metetra
.861 .724 .709 r
.82905 .28694 .83949 .30913 .86 .27538 .84939 .25011 Metetra
.656 .751 .92 r
.22295 .54517 .236 .55657 .25531 .55041 .24234 .53893 Metetra
.656 .751 .92 r
.24234 .53893 .25531 .55041 .27476 .5442 .26187 .53263 Metetra
.656 .751 .92 r
.26187 .53263 .27476 .5442 .29436 .53795 .28156 .52629 Metetra
.656 .751 .92 r
.28156 .52629 .29436 .53795 .3141 .53165 .30139 .5199 Metetra
.656 .751 .92 r
.30139 .5199 .3141 .53165 .33399 .52529 .32137 .51346 Metetra
.656 .751 .92 r
.32137 .51346 .33399 .52529 .35403 .51889 .34151 .50696 Metetra
.656 .751 .92 r
.34151 .50696 .35403 .51889 .37423 .51242 .3618 .50041 Metetra
.656 .752 .92 r
.3618 .50041 .37423 .51242 .39458 .50591 .38224 .4938 Metetra
.657 .752 .92 r
.38224 .4938 .39458 .50591 .41508 .49932 .40284 .48713 Metetra
.657 .752 .92 r
.40284 .48713 .41508 .49932 .43574 .49268 .4236 .48038 Metetra
.658 .752 .92 r
.4236 .48038 .43574 .49268 .45656 .48595 .44453 .47356 Metetra
.658 .752 .919 r
.44453 .47356 .45656 .48595 .47754 .47915 .46561 .46666 Metetra
.659 .752 .919 r
.46561 .46666 .47754 .47915 .49868 .47224 .48686 .45966 Metetra
.66 .753 .918 r
.48686 .45966 .49868 .47224 .51998 .46522 .50827 .45253 Metetra
.662 .753 .918 r
.50827 .45253 .51998 .46522 .54145 .45805 .52985 .44527 Metetra
.664 .754 .917 r
.52985 .44527 .54145 .45805 .56308 .45071 .55159 .43783 Metetra
.667 .755 .916 r
.55159 .43783 .56308 .45071 .58487 .44315 .5735 .43016 Metetra
.672 .756 .914 r
.5735 .43016 .58487 .44315 .60682 .43529 .59556 .42219 Metetra
.677 .758 .912 r
.59556 .42219 .60682 .43529 .62892 .42705 .61779 .41384 Metetra
.685 .761 .909 r
.61779 .41384 .62892 .42705 .65116 .4183 .64015 .40498 Metetra
.695 .764 .905 r
.64015 .40498 .65116 .4183 .67353 .40886 .66265 .39543 Metetra
.708 .768 .899 r
.66265 .39543 .67353 .40886 .696 .3985 .68526 .38495 Metetra
.726 .774 .891 r
.68526 .38495 .696 .3985 .71854 .38688 .70794 .37321 Metetra
.748 .78 .88 r
.70794 .37321 .71854 .38688 .74108 .37356 .73063 .35976 Metetra
.774 .787 .864 r
.73063 .35976 .74108 .37356 .76356 .3579 .75325 .34396 Metetra
.806 .795 .842 r
.75325 .34396 .76356 .3579 .78584 .33907 .7757 .32498 Metetra
.841 .801 .813 r
.7757 .32498 .78584 .33907 .80775 .31592 .79779 .30168 Metetra
.877 .805 .774 r
.79779 .30168 .80775 .31592 .82905 .28694 .81927 .27251 Metetra
.912 .804 .727 r
.81927 .27251 .82905 .28694 .84939 .25011 .83981 .23549 Metetra
.656 .751 .92 r
.20971 .53362 .22295 .54517 .24234 .53893 .22919 .52728 Metetra
.656 .751 .92 r
.22919 .52728 .24234 .53893 .26187 .53263 .24881 .5209 Metetra
.656 .751 .92 r
.24881 .5209 .26187 .53263 .28156 .52629 .26858 .51448 Metetra
.656 .751 .92 r
.26858 .51448 .28156 .52629 .30139 .5199 .28851 .508 Metetra
.656 .751 .92 r
.28851 .508 .30139 .5199 .32137 .51346 .30858 .50146 Metetra
.656 .751 .92 r
.30858 .50146 .32137 .51346 .34151 .50696 .32881 .49488 Metetra
.656 .752 .92 r
.32881 .49488 .34151 .50696 .3618 .50041 .34919 .48823 Metetra
.656 .752 .92 r
.34919 .48823 .3618 .50041 .38224 .4938 .36973 .48153 Metetra
.657 .752 .92 r
.36973 .48153 .38224 .4938 .40284 .48713 .39043 .47477 Metetra
.657 .752 .92 r
.39043 .47477 .40284 .48713 .4236 .48038 .4113 .46794 Metetra
.657 .752 .92 r
.4113 .46794 .4236 .48038 .44453 .47356 .43232 .46103 Metetra
.658 .752 .92 r
.43232 .46103 .44453 .47356 .46561 .46666 .45351 .45404 Metetra
.659 .753 .92 r
.45351 .45404 .46561 .46666 .48686 .45966 .47486 .44695 Metetra
.66 .754 .919 r
.47486 .44695 .48686 .45966 .50827 .45253 .49638 .43975 Metetra
.661 .754 .919 r
.49638 .43975 .50827 .45253 .52985 .44527 .51807 .43242 Metetra
.663 .756 .919 r
.51807 .43242 .52985 .44527 .55159 .43783 .53993 .42492 Metetra
.666 .757 .918 r
.53993 .42492 .55159 .43783 .5735 .43016 .56196 .41721 Metetra
.67 .76 .918 r
.56196 .41721 .5735 .43016 .59556 .42219 .58415 .40922 Metetra
.675 .763 .917 r
.58415 .40922 .59556 .42219 .61779 .41384 .6065 .40089 Metetra
.682 .767 .916 r
.6065 .40089 .61779 .41384 .64015 .40498 .629 .39208 Metetra
.692 .773 .914 r
.629 .39208 .64015 .40498 .66265 .39543 .65165 .38265 Metetra
.705 .781 .911 r
.65165 .38265 .66265 .39543 .68526 .38495 .67441 .37238 Metetra
.722 .792 .907 r
.67441 .37238 .68526 .38495 .70794 .37321 .69726 .36097 Metetra
.745 .806 .901 r
.69726 .36097 .70794 .37321 .73063 .35976 .72015 .34801 Metetra
.774 .824 .891 r
.72015 .34801 .73063 .35976 .75325 .34396 .74301 .33293 Metetra
.81 .845 .876 r
.74301 .33293 .75325 .34396 .7757 .32498 .76573 .31497 Metetra
.854 .868 .851 r
.76573 .31497 .7757 .32498 .79779 .30168 .78816 .2931 Metetra
.901 .891 .811 r
.78816 .2931 .79779 .30168 .81927 .27251 .81009 .26592 Metetra
.946 .906 .751 r
.81009 .26592 .81927 .27251 .83981 .23549 .83119 .23161 Metetra
.656 .751 .92 r
.19629 .5219 .20971 .53362 .22919 .52728 .21585 .51548 Metetra
.656 .751 .92 r
.21585 .51548 .22919 .52728 .24881 .5209 .23556 .50901 Metetra
.656 .751 .92 r
.23556 .50901 .24881 .5209 .26858 .51448 .25542 .50249 Metetra
.656 .751 .92 r
.25542 .50249 .26858 .51448 .28851 .508 .27544 .49592 Metetra
.656 .751 .92 r
.27544 .49592 .28851 .508 .30858 .50146 .2956 .4893 Metetra
.656 .752 .92 r
.2956 .4893 .30858 .50146 .32881 .49488 .31593 .48263 Metetra
.656 .752 .92 r
.31593 .48263 .32881 .49488 .34919 .48823 .33641 .47589 Metetra
.656 .752 .92 r
.33641 .47589 .34919 .48823 .36973 .48153 .35704 .4691 Metetra
.656 .752 .92 r
.35704 .4691 .36973 .48153 .39043 .47477 .37784 .46225 Metetra
.657 .752 .92 r
.37784 .46225 .39043 .47477 .4113 .46794 .39881 .45533 Metetra
.657 .752 .92 r
.39881 .45533 .4113 .46794 .43232 .46103 .41993 .44834 Metetra
.657 .753 .92 r
.41993 .44834 .43232 .46103 .45351 .45404 .44123 .44128 Metetra
.658 .753 .92 r
.44123 .44128 .45351 .45404 .47486 .44695 .46269 .43412 Metetra
.659 .754 .92 r
.46269 .43412 .47486 .44695 .49638 .43975 .48432 .42686 Metetra
.66 .755 .921 r
.48432 .42686 .49638 .43975 .51807 .43242 .50613 .41949 Metetra
.662 .757 .921 r
.50613 .41949 .51807 .43242 .53993 .42492 .5281 .41197 Metetra
.664 .759 .921 r
.5281 .41197 .53993 .42492 .56196 .41721 .55025 .40427 Metetra
.667 .762 .921 r
.55025 .40427 .56196 .41721 .58415 .40922 .57257 .39635 Metetra
.671 .766 .922 r
.57257 .39635 .58415 .40922 .6065 .40089 .59505 .38814 Metetra
.677 .772 .923 r
.59505 .38814 .6065 .40089 .629 .39208 .6177 .37954 Metetra
.685 .78 .923 r
.6177 .37954 .629 .39208 .65165 .38265 .6405 .37045 Metetra
.695 .792 .924 r
.6405 .37045 .65165 .38265 .67441 .37238 .66344 .36068 Metetra
.71 .807 .925 r
.66344 .36068 .67441 .37238 .69726 .36097 .68649 .35 Metetra
.73 .828 .925 r
.68649 .35 .69726 .36097 .72015 .34801 .70962 .33809 Metetra
.756 .856 .924 r
.70962 .33809 .72015 .34801 .74301 .33293 .73277 .3245 Metetra
.79 .892 .917 r
.73277 .3245 .74301 .33293 .76573 .31497 .75587 .30864 Metetra
.831 .935 .897 r
.75587 .30864 .76573 .31497 .78816 .2931 .77879 .28967 Metetra
.87 .977 .848 r
.77879 .28967 .78816 .2931 .81009 .26592 .80137 .26649 Metetra
.884 .99 .744 r
.80137 .26649 .81009 .26592 .83119 .23161 .82335 .2376 Metetra
.656 .751 .92 r
.18268 .51002 .19629 .5219 .21585 .51548 .20233 .50351 Metetra
.656 .751 .92 r
.20233 .50351 .21585 .51548 .23556 .50901 .22213 .49695 Metetra
.656 .751 .92 r
.22213 .49695 .23556 .50901 .25542 .50249 .24208 .49034 Metetra
.656 .751 .92 r
.24208 .49034 .25542 .50249 .27544 .49592 .26218 .48368 Metetra
.656 .751 .92 r
.26218 .48368 .27544 .49592 .2956 .4893 .28244 .47697 Metetra
.656 .752 .92 r
.28244 .47697 .2956 .4893 .31593 .48263 .30286 .4702 Metetra
.656 .752 .92 r
.30286 .4702 .31593 .48263 .33641 .47589 .32343 .46338 Metetra
.656 .752 .92 r
.32343 .46338 .33641 .47589 .35704 .4691 .34417 .4565 Metetra
.656 .752 .92 r
.34417 .4565 .35704 .4691 .37784 .46225 .36507 .44956 Metetra
.656 .752 .921 r
.36507 .44956 .37784 .46225 .39881 .45533 .38614 .44256 Metetra
.657 .753 .921 r
.38614 .44256 .39881 .45533 .41993 .44834 .40737 .43549 Metetra
.657 .753 .921 r
.40737 .43549 .41993 .44834 .44123 .44128 .42877 .42836 Metetra
.657 .754 .921 r
.42877 .42836 .44123 .44128 .46269 .43412 .45034 .42114 Metetra
.658 .755 .921 r
.45034 .42114 .46269 .43412 .48432 .42686 .47208 .41384 Metetra
.658 .756 .922 r
.47208 .41384 .48432 .42686 .50613 .41949 .494 .40645 Metetra
.659 .758 .923 r
.494 .40645 .50613 .41949 .5281 .41197 .51609 .39894 Metetra
.661 .76 .924 r
.51609 .39894 .5281 .41197 .55025 .40427 .53836 .3913 Metetra
.663 .763 .925 r
.53836 .3913 .55025 .40427 .57257 .39635 .56081 .3835 Metetra
.665 .768 .927 r
.56081 .3835 .57257 .39635 .59505 .38814 .58343 .3755 Metetra
.668 .775 .929 r
.58343 .3755 .59505 .38814 .6177 .37954 .60622 .36723 Metetra
.673 .784 .933 r
.60622 .36723 .6177 .37954 .6405 .37045 .62919 .35864 Metetra
.68 .797 .937 r
.62919 .35864 .6405 .37045 .66344 .36068 .65231 .3496 Metetra
.689 .815 .943 r
.65231 .3496 .66344 .36068 .68649 .35 .67559 .33999 Metetra
.7 .841 .95 r
.67559 .33999 .68649 .35 .70962 .33809 .69899 .32958 Metetra
.715 .876 .957 r
.69899 .32958 .70962 .33809 .73277 .3245 .72248 .31812 Metetra
.73 .922 .957 r
.72248 .31812 .73277 .3245 .75587 .30864 .74602 .30522 Metetra
.734 .97 .932 r
.74602 .30522 .75587 .30864 .77879 .28967 .76954 .29037 Metetra
.69 .98 .831 r
.76954 .29037 .77879 .28967 .80137 .26649 .79292 .27285 Metetra
.539 .865 .584 r
.79292 .27285 .80137 .26649 .82335 .2376 .81602 .25172 Metetra
.656 .751 .92 r
.16888 .49797 .18268 .51002 .20233 .50351 .18862 .49137 Metetra
.656 .751 .92 r
.18862 .49137 .20233 .50351 .22213 .49695 .2085 .48472 Metetra
.656 .751 .92 r
.2085 .48472 .22213 .49695 .24208 .49034 .22854 .47802 Metetra
.656 .751 .92 r
.22854 .47802 .24208 .49034 .26218 .48368 .24874 .47127 Metetra
.656 .751 .92 r
.24874 .47127 .26218 .48368 .28244 .47697 .26909 .46446 Metetra
.656 .752 .92 r
.26909 .46446 .28244 .47697 .30286 .4702 .2896 .4576 Metetra
.656 .752 .92 r
.2896 .4576 .30286 .4702 .32343 .46338 .31027 .45069 Metetra
.656 .752 .92 r
.31027 .45069 .32343 .46338 .34417 .4565 .33111 .44372 Metetra
.656 .752 .921 r
.33111 .44372 .34417 .4565 .36507 .44956 .35211 .43669 Metetra
.656 .752 .921 r
.35211 .43669 .36507 .44956 .38614 .44256 .37328 .42961 Metetra
.656 .753 .921 r
.37328 .42961 .38614 .44256 .40737 .43549 .39461 .42247 Metetra
.656 .753 .921 r
.39461 .42247 .40737 .43549 .42877 .42836 .41612 .41526 Metetra
.656 .754 .922 r
.41612 .41526 .42877 .42836 .45034 .42114 .4378 .408 Metetra
.656 .755 .922 r
.4378 .408 .45034 .42114 .47208 .41384 .45966 .40066 Metetra
.656 .756 .923 r
.45966 .40066 .47208 .41384 .494 .40645 .48169 .39326 Metetra
.657 .758 .924 r
.48169 .39326 .494 .40645 .51609 .39894 .5039 .38579 Metetra
.657 .76 .926 r
.5039 .38579 .51609 .39894 .53836 .3913 .52629 .37823 Metetra
.657 .763 .928 r
.52629 .37823 .53836 .3913 .56081 .3835 .54887 .37059 Metetra
.658 .768 .931 r
.54887 .37059 .56081 .3835 .58343 .3755 .57163 .36285 Metetra
.658 .775 .935 r
.57163 .36285 .58343 .3755 .60622 .36723 .59457 .35499 Metetra
.659 .784 .941 r
.59457 .35499 .60622 .36723 .62919 .35864 .6177 .347 Metetra
.659 .797 .948 r
.6177 .347 .62919 .35864 .65231 .3496 .64102 .33885 Metetra
.659 .815 .958 r
.64102 .33885 .65231 .3496 .67559 .33999 .66452 .3305 Metetra
.657 .841 .971 r
.66452 .3305 .67559 .33999 .69899 .32958 .6882 .32189 Metetra
.648 .875 .983 r
.6882 .32189 .69899 .32958 .72248 .31812 .71205 .31296 Metetra
.619 .912 .981 r
.71205 .31296 .72248 .31812 .74602 .30522 .73607 .3036 Metetra
.532 .918 .919 r
.73607 .3036 .74602 .30522 .76954 .29037 .76024 .29368 Metetra
.324 .793 .691 r
.76024 .29368 .76954 .29037 .79292 .27285 .78453 .283 Metetra
.78453 .283 .79292 .27285 .81602 .25172 .8089 .27131 Metetra
.656 .751 .92 r
.15489 .48575 .16888 .49797 .18862 .49137 .17471 .47906 Metetra
.656 .751 .92 r
.17471 .47906 .18862 .49137 .2085 .48472 .19468 .47232 Metetra
.656 .751 .92 r
.19468 .47232 .2085 .48472 .22854 .47802 .21481 .46552 Metetra
.656 .751 .92 r
.21481 .46552 .22854 .47802 .24874 .47127 .2351 .45867 Metetra
.656 .751 .92 r
.2351 .45867 .24874 .47127 .26909 .46446 .25554 .45177 Metetra
.656 .752 .92 r
.25554 .45177 .26909 .46446 .2896 .4576 .27615 .44482 Metetra
.656 .752 .92 r
.27615 .44482 .2896 .4576 .31027 .45069 .29692 .43781 Metetra
.656 .752 .921 r
.29692 .43781 .31027 .45069 .33111 .44372 .31786 .43075 Metetra
.656 .752 .921 r
.31786 .43075 .33111 .44372 .35211 .43669 .33896 .42364 Metetra
.656 .752 .921 r
.33896 .42364 .35211 .43669 .37328 .42961 .36023 .41647 Metetra
.655 .752 .921 r
.36023 .41647 .37328 .42961 .39461 .42247 .38167 .40925 Metetra
.655 .753 .922 r
.38167 .40925 .39461 .42247 .41612 .41526 .40328 .40198 Metetra
.655 .753 .922 r
.40328 .40198 .41612 .41526 .4378 .408 .42507 .39466 Metetra
.655 .754 .923 r
.42507 .39466 .4378 .408 .45966 .40066 .44704 .38729 Metetra
.654 .755 .924 r
.44704 .38729 .45966 .40066 .48169 .39326 .46919 .37989 Metetra
.654 .757 .925 r
.46919 .37989 .48169 .39326 .5039 .38579 .49152 .37245 Metetra
.653 .759 .927 r
.49152 .37245 .5039 .38579 .52629 .37823 .51403 .36498 Metetra
.652 .762 .93 r
.51403 .36498 .52629 .37823 .54887 .37059 .53674 .35751 Metetra
.65 .766 .934 r
.53674 .35751 .54887 .37059 .57163 .36285 .55963 .35004 Metetra
.647 .772 .939 r
.55963 .35004 .57163 .36285 .59457 .35499 .58272 .34261 Metetra
.643 .78 .946 r
.58272 .34261 .59457 .35499 .6177 .347 .60602 .33526 Metetra
.637 .791 .956 r
.60602 .33526 .6177 .347 .64102 .33885 .62952 .32804 Metetra
.626 .806 .969 r
.62952 .32804 .64102 .33885 .66452 .3305 .65324 .32101 Metetra
.606 .826 .984 r
.65324 .32101 .66452 .3305 .6882 .32189 .6772 .3143 Metetra
.565 .848 .997 r
.6772 .3143 .6882 .32189 .71205 .31296 .70141 .30804 Metetra
.476 .855 .983 r
.70141 .30804 .71205 .31296 .73607 .3036 .72591 .30244 Metetra
.28 .781 .861 r
.72591 .30244 .73607 .3036 .76024 .29368 .75073 .29777 Metetra
.034 0 0 r
.75073 .29777 .76024 .29368 .78453 .283 .77593 .29443 Metetra
.302 0 0 r
.77593 .29443 .78453 .283 .8089 .27131 .80161 .29298 Metetra
.656 .751 .92 r
.14069 .47335 .15489 .48575 .17471 .47906 .1606 .46657 Metetra
.656 .751 .92 r
.1606 .46657 .17471 .47906 .19468 .47232 .18066 .45973 Metetra
.656 .751 .92 r
.18066 .45973 .19468 .47232 .21481 .46552 .20088 .45284 Metetra
.656 .751 .92 r
.20088 .45284 .21481 .46552 .2351 .45867 .22126 .4459 Metetra
.656 .751 .92 r
.22126 .4459 .2351 .45867 .25554 .45177 .2418 .4389 Metetra
.656 .751 .92 r
.2418 .4389 .25554 .45177 .27615 .44482 .2625 .43185 Metetra
.656 .752 .921 r
.2625 .43185 .27615 .44482 .29692 .43781 .28337 .42475 Metetra
.655 .752 .921 r
.28337 .42475 .29692 .43781 .31786 .43075 .30441 .41759 Metetra
.655 .752 .921 r
.30441 .41759 .31786 .43075 .33896 .42364 .32561 .41038 Metetra
.655 .752 .921 r
.32561 .41038 .33896 .42364 .36023 .41647 .34698 .40313 Metetra
.655 .752 .921 r
.34698 .40313 .36023 .41647 .38167 .40925 .36853 .39583 Metetra
.655 .753 .922 r
.36853 .39583 .38167 .40925 .40328 .40198 .39025 .38848 Metetra
.654 .753 .922 r
.39025 .38848 .40328 .40198 .42507 .39466 .41215 .3811 Metetra
.653 .754 .923 r
.41215 .3811 .42507 .39466 .44704 .38729 .43423 .3737 Metetra
.652 .754 .924 r
.43423 .3737 .44704 .38729 .46919 .37989 .4565 .36628 Metetra
.651 .756 .926 r
.4565 .36628 .46919 .37989 .49152 .37245 .47894 .35886 Metetra
.649 .757 .928 r
.47894 .35886 .49152 .37245 .51403 .36498 .50158 .35147 Metetra
.647 .759 .931 r
.50158 .35147 .51403 .36498 .53674 .35751 .52441 .34414 Metetra
.643 .762 .935 r
.52441 .34414 .53674 .35751 .55963 .35004 .54744 .33693 Metetra
.637 .767 .941 r
.54744 .33693 .55963 .35004 .58272 .34261 .57067 .32989 Metetra
.629 .772 .949 r
.57067 .32989 .58272 .34261 .60602 .33526 .59413 .32312 Metetra
.616 .78 .96 r
.59413 .32312 .60602 .33526 .62952 .32804 .61781 .31676 Metetra
.594 .789 .973 r
.61781 .31676 .62952 .32804 .65324 .32101 .64174 .31098 Metetra
.557 .799 .989 r
.64174 .31098 .65324 .32101 .6772 .3143 .66596 .30605 Metetra
.487 .803 1 r
.66596 .30605 .6772 .3143 .70141 .30804 .6905 .3023 Metetra
.348 .774 .973 r
.6905 .3023 .70141 .30804 .72591 .30244 .71543 .30025 Metetra
.084 .637 .816 r
.71543 .30025 .72591 .30244 .75073 .29777 .74085 .3006 Metetra
.256 0 0 r
.74085 .3006 .75073 .29777 .77593 .29443 .7669 .30433 Metetra
.489 0 0 r
.7669 .30433 .77593 .29443 .80161 .29298 .79379 .31286 Metetra
.656 .751 .92 r
.12629 .46078 .14069 .47335 .1606 .46657 .14629 .4539 Metetra
.656 .751 .92 r
.14629 .4539 .1606 .46657 .18066 .45973 .16644 .44696 Metetra
.656 .751 .92 r
.16644 .44696 .18066 .45973 .20088 .45284 .18675 .43997 Metetra
.656 .751 .92 r
.18675 .43997 .20088 .45284 .22126 .4459 .20722 .43293 Metetra
.656 .751 .92 r
.20722 .43293 .22126 .4459 .2418 .4389 .22786 .42583 Metetra
.656 .751 .92 r
.22786 .42583 .2418 .4389 .2625 .43185 .24866 .41868 Metetra
.655 .751 .921 r
.24866 .41868 .2625 .43185 .28337 .42475 .26962 .41148 Metetra
.655 .752 .921 r
.26962 .41148 .28337 .42475 .30441 .41759 .29076 .40423 Metetra
.655 .752 .921 r
.29076 .40423 .30441 .41759 .32561 .41038 .31206 .39692 Metetra
.655 .752 .921 r
.31206 .39692 .32561 .41038 .34698 .40313 .33354 .38957 Metetra
.654 .752 .921 r
.33354 .38957 .34698 .40313 .36853 .39583 .3552 .38218 Metetra
.654 .752 .922 r
.3552 .38218 .36853 .39583 .39025 .38848 .37703 .37476 Metetra
.653 .752 .922 r
.37703 .37476 .39025 .38848 .41215 .3811 .39904 .36731 Metetra
.652 .753 .923 r
.39904 .36731 .41215 .3811 .43423 .3737 .42123 .35985 Metetra
.651 .753 .924 r
.42123 .35985 .43423 .3737 .4565 .36628 .44361 .35239 Metetra
.649 .754 .926 r
.44361 .35239 .4565 .36628 .47894 .35886 .46617 .34497 Metetra
.646 .755 .928 r
.46617 .34497 .47894 .35886 .50158 .35147 .48893 .33762 Metetra
.642 .756 .931 r
.48893 .33762 .50158 .35147 .52441 .34414 .51189 .33039 Metetra
.637 .757 .935 r
.51189 .33039 .52441 .34414 .54744 .33693 .53504 .32336 Metetra
.629 .76 .941 r
.53504 .32336 .54744 .33693 .57067 .32989 .55842 .31662 Metetra
.617 .762 .949 r
.55842 .31662 .57067 .32989 .59413 .32312 .58202 .31032 Metetra
.599 .765 .959 r
.58202 .31032 .59413 .32312 .61781 .31676 .60587 .30465 Metetra
.57 .767 .972 r
.60587 .30465 .61781 .31676 .64174 .31098 .62999 .29988 Metetra
.522 .766 .986 r
.62999 .29988 .64174 .31098 .66596 .30605 .65444 .29639 Metetra
.436 .753 .995 r
.65444 .29639 .66596 .30605 .6905 .3023 .67926 .29472 Metetra
.275 .701 .968 r
.67926 .29472 .6905 .3023 .71543 .30025 .70456 .29563 Metetra
0 .544 .824 r
.70456 .29563 .71543 .30025 .74085 .3006 .73047 .30017 Metetra
.352 0 0 r
.73047 .30017 .74085 .3006 .7669 .30433 .75721 .30987 Metetra
.59 .032 0 r
.75721 .30987 .7669 .30433 .79379 .31286 .78511 .32693 Metetra
.656 .751 .92 r
.11168 .44803 .12629 .46078 .14629 .4539 .13176 .44104 Metetra
.656 .751 .92 r
.13176 .44104 .14629 .4539 .16644 .44696 .15201 .43401 Metetra
.656 .751 .92 r
.15201 .43401 .16644 .44696 .18675 .43997 .17241 .42692 Metetra
.656 .751 .92 r
.17241 .42692 .18675 .43997 .20722 .43293 .19297 .41977 Metetra
.656 .751 .92 r
.19297 .41977 .20722 .43293 .22786 .42583 .2137 .41257 Metetra
.655 .751 .92 r
.2137 .41257 .22786 .42583 .24866 .41868 .2346 .40532 Metetra
.655 .751 .92 r
.2346 .40532 .24866 .41868 .26962 .41148 .25567 .39801 Metetra
.655 .751 .921 r
.25567 .39801 .26962 .41148 .29076 .40423 .2769 .39065 Metetra
.655 .751 .921 r
.2769 .39065 .29076 .40423 .31206 .39692 .29831 .38325 Metetra
.655 .751 .921 r
.29831 .38325 .31206 .39692 .33354 .38957 .3199 .3758 Metetra
.654 .751 .921 r
.3199 .3758 .33354 .38957 .3552 .38218 .34166 .36831 Metetra
.654 .752 .922 r
.34166 .36831 .3552 .38218 .37703 .37476 .3636 .36079 Metetra
.653 .752 .922 r
.3636 .36079 .37703 .37476 .39904 .36731 .38572 .35325 Metetra
.652 .752 .923 r
.38572 .35325 .39904 .36731 .42123 .35985 .40803 .34571 Metetra
.65 .752 .924 r
.40803 .34571 .42123 .35985 .44361 .35239 .43052 .3382 Metetra
.648 .752 .925 r
.43052 .3382 .44361 .35239 .46617 .34497 .4532 .33073 Metetra
.644 .752 .927 r
.4532 .33073 .46617 .34497 .48893 .33762 .47608 .32337 Metetra
.64 .752 .93 r
.47608 .32337 .48893 .33762 .51189 .33039 .49916 .31617 Metetra
.633 .752 .934 r
.49916 .31617 .51189 .33039 .53504 .32336 .52245 .30922 Metetra
.624 .752 .938 r
.52245 .30922 .53504 .32336 .55842 .31662 .54596 .30264 Metetra
.61 .751 .945 r
.54596 .30264 .55842 .31662 .58202 .31032 .5697 .29661 Metetra
.589 .749 .954 r
.5697 .29661 .58202 .31032 .60587 .30465 .5937 .29137 Metetra
.557 .745 .964 r
.5937 .29137 .60587 .30465 .62999 .29988 .61799 .28725 Metetra
.506 .735 .976 r
.61799 .28725 .62999 .29988 .65444 .29639 .64262 .28472 Metetra
.42 .71 .983 r
.64262 .28472 .65444 .29639 .67926 .29472 .66766 .28443 Metetra
.269 .649 .966 r
.66766 .28443 .67926 .29472 .70456 .29563 .69324 .28733 Metetra
.014 .507 .87 r
.69324 .28733 .70456 .29563 .73047 .30017 .71951 .29474 Metetra
.325 0 0 r
.71951 .29474 .73047 .30017 .75721 .30987 .74674 .30855 Metetra
.604 .035 0 r
.74674 .30855 .75721 .30987 .78511 .32693 .77532 .33156 Metetra
.656 .751 .92 r
.09686 .43508 .11168 .44803 .13176 .44104 .11703 .428 Metetra
.656 .751 .92 r
.11703 .428 .13176 .44104 .15201 .43401 .13736 .42086 Metetra
.656 .751 .92 r
.13736 .42086 .15201 .43401 .17241 .42692 .15786 .41366 Metetra
.656 .751 .92 r
.15786 .41366 .17241 .42692 .19297 .41977 .17852 .40641 Metetra
.656 .751 .92 r
.17852 .40641 .19297 .41977 .2137 .41257 .19934 .3991 Metetra
.655 .751 .92 r
.19934 .3991 .2137 .41257 .2346 .40532 .22034 .39174 Metetra
.655 .751 .92 r
.22034 .39174 .2346 .40532 .25567 .39801 .2415 .38433 Metetra
.655 .751 .921 r
.2415 .38433 .25567 .39801 .2769 .39065 .26284 .37686 Metetra
.655 .751 .921 r
.26284 .37686 .2769 .39065 .29831 .38325 .28436 .36935 Metetra
.655 .751 .921 r
.28436 .36935 .29831 .38325 .3199 .3758 .30605 .36179 Metetra
.654 .751 .921 r
.30605 .36179 .3199 .3758 .34166 .36831 .32792 .35419 Metetra
.653 .751 .921 r
.32792 .35419 .34166 .36831 .3636 .36079 .34997 .34656 Metetra
.653 .751 .922 r
.34997 .34656 .3636 .36079 .38572 .35325 .3722 .33892 Metetra
.651 .751 .922 r
.3722 .33892 .38572 .35325 .40803 .34571 .39462 .33128 Metetra
.649 .75 .923 r
.39462 .33128 .40803 .34571 .43052 .3382 .41723 .32366 Metetra
.647 .75 .924 r
.41723 .32366 .43052 .3382 .4532 .33073 .44003 .31611 Metetra
.644 .749 .926 r
.44003 .31611 .4532 .33073 .47608 .32337 .46303 .30867 Metetra
.639 .748 .928 r
.46303 .30867 .47608 .32337 .49916 .31617 .48624 .3014 Metetra
.632 .747 .93 r
.48624 .3014 .49916 .31617 .52245 .30922 .50965 .29441 Metetra
.622 .744 .934 r
.50965 .29441 .52245 .30922 .54596 .30264 .53328 .28783 Metetra
.608 .74 .939 r
.53328 .28783 .54596 .30264 .5697 .29661 .55716 .28185 Metetra
.588 .735 .945 r
.55716 .28185 .5697 .29661 .5937 .29137 .58129 .27671 Metetra
.557 .725 .952 r
.58129 .27671 .5937 .29137 .61799 .28725 .60572 .27279 Metetra
.51 .708 .96 r
.60572 .27279 .61799 .28725 .64262 .28472 .6305 .27059 Metetra
.435 .677 .965 r
.6305 .27059 .64262 .28472 .66766 .28443 .6557 .27082 Metetra
.313 .618 .957 r
.6557 .27082 .66766 .28443 .69324 .28733 .68145 .2745 Metetra
.118 .506 .908 r
.68145 .2745 .69324 .28733 .71951 .29474 .70793 .28306 Metetra
0 .31 .771 r
.70793 .28306 .71951 .29474 .74674 .30855 .7354 .29858 Metetra
.469 0 0 r
.7354 .29858 .74674 .30855 .77532 .33156 .7643 .3241 Metetra
.656 .751 .92 r
.08182 .42195 .09686 .43508 .11703 .428 .10208 .41476 Metetra
.656 .751 .92 r
.10208 .41476 .11703 .428 .13736 .42086 .1225 .40751 Metetra
.656 .751 .92 r
.1225 .40751 .13736 .42086 .15786 .41366 .14309 .40021 Metetra
.656 .751 .92 r
.14309 .40021 .15786 .41366 .17852 .40641 .16384 .39285 Metetra
.656 .751 .92 r
.16384 .39285 .17852 .40641 .19934 .3991 .18476 .38543 Metetra
.655 .751 .92 r
.18476 .38543 .19934 .3991 .22034 .39174 .20586 .37796 Metetra
.655 .751 .92 r
.20586 .37796 .22034 .39174 .2415 .38433 .22713 .37043 Metetra
.655 .751 .92 r
.22713 .37043 .2415 .38433 .26284 .37686 .24857 .36285 Metetra
.655 .751 .92 r
.24857 .36285 .26284 .37686 .28436 .36935 .27019 .35521 Metetra
.655 .751 .921 r
.27019 .35521 .28436 .36935 .30605 .36179 .29198 .34753 Metetra
.654 .751 .921 r
.29198 .34753 .30605 .36179 .32792 .35419 .31396 .33982 Metetra
.654 .75 .921 r
.31396 .33982 .32792 .35419 .34997 .34656 .33613 .33206 Metetra
.653 .75 .921 r
.33613 .33206 .34997 .34656 .3722 .33892 .35847 .32429 Metetra
.651 .75 .922 r
.35847 .32429 .3722 .33892 .39462 .33128 .38101 .31652 Metetra
.65 .749 .922 r
.38101 .31652 .39462 .33128 .41723 .32366 .40374 .30877 Metetra
.647 .748 .923 r
.40374 .30877 .41723 .32366 .44003 .31611 .42666 .30108 Metetra
.644 .747 .924 r
.42666 .30108 .44003 .31611 .46303 .30867 .44978 .29348 Metetra
.64 .745 .925 r
.44978 .29348 .46303 .30867 .48624 .3014 .47311 .28606 Metetra
.633 .742 .926 r
.47311 .28606 .48624 .3014 .50965 .29441 .49665 .2789 Metetra
.624 .738 .928 r
.49665 .2789 .50965 .29441 .53328 .28783 .52041 .27213 Metetra
.611 .732 .931 r
.52041 .27213 .53328 .28783 .55716 .28185 .5444 .26594 Metetra
.593 .723 .934 r
.5444 .26594 .55716 .28185 .58129 .27671 .56866 .26056 Metetra
.567 .709 .938 r
.56866 .26056 .58129 .27671 .60572 .27279 .59321 .25635 Metetra
.528 .688 .941 r
.59321 .25635 .60572 .27279 .6305 .27059 .61809 .2538 Metetra
.47 .655 .941 r
.61809 .2538 .6305 .27059 .6557 .27082 .6434 .2536 Metetra
.383 .602 .934 r
.6434 .2536 .6557 .27082 .68145 .2745 .66923 .25672 Metetra
.254 .517 .909 r
.66923 .25672 .68145 .2745 .70793 .28306 .69575 .26455 Metetra
.07 .383 .846 r
.69575 .26455 .70793 .28306 .7354 .29858 .72323 .2791 Metetra
0 .198 .725 r
.72323 .2791 .7354 .29858 .7643 .3241 .75207 .30329 Metetra
.656 .751 .92 r
.06655 .40862 .08182 .42195 .10208 .41476 .0869 .40132 Metetra
.656 .751 .92 r
.0869 .40132 .10208 .41476 .1225 .40751 .10742 .39397 Metetra
.656 .751 .92 r
.10742 .39397 .1225 .40751 .14309 .40021 .1281 .38655 Metetra
.656 .751 .92 r
.1281 .38655 .14309 .40021 .16384 .39285 .14895 .37908 Metetra
.656 .751 .92 r
.14895 .37908 .16384 .39285 .18476 .38543 .16997 .37155 Metetra
.656 .751 .92 r
.16997 .37155 .18476 .38543 .20586 .37796 .19116 .36396 Metetra
.655 .751 .92 r
.19116 .36396 .20586 .37796 .22713 .37043 .21253 .35631 Metetra
.655 .751 .92 r
.21253 .35631 .22713 .37043 .24857 .36285 .23407 .3486 Metetra
.655 .751 .92 r
.23407 .3486 .24857 .36285 .27019 .35521 .2558 .34085 Metetra
.655 .751 .92 r
.2558 .34085 .27019 .35521 .29198 .34753 .27771 .33304 Metetra
.654 .75 .92 r
.27771 .33304 .29198 .34753 .31396 .33982 .2998 .32519 Metetra
.654 .75 .92 r
.2998 .32519 .31396 .33982 .33613 .33206 .32207 .3173 Metetra
.653 .75 .921 r
.32207 .3173 .33613 .33206 .35847 .32429 .34454 .30938 Metetra
.652 .749 .921 r
.34454 .30938 .35847 .32429 .38101 .31652 .36719 .30145 Metetra
.651 .748 .921 r
.36719 .30145 .38101 .31652 .40374 .30877 .39004 .29352 Metetra
.649 .747 .921 r
.39004 .29352 .40374 .30877 .42666 .30108 .41308 .28564 Metetra
.646 .745 .921 r
.41308 .28564 .42666 .30108 .44978 .29348 .43633 .27783 Metetra
.642 .742 .921 r
.43633 .27783 .44978 .29348 .47311 .28606 .45978 .27016 Metetra
.637 .738 .922 r
.45978 .27016 .47311 .28606 .49665 .2789 .48344 .2627 Metetra
.629 .733 .922 r
.48344 .2627 .49665 .2789 .52041 .27213 .50733 .25556 Metetra
.619 .725 .922 r
.50733 .25556 .52041 .27213 .5444 .26594 .53144 .2489 Metetra
.604 .714 .922 r
.53144 .2489 .5444 .26594 .56866 .26056 .55581 .24294 Metetra
.584 .699 .921 r
.55581 .24294 .56866 .26056 .59321 .25635 .58046 .23797 Metetra
.555 .676 .919 r
.58046 .23797 .59321 .25635 .61809 .2538 .60543 .23441 Metetra
.515 .644 .914 r
.60543 .23441 .61809 .2538 .6434 .2536 .63078 .23285 Metetra
.458 .597 .903 r
.63078 .23285 .6434 .2536 .66923 .25672 .65661 .23413 Metetra
.38 .531 .882 r
.65661 .23413 .66923 .25672 .69575 .26455 .68306 .23942 Metetra
.276 .44 .844 r
.68306 .23942 .69575 .26455 .72323 .2791 .71034 .25042 Metetra
.149 .324 .784 r
.71034 .25042 .72323 .2791 .75207 .30329 .73879 .26958 Metetra
.656 .751 .92 r
.05106 .39509 .06655 .40862 .0869 .40132 .0715 .38769 Metetra
.656 .751 .92 r
.0715 .38769 .0869 .40132 .10742 .39397 .0921 .38022 Metetra
.656 .751 .92 r
.0921 .38022 .10742 .39397 .1281 .38655 .11288 .37269 Metetra
.656 .751 .92 r
.11288 .37269 .1281 .38655 .14895 .37908 .13382 .3651 Metetra
.656 .751 .92 r
.13382 .3651 .14895 .37908 .16997 .37155 .15494 .35745 Metetra
.656 .751 .92 r
.15494 .35745 .16997 .37155 .19116 .36396 .17624 .34974 Metetra
.656 .751 .92 r
.17624 .34974 .19116 .36396 .21253 .35631 .19771 .34196 Metetra
.655 .751 .92 r
.19771 .34196 .21253 .35631 .23407 .3486 .21936 .33413 Metetra
.655 .751 .92 r
.21936 .33413 .23407 .3486 .2558 .34085 .24119 .32624 Metetra
.655 .751 .92 r
.24119 .32624 .2558 .34085 .27771 .33304 .26321 .3183 Metetra
.655 .75 .92 r
.26321 .3183 .27771 .33304 .2998 .32519 .28541 .3103 Metetra
.654 .75 .92 r
.28541 .3103 .2998 .32519 .32207 .3173 .3078 .30226 Metetra
.654 .749 .92 r
.3078 .30226 .32207 .3173 .34454 .30938 .33038 .29417 Metetra
.653 .748 .92 r
.33038 .29417 .34454 .30938 .36719 .30145 .35316 .28606 Metetra
.652 .747 .919 r
.35316 .28606 .36719 .30145 .39004 .29352 .37613 .27793 Metetra
.65 .746 .919 r
.37613 .27793 .39004 .29352 .41308 .28564 .3993 .26981 Metetra
.648 .743 .919 r
.3993 .26981 .41308 .28564 .43633 .27783 .42267 .26172 Metetra
.646 .74 .918 r
.42267 .26172 .43633 .27783 .45978 .27016 .44625 .25372 Metetra
.642 .736 .917 r
.44625 .25372 .45978 .27016 .48344 .2627 .47004 .24584 Metetra
.637 .73 .916 r
.47004 .24584 .48344 .2627 .50733 .25556 .49404 .23819 Metetra
.629 .722 .914 r
.49404 .23819 .50733 .25556 .53144 .2489 .51828 .23086 Metetra
.619 .71 .911 r
.51828 .23086 .53144 .2489 .55581 .24294 .54276 .22401 Metetra
.605 .694 .906 r
.54276 .22401 .55581 .24294 .58046 .23797 .5675 .21787 Metetra
.586 .672 .899 r
.5675 .21787 .58046 .23797 .60543 .23441 .59254 .21274 Metetra
.561 .642 .888 r
.59254 .21274 .60543 .23441 .63078 .23285 .61791 .20904 Metetra
.526 .601 .871 r
.61791 .20904 .63078 .23285 .65661 .23413 .64368 .20737 Metetra
.482 .548 .848 r
.64368 .20737 .65661 .23413 .68306 .23942 .66996 .20858 Metetra
.427 .483 .814 r
.66996 .20858 .68306 .23942 .71034 .25042 .6969 .21388 Metetra
.363 .405 .771 r
.6969 .21388 .71034 .25042 .73879 .26958 .72473 .22498 Metetra
.656 .751 .92 r
.03533 .38136 .05106 .39509 .0715 .38769 .05586 .37384 Metetra
.656 .751 .92 r
.05586 .37384 .0715 .38769 .0921 .38022 .07656 .36626 Metetra
.656 .751 .92 r
.07656 .36626 .0921 .38022 .11288 .37269 .09743 .35861 Metetra
.656 .751 .92 r
.09743 .35861 .11288 .37269 .13382 .3651 .11847 .3509 Metetra
.656 .751 .92 r
.11847 .3509 .13382 .3651 .15494 .35745 .13969 .34313 Metetra
.656 .751 .92 r
.13969 .34313 .15494 .35745 .17624 .34974 .16108 .33529 Metetra
.656 .751 .92 r
.16108 .33529 .17624 .34974 .19771 .34196 .18266 .32739 Metetra
.656 .751 .92 r
.18266 .32739 .19771 .34196 .21936 .33413 .20442 .31943 Metetra
.656 .751 .92 r
.20442 .31943 .21936 .33413 .24119 .32624 .22636 .3114 Metetra
.655 .75 .92 r
.22636 .3114 .24119 .32624 .26321 .3183 .24848 .30331 Metetra
.655 .75 .92 r
.24848 .30331 .26321 .3183 .28541 .3103 .2708 .29516 Metetra
.655 .75 .919 r
.2708 .29516 .28541 .3103 .3078 .30226 .29331 .28695 Metetra
.655 .749 .919 r
.29331 .28695 .3078 .30226 .33038 .29417 .31601 .27869 Metetra
.654 .748 .919 r
.31601 .27869 .33038 .29417 .35316 .28606 .3389 .27037 Metetra
.654 .747 .918 r
.3389 .27037 .35316 .28606 .37613 .27793 .362 .26201 Metetra
.653 .745 .918 r
.362 .26201 .37613 .27793 .3993 .26981 .3853 .25362 Metetra
.652 .743 .916 r
.3853 .25362 .3993 .26981 .42267 .26172 .4088 .24522 Metetra
.65 .74 .915 r
.4088 .24522 .42267 .26172 .44625 .25372 .43251 .23681 Metetra
.648 .735 .913 r
.43251 .23681 .44625 .25372 .47004 .24584 .45643 .22844 Metetra
.645 .729 .91 r
.45643 .22844 .47004 .24584 .49404 .23819 .48056 .22015 Metetra
.641 .721 .906 r
.48056 .22015 .49404 .23819 .51828 .23086 .50492 .21199 Metetra
.636 .71 .9 r
.50492 .21199 .51828 .23086 .54276 .22401 .52952 .20405 Metetra
.628 .694 .892 r
.52952 .20405 .54276 .22401 .5675 .21787 .55435 .19644 Metetra
.618 .674 .881 r
.55435 .19644 .5675 .21787 .59254 .21274 .57945 .18932 Metetra
.604 .646 .865 r
.57945 .18932 .59254 .21274 .61791 .20904 .60482 .18291 Metetra
.586 .612 .844 r
.60482 .18291 .61791 .20904 .64368 .20737 .63052 .17752 Metetra
.563 .569 .817 r
.63052 .17752 .64368 .20737 .66996 .20858 .65659 .17358 Metetra
.536 .519 .784 r
.65659 .17358 .66996 .20858 .6969 .21388 .68311 .17171 Metetra
.504 .463 .745 r
.68311 .17171 .6969 .21388 .72473 .22498 .7102 .17277 Metetra
.656 .751 .92 r
.01937 .36742 .03533 .38136 .05586 .37384 .03999 .35978 Metetra
.656 .751 .92 r
.03999 .35978 .05586 .37384 .07656 .36626 .06078 .35208 Metetra
.656 .751 .92 r
.06078 .35208 .07656 .36626 .09743 .35861 .08174 .34431 Metetra
.656 .751 .92 r
.08174 .34431 .09743 .35861 .11847 .3509 .10288 .33648 Metetra
.656 .751 .92 r
.10288 .33648 .11847 .3509 .13969 .34313 .1242 .32858 Metetra
.656 .751 .92 r
.1242 .32858 .13969 .34313 .16108 .33529 .1457 .32062 Metetra
.656 .751 .92 r
.1457 .32062 .16108 .33529 .18266 .32739 .16738 .31259 Metetra
.656 .751 .92 r
.16738 .31259 .18266 .32739 .20442 .31943 .18924 .30449 Metetra
.656 .751 .92 r
.18924 .30449 .20442 .31943 .22636 .3114 .21129 .29632 Metetra
.656 .751 .92 r
.21129 .29632 .22636 .3114 .24848 .30331 .23353 .28808 Metetra
.656 .75 .919 r
.23353 .28808 .24848 .30331 .2708 .29516 .25596 .27977 Metetra
.656 .75 .919 r
.25596 .27977 .2708 .29516 .29331 .28695 .27858 .27139 Metetra
.656 .749 .919 r
.27858 .27139 .29331 .28695 .31601 .27869 .3014 .26293 Metetra
.656 .748 .918 r
.3014 .26293 .31601 .27869 .3389 .27037 .32442 .2544 Metetra
.656 .747 .917 r
.32442 .2544 .3389 .27037 .362 .26201 .34765 .2458 Metetra
.656 .746 .916 r
.34765 .2458 .362 .26201 .3853 .25362 .37107 .23712 Metetra
.656 .743 .915 r
.37107 .23712 .3853 .25362 .4088 .24522 .39471 .22837 Metetra
.655 .741 .912 r
.39471 .22837 .4088 .24522 .43251 .23681 .41855 .21953 Metetra
.655 .736 .909 r
.41855 .21953 .43251 .23681 .45643 .22844 .44261 .21062 Metetra
.655 .731 .905 r
.44261 .21062 .45643 .22844 .48056 .22015 .46688 .20163 Metetra
.654 .723 .9 r
.46688 .20163 .48056 .22015 .50492 .21199 .49137 .19255 Metetra
.653 .713 .892 r
.49137 .19255 .50492 .21199 .52952 .20405 .51608 .1834 Metetra
.651 .699 .881 r
.51608 .1834 .52952 .20405 .55435 .19644 .54102 .17416 Metetra
.648 .681 .867 r
.54102 .17416 .55435 .19644 .57945 .18932 .56618 .16484 Metetra
.644 .658 .848 r
.56618 .16484 .57945 .18932 .60482 .18291 .59158 .15543 Metetra
.638 .628 .824 r
.59158 .15543 .60482 .18291 .63052 .17752 .6172 .14594 Metetra
.629 .593 .795 r
.6172 .14594 .63052 .17752 .65659 .17358 .64307 .13635 Metetra
.618 .554 .76 r
.64307 .13635 .65659 .17358 .68311 .17171 .66917 .12668 Metetra
.604 .511 .722 r
.66917 .12668 .68311 .17171 .7102 .17277 .69552 .11692 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001GR000`400?l00000o`00003ooooooona
ooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00oooooolVooooo`Co000000?o
410@ooooooooool0Q?ooool00?oooooo:?ooool00ol0003oooooooooo`26ooooo`00oooooolXoooo
o`03o`000?oooooooooo08Kooooo003oooooobSooooo00?o0000ooooooooool0Q_ooool00?oooooo
:?ooool00ol0003oooooooooo`26ooooo`00oooooolXooooo`03o`000?oooooooooo08Kooooo003o
ooooobSooooo00?o0000ooooooooool0Q_ooool00?oooooo9_ooool00ol0003oA4A4o`00000;oooo
o`04okZj^_l@413o0000ogMgMgWooooo003oooooobKooooo00?oc<c<oeEEEOl000002_ooool01_o<
c<co<S8bonk^k_o^k^ko8B4QojVYZGSooooo003ooooooc?ooooo00KoA4A4ojVYZOooooooooooojVY
ZOlb<S9hooooo`00oooooolcooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M_oo
ool00?oooooo<oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Kooooo003ooooo
oc?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1fooooo`00oooooolcooooo`06
odA4A?nYZJWooooooooooonYZJWoA4A4N?ooool00?oooooo;Oooool2o`0000Cooooo00Koc<c<oc8b
<_o^k^kok^k^oc8b<_o<c<ahooooo`00oooooolZooooo`?o000000?oooooo`000?ooool01?ooool0
1?nj^[[o410@oa0@4?o<c<aiooooo`00oooooolXooooo`;o00001?ooool2o`00087ooooo003ooooo
obGooooo0ol00006ooooo`03o`000?oooooo0000083ooooo003oooooob;ooooo0ol00009ooooo`03
o`000?oooooo0000083ooooo003oooooob3ooooo0_l0000<ooooo`04o`000?ooooooooooo`0007oo
oooo003ooooooagooooo1?l0000=ooooo`05o`000?ooooooooooooooool00000O_ooool00=kooooo
00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06onk^k_m4A4Co0000o`00
0?m4A4Cok^k^9Oooool2o`0000Cooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooo
oooo000007kooooo003Mooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo
00Ko<S8bogMgMoo^k^kok^k^ogMgMolb<S8Rooooo`?o00004oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo07_ooooo003Mooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool0
0omEEEGo0000oeEEE@04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool2
o`0001Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1jooooo`00gOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko<S8bogMgMoo^k^kok^k^ogMgMolb
<S8Mooooo`?o00006Oooool01?l0003oooooooooooooool2o`0007cooooo003Mooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool00ooMgMgo0000o`000002o`000003omgMgOoo
oooooooo01Wooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0NOoo
ool00=gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`06oc8b<_mVIVKo
k^k^onk^k_mVIVKo<S8b6?ooool3o`0000;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo07Sooooo003Mooooo`06odA4A?nYZJWooooooooooonYZJWo
A4A43?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo0ol0000Qooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0N?ooool00=gooooo00Koc<c<oc8b<_o^k^ko
k^k^oc8b<_o<c<`<ooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b4oooool2o`0002Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1gooooo`00g_ooool01?nj^[[o410@oa0@4?o<
c<`=ooooo`06onk^k_m4A4Co0000o`000?m4A4Cok^k^4?ooool3o`0002Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1fooooo`00S?ooool01ol@413o0000oa0@4?oooooo410@o`00
0?l@4100L?ooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1foooo
o`00SOooool01_lb<S;oQhN7oooooonj^[[o0000onk^kVgooooo0ol000000ooooooo0000ooooo`0X
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0MOooool008gooooo00Gok^k^ob4Q
8Oo<c<co8B4Qolc<c01/ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo07Gooooo002>ooooo`03okZj^_l0003oQhN706[ooooo0ol0000`ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0M?ooool008gooooo00Gok^k^oc8b<_o<c<co<S8bonk^kP1Woooo
o`;o0000<oooool00ol0003oooooooooo`07ooooo`?o0000MOooool008gooooo00GoEEEEogMgMooo
ooooQhN7oeEEE@1Tooooo`?o0000=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
07?ooooo002<ooooo`07oa0@4?l0003o410@ooooool@413o0000oa0@401Pooooo`?o000000?ooooo
o`000?ooool0=Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07;ooooo003aoooo
o`;o00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0LOooool00>kooooo0ol0000mooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0LOooool00>cooooo0_l00010ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
L?ooool00>Wooooo0ol00012ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Kooo
ool00>Oooooo0ol00014ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Koooool0
0:Sooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06onk^k_m4A4Co
0000o`000?mEEEGok^k^9Oooool3o`0000?ooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo06kooooo002Wooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7o
ZJVY1Oooool3o`0000Cooooo00KoEEEEogMgMoooooooooooogMgMomEEEDSooooo`;o0000Boooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06gooooo002Wooooo`06odA4A?nYZJWooooo
oooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@04ooooo`03oa0@4?oooooooooo00;ooooo00?o
0000ooooooooool07_ooool3o`0004gooooo00?o0000ooooooooool03Oooool2o`0006oooooo002W
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003ok^k^ooooo`02
ooooo`03o`000?oooooooooo01_ooooo0ol0001@ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0K?ooool00:Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:oooo
o`06o`000?mEEEGok^k^oooooomgMgOoEEEE6oooool3o`0005;ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`08ooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED0
1?ooool6o`0004cooooo002Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool01_lQ8B7oIVIVo`000?l0003oEEEEonk^kQSooooo0ol00003ooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`06olc<c?lb<S;ok^k^onk^
k_lQ8B7oZJVY1Oooool3o`0000Cooooo00?oV9RHo`000?o<c<`00_ooool00ol@413oooooooooo`1:
ooooo`00Yoooool01_m4A4CoZJVYooooooooooooZJVYodA4A0cooooo00?oQhN7ofIVI_ooool06Ooo
ool2o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`06odA4A?nY
ZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@05ooooo`03oiRHV?l0003oc<c<04ko
oooo002Wooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3Oooool00olb<S;oIVIVomgMg@0Eoooo
o`?o0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0<ooooo`03ojVYZOl@413oc<c<04gooooo002Xooooo`04
okZj^_l@413o410@olc<c0oooooo00CoMgMgoa0@4?l0003o8B4Q4Oooool2o`0005gooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03Oooool00oo<c<co410@olc<c01<ooooo`00cOooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03_ooool00onYZJWo<S8booooo`1;ooooo`00boooool2o`0000?ooooo00?o0000oooooooo
ool0G?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00KoA4A4ojVYZOoo
ooooooooojVYZOm4A4@Aooooo`03o`000?oooooooooo04[ooooo0038ooooo`?o0000I?ooool00ol0
003oooooooooo`0Booooo`?o00001Oooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00Ko
0000ohN7Qoo^k^koooooogMgMolb<S9<ooooo`00aOooool3o`0006Oooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`03ooooo`04okZj^_l@413o410@olc<c0gooooo00KoZJVYoc8b<_l0
003o0000oeEEEOo^k^i<ooooo`00`oooool2o`0006[ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`1Uooooo`00`?ooool3o`0006cooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`1Uooooo`00__ooool2o`0000?ooooo00?o0000ooooooooool0JOooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo06Cooooo002kooooo`?o00001_ooool00ol0003ooooooooo
o`1Wooooo`;o00006_ooool00ol0003oooooooooo`1Sooooo`00^Oooool2o`00073ooooo0ol00000
0onJP[So0000ooooo`0Iooooo`03o`000?oooooooooo06?ooooo002fooooo`?o0000L?ooool2o`00
00CoVX:h00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Rooooo`00M_ooool01?nj^[[o
410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Oooooo0_l000000ol@413oooooooooo`0Uoooo
o`?o0000Koooool3o`0000OoVX:h00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Qoooo
o`00MOooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00008ooooo`03o`000?oooooo
oooo02?ooooo0ol00003ooooo`03o`000?oooooooooo06[ooooo0_l0000:oiZ2^003o`000?oooooo
oooo01Sooooo0_l0001Sooooo`00MOooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?o
EEEEo`000?mEEED01?ooool6o`00027ooooo0ol0001`ooooo`?o000000?oWXg2o`000?nJP[P02OnJ
P[P00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo063ooooo001eooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02_ooool01OmVIVKoZJVYoooooooooooo0000023ooooo0_l0
001aooooo`;o00001OnNSL800ol0003oVX:hoiZ2^007oiZ2^0;o00006oooool00ol0003ooooooooo
o`1Pooooo`00MOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Gok^k^
ob4Q8Oo^k^koooooo`00000Mooooo`?o0000L?ooool3o`0000OoWXg200?o0000oiZ2^?nJP[P01onJ
P[P2o`0001cooooo00?o0000ooooooooool0Goooool007Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0;ooooo`04ojVYZOmVIVKoooooo`0001_ooooo0ol0001`ooooo`;o00002_nN
SL800ol0003oVX:hoiZ2^007oiZ2^0;o00007Oooool00ol0003oooooooooo`1Nooooo`00MOooool0
1_m4A4CoZJVYooooooooooooZJVYodA4A0kooooo00?oA4A4olc<c?l000006?ooool3o`0000?ooooo
00?o0000ooooooooool0J_ooool3o`000003oj6Gbol0003oWXg200[oWXg200?o0000oiZ2^?nJP[P0
1_nJP[P2o`0001gooooo00?o0000ooooooooool0G_ooool007Gooooo00Koc<c<oc8b<_o^k^kok^k^
oc8b<_o<c<`>ooooo`03omgMgOm4A4Co000001Kooooo0_l0001`ooooo`?o00001OnQUl/00ol0003o
WXg2oij=`P08oij=`P03o`000?nJP[SoVX:h00KoVX:h00?o0000oiZ2^?l000007Oooool00ol0003o
ooooooooo`1Mooooo`00M_ooool01?nj^[[o410@oa0@4?o<c<`@ooooo`03ohN7Qol0003ooooo01;o
oooo0ol0001_ooooo`?o00002?nQUl/00ol0003oWXg2oij=`P08oij=`P03o`000?nJP[SoVX:h00Ko
VX:h00?o0000oiZ2^?l000007_ooool00ol0003oooooooooo`1Looooo`00WOooool2o`0006oooooo
0ol000000onSX=;o0000oj6Gb`09oj6Gb`03o`000?nNSL;oWXg200SoWXg200?o0000oiZ2^?nJP[P0
1OnJP[P00ol0003oVX:ho`00000Nooooo`03o`000?oooooooooo05cooooo002Jooooo`?o000000?o
ooooo`000?ooool0K?ooool2o`0000GoXj3B00?o0000oj6GbonQUl/01onQUl/00ol0003oWXg2oij=
`P08oij=`P03o`000?nJP[SoVX:h00GoVX:h00?o0000oiZ2^?l000007Oooool3o`0005gooooo002G
ooooo`?o0000Koooool3o`0000OoXj3B00?o0000oj6GbonQUl/01onQUl/00ol0003oWXg2oij=`P08
oij=`P03o`000?nJP[SoVX:h00GoVX:h00Co0000oiZ2^?nJP[So00007oooool00ol0003ooooooooo
o`1Jooooo`00UOooool2o`00073ooooo0_l0000:oj>PdP03o`000?nQUl_oXIO;00SoXIO;00?o0000
oij=`_nNSL802?nNSL800ol0003oVX:hoiZ2^004oiZ2^004o`000?nJP[SoVX:ho`0001oooooo00?o
0000ooooooooool0F_ooool009;ooooo0ol0001_ooooo`?o000000?oY:SIo`000?nSX=802_nSX=80
0ol0003oXIO;oj6Gb`07oj6Gb`03o`000?nNSL;oWXg200SoWXg200?o0000oiZ2^?nJP[P01?nJP[P0
1?l0003oVX:hoiZ2^?l0000Pooooo`03o`000?oooooooooo05Wooooo002@ooooo`;o0000L?ooool2
o`0000GoY:SI00?o0000oj>Pd_nSX=802?nSX=800ol0003oXIO;oj6Gb`08oj6Gb`03o`000?nNSL;o
WXg200OoWXg200?o0000oiZ2^?nJP[P01?nJP[P01Ol0003oVX:hoiZ2^?nJP[So0000023ooooo00?o
0000ooooooooool0F?ooool008gooooo0ol000000ooooooo0000ooooo`1/ooooo`?o00001onTZ=T0
0ol0003oXj3Boj>PdP09oj>PdP03o`000?nQUl_oXIO;00OoXIO;00?o0000oij=`_nNSL802?nNSL80
0ol0003oVX:hoiZ2^003oiZ2^005o`000?nJP[SoVX:hoiZ2^?l000008?ooool00ol0003ooooooooo
o`1Hooooo`00Roooool2o`0000Gooooo00?o0000ooooooooool0J?ooool2o`0000_oY:SI00?o0000
oj>Pd_nSX=802?nSX=800ol0003oXIO;oj6Gb`08oj6Gb`03o`000?nNSL;oWXg200OoWXg200?o0000
oiZ2^?nJP[P00onJP[P01Ol0003oVX:hoiZ2^?nJP[So0000027ooooo00?o0000ooooooooool0Eooo
ool008Sooooo0ol0001_ooooo`?o000000?oYJkMo`000?nTZ=T02_nTZ=T00ol0003oXj3Boj>PdP09
oj>PdP03o`000?nQUl_oXIO;00OoXIO;00?o0000oij=`_nNSL801onNSL800ol0003oVX:hoiZ2^003
oiZ2^005o`000?nJP[SoVX:hoiZ2^?l000008_ooool00ol0003oooooooooo`1Fooooo`00Q_ooool2
o`0006oooooo0ol00005ojF^g@03o`000?nTZ=WoY:SI00WoY:SI00?o0000oj>Pd_nSX=802?nSX=80
0ol0003oXIO;oj6Gb`07oj6Gb`03o`000?nNSL;oWXg200?oWXg22ol00004oiZ2^003o`000?oooooo
oooo01oooooo0_l0001Gooooo`00AOooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003o
EEEE00Cooooo1_l0000Wooooo`?o0000K_ooool3o`0000SoYJkM00?o0000ojBXfOnTZ=T02OnTZ=T0
0ol0003oXj3Boj>PdP08oj>PdP03o`000?nQUl_oXIO;00?oXIO;2_l00005ohV4b003o`000?n1M[ko
PGJn00?oPGJn1Ol0000Pooooo`03o`000?oooooo000005Oooooo0014ooooo`06olc<c?lb<S;ok^k^
onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00?oV9RHo`000?o<c<`00_ooool00ol@413ooooooooo
o`0Rooooo`?o00000oooool00ol0003oooooooooo`1Xooooo`?o000000?oY[;Qo`000?nU[]d02OnU
[]d00ol0003oY:SIojBXf@08ojBXf@03o`000?nSX=;oXj3B00OoXj3B1ol00005oi2Ad@03o`000?n9
Q<SoRHC800OoRHC800?o0000oh5f__n1M[h00on1M[h01Ol0003oPGJnoh5f__n1M[ko000002?ooooo
00?o0000ooooooooool02?ooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Oo
oooo0_l000000ol@413oooooooooo`0cooooo`00A?ooool01_m4A4CoZJVYooooooooooooZJVYoc8b
<PGooooo00?oEEEEo`000?mEEED01Oooool00onHV9So0000olc<c00Tooooo`;o0000Koooool2o`00
00GoY[;Q00?o0000ojF^gOnU[]d02?nU[]d00ol0003oY:SIojBXf@08ojBXf@03o`000?nSX=;oXj3B
00?oXj3B0ol00002oiJLf003o`000?n@TM7oT97A00SoT97A00?o0000ohV4b?n9Q<P01on9Q<P00ol0
003oPGJnoh5f_P02oh5f_P05o`000?n1M[koPGJnoh5f__l000008oooool00ol0003oooooooooo`07
ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Sooooo00?o0000ooooooooool0
=?ooool004Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03ojVYZOl@
413oc<c<023ooooo0ol0001^ooooo`?o00001onV/^400ol0003oYJkMojF^g@08ojF^g@03o`000?nT
Z=WoY:SI00SoY:SI00?o0000oj>Pd_nSX=800ol00006oiJLf003o`000?n@TM7oT97A00OoT97A00?o
0000ohV4b?n9Q<P01on9Q<P00ol0003oPGJnoh5f_P02oh5f_P03o`000?n1M[koPGJn00;oPGJn00?o
0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`06odA4A?nYZJWooooooooooonYZJWo
<S8b1Oooool00omEEEGo0000oeEEE@04ooooo`Ko0000=Oooool004Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`03olc<c?l@413oc<c<01gooooo0_l0001_ooooo`;o0000
2onV/^400ol0003oYJkMojF^g@08ojF^g@03o`000?nTZ=WoY:SI00KoY:SI1?l00009oiJLf003o`00
0?n@TM7oT97A00OoT97A00?o0000ohV4b?n9Q<P01on9Q<P00ol0003oPGJnoh5f_P02oh5f_P03o`00
0?n1M[koPGJn00;oPGJn00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01OmVIVKoZJVYoooooooooooo000003Ko
oooo0014ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00onYZJWo<S8b
ooooo`0Iooooo`?o000000?oooooo`000?ooool0Joooool3o`000003ojNfi?l0003oY[;Q00_oY[;Q
00?o0000ojF^gOnU[]d01onU[]d01?l0003oY:SIojBXfOnTZ=T5o`0000;oVZGM00?o0000oiJLf?nF
W=P02?nFW=P00ol0003oT97Aoi2Ad@08oi2Ad@03o`000?n9Q<SoRHC800OoRHC800Go0000oh5f__n1
M[koPGJno`000004oh5f_P03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Gok^k^ob4Q8Oo^k^koooooo`00000=
ooooo`05oa0@4?l0003o0000o`000?l@41009?ooool004Cooooo00KoA4A4ojVYZOooooooooooojVY
ZOm4A4@Aooooo`03o`000?oooooooooo01Kooooo0_l0001^ooooo`?o00001OnW]^@00ol0003oY[;Q
ojJbh@09ojJbh@03o`000?nU[]goYJkM00OoYJkM1?l00008oiZUg@03o`000?nFW=SoUYcH00SoUYcH
00?o0000oi2AdOn@TM401on@TM400ol0003oRHC8ohV4b007ohV4b005o`000?n1M[koPGJnoh5f__l0
00001?n1M[h00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0;ooooo`04ojVYZOmVIVKoooooo`0000oooooo00?oV9RHoc8b
<_ooool09?ooool004Cooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`06o`000?n7QhOo
k^k^oooooomgMgOo<S8b5Oooool3o`0006gooooo0ol00009ojNfi003o`000?nV/^7oY[;Q00WoY[;Q
00?o0000ojF^gOnU[]d00onU[]d3o`000003oij/hOl0003oVZGM00WoVZGM00?o0000oiJLf?nFW=P0
2?nFW=P00ol0003oT97Aoi2Ad@08oi2Ad@03o`000?n9Q<SoRHC800KoRHC800Go0000oh5f__n1M[ko
PGJno`000005oh5f_P03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool01_m4A4Co
ZJVYooooooooooooZJVYodA4A0kooooo00?oA4A4olc<c?l000004?ooool00ol@413ogMgMooooo`0S
ooooo`00AOooool01?nj^[[o410@oa0@4?o<c<`=ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^
4oooool2o`0006gooooo0ol000000onW^NKo0000ojNfi009ojNfi003o`000?nV/^7oY[;Q00WoY[;Q
00?o0000ojF^gOnU[]d00ol00005oij/h@03o`000?nJYMgoVZGM00SoVZGM00?o0000oiJLf?nFW=P0
2?nFW=P00ol0003oT97Aoi2Ad@07oi2Ad@03o`000?n9Q<SoRHC800OoRHC800Co0000oh5f__n1M[ko
00001On1M[h00ol0003oooooooooo`0Rooooo`;o00001Oooool01_o<c<co<S8bonk^k_o^k^ko<S8b
olc<c0kooooo00?ogMgModA4A?l000004?ooool2oeEEEBCooooo001/ooooo`?o0000KOooool2o`00
00GoYkWV00?o0000ojNfi?nW]^@02?nW]^@00ol0003oY[;QojJbh@07ojJbh@Co00002?nN[>400ol0
003oVZGMoiZUg@09oiZUg@03o`000?nFW=SoUYcH00OoUYcH00?o0000oi2AdOn@TM401on@TM400ol0
003oRHC8ohV4b007ohV4b004o`000?n1M[koPGJno`0000GoPGJn00?o0000ooooooooool08Oooool0
1?l0003oooooooooool00005ooooo`04okZj^_l@413o410@olc<c13ooooo00?oQhN7o`000?ooool0
3_ooool01?oMgMgo410@ob4Q8OoMgMdSooooo`00JOooool3o`0000;ooooo00?o0000ooooooooool0
J?ooool3o`0000SoYkWV00?o0000ojNfi?nW]^@01onW]^@00ol0003oY[;QojJbh@04ojJbh@?o0000
0_nP/N@00ol0003oWZcQoij/h@08oij/h@03o`000?nJYMgoVZGM00SoVZGM00?o0000oiJLf?nFW=P0
2?nFW=P00ol0003oT97Aoi2Ad@07oi2Ad@03o`000?n9Q<SoRHC800KoRHC800Co0000oh5f__n1M[ko
00001On1M[h00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Oooooo00CoEEEEogMgMonH
V9SoEEEE8oooool006Oooooo0_l0001^ooooo`;o00002onW^NH00ol0003oYkKTojNfi008ojNfi003
o`000?nV/^7oY[;Q00?o00001_nP/N@00ol0003oWZcQoij/h@08oij/h@03o`000?nJYMgoVZGM00So
VZGM00?o0000oiJLf?nFW=P01onFW=P00ol0003oT97Aoi2Ad@07oi2Ad@03o`000?n9Q<SoRHC800Oo
RHC800?o0000oh5f__l000001_n1M[h00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Ko
oooo00Kok^k^oa0@4?o^k^koooooo`000?oMgMdRooooo`00I?ooool3o`0006gooooo0ol000000onW
^nOo0000ojNiiP0;ojNiiP03o`000?nW]^CoYkKT00OoYkKT0ol0000:oj2ai003o`000?nN[>7oWZcQ
00OoWZcQ00?o0000oiZUgOnJYMd02?nJYMd00ol0003oUYcHoiJLf007oiJLf003o`000?n@TM7oT97A
00OoT97A00?o0000ohV4b?n9Q<P01on9Q<P00ol0003oPGJno`000006oh5f_P03o`000?oooooooooo
02Gooooo00?o0000ooooooooool09Oooool01_mgMgOoEEEEooooooooooooMgMgofIVIR;ooooo001R
ooooo`;o0000KOooool3o`0000GoYk_W00?o0000ojNii_nW^NH02OnW^NH00ol0003oYkKTojNfi004
ojNfi0?o000000?oX[GVo`000?nP/N@02_nP/N@00ol0003oWZcQoij/h@08oij/h@03o`000?nJYMgo
VZGM00KoVZGM6_l00005ohV4b003o`000?n1M[ko000000KoPGJn00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Tooooo`07o`000?oMgMgoooooooooooo^k^ko0000onk^kP0Qooooo`00Gooo
ool4o`0006_ooooo0ol00009ojNki`03o`000?nW^NKoYkWV00WoYkWV00?o0000ojNfi?nW]^@00ol0
0005oj:eiP03o`000?nP/NCoX;7T00WoX;7T00?o0000oij/hOnN[>401onN[>401?l0003oVZGMoiZU
gOnJYMd5o`0000;oSjCS00?o0000ohJIg_n6VMh01on6VMh00ol0003oNhcIog^<f@07og^<f@04o`00
0?m]Nm3oKG_@ofekd0Go000000?oRHC8o`000?l000001_n1M[h00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02?ooooo00?o410@o`000?l000000_ooool2o`000003oa0@4?oooooooooo01oo
oooo001Mooooo`;o00001?ooool00ol0003oooooooooo`1Uooooo`?o000000?oYkcXo`000?nW^nL0
2_nW^nL00ol0003oYkWVojNiiP07ojNiiPCo00002OnR]NH00ol0003oX;7Toj2ai008oj2ai003o`00
0?nN[>7oWZcQ00KoWZcQ1Ol00008ohnTh`03o`000?n6VMkoQYWN00OoQYWN00?o0000og^<fOmkS=T0
1omkS=T00ol0003oKG_@ofekd005ofekd0?o00001on1M[h00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04_ooooo001Jooooo`?o0000Joooool3o`0000GoYkcX00?o0000ojNkionW^nL02?nW
^nL00ol0003oYkWVojNiiP04ojNiiP?o00000_nT^>L00ol0003oX[GVoj:eiP09oj:eiP03o`000?nP
/NCoX;7T00SoX;7T00?o0000oij/hOnN[>401Ol00002oiJ/iP03o`000?n?Y>?oSjCS00SoSjCS00?o
0000ohJIg_n6VMh01on6VMh00ol0003oNhcIog^<f@07og^<f@03o`000?m]Nm3oKG_@00KoKG_@1?l0
0005oh5f_P03o`000?oooooooooo02Kooooo0_l0001<ooooo`00F?ooool2o`0006_ooooo0ol00009
ojNlj003o`000?nW^nOoYk_W00SoYk_W00?o0000ojNii_nW^NH00ol00006ojBhi`03o`000?nR]NKo
X[GV00SoX[GV00?o0000oj2ai?nP/N@01onP/N@4o`0000SoUZcV00?o0000ohnThon?Y><02?n?Y><0
0ol0003oQYWNohJIgP07ohJIgP03o`000?mkS=WoNhcI00KoNhcI00?o0000ofekd?m]Nm001om]Nm00
0ol0003oG6O5oeaWa@02o`0000?oPGJn00?o0000ooooooooool09Oooool00ol0003oooooo`00001<
ooooo`00:_ooool01?nj^[[o410@o`000?mgMgLWooooo`?o0000Joooool2o`000003ojNmjOl0003o
YkcX00[oYkcX00?o0000ojNkionW^nL01onW^nL3o`0000[oY;SW00?o0000oj:ei_nR]NH02?nR]NH0
1?l0003oX;7Toj2ai?nP/N@5o`0000;oV[7W00?o0000oiJ/i_nF[>H02?nF[>H00ol0003oSjCSohnT
h`07ohnTh`03o`000?n6VMkoQYWN00OoQYWN00?o0000og^<fOmkS=T01omkS=T00ol0003oKG_@ofek
d006ofekd003o`000?mLIlGoG6O500;oG6O50_l000000on1M[ko0000ooooo`0Yooooo`03o`000?oo
oooooooo04Wooooo000Yooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY8oooool3o`0000;ooooo
00?o0000ooooooooool0I_ooool3o`0000CoYkgY00?o0000ojNlj?nW_>P02?nW_>P00ol0003oYk_W
ojNki`04ojNki`?o000000?oYK[Xo`000?nT^>L02onT^>L00ol0003oX[GVoj:eiP07oj:eiPCo0000
2?nJ/NL00ol0003oUZcVoiJ/iP07oiJ/iP03o`000?n?Y>?oSjCS00SoSjCS00?o0000ohJIg_n6VMh0
1on6VMh00ol0003oNhcIog^<f@06og^<f@03o`000?m]Nm3oKG_@00KoKG_@0_l00005oeaWa@?o0000
:Oooool00ol0003oooooooooo`19ooooo`00:Oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<R7o
oooo0_l0001/ooooo`;o00002?nW_NT00ol0003oYkcXojNlj008ojNlj003o`000?nW^nOoYk_W00?o
00001OnU^^P00ol0003oY;SWojBhi`09ojBhi`03o`000?nR]NKoX[GV00CoX[GV0ol000000onN]NWo
0000oiZai`0:oiZai`03o`000?nF[>KoUZcV00OoUZcV00?o0000ohnThon?Y><01on?Y><00ol0003o
QYWNohJIgP07ohJIgP03o`000?mkS=WoNhcI00OoNhcI00?o0000ofekd?m]Nm001_m]Nm000ol0003o
G6O5oeaWa@05oeaWa@03o`000?oooooooooo02Sooooo00?o0000ooooooooool0B?ooool002Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`?o0000K?ooool2o`0000_oYkgY
00?o0000ojNlj?nW_>P01onW_>P3o`0000WoYK[X00?o0000ojBhionT^>L02OnT^>L00ol0003oX[GV
oj:eiP03o`0000GoW[GY00?o0000oiZaionJ/NL02OnJ/NL00ol0003oUZcVoiJ/iP06oiJ/iP03o`00
0?n?Y>?oSjCS00SoSjCS00?o0000ohJIg_n6VMh01on6VMh00ol0003oNhcIog^<f@06og^<f@03o`00
0?m]Nm3oKG_@00KoKG_@00?o0000oeaWaOmLIlD01OmLIlD00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo04Oooooo000Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_oo
ool2o`0006cooooo0ol000000onW_^[o0000ojNmj@0:ojNmj@03o`000?nW_>SoYkcX00CoYkcX0ol0
00000onU_>Wo0000ojFjj00:ojFjj003o`000?nT^>OoY;SW00SoY;SW0ol00009oijej@03o`000?nJ
/NOoV[7W00SoV[7W00?o0000oiJ/i_nF[>H01onF[>H00ol0003oSjCSohnTh`07ohnTh`03o`000?n6
VMkoQYWN00OoQYWN00?o0000og^<fOmkS=T01omkS=T00ol0003oKG_@ofekd005ofekd003o`000?mL
IlGoG6O500KoG6O500?o0000ooooooooool09?ooool3o`000003ooooool0003ooooo04Sooooo000Y
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool3o`000003ooooool0003o
oooo06Sooooo0ol00005ojNnjP03o`000?nW_NWoYkgY00WoYkgY00?o0000ojNlj?nW_>P00ol00005
ojFlj@03o`000?nU^^SoYK[X00WoYK[X00?o0000ojBhionT^>L01?nT^>L3o`000003oj6hjOl0003o
W[GY00[oW[GY00?o0000oiZaionJ/NL02?nJ/NL00ol0003oUZcVoiJ/iP03oiJ/iQco00001OmkS=T0
0ol0003oKG_@ofekd005ofekd0;o00001omLIlD00ol0003oooooooooo`0Sooooo`07o`000?oRoKko
0000oo;W`?l0003oooooo`000018ooooo`00:Oooool01_m4A4CoZJVYooooooooooooZJVYodA4A1Oo
oooo0_l0001[ooooo`?o00002OnW_^X00ol0003oYkgYojNmj@08ojNmj@?o00002OnU_>T00ol0003o
YK[XojFjj009ojFjj003o`000?nT^>OoY;SW00?o00001OnQ^>T00ol0003oW[GYoijej@08oijej@03
o`000?nJ/NOoV[7W00OoV[7W1ol00004ohj]j`03o`000?n3Y>WoPjCY00OoPjCY00?o0000ogFHiome
V>L01omeV>L01?l0003oHHOQof67hOmQQn46o`0000OoKG_@0_l00007oeaWa@03o`000?oooooooooo
02;ooooo00?o0000on;m__l000000oobil000ol0003oooooo`000017ooooo`00:Oooool01_o<c<co
<S8bonk^k_o^k^ko<S8bolc<c1Cooooo0ol0001Zooooo`?o000000?oYkkZo`000?nW_^X02_nW_^X0
0ol0003oYkgYojNmj@04ojNmj@?o000000?oY[gZo`000?nU_>T02_nU_>T00ol0003oYK[XojFjj007
ojFjj0Co00002OnQ^>T00ol0003oW[GYoijej@08oijej@04o`000?nJ/NOoV[7WoiZai`Go00000_nE
/^/00ol0003oSZg[ohj]j`07ohj]j`03o`000?n3Y>WoPjCY00OoPjCY00?o0000ogFHiomeV>L01ome
V>L00ol0003oHHOQof67h@05of67h@?o00001Om]Nm02o`0000SoG6O500?o0000ooooooooool08Ooo
ool2o`0000Col^O00ol00017ooooo`00:_ooool01?nj^[[o410@oa0@4?o<c<`Cooooo`;o0000J_oo
ool3o`0000GoYkkZ00?o0000ojNnj_nW_^X02OnW_^X00ol0003oYkgYojNmj@03o`0000GoY[gZ00?o
0000ojFljOnU_>T02OnU_>T01?l0003oYK[XojFjj?nU^^P5o`0000;oXk[Z00?o0000oj6hjOnQ^>T0
2OnQ^>T00ol0003oW[GYoijej@07oijej@Co00002?nE/^/00ol0003oSZg[ohj]j`07ohj]j`03o`00
0?n3Y>WoPjCY00OoPjCY00?o0000ogFHiomeV>L01_meV>L00ol0003oHHOQof67h@06of67h@03o`00
0?m6L=So000000;o00000_m]Nm000ol0003oKG_@o`000007oeaWa@03o`000?oooooooooo023ooooo
00?o0000on;m__l000000oobil001Ol0003ojLfjo`000?oooooo000004Kooooo000nooooo`?o0000
JOooool3o`0000WoYkkZ00?o0000ojNnj_nW_^X02?nW_^X3o`0000WoY[gZ00?o0000ojFljOnU_>T0
2?nU_>T4o`0000SoXk[Z00?o0000oj6hjOnQ^>T02?nQ^>T00ol0003oW[GYoijej@04oijej@?o0000
00?oV[K/o`000?nE/^/02OnE/^/00ol0003oSZg[ohj]j`07ohj]j`03o`000?n3Y>WoPjCY00SoPjCY
00?o0000ogFHiomeV>L01_meV>L00ol0003oHHOQof67h@06of67h@04o`000?m6L=SoAW3HodI`f0?o
000000?oKG_@o`000?mLIlD01_mLIlD00ol0003oooooooooo`0Oooooo`?o00001?obil001_l0003o
jLfjonW=^_l0003oooooo`0004Gooooo000kooooo`?o00000oooool00ol0003oooooooooo`1Toooo
o`;o000000?oYkoZo`000?nW_^X02_nW_^X00ol0003oYkkZojNnjP04ojNnjP?o000000?oY[kZo`00
0?nV_NX02_nV_NX00ol0003oYKcYojFlj@04ojFlj@?o000000?oY;cZo`000?nS^^X02_nS^^X00ol0
003oXKSYoj6hj@08oj6hj@03o`000?nN]NWoW[GY00?o00001OnJ]^`00ol0003oUK;[oiFbj`08oiFb
j`03o`000?n>[N_oSZg[00OoSZg[00?o0000oh>TjOn3Y>T01on3Y>T00ol0003oMISWogFHi`06ogFH
i`03o`000?mQQn7oHHOQ00KoHHOQ00?o0000odI`f?l000000_l000001?m6L=So0000o`000?l00008
oeaWa@03o`000?oooooooooo01gooooo0_l000000ooRoKko0000oo;W`002oo;W`003o`000?oYcK[o
jLfj00;ojLfj0_l00015ooooo`00>Oooool2o`0006[ooooo0ol00004ojNojP03o`000?nW_^[oYkkZ
00WoYkkZ00?o0000ojNnj_nW_^X00ol00005ojJnjP03o`000?nV_N[oY[gZ00WoY[gZ00?o0000ojFl
jOnU_>T00ol00005ojBljP03o`000?nS^^[oXk[Z00WoXk[Z00?o0000oj6hjOnQ^>T01_nQ^>T4o`00
00WoV[K/00?o0000oiFbjonE/^/02?nE/^/00ol0003oSZg[ohj]j`06ohj]j`03o`000?n3Y>WoPjCY
00SoPjCY00?o0000ogFHiomeV>L01OmeV>L00ol0003oHHOQof67h@05of67h@?o00001Om6L=P01?l0
003oAW3Ho`000?l00006oeaWa@03o`000?oooooooooo01gooooo0ol00003oo;W`003o`000?oYcK[o
jLfj00CojLfj0_l00014ooooo`00=_ooool3o`0006[ooooo0_l00008ojNojP03o`000?nW_^[oYkkZ
00SoYkkZ0ol00009ojJnjP03o`000?nV_N[oY[gZ00SoY[gZ0ol00009ojBljP03o`000?nS^^[oXk[Z
00WoXk[Z00?o0000oj6hjOnQ^>T01Ol00002oijik003o`000?nJ]^coV[K/00WoV[K/00?o0000oiFb
jonE/^/01onE/^/00ol0003oSZg[ohj]j`07ohj]j`03o`000?n3Y>WoPjCY00?oPjCY2?l00005ogFH
i`04o`000?mQQn7oHHOQof67h@?o00000_mQQn400ol0003oAW3HodI`f004odI`f0;o000000?o9U;8
o`000?mLIlD01?mLIlD00ol0003oooooooooo`0Looooo`?o00001?obil000ol0003ojLfjonW=^P04
onW=^P03o`000?oooooo000004?ooooo000eooooo`;o0000J_ooool2o`0000_oYkoZ00?o0000ojNn
j_nW_^X01OnW_^X2o`000003ojNnjol0003oY[kZ00[oY[kZ00?o0000ojJmj_nV_NX01OnV_NX2o`00
0003ojFmjol0003oY;cZ00[oY;cZ00?o0000oj>jj_nS^^X02?nS^^X3o`0000SoW[W/00?o0000oiZf
k?nJ]^`02?nJ]^`00ol0003oUK;[oiFbj`06oiFbja7o00001OmhYo000ol0003oHY[_of:Jk`09o`00
00GoHHOQ00?o0000odI`f?m6L=P01Om6L=P2o`000003obIBb?l0003oG6O500CoG6O500?o0000oooo
ooooool06_ooool4o`0000?ol^O000?o0000onW=^_oYcKX01?oYcKX01?l0003og;Veo`000?l00013
ooooo`00=?ooool4o`0006Kooooo0ol00002ojNoj`03o`000?nW_n[oYkoZ00SoYkoZ00?o0000ojNn
j_nW_^X00_nW_^X3o`0000CoYkk[00?o0000ojJnj_nV_^X02?nV_^X00ol0003oY[gZojJmjP02ojJm
jP?o00001?nU_N/00ol0003oY;cZojBljP09ojBljP03o`000?nS^^[oXk[Z00CoXk[Z0ol000000onQ
^nco0000oijik009oijik003o`000?nJ]^coV[K/00SoV[K/00?o0000oiFbjonE/^/01Ol00002oi6e
l003o`000?n7/?3oQk3`00OoQk3`00?o0000ogRWl?mhYo002?mhYo000ol0003oHY[_of:Jk`02of:J
k`Ko00001_mQQn400ol0003oAW3HodI`f004odI`f0;o00000_lVD/P2o`0000?oG6O500?o0000oooo
ooooool06Oooool4o`0000Col^O000?o0000onW=^_oYcKX01?oYcKX01Ol0003og;Veo`000?oooooo
000004;ooooo000eooooo`;o000000?oooooo`000?ooool0HOooool3o`0000KoYko[00?o0000ojNo
j_nW_nX02?nW_nX01?l0003oYkkZo`000?l00008ojNnj`03o`000?nV_^[oY[kZ00SoY[kZ00Co0000
ojJmj_l0003o00002?nU_N/00ol0003oY;cZojBljP09ojBljP03o`000?nS^^[oXk[Z00?o00001OnQ
^n`00ol0003oW[W/oijik008oijik003o`000?nJ]^coV[K/00KoV[K/1?l00008oi6el003o`000?n7
/?3oQk3`00OoQk3`00?o0000ogRWl?mhYo001omhYo000ol0003oHY[_o`000002o`0000?oHY[_00?o
0000od64j?m1Q>P00ol00003of67h@03o`000?m6L=SoAW3H00GoAW3H0_l00003obIBb004o`000?mL
IlGoG6O5o`0001[ooooo1Ol00003oo;W`003o`000?oYcK[ojLfj00CojLfj00?o0000ombi]OoL^KD0
0_l000000ooooooo0000ooooo`10ooooo`00=Oooool01Ol0003ooooooooooooooooo000005kooooo
0ol0000:ojNoj`03o`000?nW_n[oYkoZ00OoYkoZ0_l0000;ojNnj`03o`000?nV_^[oY[kZ00OoY[kZ
0_l0000;ojFmj`03o`000?nT_>[oY;cZ00SoY;cZ0ol00009oj6kk003o`000?nN^NcoW[W/00SoW[W/
00?o0000oiZfk?nJ]^`01Ol00002oiNik`03o`000?nA]O3oTKG`00SoTKG`00?o0000ohN`l?n7/?00
1on7/?000ol0003oN:O`ogRWl005ogRWl0?o00001omRV^l00ol0003o@HCXod64j002od64j0Co0000
2?m6L=P00ol0003o9U;8obIBb002obIBb0;o000000?oG6O5o`000?ooool05oooool5o`0000Col^O0
00?o0000onW=^_oYcKX00ooYcKX00ol0003og;Veombi]@02ombi]@03o`000?oooooo000000[ooooo
00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06onk^k_m4A4Co0000o`00
0?mEEEGok^k^8?ooool002Wooooo1?l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0F?ooool3o`0000;oYko[00?o0000ojNojonW_n/02OnW_n/00ol0
003oYkoZojNojP03ojNojP?o00000_nW_n/00ol0003oYkk[ojNnj`09ojNnj`03o`000?nV_^[oY[kZ
00?oY[kZ0ol00002ojFnj`03o`000?nU_N_oYKg[00WoYKg[00?o0000ojBlj_nT_>X01?nT_>X3o`00
0003oj>lk?l0003oXK_/00[oXK_/00?o0000oijik?nN^N`01_nN^N`4o`0000SoUkW_00?o0000oi6e
l?nA]O002?nA]O000ol0003oQk3`ohN`l007ohN`l003o`000?mhYo3oN:O`00;oN:O`0_l00003ogRW
l003o`000?mRV^ooHY[_00GoHY[_00?o0000od64j?m1Q>P01?m1Q>P3o`0000KoAW3H0_l00005obIB
b0;o00005oooool6o`0000?ol^O000?o0000onW=^_oYcKX01?oYcKX00ol0003og;Veombi]@02ombi
]@04o`000?ooooooooooo`0000Sooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o0000
1?ooool01_mEEEGoMgMgooooooooooooMgMgoeEEEB3ooooo000[ooooo`03o`000?oooooooooo00Ko
oooo0_l00005ooooo`03o`000?oooooooooo05Cooooo0ol00006ojNoj`03o`000?nW_n_oYko[00Wo
Yko[00?o0000ojNoj_l000000_l00006ojNoj`03o`000?nW_^_oYkk[00WoYkk[00?o0000ojJnj_l0
00000_l00006ojFnj`03o`000?nU_N_oYKg[00WoYKg[00?o0000ojBlj_nT_>X00ol00005oj>lk003
o`000?nQ^ncoXK_/00WoXK_/00?o0000oijik?nN^N`01Ol00002oibkkP03o`000?nG^NooUkW_00So
UkW_00?o0000oi6el?nA]O001onA]O000ol0003oQk3`ohN`l008ohN`l0Co00001OmhYo000ol0003o
HY[_of:Jk`06of:Jk`03o`000?m1Q>So@HCX00Co@HCX00Co0000oa5Rf?l0003o00001Om6L=P00ol0
003o9U;8obIBb004obIBb003o`000?oooooooooo01Cooooo1ol00002oo;W`003o`000?oYcK[ojLfj
00CojLfj00?o0000ombi]OoL^KD01?oL^KD01?l0003oooooooooool00007ooooo`06odA4A?nYZJWo
oooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@04ooooo`03oa0@4?oooooooooo00;ooooo
00?o0000ooooooooool07_ooool002_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo057ooooo0_l0000:ojNoj`03o`000?nW_n_oYko[00SoYko[0_l0
000:ojNoj`03o`000?nW_^_oYkk[00SoYkk[0_l0000:ojFnj`03o`000?nU_N_oYKg[00SoYKg[0ol0
0009oj>lk003o`000?nQ^ncoXK_/00SoXK_/0ol00008oibkkP03o`000?nG^NooUkW_00SoUkW_00?o
0000oi6el?nA]O001onA]O000ol0003oQk3`ohN`l003ohN`l1Co00000omRV^l00ol0003o@HCXod64
j004od64j003o`000?lAH]So4F;H00?o00000_m6L=P2o`0000Ko9U;800?o0000ooooooooool04_oo
ool7o`000004onKTcol0003ol^O0o`0000KojLfj00?o0000ombi]OoL^KD01?oL^KD01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003o
k^k^ooooo`02ooooo`03o`000?oooooooooo01kooooo000Oooooo`Oo00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0COooool3o`000003ojNo
jol0003oYko[00[oYko[00?o0000ojNojonW_n/01?nW_n/3o`000003ojNojol0003oYko[00[oYko[
00?o0000ojNnjonW_^/01?nW_^/3o`000003ojJnjol0003oYKk[00[oYKk[00?o0000ojFmjonU_N/0
1?nU_N/3o`000003ojBmjol0003oXkc/00[oXkc/00?o0000oj6kk?nQ^n`01?nQ^n`3o`000003oinl
kOl0003oW;_^00WoW;_^00?o0000oiNikonG^Nl02?nG^Nl00ol0003oTKG`oi6el003oi6el0_o0000
0on2]OD00ol0003oKjggofn]m`07ofn]m`03o`000?m@W_CoD9kd00;oD9kd1_l00005od64j003o`00
0?lAH]So4F;H00;o4F;H0_l000000om6L=So0000o`000005obIBb003o`000?oooooooooo013ooooo
1ol000001Om=003o0000onKTcooVi<oo000000KojLfj00?o0000ombi]OoL^KD01OoL^KD01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:oooo
o`06o`000?mEEEGok^k^oooooomgMgOoEEEE8?ooool002_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Wooooo0ol00005ojNoj`03o`000?nW_n_o
Yko[00WoYko[00?o0000ojNojonW_n/00ol00005ojNoj`03o`000?nW_n_oYko[00WoYko[00?o0000
ojNnjonW_^/00ol00005ojJnj`03o`000?nU_^_oYKk[00WoYKk[00?o0000ojFmjonU_N/00ol00005
ojBmj`03o`000?nS_>coXkc/00WoXkc/00?o0000oj6kk?nQ^n`00ol00005oinlk@03o`000?nL^nko
W;_^00SoW;_^00?o0000oiNikonG^Nl01_nG^Nl7o`0000GoS[Wc0ol00007oh:em@03o`000?m_[OOo
Kjgg00OoKjgg00?o0000oe2Nm?m@W_@01Om@W_@00ol0003o7X7Xo`000002o`0000?o@HCX00?o0000
oa5Rf?lAH]P00olAH]P3o`0000Ko9U;800?o0000ooooooooool03_ooool00ol0003oD/^`o`000003
o`0000;oC@0000Go0000onKTcooVi<ooi^C?o`000006onW=^P03o`000?oL^KGog;Ve00Kog;Ve00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2_ooool01_lQ8B7oIVIVo`000?l0003oEEEEonk^kR3ooooo000[ooooo`03o`000?oooooooooo00Ko
oooo0_l00009ooooo`03o`000?oooooooooo04Gooooo0ol00009ojNoj`03o`000?nW_n_oYko[00So
Yko[0ol00009ojNoj`03o`000?nW_n_oYko[00SoYko[0ol00009ojJnj`03o`000?nU_^_oYKk[00So
YKk[0ol00009ojBmj`03o`000?nS_>coXkc/00SoXkc/0ol00009oinlk@03o`000?nL^nkoW;_^00So
W;_^00?o0000oiNikonG^Nl01Ol00002oiJll@03o`000?n>^O?oS[Wc00CoS[Wc0ol000000on>^O?o
0000oh:em@08oh:em@03o`000?m_[OOoKjgg00OoKjgg00?o0000oe2Nm?m@W_@01Om@W_@01?l0003o
7X7Xoaj1j?lNPNP2o`000003od64j?l0003o4F;H00Ko4F;H0_l00005obIBb003o`000?oooooooooo
00gooooo00?o0000oe;;/?l000000_l00004odd00006o`000?oVi<ooi^C?o`000?oPc/Ko00001?oY
cKX00ol0003og;Veombi]@07ombi]@03o`000?oooooooooo00;o00001Oooool01_m4A4CoZJVYoooo
ooooooooZJVYodA4A0cooooo00?oQhN7ofIVI_ooool08oooool002_ooooo00?o0000ooooooooool0
1Oooool2o`0000_ooooo00?o0000ooooooooool0@_ooool2o`0000;oYko[00?o0000ojNojonW_n/0
2?nW_n/00ol0003oYko[ojNoj`04ojNoj`?o000000?oYko[o`000?nW_n/02_nW_n/00ol0003oYko[
ojNoj`04ojNoj`?o000000?oY[o[o`000?nV_^/02_nV_^/00ol0003oYKk[ojFnj`04ojFnj`?o0000
00?oYKk[o`000?nT_N/02_nT_N/00ol0003oXkc/oj>lk004oj>lk0?o000000?oX[g]o`000?nO_>d0
2_nO_>d00ol0003oW;_^oibkkP06oibkkPCo00002?nF_?400ol0003oS[Wcohjil`03o`0000GoS[Wc
00?o0000oh:emOn2]OD01on2]OD00ol0003oKjggofn]m`07ofn]m`03o`000?m@W_CoD9kd00GoD9kd
00?o0000oaj1j?lNPNP00_lNPNP3o`0000Ko4F;H00?o0000o`0b^Ol000001?lVD/P00ol0003ooooo
ooooo`0;ooooo`;o000000?oD/^`o`000?l000001_m=00000ol0003oi^C?o`000003on3>aP04o`00
0?oYcK[ojLfjo`0000Wog;Ve0_l000001Ooooooo0000oooooooooooo000000Cooooo00Koc<c<oc8b
<_o^k^kok^k^oc8b<_o<c<`=ooooo`03oc8b<_mVIVKogMgM02;ooooo000Yooooo`03o`000?m4A4Co
000000Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0nooooo`?o00001OnW_n/0
0ol0003oYko[ojNoj`08ojNoj`03o`000?nW_n_oYko[00?o00001OnW_n/00ol0003oYko[ojNoj`09
ojNoj`03o`000?nW_n_oYko[00?o00001OnV_n/00ol0003oY[k[ojJnj`09ojJnj`03o`000?nU_^_o
YKk[00?o00001OnU_^/00ol0003oY;g[ojBmj`09ojBmj`03o`000?nS_>coXkc/00?o00001OnR_Nd0
0ol0003oWkc]oinlk@09oinlk@03o`000?nL^nkoW;_^00Go00000_nK_O000ol0003oU[caoiJll@07
oiJll@?o00002On>^O<00ol0003oP[Geoh:em@03oh:emACo00000_m@W_@00ol0003o7X7Xoaj1j004
oaj1j0;o00001OlAH]P00ol0003o03:io`000004obIBb003o`000?oooooooooo00Wooooo00Co0000
oe;;/?l0003o00001om=00000ol0003oi^C?o`000005on3>aP03o`000?oYcK[o000000Sog;Ve00Co
0000olnY/oo?ZK?o00001?ooool00ol0003oooooooooo`02ooooo`04okZj^_l@413o410@olc<c0oo
oooo00CoMgMgoa0@4?l0003o8B4Q8?ooool002Wooooo00?oc<c<oeEEEOl000001oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03_ooooo0_l00009ojNoj`03o`000?nW_n_oYko[00Oo
Yko[0ol00009ojNoj`03o`000?nW_n_oYko[00SoYko[0ol00009ojJoj`03o`000?nV_^_oY[k[00So
Y[k[0ol00009ojFnj`03o`000?nT_N_oY;g[00SoY;g[0ol00009oj:mk@03o`000?nO_>goWkc]00So
Wkc]0ol00008oi^ml003o`000?nF_?7oU[ca00CoU[ca0_l00002oiJll@03o`000?n>^O?oS[Wc00Ko
S[Wc1ol00005oh6ln@03o`000?m[]O_oJkGk00OoJkGk00?o0000odBVmom4Y_L00_m4Y_L6o`0000Co
7X7X0ol00004oa5Rf0?o00000olVD/P00ol0003oooooooooo`08ooooo`?o000000?o2000o`000?m=
00001_m=00000ol0003oi^C?o`000006on3>aP03o`000?oL^KGog;Ve00Oog;Ve00Co0000olnY/oo?
ZK?o00001?ooool00ol0003oooooooooo`0iooooo`00<oooool2o`0000kooooo00?o0000oooooooo
ool0>?ooool3o`0000_oYko[00?o0000ojNojonW_n/00onW_n/3o`0000;oYko[00?o0000ojNojonW
_n/02?nW_n/00ol0003oYko[ojNoj`04ojNoj`?o000000?oYko[o`000?nV_n/02_nV_n/00ol0003o
Y[k[ojJnj`04ojJnj`?o000000?oY[o[o`000?nU_^/02_nU_^/00ol0003oY;g[ojBmj`04ojBmj`?o
000000?oXkk/o`000?nR_Nd02_nR_Nd00ol0003oWkc]oinlk@04oinlk@?o000000?oWkk_o`000?nK
_O002OnK_O000ol0003oU[caoiJll@03o`0000GoU[ca00?o0000ohjilon>^O<01Ol00002ohjnmP03
o`000?n1_?WoPKci00SoPKci00?o0000of^enom[]O/01om[]O/00ol0003oA:KgodBVm`06odBVm`Co
00000_lNPNP01?l0003o04o5o`000?l00002oa5Rf003o`000?l0<[Wo000000;o00000_lVD/P00ol0
003oooooooooo`05ooooo`?o00000_l800000ol0003oC@00odd00006odd000;o00001ooPc/H00ol0
003og;Veombi]@06ombi]@05o`000?o?ZK?ocjVcolnY/ol000001Oooool00ol0003oooooooooo`0h
ooooo`00<oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo0ol00003ojO0
j`03o`000?nW_n_oYko[00WoYko[00?o0000ojNojol000000_l00006ojNoj`03o`000?nW_n_oYko[
00SoYko[00?o0000ojNojonW_n/00ol00005ojNoj`03o`000?nV_n_oY[o[00WoY[o[00?o0000ojJn
jonV_^/00ol00005ojJoj`03o`000?nU_^_oYKk[00WoYKk[00?o0000ojBmjonT_N/00ol00005oj>n
k003o`000?nR_NgoX[g]00WoX[g]00?o0000oinlkOnO_>d00ol00005oinnk`03o`000?nK_O3oVkg`
00OoVkg`0ol00007oiJll@Co00002?n>__H00ol0003oPKcioh6ln@08oh6ln@03o`000?m[]O_oJkGk
00OoJkGk00?o0000odBVmom4Y_L01om4Y_L00ol0003o0h7No`000003o`0000;o04o500[o0000oa5R
f?lAH]So0000o`0b^Ol0003o03:io`000?lVD/So00001Oooool2o`0000Co200000Co0000odd00?m=
003oC@001ol00007on3>aP03o`000?oF_;oo000000Oog;Ve00?o0000olnY/oo?ZK<00_o?ZK<00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03Oooooo000cooooo`03o`000?oooooooooo00oo
oooo0_l0000aooooo`?o00001onW`>/00ol0003oYko[ojNoj`08ojNoj`;o00002_nW_n/00ol0003o
Yko[ojNoj`07ojNoj`?o00002OnW_n/00ol0003oY[o[ojJoj`08ojJoj`?o00002OnV_n/00ol0003o
YKk[ojFnj`08ojFnj`?o00002OnS_^`00ol0003oX[g]oj:mk@08oj:mk@?o00002OnO_^l00ol0003o
Vkg`oi^ml003oi^ml0?o000000?oVkg`o`000?nF_?400_nF_?45o`0000;oU[od00?o0000ohjnm_n>
__H02?n>__H00ol0003oPKcioh6ln@08oh6ln@03o`000?m[]O_oJkGk00?oJkGk5Ol000001_l0ClGo
0000o`000?l0003o03:io`0000;o03:i00Co0000obIBb?l0003ooooo3Ol00005ogd000;o00001_oP
c/H01?l0003oe[boomJl_ol00006ombi]@03o`000?o?ZK?ocjVc00?ocjVc00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0gooooo`00<oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo02cooooo0ol0000:ojO0j`03o`000?nW_n_oYko[00CoYko[0ol000000onW_n_o0000ojNo
j`0:ojNoj`03o`000?nW_n_oYko[00?oYko[0ol00002ojNoj`03o`000?nW_n_oYko[00SoYko[00?o
0000ojJojonV_n/01?nV_n/3o`0000;oY[o[00?o0000ojJojonV_n/02?nV_n/00ol0003oYKk[ojFn
j`04ojFnj`?o00000_nT_n`00ol0003oXkk/oj>nk008oj>nk003o`000?nR_NgoX[g]00CoX[g]0ol0
00000onQ_nko0000oinnk`09oinnk`03o`000?nK_O3oVkg`00?o00000onK_O05o`0000SoU[od00?o
0000ohjnm_n>__H02?n>__H00ol0003oPKcioh6ln@03oh6ln@[o00001_m_`?h00ol0003oA[?godJc
m`07odJcm`Oo000000Go04o5o`000?l0003o03:io`000002o`0b^@Ko00001Om100000ol0003oO@00
ogd00006ogd000;o00001_oPc/H00ol0003oe[boomJl_`02omJl_`03o`000?oL^KGog;Ve00;og;Ve
00?o0000olnY/oo?ZK<01?o?ZK<00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo
000booooo`;o00005?ooool00ol0003oooooooooo`0Xooooo`?o00000onW`>/00ol0003oYl3[ojO0
j`08ojO0j`03o`000?nW_n_oYko[00?o00001OnW_n/00ol0003oYko[ojNoj`09ojNoj`03o`000?nW
_n_o000000;o00001_nW_n/00ol0003oYko[ojNoj`08ojNoj`03o`000?nV_n_oY[o[00?o00001_nV
_n/00ol0003oY[o[ojJoj`08ojJoj`03o`000?nU_^_oYKk[00?o00001_nT_n`00ol0003oXkk/oj>n
k008oj>nk003o`000?nR_NgoX[g]00?o00001OnQ_nh00ol0003oWkk_oinnk`07oinnk`?o000000?o
Vkg`o`000?l000000ol00003oic0l@03o`000?nF_oCoU[od00SoU[od00?o0000ohjnm_n>__H01_n>
__H7o`0000OoQLCl00?o0000ofo0o_m_`?h01om_`?h00ol0003oA[?godJcm`03odJcma3o00000_l0
<[T00ol0003o@@00od400006od400003o`000?mm003oO@0000OoO@0000?o0000on3>a_oPc/H01OoP
c/H00ol0003oe[boomJl_`02omJl_`03o`000?oL^KGog;Ve00;og;Ve00?o0000olnY/oo?ZK<01Oo?
ZK<00ol0003oooooooooo`02ooooo`?o0000=oooool003;ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Tooooo`?o00001onW`>/00ol0003oYl3[ojO0j`07ojO0j`?o00002OnW_n/0
0ol0003oYko[ojNoj`08ojNoj`;o00002_nW_n/00ol0003oYko[ojNoj`07ojNoj`?o00002_nV_n/0
0ol0003oY[o[ojJoj`06ojJoj`Co00002_nT_n`00ol0003oXkk/oj>nk006oj>nk0Co00002OnQ_nh0
0ol0003oWkk_oinnk`03oinnk`?o000000CoWkk_o`000?l0003o00002OnL`?400ol0003oU[odoiJo
m008oiJom003o`000?n>__KoS[kf00Go00001?nAa?P00ol0003oQLClohG4o008ohG4o003o`000?m_
`?koKl3n00?oKl3n2Ol00007oeW6n@[o00000_l0<[T5o`0000;o@@0000?o0000ogd00?mm00002?mm
00000ol0003oh<k6on3>aP04on3>aP03o`000?oF_;ooe[bo00?oe[bo00Go0000ombi]OoL^KGog;Ve
o`000008olnY/`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=Oooool003;ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Qooooo`;o00002onW`>/00ol0003oYl3[ojO0
j`03ojO0j`?o00000_nW_n/00ol0003oYko[ojNoj`08ojNoj`03o`000?nW_n_oYko[00CoYko[0ol0
00000onW_n_o0000ojNoj`0:ojNoj`03o`000?nW_n_oYko[00?oYko[0ol00003ojJoj`03o`000?nV
_n_oY[o[00SoY[o[00?o0000ojJojonV_n/01Ol00003ojFok003o`000?nT_ncoY;o/00WoY;o/00?o
0000oj>nk?nS_^`01Ol00003oj>ok@03o`000?nQ_nkoXKo^00OoXKo^00Co0000oinnkonO_^ooWkk_
0_l000001?nO_^oo0000o`000?l00002oio0l003o`000?nL`?7oW<3a00SoW<3a00?o0000oiJom?nF
_o@01_nF_o@4o`0000[oTLCh00?o0000ohG4o?n5a?`01_n5a?`7o`0000KoO<go0ol00002oeW6n@Go
00000omif_/2o`0000?oW^Wk0_l00002o`0b^@03o`000?mJ003oFP0000;oFP001?l00008ogd00003
o`000?oPc/Koh<k600Coh<k600?o0000omJl_ooF_;l01OoF_;l01?l0003og;Veombi]Ol00008olnY
/`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool003;ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Mooooo`?o000000?oYl3[o`000?nW`>/02onW`>/00ol0003o
Yl3[o`000002o`0000KoYko[00?o0000ojNojonW_n/02?nW_n/00ol0003oYko[ojNoj`03o`0000Go
Yko[00?o0000ojNojonW_n/02OnW_n/00ol0003oYko[o`000002o`0000OoY[o[00?o0000ojJojonV
_n/01onV_n/3o`0000WoYKo/00?o0000ojBok?nT_n`02?nT_n`3o`0000WoXko]00?o0000oj6ok_nQ
_nh01onQ_nh6o`0000KoWl3`00?o0000oic0lOnL`?402?nL`?400ol0003oU[odoiJom005o`0000Co
VL?e00?o0000oi74n?nAa?P02?nAa?P00ol0003oQLClohG4o005o`0000?oS/cm00?o0000ogc=ooml
cOl02?mlcOl4o`0000GoNM[k0ol00004oikYn`;o000000Ko^^cdo`000?l0<[Wo03:io`000?mJ0002
o`0000CoU`P00ol00005ogd000;o00001OoPc/H00ol0003oe[boomJl_`05omJl_`03o`000?oL^KGo
000000[ocjVc00?o0000ooooooooool01?ooool00ol0003oooooooooo`0dooooo`00<_ooool3o`00
01Oooooo00?o0000ooooooooool06Oooool3o`0000GoYl3[00?o0000ojO0jonW`>/02OnW`>/2o`00
00[oYko[00?o0000ojNojonW_n/01onW_n/3o`0000WoYko[00?o0000ojNojonW_n/02?nW_n/2o`00
00_oY[o[00?o0000ojJojonV_n/00onV_n/3o`000003ojJok?l0003oYKo/00[oYKo/00?o0000ojBo
k?nT_n`01?nT_n`3o`000003ojBokOl0003oXko]00[oXko]00?o0000oj6ok_nQ_nh00onQ_nh6o`00
00[oWl3`00?o0000oic0lOnL`?401_nL`?44o`0000[oVL?e00?o0000oi74n?nAa?P01_nAa?P4o`00
00WoS/cm00?o0000ogc=oomlcOl01?mlcOl3o`0000CoT=Wo0_l000000omif__o0000o`000005oikY
n`;o00001?njk?@2o`000003o`0b^Ol0003o000000SoU`P00ol00002ogd00003o`000?oGcM3o0000
00?oh<k600?o0000omJl_ooF_;l01ooF_;l00ol0003ocjVcolnY/`09olnY/`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0<oooool0037ooooo0_l0000Jooooo`03o`000?oooooooooo01Go
oooo0ol00009ojO0j`03o`000?nW`>_oYl3[00KoYl3[0_l000000onW`>_o0000ojNoj`0:ojNoj`03
o`000?nW_n_oYko[00?oYko[0ol00002ojNoj`03o`000?nW_n_oYko[00SoYko[00?o0000ojNojonW
_n/01?nW_n/3o`0000;oYko[00?o0000ojJojonV_n/02OnV_n/00ol0003oY[o[o`000002o`0000Go
Y[o/00?o0000ojFok?nU_n`02OnU_n`00ol0003oY;o/ojBok003o`0000GoY;o]00?o0000oj>okOnS
_nd02OnS_nd00ol0003oXKo^o`000004o`0000?oX/3_00?o0000oio0l?nO`?002OnO`?000ol0003o
W<3aoic0l@05o`0000?oWL?b00?o0000oiW3mOnI`oD02OnI`oD00ol0003oTLChoi74n005o`0000?o
V<Wi00?o0000ohk<oOn>c?d02?n>c?d00ol0003oO<googc=o`03o`0000SoT=Wo0ol00005oikYn`03
o`000?njk?Co^^cd00?o^^cd0_l000001?o:i>[o0000o`000?nJ2002o`0000WoU`P00_l00003omO=
d003o`000?oPc/Ko000000[oe[bo00?o0000olnY/oo?ZK<02Oo?ZK<00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03;ooooo000aooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool04Oooool3o`0000;oYl3[00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o
00001?nW`>/00ol0003oYko[ojNoj`09ojNoj`03o`000?nW_n_o000000;o00001_nW_n/00ol0003o
Yko[ojNoj`08ojNoj`03o`000?nW_n_oYko[00?o00001_nW_n/00ol0003oY[o[ojJoj`08ojJoj`;o
00002OnV_n`00ol0003oYKo/ojFok008ojFok0?o00002OnT_nd00ol0003oXko]oj>ok@07oj>ok@Co
00002?nR`>l00ol0003oWl3`oio0l008oio0l0?o00002OnM`o800ol0003oVL?eoiW3m@08oiW3m@?o
00002OnHbOT00ol0003oS/cmohk<o@06ohk<o@Co00002?n@fOl3o`0000?oYMok0_l000000onNjO_o
0000o`000004ok[/m0;o00000_o:i>X01?l0003ob^CZo`000?l00002oiX80003o`000?nG203oU`P0
00OoU`P000?o0000omO=d?oGcM000_oGcM000ol0003oe[boomJl_`08omJl_`03o`000?o;[[co0000
00WocjVc0_l00008ooooo`03o`000?oooooooooo03;ooooo000Dooooo`04okZj^_l@413o0000ogMg
M`Kooooo00?oEEEEo`000?mEEED01?ooool01_nHV9So410@o`000?l0003oA4A4onk^kPKooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`?o00001_nW`>/00ol0003oYl3[ojO0
j`08ojO0j`04o`000?nW`>_o0000o`0000SoYl3[00?o0000ojNojonW_n/02?nW_n/2o`0000[oYko[
00?o0000ojNojonW_n/01onW_n/3o`0000[oYko[00?o0000ojJojonV_n/01?nV_n/3o`000003ojJo
k?l0003oY[o/00WoY[o/00?o0000ojFok?nU_n`01?nU_n`3o`000003ojFok?l0003oY;o]00[oY;o]
00?o0000oj>okOnS_nd00onS_nd4o`000003oj?0k_l0003oX/3_00WoX/3_00?o0000oio0l?nO`?00
1?nO`?03o`0000;oXL;`00?o0000oig3l_nM`o802?nM`o800ol0003oVL?eoiW3m@04oiW3m@?o0000
00?oWLOeo`000?nHbOT02_nHbOT00ol0003oS/cmohk<o@05o`0000CoVm?k0ol00002oi3Io`?o0000
1onUgo/3o`0000Co^^cd00?o0000ol[Tj_o:i>X00oo:i>X01?l0003ob^CZo`000?l00002oiX800;o
00001_nG20000ol0003oelg@omO=d003omO=d003o`000?oF_;ooe[bo00Ooe[bo00Co0000ol^^_?o;
[[co00002?o?ZK<01?l0003o`Ybbol:L/_l00008ooooo`03o`000?oooooooooo037ooooo000Coooo
o`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7Qooooooooooo
ogMgMom4A4@6ooooo`;o00007Oooool00ol0003oooooooooo`0:ooooo`;o00002_nW`>/00ol0003o
Yl3[ojO0j`07ojO0j`?o00002_nW`>/00ol0003oYko[ojNoj`04ojNoj`?o000000?oYl3[o`000?nW
_n/02_nW_n/00ol0003oYko[ojNoj`03ojNoj`?o00000onW_n/00ol0003oYko[ojNoj`08ojNoj`03
o`000?nV_n_oY[o[00?o00001OnV_n`00ol0003oY[o/ojJok008ojJok003o`000?nU_ncoYKo/00?o
00001OnU_n`00ol0003oY;o]ojBok@09ojBok@03o`000?nS_ngo000000?o00001OnS`>h00ol0003o
X/3_oj;0k`08oj;0k`03o`000?nO`?3oWl3`00?o00001_nQ`_000ol0003oWL?boig3lP08oig3lP03
o`000?nI`oGoVL?e00?o00001OnMaoD00ol0003oV<WioiS9n@08oiS9n@?o00002onKdo/3o`0000So
YMok0_l00003okOPm0;o000000?o^^cdo`000?o:i>X01_o:i>X01?l0003ocmSPo`000?l00003oiX8
00;o00000onG20000ol0003oelg@omO=d003omO=d003o`000?o@_/Wo000000Ooe[bo00Go0000ol^^
_?o;[[cobjjlo`000007olnY/`05o`000?o2W;;o`Ybbol:L/_l000001oooool00ol0003oooooo`00
000booooo`004oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED0
2Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
1_ooool3o`0000;oYl3[00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[ojO0j`03ojO0j`?o0000
0onW`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW_n_oYko[00?o00001OnW`>/00ol0003oYko[
ojNoj`09ojNoj`03o`000?nW_n_o000000;o00001onW_n/00ol0003oYko[ojNoj`07ojNoj`?o0000
2OnV_n`00ol0003oY[o/ojJok007ojJok0?o00002OnU_n`00ol0003oY;o]ojBok@07ojBok@Co0000
2OnS`>h00ol0003oX/3_oj;0k`07oj;0k`?o00002_nQ`_000ol0003oWL?boig3lP06oig3lPCo0000
2OnMaoD00ol0003oV<WioiS9n@04oiS9n@?o00000onPc_P00ol0003oVm?koi_Cn`06oi_Cn`;o0000
0onXeoP00ol0003oYMokojGOn`02ojGOn`?o00001_ngh?@2o`0000Kob^CZ0ol00002oloHh0;o0000
1?nJ20000ol0003oU`P0o`000005omO=d004o`000?o@_/Wod;k9o`0000Koe[bo00?o0000ol^^_?o;
[[`00oo;[[`00ol0003ocjVcolnY/`04olnY/`05o`000?o2W;;o`Ybbol:L/_l000002Oooool00ol0
003oooooooooo`0`ooooo`002_ooool7o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0>ooooo`03onk^k_l0003ooooo00Gooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`02ooooo`?o00001_nW`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_o000000;o
00001onW`>/00ol0003oYl3[ojO0j`07ojO0j`?o00002OnW`>/00ol0003oYko[ojNoj`08ojNoj`;o
00002onW_n/00ol0003oYko[ojNoj`03ojNoj`?o000000?oYko[o`000?nV_n`02_nV_n`00ol0003o
Y[o/ojJok003ojJok0?o000000?oY[o/o`000?nU_n`02_nU_n`00ol0003oY;o]ojBok@04ojBok@?o
00000_nT`>d00ol0003oXl3^oj?0kP07oj?0kP03o`000?nR`>ooX/3_00CoX/3_0ol00002oj?1k`03
o`000?nQ`_3oXL;`00WoXL;`00?o0000oig3l_nM`o801Ol00002oj75lP03o`000?nMaoGoWLOe00Wo
WLOe00?o0000oiS9nOnHbOT00ol00007oj3>n003o`000?nKdo_oVm?k00;oVm?k0ol00006ojSGn004
o`000?nUgo_o0000o`0000So]n3d00?o0000ol7Kk?l000001Oo:i>X01Ol0003ocmSPoloHh?o?f>3o
000000?ocmSP00Co0000oiX80?nJ203oVPP00_l00005omO=d003o`000?o@_/Wod;k900;od;k900?o
0000omJl_ooF_;l00ooF_;l00ol0003objjlol^^_003ol^^_003o`000?o?ZK?ocjVc00?ocjVc00?o
0000ol:L/_o2W;800oo2W;800ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo000C
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_l@413oV9RHoooooooo
ooooMgMgofIVIPKooooo00?o0000ooooooooool07oooool01?l0003oooooo`000?l0000:ojO0j`03
o`000?nW`>_oYl3[00OoYl3[0ol0000:ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00002ojO0j`03
o`000?nW`>_oYl3[00SoYl3[00?o0000ojNojonW_n/01?nW_n/3o`0000;oYko[00?o0000ojNojonW
_n/02OnW_n/00ol0003oYko[o`000002o`0000GoYko[00?o0000ojJok?nV_n`02OnV_n`00ol0003o
Y[o/o`000002o`0000GoY[o/00?o0000ojFok?nU_n`02OnU_n`00ol0003oY;o]ojBok@03o`0000Ko
Y<3]00?o0000oj?0k_nS`>h01onS`>h00ol0003oX/3_oj;0k`03o`0000KoXl7_00?o0000oj72l?nQ
`_002?nQ`_03o`0000SoXLGb00?o0000oig7mOnMaoD02?nMaoD3o`0000_oX<kh00Co0000oi_Cnol0
003o00002OnXeoP2o`0000So]n3d0_l00003ol7Kk005o`000?o:i>[ob^CZol[Tj_l000001Oo?f>00
0ol0003ocmSPoloHh002o`000003oiX80?l0003oelg@00Goelg@00?o0000om2nbOo@_/T00oo@_/T0
0ol0003oe[boomJl_`02omJl_`03o`000?o;[[cobjjl00Cobjjl00?o0000olnY/oo?ZK<00_o?ZK<0
0ol0003o`Ybbol:L/P04ol:L/P03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool0
01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000
o`000?mVIVH01oooool00ol0003oooooooooo`0Nooooo`?o00000_nW`>/00ol0003oYl3[ojO0j`08
ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000
ojO0jol000000_l00006ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000ojNojonW_n/00ol00006
ojNoj`03o`000?nW_n_oYko[00SoYko[0_l00009ojNoj`03o`000?nV_ncoY[o/00SoY[o/0_l00009
ojJok003o`000?nU_ncoYKo/00SoYKo/0ol0000:ojC0k@03o`000?nS`>koXl3^00GoXl3^1?l0000:
oj?1k`03o`000?nQ`_3oXL;`00CoXL;`0ol000000onSa?3o0000oj75lP09oj75lP03o`000?nMaoGo
WLOe00CoWLOe0ol00003oj?:m003o`000?nPc_SoX<kh00SoX<kh0ol00008ojSGn0;o00000_nceo<0
0ol0003o]n3dokOPm004okOPm003o`000?o1fnco`M_/00Co`M_/00?o0000ol[Tj_l000001oo?f>02
o`0000;oc/_G0_l00005omO=d003o`000?o@_/Wod;k900God;k900Co0000omJl_ooF_;oo00002?o;
[[`01Ol0003ocjVcolnY/oo?ZK?o000000Ko`Ybb00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0^ooooo`004oooool01_m4A4CoZJVYooooooooooooZJVYodA4A0cooooo00?o0000oooooooo
ool02?ooool2o`0001gooooo0ol00006ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000ojO0jol0
00000_l00007ojO0j`03o`000?nW`>_oYl3[00OoYl3[0_l0000:ojO0j`03o`000?nW`>_oYl3[00Oo
Yl3[0ol0000:ojNoj`03o`000?nW_n_oYko[00CoYko[0ol000000onW_n_o0000ojNoj`09ojNoj`03
o`000?nV_ncoY[o/00CoY[o/0ol000000onV`>co0000ojJok009ojJok003o`000?nU_ncoYKo/00Co
YKo/0ol00002ojG0k003o`000?nT`>goY<3]00WoY<3]00?o0000oj?0k_nS`>h01?l00003ojC1kP03
o`000?nS`NooXl7_00WoXl7_00?o0000oj72l?nQ`_000ol00005oj?4l003o`000?nQaO;oXLGb00So
XLGb00?o0000oig7mOnMaoD00ol00007oj?:m003o`000?nPc_SoX<kh00CoX<kh0ol00003ojS@m@03
o`000?nXeoSoZ=Oh00;oZ=Oh0ol00005ok?Gl`04o`000?ngh?Co]n3dokOPm0;o00001oo1fn`2o`00
00OocmSP0_l00005olk;e`05o`000?oGcM3oelg@omO=d?l000002?o@_/T00ol0003oe[boo`000009
ol^^_004o`000?o?ZK?ocjVco`0000So`Ybb00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0]ooooo`004oooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Jooooo`?o00002OnW`>/00ol0003oYl3[ojO0j`07ojO0j`?o0000
2_nW`>/00ol0003oYl3[ojO0j`03ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`08ojO0j`03o`00
0?nW`>_oYl3[00?oYl3[0ol00003ojO0j`03o`000?nW_n_oYko[00SoYko[00?o0000ojNojonW_n/0
0ol00005ojNoj`03o`000?nW_n_oYko[00SoYko[00?o0000ojJok?nV_n`00ol00005ojK0k003o`00
0?nV_ncoY[o/00SoY[o/00?o0000ojFok?nU_n`00ol00006ojG0k003o`000?nT`>goY<3]00SoY<3]
0ol00008ojC1kP03o`000?nS`NooXl7_00SoXl7_0ol00009oj?4l003o`000?nQaO;oXLGb00KoXLGb
1?l0000;oj?:m003o`000?nPc_SoX<kh00?o00001onXd?D01?l0003oZ=Oho`000?l00009ok?Gl`03
o`000?ngh?Co000000So`M_/00Co0000olKBi?o6d^Co00001Oo?f>001?l0003oc/_Golk;eol00005
olk;e`03o`000?oGcM3o000000[od;k900?o0000ol^^_?o;[[`02?o;[[`00ol0003ocjVco`000009
ol:L/P03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool001Cooooo00Co^[Zjoa0@
4?l@413oc<c<3Oooool5o`0000Kooooo00?o0000ooooooooool05oooool3o`0000?oYl3[00?o0000
ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0j`03ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`08
ojO0j`03o`000?nW`>_o000000;o00001_nW`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_o
000000;o00001onW`>/00ol0003oYko[ojNoj`07ojNoj`?o00002OnW_n/00ol0003oYko[ojNoj`07
ojNoj`?o00002OnV`>`00ol0003oY[o/ojJok007ojJok0?o00002_nU`>`00ol0003oY<3]ojC0k@04
ojC0k@?o000000?oYL7]o`000?nT`Nh02OnT`Nh00ol0003oXl7_oj?1k`04oj?1k`?o00000_nT`nl0
0ol0003oXlC`oj?4l008oj?4l003o`000?nQaO;oXLGb00Go00001?nTao800ol0003oXl[doj?:m008
oj?:m0?o00002_nXd?D2o`0000_o/mOc0ol00006ol7Kk0;o00001?o6d^@01Ol0003ocmSPoloHh?o?
f>3o000000Coc/_G00?o0000olk;eoo>bmL00_o>bmL2o`0000[od;k90_l0000;ol^^_003o`000?o2
W;;o`Ybb00So`Ybb00?o0000ooooooooool02?ooool2o`0002kooooo000`ooooo`03o`000?oooooo
oooo01Cooooo0ol00007ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jol000000_l00007
ojO0j`03o`000?nW`>_oYl3[00OoYl3[0_l0000:ojO0j`03o`000?nW`>_oYl3[00OoYl3[0_l0000;
ojO0j`03o`000?nW_n_oYko[00?oYko[0ol000000onW`>_o0000ojNoj`0:ojNoj`03o`000?nW_n_o
Yko[00?oYko[0ol00002ojO0k003o`000?nV`>coY/3/00SoY/3/00?o0000ojJok?nV_n`00onV_n`3
o`0000;oY/3/00?o0000ojG0k?nU`>`02OnU`>`00ol0003oY<3]ojC0k@03o`0000GoYL7]00?o0000
ojC1k_nT`Nh02?nT`Nh00ol0003oXl7_oj?1k`03o`0000KoY<?_00?o0000oj?4l?nSa?001onSa?03
o`0000[oY<Ob00?o0000oj?:m?nSb_@01?nSb_@3o`0000;oZ<cb00?o0000ojS@mOnXd?D01_nXd?D2
o`0000;o/=3a00?o0000ok?Glonceo<01_nceo<2o`0000?o^]?/00Co0000ol7Kk?o1fnco`M_/0_l0
0007olKBi003o`000?o?f>3o000000Goc/_G00Oo0000olk;eoo>bmOoc/_Go`000?o9_m7o000000Wo
d;k900Co0000olNbaOo7//Go00002Oo;[[`2o`0000_o`Ybb00?o0000ooooooooool02Oooool00ol0
003oooooooooo`07ooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool0
1_o^k^koA4A4o`000?l0003oA4A4onk^kPgooooo000_ooooo`?o00004oooool3o`0000[oYl3[00?o
0000ojO0jonW`>/01OnW`>/4o`0000[oYl3[00?o0000ojO0jonW`>/00onW`>/3o`000003ojO0jol0
003oYl3[00[oYl3[00?o0000ojO0jonW`>/00onW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/02OnW
`>/00ol0003oYko[o`000002o`0000GoYl3[00?o0000ojNojonW_n/02OnW_n/00ol0003oYko[o`00
0002o`0000KoYl3/00?o0000ojK0k?nV`>`02?nV`>`00ol0003oY[o/o`000002o`0000KoY/3/00?o
0000ojG0k?nU`>`02?nU`>`3o`0000WoYL7]00?o0000ojC1k_nT`Nh01onT`Nh3o`0000[oY<?_00?o
0000oj?4l?nSa?000onSa?03o`0000;oYLG`00?o0000ojC7l_nTao802OnTao800ol0003oXl[doj?:
m003o`0000KoZ<cb00?o0000ojS@mOnXd?D00_nXd?D3o`0000Go/=3a00?o0000ok?Glonceo<00_nc
eo<3o`0000Ko^]?/00?o0000ol7Kk?l000002Oo6d^@2o`0000Ooc/_G00?o0000olk;eol000000oo9
_m400ol0003od;k9om2nb@05om2nb@05o`000?o7//Goak;5olNbaOl000002?o;[[`01?l0003o`::k
ol2R^ol0000:ol:L/P03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool01_o<c<co
<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`06oc8b<_mgMgOok^k^onk^k_mgMgOo<S8b
3Oooool0033ooooo00?o0000ooooooooool03oooool3o`0000?oYl3[00?o0000ojO0jonW`>/02?nW
`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[o`00
0002o`0000GoYl3[00?o0000ojO0jonW`>/02OnW`>/00ol0003oYl3[o`000002o`0000KoYl3[00?o
0000ojO0jonW`>/02?nW`>/2o`0000WoYl3[00?o0000ojNojonW_n/02?nW_n/2o`0000[oYl3/00?o
0000ojK0k?nV`>`01_nV`>`3o`0000[oY/3/00?o0000ojG0k?nU`>`01?nU`>`3o`000003ojK1kOl0
003oYL7]00[oYL7]00?o0000ojC1k_nT`Nh00onT`Nh3o`0000;oYL;^00?o0000ojC3konT`nl02OnT
`nl00ol0003oXlC`o`000002o`0000KoYLG`00?o0000ojC7l_nTao802?nTao83o`0000[oZ<cb00Co
0000ojS@mOl0003o00002On`d?401?l0003o/mOco`000?l00009ok[Ck0;o00002Oo6d^@00ol0003o
a/WMo`000007olk;e`;o00001?o9_m400ol0003od;k9om2nb@04om2nb@03o`000?o7//Goak;500?o
ak;500?o0000ol^^_?o;[[`01?o;[[`01Ol0003o`::kol2R^oo0X[_o000000[o`Ybb00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`05ooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Ooo
ool00omEEEGo0000oeEEE@04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02ooo
ool002oooooo00?o0000ooooooooool03Oooool3o`0000OoYl3[00?o0000ojO0jonW`>/01onW`>/3
o`0000WoYl3[00?o0000ojO0jonW`>/01onW`>/2o`0000WoYl3[00?o0000ojO0jonW`>/02?nW`>/2
o`0000[oYl3[00?o0000ojO0jonW`>/01?nW`>/3o`000003ojO0jol0003oYl3[00WoYl3[00?o0000
ojNojonW_n/01?nW_n/3o`0000;oYl3[00?o0000ojO0k?nW`>`02?nW`>`00ol0003oY/3/ojK0k006
o`0000;oY/3/00?o0000ojK0k?nV`>`02?nV`>`00ol0003oYL3/ojG0k003o`0000GoY/7]00?o0000
ojG1kOnU`Nd02OnU`Nd00ol0003oY<7^o`000002o`0000KoYL;^00?o0000ojC3konT`nl02?nT`nl2
o`0000[oYLG`00?o0000ojC7l_nTao801?nTao83o`0000;oZ<S`00?o0000ojS<l_nXc?802?nXc?82
o`0000_o/=3a0_l00009ok[Ck0;o000000?o_/kVo`000?o6d^@01oo6d^@01Ol0003oa/WMolK9gOo6
bMgo000000Goc/_G00Co0000olVodOo9_m7o00001?o9_m400ol0003od;k9om2nb@02om2nb@03o`00
0?o7//Goak;500Coak;500?o0000ol^^_?o;[[`00oo;[[`00ol0003o`::kol2R^`02ol2R^`03o`00
0?o2W;;o`Ybb00Wo`Ybb00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_lb<S;oMgMgonk^k_o^k^koMgMgoc8b
<Pgooooo000_ooooo`03o`000?oooooooooo00_ooooo0ol0000:ojO0j`03o`000?nW`>_oYl3[00?o
Yl3[0ol000000onW`>_o0000ojO0j`0:ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00002ojO0j`03
o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/01?nW`>/3o`0000;oYl3[00?o0000ojO0jonW
`>/02?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00?o0000ojO0jonW`>/02?nW`>/00ol0003o
Yko[ojNoj`03o`0000KoYl3[00?o0000ojO0k?nW`>`01onW`>`6o`0000KoY/3/00?o0000ojK0k?nV
`>`01onV`>`3o`0000WoY/7]00?o0000ojG1kOnU`Nd02?nU`Nd2o`0000[oYL;^00?o0000ojC3konT
`nl01?nT`nl3o`000003ojK4kol0003oYLG`00[oYLG`00?o0000ojC7l_nTao800ol00006ojS8l003
o`000?nXc?;oZ<cb00CoZ<cb0ol00002ojk<k`03o`000?n`d?7o/=3a00Ko/=3a0_l00002okG>k003
o`000?njdnco^]?/00Co^]?/0_l00004okk>iP03o`000?o6d^Coa];T00?oa];T0_l00005olK9g@05
o`000?o>bmOoc/_Golk;eol000000oo9_m400ol0003obKoAolVod@03olVod@04o`000?o@_/Wod;k9
o`0000Ooak;500?o0000ol^^_?o;[[`00_o;[[`00ol0003o`::kol2R^`04ol2R^`03o`000?o2W;;o
`Ybb00So`Ybb00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02_ooool00ooMgMgo0000o`000002o`000003omgMgOoooooo
oooo00_ooooo000_ooooo`;o00002Oooool3o`0000?oYl3[00?o0000ojO0jonW`>/02?nW`>/00ol0
003oYl3[o`000002o`0000GoYl3[00?o0000ojO0jonW`>/02OnW`>/00ol0003oYl3[o`000002o`00
00KoYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0j`03o`0000KoYl3[00?o0000ojO0
jonW`>/01onW`>/3o`0000WoYl3[00?o0000ojO0jonW`>/01onW`>/3o`0000[oYl3[00?o0000ojO0
k?nW`>`00onW`>`6o`0000[oY/3/00?o0000ojK0k?nV`>`00onV`>`3o`0000;oY/3/00?o0000ojK1
kOnV`Nd02?nV`Nd00ol0003oYL7]ojG1k@04ojG1k@?o000000?oY/7]o`000?nU`^h02_nU`^h00ol0
003oY<?_ojC3k`03o`0000GoY/C_00?o0000ojG5l?nUaO002?nUaO03o`0000[oZ<S`00?o0000ojS<
l_nXc?800ol00006ojk<k`03o`000?n`d?7o/=3a00;o/=3a0ol00005okG>k003o`000?njdnco^]?/
00;o^]?/00?o0000okk>i_nnc^H01Onnc^H01Ol0003oa];TolKBi?o6d^Co000000Soa/WM00?o0000
olk;eol000001Oo9_m400ol0003obKoAolVod@02olVod@03o`000?o@_/Wo000000Woak;500Co0000
ol^^_?o;[[co00001oo0X[/00ol0003o`Ybbol:L/P07ol:L/P;o00003Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_lb<S;oIVIVonk^
k_o^k^koIVIVoc8b<Pgooooo000_ooooo`03o`000?oooooooooo00Gooooo0ol00007ojO0j`03o`00
0?nW`>_oYl3[00OoYl3[0_l00009ojO0j`03o`000?nW`>_oYl3[00SoYl3[0_l0000:ojO0j`03o`00
0?nW`>_oYl3[00GoYl3[1?l0000:ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00002ojO0j`03o`00
0?nW`>_oYl3[00SoYl3[00?o0000ojO0jonW`>/00onW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/0
2?nW`>/00ol0003oYl3/o`000005o`0000;oYl3/00?o0000ojK0k?nV`>`02OnV`>`00ol0003oY/3/
o`000002o`0000KoY/3/00?o0000ojK1kOnV`Nd02?nV`Nd00ol0003oYL7]ojG1k@03o`0000GoY/7]
00?o0000ojG2k_nU`^h02?nU`^h3o`0000WoY/C_00?o0000ojG5l?nUaO001?nUaO03o`000003ojS6
kol0003oZ<S`00[oZ<S`0ol0000:ojk<k`04o`000?n`d?7o0000o`0000Wo]Lk/00Co0000ok[Ck?l0
003o00002Onnc^H00ol0003oa];To`000009olK9g@;o00001oo9_m401?l0003obKoAolVodOo9_m42
o`0000[oak;500?o0000ol^^_?l000002Oo0X[/00ol0003o`Ybbol:L/P05ol:L/P03o`000?ndT[Co
000000gooooo0_l00004ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A43?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00_ooooo000_ooooo`03o`000?oooooooooo00?ooooo0ol0
000:ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol000000onW`>_o0000ojO0j`09ojO0j`03o`000?nW
`>_oYl3[00CoYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000ojO0jonW`>/01?l0
0004ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000ojO0jol000000_l00006ojO0j`03o`000?nW
`>_oYl3[00SoYl3[00?o0000ojO0jol000000_l00007ojO0j`03o`000?nW`>_oYl3[00OoYl3[1Ol0
0006ojO0k003o`000?nV`>coY/3/00SoY/3/0_l0000:ojK0k003o`000?nV`NgoY/7]00KoY/7]1?l0
0009ojK1k@03o`000?nU`^koYL;^00CoYL;^0ol00002ojK3kP03o`000?nVa>ooY/C_00SoY/C_00?o
0000ojG5l?nUaO000ol00005ojS6k`03o`000?nXb?3oZ<S`00KoZ<S`0_l000000on/b>ko0000ojk<
k`0:ojk<k`;o00002onec^`2o`0000_o_/kV0_l00009olK9g@03o`000?o3`=So000000SobKoA00Go
0000olVodOl0003o`kK=o`00000:olNba@;o00002_o0X[/00ol0003o`Ybbol:L/P04ol:L/P05o`00
0?ndT[Co]9:dokBB]?l000002_ooool2o`0000;ooooo00Ko0000ooooooooooooooooolc<c?lb<S82
onk^kP03oc8b<_o<c<cooooo00_ooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb<S8=ooooo`00;ooo
ool00ol0003oooooooooo`03o`0000?oYl3[00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[o`00
0002o`0000GoYl3[00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[ojO0j`03o`0000KoYl3[00?o
0000ojO0jonW`>/01onW`>/3o`0000WoYl3[00?o0000ojO0jonW`>/01onW`>/3o`0000WoYl3[00?o
0000ojO0jonW`>/01onW`>/2o`0000_oYl3[00?o0000ojO0jonW`>/00onW`>/5o`0000[oYl3/00?o
0000ojK0k?nV`>`01?nV`>`3o`0000;oY/3/00?o0000ojK0k?nV`>`02?nV`>`00ol0003oY/7]ojK1
k@05o`0000?oY/7]00?o0000ojK1kOnV`Nd02?nV`Nd00ol0003oYL;^ojG2kP03o`0000KoY/?^00?o
0000ojK4konVa>l01onVa>l3o`0000WoZ<K_00?o0000ojS8l?nXb?000_nXb?03o`0000Co[<S^00?o
0000ojk<kon^c>l01_n^c>l2o`000003ok7:k?l0003o]Lk/00So]Lk/0_l000000onhb^So0000okk>
iP08okk>iP;o000000?o_lOQo`000?o6bMd01oo6bMd01Ol0003o`l3Hol?0f?o3`=So000000OobKoA
0_l00003ol>fc@03o`000?o7//Goak;500Koak;500?o0000okfXa?l000002_o0X[/00ol0003o`Ybb
ol:L/P03ol:L/P03o`000?ndT[Co]9:d00;o]9:d00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`02ooooo`04okZj^_l@413o410@olc<c0gooooo00Kok^k^odA4A?l0003o0000odA4A?o^k^h=
ooooo`00;_ooool4o`0000OoYl3[00?o0000ojO0jonW`>/01onW`>/2o`0000WoYl3[00?o0000ojO0
jonW`>/01onW`>/3o`0000[oYl3[00?o0000ojO0jonW`>/00onW`>/3o`0000;oYl3[00?o0000ojO0
jonW`>/02?nW`>/00ol0003oYl3[ojO0j`03ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`07ojO0
j`03o`000?nW`>_oYl3[00?oYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00WoYl3[00?o0000ojO0
jol000001?l00003ojO0k003o`000?nW`>coYl3/00SoYl3/00?o0000ojK0k?nV`>`00ol00006ojK0
k003o`000?nV`>coY/3/00OoY/3/0ol00009ojK1k@03o`000?nV`NgoY/7]00OoY/7]0ol0000:ojK3
kP03o`000?nVa>ooY/C_00?oY/C_0ol00002ojS4kP03o`000?nXa^ooZ<K_00SoZ<K_00Co0000ojS8
l?l0003o00002?n/b>h00ol0003o[/c_ojk<k`02ojk<k`?o00001?nab^`00ol0003o]Lk/okG>k004
okG>k0;o00001?nhb^P00ol0003o_/kVokk>iP04okk>iP;o00001?noan400ol0003oa/WMolK9g@03
olK9g@;o00001?o3`=P00ol0003obKoAolVod@04olVod@?o00000oo3]/d00ol0003oak;5olNba@05
olNba@05o`000?nmZ<Co_JS4okfXa?l000002_o0X[/01Ol0003o`Ybbol:L/_o2W;;o000000Go]9:d
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Uooooo`00;_ooool2o`0000[oYl3[00?o
0000ojO0jonW`>/00onW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0
j`03ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_o000000;o00001_nW
`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_o000000;o00001onW`>/00ol0003oYl3[ojO0
j`07ojO0j`03o`000?nW`>_o000000;o00001_nW`>/00ol0003oYl3[ojO0j`08ojO0j`Co00001onW
`>`00ol0003oYl3/ojO0k007ojO0k0?o00002_nV`>`00ol0003oY/3/ojK0k003ojK0k0?o000000?o
Y/7/o`000?nV`Nd02_nV`Nd00ol0003oY/7]ojK1k@03ojK1k@?o00000_nW`^d00ol0003oY/?^ojK3
kP09ojK3kP03o`000?nVa>oo000000;o00001_nXa>h00ol0003oZ<K_ojS6k`07ojS6k`?o00002_n/
b>h01?l0003o[/c_o`000?l00008ok7:k003o`000?nec^co]Lk/00;o]Lk/00?o0000okS:j?nhb^P0
1Onhb^P00ol0003o_/kVokk>iP02okk>iP03o`000?noan7o_lOQ00Go_lOQ00Go0000olK9gOo6bMgo
a/WMo`000007ol?0f003o`000?o9_m7obKoA00;obKoA00Go0000ol>fcOo3]/go`kK=o`000003ol>f
c@03o`000?o7//Goak;500?oak;500?o0000okfXa?nmZ<@00_nmZ<@00ol0003o`::kol2R^`08ol2R
^`04o`000?o2W;;o`Ybbo`0000Oo]9:d00?o0000ooooooooool03Oooool00ol0003oooooooooo`0T
ooooo`00;_ooool00ol0003oooooo`00000:ojO0j`03o`000?nW`>_o000000;o00001_nW`>/00ol0
003oYl3[ojO0j`07ojO0j`03o`000?nW`>_o000000;o00001onW`>/00ol0003oYl3[ojO0j`07ojO0
j`;o00002_nW`>/00ol0003oYl3[ojO0j`07ojO0j`;o00002onW`>/00ol0003oYl3[ojO0j`05ojO0
j`?o00002_nW`>/00ol0003oYl3[ojO0j`04ojO0j`Ko00002OnW`>`00ol0003oYl3/ojO0k003ojO0
k0?o00000_nW`>`00ol0003oY/3/ojK0k009ojK0k003o`000?nV`>co000000;o00001OnV`N`00ol0
003oY/7]ojK1k@09ojK1k@03o`000?nV`Ngo000000;o00001_nW`^d00ol0003oY/?^ojK3kP08ojK3
kP;o00002_nXa>h00ol0003oZ<K_ojS6k`03ojS6k`?o00000on[a^d00ol0003o[<S^ojc8kP07ojc8
kP;o00002onab^`01?l0003o]Lk/o`000?l00009okS:j004o`000?nnc^Ko0000o`0000Wo_lOQ00?o
0000olK9gOl000002Oo3`=P01?l0003obKoAolVodOl00004ol>fc@05o`000?o3]/go`kK=ol>fcOl0
00001?o7//D00ol0003o_JS4okfXa003okfXa003o`000?o0X[_o`::k00So`::k00?o0000ol:L/_l0
00002?ndT[@00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Cooooo000Rooooo`04okZj
^_l@413o0000ogMgM`Sooooo00Co0000oooooooooooo00002OnW`>/3o`0000WoYl3[00?o0000ojO0
jonW`>/01_nW`>/3o`0000[oYl3[00?o0000ojO0jonW`>/00onW`>/3o`0000;oYl3[00?o0000ojO0
jonW`>/02?nW`>/00ol0003oYl3[ojO0j`03ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`09ojO0
j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_oYl3[
00Go00001?nW`>/00ol0003oYl3/ojO0k007ojO0k003o`000?nW`>co000000;o00001_nW`>`00ol0
003oY/3/ojK0k008ojK0k0;o00002OnV`N`00ol0003oY/7]ojK1k@08ojK1k@;o00002_nW`^d00ol0
003oY/?^ojK3kP04ojK3kP?o000000?oZ<?]o`000?nXa>h02_nXa>h00ol0003oZ<K_o`000002o`00
00OoZlK]00?o0000ojc8k_n/b>h00on/b>h3o`0000;o[lO/00?o0000ok7:k?nab^`02?nab^`2o`00
00_o^<[X0_l0000;oko7h@;o00002_o3`=P00ol0003obKoAo`000006ol>fc@05o`000?o3]/go`kK=
ol>fcOl000000_o7//D00ol0003o_JS4okfXa005okfXa003o`000?o0X[_o`::k00Oo`::k0_l00009
okBB]003o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool0027ooooo00Koc<c<oc8b
<_o^k^kok^k^ob4Q8OnYZJT7ooooo`05o`000?ooooooooooooooool000001OnW`>/3o`0000?oYl3[
00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/00ol0003oYl3[
ojO0j`08ojO0j`03o`000?nW`>_o000000;o00001_nW`>/00ol0003oYl3[ojO0j`08ojO0j`03o`00
0?nW`>_o000000;o00001_nW`>/00ol0003oYl3[ojO0j`08ojO0j`?o00002?nW`>/00ol0003oYl3[
ojO0j`07ojO0j`Go00002?nW`>/00ol0003oYl3/ojO0k005ojO0k0?o00002_nW`>`00ol0003oY/3/
ojK0k004ojK0k0?o00000_nW`N`00ol0003oY/7/ojK1k007ojK1k003o`000?nV`NgoY/7]00CoY/7]
0ol000000onW`Nco0000ojO2k@0:ojO2k@03o`000?nV`nkoY/?^00?o00001OnX`nd00ol0003oZ<C^
ojS4kP08ojS4kP;o00002on[a^d00ol0003o[<S^o`000002o`0000Ko[lO/00?o0000ok7:k?nab^`0
1Onab^`2o`0000;o]<OY00?o0000okS:j?nhb^P01_nhb^P2o`000003okW6i?l0003o_lOQ00So_lOQ
0_l000000onm`Mco0000ol?0f009ol?0f0;o00002?o3]/d01_l0003o`kK=ol>fcOl0003oak;5o`00
00So_JS400?o0000ol2R^oo0X[/01_o0X[/00ol0003o]9Vlo`000009okBB]003o`000?oooooooooo
00gooooo0ol0000Tooooo`008Oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PKooooo0ol00003
ooooo`03o`000?nW`>_o000000;o00001onW`>/00ol0003oYl3[ojO0j`07ojO0j`04o`000?nW`>_o
0000o`0000OoYl3[00?o0000ojO0jonW`>/01onW`>/3o`0000WoYl3[00?o0000ojO0jonW`>/01onW
`>/2o`0000[oYl3[00?o0000ojO0jonW`>/01?nW`>/3o`000003ojO0jol0003oYl3[00WoYl3[00?o
0000ojO0jonW`>/00onW`>/5o`000003ojO0jol0003oYl3[00WoYl3[00?o0000ojO0k?nW`>`01?l0
0003ojO0k003o`000?nW`>coYl3/00SoYl3/00?o0000ojK0k?nV`>`00ol00006ojO1k003o`000?nV
`NcoY/7/00OoY/7/00?o0000ojK1kOnV`Nd00ol00005ojO1k003o`000?nW`^goYl;]00SoYl;]0ol0
0009ojS3k@03o`000?nXa>koZ<C^00CoZ<C^0ol000000onZa>go0000oj_6k@0:oj_6k@;o00002_n_
an`00ol0003o/L[/ok7:k002ok7:k0;o00001OndanT00ol0003o^<[XokS:j002okS:j0?o00001?ni
a^@00ol0003o_lOQoko7h@04oko7h@;o00001?nm`M`00ol0003o`l3Hol?0f006ol?0f003o`000?nn
^=Co000000Wo`kK=00Co0000ol>fcOl0003o00002OnmZ<@00ol0003o`::kol2R^`04ol2R^`;o0000
0_ndVK`00ol0003o]9:dokBB]008okBB]003o`000?oooooooooo00kooooo00?o0000ooooooooool0
8_ooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo0_l0000:ojO0j`03o`000?nW`>_oYl3[00GoYl3[0ol0000:ojO0j`03o`000?nW
`>_oYl3[00?oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/00onW
`>/3o`0000;oYl3[00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00?o
0000ojO0jonW`>/02?nW`>/00ol0003oYl3[o`000004o`0000GoYl3[00?o0000ojO0jonW`>/01onW
`>/3o`0000SoYl3/00?o0000ojO0k?nW`>`01onW`>`3o`0000[oYl7/00?o0000ojK1k?nV`N`01OnV
`N`4o`0000WoYl7/00?o0000ojO2kOnW`^d01?nW`^d3o`0000;oZ<;]00?o0000ojS3kOnX`nd02?nX
`nd00ol0003oZ<C^ojS4kP03o`0000GoZ/C]00?o0000oj_6kOn[a^d01_n[a^d2o`000003ojg5k?l0
003o[lO/00[o[lO/00Co0000ok7:k?l0003o00002?ndanT01?l0003o^<[Xo`000?l00008okW6i003
o`000?noan7o_lOQ00;o_lOQ00?o0000okg1g?nm`M`01Onm`M`00ol0003o`l3Hol?0f003ol?0f0;o
00000onn^=@00ol0003o`kK=ol>fc@06ol>fc@;o000000?o^jg<o`000?nmZ<@02OnmZ<@00ol0003o
`::kol2R^`02ol2R^`03o`000?ndVKco]9Vl00?o]9Vl00?o0000okBB]?ndT[@01ondT[@00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?nW`>_oYl3[00SoYl3[
00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000ojO0jol00000
0_l00007ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jol000000_l00006ojO0j`03o`00
0?nW`>_oYl3[00OoYl3[0ol00009ojO0j`03o`000?nW`>_oYl3[00OoYl3[1?l00009ojO0j`03o`00
0?nW`>_oYl3[00?oYl3[0ol000000onW`>_o0000ojO0k009ojO0k003o`000?nW`>coYl3/00?oYl3/
0ol00002ojO0k003o`000?nW`NcoYl7/00WoYl7/00?o0000ojK1k?nV`N`01?l00003ojO1k003o`00
0?nW`NcoYl7/00SoYl7/00?o0000ojO2kOnW`^d00ol00006ojS2k@03o`000?nX`ngoZ<?]00OoZ<?]
0ol00009oj[4k@03o`000?n[a^goZlK]00;oZlK]0ol00004ojg5k003o`000?n_anco[lO/00So[lO/
0_l0000:okC7j@;o00002onia^@01?l0003o_lOQo`000?l00008okg1g004o`000?o3`=So`l3Hol?0
f0;o00001Onn^=@00ol0003o`kK=ol>fc@05ol>fc@?o00000_nk[L`00ol0003o_JS4okfXa007okfX
a003o`000?o0X[_o`::k00;o00001_ndVK`00ol0003o]9:dokBB]007okBB]003o`000?oooooooooo
013ooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ojO0jonW`>/01onW`>/3o`0000So
Yl3[00?o0000ojO0jonW`>/01onW`>/3o`0000[oYl3[00?o0000ojO0jonW`>/01OnW`>/3o`0000[o
Yl3[00?o0000ojO0jonW`>/00onW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003o
Yl3[ojO0j`03ojO0j`Co000000?oYl3[o`000?nW`>/02_nW`>/00ol0003oYl3[o`000002o`0000Go
Yl3[00?o0000ojO0k?nW`>`02?nW`>`00ol0003oYl3/o`000002o`0000KoYl3/00?o0000ojO1k?nW
`N`02?nW`N`3o`0000SoYl7/00?o0000ojO1k?nW`N`01onW`N`3o`0000[oZ<;]00?o0000ojS3kOnX
`nd00onX`nd3o`0000;oZL?/00?o0000oj[4kOnZa>d02?nZa>d01?l0003oZlK]o`000?l00008ojg5
k003o`000?n_anco[lO/00Co[lO/0ol00002ok75j@03o`000?ndanWo]<OY00Go]<OY0_l000000one
a>Ko0000okW6i00:okW6i0;o00002onm`M`00ol0003o`l3Ho`000008okjhe003o`000?o3]/go`kK=
00?o`kK=00Oo0000ok^]c?nk[Lco^jg<o`000?nk[Lco000000Wo_JS400?o0000ol2R^ol000002?nd
VK`00ol0003o]9:dokBB]007okBB]003o`000?oooooooooo013ooooo00?o0000ooooooooool08?oo
ool0027ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@6ooooo`;o00002Oooool00ol0003oYl3[
ojO0j`03ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?nW`>_oYl3[00?oYl3[
0ol00003ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`00
0?nW`>_oYl3[00SoYl3[00?o0000ojO0jol000000_l00007ojO0j`03o`000?nW`>_oYl3[00OoYl3[
00?o0000ojO0jol000001?l00004ojO0j`03o`000?nW`>_oYl3[00SoYl3[0_l00009ojO0j`03o`00
0?nW`>coYl3/00OoYl3/0_l0000:ojO0k003o`000?nW`NcoYl7/00CoYl7/0ol00002ojO1k003o`00
0?nW`NcoYl7/00OoYl7/00?o0000ojO1k?nW`N`00onW`N`3o`0000;oZ<;/00?o0000ojS2kOnX`^d0
2OnX`^d00ol0003oZ<?]o`000002o`0000KoZL?/00?o0000oj[4kOnZa>d01onZa>d2o`0000_o[LG/
00?o0000ojo7k?n_an`00ol00006ok75j@03o`000?ndanWo]<OY00;o]<OY0_l00004okG4iP03o`00
0?nia^Co^LKT00Oo^LKT00?o0000okS1h?l000002onm`M`2o`0000[o_[SD00?o0000ol>fcOo3]/d0
0_l00004ok^]c004o`000?nk[Lco^jg<o`0000So_JS40_l0000:okBI_003o`000?ndT[Co]9:d00Oo
]9:d00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`008Oooool01_o<c<co<S8b
onk^k_o^k^ko<S8bolc<c0Kooooo00?o0000ooooooooool02Oooool00ol0003oYl3[o`000002o`00
00KoYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[o`000002o`0000OoYl3[00?o0000ojO0
jonW`>/01onW`>/3o`0000SoYl3[00?o0000ojO0jonW`>/01onW`>/3o`0000[oYl3[00?o0000ojO0
jonW`>/01OnW`>/5o`0000SoYl3[00?o0000ojO0jonW`>/01?nW`>/3o`0000;oYl3[00?o0000ojO0
jonW`>/01onW`>/00ol0003oYl3/ojO0k003ojO0k0?o00000_nW`>`00ol0003oYl3/ojO0k008ojO0
k003o`000?nW`NcoYl7/00?o00001_nW`N`00ol0003oYl7/ojO1k007ojO1k003o`000?nW`Nco0000
00;o00001_nX`^`00ol0003oZ<;]ojS2k@08ojS2k@;o00002_nY`n`00ol0003oZ/C]oj[4k@03oj[4
k@?o000000?oZlC/o`000?n]aN`02_n]aN`3o`0000[o/LGY00Co0000okC7jOl0003o00001onea>H0
0ol0003o^LKTokW6i004okW6i0;o00000onh`N000ol0003o_L7Lokg1g006okg1g0;o000000?o^[[J
o`000?nn^=@02Onn^=@00ol0003o`kK=o`000007ok^]c003o`000?nk[Lco000000Oo_JS400?o0000
ok>PaOl000002_ndVK`00ol0003o]9:dokBB]007okBB]003o`000?oooooooooo013ooooo00?o0000
ooooooooool07oooool002;ooooo00Co^[Zjoa0@4?l@413oc<c<1oooool00ol0003oooooooooo`0:
ooooo`;o00002OnW`>/00ol0003oYl3[ojO0j`06ojO0j`?o00002_nW`>/00ol0003oYl3[ojO0j`03
ojO0j`?o000000?oYl3[o`000?nW`>/02OnW`>/00ol0003oYl3[ojO0j`03ojO0j`?o00000onW`>/0
0ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_oYl3[00Ko000000?oYl3[o`000?nW`>/02OnW`>/0
0ol0003oYl3[ojO0j`03o`0000KoYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3/o`000002
o`0000KoYl3/00?o0000ojO0k?nW`>`01onW`>`3o`0000[oYl7/00?o0000ojO1k?nW`N`01OnW`N`3
o`0000[oZ<;/00?o0000ojS2kOnX`^d01?nX`^d3o`000003ojW2k?l0003oZL?/00[oZL?/00?o0000
oj[4kOl000000_l00005oj_4k003o`000?n]aNco[LG/00Ko[LG/0_l000000on^a>[o0000ok75j@0:
ok75j@;o00002_nea>H01?l0003o^LKTokW6i?nia^@2o`0000Ko^<7P00?o0000okg1g?nm`M`00onm
`M`2o`0000Co^[[J00?o0000okjhe?nn^=@01onn^=@2o`0000Wo^jg<0_l00005okfXa0;o00000onc
X<D00ol0003o]9VlokBI_007okBI_003o`000?ndT[Co]9:d00Oo]9:d00?o0000ooooooooool03ooo
ool3o`00023ooooo000]ooooo`03o`000?oooooooooo00cooooo00?o0000ojO0jonW`>/01onW`>/0
0ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_o
000000;o00001OnW`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_o000000;o00001onW`>/0
0ol0003oYl3[ojO0j`07ojO0j`Ko00001OnW`>/00ol0003oYl3[ojO0j`07ojO0j`?o00002_nW`>/0
0ol0003oYl3[ojO0j`05ojO0j`?o00002_nW`>`00ol0003oYl3/ojO0k003ojO0k0?o00000_nW`>`0
0ol0003oYl7/ojO1k009ojO1k003o`000?nW`NcoYl7/00Co00000onW`N`00ol0003oZ<;/ojS2k008
ojS2k003o`000?nX`^goZ<;]00?o00001OnY`^`00ol0003oZL?/ojW3k008ojW3k0;o00002On[a>`0
0ol0003o[LG/ojg5k002ojg5k0?o00001?n^a>X00ol0003o/LGYok75j@06ok75j@;o000000?o/L?W
o`000?nea>H02_nea>H00ol0003o^LKTo`000008okS1h003o`000?nm`Mco_L7L00;o_L7L00?o0000
okZjf_nj^]X01?nj^]X00ol0003o_[SDokjhe006okjhe003o`000?nh/M?o000000[o^jg<0_l00002
okfXa0;o00001OncX<D00ol0003o]9VlokBI_007okBI_003o`000?ndT[Co]9:d00So]9:d00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Mooooo`00;?ooool2o`0000oooooo00?o0000ojO0
jonW`>/01onW`>/01?l0003oYl3[o`000?l00007ojO0j`03o`000?nW`>_oYl3[00OoYl3[0ol00008
ojO0j`03o`000?nW`>_oYl3[00OoYl3[0ol0000:ojO0j`03o`000?nW`>_oYl3[00?oYl3[1_l00009
ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00WoYl3[00?o0000
ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>coYl3/00SoYl3/00?o0000ojO0k?l000000_l00006
ojO0k003o`000?nW`NcoYl7/00SoYl7/0ol00008ojO1k003o`000?nX`^coZ<;/00OoZ<;/0ol00009
ojW2k003o`000?nY`ncoZL?/00CoZL?/0ol000000onZ`n_o0000oj_4k009oj_4k004o`000?n]aNco
0000o`0000So[/CZ00?o0000ok75jOnaaNT00_naaNT3o`0000Co/L?W00?o0000okG4i_nea>H02?ne
a>H2o`0000[o^<7P00Co0000okg1g?l0003o00002?nj^]X00ol0003o_[SDokjhe003okjhe0;o0000
0onh/M<00ol0003o^jg<ok^]c007ok^]c0;o000000?o_JS4o`000?ncX<D01_ncX<D00ol0003o]9Vl
okBI_008okBI_003o`000?ndT[Co]9:d00Ko]9:d0_l0000Cooooo`03o`000?oooooooooo01gooooo
000/ooooo`03o`000?oooooooooo00oooooo00?o0000ojO0jonW`>/01OnW`>/3o`0000[oYl3[00?o
0000ojO0jonW`>/00onW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0
j`03ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_o000000Go00000_nW
`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_o000000;o00001_nW`>/00ol0003oYl3[ojO0
j`08ojO0j`?o00002?nW`>/00ol0003oYl3/ojO0k007ojO0k0;o00002_nW`>`00ol0003oYl7/ojO1
k004ojO1k0?o000000?oYl7/o`000?nW`N`02OnW`N`00ol0003oZ<;/ojS2k003ojS2k0?o00000_nX
`^`00ol0003oZL;/ojW2k008ojW2k003o`000?nY`ncoZL?/00?o00001OnZ`n/00ol0003oZlC/oj_4
k007oj_4k0?o00002_n^a>X01?l0003o/LGYo`000?l00008ok73i`03o`000?nea>Ko]LCV00Go]LCV
0_l000000ond`N?o0000okS1h009okS1h0;o00002onj^]X00ol0003o_[SDokjhe002o`0000Go^;7C
00?o0000ok^]c?nk[L`02?nk[L`2o`0000Wo/j3500?o0000okBI_?ndVK`01ondVK`00ol0003o]9:d
okBB]004okBB]0;o000000?oY8Rgo`000?ooool04oooool00ol0003oooooooooo`0Looooo`00;?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0
j`08ojO0j`03o`000?nW`>_o000000;o00001onW`>/00ol0003oYl3[ojO0j`06ojO0j`03o`000?nW
`>_o000000;o00001onW`>/00ol0003oYl3[ojO0j`07ojO0j`Go00001_nW`>/00ol0003oYl3[ojO0
j`07ojO0j`;o00002_nW`>/00ol0003oYl3[ojO0j`04ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0
j`07ojO0j`03o`000?nW`>coYl3/00?oYl3/0ol00002ojO0k003o`000?nW`>coYl3/00SoYl3/00?o
0000ojO1k?nW`N`00ol00005ojO1k003o`000?nW`NcoYl7/00SoYl7/00?o0000ojS2k?l000000_l0
0006ojS2k003o`000?nY`^coZL;/00OoZL;/0ol00009oj[3j`03o`000?n[a>coZlC/00?oZlC/0ol0
0003ojc3jP03o`000?n^a>[o[/CZ00Oo[/CZ0_l0000:ok73i`03o`000?nea>Ko]LCV00;o]LCV0ol0
0004okC1h`03o`000?nh`N3o^<7P00Go^<7P0_l000000onf_=ko0000okZjfP0:okZjfP03o`000?nn
^=Co000000So^;7C00?o0000ok^]c?nk[L`01Onk[L`2o`000003ok:Vc?l0003o/j3500So/j3500?o
0000okBI_?ndVK`01ondVK`01?l0003o]9:dokBB]?ndT[@3o`0000?oY8Rg00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Kooooo`00;?ooool00ol0003oooooooooo`0Aooooo`;o00002?nW
`>/00ol0003oYl3[ojO0j`07ojO0j`?o00002_nW`>/00ol0003oYl3[ojO0j`04ojO0j`Co00002_nW
`>/00ol0003oYl3[ojO0j`03ojO0j`Ko00002OnW`>/00ol0003oYl3[ojO0j`03ojO0j`?o00000_nW
`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_oYl3[00?o00001_nW`>/00ol0003oYl3[ojO0
j`07ojO0j`03o`000?nW`>co000000;o00001_nW`>`00ol0003oYl3/ojO0k007ojO0k0?o00002OnW
`N`00ol0003oYl7/ojO1k006ojO1k0?o00002_nX`^`00ol0003oZL;/ojW2k003ojW2k0?o000000?o
ZL;[o`000?nZ`n/02_nZ`n/00ol0003oZlC/o`000002o`0000Oo[<?Z00?o0000ojk4j_n^a>X00on^
a>X3o`000003ojo2j?l0003o/L?W00[o/L?W00Co0000okG4i_l0003o00002?nd`N<00ol0003o^<7P
okS1h002okS1h0;o00001?nf_=h00ol0003o^[[JokZjfP08okZjfP;o00002Onh/M<00ol0003o^jg<
ok^]c003ok^]c0;o00001?nbY/`00ol0003o/j35ok>Pa@07ok>Pa@03o`000?ndVKco]9Vl00Oo]9Vl
0ol00007ojB8]`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06oooool002cooooo00?o
0000ooooooooool04_ooool00ol0003oYl3[ojO0j`07ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol0
0003ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW
`>_oYl3[00SoYl3[00?o0000ojO0jol000001Ol00003ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o
0000ojO0jol000000_l00006ojO0j`03o`000?nW`>_oYl3[00OoYl3[0ol0000:ojO0j`03o`000?nW
`>_oYl3[00GoYl3[0ol0000:ojO0k003o`000?nW`>coYl3/00?oYl3/0ol00002ojO1k003o`000?nW
`NcoYl7/00SoYl7/00?o0000ojO1k?nW`N`01Ol00002ojS1k003o`000?nX`^coZ<;/00WoZ<;/00?o
0000ojW2k?l000000_l00005ojW2j`03o`000?nZ`n_oZ/?[00SoZ/?[0_l0000;ojc3jP03o`000?n^
a>[o000000;o00001On_`^P00ol0003o/L?Wok73i`08ok73i`;o00002ond`N<01?l0003o^<7Po`00
0?l00007okJlgP03o`000?nj^][o^[[J00Go^[[J0_l000000one]MWo0000okRad`09okRad`05o`00
0?nk[Lco^jg<ok^]c?l000001_nbY/`00ol0003o/j35ok>Pa@07ok>Pa@03o`000?ndVKco]9Vl00Ko
]9Vl0_l00009ojB8]`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06_ooool002_ooooo
0ol0000Dooooo`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jol000000_l00007ojO0j`03o`00
0?nW`>_oYl3[00OoYl3[0ol00008ojO0j`03o`000?nW`>_oYl3[00OoYl3[1Ol00007ojO0j`03o`00
0?nW`>_oYl3[00GoYl3[0ol0000:ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00003ojO0j`03o`00
0?nW`>_oYl3[00SoYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>coYl3/00SoYl3/
00?o0000ojO0k?l000000_l00006ojO1k003o`000?nW`NcoYl7/00OoYl7/0ol00008ojS1k003o`00
0?nX`^coZ<;/00SoZ<;/0_l00009ojW2j`03o`000?nZ`n_oZ/?[00CoZ/?[0ol000000on[`^_o0000
ojc3jP0:ojc3jP;o00002On_`^P00ol0003o/L?Wok73i`04ok73i`?o000000?o/L7Uo`000?nd`N<0
2_nd`N<2o`0000Wo][cN00?o0000okZjf_nj^]X00_nj^]X3o`0000Co]KGI00?o0000okRadonh/M<0
1onh/M<01?l0003o^jg<o`000?l00007ok:Vc0;o00002OncX<D00ol0003o]9VlokBI_003okBI_0;o
000000?oYY6oo`000?nTR;L02?nTR;L00ol0003oooooooooo`0Booooo`?o00002Oooool4o`000003
oa0@4?oooooooooo00_ooooo000[ooooo`03o`000?oooooooooo01Gooooo00?o0000ojO0jonW`>/0
1_nW`>/3o`0000[oYl3[00?o0000ojO0jonW`>/00onW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/0
1onW`>/00ol0003oYl3[ojO0j`03ojO0j`Ko00002_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[o`000002o`0000OoYl3[00?o0000ojO0jonW`>/0
1onW`>/3o`0000SoYl3[00?o0000ojO0k?nW`>`01onW`>`2o`0000[oYl7/00?o0000ojO1k?nW`N`0
0onW`N`3o`0000;oZ<7[00?o0000ojS1k?nX`N`01onX`N`00ol0003oZ<;/ojS2k004ojS2k0?o0000
00?oZL7[o`000?nY`^/02OnY`^/00ol0003oZ/?[oj[3j`03o`0000GoZl;[00?o0000ojc3j_n/`nX0
1_n/`nX2o`000003ojg2jOl0003o[l;X00Wo[l;X00?o0000ok73iona`nL00ol00005ok71i@03o`00
0?nd`N?o]<7S00Ko]<7S0_l000000onc_N;o0000okJlgP09okJlgP04o`000?nj^][o0000o`0000Oo
]KGI00?o0000okRadonh/M<01onh/M<2o`0000[o/ZK<0_l00008ok>Pa@04o`000?ndVKco]9VlokBI
_0;o00001?nVTKl00ol0003oY8RgojB8]`06ojB8]`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0=ooooo`00:oooool00ol0003oooooooooo`0Fooooo`03
o`000?nW`>_oYl3[00;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000ojO0jol0
00000_l00006ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jol000001?l00004ojO0j`03
o`000?nW`>_oYl3[00OoYl3[0ol00008ojO0j`03o`000?nW`>_oYl3[00OoYl3[0ol0000:ojO0j`03
o`000?nW`>_oYl3[00?oYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0k?nW
`>`00onW`>`3o`0000;oYl3[00?o0000ojO1k?nW`N`02?nW`N`00ol0003oYl7/o`000002o`0000Ko
Z<7[00?o0000ojS1k?nX`N`01onX`N`00ol0003oZ<;/ojS2k003o`0000GoZL7[00?o0000ojW2jonY
`^/01onY`^/3o`0000WoZl;[00?o0000ojc3j_n/`nX00_n/`nX3o`0000Co[L;Y00?o0000ojo2j?n_
`^P01on_`^P3o`0000Wo/L7U00?o0000okC1hond`N<00_nd`N<3o`0000Co/kgR00?o0000okJlg_nf
_=h01onf_=h2o`0000[o]KGI00?o0000okRadonh/M<01?nh/M<2o`000003ok6/dol0003o/ZK<00Wo
/ZK<0_l00008ok>Pa@04o`000?ndVKco0000o`0000KoYY6o00?o0000ojB8]onTR;L01onTR;L00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool002_o
oooo00?o0000ooooooooool05oooool01?l0003oYl3[o`000?l00007ojO0j`03o`000?nW`>_oYl3[
00OoYl3[0_l0000:ojO0j`03o`000?nW`>_oYl3[00GoYl3[1Ol00008ojO0j`03o`000?nW`>_oYl3[
00?oYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/00onW`>/3o`00
00?oYl3[00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[o`000002o`0000KoYl3[00?o0000ojO0
jonW`>/01onW`>/00ol0003oYl3/o`000002o`0000KoYl3[00?o0000ojO1k?nW`N`01onW`N`2o`00
00[oZ<7[00?o0000ojS1k?nX`N`01OnX`N`4o`0000WoZL7[00?o0000ojW2jonY`^/00onY`^/3o`00
00;oZ/7[00?o0000oj_2jon[`^/02?n[`^/01?l0003o[<?Zo`000?l00008ojg2j@03o`000?n_`^So
[l;X00?o[l;X0ol00002ojo0i`03o`000?na`NGo/L7U00So/L7U00Co0000okC1hol0003o00002?nc
_N800ol0003o][cNokJlgP04okJlgP;o000000?o/[SMo`000?ne]MT02_ne]MT01?l0003o^;7CokRa
donh/M<2o`0000Co/JcC00?o0000ok:Vc?nbY/`02?nbY/`2o`0000Oo/j350_l00008ojJA_`03o`00
0?nTR;OoY8Rg00OoY8Rg00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00gooooo000[ooooo`?o00006?ooool00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW
`>_oYl3[00?oYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000ojO0jonW`>/01_l0
00000onW`>_o0000ojO0j`09ojO0j`03o`000?nW`>_o000000;o00001_nW`>/00ol0003oYl3[ojO0
j`07ojO0j`03o`000?nW`>_o000000;o00001onW`>/00ol0003oYl3[ojO0j`07ojO0j`;o00002_nW
`>/00ol0003oYl3[ojO0j`05ojO0j`?o00002_nW`>/00ol0003oYl7/ojO1k003ojO1k0?o00000_nX
`N/00ol0003oZ<7[ojS1j`08ojS1j`03o`000?nX`NcoZ<7/00Co00000onX`N/00ol0003oZL7[ojW1
j`08ojW1j`03o`000?nY`^_o000000;o00001_nZ`N/00ol0003oZl;[oj_2j`07oj_2j`;o00002on]
`^T00ol0003o[l;Xo`000002o`0000Ko[l3W00?o0000ok71iOna`ND01ona`ND2o`0000[o/kgR00?o
0000okJlg_nf_=h00_nf_=h2o`0000Co/[SM00?o0000okFefOne]MT02?ne]MT01?l0003o^;7Co`00
0?l00006ok6/d`03o`000?nbY/co/ZK<00So/ZK<00?o0000ok>PaOl000000oncX<D3o`000003ojNI
aol0003oYY6o00SoYY6o00?o0000ojB8]onTR;L01_nTR;L00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03Oooool002[ooooo0_l0000Kooooo`03o`000?nW
`>_oYl3[00SoYl3[00?o0000ojO0jol000000_l00006ojO0j`03o`000?nW`>_oYl3[00OoYl3[1_l0
0005ojO0j`03o`000?nW`>_oYl3[00OoYl3[0ol00009ojO0j`03o`000?nW`>_oYl3[00GoYl3[1?l0
000:ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o
0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000ojO1k?l000000_l0
0006ojS1j`03o`000?nX`N_oZ<7[00OoZ<7[0ol00008ojS1j`03o`000?nY`N_oZL7[00OoZL7[0_l0
000:oj[1j`03o`000?n[`^_oZl;[00?oZl;[0ol00002ojc1j@03o`000?n]`^Wo[L;Y00So[L;Y0_l0
000:ojo0i`03o`000?na`NGo/L7U00?o/L7U0ol000000on`_^Co0000ok>mhP0:ok>mhP04o`000?nf
_=ko0000o`0000Ko/[SM00?o0000okFefOne]MT02?ne]MT2o`0000Wo/JcC00?o0000ok:Vc?nbY/`0
1onbY/`00ol0003o/j35ok>Pa@03o`0000GoYiW700?o0000ojJA_onVTKl01_nVTKl00ol0003oY8Rg
ojB8]`07ojB8]`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0=ooooo`003Oooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo
00KoV9RHoa0@4?l0003o0000odA4A?o^k^h7ooooo`03o`000?oooooooooo01[ooooo00?o0000ojO0
jonW`>/01onW`>/3o`0000WoYl3[00?o0000ojO0jonW`>/00onW`>/3o`000004ojO0jol0003o0000
o`0000SoYl3[00?o0000ojO0jonW`>/00onW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01onW`>/0
0ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[o`000002
o`0000KoYl3[00?o0000ojO0jonW`>/01onW`>/3o`0000SoYl3[00?o0000ojO0jonW`>/01onW`>/2
o`0000[oZ<7[00?o0000ojS1jonX`N/00onX`N/3o`0000;oZ<7[00?o0000ojS1jonX`N/01onX`N/0
0ol0003oZL7[ojW1j`03ojW1j`?o00000_nY`N/00ol0003oZ/7[oj[1j`08oj[1j`03o`000?n[`^_o
000000;o00001_n/`NT00ol0003o[L;Yojg2j@05ojg2j@;o000000?o[L3Xo`000?n_`>L02_n_`>L0
0ol0003o/L7Uo`000002o`0000Go/;kT00?o0000ok>mh_nc_N802?nc_N82o`0000Wo/[SM00?o0000
okFefOne]MT01One]MT2o`000003ojnafOl0003o/JcC00So/JcC00?o0000ok:Vc?nbY/`01onbY/`4
o`0000OoYiW700?o0000ojJA_onVTKl01_nVTKl00ol0003oY8RgojB8]`07ojB8]`03o`000?oooooo
oooo01Cooooo0ol00007ooooo`03o`000?oooooooooo00gooooo000<ooooo`06olc<c?lb<S;ok^k^
onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@7ooooo`03
o`000?oooooooooo01_ooooo00?o0000ojO0jonW`>/00onW`>/3o`0000?oYl3[00?o0000ojO0jonW
`>/01onW`>/00ol0003oYl3[o`000002o`000004ojO0jol0003o0000o`0000?oYl3[00?o0000ojO0
jonW`>/01_nW`>/00ol0003oYl3[o`000002o`0000OoYl3[00?o0000ojO0jonW`>/01_nW`>/3o`00
00WoYl3[00?o0000ojO0jonW`>/01onW`>/2o`0000[oYl3[00?o0000ojO0jonW`>/00onW`>/3o`00
00;oYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0j`03ojO0j`?o00000_nX`>/00ol0
003oZ<7[ojS1j`08ojS1j`03o`000?nX`N_o000000;o00001_nX`N/00ol0003oZ<7[ojS1j`07ojS1
j`03o`000?nY`N_o000000;o00001_nY`N/00ol0003oZ/7[oj[1j`07oj[1j`;o00002_n/`NT00ol0
003o[L;Yojg2j@02ojg2j@;o00001?n]`>P00ol0003o[l3Wojo0i`08ojo0i`;o00002On`_^@00ol0
003o/kgRok>mhP04ok>mhP?o000000?o/;[Qo`000?nb^=d02Onb^=d01?l0003o]KGIokFefOne]MT3
o`0000Co[k7I00?o0000ok6/dona[=<01_na[=<00ol0003o/ZK<ok:Vc005ok:Vc0;o000000GoZ:7?
o`000?nWVLOoYiW7o`000006ojNIa`03o`000?nVTKooYY6o00OoYY6o00?o0000ojB8]onTR;L01_nT
R;L00ol0003oooooooooo`0Aooooo`Co000000?oooooo`000?ooool01?ooool00ol0003oA4A4o`00
000?ooooo`003?ooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED0
2Oooool00ol0003oooooooooo`04ooooo`;o00007_ooool00ol0003oYl3[o`000002o`0000OoYl3[
00?o0000ojO0jonW`>/01_nW`>/6o`0000OoYl3[00?o0000ojO0jonW`>/01?nW`>/4o`0000[oYl3[
00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[
ojO0j`03ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_o000000;o0000
1_nW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?nW`>_o000000;o00001_nX`>/00ol0003oZ<7[
ojS1j`07ojS1j`;o00002_nX`N/00ol0003oZ<7[ojS1j`05ojS1j`?o00002_nY`N/00ol0003oZ/7[
oj[1j`03oj[1j`?o000000?oZ/7Zo`000?n/`NT02_n/`NT01?l0003o[L;Yo`000?l00007ojg0j003
o`000?n_`>Oo[l3W00Go[l3W0_l000000on^_^Ko0000ok2ni009ok2ni003o`000?nc_N;o/kgR00?o
00001On`^^400ol0003o/[SMok:hg@07ok:hg@04o`000?ne]MWo0000o`0000Oo[k7I00?o0000ok6/
dona[=<01ona[=<01?l0003o/ZK<ok:Vc?nbY/`3o`0000CoZ:7?00Co0000ojNIaonWVLOo00001_nW
VLL00ol0003oYY6oojJA_`06ojJA_`03o`000?nTR;OoY8Rg00KoY8Rg00?o0000ooooooooool03_oo
ool3o`0000Gooooo00?o0000ooooooooool00oooool00oo<c<coEEEEo`00000?ooooo`003?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?ok^k^o`000?ooool01Oooool0
0ol0003oooooooooo`0Nooooo`;o00002_nW`>/00ol0003oYl3[ojO0j`02ojO0j`Oo00002_nW`>/0
0ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW`>/02?nW`>/01?l0003oYl3[o`000?l0
0007ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jol000000_l00006ojO0j`03o`000?nW
`>_oYl3[00OoYl3[0_l0000:ojO0j`03o`000?nW`>_oYl3[00GoYl3[0ol0000:ojS0j`03o`000?nX
`N_oZ<7[00?oZ<7[0ol000000onX`>_o0000ojS1j`0:ojS1j`03o`000?nX`N_oZ<7[00Co00000onY
`N/00ol0003oZL7[ojW1j`08ojW1j`03o`000?nZ`N_o000000;o00001OnZ`NX00ol0003o[<7Yojc1
j@08ojc1j@;o00002On]`>P00ol0003o[l3Wojo0i`02ojo0i`?o00001?n^_^H00ol0003o/;kTok2n
i007ok2ni0?o00002On`^^400ol0003o/[SMok:hg@06ok:hg@;o00002_n_/MT00ol0003o/JcCok6/
d`06ok6/d`04o`000?nbY/co0000o`0000OoZ:7?00Go0000ojNIaonWVLOoYiW7o`000005ojNIa`03
o`000?nVTKooYY6o00KoYY6o00?o0000ojB8]onTR;L01onTR;L00ol0003oooooooooo`09ooooo`Co
00002?ooool00ol0003oooooooooo`0Eooooo`003?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00[ooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH6ooooo`03o`000?oooooooooo
023ooooo00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[o`000004o`0000CoYl3[00?o0000ojO0
jonW`>/01onW`>/3o`0000SoYl3[00?o0000ojO0jonW`>/01onW`>/2o`0000[oYl3[00?o0000ojO0
jonW`>/01OnW`>/4o`0000WoYl3[00?o0000ojO0jonW`>/00onW`>/3o`0000;oYl3[00?o0000ojO0
jonW`>/02?nW`>/00ol0003oYl3[ojO0j`04o`0000;oZ<3[00?o0000ojS0jonX`>/02OnX`>/00ol0
003oZ<7[o`000002o`0000GoZ<3[00?o0000ojS1jonX`N/02?nX`N/3o`0000SoZL7[00?o0000ojW1
jonY`N/01_nY`N/3o`0000WoZ/7Z00?o0000ojc1jOn/`NT01?n/`NT3o`000003oj_0jOl0003o[L3X
00Wo[L3X00Co0000ojo0iol0003o00002?n^_^H00ol0003o/;kTok2ni004ok2ni0;o000000?o[[cS
o`000?n`^^402On`^^400ol0003o/[SMok:hg@03ok:hg@?o000000?o[[CMo`000?n_/MT02On_/MT0
0ol0003o/JcCok6/d`06ok6/d`;o00002OnXXLl01Ol0003oYiW7ojNIaonWVLOo000000GoYiW700?o
0000ojJA_onVTKl01onVTKl00ol0003oY8RgojB8]`06ojB8]`03o`000?oooooooooo00Kooooo0ol0
000<ooooo`03o`000?oooooooooo01Gooooo000<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02_ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000ooooooooool08Ooo
ool2o`0000OoYl3[1Ol00008ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00002ojO0j`03o`000?nW
`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/00onW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/02?nW
`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[o`00
0002o`0000KoYl3[00?o0000ojO0jonW`>/01onW`>/3o`0000OoZ<3[00?o0000ojS0jonX`>/02?nX
`>/2o`0000WoZ<3[00?o0000ojS1jonX`N/01?nX`N/3o`000003ojS1jol0003oZL7[00WoZL7[00?o
0000ojW1jonY`N/01Ol00003ojW1jP03o`000?nZ`N[oZ/7Z00OoZ/7Z00?o0000ojc1jOn/`NT00ol0
0005oj_0j@03o`000?n]`>So[L3X00Oo[L3X0_l0000:ojjniP03o`000?n`_^Co/;kT00;o/;kT0_l0
0004ojjlh`03o`000?n`^^7o/;[Q00So/;[Q00?o0000ok:hgOl000000_l00005ojjdg@03o`000?n_
/MWo[k7I00So[k7I00?o0000ok6/dona[=<00_na[=<3o`000003ojVXeOl0003oZ:7?00WoZ:7?00Go
0000ojNIaonWVLOoYiW7o`000005ojNIa`03o`000?nVTKooYY6o00KoYY6o00?o0000ojB8]onTR;L0
1_nTR;L00ol0003oooooooooo`03ooooo`?o00004?ooool00ol0003oooooooooo`0Dooooo`003?oo
ool01_m4A4CoZJVYooooooooooooZJVYodA4A0cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?nW`>_oYl3[00Ko000000?oYl3[o`000?nW`>/02OnW`>/00ol0003o
Yl3[o`000002o`0000KoYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[o`000002o`0000Ko
Yl3[00?o0000ojO0jonW`>/01onW`>/3o`0000WoYl3[00?o0000ojO0jonW`>/01OnW`>/3o`0000[o
Yl3[00?o0000ojO0jonW`>/00onW`>/3o`000003ojO0jol0003oZ<3[00SoZ<3[00?o0000ojS0jonX
`>/01?nX`>/3o`000003ojS0jol0003oZ<3[00WoZ<3[00?o0000ojS1jonX`N/00ol00005ojS1j`03
o`000?nY`N_oZL7[00OoZL7[0ol00009ojW1jP03o`000?nZ`N[oZ/7Z00GoZ/7Z1?l00009oj_0j@03
o`000?n]`>So[L3X00?o[L3X0ol000000on/_nOo0000ojjniP0:ojjniP04o`000?n`_^Co0000o`00
00Oo[[cS00?o0000ok2jhOn`^^401on`^^42o`0000Wo[[CM00?o0000ojnafOn_/MT01on_/MT00ol0
003o/JcCo`000002o`0000GoZJSE00?o0000ojRQconXXLl01onXXLl00ol0003oYiW7ojNIa`02ojNI
a`03o`000?nWVLOoYiW700;oYiW700?o0000ojJA_onVTKl01_nVTKl00ol0003oY8RgojB8]`06ojB8
]`03o`000?oooooo000000?o00004oooool00ol0003oooooooooo`0Dooooo`003?ooool01_o<c<co
<S8bonk^k_o^k^ko<S8bolc<c0cooooo00?o0000ooooooooool02?ooool2o`0002Kooooo1Ol00005
ojO0j`03o`000?nW`>_oYl3[00OoYl3[0_l0000:ojO0j`03o`000?nW`>_oYl3[00GoYl3[0ol0000:
ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000
ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000ojO0jol000000_l00005
ojO0j`03o`000?nX`>_oZ<3[00OoZ<3[00?o0000ojS0jonX`>/00ol00005ojS0j`03o`000?nX`>_o
Z<3[00OoZ<3[0ol00009ojS1j`03o`000?nY`N_oZL7[00?oZL7[0ol00002ojW0j`03o`000?nY`N[o
ZL7Z00SoZL7Z00?o0000oj[1j_nZ`NX01?l00002oj[0j@03o`000?n[`>WoZl3Y00WoZl3Y00?o0000
ojg0j?l000000_l00005ojboi`03o`000?n^_^Ko[[kV00So[[kV0_l00009ojjlh`03o`000?n`^^7o
/;[Q00Co/;[Q0ol000000on]]n7o0000ojjdg@08ojjdg@03o`000?n_/MWo[k7I00Ko[k7I0ol00008
ojVXe@03o`000?nXXLooZ:7?00SoZ:7?00Go0000ojNIaonWVLOoYiW7o`000004ojNIa`03o`000?nV
TKooYY6o00OoYY6o00?o0000ojB8]onTR;L01_nTR;L00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01Cooooo000=ooooo`04okZj^_l@413o410@olc<c0gooooo1Ol00006ooooo`03o`000?oo
oooooooo02Gooooo0ol00008ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00002ojO0j`03o`000?nW
`>_oYl3[00SoYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o
0000ojO0jol000000_l00006ojO0j`03o`000?nW`>_oYl3[00OoYl3[0ol00008ojO0j`03o`000?nW
`>_oYl3[00OoYl3[0_l00009ojO0j`03o`000?nX`>_oZ<3[00GoZ<3[1?l00009ojS0j`03o`000?nX
`>_oZ<3[00?oZ<3[0ol00002ojS0j`03o`000?nX`N_oZ<7[00SoZ<7[00?o0000ojW1jol000000_l0
0006ojW0j`03o`000?nY`N[oZL7Z00OoZL7Z0ol00007oj[0j@03o`000?n[`>WoZl3Y00SoZl3Y0_l0
0009ojboi`03o`000?n^_^Ko[[kV00Co[[kV0ol000000on]_NGo0000ojjlh`09ojjlh`03o`000?n`
^^7o/;[Q00?o00001On]]n400ol0003o[[CMojjdg@07ojjdg@03o`000?n_/MWo[k7I00Go00000_nY
[M/00ol0003oZJSEojVXe@07ojVXe@03o`000?nXXLooZ:7?00OoZ:7?00?o0000ojNIaonWVLL00_nW
VLL00ol0003oYiW7ojNIa`02ojNIa`03o`000?nVTKooYY6o00;oYY6o3_l0000Gooooo`03o`000?oo
oooooooo01Cooooo000Yooooo`03o`000?oooooooooo02;ooooo0ol00003ooooo`03o`000?nW`>_o
Yl3[00KoYl3[00?o0000ojO0jol000000_l00006ojO0j`03o`000?nW`>_oYl3[00OoYl3[0ol00008
ojO0j`03o`000?nW`>_oYl3[00OoYl3[0_l0000:ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00002
ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/00onW`>/3o`000003ojO0jol0003o
Yl3[00WoYl3[00?o0000ojS0jonX`>/01?l00004ojS0j`03o`000?nX`>_oZ<3[00OoZ<3[00?o0000
ojS0jol000000_l00006ojS0j`03o`000?nX`N_oZ<7[00OoZ<7[0_l0000:ojW0j`03o`000?nY`N[o
ZL7Z00?oZL7Z0ol000000onY`>[o0000oj[0j@08oj[0j@03o`000?n[`>WoZl3Y00CoZl3Y0ol00000
0on[_nSo0000ojboi`09ojboi`03o`000?n^_^Ko[[kV00?o00001On]_ND00ol0003o[[cSojjlh`07
ojjlh`?o00002On]]n400ol0003o[[CMojjdg@06ojjdg@?o00002?nY[M/00ol0003oZJSEojVXe@06
ojVXe@03o`000?nXXLooZ:7?00OoZ:7?00?o0000ojNIaonWVLL00onWVLL9o`0000CoUXW400?o0000
oi5o^onAOk/01_nAOk/00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo000Yoooo
o`03o`000?oooooooooo01oooooo0ol00007ooooo`03o`000?nW`>_oYl3[00CoYl3[1?l00009ojO0
j`03o`000?nW`>_oYl3[00?oYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0
jonW`>/00onW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[o`000002o`00
00KoYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[o`000002o`0000GoYl3[00?o0000ojO0
jonW`>/01onW`>/3o`0000WoZ<3[00?o0000ojS0jonX`>/01OnX`>/3o`0000[oZ<3[00?o0000ojS1
jonX`N/00onX`N/3o`0000;oZ<3[00?o0000ojW0jonY`>/02?nY`>/00ol0003oZL7Zo`000002o`00
00GoZL3Z00?o0000oj[0jOnZ`>T01onZ`>T00ol0003oZl3Yoj_0j@03o`0000GoZkoX00?o0000ojbo
ion/_nL01on/_nL3o`0000Wo[KgU00?o0000ojjlhon^_><00on^_><3o`000003ojbji?l0003o[KOQ
00Wo[KOQ00?o0000ojjdgOn^]=d00on^]=d3o`000003ojVbgol0003oZJgK00SoZJgK00?o0000ojVX
eOnYZ=D01onYZ=D00ol0003oZ:7?ojRQc`05ojRQc`Oo000000GoVY?<o`000?nJTlcoVY?<o`000009
oiJ9a003o`000?nAOk_oTGnk00GoTGnk00?o0000ooooooooool05Oooool00ol0003oooooooooo`0D
ooooo`00:Oooool2o`0001gooooo0ol0000;ooooo`03o`000?nW`>_oYl3[00?o00001?nW`>/00ol0
003oYl3[ojO0j`07ojO0j`03o`000?nW`>_o000000;o00001_nW`>/00ol0003oYl3[ojO0j`07ojO0
j`03o`000?nW`>_o000000;o00001_nW`>/00ol0003oYl3[ojO0j`07ojO0j`;o00002_nW`>/00ol0
003oYl3[ojO0j`05ojO0j`?o00002OnW`>/00ol0003oYl3[ojO0j`03ojO0j`?o00000_nX`>/00ol0
003oZ<3[ojS0j`08ojS0j`03o`000?nX`>_oZ<3[00Co00000onX`>/00ol0003oZ<3[ojS0j`08ojS0
j`03o`000?nX`N_o000000;o00001_nX`>/00ol0003oZL3[ojW0j`07ojW0j`;o00002OnY`>X00ol0
003oZ/3Yoj[0j@05oj[0j@Co00002On[_nP00ol0003o[;oWojboi`03ojboi`?o000000?oZkgWo`00
0?n]_ND02_n]_ND00ol0003o[[cSo`000002o`0000Go[;[T00?o0000ojfghOn]]n402?n]]n400ol0
003o[[CMo`000002o`0000GoZK;O00?o0000ojV]fonY[M/01onY[M/00ol0003oZJSEojVXe@06ojVX
e@03o`000?nXXLooZ:7?00Go00000_nMWM<00ol0003oVY?<oiZCc003oiZCc005o`000?nJTlcoVY?<
oiZCc?l000002?nFRL@00ol0003oTGnkoi5o^`06oi5o^`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool05?ooool002Sooooo0_l0000Kooooo`?o00003oooool2o`0000SoYl3[00?o0000ojO0
jonW`>/01_nW`>/3o`0000WoYl3[00?o0000ojO0jonW`>/01OnW`>/4o`0000WoYl3[00?o0000ojO0
jonW`>/00onW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[ojO0j`04o`00
00?oYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[o`000002o`0000KoZ<3[00?o0000ojS0
jonX`>/01onX`>/3o`0000SoZ<3[00?o0000ojS0jonX`>/01onX`>/2o`0000[oZ<3[00?o0000ojW0
jonY`>/00onY`>/3o`000003ojW0j_l0003oZL3Z00WoZL3Z00?o0000oj[0jOnZ`>T01?l00003ojZo
j@03o`000?n[_nSoZkoX00SoZkoX00?o0000ojboiol000000_l00005oj^mi`03o`000?n]_NGo[KgU
00So[KgU0_l00009ojbji003o`000?n]]n7o[KOQ00Oo[KOQ0_l00008ojVbg`03o`000?nY[M_oZJgK
00SoZJgK00?o0000ojVXeOnYZ=D01?nYZ=D4o`0000SoWIgC00?o0000oiZCc?nJTl`00onJTl`01?l0
003oVY?<oiZCc?l00008oiJ9a003o`000?nAOk_oTGnk00KoTGnk00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Dooooo`00:Oooool00ol0003oooooooooo`0Fooooo`?o00004oooool00ol0
003oYl3[ojO0j`07ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[
00OoYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0
jol000000_l00006ojO0j`03o`000?nW`>_oYl3[00OoYl3[0ol00008ojO0j`03o`000?nW`>_oYl3[
00GoYl3[0ol0000:ojS0j`03o`000?nX`>_oZ<3[00?oZ<3[0ol00002ojS0j`03o`000?nX`>_oZ<3[
00OoZ<3[00?o0000ojS0jonX`>/00onX`>/3o`000003ojS0jol0003oZ<3[00[oZ<3[00?o0000ojW0
jol000000_l00005ojW0jP03o`000?nY`>[oZL3Z00OoZL3Z0ol00008ojZoj@03o`000?n[_nSoZkoX
00OoZkoX0_l00009oj^mi`03o`000?n]_NGo[KgU00Co[KgU0ol000000on[^nKo0000ojbji008ojbj
i003o`000?n]]n7o[KOQ00Co[KOQ0ol000000onY]^;o0000ojVbg`08ojVbg`03o`000?nY[M_oZJgK
00OoZJgK00?o0000ojVXeOnYZ=D01?l00002oj2Uf@03o`000?nMWM?oWIgC00OoWIgC00?o0000oiZC
c?nJTl`01?nJTl`00ol0003oVY?<o`000009oiJ9a003o`000?nAOk_oTGnk00GoTGnk00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Cooooo`00:?ooool00ol0003oooooooooo`0Dooooo`?o
00005oooool00ol0003oYl3[ojO0j`07ojO0j`04o`000?nW`>_o0000o`0000OoYl3[00?o0000ojO0
jonW`>/01_nW`>/3o`0000WoYl3[00?o0000ojO0jonW`>/01OnW`>/4o`0000WoYl3[00?o0000ojO0
jonW`>/00onW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0j`04o`00
00?oYl3[00?o0000ojS0jonX`>/02?nX`>/00ol0003oZ<3[o`000002o`0000KoZ<3[00?o0000ojS0
jonX`>/01onX`>/00ol0003oZ<3[o`000002o`0000GoZ<3[00?o0000ojS0jonX`>/02?nX`>/2o`00
00WoZL3Z00?o0000ojW0j_nY`>X00onY`>X3o`000003ojVojOl0003oZ[oY00WoZ[oY00?o0000oj^o
j?n[_nP00on[_nP3o`000003ojZnj?l0003oZkgW00WoZkgW00?o0000ojfmiOn]_ND00ol00005oj^k
iP03o`000?n/^^Co[;[T00Oo[;[T00?o0000ojfghOn]]n400ol00005ojVfhP03o`000?nY/]ooZK;O
00OoZK;O00?o0000ojV]fonY[M/01OnY[M/4o`0000OoX:GI00?o0000oifMdonMWM<01_nMWM<00ol0
003oVY?<oiZCc004oiZCc004o`000?nJTlcoVY?<o`0000SoUXW400?o0000oi5o^onAOk/01_nAOk/0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo000Xooooo`03o`000?oooooooooo
01;ooooo0_l0000Kooooo`03o`000?nW`>_oYl3[00GoYl3[1?l00009ojO0j`03o`000?nW`>_oYl3[
00;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/01?l00004ojO0
j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jol000000_l00006ojO0j`03o`000?nW`>_oYl3[
00KoYl3[0ol00008ojO0j`03o`000?nX`>_oZ<3[00OoZ<3[0_l0000:ojS0j`03o`000?nX`>_oZ<3[
00GoZ<3[0ol00009ojS0j`03o`000?nX`>_oZ<3[00CoZ<3[0ol000000onX`>_o0000ojW0jP09ojW0
jP03o`000?nY`>[o000000;o00001OnY_nT00ol0003oZ[oYojZoj@08ojZoj@03o`000?n[_nSo0000
00;o00001OnZ_^P00ol0003oZkgWoj^mi`07oj^mi`?o00002On[^nH00ol0003o[;[Tojbji006ojbj
i0?o00002?nY]^800ol0003oZK;OojVbg`07ojVbg`03o`000?nY[M_oZJgK00Go00000_nRZmh00ol0
003oX:GIoj2Uf@06oj2Uf@03o`000?nMWM?oWIgC00OoWIgC00?o0000oiZCc?nJTl`01?nJTl`00ol0
003oVY?<o`000008oiJ9a003o`000?nAOk_oTGnk00KoTGnk00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Cooooo`00:?ooool2o`00013ooooo0ol0000Nooooo`03o`000?nW`>_oYl3[00Co
00001?nW`>/00ol0003oYl3[ojO0j`07ojO0j`04o`000?nW`>_o0000o`0000OoYl3[00?o0000ojO0
jonW`>/01_nW`>/3o`0000WoYl3[00?o0000ojO0jonW`>/01OnW`>/3o`0000[oYl3[00?o0000ojO0
jonW`>/00_nW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oZ<3[ojS0j`03ojS0
j`?o00000_nX`>/00ol0003oZ<3[ojS0j`08ojS0j`03o`000?nX`>_oZ<3[00Co00000onX`>/00ol0
003oZ<3[ojS0j`07ojS0j`03o`000?nX`>_oZ<3[00?o00001OnX`>/00ol0003oZL3ZojW0jP07ojW0
jP;o00002OnY_nT00ol0003oZ[oYojZoj@06ojZoj@?o00002OnZ_^P00ol0003oZkgWoj^mi`03oj^m
i`?o000000?oZ[cWo`000?n[^nH02On[^nH00ol0003o[;[Tojbji003ojbji0?o000000?oZ;STo`00
0?nY]^802OnY]^800ol0003oZK;OojVbg`05ojVbg`Co00002?nRZmh00ol0003oX:GIoj2Uf@06oj2U
f@03o`000?nMWM?oWIgC00KoWIgC00?o0000oiZCc?nJTl`01OnJTl`2o`0000WoUXW400?o0000oi5o
^onAOk/01OnAOk/00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo000Xooooo`03
o`000?oooooooooo00cooooo0ol0000Rooooo`;o00002OnW`>/00ol0003oYl3[ojO0j`05ojO0j`Co
00002OnW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`08ojO0j`03
o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`08ojO0j`04o`000?nW`>_o0000o`00
00KoYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oZ<3[o`000002o`0000KoZ<3[00?o0000ojS0
jonX`>/01onX`>/3o`0000SoZ<3[00?o0000ojS0jonX`>/01OnX`>/4o`0000WoZ<3[00?o0000ojW0
j_nY`>X00onY`>X3o`000003ojVoj_l0003oZKoY00WoZKoY00?o0000ojZojOnZ_nT01Ol00002ojVo
j@03o`000?nZ_^SoZ[kX00SoZ[kX00?o0000oj^miol000000_l00005ojZli`03o`000?n[^nKoZk_V
00SoZk_V00?o0000ojbji?l000000_l00005ojRhi003o`000?nY]^;oZKKR00OoZKKR00?o0000ojVb
gonY/]l01Ol00002ojB`h@03o`000?nRZmkoXZ_N00OoXZ_N00?o0000oj2UfOnPYMT01_nPYMT00ol0
003oWIgCoifMd`07oifMd`03o`000?nJTlcoVY?<00GoVY?<0_l00008oiJ9a003o`000?nAOk_oTGnk
00GoTGnk00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`00:?ooool00ol0003o
ooooooooo`09ooooo`?o00009_ooool00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_oYl3[00Co
00001?nW`>/00ol0003oYl3[ojO0j`07ojO0j`04o`000?nW`>_o0000o`0000KoYl3[00?o0000ojO0
jonW`>/01onW`>/3o`0000SoYl3[00?o0000ojO0jonW`>/01onW`>/2o`0000WoYl3[00?o0000ojO0
jonW`>/01OnW`>/4o`0000WoZ<3[00?o0000ojS0jonX`>/00onX`>/3o`000003ojS0jol0003oZ<3[
00WoZ<3[00?o0000ojS0jonX`>/01?l00004ojS0j`03o`000?nX`>_oZ<3[00OoZ<3[00?o0000ojW0
j_l000000_l00005ojVojP03o`000?nY_nWoZKoY00OoZKoY0ol00008ojVoj@03o`000?nZ_^SoZ[kX
00OoZ[kX0_l00009ojZli`03o`000?n[^nKoZk_V00KoZk_V0ol00009ojRhi003o`000?nY]^;oZKKR
00KoZKKR0ol00008ojB`h@03o`000?nRZmkoXZ_N00OoXZ_N00?o0000oj2UfOnPYMT01_nPYMT00ol0
003oWIgCoifMd`06oifMd`03o`000?nJTlcoVY?<00GoVY?<0_l00008oiJ9a003o`000?nAOk_oTGnk
00KoTGnk00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`00:?ooool00ol0003o
ooooooooo`06ooooo`?o0000:_ooool00ol0003oYl3[ojO0j`07ojO0j`?o00002OnW`>/00ol0003o
Yl3[ojO0j`05ojO0j`?o00002OnW`>/00ol0003oYl3[ojO0j`03ojO0j`?o00000_nW`>/00ol0003o
Yl3[ojO0j`07ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol000000onW`>_o0000ojO0j`09ojO0j`03
o`000?nW`>_oYl3[00Co00001?nX`>/00ol0003oZ<3[ojS0j`07ojS0j`03o`000?nX`>_o000000;o
00001OnX`>/00ol0003oZ<3[ojS0j`07ojS0j`?o00002OnX`>/00ol0003oZ<3[ojS0j`05ojS0j`?o
00002OnY_nX00ol0003oZKoYojVoj@03ojVoj@?o00000_nY_nT00ol0003oZKoYojVoj@07ojVoj@03
o`000?nZ_^SoZ[kX00?oZ[kX0ol000000onY_NSo0000ojZli`09ojZli`03o`000?n[^nKoZk_V00Go
00000_nX^^H00ol0003oZ;STojRhi007ojRhi003o`000?nY]^;oZKKR00?oZKKR0ol000000onU]>Co
0000ojB`h@08ojB`h@03o`000?nRZmkoXZ_N00OoXZ_N00?o0000oj2UfOnPYMT01_nPYMT00ol0003o
WIgCoifMd`06oifMd`03o`000?nJTlcoVY?<00KoVY?<00?o0000oiJ9a?nFRL@01onFRL@00ol0003o
TGnkoi5o^`05oi5o^`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool002Sooooo
0_l00004ooooo`?o0000;_ooool00ol0003oYl3[ojO0j`03ojO0j`?o00000_nW`>/00ol0003oYl3[
ojO0j`08ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`00
0?nW`>_o000000;o00001_nW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?nW`>_o000000;o0000
1OnW`>/00ol0003oYl3[ojO0j`07ojO0j`?o00002OnX`>/00ol0003oZ<3[ojS0j`05ojS0j`?o0000
2OnX`>/00ol0003oZ<3[ojS0j`03ojS0j`?o00000_nX`>/00ol0003oZ<3[ojS0j`08ojS0j`03o`00
0?nX`>_oZ<3[00Co00000_nX`>X00ol0003oZKoZojVojP08ojVojP03o`000?nY_nWo000000;o0000
1_nY_nT00ol0003oZKoYojVoj@07ojVoj@03o`000?nZ_^So000000;o00001OnY_NP00ol0003oZ[cW
ojZli`07ojZli`?o00002?nX^^H00ol0003oZ;STojRhi007ojRhi003o`000?nY]^;o000000;o0000
1OnU]>@00ol0003oY;3QojB`h@07ojB`h@03o`000?nRZmkoXZ_N00KoXZ_N00?o0000oj2UfOnPYMT0
0onPYMTCo`0000?oVY?<00?o0000oiJ9a?nFRL@01_nFRL@00ol0003oTGnkoi5o^`05oi5o^`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04oooool002Oooooo00Co0000oooooooooooooooo
0ol0000booooo`03o`000?nW`>_o000000;o00001_nW`>/00ol0003oYl3[ojO0j`07ojO0j`?o0000
2?nW`>/00ol0003oYl3[ojO0j`06ojO0j`;o00002_nW`>/00ol0003oYl3[ojO0j`05ojO0j`Co0000
2?nW`>/00ol0003oYl3[ojO0j`03ojO0j`?o00000_nW`>/00ol0003oZ<3[ojS0j`08ojS0j`03o`00
0?nX`>_oZ<3[00Co00000onX`>/00ol0003oZ<3[ojS0j`07ojS0j`03o`000?nX`>_o000000;o0000
1_nX`>/00ol0003oZ<3[ojS0j`07ojS0j`?o00001onX`>X00ol0003oZKoZojVojP07ojVojP;o0000
2_nY_nT00ol0003oZKoYojVoj@05ojVoj@?o00002OnY_NP00ol0003oZ[cWojZli`03ojZli`?o0000
00?oZ;cWo`000?nX^^H02OnX^^H00ol0003oZ;STojRhi005ojRhi0?o00002OnU]>@00ol0003oY;3Q
ojB`h@07ojB`h@03o`000?nRZmkoXZ_N00CoXZ_N1ol00004oiJSgP03o`000?n@V][oT9[J00KoT9[J
00?o0000ohV?don9Sm<00on9Sm<9o`0000?oUXW400?o0000oi5o^onAOk/01OnAOk/00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01;ooooo000Wooooo`Co0000=_ooool2o`0000WoYl3[00?o
0000ojO0jonW`>/00onW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0
j`02ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_oYl3[00Co00001?nW
`>/00ol0003oYl3[ojO0j`06ojO0j`03o`000?nW`>_o000000;o00001_nW`>/00ol0003oZ<3[ojS0
j`07ojS0j`?o00002?nX`>/00ol0003oZ<3[ojS0j`05ojS0j`?o00002_nX`>/00ol0003oZ<3[ojS0
j`03ojS0j`?o000000?oZ<3[o`000?nX`>X02?nX`>X00ol0003oZKoZojVojP03ojVojP?o00000_nX
_nX00ol0003oZKoYojVoj@08ojVoj@03o`000?nY_nWoZKoY00Co00000onY_^T00ol0003oZKgXojVm
j007ojVmj003o`000?nZ_>Oo000000;o00001OnX_>L00ol0003oZ;[VojRjiP08ojRjiP03o`000?nX
^>CoZ;ST00Co00000_nU^>H00ol0003oYKCTojFdi007ojFdi003o`000?nT/>7oY;3Q00OoY;3Q00?o
0000oj:[g_nRZmh01?l00002oiZ[hP03o`000?nFXmkoUZ?N00OoUZ?N00?o0000oi2Jf_n@V]X01_n@
V]X00ol0003oRHoCohV?d`05ohV?d`;o00001?n0P//6o`0000KoTGnk00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Booooo`006oooool4o`000003oa0@4?oooooooooo00Gooooo0_l0000j
ooooo`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jol000000_l00006ojO0j`03o`000?nW`>_o
Yl3[00OoYl3[00Co0000ojO0jol0003o00001_nW`>/00ol0003oYl3[ojO0j`07ojO0j`?o00002OnW
`>/00ol0003oYl3[ojO0j`04ojO0j`Co00002OnW`>/00ol0003oZ<3[ojS0j`03ojS0j`?o00000_nX
`>/00ol0003oZ<3[ojS0j`07ojS0j`03o`000?nX`>_oZ<3[00Co00000onX`>/00ol0003oZ<3[ojS0
j`08ojS0j`03o`000?nX`>_o000000;o00001OnX`>/00ol0003oZ<3ZojS0jP07ojS0jP03o`000?nY
_n[o000000;o00001_nX_nX00ol0003oZKoYojVoj@07ojVoj@?o00002?nY_^T00ol0003oZKgXojVm
j005ojVmj0?o00002OnX_>L00ol0003oZ;[VojRjiP06ojRjiPCo00001onU^>H00ol0003oYKCTojFd
i007ojFdi003o`000?nT/>7oY;3Q00?oY;3Q1_l00007oiZ[hP03o`000?nFXmkoUZ?N00KoUZ?N00?o
0000oi2Jf_n@V]X01_n@V]X00ol0003oRHoCohV?d`06ohV?d`;o00001on0P//01?l0003oMgC2o`00
0?l00004oi5o^`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool001gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0hooooo`;o00001_nW`>/4o`0000WoYl3[00?o
0000ojO0jonW`>/01OnW`>/4o`0000SoYl3[00?o0000ojO0jonW`>/00onW`>/3o`0000;oYl3[00?o
0000ojO0jonW`>/02?nW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW`>/01onW
`>/00ol0003oZ<3[o`000002o`0000KoZ<3[00?o0000ojS0jonX`>/01_nX`>/3o`0000SoZ<3[00?o
0000ojS0jonX`>/01onX`>/2o`0000WoZ<3[00?o0000ojS0j_nX`>X01OnX`>X4o`0000WoZ;oZ00?o
0000ojVojOnY_nT00onY_nT3o`000003ojRnjOl0003oZKkY00WoZKkY00?o0000ojVmj?nY_NP01?l0
0002ojRmj003o`000?nX_>OoZ;cW00SoZ;cW00?o0000ojRji_nX^^H01Ol00002ojJji`03o`000?nU
^>KoYKSV00OoYKSV00?o0000ojFdi?nU]>@01OnU]>@7o`0000CoW[3U00?o0000oiZ[h_nJZn801_nJ
Zn800ol0003oUZ?NoiJSgP07oiJSgP03o`000?n@V][oT9[J00KoT9[J00?o0000ohV?don9Sm<01On9
Sm<00ol0003oP8;;o`000006oh22b`04o`000?mgM<;oMgC2ogMd`P?o000000?oTGnko`000?ooool0
5?ooool00ol0003oooooooooo`0Booooo`007Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o
0000ojO0jonW`>/01?l00004ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojO0jol000000_l0
0006ojO0j`03o`000?nW`>_oYl3[00OoYl3[0ol00008ojO0j`03o`000?nW`>_oYl3[00GoYl3[0ol0
000:ojS0j`03o`000?nX`>_oZ<3[00;oZ<3[0ol00002ojS0j`03o`000?nX`>_oZ<3[00OoZ<3[00?o
0000ojS0jonX`>/00onX`>/3o`000003ojS0jol0003oZ<3[00WoZ<3[00?o0000ojS0j_nX`>X01?l0
0004ojRojP03o`000?nX_n[oZ;oZ00OoZ;oZ00?o0000ojVojOl000000_l00005ojRnj@03o`000?nY
_^WoZKkY00OoZKkY0ol00007ojRmj003o`000?nX_>OoZ;cW00OoZ;cW0ol00008ojJji`03o`000?nU
^>KoYKSV00OoYKSV00?o0000ojFdi?nU]>@01?l00002oj2di`03o`000?nN/>GoW[3U00OoW[3U00?o
0000oiZ[h_nJZn801_nJZn800ol0003oUZ?NoiJSgP06oiJSgP03o`000?n@V][oT9[J00KoT9[J00?o
0000ohV?don9Sm<01On9Sm<00ol0003oP8;;o`000007oh22b`03o`000?mgM<;oMgC200?oMgC20ol0
000Dooooo`03o`000?oooooooooo01;ooooo000Mooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0>Oooool2o`0000SoYl3[00?o0000ojO0jonW`>/01_nW`>/3o`0000WoYl3[00?o0000
ojO0jonW`>/01?nW`>/4o`0000WoYl3[00?o0000ojO0jonW`>/00onW`>/3o`0000;oYl3[00?o0000
ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojS0jonX`>/02?nX`>/0
1?l0003oZ<3[o`000?l00006ojS0j`03o`000?nX`>_oZ<3[00OoZ<3[00?o0000ojS0jol000000_l0
0005ojS0j`03o`000?nX`>_oZ<3[00OoZ<3[0ol00009ojRojP03o`000?nX_n[oZ;oZ00GoZ;oZ0ol0
0009ojRnj@03o`000?nY_^WoZKkY00?oZKkY0ol000000onX_^Wo0000ojRmj008ojRmj003o`000?nX
_>OoZ;cW00?oZ;cW0ol000000onV^nSo0000ojJji`09ojJji`03o`000?nU^>KoYKSV00GoYKSV1?l0
0007oj2di`03o`000?nN/>GoW[3U00OoW[3U00?o0000oiZ[h_nJZn801_nJZn800ol0003oUZ?NoiJS
gP06oiJSgP03o`000?n@V][oT9[J00GoT9[J00?o0000ohV?don9Sm<01_n9Sm<00ol0003oP8;;o`00
0006oh22b`03o`000?mgM<;oMgC200GoMgC200?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`007Oooool00ol0003oooooooooo`0<ooooo`;o0000>_ooool00ol0003oYl3[ojO0j`07
ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000
ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jol000000_l00006
ojO0j`03o`000?nW`>_oYl3[00KoYl3[0ol00008ojO0j`03o`000?nX`>_oZ<3[00OoZ<3[0_l00009
ojS0j`03o`000?nX`>_oZ<3[00GoZ<3[0ol00009ojS0j`03o`000?nX`>_oZ<3[00?oZ<3[0ol00002
ojRoj`03o`000?nX_n[oZ;oZ00SoZ;oZ00?o0000ojRoj_nX_nX01?l00003ojRojP03o`000?nX_^Wo
Z;kY00OoZ;kY00?o0000ojVnjOl000000_l00005ojRnj@03o`000?nX_NSoZ;gX00OoZ;gX00?o0000
ojRliol000000_l00005ojJkj003o`000?nV^^OoY[[W00SoY[[W00?o0000ojFhi_nU^>H01?l00002
oj:hj003o`000?nP]>OoX;CW00OoX;CW00?o0000oij`iOnN/>D01_nN/>D00ol0003oVZ_RoiZ[hP06
oiZ[hP03o`000?nFXmkoUZ?N00KoUZ?N00?o0000oi2Jf_n@V]X01_n@V]X00ol0003oRHoCohV?d`05
ohV?d`04o`000?n0P/_oP8;;o`0000GoP8;;00?o0000ogMd`_mgM<801OmgM<800ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo000Mooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0>?ooool00ol0003oYl3[ojO0j`07ojO0j`04o`000?nW`>_o0000o`0000KoYl3[00?o
0000ojO0jonW`>/01onW`>/3o`0000SoYl3[00?o0000ojO0jonW`>/01OnW`>/4o`0000WoYl3[00?o
0000ojO0jonW`>/00_nW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oZ<3[ojS0
j`03ojS0j`?o000000?oZ<3[o`000?nX`>/02OnX`>/00ol0003oZ<3[ojS0j`04o`0000?oZ<3[00?o
0000ojS0jonX`>/01onX`>/00ol0003oZ<3[o`000002o`0000KoZ;o[00?o0000ojRoj_nX_nX01onX
_nX3o`0000SoZ;oZ00?o0000ojRnjOnX_^T01OnX_^T3o`0000WoZ;kY00?o0000ojRmj?nX_NP01OnX
_NP3o`0000WoY[_X00?o0000ojJjionV^^L01onV^^L3o`0000OoX[SX00?o0000oj2dionP]>L01_nP
]>L00ol0003oW[3Uoij`i@07oij`i@03o`000?nJZn;oVZ_R00;oVZ_R4ol00002oi2JfP03o`000?n9
Sm?oRHoC00KoRHoC00Co0000oh22bon0P/_o00001On0P//00ol0003oMgC2ogMd`P04ogMd`P03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04Oooool001gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0hooooo`03o`000?nW`>_oYl3[00GoYl3[1?l00008ojO0j`03o`000?nW
`>_oYl3[00?oYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/01?l0
0004ojO0j`03o`000?nW`>_oYl3[00OoYl3[00Co0000ojO0jol0003o00001_nW`>/00ol0003oYl3[
ojO0j`07ojO0j`03o`000?nX`>_o000000;o00001OnX`>/00ol0003oZ<3[ojS0j`07ojS0j`?o0000
2?nX`>/00ol0003oZ<3[ojS0j`05ojS0j`Co00002OnX_n/00ol0003oZ;oZojRojP03ojRojP?o0000
00?oZ;oZo`000?nX_nX02OnX_nX00ol0003oZ;kYojRnj@04o`0000;oZ;kZ00?o0000ojRnjOnX_^T0
2?nX_^T00ol0003oZ;gXojRmj004o`0000;oYkgY00?o0000ojJkj?nV^nP01onV^nP00ol0003oY[[W
ojJji`04ojJji`?o000000?oY;[Yo`000?nR^>P02?nR^>P00ol0003oX;CWoj2di`06oj2di`03o`00
0?nN/>GoW[3U00?oW[3U2?l00004oi:/j003o`000?n:Y>GoRZCU00KoRZCU00?o0000ognIh_moVN80
0omoVN86o`0000GoRHoC00Co0000oh22bon0P/_o00001On0P//00ol0003oMgC2ogMd`P05ogMd`P03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool001_ooooo00?o0000odA4A?l00000
4_ooool00ol0003oooooooooo`0hooooo`03o`000?nW`>_oYl3[00Co00001?nW`>/00ol0003oYl3[
ojO0j`06ojO0j`03o`000?nW`>_o000000;o00001_nW`>/00ol0003oYl3[ojO0j`06ojO0j`?o0000
2OnW`>/00ol0003oYl3[ojO0j`05ojO0j`?o00002OnW`>/00ol0003oYl3[ojO0j`05ojO0j`?o0000
2OnX`>/00ol0003oZ<3[ojS0j`03ojS0j`?o000000?oZ<3[o`000?nX`>/02OnX`>/00ol0003oZ<3[
ojS0j`04o`0000CoZ;o[00?o0000ojRojonX_n/01onX_n/00ol0003oZ;oZo`000002o`0000GoZ;oZ
00?o0000ojRoj_nX_nX01onX_nX3o`0000OoZ;kZ00?o0000ojRnjOnX_^T01onX_^T3o`0000OoYkgY
00?o0000ojJkj?nV^nP01onV^nP00ol0003oY[[WojJji`03o`0000GoY;[Y00?o0000oj:hj?nR^>P0
1_nR^>P00ol0003oX;CWoj2di`05oj2di`Oo00001?nH/NT00ol0003oTZcXoi:/j006oi:/j003o`00
0?n:Y>GoRZCU00KoRZCU00?o0000ognIh_moVN801OmoVN800ol0003oLX_Log:;g006o`0000?oP8;;
00?o0000oh22bon0P//00_n0P//00ol0003oMgC2ogMd`P05ogMd`P03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04Oooool001_ooooo00?oc<c<oeEEEOl000004oooool00ol0003ooooooooo
o`0hooooo`;o00002OnW`>/00ol0003oYl3[ojO0j`04ojO0j`Co00002OnW`>/00ol0003oYl3[ojO0
j`02ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_oYl3[00Co00000onW
`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oZ<3[ojS0
j`07ojS0j`03o`000?nX`>_o000000;o00001OnX`>/00ol0003oZ<3[ojS0j`07ojS0j`?o00002OnX
_n/00ol0003oZ;o[ojRoj`05ojRoj`?o00002OnX_nX00ol0003oZ;oZojRojP03ojRojP?o000000?o
Z;oZo`000?nX_^X02?nX_^X00ol0003oZ;kYojRnj@03ojRnj@?o000000?oYkgZo`000?nW_NT02?nW
_NT00ol0003oY[_XojJkj005ojJkj0Co00002?nT^^T00ol0003oX[SXoj:hj007oj:hj003o`000?nP
]>OoX;CW00Co00000_nL]^X00ol0003oV;7YoiRaj@07oiRaj@03o`000?nB[>SoTZcX00KoTZcX00?o
0000ohZTiOn:Y>D01On:Y>D00ol0003oOiWRognIhP06ognIhP03o`000?mbRmcoLX_L00CoLX_L0ol0
0002oh22b`03o`000?n0P/_oP8;;00;oP8;;00?o0000ogMd`_mgM<801?mgM<800ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo017ooooo000booooo`;o0000>Oooool00ol0003oYl3[ojO0j`08
ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/00ol0003oYl3[ojO0j`07ojO0j`04o`000?nW`>_o
0000o`0000KoYl3[00?o0000ojO0jonW`>/01onW`>/3o`0000SoYl3[00?o0000ojO0jonW`>/01OnW
`>/4o`0000SoYl3[00?o0000ojS0jonX`>/01OnX`>/4o`0000SoZ<3[00?o0000ojS0jonX`>/00onX
`>/3o`0000;oZ<3[00?o0000ojRojonX_n/02?nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o
0000ojRoj_nX_nX01onX_nX00ol0003oZ;oZo`000002o`0000GoZ;oZ00?o0000ojRnj_nX_^X01onX
_^X00ol0003oZ;kYo`000002o`0000GoYkgZ00?o0000ojNmjOnW_NT01onW_NT00ol0003oY[_XojJk
j004o`0000;oYK_Y00?o0000ojBjjOnT^^T02?nT^^T00ol0003oX[SXoj:hj005oj:hj0Co00001onL
]^X00ol0003oV;7YoiRaj@07oiRaj@03o`000?nB[>SoTZcX00GoTZcX00?o0000ohZTiOn:Y>D01_n:
Y>D00ol0003oOiWRognIhP05ognIhP03o`000?mbRmcoLX_L00GoLX_L00?o0000of5ie?l000000ol0
0003oh22b`03o`000?mgM<;oMgC200GoMgC200?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Aooooo`00=?ooool00ol0003oooooooooo`0gooooo`03o`000?nW`>_oYl3[00OoYl3[0ol00008
ojO0j`03o`000?nW`>_oYl3[00GoYl3[1?l00008ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00002
ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_o
Yl3[00OoYl3[00?o0000ojS0jonX`>/01?l00004ojS0j`03o`000?nX`>_oZ<3[00KoZ<3[00?o0000
ojS0jol000000_l00006ojS0j`03o`000?nX_n_oZ;o[00OoZ;o[0ol00008ojRoj`03o`000?nX_n[o
Z;oZ00GoZ;oZ0ol00009ojRojP03o`000?nX_^[oZ;kZ00GoZ;kZ0ol00009ojNmjP03o`000?nW_NWo
YkgY00GoYkgY1?l00007ojFkj@03o`000?nT^^WoY;[Y00OoY;[Y00?o0000oj:hj?nR^>P01Ol00002
oinhjP03o`000?nL]^[oW;KZ00OoW;KZ00?o0000oiRajOnH/NT01_nH/NT00ol0003oTZcXoi:/j006
oi:/j003o`000?n:Y>GoRZCU00KoRZCU00?o0000ognIh_moVN801OmoVN800ol0003oLX_Log:;g005
og:;g004o`000?mQNMCoHGWDof5ie0;o00000_n0P//00ol0003oMgC2ogMd`P05ogMd`P03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04Oooool003Gooooo00?o0000ooooooooool0=oooool0
0ol0003oYl3[ojO0j`03ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?nW`>_o
Yl3[00Co00001?nW`>/00ol0003oYl3[ojO0j`06ojO0j`03o`000?nW`>_o000000;o00001_nW`>/0
0ol0003oYl3[ojO0j`06ojO0j`?o00002?nW`>/00ol0003oYl3[ojO0j`06ojO0j`?o00002OnX`>/0
0ol0003oZ<3[ojS0j`04ojS0j`Co00002OnX`>/00ol0003oZ;o[ojRoj`03ojRoj`?o000000?oZ;o[
o`000?nX_n/02OnX_n/00ol0003oZ;oZojRojP04o`0000;oYkoZ00?o0000ojRoj_nX_nX02?nX_nX0
0ol0003oZ;kZojRnjP04o`0000?oYkkZ00?o0000ojNmj_nW_NX01onW_NX00ol0003oYkgYojNmj@04
o`0000;oYKgZ00?o0000ojFkjOnU^nT01onU^nT00ol0003oY;[YojBjj@05ojBjj@Co00002?nO^>X0
0ol0003oW;KZoibfjP07oibfjP03o`000?nH/NWoV;7Y00;oV;7Y4ol00002ohZTi@03o`000?moVN;o
OiWR00KoOiWR00?o0000og:;g?mbRm`01?mbRm`00ol0003oHGWDof5ie002of5ie0Go00001_mgM<80
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo000fooooo`03o`000?oooooooooo
03Oooooo00?o0000ojO0jol000000_l00006ojO0j`03o`000?nW`>_oYl3[00KoYl3[0ol00009ojO0
j`03o`000?nW`>_oYl3[00CoYl3[1?l00009ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00002ojO0
j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000;oYl3[00?o0000ojS0
jonX`>/02?nX`>/00ol0003oZ<3[ojS0j`03o`0000CoZ<3[00?o0000ojS0jonX`>/01onX`>/00ol0
003oZ;o[o`000002o`0000GoZ;o[00?o0000ojRojonX_n/01onX_n/3o`0000OoYkoZ00?o0000ojRo
j_nX_nX01onX_nX3o`0000SoYkkZ00?o0000ojNmj_nW_NX01OnW_NX4o`0000OoYKgZ00?o0000ojFk
jOnU^nT01onU^nT00ol0003oY;[YojBjj@04o`0000?oX[_[00?o0000oinhj_nO^>X01onO^>X00ol0
003oW;KZoibfjP05oibfjPKo00001?nB]>h00ol0003oRZk^ohZ^kP06ohZ^kP03o`000?mmY^goOJK]
00?oOJK]2Ol00002ognIhP03o`000?mbRmcoLX_L00GoLX_L00?o0000of5ie?mQNM@00_mQNM@00ol0
003oHGWDof5ie002o`0000KoMgC200?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`00=oooool2o`0003Sooooo0_l00009ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00002ojO0j`03
o`000?nW`>_oYl3[00SoYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00Oo
Yl3[00Co0000ojO0jol0003o00001_nW`>/00ol0003oYl3[ojO0j`07ojO0j`04o`000?nW`>_o0000
o`0000KoYl3[00?o0000ojS0jonX`>/01onX`>/3o`0000SoZ<3[00?o0000ojS0jonX`>/01OnX`>/3
o`0000WoZ;o[00?o0000ojRojonX_n/00onX_n/3o`000003ojNojol0003oYkoZ00SoYkoZ00?o0000
ojRoj_nX_nX00onX_nX3o`000003ojNoj_l0003oYkkZ00WoYkkZ00?o0000ojNmj_nW_NX01?l00002
ojJmjP03o`000?nU_N[oYKgZ00OoYKgZ00?o0000ojFkjOnU^nT01OnU^nT4o`0000SoX[_[00?o0000
oinhj_nO^>X01_nO^>X00ol0003oW;KZoibfjP05o`0000;oVKS]00?o0000oi:dk_nB]>h01_nB]>h0
0ol0003oRZk^ohZ^kP06ohZ^kP03o`000?mmY^goOJK]00GoOJK]00?o0000of^Jjom[V^/00om[V^/6
o`0000CoLX_L00?o0000of5ie?mQNM@00_mQNM@01_l0003oHGWDof5ie?l0003oCFG:o`0000GoMgC2
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`00>Oooool00ol0003ooooooooo
o`0gooooo`03o`000?nW`>_oYl3[00OoYl3[00Co0000ojO0jol0003o00001_nW`>/00ol0003oYl3[
ojO0j`07ojO0j`?o00002?nW`>/00ol0003oYl3[ojO0j`05ojO0j`?o00002OnW`>/00ol0003oYl3[
ojO0j`05ojO0j`?o00002OnW`>/00ol0003oZ<3[ojS0j`03ojS0j`?o000000?oYl3[o`000?nX`>/0
2OnX`>/00ol0003oZ<3[ojS0j`04o`0000?oZ;o[00?o0000ojRojonX_n/01onX_n/00ol0003oZ;o[
o`000002o`0000GoYko[00?o0000ojNoj_nW_nX01onW_nX00ol0003oZ;oZo`000002o`0000GoYkoZ
00?o0000ojNnj_nW_^X01onW_^X3o`0000OoY[gZ00?o0000ojFmj_nU_NX01onU_NX00ol0003oYK_Y
ojFkj@04o`0000?oXkc[00?o0000oj:kjonR^n/01onR^n/00ol0003oWkSZoinhjP02oinhjPKo0000
2?nI^>d00ol0003oT[C^oi:dkP06oi:dkP03o`000?n:[^koRZk^00KoRZk^00?o0000ogfVkOmmY^d0
1OmmY^d00ol0003oJi[[of^Jj`05of^Jj`03o`000?mBQnKoDXOV00?o00000_mbRm`00ol0003oHGWD
of5ie002of5ie005o`000?mQNMCoHGWDo`000?m=ILX00_l00003ogMd`P03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool003[ooooo00?o0000ooooooooool0=oooool00ol0003oYl3[
ojO0j`05ojO0j`Co00002?nW`>/00ol0003oYl3[ojO0j`03ojO0j`?o00000_nW`>/00ol0003oYl3[
ojO0j`07ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`00
0?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?nX`>_o000000;o0000
1OnW`>/00ol0003oZ<3[ojS0j`07ojS0j`?o00002?nX_n/00ol0003oZ;o[ojRoj`05ojRoj`?o0000
2OnW_n/00ol0003oYkoZojNojP05ojNojP?o00002OnW_nX00ol0003oYkkZojNnjP03ojNnjP?o0000
00?oY[k[o`000?nV_NX02?nV_NX00ol0003oYKgZojFmjP05ojFmjPCo00002?nS_>/00ol0003oX[_[
oj:kj`05oj:kj`Ko00001OnM^^d00ol0003oVKS]oiVhk@07oiVhk@03o`000?nB]>koT[C^00KoT[C^
00?o0000ohZ^k_n:[^h01_n:[^h00ol0003oOJK]ogfVk@05ogfVk@03o`000?m[V^_oJi[[00GoJi[[
00?o0000oe:7i_mBQnH00_mBQnH3o`0000GoHGWD00?o0000of5ie?l000000om=ILX01Ol0003oMgC2
ogMd`_mgM<;o000001;ooooo00?o0000ooooooooool04?ooool003_ooooo00?o0000ooooooooool0
=oooool00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[
o`000002o`0000KoYl3[00?o0000ojO0jonW`>/01_nW`>/3o`0000SoYl3[00?o0000ojO0jonW`>/0
1OnW`>/4o`0000SoYl3[00?o0000ojO0jonW`>/01OnW`>/3o`0000WoYl3[00?o0000ojS0jonX`>/0
0onX`>/3o`000003ojO0jol0003oZ;o[00WoZ;o[00?o0000ojRojonX_n/01?l00003ojNoj`03o`00
0?nW_n_oYko[00OoYko[00?o0000ojNoj_nW_nX01?l00003ojNoj`03o`000?nW_n[oYkoZ00OoYkoZ
00?o0000ojNnj_l000000_l00005ojJnj`03o`000?nV_N[oY[gZ00OoY[gZ00?o0000ojFmj_nU_NX0
1?l00003ojBmj`03o`000?nS_>_oXkc[00OoXkc[00?o0000oj:kjonR^n/01?l00002oj2lk@03o`00
0?nM^^goWK[]00OoWK[]00?o0000oiVhkOnI^>d01_nI^>d00ol0003oT[C^oi:dkP03oi:dkQ;o0000
0_mmY^d00ol0003oJi[[of^Jj`05of^Jj`03o`000?mBQnKoDXOV00GoDXOV0_l00004of5ie0;o0000
1?m=ILX01?l0003oMgC2ogMd`_l0000Booooo`03o`000?oooooooooo013ooooo000looooo`03o`00
0?oooooooooo03Oooooo0_l00009ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00009ojO0j`03o`00
0?nW`>_oYl3[00;oYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/0
1?l00004ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`00
0?nW`>_oYl3[00OoYl3[00?o0000ojS0jol000000_l00005ojO0j`03o`000?nX_n_oZ;o[00OoZ;o[
0ol00008ojNoj`03o`000?nW_n_oYko[00GoYko[1?l00008ojNoj`03o`000?nW_n[oYkoZ00GoYkoZ
0ol00009ojJnj`03o`000?nV_N[oY[gZ00GoY[gZ1?l00008ojBmj`03o`000?nS_>_oXkc[00GoXkc[
1?l00007oj2lk@03o`000?nM^^goWK[]00OoWK[]00?o0000oiVhkOnI^>d00_nI^>d9o`0000CoS[Sb
00?o0000oh>cm?n3/o@01_n3/o@00ol0003oL:_eog2[m@02og2[m@Ko00001Om[V^/00ol0003oDXOV
oe:7iP04oe:7iP04o`000?l^K=_o0000o`0000;oHGWD00?o0000of5ie?l000001?m=ILX3o`0001;o
oooo00?o0000ooooooooool04?ooool003gooooo0_l0000iooooo`03o`000?nW`>_oYl3[00OoYl3[
00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00OoYl3[00Co0000ojO0jol0003o
00001_nW`>/00ol0003oYl3[ojO0j`06ojO0j`?o00002OnW`>/00ol0003oYl3[ojO0j`04ojO0j`Co
00002?nW`>/00ol0003oYl3[ojO0j`05ojO0j`Co00002?nW`>/00ol0003oZ;o[ojRoj`03ojRoj`?o
000000?oYko[o`000?nW_n/02OnW_n/00ol0003oYko[ojNoj`04o`0000?oYko[00?o0000ojNojonW
_n/01onW_n/00ol0003oYkoZojNojP04o`0000?oYko[00?o0000ojJnjonV_^/01onV_^/00ol0003o
Y[gZojJmjP04o`0000?oYKk[00?o0000ojBmjonT_N/01onT_N/00ol0003oXkc[oj>lj`04o`0000;o
X[g/00?o0000oj2lkOnP_>d01onP_>d00ol0003oWK[]oifjk@05oifjk@Ko00001OnF^o400ol0003o
S[SbohjhlP06ohjhlP03o`000?n3/oCoPk?d00KoPk?d00?o0000og2[mOm`ZoD01Om`ZoD00ol0003o
Di_co`000005o`0000OoDXOV00Co0000obi/fol^K=_o00000_mQNM@2o`0000KoCFG:0_l0000@oooo
o`;o00004_ooool003oooooo00?o0000ooooooooool0=oooool00ol0003oYl3[ojO0j`05ojO0j`Co
00002?nW`>/00ol0003oYl3[ojO0j`05ojO0j`?o00002OnW`>/00ol0003oYl3[ojO0j`02ojO0j`?o
00000_nW`>/00ol0003oYl3[ojO0j`08ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/00ol0003o
Yl3[ojO0j`06ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/00ol0003oYl3[ojO0j`06ojO0j`03
o`000?nX_n_o000000;o00001OnW_n/00ol0003oYko[ojNoj`07ojNoj`?o00002?nW_n/00ol0003o
Yko[ojNoj`05ojNoj`Co00002?nW_n/00ol0003oY[k[ojJnj`05ojJnj`Co00002?nU_^/00ol0003o
Y;g[ojBmj`05ojBmj`Co00001onR_N`00ol0003oX;c]oj2lk@07oj2lk@03o`000?nM^^goWK[]00Co
00000_nK_>l00ol0003oU[_aoiJkl@07oiJkl@03o`000?n>^?;oS[Sb00KoS[Sb00?o0000oh>cm?n3
/o@01_n3/o@00ol0003oL:_eog2[m@05og2[m@03o`000?mCVo?oDi_c00?oDi_c0ol00005oe:7iP04
o`000?l^K=_o;VcKobi/f`;o000000?oHGWDo`000?l000001_m=ILX00ol0003oooooooooo`0;oooo
o`?o000000?oQ18So`000?ooool04Oooool0043ooooo00?o0000ooooooooool0=oooool00ol0003o
Yl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`04o`0000?o
Yl3[00?o0000ojO0jonW`>/01onW`>/01?l0003oYl3[o`000?l00006ojO0j`03o`000?nW`>_oYl3[
00OoYl3[0ol00008ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00009ojO0j`03o`000?nW`>_oYl3[
00CoYl3[1?l00008ojNoj`03o`000?nW_n_oYko[00?oYko[0ol000000onW_n_o0000ojNoj`09ojNo
j`03o`000?nW_n_oYko[00Co00000_nW_n/00ol0003oYko[ojNoj`08ojNoj`03o`000?nV_^_oY[k[
00Co00000onV_^/00ol0003oYKk[ojFnj`07ojFnj`03o`000?nT_N_oY;g[00Co00000_nS_^`00ol0
003oX[g/oj:mk007oj:mk003o`000?nP_>goX;c]00GoX;c]1?l00007oi^lk`03o`000?nF^o7oU[_a
00OoU[_a00?o0000ohjhl_n>^?801On>^?800ol0003oPk?doh>cm003oh>cm0[o00000_m`ZoD00ol0
003oDi_coe>Kl`04oe>Kl`Co00000omBQnH00ol0003o;VcKobi/f`02obi/f`?o00001_m=ILX00ol0
003oooooooooo`08ooooo`?o00001?n44R<00ol0003oooooooooo`0@ooooo`00@Oooool00ol0003o
ooooooooo`0gooooo`;o00002OnW`>/00ol0003oYl3[ojO0j`04ojO0j`Co00002?nW`>/00ol0003o
Yl3[ojO0j`05ojO0j`Co00002?nW`>/00ol0003oYl3[ojO0j`03ojO0j`?o000000?oYl3[o`000?nW
`>/02OnW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003o
Yl3[ojO0j`03o`0000CoYko[00?o0000ojNojonW_n/01_nW_n/00ol0003oYko[o`000002o`0000Go
Yko[00?o0000ojNojonW_n/01onW_n/3o`0000OoYko[00?o0000ojNojonW_n/01onW_n/3o`0000So
Y[k[00?o0000ojFnjonU_^/01OnU_^/4o`0000OoXkk/00?o0000oj:mk?nR_N`01onR_N`00ol0003o
X;c]oj2lk@04o`0000?oWkg^00?o0000oi^lkonK_>l01_nK_>l00ol0003oU[_aoiJkl@05oiJkl@oo
00001?mn^OT00ol0003oIK7jofFanP03ofFanPKo00001?mCVo<00ol0003o983XobB0j002o`0000;o
DXOV00?o0000obi/fol^K=/00ol^K=/00ol0003oCFG:odeUbP05odeUbP03o`000?oooooooooo00Co
oooo0ol00007oh@B8`;o00004Oooool004;ooooo0_l0000hooooo`03o`000?nW`>_oYl3[00SoYl3[
00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojO0jonW`>/0
1?l00004ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojO0jol000000_l00005ojO0j`03o`00
0?nW`>_oYl3[00OoYl3[0ol00008ojO0j`03o`000?nW`>_oYl3[00GoYl3[1?l00008ojNoj`03o`00
0?nW_n_oYko[00CoYko[1?l00008ojNoj`03o`000?nW_n_oYko[00?oYko[0ol000000onW_n_o0000
ojNoj`08ojNoj`03o`000?nW_n_oYko[00?oYko[0ol000000onV_n_o0000ojJnj`09ojJnj`03o`00
0?nU_^_oYKk[00Co00000_nU_^`00ol0003oXkk/oj>nk007oj>nk003o`000?nR_NcoX[g/00GoX[g/
1?l00008oinmkP03o`000?nK_>ooVkc_00KoVkc_00?o0000oiJklOnF^o401?l00002oiFnm003o`00
0?n<_OKoS;gf00OoS;gf00?o0000ogjinOmn^OT01Omn^OT00ol0003oIK7jofFanP06ofFanP03o`00
0?ljW_Co000000Go00000olTP>P3o`0000Ko;VcK0_l00005odeUbP03o`000?oooooo000000Co0000
0_mK00000ol0003oQ18Soh@B8`05oh@B8`;o00004Oooool004Cooooo00?o0000ooooooooool0=_oo
ool00ol0003oYl3[ojO0j`07ojO0j`?o00002?nW`>/00ol0003oYl3[ojO0j`04ojO0j`Co00002OnW
`>/00ol0003oYl3[ojO0j`04ojO0j`Co00002?nW`>/00ol0003oYl3[ojO0j`03ojO0j`?o000000?o
Yl3[o`000?nW`>/02OnW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojNojonW_n/01onW
_n/00ol0003oYko[ojNoj`03o`0000CoYko[00?o0000ojNojonW_n/01_nW_n/00ol0003oYko[o`00
0002o`0000GoYko[00?o0000ojNojonW_n/01onW_n/00ol0003oYko[o`000002o`0000GoY[o[00?o
0000ojJnjonV_^/01onV_^/3o`0000OoYKk/00?o0000oj>nk?nS_^`01onS_^`00ol0003oX[g/oj:m
k004o`0000;oXKk]00?o0000oinmk_nO_Nh02?nO_Nh00ol0003oVkc_oi^lk`02oi^lk`Ko00001onE
__@00ol0003oS;gfohbmmP07ohbmmP03o`000?mn^OWoO[Wi00GoO[Wi00?o0000ofFan_mU/OX01_mU
/OX00ol0003o>YkdocZNm003ocZNm0Co00000olTP>P2o`0000Co;VcK0ol00004odeUbP;o00001_mK
00000ol0003oQ18Soh@B8`05oh@B8`03o`000?oooooo0000017ooooo0015ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ojO0jonW`>/00onW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/01onW`>/0
0ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0j`03
o`0000CoYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[o`000002o`0000GoYl3[00?o0000
ojO0jonW`>/01onW`>/3o`0000SoYl3[00?o0000ojNojonW_n/01OnW_n/4o`0000SoYko[00?o0000
ojNojonW_n/01?nW_n/3o`0000WoYko[00?o0000ojNojonW_n/01OnW_n/3o`0000WoY[o[00?o0000
ojJnjonV_^/00onV_^/3o`000003ojFok?l0003oYKk/00SoYKk/00?o0000oj>nk?nS_^`01OnS_^`4
o`0000OoXKk]00?o0000oinmk_nO_Nh01_nO_Nh6o`0000CoVkoa00?o0000oiFnm?nE__@01onE__@0
0ol0003oS;gfohbmmP03ohbmmQ_o00000_ljW_@4o`000004obB0j?l0003o0000o`0000?o;VcK00?o
0000o`97aol000001?m=ILX00ol0003oF`00oe/00004oe/00003o`000?n44R?oQ18S00GoQ18S00?o
0000ooooool000004Oooool004Kooooo00?o0000ooooooooool0=_ooool00ol0003oYl3[o`000002
o`0000KoYl3[00?o0000ojO0jonW`>/01_nW`>/3o`0000SoYl3[00?o0000ojO0jonW`>/01OnW`>/4
o`0000SoYl3[00?o0000ojO0jonW`>/01?nW`>/4o`0000SoYl3[00?o0000ojO0jonW`>/00onW`>/3
o`000003ojO0jol0003oYl3[00WoYl3[00?o0000ojNojonW_n/01?l00003ojNoj`03o`000?nW_n_o
Yko[00OoYko[00?o0000ojNojonW_n/00ol00003ojNoj`03o`000?nW_n_oYko[00OoYko[00?o0000
ojNojonW_n/01?l00003ojJoj`03o`000?nV_n_oY[o[00OoY[o[00?o0000ojJnjol000000_l00005
ojFok003o`000?nU_^coYKk/00OoYKk/00?o0000oj>nk?nS_^`01?l00002oj>ok@03o`000?nQ_^go
XKk]00OoXKk]00?o0000oinmk_nO_Nh01Ol00002oijol003o`000?nK_o7oVkoa00KoVkoa00?o0000
oiFnm?nE__@01OnE__@7o`0000GoSL?i00?o0000ogg1oOmm`Od01_mm`Od2o`0000OoHK_m00Co0000
obZSkOlZXngo:Z?]2Ol000001?l0DL[o0000obi/fol^K=/2o`000003o`97aol0003oCFG:00;oCFG:
00?o0000oe/00?mK00001?mK00000ol0003oQ18Soh@B8`05oh@B8`03o`000?oooooo0000017ooooo
0017ooooo`;o0000=oooool2o`0000WoYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000;oYl3[00?o
0000ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01onW
`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[o`00
0002o`0000GoYl3[00?o0000ojO0jonW`>/01onW`>/3o`0000SoYko[00?o0000ojNojonW_n/01OnW
_n/4o`0000OoYko[00?o0000ojNojonW_n/01OnW_n/4o`0000SoY[o[00?o0000ojJojonV_n/01OnV
_n/3o`0000WoYKo/00?o0000ojFnk?nU_^`01OnU_^`4o`0000OoXko]00?o0000oj6nkOnQ_^d01OnQ
_^d4o`0000SoW[o`00?o0000oi^olOnK_o401_nK_o400ol0003oUKkdoiFnm004o`0000?oU/?f00?o
0000ohg3nOn=`oT01on=`oT00ol0003oOL7mogg1o@03ogg1oAco000000Go;VcKo`000?l0003o0TO7
o`000002odeUbPco00000on44R<00ol0003oooooo`00000Aooooo`00BOooool00ol0003ooooooooo
o`0fooooo`03o`000?nW`>_oYl3[00OoYl3[00Co0000ojO0jol0003o00001_nW`>/00ol0003oYl3[
ojO0j`06ojO0j`?o00002?nW`>/00ol0003oYl3[ojO0j`05ojO0j`Co00002?nW`>/00ol0003oYl3[
ojO0j`04ojO0j`Co00002?nW`>/00ol0003oYl3[ojO0j`03ojO0j`?o000000?oYl3[o`000?nW_n/0
2OnW_n/00ol0003oYko[ojNoj`04o`0000?oYko[00?o0000ojNojonW_n/01_nW_n/00ol0003oYko[
ojNoj`04o`0000?oYko[00?o0000ojJojonV_n/01onV_n/00ol0003oY[o[ojJoj`04o`0000?oY[o/
00?o0000ojFok?nU_n`01onU_n`00ol0003oYKk/ojFnk004o`0000;oY;o/00?o0000oj>okOnS_nd0
1onS_nd00ol0003oXKk]oj6nk@04o`0000?oXL3_00?o0000oijol?nN_o001onN_o000ol0003oVkoa
oi^ol@02oi^ol@Ko00002?nF`oH00ol0003oSL?iohg3n@05ohg3n@Oo00001_n3b_h00ol0003oIlOn
ofO7oP02ofO7oP_o00000_ooool8o`000005o`97aol0003oCFG:odeUb_l000001?mk00000ol0003o
WbLMoilW7@03oilW7@Co000000?oooooo`000?ooool04?ooool004[ooooo00?o0000ooooooooool0
=_ooool00ol0003oYl3[ojO0j`05ojO0j`?o00002OnW`>/00ol0003oYl3[ojO0j`02ojO0j`?o0000
0_nW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[
ojO0j`07ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/00ol0003oYl3[ojO0j`06ojO0j`03o`00
0?nW`>_o000000;o00001OnW`>/00ol0003oYko[ojNoj`07ojNoj`?o00002?nW_n/00ol0003oYko[
ojNoj`04ojNoj`Co00002?nW_n/00ol0003oY[o[ojJoj`05ojJoj`Co00002?nV_n`00ol0003oYKo/
ojFok005ojFok0Co00001onT_n`00ol0003oXko]oj>ok@05oj>ok@Co00002?nQ`>l00ol0003oW[o`
oijol005oijol0Ko00001_nL`_<00ol0003oU/?foiK3mP06oiK3mP03o`000?n=`oWoSL?i00Co0000
0onBbO/00ol0003oPl[noh?:oP06oh?:oPKo00001OmjeOh3o`0000Sooooo0_l000000ol0DL[o0000
o`000002o`97a`03o`000?m=IL[o000000?oN`0000?o0000oilW7OnO9ad01onO9ad00ol0003ooooo
o`00000Aooooo`00Boooool00ol0003oooooooooo`0fooooo`03o`000?nW`>_oYl3[00Co00000onW
`>/00ol0003oYl3[ojO0j`07ojO0j`04o`000?nW`>_o0000o`0000KoYl3[00?o0000ojO0jonW`>/0
1_nW`>/3o`0000SoYl3[00?o0000ojO0jonW`>/01OnW`>/4o`0000SoYl3[00?o0000ojO0jonW`>/0
1?nW`>/4o`0000SoYl3[00?o0000ojNojonW_n/00onW_n/3o`000003ojNojol0003oYko[00WoYko[
00?o0000ojNojonW_n/00ol00003ojNoj`03o`000?nW_n_oYko[00OoYko[00?o0000ojJojonV_n/0
1?l00003ojJoj`03o`000?nV_ncoY[o/00OoY[o/00?o0000ojFok?nU_n`01?l00002ojFok003o`00
0?nT_ncoY;o/00OoY;o/00?o0000oj>okOnS_nd01?l00003oj?0kP03o`000?nQ`>ooXL3_00OoXL3_
00?o0000oijol?nN_o001?l00003oio2l@03o`000?nL`_?oW<;c00OoW<;c00?o0000oiK3m_nF`oH0
0_nF`oH6o`0000SoT/Wk00?o0000oh?:o_n3b_h01Ol00004ohoCoP03o`000?mjeOkoN]Gn00Co0000
3Oooool4o`0000;o0TO71?l000000omk003o0000oilW7@08oilW7@04o`000?ooooooooooo`00013o
oooo001<ooooo`03o`000?oooooooooo03Kooooo0_l00008ojO0j`03o`000?nW`>_oYl3[00GoYl3[
0ol00009ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00OoYl3[
00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/0
0ol00004ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojNojol000000_l00005ojNoj`03o`00
0?nW_n_oYko[00OoYko[0ol00007ojNoj`03o`000?nW_n_oYko[00GoYko[1?l00008ojJoj`03o`00
0?nV_ncoY[o/00GoY[o/1?l00007ojFok003o`000?nT_ncoY;o/00GoY;o/1?l00008oj?0kP03o`00
0?nQ`>ooXL3_00GoXL3_1?l00008oio2l@03o`000?nL`_?oW<;c00GoW<;c1_l00005oi[7m`03o`00
0?nBbO_oT/Wk00GoT/Wk1?l00008ohoCoPCo00004oooool3o`0000;o0TO71Ol00008oilW7@05o`00
0?ooooooooooooooool000004?ooool004gooooo0_l0000hooooo`03o`000?nW`>_oYl3[00KoYl3[
00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00OoYl3[00Co0000ojO0jol0003o
00001_nW`>/00ol0003oYl3[ojO0j`06ojO0j`?o00002?nW`>/00ol0003oYl3[ojO0j`05ojO0j`Co
00002?nW`>/00ol0003oYl3[ojO0j`04ojO0j`?o00002OnW_n/00ol0003oYko[ojNoj`03ojNoj`?o
000000?oYko[o`000?nW_n/02?nW_n/00ol0003oYko[ojNoj`04o`0000?oYko[00?o0000ojJojonV
_n/01onV_n/00ol0003oY[o/ojJok004o`0000?oY[o/00?o0000ojFok?nU_n`01_nU_n`00ol0003o
Y;o/ojBok004o`0000?oY<3]00?o0000oj?0k_nS`>h01onS`>h00ol0003oXL3_oj70k`04o`0000?o
X/7_00?o0000oio2lOnO`_401onO`_400ol0003oW<;coic2l`04o`0000;oW/Gc00?o0000oi[7monJ
aoL01onJaoL00ol0003oT/Wkoi;9n`04o`0000CoVLkj00?o0000ohoCo_n?doh01Ol0000Iooooo`;o
00000_l2AlL01?l0003o/2d3ok0]0on`;@<2o`0000KoWbLM00Go0000ooooooooooooooooo`00000@
ooooo`00Coooool00ol0003oooooooooo`0fooooo`03o`000?nW`>_oYl3[00CoYl3[1?l00008ojO0
j`03o`000?nW`>_oYl3[00GoYl3[0ol00009ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00002ojO0
j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[
00OoYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW_n_oYko[00OoYko[00?o0000ojNo
jol000000_l00005ojNoj`03o`000?nW_n_oYko[00KoYko[0ol00008ojNoj`03o`000?nV_n_oY[o[
00GoY[o[1?l00008ojJok003o`000?nU_ncoYKo/00CoYKo/1?l00008ojC0k@03o`000?nS`>koXl3^
00GoXl3^1?l00008oj;1k`03o`000?nO`_7oWl;a00GoWl;a1?l00007oik5l`03o`000?nJaoOoV/Og
00GoV/Og1?l00008oiW>nP?o00007oooool2o`000003o`97aol0003o/2d300Co/2d30_l00004oilW
7@05o`000?ooooooooooooooool000004?ooool0053ooooo00?o0000ooooooooool0=_ooool00ol0
003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`04o`00
00?oYl3[00?o0000ojO0jonW`>/01onW`>/01?l0003oYl3[o`000?l00006ojO0j`03o`000?nW`>_o
Yl3[00KoYl3[0ol00008ojO0j`03o`000?nW`>_oYl3[00GoYl3[1?l00007ojO0j`03o`000?nW_n_o
Yko[00GoYko[0ol00009ojNoj`03o`000?nW_n_oYko[00;oYko[0ol000000onW_n_o0000ojNoj`09
ojNoj`03o`000?nV_n_oY[o[00Co00000onV_n`00ol0003oY[o/ojJok007ojJok003o`000?nU_nco
YKo/00?o00000onU`>`00ol0003oY<3]ojC0k@07ojC0k@03o`000?nS`>koXl3^00Co00000onS`Nh0
0ol0003oX/7_oj;1k`07oj;1k`03o`000?nO`_7oWl;a00Co00000_nQa?400ol0003oW/Gcoik5l`07
oik5l`03o`000?nJaoOoV/Og00Co00000onOboH00ol0003oVLkjoiW>nP03oiW>nP?o00008oooool2
o`000003o`97aol0003o/2d300Go/2d300Go0000oilW7OnO9agoWbLMo`000003ooooo`03o`000?oo
oooooooo00kooooo001Aooooo`03o`000?oooooooooo03Kooooo0_l00008ojO0j`03o`000?nW`>_o
Yl3[00CoYl3[1?l00008ojO0j`03o`000?nW`>_oYl3[00GoYl3[0ol00009ojO0j`03o`000?nW`>_o
Yl3[00;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojO0jonW`>/01?l00003
ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojNojonW_n/01?l00003ojO0j`03o`000?nW_n_o
Yko[00OoYko[00Co0000ojNojol0003o00001OnW_n/00ol0003oYko[ojNoj`07ojNoj`?o00002?nV
_n`00ol0003oY[o/ojJok005ojJok0Co00001onU`>`00ol0003oY<3]ojC0k@05ojC0k@Co00002?nS
`Nh00ol0003oX/7_oj;1k`05oj;1k`Co00001onQa?400ol0003oW/Gcoik5l`05oik5l`Co00002?nO
boH00ol0003oVLkjo`000002o`0002Oooooo1?l00006ok0]0`?o00001?ooool00ol0003ooooooooo
o`0>ooooo`00D_ooool2o`0003Sooooo00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`03
o`0000CoYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000
ojO0jonW`>/01onW`>/01?l0003oYl3[o`000?l00007ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l0
0008ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00008ojO0j`03o`000?nW_n_oYko[00GoYko[0ol0
0008ojNoj`03o`000?nW_n_oYko[00?oYko[0ol000000onV`>co0000ojJok009ojJok003o`000?nV
_ncoY[o/00Co00000_nV`>`00ol0003oYL3/ojG0k007ojG0k003o`000?nT`>goY<3]00Co00000onU
`Nd00ol0003oXl7^oj?1kP07oj?1kP03o`000?nR`NooX/7_00Co00000_nS`o000ol0003oXLCaoj74
l@07oj74l@03o`000?nNaO?oW/Gc00Co00000onRb?<00ol0003oWl_foio;mP05oio;mP?o0000:_oo
ool00ol0003oooooo`000003o`0000Ko/2d300?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0>ooooo`00E?ooool00ol0003oooooooooo`0fooooo`03o`000?nW`>_oYl3[00CoYl3[1?l00008
ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00008ojO0j`03o`000?nW`>_oYl3[00GoYl3[0ol0000:
ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?nW`>_o
Yl3[00?o00001?nW`>/00ol0003oYl3[ojO0j`06ojO0j`03o`000?nW_n_oYko[00Co00000onW`>/0
0ol0003oYko[ojNoj`06ojNoj`03o`000?nW_n_o000000;o00001OnV`>`00ol0003oY[o/ojJok007
ojJok0?o00001onV`>`00ol0003oYL3/ojG0k005ojG0k0Co00002?nU`Nd00ol0003oXl7^oj?1kP05
oj?1kPCo00001onS`o000ol0003oXLCaoj74l@05oj74l@Co00002?nRb?<00ol0003oWl_foio;mP04
o`0002kooooo00Ko0000ooooool0003o0000oj/N0?l00005ok0]0`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03_ooool005Gooooo00?o0000ooooooooool0=_ooool00ol0003oYl3[ojO0
j`03o`0000CoYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o
0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01onW
`>/3o`0000OoYl3[00?o0000ojO0jonW`>/01OnW`>/4o`0000SoYl3[00?o0000ojO0jonW`>/01?nW
`>/4o`0000SoYl3[00?o0000ojNojonW_n/01?nW_n/3o`0000WoY/3/00?o0000ojJok?nV_n`00onV
_n`3o`0000;oY/3/00?o0000ojK0k?nV`>`01_nV`>`00ol0003oYL3/ojG0k004o`0000?oYL7]00?o
0000ojG1kOnU`Nd01onU`Nd00ol0003oXl7^oj?1kP04o`0000;oY<;^00?o0000oj?3l?nS`o001onS
`o000ol0003oXLCaoj74l@04o`0000?oY<Ga00?o0000oj;8lonRb?<01OnRb?<4o`0003?ooooo00?o
0000ooooool000000_n[7P02o`0000?o/2d300?o0000ooooooooool00oooool00ol0003ooooooooo
o`0=ooooo`00E_ooool00ol0003oooooooooo`0fooooo`;o00002?nW`>/00ol0003oYl3[ojO0j`04
ojO0j`Co00002?nW`>/00ol0003oYl3[ojO0j`04ojO0j`Co00002?nW`>/00ol0003oYl3[ojO0j`03
ojO0j`?o000000?oYl3[o`000?nW`>/02?nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000
ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/01onW`>/0
0ol0003oYko[ojNoj`03o`0000?oYl3[00?o0000ojK0k?nV`>`01onV`>`00ol0003oY[o/o`000002
o`0000KoY/3/00?o0000ojK0k?nV`>`01?nV`>`4o`0000SoYL7]00?o0000ojG1kOnU`Nd01OnU`Nd4
o`0000OoY<;^00?o0000oj?3l?nS`o001OnS`o04o`0000SoY<Ga00?o0000oj;8lonRb?<01?l0000h
ooooo`03o`000?oooooo000000?oZah000?o0000ok0]0ol000001_ooool00ol0003oooooooooo`0=
ooooo`00Eoooool00ol0003oooooooooo`0fooooo`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0
jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojO0jonW`>/00ol00004ojO0
j`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojO0jol000000_l00005ojO0j`03o`000?nW`>_oYl3[
00KoYl3[0ol00008ojO0j`03o`000?nW`>_oYl3[00GoYl3[1?l00007ojO0j`03o`000?nW`>_oYl3[
00GoYl3[1?l00007ojO0j`03o`000?nV`>coY/3/00GoY/3/0ol0000:ojK0k003o`000?nV`>coY/3/
00?o00000onV`>`00ol0003oYL7]ojG1k@07ojG1k@03o`000?nU`NgoYL7]00Co00000_nU`Nd00ol0
003oY<;^ojC2kP07ojC2kP03o`000?nS`o3oXl?`00Co00001?nUa>l00ol0003oY<GaojC5l@04ojC5
l@Co0000??ooool01?l0003oooooooooool00003oj/N00;o00001_ooool00ol0003oooooooooo`0=
ooooo`00F?ooool2o`0003Oooooo00?o0000ojO0jonW`>/01_nW`>/3o`0000SoYl3[00?o0000ojO0
jonW`>/01?nW`>/4o`0000SoYl3[00?o0000ojO0jonW`>/01?nW`>/4o`0000SoYl3[00?o0000ojO0
jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`04o`00
00?oYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0
jonW`>/01_nW`>/00ol0003oY/3/ojK0k004o`0000?oYl3/00?o0000ojK0k?nV`>`01onV`>`3o`00
00OoY/3/00?o0000ojG1kOnU`Nd01OnU`Nd4o`0000OoYL7]00?o0000ojC2k_nT`^h01OnT`^h4o`00
00WoYLC_00?o0000ojC5lOnTaO400ol00011ooooo`04o`000?ooooooooooo`0000;oZah00_l00006
ooooo`03o`000?oooooooooo00gooooo001Jooooo`03o`000?oooooooooo03Gooooo00?o0000ojO0
jonW`>/00_nW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0j`03o`00
00?oYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0
jonW`>/01_nW`>/01?l0003oYl3[o`000?l00007ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00008
ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00008ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00008
ojO0k003o`000?nV`>coY/3/00?oY/3/0ol000000onV`>co0000ojK0k008ojK0k003o`000?nU`Ngo
YL7]00Co00000onV`Nd00ol0003oYL7]ojG1k@06ojG1k@03o`000?nT`^koY<;^00Co00000onV`nh0
0ol0003oYLC_ojG4k`07ojG4k`?o0000AOooool00ol0003oooooooooo`02o`0000Sooooo00?o0000
ooooooooool03Oooool005_ooooo00?o0000ooooooooool0=Oooool01?l0003oYl3[o`000?l00006
ojO0j`03o`000?nW`>_oYl3[00GoYl3[1?l00007ojO0j`03o`000?nW`>_oYl3[00GoYl3[1?l00008
ojO0j`03o`000?nW`>_oYl3[00CoYl3[0ol0000:ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/0
0ol0003oYl3[ojO0j`07ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`07
ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>`00ol0003oYl3/ojO0k007ojO0k003o`000?nV`>co
000000;o00001OnV`>`00ol0003oY/3/ojK0k005ojK0k0Co00002?nV`Nd00ol0003oYL7]ojG1k@04
ojG1k@Co00002?nV`nh00ol0003oYLC_ojG4k`03ojG4k`?o0000B?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00gooooo001Looooo`03o`000?oooooooooo03Gooooo00?o0000ojO0
jonW`>/01onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0
003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0j`03o`00
00?oYl3[00?o0000ojO0jonW`>/01onW`>/3o`0000OoYl3[00?o0000ojO0jonW`>/01OnW`>/4o`00
00OoYl3[00?o0000ojO0jonW`>/01OnW`>/4o`0000OoYl3/00?o0000ojO0k?nW`>`01OnW`>`3o`00
00WoY/3/00?o0000ojK0k?nV`>`01?l00003ojK1k003o`000?nV`NgoY/7]00OoY/7]00?o0000ojG1
kOnU`Nd00ol00003ojK2k@03o`000?nV`nkoY/?^00OoY/?^00?o0000ojG4kol000000_l0001<oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool005gooooo0_l0000fooooo`03
o`000?nW`>_oYl3[00KoYl3[0ol00008ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00008ojO0j`03
o`000?nW`>_oYl3[00GoYl3[1?l00007ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol000000onW`>_o
0000ojO0j`08ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`06ojO0j`03
o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3/ojO0k006ojO0k003o`000?nW`>coYl3/00Co
00000onW`>`00ol0003oY/3/ojK0k006ojK0k0?o00002?nV`N`00ol0003oY/7]ojK1k@05ojK1k@Co
00001onV`^d00ol0003oY/?^ojK3kP05ojK3kP?o0000D?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00cooooo001Oooooo`03o`000?oooooooooo03Cooooo00?o0000ojO0jonW`>/0
0_nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[
00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/0
1_nW`>/00ol0003oYl3[o`000002o`0000GoYl3[00?o0000ojO0jonW`>/01_nW`>/3o`0000SoYl3[
00?o0000ojO0jonW`>/01?nW`>/4o`0000SoYl3[00?o0000ojO0k?nW`>`01?nW`>`4o`0000SoYl3/
00?o0000ojK0k?nV`>`00_nV`>`3o`0000;oYl7/00?o0000ojK1k?nV`N`01onV`N`00ol0003oY/7]
ojK1k@04o`0000;oY/7]00?o0000ojK2kOnV`^d01onV`^d00ol0003oY/?^ojK3kP04o`0005Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`00H?ooool00ol0003ooooooooo
o`0dooooo`04o`000?nW`>_o0000o`0000OoYl3[00?o0000ojO0jonW`>/01?nW`>/4o`0000SoYl3[
00?o0000ojO0jonW`>/01?nW`>/4o`0000SoYl3[00?o0000ojO0jonW`>/01?nW`>/3o`0000WoYl3[
00?o0000ojO0jonW`>/00_nW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[
ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3/ojO0k003o`0000?oYl3/
00?o0000ojO0k?nW`>`01onW`>`01?l0003oY/3/o`000?l00006ojO1k003o`000?nV`NcoY/7/00Go
Y/7/1?l00007ojK1k@03o`000?nV`^goY/;]00GoY/;]1?l0001Hooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool03?ooool0067ooooo00?o0000ooooooooool0=?ooool2o`0000WoYl3[
00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojO0jonW`>/0
0ol00004ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`00
0?nW`>_oYl3[00OoYl3[00Co0000ojO0jol0003o00001_nW`>/00ol0003oYl3[ojO0j`05ojO0j`Co
00001onW`>/00ol0003oYl3[ojO0j`05ojO0j`Co00001onW`>`00ol0003oYl3/ojO0k005ojO0k0?o
00002OnW`N`00ol0003oY/7/ojK1k004o`0000;oYl7/00?o0000ojK1kOnV`Nd01onV`Nd00ol0003o
Y/;]ojK2k@04o`0005gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`00
H_ooool2o`0003Kooooo00?o0000ojO0jonW`>/01_nW`>/3o`0000SoYl3[00?o0000ojO0jonW`>/0
1?nW`>/4o`0000SoYl3[00?o0000ojO0jonW`>/01?nW`>/4o`0000OoYl3[00?o0000ojO0jonW`>/0
1OnW`>/3o`0000WoYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00KoYl3[
00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>coYl3/00KoYl3/00?o0000ojO0k?nW`>`0
1?l00003ojO0k003o`000?nW`NcoYl7/00KoYl7/0ol00007ojO1k003o`000?nV`NgoY/7]00GoY/7]
1?l0001Rooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool006Cooooo00?o
0000ooooooooool0=?ooool00ol0003oYl3[ojO0j`02ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0
j`07ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?nW
`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`06ojO0j`03o`000?nW`>_oYl3[00Co00000onW
`>/00ol0003oYl3[ojO0j`06ojO0j`?o00002?nW`>/00ol0003oYl3[ojO0j`04ojO0j`Co00002?nW
`>/00ol0003oYl3/ojO0k004ojO0k0Co00002?nW`>`00ol0003oYl7/ojO1k002ojO1k0?o00000_nW
`N`00ol0003oYl7/ojO1k006ojO1k003o`000?nV`NgoY/7]00Co0000I_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00cooooo001Uooooo`03o`000?oooooooooo03Cooooo00Co0000
ojO0jol0003o00001_nW`>/00ol0003oYl3[ojO0j`05ojO0j`Co00001onW`>/00ol0003oYl3[ojO0
j`05ojO0j`Co00001onW`>/00ol0003oYl3[ojO0j`04ojO0j`Co00002?nW`>/00ol0003oYl3[ojO0
j`02ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?nW`>_oYl3[00?o00000onW
`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0
k007ojO0k004o`000?nW`Nco0000o`0000KoYl7/00?o0000ojO1k?nW`N`01?nW`N`4o`0006_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`00I_ooool00ol0003ooooooooo
o`0dooooo`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW
`>_oYl3[00KoYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o
0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00KoYl3[00Co0000ojO0jol0003o0000
1_nW`>/00ol0003oYl3[ojO0j`05ojO0j`Co00001onW`>/00ol0003oYl3[ojO0j`05ojO0j`Co0000
1onW`>`00ol0003oYl3/ojO0k005ojO0k0?o00002OnW`N`00ol0003oYl7/ojO1k003o`00073ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`00Ioooool00ol0003ooooooooo
o`0dooooo`03o`000?nW`>_oYl3[00KoYl3[0ol00008ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l0
0008ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00008ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l0
0008ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`06ojO0j`03o`000?nW
`>_oYl3[00Co00000onW`>`00ol0003oYl3/ojO0k006ojO0k003o`000?nW`>coYl3/00Co00000onW
`N`00ol0003oYl7/ojO1k005ojO1k0Co0000M?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00_ooooo001Xooooo`;o0000=Oooool00ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/0
0ol0003oYl3[ojO0j`06ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/00ol0003oYl3[ojO0j`06
ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?nW`>_o
Yl3[00?o00001?nW`>/00ol0003oYl3[ojO0j`04ojO0j`Co00002?nW`>/00ol0003oYl3[ojO0j`04
ojO0j`Co00002?nW`>`00ol0003oYl3/ojO0k004ojO0k0Co00002?nW`N`00ol0003oYl7/ojO1k004
o`0007Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`00J_ooool00ol0
003oooooooooo`0cooooo`04o`000?nW`>_o0000o`0000OoYl3[00?o0000ojO0jonW`>/01?nW`>/4
o`0000SoYl3[00?o0000ojO0jonW`>/01?nW`>/4o`0000OoYl3[00?o0000ojO0jonW`>/01OnW`>/4
o`0000SoYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000
ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>coYl3/00OoYl3/00?o0000ojO0k?nW`>`00ol00003
ojO0k003o`000?nW`NcoYl7/00KoYl7/0ol0001mooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02oooool006_ooooo00?o0000ooooooooool0<oooool2o`0000WoYl3[00?o0000ojO0
jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/00ol00003ojO0
j`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[
00KoYl3[0ol00007ojO0j`03o`000?nW`>_oYl3[00GoYl3[1?l00007ojO0j`03o`000?nW`>coYl3/
00GoYl3/1?l00007ojO0k003o`000?nW`NcoYl7/00;oYl7/0ol00021ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02oooool006cooooo00?o0000ooooooooool0=?ooool00ol0003o
Yl3[ojO0j`06ojO0j`?o00001onW`>/00ol0003oYl3[ojO0j`05ojO0j`Co00001onW`>/00ol0003o
Yl3[ojO0j`04ojO0j`Co00002?nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000_nW`>/00ol0003o
Yl3[ojO0j`06ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`06ojO0j`03
o`000?nW`>coYl3/00Co00000_nW`>/00ol0003oYl3/ojO0k007ojO0k004o`000?nW`Nco0000o`00
08Gooooo00Go0000ooooooooooooooooo`00000=ooooo`00KOooool2o`0003Gooooo00?o0000ojO0
jonW`>/00_nW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`04o`00
00?oYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0
jonW`>/01onW`>/01?l0003oYl3[o`000?l00006ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00008
ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00007ojO0j`03o`000?nW`>coYl3/00GoYl3/0ol00027
ooooo`05o`000?ooooooooooooooool000003Oooool006oooooo00?o0000ooooooooool0<oooool0
1?l0003oYl3[o`000?l00006ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00008ojO0j`03o`000?nW
`>_oYl3[00CoYl3[1?l00007ojO0j`03o`000?nW`>_oYl3[00GoYl3[1?l00008ojO0j`03o`000?nW
`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?nW`>_oYl3[00?o00000onW
`>/00ol0003oYl3[ojO0j`06ojO0j`03o`000?nW`>coYl3/00Co0000Roooool01?l0003ooooooooo
ool0000=ooooo`00L?ooool00ol0003oooooooooo`0cooooo`;o00002?nW`>/00ol0003oYl3[ojO0
j`03o`0000CoYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o
0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW`>/01?nW
`>/4o`0000OoYl3[00?o0000ojO0jonW`>/01OnW`>/4o`0000OoYl3[00?o0000ojO0jonW`>/01?nW
`>/4o`00093ooooo00?o0000ooooool000003Oooool0077ooooo00?o0000ooooooooool0=?ooool0
0ol0003oYl3[ojO0j`04ojO0j`Co00002?nW`>/00ol0003oYl3[ojO0j`04ojO0j`Co00001onW`>/0
0ol0003oYl3[ojO0j`04ojO0j`Co00002OnW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000
ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01_nW`>/0
0ol0003oYl3[ojO0j`03o`0009Cooooo00Co0000oooooooooooo00003?ooool007;ooooo0_l0000e
ooooo`03o`000?nW`>_oYl3[00?o00001?nW`>/00ol0003oYl3[ojO0j`06ojO0j`03o`000?nW`>_o
Yl3[00?o00000onW`>/00ol0003oYl3[ojO0j`06ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/2
o`0000KoYl3[1?l00007ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00008ojO0j`03o`000?nW`>_o
Yl3[00CoYl3[1?l0002Hooooo`03o`000?oooooo000000cooooo001dooooo`03o`000?oooooooooo
03?ooooo0_l00008ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00007ojO0j`03o`000?nW`>_oYl3[
00CoYl3[1?l00009ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`06ojO0
j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?nW`>_oYl3[
00?o0000WOooool2o`0000cooooo001eooooo`03o`000?oooooooooo03Cooooo00?o0000ojO0jonW
`>/01_nW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003o
Yl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/01onW`>/3o`0000OoYl3[00?o0000ojO0jonW
`>/01?nW`>/4o`0000OoYl3[00?o0000ojO0jonW`>/01OnW`>/4o`0009oooooo0ol0000<ooooo`00
M_ooool00ol0003oooooooooo`0dooooo`03o`000?nW`>_oYl3[00CoYl3[1?l00007ojO0j`03o`00
0?nW`>_oYl3[00CoYl3[1?l00007ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00002ojO0j`03o`00
0?nW`>_oYl3[00KoYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00KoYl3[
00?o0000ojO0jonW`>/01?l0002Oooooo`Co00003oooool007Oooooo00?o0000ooooooooool0=?oo
ool00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0
j`03o`0000?oYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[o`000002o`0000KoYl3[00?o
0000ojO0jonW`>/01?nW`>/4o`0000OoYl3[00?o0000ojO0jonW`>/01?nW`>/4o`0009oooooo1?l0
000Cooooo`00N?ooool2o`0003Gooooo0_l00007ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00007
ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00009ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/0
0ol0003oYl3[ojO0j`06ojO0j`03o`000?nW`>_oYl3[00?o0000X?ooool3o`0001Oooooo001joooo
o`03o`000?oooooooooo03?ooooo00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`03o`00
00?oYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0
jonW`>/01OnW`>/4o`0000OoYl3[00?o0000ojO0jonW`>/01?nW`>/4o`0009oooooo1?l0000Joooo
o`00Noooool00ol0003oooooooooo`0cooooo`03o`000?nW`>_oYl3[00CoYl3[1?l00007ojO0j`03
o`000?nW`>_oYl3[00CoYl3[1?l00008ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003o
Yl3[ojO0j`06ojO0j`03o`000?nW`>_oYl3[00?o0000Woooool4o`0001kooooo001looooo`03o`00
0?oooooooooo03?ooooo00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00KoYl3[
00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00008ojO0j`03o`00
0?nW`>_oYl3[00CoYl3[1?l0002Nooooo`Co00008_ooool007gooooo0_l0000dooooo`;o00001onW
`>/00ol0003oYl3[ojO0j`04ojO0j`Co00002?nW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o
0000ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0j`03o`0009kooooo1?l0000Vooooo`00Ooooool0
0ol0003oooooooooo`0booooo`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojO0jonW`>/00ol00004
ojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l00007ojO0j`03o`000?nW`>_oYl3[00GoYl3[1?l0002N
ooooo`?o0000:_ooool0083ooooo00?o0000ooooooooool0<_ooool00ol0003oYl3[ojO0j`04ojO0
j`Co00002?nW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/01_nW`>/00ol0
003oYl3[ojO0j`04o`0009kooooo1?l0000]ooooo`00POooool00ol0003oooooooooo`0booooo`03
o`000?nW`>_oYl3[00?o00001?nW`>/00ol0003oYl3[ojO0j`04ojO0j`Co00001onW`>/00ol0003o
Yl3[ojO0j`04ojO0j`Co0000W_ooool4o`00037ooooo0022ooooo`03o`000?oooooooooo03;ooooo
0_l00008ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`06ojO0j`03o`00
0?nW`>_oYl3[00?o0000W_ooool4o`0003Gooooo0023ooooo`;o0000=?ooool00ol0003oYl3[ojO0
j`04ojO0j`Co00001onW`>/00ol0003oYl3[ojO0j`04ojO0j`Co0000WOooool4o`0003Wooooo0025
ooooo`03o`000?oooooooooo03;ooooo00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_o
Yl3[00KoYl3[00?o0000ojO0jonW`>/00ol0002Mooooo`Co0000?Oooool008Kooooo00?o0000oooo
ooooool0<_ooool2o`0000OoYl3[00?o0000ojO0jonW`>/01?nW`>/4o`0009gooooo0ol00011oooo
o`00Qoooool00ol0003oooooooooo`0booooo`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojO0jonW
`>/00ol0002Mooooo`Co0000A?ooool008Sooooo0_l0000cooooo`03o`000?nW`>_oYl3[00CoYl3[
1?l0002Looooo`Co0000B?ooool008[ooooo00?o0000ooooooooool0<Oooool00ol0003oYl3[ojO0
j`03o`0009cooooo1?l0001<ooooo`00Roooool00ol0003oooooooooo`0aooooo`;o0000Voooool4
o`00053ooooo002<ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0U_ooool3o`00
05Cooooo002=ooooo`;o0000<?ooool00ol0003oooooooooo`2Cooooo`Co0000Eoooool008oooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2?ooooo`Co0000Foooool0093ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`2;ooooo`Co0000Goooool0097ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`27ooooo`Co0000Hoooool009;ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`23ooooo`Co0000Ioooool009?ooooo0_l0000Zooooo`03
o`000?oooooooooo083ooooo0ol0001[ooooo`00UOooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo07cooooo1?l0001^ooooo`00U_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo07Sooooo1?l0001booooo`00Uoooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo07Cooooo1?l0001fooooo`00V?ooool2o`0002Gooooo00?o0000ooooooooool0L?ooool4o`00
07[ooooo002Jooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0KOooool3o`0007ko
oooo002Kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0JOooool4o`00087ooooo
002Looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0IOooool4o`0008Gooooo002M
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0HOooool4o`0008Wooooo002Noooo
o`;o00007oooool00ol0003oooooooooo`1Mooooo`Co0000SOooool00:3ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`1Jooooo`?o0000TOooool00:7ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`1Fooooo`Co0000U?ooool00:;ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`1Booooo`Co0000V?ooool00:?ooooo0_l0000Jooooo`03o`000?oooooo
oooo04kooooo1?l0002Looooo`00YOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
04[ooooo1?l0002Pooooo`00Y_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Ko
oooo1?l0002Tooooo`00Yoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo
0ol0002Xooooo`00Z?ooool2o`0001Gooooo00?o0000ooooooooool0?oooool4o`000:_ooooo002Z
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>oooool4o`000:oooooo002[oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=oooool4o`000;?ooooo002/ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool4o`000;Oooooo002]ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0<?ooool3o`000;_ooooo002^ooooo`;o00003_oo
ool00ol0003oooooooooo`0]ooooo`Co0000__ooool00;3ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Yooooo`Co0000`_ooool00;7ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Uooooo`Co0000a_ooool00;;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Qooooo`Co0000b_ooool00;?ooooo0_l00009ooooo`03o`000?oooooooooo01gooooo
1?l0003>ooooo`00]Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo0ol0
003Booooo`00]_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0003E
ooooo`00]oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0003Ioooo
o`00^?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0003Mooooo`00
^Oooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000>7ooooo002kooooo`04o`000?oo
ooooooooo`0000Wooooo0ol0003Uooooo`00_?ooool00ol0003oooooo`000005ooooo`Co0000j?oo
ool00;gooooo0_l000000ooooooo0000o`000002o`000>cooooo002nooooo`;o0000l?ooool00?oo
oooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oo
oooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool009Gooooo0ol000000ol@
413oooooooooo`04ooooo`05ohN7Qol@413o0000oa0@4?n7QhL01?ooool01_o<c<co8B4Qo`000?l0
003oEEEEokZj^P?ooooo00KoMgMgoa0@4?l0003o410@oeEEEOoMgMd2ooooo`03oa0@4?l0003o0000
00;ooooo0_l000001Ol@413oooooooooooo<c<co8B4Q00;o000000GoEEEEokZj^_oooooooooooa0@
4005o`00000:oa0@4?ooooooooooojVYZOl@413o0000ob4Q8OnHV9So410@o`0000;ooooo00?o410@
o`000?l000001?l0000;ooooo`03oa0@4?l0003o000000?o000000Co410@oooooooooooo410@0_l0
0002ooooo`;o000000?o410@ooooooooool02?ooool01onYZJWo410@o`000?lQ8B7oV9RHoa0@4?l0
00002oooool01ol@413o0000oiRHV?l@413o0000oa0@4?nYZJT00oooool01On7QhOo410@o`000?l@
413oQhN700?ooooo00Oo410@o`000?l@413ooooooa0@4?l0003o410@07_ooooo002Fooooo`03o`00
0?oooooooooo00Gooooo00OoQhN7ob4Q8Oo<c<coooooolc<c?lQ8B7oQhN700?ooooo00Ko410@ohN7
Qoooooook^k^ojVYZOlQ8B42ooooo`07ogMgMom4A4CogMgMoooooooMgMgoQhN7ob4Q8@03ooooo`03
o`000?oooooooooo00;ooooo00[o0000oooooooooooooooooa0@4?n7QhOoooooonk^k_nYZJWo8B4Q
1Oooool00ol0003oooooooooo`03ooooo`06o`000?nj^[[oooooomgMgOmgMgOo00001_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`09ooooo`06o`000?nj^[[oooooomgMgOmgMgOo00003Oooool03ol0003o8B4Qolc<
c?ooooooc<c<ob4Q8OnYZJWoooooohN7QolQ8B7oc<c<ooooooo<c<co8B4QohN7Q`03ooooo`06oc8b
<_n7QhOooooookZj^_l0003ok^k^Noooool009Kooooo00?o0000ooooooooool01Oooool00ol@413o
c<c<ooooo`02ooooo`03olc<c?l@413ooooo00;ooooo00?o0000ooooooooool01Oooool00ol@413o
k^k^ooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:oooo
o`03o`000?oooooooooo00?ooooo00Ko410@ohN7Qoo^k^koooooomgMgOl00006ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Ko410@ohN7Qoo^k^koooooomgMgOl0000=ooooo`03o`000?o<c<cooooo00;o
oooo00Goc<c<oa0@4?oooooo410@olc<c003ooooo`03olc<c?l@413ooooo00;ooooo00Gok^k^ob4Q
8Oo<c<co8B4Qolc<c01looooo`00U_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000007ooooo`Oo00000oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`03ooooo`06olc<c?m4
A4Co0000o`000?l@413o00001_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`06olc<c?m4A4Co0000o`00
0?l@413o00003Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool00_ooool00onj^[[o0000ohN7Q`1mooooo`00U_ooool4o`000006oeEEEOo^k^kooooo
ooooool@413o^[Zj0oooool00onj^[[o410@ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
410@omgMgOooool00_ooool00ooMgMgo0000ooooo`02ooooo`03o`000?o^k^kooooo00;ooooo00Go
0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000onk^k_ooool0
0_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000olc<c?ooool0
0_ooool01Oo<c<co410@ooooool@413o^[Zj00?ooooo00?o^[Zjoa0@4?ooool00_ooool01Oo^k^ko
<S8bolc<c?lb<S;ok^k^07cooooo002Fooooo`06o`000?oooooooooooooooon7QhOo<S8b0_ooool0
1on7QhOo8B4Qolc<c?ooooooc<c<ob4Q8On7QhL00oooool00ol0003oooooooooo`05ooooo`07ohN7
QolQ8B7o^[ZjoooooooMgMgo8B4QogMgM`03ooooo`06o`000?m4A4CogMgMoooooomgMgOo410@0ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?oQhN7oc8b<_ooool01Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00Ko0000odA4A?oMgMgooooo
ogMgMol@410?ooooo`03ohN7Qolb<S;ooooo00cooooo00oo0000ob4Q8Oo<c<coooooolc<c?lQ8B7o
V9RHoooooon7QhOo8B4Qolc<c?ooooooc<c<ob4Q8On7QhL00oooool01OmEEEGoMgMgoooooon7QhOo
EEEE07cooooo002Fooooo`03o`000?oooooooooo00;ooooo00Wo0000ooooooooooooooooohN7Qol@
413o0000oa0@4?n7QhL00_ooool00ol@413o0000o`000003o`000003oa0@4?oooooooooo00;ooooo
00GoQhN7oa0@4?l0003o410@ogMgM`03ooooo`09oa0@4?l0003oMgMgoa0@4?l0003o8B4Qolc<c?oo
oooo410@00Go000000?o410@ooooooooool00_ooool00ol@413o0000o`000006ooooo`05odA4A?l0
003o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000Gooooo
00Oo410@o`000?mgMgOo410@o`000?lQ8B7oc<c<00cooooo00GoA4A4o`000?l0003o410@olc<c00=
ooooo`06o`000?n7QhOo410@o`000?l@413oV9RH0oooool01On7QhOo410@o`000?l@413oQhN700?o
oooo00Oo410@o`000?l@413ooooooa0@4?l0003o410@07_ooooo002Fooooo`06o`000?oooooooooo
oooooon7QhOo<S8b3?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`2@ooooo`00UOooool5o`000003oeEEEOo^k^ko
oooo00_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo093ooooo002Xooooo`03oa0@4?oooooooooo01Sooooo00?o410@ooooooooool02?ooool00ol@
413oooooooooo`0=ooooo`03oa0@4?l0003o0000017ooooo00?o410@ooooooooool09oooool00ol@
413o0000ooooo`2Aooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00\
\>"],
  ImageRangeCache->{{{0, 359.125}, {291.062, 0}} -> {-0.0975847, 0.020501, \
0.00375249, 0.00375249}}]
}, Open  ]],

Cell[TextData[{
  "\tThe reader is invited to vary the value of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " in this solution, as well as the shape of the box.  "
}], "Text"],

Cell[TextData[{
  "\t We can use this solution method to determine the general solution for \
the case of arbitrary nonzero potentials specified on all four sides at once \
by using the following argument. We can  repeat our analysis, taking the case \
where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_A = \(\[Phi]\_C = \(\[Phi]\_D = 0\)\)\)]],
  " and only ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_B\)(x)\)]],
  " is nonzero, next evaluating the case where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_A = \(\[Phi]\_B = \(\[Phi]\_D = 0\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_C\)(y)\)]],
  " is nonzero, and finally taking the case where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_A = \(\[Phi]\_B = \(\[Phi]\_C = 0\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_D\)(x)\)]],
  " is nonzero. We can then superimpose the results from these calculatiosn \
to obtain the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  " for any combination of potentials specified on the rectangular boundary. \
"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Example 2: von Neumann Boundary Conditions; the Current Density in \
a Conducting Wire\
\>", "Section",
  CellTags->"c:30"],

Cell[TextData[{
  "\t Let's now study an example with von Neumann boundary conditions over \
part of the surface. Consider a current-carrying wire made of electrically \
conductive material, such as copper (see Fig. ",
  ButtonBox["3.10",
    ButtonData:>"Fig. 3.10",
    ButtonStyle->"Hyperlink"],
  ") The length of the wire is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(b\)\(,\)\)\)]],
  " and its width is ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " . (For simplicity, we neglect any ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-dependence.) The left and right sides of the wire are insulated (coated \
with rubber, say). To the top of the wire, a voltage ",
  Cell[BoxData[
      \(TraditionalForm\`V\_o\)]],
  " is applied, causing a current ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  " (in amperes)",
  StyleBox[" ",
    FontSlant->"Italic"],
  "to run through to the bottom, where is it extracted (see the figure). The \
question is to determine the distribution of current and the electric field \
inside the wire. "
}], "Text"],

Cell[TextData[{
  " These two quantities are related: current flows because there is an \
electric field ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["E",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"-", 
            StyleBox[\(\[Del]\[Phi]\),
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  " inside the conductor. The ",
  StyleBox["current density",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        StyleBox["j",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " inside the rod (in amperes per square meter) satisfies Ohm's law, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{
              StyleBox["j",
                FontWeight->"Bold",
                FontSlant->"Plain"], " ", "=", " "}],
            "TraditionalForm"], "\[Sigma]", " ", 
          StyleBox["E",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  " is the electrical conductivity of the material. We wish to determine ",
  Cell[BoxData[
      FormBox[
        StyleBox["j",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["E",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", \(x, y\), ")"}], TraditionalForm]]],
  " [or equivalently, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  "].  "
}], "Text",
  CellTags->"i:77"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006/0003Gb000`400?l00000o`00003oo`3ooon]
0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]
0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]
0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]
0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]
0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]
0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooon]
0?ooo`00NP3oool500000?l0oooo;P3oool007X0oooo1@00003o0?ooobh0oooo001j0?ooo`030820
P000000000000080000000<0P8200?ooo`3oool0o`3oool[0?ooo`00N`3oool500000?l0oooo;@3o
ool007/0oooo1@00003o0?ooobd0oooo001k0?ooo`D00000o`3oool]0?ooo`00N`3oool00`20P800
000000000002000000030820P03oool0oooo0?l0oooo:P3oool007/0oooo00<0P820000000000000
0P0000000`20P800oooo0?ooo`3o0?ooobX0oooo001k0?ooo`030820P000000000000080000000<0
P8200?ooo`3oool0o`3ooolZ0?ooo`00N`3oool00`20P800000000000002000000030820P03oool0
oooo0?l0oooo:P3oool007`0oooo1@00003o0?ooob`0oooo001l0?ooo`D00000o`3oool/0?ooo`00
O03oool500000?l0oooo;03oool007`0oooo00<0P8200000000000000P0000000`20P800oooo0?oo
o`3o0?ooobT0oooo000X0?ooo`D00000D03oool5000005l0oooo00<0P8200000000000000P000000
0`20P800oooo0?ooo`330?ooo`009@3oool00`10@400000000000007000000030820P03oool0oooo
04H0oooo0`20P809000000<0P820E`3oool00`30`<00000000000008000000030820P03oool0oooo
0<00oooo000S0?ooo`D0000000@0P8200?ooo`3oool0oooo1@0000160?oooa40000000<0P8200?oo
o`3oool0DP3oool5000000@0oooo1@0000310?ooo`008P3oool00`20P800000000000002000000H0
oooo00<0P8200000000000000P0000140?ooo`H000000P3oool5000000030?ooo`000000000000@0
0000DP3oool00`20P800000000000002000000H0oooo100000000`20P800oooo0?ooo`2n0?ooo`00
8@3oool01@20P8000000000000000000@41000P0oooo00<0P8200000000000000P0000000`20P800
oooo0?ooo`0n0?ooo`030820P0000000000000<0000000@0P8200?ooo`3oool0oooo1@0000020?oo
o`030<30`020P800000000<0000000<0@4100?ooo`3oool0C@3oool01@20P8000000000000000000
P82000P0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`2l0?ooo`008@3oool40000
00030820P03oool0oooo00L0oooo00<0P8200000000000000P00000o0?ooo`030820P00000000000
00<000001@3oool5000000D0oooo1@00001>0?ooo`@000002P3oool00`20P8000000000000020000
0;h0oooo000P0?ooo`030820P00000000000008000002`3oool5000003h0oooo00<0P82000000000
00000`0000050?ooo`030820P00000000000008000001@3oool00`20P80000000000000200000003
0820P03oool0oooo04X0oooo100000000`20P800oooo0?ooo`090?ooo`@0000000<0P8200?ooo`3o
ool0^`3oool00200oooo100000000`20P800oooo0?ooo`090?ooo`030820P0000000000000800000
00<0P8200?ooo`3oool0>P3oool00`20P800000000000003000000030820P03oool0oooo00<0oooo
00<0P8200000000000000P0000000`20P800oooo0?ooo`030?ooo`030820P0000000000000800000
00<0P8200?ooo`3oool0B03oool00`20P800000000000002000000030<30`03oool0oooo00T0oooo
00<0P8200000000000000P00002m0?ooo`007`3oool5000000d0oooo1@00000l0?ooo`H0000000<0
P8200?ooo`3oool00`3oool00`20P800000000000002000000030820P03oool0oooo00@0oooo1P00
00190?ooo`D000003@3oool500000;`0oooo000N0?ooo`030820P000000000000080000000<0P820
0?ooo`3oool02`3oool00`20P800000000000002000000030820P03oool0oooo03P0oooo00<0`<30
000000000000100000060?ooo`030<30`000000000000080000000<0P8200?ooo`3oool01@3oool0
0`10@400000000000002000000030820P03oool0oooo04D0oooo00<0P8200000000000000P000000
0`20P800oooo0?ooo`0;0?ooo`030410@000000000000080000000<0`<300?ooo`3oool09P3oool4
0820P0030<30`03oool0oooo00X0oooo0`20P81o0?ooo`007P3oool5000000l0oooo1@00000j0?oo
o`030820P0000000000000@000001`3oool4000000030820P03oool0oooo00D0oooo00<0P8200000
000000000`0000170?ooo`D000003P3oool00`20P800000000000002000000030820P03oool0oooo
02D0oooo1`0000000`20P800oooo0?ooo`070?ooo`H00000O@3oool001d0oooo00<0P82000000000
00000`00000?0?ooo`D0000000<0P8200?ooo`3oool0=`3oool00`20P800000000000004000000L0
oooo1@0000080?ooo`H00000A@3oool6000000h0oooo00<0P8200000000000000`00000U0?ooo`/0
0000203oool6000000030820P03oool0oooo07X0oooo000M0?ooo`030410@0000000000000800000
00<0@4100?ooo`3oool03@3oool00`10@400000000000002000000030410@03oool0oooo03L0oooo
00<0P820000000000000100000070?ooo`030820P0000000000000800000203oool00`20P8000000
00000003000000030<30`03oool0oooo0440oooo00<0`<300000000000000`0000000`10@400oooo
0?ooo`0<0?ooo`030<30`0000000000000<0000000<0P8200?ooo`3oool08@3oool00`20P8000000
0000000:000000030820P03oool0oooo00@0oooo1`0000000`20P800oooo0?ooo`1i0?ooo`007@3o
ool5000000030820P03oool0oooo00d0oooo00<0P8200000000000000`00000i0?ooo`030820P000
0000000000@00000203oool4000000T0oooo1@0000000`20P800oooo0?ooo`110?ooo`030820P000
0000000000<0000000<0P8200?ooo`3oool03@3oool6000002<0oooo3`0000050?ooo`D000000P3o
ool2000007X0oooo000M0?ooo`D0000000<0P8200?ooo`3oool03@3oool00`20P800000000000003
000003T0oooo00<0P820000000000000100000080?ooo`@000002@3oool5000000030820P03oool0
oooo0440oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`0=0?ooo`H000008`3oool8
000000<0oooo1@0000040?ooo`D000000P3oool2000000030820P03oool0oooo07L0oooo000L0?oo
o`030820P0000000000000<0000000<0P8200?ooo`3oool03@3oool00`20P8000000000000030000
00030820P03oool0oooo03H0oooo00<0P820000000000000100000080?ooo`050410@00000000000
00000020P800203oool00`20P800000000000003000004<0oooo00<0@4100000000000000`000000
0`20P800oooo0?ooo`0=0?ooo`H0000000<0P8200?ooo`3oool07`3oool7000000030820P03oool0
oooo00@0oooo00@0`<30000000000000@4100`3oool5000000<0oooo00<0P8200000003oool0N03o
ool001`0oooo1P0000000`20P800oooo0?ooo`0=0?ooo`030820P0000000000000@00000>03oool0
0`20P800000000000004000000P0oooo00<0P8200000000000000P0000080?ooo`030820P0000000
000000<00000@`3oool6000000030820P03oool0oooo00d0oooo1`00000Q0?ooo`H0000000<0P820
0?ooo`3oool0203oool200000080oooo1P0000030?ooo`800000N03oool001`0oooo1P00000@0?oo
o`030<30`0000000000000@00000>@3oool6000000030820P03oool0oooo00D0oooo00<0P8200000
000000000P0000080?ooo`030<30`0000000000000<0000000<0P8200?ooo`3oool04`3ooolU0820
P0030<30`03oool0oooo00D0oooo1P00000@0?ooo`030820P0000000000000@000008@3oool60000
00030820P03oool0oooo00P0oooo00<0`<3000000010@4000P3oool5000000<0oooo00<0`<300?oo
o`3oool0M`3oool001`0oooo1P00000A0?ooo`H00000>@3oool6000000030820P03oool0oooo00D0
oooo00<0P8200000000000000P0000090?ooo`H000005@3ooolU000000030820P03oool0oooo00D0
oooo1P00000A0?ooo`H000008@3oool6000000030820P03oool0oooo00X0oooo0P0000000`3oool0
000000000003000000030820P03oool0oooo07X0oooo000K0?ooo`L000004@3oool6000003T0oooo
1P0000000`20P800oooo0?ooo`060?ooo`@0000000<0P8200?ooo`3oool01P3oool6000001D0oooo
9@0000000`20P800oooo0?ooo`040?ooo`L000004@3oool600000240oooo1P00000=0?ooo`040820
P000000000000820P0@0000000<0P8200?ooo`3oool0NP3oool001/0oooo1`00000A0?ooo`L00000
>@3oool5000000030410@03oool0oooo00H0oooo100000000`20P800oooo0?ooo`060?ooo`H00000
@@3oool700000140oooo1P0000000`20P800oooo0?ooo`0N0?ooo`H0000000<0P8200?ooo`3oool0
2`3oool7000000030820P03oool0oooo07X0oooo000K0?ooo`L000004@3oool7000003T0oooo1P00
00080?ooo`@0000000<0P8200?ooo`3oool01P3oool600000440oooo1`00000A0?ooo`H0000000<0
P8200?ooo`3oool07`3oool5000000030820P03oool0oooo00`0oooo1`00001l0?ooo`006`3oool7
00000140oooo1`00000i0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool01P3oool3
000000030820P03oool0oooo00H0oooo1P0000110?ooo`L000004@3oool6000000030820P03oool0
oooo01l0oooo1@0000000`20P800oooo0?ooo`0=0?ooo`H00000O03oool001/0oooo1`00000A0?oo
o`L00000>P3oool6000000P0oooo100000080?ooo`H00000@@3oool700000140oooo1P0000000`20
P800oooo0?ooo`0O0?ooo`D0000000<0P8200?ooo`3oool03@3oool00`20P8000000000000030000
07`0oooo000K0?ooo`L000004@3oool7000003X0oooo1`0000070?ooo`@00000203oool600000440
oooo1`00000A0?ooo`H0000000<0P8200?ooo`3oool07`3oool00`20P800000000000003000000l0
oooo00<0P8200000000000001000001k0?ooo`006`3oool700000140oooo1`00000k0?ooo`H00000
00<0`<300?ooo`3oool0103oool01020P80000000000000000080?ooo`D0000000<0P8200?ooo`3o
ool0?`3oool700000140oooo1P0000000`20P800oooo0?ooo`0O0?ooo`030820P0000000000000<0
0000403oool6000007/0oooo000K0?ooo`L000004@3oool7000003`0oooo1P0000070?ooo`<00000
1`3oool00`20P80000000000000300000480oooo1`00000A0?ooo`H0000000<0P8200?ooo`3oool0
803oool500000140oooo1P00001j0?ooo`006`3oool700000140oooo1`00000l0?ooo`030820P000
0000000000<000001`3oool3000000L0oooo00<0P8200000000000000`0000120?ooo`L000004@3o
ool6000000030820P03oool0oooo0200oooo1P00000@0?ooo`H00000NP3oool001/0oooo1`00000A
0?ooo`L00000?@3oool00`20P800000000000003000000030820P03oool0oooo00<0oooo00@0@410
00000000000000001P3oool5000000030820P03oool0oooo01@0oooo9@20P8000`30`<00oooo0?oo
o`040?ooo`L000004@3oool6000000030820P03oool0oooo0240oooo1@0000000`20P800oooo0?oo
o`0=0?ooo`030820P0000000000000<00000NP3oool001/0oooo1`00000A0?ooo`L00000?P3oool0
0`20P800000000000003000000030820P03oool0oooo0080oooo00@0P82000000000000000001@3o
ool6000001L0oooo9@0000000`20P800oooo0?ooo`040?ooo`L000004@3oool6000000030820P03o
ool0oooo0280oooo1@00000?0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0M`3o
ool001/0oooo00<0P8200000000000001000000A0?ooo`L00000?`3oool00`20P800000000000003
000000050820P030`<00oooo0?ooo`20P8000`0000040?ooo`030410@000000000000080000000<0
@4100?ooo`3oool05P3ooolU0820P0030<30`03oool0oooo00@0oooo00<0P8200000000000001000
000A0?ooo`H0000000<0P8200?ooo`3oool08P3oool00`10@400000000000002000000030820P03o
ool0oooo00d0oooo1@0000000`20P800oooo0?ooo`1g0?ooo`00703oool6000000030820P03oool0
oooo00h0oooo1P0000120?ooo`030820P0000000000000@0000000<0oooo0820P00000000P000002
0?ooo`L00000AP3oool6000000030820P03oool0oooo00h0oooo1P00000V0?ooo`D000003`3oool6
000007T0oooo000L0?ooo`H0000000<0P8200?ooo`3oool03P3oool6000004@0oooo4P0000170?oo
o`H0000000<0P8200?ooo`3oool03P3oool6000002H0oooo1@00000?0?ooo`H00000N@3oool001`0
oooo1P0000000`20P800oooo0?ooo`0>0?ooo`H00000A@3oool00`30`<00P8200820P00:00000080
P82000<0`<300?ooo`3oool0AP3oool6000000030820P03oool0oooo00h0oooo1P00000W0?ooo`03
0410@00000000000008000003P3oool6000007T0oooo000L0?ooo`H0000000<0P8200?ooo`3oool0
3@3oool00`20P800000000000004000004/0oooo1000001>0?ooo`H0000000<0P8200?ooo`3oool0
3@3oool7000002P0oooo100000000`20P800oooo0?ooo`0;0?ooo`L00000N03oool001d0oooo1@00
00000`20P800oooo0?ooo`0=0?ooo`030820P0000000000000<00000C@3oool3000004h0oooo00<0
P8200000000000000`0000000`20P800oooo0?ooo`0=0?ooo`H00000:@3oool5000000d0oooo1`00
001h0?ooo`007@3oool5000000030820P03oool0oooo00d0oooo00<0P8200000000000000`00001=
0?ooo`<0000000<0P8200?ooo`3oool0B`3oool00`20P800000000000003000000030820P03oool0
oooo00d0oooo1P00000Z0?ooo`030820P0000000000000800000303oool7000000030<30`03oool0
oooo07D0oooo000M0?ooo`030820P0000000000000<000003`3oool00`20P8000000000000030000
04d0oooo0`0000000`20P800oooo0?ooo`1<0?ooo`H000003`3oool6000002/0oooo00<0P8200000
000000000P00000;0?ooo`80000000<0P8200000000000000P0000000`20P800oooo0?ooo`1e0?oo
o`007@3oool00`20P800000000000003000000l0oooo00<0@4100000000000000P0000000`20P800
oooo0?ooo`1;0?ooo`040410@000000000000820P4h0oooo1P00000>0?ooo`030<30`00000000000
00<00000;P3oool01010@400000000000010@40:0?ooo`80000000<0P8200000000000000P000000
0`20P800oooo0?ooo`1e0?ooo`007P3oool5000000l0oooo1@00001>0?ooo`040820P00000000000
0820P4l0oooo1@00000>0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0;@3oool5
000000L0oooo00@0P8200000003oool0P8201@00001g0?ooo`007P3oool5000000l0oooo1@00001>
0?ooo`040820P00000000000000004l0oooo1@00000>0?ooo`030820P000000000000080000000<0
P8200?ooo`3oool0;`3oool3000000030820P03oool0oooo00@0oooo0P0000020?ooo`D00000M`3o
ool001l0oooo1@00000=0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0C03oool0
1030`<00000000000000001@0?ooo`D000003@3oool00`10@400000000000002000000030<30`03o
ool0oooo02l0oooo00<0`<300820P00000000P0000040820P00300000010@400oooo0080oooo0P20
P803000000030820P03oool0oooo07@0oooo000P0?ooo`@000003@3oool4000000030820P03oool0
oooo04h0oooo0`00001@0?ooo`030820P00000000000008000003@3oool4000003L0oooo1@000009
0?ooo`030820P0000000oooo07D0oooo000P0?ooo`030410@00000000000008000002`3oool50000
00030<30`03oool0oooo04h0oooo0`00001@0?ooo`030<30`000000000000080000000<0P8200?oo
o`3oool02@3oool4000000030410@03oool0oooo0;/0oooo000Q0?ooo`@0000000<0P8200?ooo`3o
ool01`3oool00`20P800000000000002000005<0oooo0`00001A0?ooo`@000002P3oool00`20P800
00000000000200000;h0oooo000R0?ooo`@000002@3oool00`20P800000000000002000005<0oooo
0`00001B0?ooo`@000002@3oool00`20P80000000000000200000;h0oooo000R0?ooo`030<30`000
000000000080000000<0P8200?ooo`3oool0103oool01@20P8000000000000000000@41005@0oooo
0`00001B0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0103oool01@20P8000000
000000000000P8200;l0oooo000T0?ooo`D00000103oool4000005H0oooo0`00001D0?ooo`D00000
0`3oool00`20P80000000000000200000<40oooo000U0?ooo`/00000F03oool3000005<0oooo00<0
P8200000000000002@0000320?ooo`009P3oool20820P0030410@000000000000080000000<0@410
0820P03oool0/03oool20820P0D000000P20P8330?ooo`00o`3ooon]0?ooo`00o`3ooon]0?ooo`00
o`3ooon]0?ooo`00o`3ooon]0?ooo`00o`3ooomS0?ooo`060820P0000000000000000010@400P820
A03oool00?l0ooooH`3oool800000480oooo003o0?ooof<0oooo2@0000000`20P800oooo0?ooo`0n
0?ooo`00?03oool00`20P80000000000003K000000030820P03oool0oooo04@0oooo00<0P8200000
000000002P0000000`10@400P8200<30`00k0?ooo`00?03oool00`20P80000000000003K00000003
0820P03oool0oooo04@0oooo00<0P8200000000000003`00000i0?ooo`00?03oool00`20P8000000
0000003K000000030820P03oool0oooo04@0oooo00<0P820000000000000400000020820P3H0oooo
000l0?ooo`030820P000000000000=/0000000<0P8200?ooo`3oool0A03ooolG000000030820P03o
ool0oooo0340oooo000l0?ooo`030820P000000000000=/0000000<0P8200?ooo`3oool0A03ooolI
00000380oooo000l0?ooo`030820P000000000000=/0000000<0P8200?ooo`3oool0A03ooolK0000
0080P820;P3oool003`0oooo00<0P820000000000000f`0000000`20P800oooo0?ooo`140?oooal0
000000<0P8200?ooo`3oool0:@3oool003`0oooo00<0P820000000000000o`000014000000030820
P03oool0oooo02L0oooo000l0?ooo`030820P000000000000?l00000A00000000`20P800oooo0?oo
o`0W0?ooo`00>`3ooooo000004H0000000<0P8200?ooo`3oool0:@3oool001D0oooo00<0@4100?oo
o`3oool0903oool00`10@40000000000003K000000030820P03oool0oooo01l0oooo00D0@4100000
0000000000000820P00P0?ooo`030410@0000000000001P000000P20P80^0?ooo`005@3oool20000
02D0oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool0803oool40000
00030820P03oool0oooo01d0oooo00<0P8200000000000005P00000b0?ooo`005@3oool3000002@0
oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool08@3oool4000001l0
oooo00<0P8200000000000005000000d0?ooo`005@3oool3000000030410@03oool0oooo0240oooo
00<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool08P3oool01@10@4000000
000000000000P82001d0oooo00<0P820000000000000400000000`20P800`<300?ooo`0e0?ooo`00
5@3oool00`20P80000000000000200000280oooo00<0P8200000000000002P0000350?ooo``00000
00<0P8200?ooo`3oool08`3oool4000000030820P03oool0oooo01X0oooo00<0P820000000000000
3P00000j0?ooo`005P3oool01@20P8000000000000000000@4100240oooo00<0P820000000000000
2P0000350?ooo``0000000<0@4100?ooo`3oool0903oool01@10@4000000000000000000P82001/0
oooo00<0P8200000000000002P0000020820P3`0oooo000H0?ooo`@00000803oool00`20P8000000
0000000:00000<D0oooo3P00000V0?ooo`@00000703oool9000000030820P03oool0oooo03h0oooo
000H0?ooo`030820P00000000000008000007`3oool00`20P80000000000000:00000<D0oooo3`00
000V0?ooo`<00000703oool7000004<0oooo000I0?ooo`050820P0000000000000000010@4007P3o
ool00`20P80000000000000:00000<D0oooo3`0000000`10@400oooo0?ooo`0T0?ooo`030410@000
0000oooo01`0oooo0P0000020820P4D0oooo000J0?ooo`030820P00000000000008000007@3oool0
0`20P80000000000000:00000<D0oooo4@00000V0?ooo`030000003oool0oooo06@0oooo000K0?oo
o`030820P000000000000080000000<0`<300?ooo`3oool06@3oool00`20P80000000000000:0000
0<D0oooo300000020820P0<0000000<0@4100?ooo`3oool0GP3oool00`10@4000000000000020820
P0d0oooo00D0@410000000000000@4100820P00E0?ooo`007@3oool4000001/0oooo00<0P8200000
000000002P0000350?ooo``0000000<0P8200?ooo`3oool01000001O0?ooo`D0000000<0P8200?oo
o`3oool02@3oool6000000030820P03oool0oooo0180oooo000M0?ooo`030820P000000000000080
00006P3oool00`20P80000000000000:00000<D0oooo300000001020P800oooo0?ooo`20P8040000
05h0oooo1P00000;0?ooo`L00000503oool001h0oooo00D0P82000000000000000000410@00I0?oo
o`030820P0000000000000X00000a@3oool<000000050820P03oool0oooo0?ooo`20P8000`000000
0`10@400oooo0?ooo`1K0?ooo`L0000000<0P8200?ooo`3oool01P3oool00`20P800000000000006
000000030820P03oool0oooo0100oooo000P0?ooo`@00000603oool00`20P80000000000000:0000
0<D0oooo300000000`20P800oooo0?ooo`020?ooo`030820P0000000000000800000G03oool30000
0080oooo00@0P820000000000000P8201`3oool00`20P800000000000002000000030820P03oool0
P8200080000000<0P8200?ooo`3oool03`3oool00200oooo00<0P8200000000000000P00000G0?oo
o`030820P0000000000000X00000a@3oool<000000030820P03oool0oooo00<0oooo1@00001K0?oo
o`80000000@0P8200?ooo`3oool0oooo0P0000000`20P800oooo0?ooo`050?ooo`D0000000<0P820
0?ooo`3oool00P0000000`20P800oooo0?ooo`0?0?ooo`008@3oool01@20P8000000000000000000
@41001H0oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool0103oool0
1@20P8000000000000000000@41005X0oooo0P20P8050?ooo`80000000<0P8200?ooo`3oool0103o
ool5000000070<30`03oool0oooo0?ooo`20P80000000820P00@0?ooo`008P3oool00`20P8000000
00000002000001D0oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool0
1@3oool00`20P80000000000000200000640oooo0P0000060?ooo`D000001@3oool00`20P8000000
0?ooo`0?0?ooo`008`3oool00`20P800000000000002000000030<30`03oool0oooo0140oooo00<0
P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool01P3oool01@20P80000000000
00000000@4100600oooo00<0`<3000000010@400103oool6000000H0oooo00<000000820P03oool0
3P3oool002D0oooo1000000C0?ooo`030820P0000000000000X00000a@3oool<000000030820P03o
ool0oooo00P0oooo1000001P0?ooo`800000103oool5000001P0oooo000U0?ooo`030820P0000000
0000008000004P3oool00`20P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`08
0?ooo`030820P0000000000000800000H03oool2000000<0oooo1@00000H0?ooo`009P3oool01@20
P8000000000000000000@4100140oooo00<0P8200000000000002P0000350?ooo``0000000<0P820
0?ooo`3oool02@3oool01@20P8000000000000000000@41005l0oooo00@0P82000000020P800oooo
1@0000000`20P800oooo0?ooo`0F0?ooo`00:03oool400000100oooo00<0P8200000000000002P00
00350?ooo``0000000<0P8200?ooo`3oool02P3oool00`20P800000000000002000005l0oooo0P00
00000`3oool0000000000003000001T0oooo000X0?ooo`030820P00000000000008000003`3oool0
0`20P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`0;0?ooo`@0000000<0P820
0?ooo`3oool0G03oool2000000030820P0000000000000<000006@3oool002T0oooo00D0P8200000
0000000000000410@00>0?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0
oooo00`0oooo00D0P82000000000000000000820P01N0?ooo`030820P0000000000000<0000000<0
@4100?ooo`3oool05`3oool002X0oooo00<0P8200000000000000P00000=0?ooo`030820P0000000
000000X00000a@3oool<000000030820P03oool0oooo00d0oooo00<0P8200000000000000P00001N
0?ooo`D0000000<0P8200?ooo`3oool05`3oool002/0oooo00D0P82000000000000000000410@00<
0?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0oooo00h0oooo00D0P820
00000000000000000410@01M0?ooo`030410@000000000000080000000<0P8200?ooo`3oool05`3o
ool002d0oooo1000000;0?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0
oooo00l0oooo00<0P8200000000000000P00001L0?ooo`D000006P3oool002d0oooo00<0P8200000
000000000P00000:0?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0oooo
0100oooo1@00001K0?ooo`D000006P3oool002h0oooo00D0P82000000000000000000410@0090?oo
o`030820P0000000000000X00000a@3oool<000000030820P03oool0oooo0140oooo00D0P8200000
0000000000000410@01I0?ooo`D0000000<0P8200?ooo`3oool0603oool002l0oooo00<0P8200000
000000000P0000080?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0oooo
0180oooo00<0P8200000000000000P00001H0?ooo`H000006P3oool00300oooo00<0P82000000000
00000P0000000`30`<00oooo0?ooo`040?ooo`030820P0000000000000X00000a@3oool<00000003
0820P03oool0oooo01<0oooo00D0P82000000000000000000410@01F0?ooo`030820P00000000000
00@0000000<0P8200?ooo`3oool05`3oool00380oooo100000060?ooo`030820P0000000000000X0
0000a@3oool<000000030820P03oool0oooo01D0oooo1000001E0?ooo`D0000000<0P82000000000
00006@3oool00380oooo00<0P8200000000000000P0000050?ooo`030820P0000000000000X00000
a@3oool<000000030820P03oool0oooo01D0oooo00<0P8200000000000000P00001D0?ooo`D00000
00@0P8200?ooo`0000000000603oool003<0oooo00D0P82000000000000000000410@0040?ooo`03
0820P0000000000000X00000a@3oool<000000030820P03oool0oooo01H0oooo00D0P82000000000
000000000410@01B0?ooo`030820P0000000000000<0000000D0P8200?ooo`10@40000000820P00G
0?ooo`00=@3oool4000000<0oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?oo
o`3oool05`3oool00`20P80000000000000200000540oooo00<0P8200000000000000`0000030?oo
o`80000000<0P8200?ooo`3oool0503oool003D0oooo00<0P8200000000000000P0000020?ooo`03
0820P0000000000000X00000a@3oool<000000030820P03oool0oooo01P0oooo100000000`20P800
oooo0?ooo`1>0?ooo`H000000`3oool3000001H0oooo000f0?ooo`070820P0000000000000000010
@400oooo0820P00<00000<D0oooo300000000`20P800oooo0?ooo`0I0?ooo`050820P00000000000
00000020P800CP3oool00`20P800000000000003000000030820P03oool0oooo0080oooo00@0P820
000000000000`<300P3oool01@20P8000000000000000000P82000d0oooo000g0?ooo`030820P000
000000000080000000<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool06P3o
ool00`20P800000000000002000004`0oooo00<0P820000000000000100000060?ooo`030820P000
0000000000L0000000<0P8200?ooo`3oool02P3oool003P0oooo00<0P8200000000000003P000035
0?ooo``0000000<0P8200?ooo`3oool06`3oool01@20P8000000000000000000@41004D0oooo00<0
`<300820P020P8000P20P807000000030820P03oool0oooo00@0oooo00<0`<300000000000001`00
00000`20P800oooo0?ooo`0:0?ooo`00>P3oool?00000<D0oooo300000000`20P800oooo0?ooo`0L
0?ooo`030820P0000000000000800000A03oool00`20P800000000000009000000T0oooo20000000
0`20P800oooo0?ooo`0:0?ooo`00>P3oool00`20P80000000000000<00000<D0oooo300000000`20
P800oooo0?ooo`0M0?ooo`D00000A@3oool9000000030820P03oool0oooo00P0oooo1`0000000`20
P800oooo0?ooo`0:0?ooo`005@3oool00`30`<00oooo0?ooo`0S0?ooo`030820P0000000000000/0
0000a@3oool<000000030820P03oool0oooo01h0oooo00D0P82000000000000000000410@0180?oo
o`80P82000<0@410000000000000303oool00`20P800@41000000002000000030820P03oool0oooo
00/0oooo000E0?ooo`030000003oool0oooo02@0oooo00<0P8200000000000002P0000350?ooo``0
000000<0P8200?ooo`3oool07`3oool00`20P800000000000002000006/0oooo000E0?ooo`800000
9@3oool00`20P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`0P0?ooo`@00000
00<0P8200?ooo`3oool0J03oool001D0oooo0`0000000`30`<00oooo0?ooo`0Q0?ooo`030820P000
0000000000X00000a@3oool<000000030820P03oool0oooo0240oooo00D0P8200000000000000000
0820P01Y0?ooo`005@3oool01020P800000000000000000S0?ooo`030820P0000000000000X00000
a@3oool<000000030820P03oool0oooo0280oooo00<0P8200000000000000P00001X0?ooo`005P3o
ool01@20P8000000000000000000`<300240oooo00<0P8200000000000002P0000350?ooo``00000
00<0P8200?ooo`3oool08`3oool01@20P8000000000000000000@41006L0oooo000H0?ooo`<00000
8@3oool00`20P80000000000000:00000<D0oooo3@00000V0?ooo`030820P0000000000000800000
IP3oool001P0oooo00@0P8200000000000000000803oool00`20P80000000000000:00000<D0oooo
3P00000V0?ooo`@00000IP3oool001T0oooo00D0P82000000000000000000<30`00N0?ooo`030820
P0000000000000X00000a@3oool?000000030<30`03oool0oooo02<0oooo00<0P820000000000000
IP3oool001X0oooo00@0P82000000000000000007P3oool00`20P80000000000000:00000<D0oooo
4000000V0?ooo`030820P0000000oooo06D0oooo000K0?ooo`050820P0000000000000000020P800
703oool00`20P80000000000000:00000<D0oooo300000000`10@400000000000002000000030<30
`03oool0oooo02<0oooo00<0P8200?ooo`3oool0I03oool001d0oooo0`0000000`20P800oooo0?oo
o`0I0?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0000000<00000S03o
ool001d0oooo00@0P82000000000000000006`3oool00`20P80000000000000:00000<D0oooo3000
00000`20P800oooo0?ooo`04000008/0oooo000N0?ooo`050820P0000000000000000030`<006@3o
ool00`20P80000000000000:00000<D0oooo300000001020P800oooo0?ooo`30`<04000000030<30
`03oool0oooo08L0oooo000P0?ooo`<000006@3oool00`20P80000000000000:00000<D0oooo3000
00000`20P800oooo0?ooo`020?ooo`@00000R@3oool00200oooo00@0P8200000000000000000603o
ool00`20P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`020?ooo`030820P000
0000000000800000R03oool00240oooo00D0P82000000000000000000<30`00F0?ooo`030820P000
0000000000X00000a@3oool<000000030820P03oool0oooo00<0oooo00<0P8200000000000000P00
00000`30`<00oooo0?ooo`240?ooo`008P3oool01020P800000000000000000F0?ooo`030820P000
0000000000X00000a@3oool<000000030820P03oool0oooo00D0oooo100000260?ooo`008`3oool0
1@20P8000000000000000000P82001@0oooo00<0P8200000000000002P0000350?ooo``0000000<0
P8200?ooo`3oool01@3oool00`30`<00000000000002000000030<30`03oool0oooo0880oooo000U
0?ooo`<0000000<0P8200?ooo`3oool04@3oool00`20P80000000000000:00000<D0oooo30000000
0`20P800oooo0?ooo`070?ooo`@00000Q03oool002D0oooo00@0P82000000000000000004`3oool0
0`20P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`080?ooo`@00000P`3oool0
02H0oooo00D0P82000000000000000000<30`00A0?ooo`030820P0000000000000X00000a@3oool<
000000030820P03oool0oooo00P0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`1o
0?ooo`00:03oool300000140oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?oo
o`3oool02P3oool400000840oooo000X0?ooo`040820P0000000000000000100oooo00<0P8200000
000000002P0000350?ooo``0000000<0P8200?ooo`3oool02P3oool00`20P8000000000000020000
0800oooo000Y0?ooo`050820P0000000000000000030`<003P3oool00`20P80000000000000:0000
0<D0oooo300000000`20P800oooo0?ooo`0;0?ooo`050820P0000000000000000010@400O`3oool0
02X0oooo00@0P82000000000000000003P3oool00`20P80000000000000:00000<D0oooo30000000
0`20P800oooo0?ooo`0=0?ooo`@00000OP3oool002/0oooo00D0P82000000000000000000<30`00<
0?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0oooo00d0oooo00<0`<30
0000000000000P0000000`30`<00oooo0?ooo`1j0?ooo`00;@3oool3000000`0oooo00<0P8200000
000000002P0000350?ooo``0000000<0P8200?ooo`3oool03`3oool4000007`0oooo000]0?ooo`04
0820P00000000000000000/0oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?oo
o`3oool03`3oool00`20P800000000000002000007/0oooo000^0?ooo`050820P000000000000000
0030`<002@3oool00`20P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`0@0?oo
o`030820P000000000000080000000<0`<300?ooo`3oool0M`3oool002l0oooo00@0P82000000000
000000002@3oool00`20P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`0B0?oo
o`@00000N@3oool00300oooo00D0P82000000000000000000820P0070?ooo`030820P00000000000
00X00000a@3oool<000000030820P03oool0oooo0180oooo00<0`<300000000000000P0000000`30
`<00oooo0?ooo`1e0?ooo`00<P3oool3000000030820P03oool0oooo00@0oooo00<0P82000000000
00002P0000350?ooo``0000000<0P8200?ooo`3oool0503oool4000007L0oooo000b0?ooo`040820
P00000000000000000H0oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3o
ool05@3oool4000007H0oooo000c0?ooo`050820P0000000000000000030`<00103oool00`20P800
00000000000:00000<D0oooo300000000`20P800oooo0?ooo`0E0?ooo`030<30`000000000000080
000000<0`<300?ooo`3oool0LP3oool003D0oooo0`0000040?ooo`030820P0000000000000X00000
a@3oool<000000030820P03oool0oooo01L0oooo1000001d0?ooo`00=@3oool01020P80000000000
000000030?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0oooo01L0oooo
00<0P8200000000000000P00001c0?ooo`00=P3oool01`20P8000000000000000000`<300?ooo`20
P800300000350?ooo``0000000<0P8200?ooo`3oool0603oool01@20P8000000000000000000@410
0780oooo000g0?ooo`060820P000000000000000003oool0P820300000350?ooo``0000000<0P820
0?ooo`3oool06P3oool400000740oooo000h0?ooo`050820P0000000000000000010@40030000035
0?ooo``0000000<0P8200?ooo`3oool06P3oool00`30`<00000000000002000000030<30`03oool0
oooo06d0oooo000j0?ooo`l00000a@3oool<000000030820P03oool0oooo01`0oooo1000001_0?oo
o`00>P3oool00`20P80000000000000<00000<D0oooo300000000`20P800oooo0?ooo`0L0?ooo`03
0820P0000000000000800000KP3oool003/0oooo00<0P8200000000000002`0000350?ooo``00000
00<0P8200?ooo`3oool07@3oool00`20P800000000000002000000030<30`03oool0oooo06X0oooo
000E0?ooo`030820P03oool0oooo02@0oooo00<0P8200000000000002P0000350?ooo``0000000<0
P8200?ooo`3oool07`3oool4000006`0oooo000E0?ooo`030000003oool0oooo02@0oooo00<0P820
0000000000002P0000350?ooo``0000000<0P8200?ooo`3oool07`3oool00`20P800000000000002
000006/0oooo000E0?ooo`80000000<0P8200?ooo`3oool08P3oool00`20P80000000000000:0000
0<D0oooo300000000`20P800oooo0?ooo`0P0?ooo`050820P0000000000000000010@400JP3oool0
01D0oooo0`0000000`20P800oooo0?ooo`0Q0?ooo`030820P0000000000000X00000a@3oool<0000
00030820P03oool0oooo0280oooo1000001Y0?ooo`005@3oool01@30`<000000000000000000P820
0280oooo00<0P8200000000000002P00001T0?ooo`030<30`03oool0oooo05h0oooo300000000`20
P800oooo0?ooo`0R0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0I@3oool001L0
oooo0`0000000`20P800oooo0?ooo`0O0?ooo`030820P0000000000000X00000I03oool00`20P800
oooo0?ooo`1N0?ooo``0000000<0P8200?ooo`3oool0903oool4000006L0oooo000H0?ooo`<00000
8@3oool00`20P80000000000000:000006@0oooo00<0P8200?ooo`3oool0GP3oool=000002H0oooo
00<0P8200000000000000P00001V0?ooo`00603oool01@30`<000000000000000000P82001l0oooo
00<0P8200000000000002P00001T0?ooo`030410@0000000oooo05h0oooo3P0000000`20P800oooo
0?ooo`0S0?ooo`040820P00000000000000006H0oooo000J0?ooo`<0000000<0P8200?ooo`3oool0
703oool00`20P80000000000000:000006@0oooo0P00001O0?ooo`l0000000<0P8200?ooo`3oool0
903oool2000006H0oooo000J0?ooo`050<30`0000000000000000020P8007@3oool00`20P8000000
0000000:00000680oooo00D0P82000000000000000000<30`01N0?oooa00000000<0P8200?ooo`3o
ool08`3oool00`30`<0000000?ooo`1U0?ooo`00703oool4000001`0oooo00<0P820000000000000
2P00001R0?ooo`@0000000<0P8200?ooo`3oool0G03oool<000000030820P0000000000000800000
00<0P8200?ooo`3oool0RP3oool001d0oooo0`0000000`20P800oooo0?ooo`0I0?ooo`030820P000
0000000000X00000HP3oool4000000030820P03oool0oooo05`0oooo300000000`20P800oooo0000
0003000008`0oooo000M0?ooo`050<30`0000000000000000020P8006P3oool00`20P80000000000
000:00000640oooo00<0`<300000000000000`00001N0?ooo``0000000@0P8200?ooo`3oool0@410
0`0000000`20P800oooo0?ooo`280?ooo`007`3oool3000000030820P03oool0oooo01L0oooo00<0
P8200000000000002P00001Q0?ooo`030820P0000000000000<00000GP3oool<000000040820P03o
ool0oooo0?ooo`@0000000<0P8200?ooo`3oool0Q`3oool00200oooo0`00000I0?ooo`030820P000
0000000000X00000H@3oool00`20P800000000000004000005d0oooo300000000`20P800oooo0?oo
o`020?ooo`@00000R@3oool00200oooo00D0`<3000000000000000000820P00G0?ooo`030820P000
0000000000X00000H@3oool7000005d0oooo300000000`20P800oooo0?ooo`020?ooo`030<30`000
000000000080000000<0P8200?ooo`3oool0Q@3oool00280oooo0`0000000`20P800oooo0?ooo`0D
0?ooo`030820P0000000000000X00000H@3oool7000005d0oooo300000000`20P800oooo0?ooo`04
0?ooo`@0000000<0P8200?ooo`3oool0Q03oool00280oooo00D0`<3000000000000000000820P00E
0?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`05
0?ooo`050410@0000000000000000020P800Q@3oool002@0oooo1000000D0?ooo`030820P0000000
000000X00000G`3oool:000005`0oooo300000000`20P800oooo0?ooo`060?ooo`@0000000<0P820
0?ooo`3oool0PP3oool002D0oooo0`0000000`20P800oooo0?ooo`0A0?ooo`030820P00000000000
00X00000G`3oool:000000030820P03oool0oooo05T0oooo300000000`20P800oooo0?ooo`070?oo
o`@00000Q03oool002D0oooo00D0`<3000000000000000000820P00B0?ooo`030820P00000000000
00X00000GP3oool00`30`<00000000000008000000030820P03oool0oooo05T0oooo300000000`20
P800oooo0?ooo`080?ooo`050410@0000000000000000020P800PP3oool002L0oooo0`0000000`20
P800oooo0?ooo`0?0?ooo`030820P0000000000000X00000GP3oool00`20P8000000000000090000
05/0oooo300000000`20P800oooo0?ooo`090?ooo`@0000000<0P8200?ooo`3oool0O`3oool002P0
oooo0`00000A0?ooo`030820P0000000000000X00000GP3oool00`20P800000000000009000005/0
oooo300000000`20P800oooo0?ooo`0:0?ooo`@00000P@3oool002P0oooo00D0`<30000000000000
00000820P00?0?ooo`030820P0000000000000X00000GP3oool<000005/0oooo300000000`20P800
oooo0?ooo`0:0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0O@3oool002X0oooo
0`0000000`20P800oooo0?ooo`0<0?ooo`030820P0000000000000X00000GP3oool=000005X0oooo
300000000`20P800oooo0?ooo`0<0?ooo`@00000O`3oool002X0oooo00D0`<300000000000000000
0820P00=0?ooo`030820P0000000000000X00000G@3oool>000005X0oooo300000000`20P800oooo
0?ooo`0=0?ooo`050410@0000000000000000020P800O@3oool002`0oooo0`0000000`20P800oooo
0?ooo`0:0?ooo`030820P0000000000000X00000G03oool00`20P80000000000000<000000030820
P03oool0oooo05L0oooo300000000`20P800oooo0?ooo`0>0?ooo`@0000000<0P8200?ooo`3oool0
NP3oool002d0oooo0`00000<0?ooo`030820P0000000000000X00000G03oool00`20P80000000000
000<000000030820P03oool0oooo05L0oooo300000000`20P800oooo0?ooo`0?0?ooo`@00000O03o
ool002d0oooo00D0`<3000000000000000000820P00:0?ooo`030820P0000000000000X00000G03o
ool00`20P80000000000000<000000030410@03oool0oooo05L0oooo300000000`20P800oooo0?oo
o`0?0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0N03oool002l0oooo0`000000
0`20P800oooo0?ooo`070?ooo`030820P0000000000000X00000G03oool@000005T0oooo30000000
0`20P800oooo0?ooo`0A0?ooo`@0000000<0P8200?ooo`3oool0M`3oool002l0oooo00D0`<300000
0000000000000820P0080?ooo`030820P0000000000000X00000G03oool@000005T0oooo30000000
0`20P800oooo0?ooo`0B0?ooo`050410@0000000000000000020P800N03oool00340oooo10000007
0?ooo`030820P0000000000000X00000F`3ooolB000005P0oooo300000000`20P800oooo0?ooo`0C
0?ooo`@0000000<0P8200?ooo`3oool0M@3oool00380oooo0`0000000`20P800oooo0?ooo`040?oo
o`030820P0000000000000X00000F`3ooolB000005P0oooo300000000`20P800oooo0?ooo`0D0?oo
o`@00000M`3oool00380oooo00D0`<3000000000000000000820P0050?ooo`030820P00000000000
00X00000FP3oool00`20P80000000000000@000000030820P03oool0oooo05D0oooo300000000`20
P800oooo0?ooo`0E0?ooo`050410@0000000000000000020P800M@3oool003@0oooo0`0000000`20
P800oooo0?ooo`020?ooo`030820P0000000000000X00000FP3ooolD000005L0oooo300000000`20
P800oooo0?ooo`0F0?ooo`@0000000<0P8200?ooo`3oool0LP3oool003D0oooo0`0000040?ooo`03
0820P0000000000000X00000FP3ooolD000005L0oooo300000000`20P800oooo0?ooo`0G0?ooo`@0
0000M03oool003D0oooo00D0`<3000000000000000000820P0020?ooo`030820P0000000000000X0
0000F@3oool00`30`<0000000000000B000000030820P03oool0oooo05@0oooo300000000`20P800
oooo0?ooo`0G0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0L03oool003L0oooo
0`0000000`20P800oooo0820P00<000005T0oooo00<0P8200000000000004P0000000`20P800oooo
0?ooo`1D0?ooo``0000000<0P8200?ooo`3oool06@3oool400000780oooo000g0?ooo`040<30`000
0000000000000080P8203000001I0?ooo`030410@000000000000180000000<0@4100?ooo`3oool0
E03oool<000000030820P03oool0oooo01X0oooo00D0@41000000000000000000820P01`0?ooo`00
>@3oool@000005T0oooo5P00001F0?ooo``0000000<0P8200?ooo`3oool06`3oool4000000030820
P03oool0oooo06d0oooo000j0?ooo`l00000F@3ooolF000005H0oooo300000000`20P800oooo0?oo
o`0L0?ooo`@00000K`3oool003X0oooo00<0`<300000000000003000001H0?ooo`030820P0000000
000001D00000E@3oool<000000030820P03oool0oooo01`0oooo00<0`<300000000000000P000000
0`20P800oooo0?ooo`1[0?ooo`005@3oool00`20P800oooo0?ooo`0T0?ooo`d00000F03ooolH0000
05D0oooo300000000`20P800oooo0?ooo`0N0?ooo`@0000000<0P8200?ooo`3oool0JP3oool001D0
oooo00<000000?ooo`3oool0903oool00`20P80000000000000:000005P0oooo1`0000000`3oool0
000000000007000000030?ooo`000000000000D00000E03oool<000000030820P03oool0oooo01l0
oooo1000001/0?ooo`005@3oool2000000030820P03oool0oooo0280oooo00<0P820000000000000
2P00001G0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool02@0000020?ooo`030410
@0000000000000<00000E03oool<000000030820P03oool0oooo01l0oooo00<0`<30000000000000
0P0000000`30`<00oooo0?ooo`1X0?ooo`005@3oool3000000030820P03oool0oooo0240oooo00<0
P8200000000000002P00001G0?ooo`030820P000000000000080000000@0P8200?ooo`3oool0oooo
2@0000030?ooo`D00000E03oool<000000030820P03oool0oooo0240oooo1000001Z0?ooo`005@3o
ool01@10@4000000000000000000P8200280oooo00<0P8200000000000002P00001G0?ooo`@00000
00<0P8200?ooo`3oool00P3oool9000000@0oooo00D0P82000000000000000000820P01C0?ooo``0
000000<0P8200?ooo`3oool08P3oool01@10@4000000000000000000P82006P0oooo000F0?ooo`@0
000000<0P8200?ooo`3oool07`3oool00`20P80000000000000:000005L0oooo100000050?ooo`T0
00001@3oool01020P800000000000020P81C0?ooo``0000000<0P8200?ooo`3oool08`3oool40000
00030820P03oool0oooo06D0oooo000G0?ooo`@000008@3oool00`20P80000000000000:000005L0
oooo0`0000060?ooo`T000001@3oool01020P800000000000000001C0?ooo``0000000<0P8200?oo
o`3oool0903oool4000006L0oooo000H0?ooo`050410@0000000000000000020P8007`3oool00`20
P80000000000000:000005H0oooo00@0P820000000000000`<301P3oool9000000H0oooo00<0P820
000000000000D`3oool=000000030820P03oool0oooo02<0oooo00<0`<300000000000000P00001V
0?ooo`006@3oool4000000030820P03oool0oooo01`0oooo00<0P8200000000000002P00001F0?oo
o`800000203oool9000000P0oooo0P00001B0?ooo`l000009P3oool3000006H0oooo000J0?ooo`05
0410@0000000000000000020P8007@3oool00`20P80000000000000:000005H0oooo00<000000820
P03oool01`3oool9000000P0oooo00<0`<300000003oool0D@3oool?000000030410@03oool0oooo
02@0oooo00<0@4100000003oool0I@3oool001/0oooo1@00000L0?ooo`030820P0000000000000X0
0000E@3oool2000000T0oooo2@0000090?ooo`030000003oool0oooo0500oooo4@00000V0?ooo`03
0000003oool0oooo06@0oooo000L0?ooo`@0000000<0P8200?ooo`3oool06@3oool00`20P8000000
0000000:000005D0oooo00<000000?ooo`3oool0203oool9000000X0oooo00<0P8200?ooo`3oool0
C`3oool<000000030820P000000000000080000000<0P8200?ooo`3oool0RP3oool001d0oooo00D0
@41000000000000000000820P00J0?ooo`030820P0000000000000X00000E@3oool00`20P800oooo
0?ooo`080?ooo`T000002P3oool00`30`<00oooo0?ooo`1?0?ooo``0000000<0P8200?ooo`20P800
0`0000000`20P800oooo0?ooo`290?ooo`007P3oool4000000030820P03oool0oooo01L0oooo00<0
P8200000000000002P00001P0?ooo`T000002P3oool00`20P800oooo0?ooo`1?0?ooo``0000000@0
P8200?ooo`3oool0P8201000002:0?ooo`007`3oool4000001T0oooo00<0P8200000000000002P00
001P0?ooo`T00000G03oool<000000040820P03oool0oooo0?ooo`@0000000<0P8200?ooo`3oool0
Q`3oool00200oooo00D0@41000000000000000000820P00G0?ooo`030820P0000000000000X00000
H03oool9000005`0oooo300000000`20P800oooo0?ooo`020?ooo`050410@0000000000000000020
P800R03oool00240oooo100000000`20P800oooo0?ooo`0D0?ooo`030820P0000000000000X00000
H03oool9000005`0oooo300000000`20P800oooo0?ooo`030?ooo`D00000Q`3oool00280oooo00D0
@41000000000000000000820P00E0?ooo`030820P0000000000000X00000H03oool9000005`0oooo
300000000`20P800oooo0?ooo`040?ooo`050820P0000000000000000010@400QP3oool002<0oooo
1@00000D0?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000000`20P800oooo
0?ooo`050?ooo`030820P0000000000000800000Q@3oool002@0oooo100000000`20P800oooo0?oo
o`0A0?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000000`20P800oooo0?oo
o`060?ooo`@0000000<0P8200?ooo`3oool0PP3oool002D0oooo00D0@41000000000000000000820
P00B0?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000000`20P800oooo0?oo
o`070?ooo`050820P0000000000000000020P800P`3oool002H0oooo100000000`20P800oooo0?oo
o`0?0?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000000`20P800oooo0?oo
o`080?ooo`030820P0000000000000800000PP3oool002L0oooo1000000A0?ooo`030820P0000000
000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`090?ooo`@0000000<0P820
0?ooo`3oool0O`3oool002P0oooo00D0@41000000000000000000820P00?0?ooo`030820P0000000
000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0:0?ooo`050410@0000000
000000000020P800P03oool002T0oooo100000000`20P800oooo0?ooo`0<0?ooo`030820P0000000
000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0;0?ooo`@0000000<0P820
0?ooo`3oool0O@3oool002X0oooo00D0@41000000000000000000820P00=0?ooo`030820P0000000
000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0<0?ooo`050820P0000000
000000000020P800OP3oool002/0oooo100000000`20P800oooo0?ooo`0:0?ooo`030820P0000000
000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0=0?ooo`030820P0000000
000000800000O@3oool002`0oooo1000000<0?ooo`030820P0000000000000X00000H03oool90000
05`0oooo300000000`20P800oooo0?ooo`0>0?ooo`@0000000<0P8200?ooo`3oool0NP3oool002d0
oooo00D0@41000000000000000000820P00:0?ooo`030820P0000000000000X00000H03oool90000
05`0oooo300000000`20P800oooo0?ooo`0?0?ooo`050410@0000000000000000020P800N`3oool0
02h0oooo100000000`20P800oooo0?ooo`070?ooo`030820P0000000000000X00000H03oool90000
05`0oooo300000000`20P800oooo0?ooo`0@0?ooo`D00000NP3oool002l0oooo00D0@41000000000
000000000820P0080?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000000`20
P800oooo0?ooo`0A0?ooo`050820P0000000000000000010@400N@3oool00300oooo1@0000070?oo
o`030820P0000000000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0B0?oo
o`030820P0000000000000800000N03oool00340oooo100000000`20P800oooo0?ooo`040?ooo`03
0820P0000000000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0C0?ooo`@0
000000<0P8200?ooo`3oool0M@3oool00380oooo00D0@41000000000000000000820P0050?ooo`03
0820P0000000000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0D0?ooo`05
0820P0000000000000000020P800MP3oool003<0oooo100000000`20P800oooo0?ooo`020?ooo`03
0820P0000000000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0E0?ooo`03
0820P0000000000000800000M@3oool003@0oooo100000040?ooo`030820P0000000000000X00000
H03oool9000005`0oooo300000000`20P800oooo0?ooo`0F0?ooo`@0000000<0P8200?ooo`3oool0
LP3oool003D0oooo00D0@41000000000000000000820P0020?ooo`030820P0000000000000X00000
H03oool9000005`0oooo300000000`20P800oooo0?ooo`0G0?ooo`050410@0000000000000000020
P800L`3oool003H0oooo100000000`20P800oooo0820P00<00000600oooo2@00001L0?ooo``00000
00<0P8200?ooo`3oool0603oool4000000030820P03oool0oooo0700oooo000g0?ooo`040410@000
0000000000000080P8203000001P0?ooo`T00000G03oool<000000030820P03oool0oooo01T0oooo
00D0P82000000000000000000820P01a0?ooo`00>03ooolA00000600oooo2@00001L0?ooo``00000
00<0P8200?ooo`3oool06P3oool00`20P80000000000000200000700oooo000i0?oooa000000H03o
ool9000005`0oooo300000000`20P800oooo0?ooo`0K0?ooo`@0000000<0P8200?ooo`3oool0K@3o
ool003X0oooo00<0@4100000000000003000001P0?ooo`T00000G03oool<000000030820P03oool0
oooo01`0oooo00D0@41000000000000000000820P01^0?ooo`00>`3oool>00000600oooo2@00001L
0?ooo``0000000<0P8200?ooo`3oool07@3oool5000006d0oooo000E0?ooo`030410@03oool0oooo
02@0oooo00<0@4100000000000002P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo
01h0oooo00D0P82000000000000000000410@01/0?ooo`005@3oool2000002D0oooo00<0P8200000
000000002P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo01l0oooo00<0P8200000
000000000P00001[0?ooo`005@3oool3000002@0oooo00<0P8200000000000002P00001P0?ooo`T0
0000G03oool<000000030820P03oool0oooo0200oooo100000000`20P800oooo0?ooo`1X0?ooo`00
5@3oool3000000030410@03oool0oooo0240oooo00<0P8200000000000002P00001P0?ooo`T00000
G03oool<000000030820P03oool0oooo0240oooo00D0P82000000000000000000820P01Y0?ooo`00
5@3oool00`20P80000000000000200000280oooo00<0P8200000000000002P00001P0?ooo`T00000
G03oool<000000030820P03oool0oooo0280oooo00<0P8200000000000000P00001X0?ooo`005P3o
ool4000000030820P03oool0oooo01l0oooo00<0P8200000000000002P00001P0?ooo`T00000G03o
ool<000000030820P03oool0oooo02<0oooo100000000`20P800oooo0?ooo`1U0?ooo`005`3oool0
1@20P8000000000000000000P8200200oooo00<0P8200000000000002P00001P0?ooo`T00000G03o
ool<000000030410@03oool0oooo02@0oooo00D0@41000000000000000000820P01V0?ooo`00603o
ool00`20P800000000000002000001l0oooo00<0P8200000000000002P00001P0?ooo`T00000G03o
ool>000002H0oooo1000001V0?ooo`006@3oool01@20P8000000000000000000@41001h0oooo00<0
P8200000000000002P00001P0?ooo`T00000G03oool?000000030<30`03oool0oooo02<0oooo00<0
P820000000000000IP3oool001X0oooo00<0P8200000000000000P00000M0?ooo`030820P0000000
000000X00000H03oool9000005`0oooo4000000V0?ooo`030820P0000000oooo06D0oooo000K0?oo
o`D00000703oool00`20P80000000000000:00000600oooo2@00001L0?oooa4000009P3oool00`00
0000oooo0?ooo`1T0?ooo`00703oool01@20P8000000000000000000@41001/0oooo00<0P8200000
000000002P00001P0?ooo`T00000G03oool<00000080P8200`0000000`10@400oooo0?ooo`2:0?oo
o`007@3oool00`20P800000000000002000001X0oooo00<0P8200000000000002P00001P0?ooo`T0
0000G03oool<000000030820P03oool0oooo00@00000R`3oool001h0oooo100000000`20P800oooo
0?ooo`0G0?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000001020P800oooo
0?ooo`20P804000008X0oooo000O0?ooo`050820P0000000000000000020P800603oool00`20P800
00000000000:00000600oooo2@00001L0?ooo``0000000D0P8200?ooo`3oool0oooo0820P0030000
00030410@03oool0oooo08L0oooo000P0?ooo`030820P00000000000008000005`3oool00`20P800
00000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool00P3oool00`20P800
000000000002000008P0oooo000Q0?ooo`050820P0000000000000000010@4005P3oool00`20P800
00000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool00`3oool00`20P800
000000000002000000030<30`03oool0oooo08@0oooo000R0?ooo`030820P0000000000000800000
5@3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool0
1@3oool4000008H0oooo000S0?ooo`D00000503oool00`20P80000000000000:00000600oooo2@00
001L0?ooo``0000000<0P8200?ooo`3oool01@3oool00`20P800000000000002000008D0oooo000T
0?ooo`050820P0000000000000000010@4004`3oool00`20P80000000000000:00000600oooo2@00
001L0?ooo``0000000<0P8200?ooo`3oool01P3oool01@20P8000000000000000000@41008@0oooo
000U0?ooo`030820P00000000000008000004P3oool00`20P80000000000000:00000600oooo2@00
001L0?ooo``0000000<0P8200?ooo`3oool0203oool4000008<0oooo000V0?ooo`050820P0000000
000000000010@4004@3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0
P8200?ooo`3oool0203oool00`30`<00000000000002000000030<30`03oool0oooo07l0oooo000X
0?ooo`@00000403oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P820
0?ooo`3oool02P3oool400000840oooo000X0?ooo`030820P00000000000008000003`3oool00`20
P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool02P3oool00`20
P80000000000000200000800oooo000Y0?ooo`050820P0000000000000000010@4003P3oool00`20
P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool02`3oool01@20
P8000000000000000000@41007l0oooo000Z0?ooo`030820P00000000000008000003@3oool00`20
P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool03@3oool40000
07h0oooo000[0?ooo`@0000000<0P8200?ooo`3oool02P3oool00`20P80000000000000:00000600
oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool03@3oool00`20P800000000000002000007d0
oooo000/0?ooo`050820P0000000000000000020P8002`3oool00`20P80000000000000:00000600
oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool03P3oool01@20P8000000000000000000@410
07`0oooo000]0?ooo`030820P00000000000008000002P3oool00`20P80000000000000:00000600
oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool03`3oool00`20P800000000000002000007/0
oooo000^0?ooo`050820P0000000000000000010@4002@3oool00`20P80000000000000:00000600
oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool0403oool00`20P80000000000000200000003
0<30`03oool0oooo07L0oooo000_0?ooo`030820P0000000000000800000203oool00`20P8000000
0000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool04P3oool4000007T0oooo
000`0?ooo`D000001`3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0
P8200?ooo`3oool04P3oool00`20P800000000000002000007P0oooo000a0?ooo`050820P0000000
000000000010@4001P3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0
P8200?ooo`3oool04`3oool01@20P8000000000000000000@41007L0oooo000b0?ooo`030820P000
00000000008000001@3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0
P8200?ooo`3oool05@3oool4000007H0oooo000c0?ooo`@0000000<0P8200?ooo`3oool00P3oool0
0`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool05@3oool0
0`20P800000000000002000007D0oooo000d0?ooo`050820P0000000000000000020P8000`3oool0
0`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool05P3oool0
1@20P8000000000000000000@41007@0oooo000e0?ooo`030820P00000000000008000000P3oool0
0`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool05`3oool0
0`20P800000000000002000007<0oooo000f0?ooo`070820P0000000000000000010@400oooo0820
P00<00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool0603oool01@20P80000000000
00000000@4100780oooo000g0?ooo`030820P000000000000080000000<0P8200000000000002P00
001P0?ooo`T00000G03oool<000000030820P03oool0oooo01X0oooo1000001a0?ooo`00>03ooolA
00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool06P3oool00`20P800000000000002
00000700oooo000i0?ooo`030820P0000000000000d00000H03oool9000005`0oooo300000000`20
P800oooo0?ooo`0K0?ooo`050820P0000000000000000010@400K`3oool003X0oooo00<0P8200000
000000003000001P0?ooo`T00000G03oool<000000030820P03oool0oooo01`0oooo00<0P8200000
000000000P00001^0?ooo`005@3oool00`30`<00oooo0?ooo`0S0?ooo`030820P0000000000000/0
0000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0M0?ooo`030820P000000000000080
000000<0`<300?ooo`3oool0JP3oool001D0oooo00<000000?ooo`3oool0903oool00`20P8000000
0000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool07`3oool4000006`0oooo
000E0?ooo`8000009@3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0
P8200?ooo`3oool07`3oool00`20P800000000000002000006/0oooo000E0?ooo`<0000000<0`<30
0?ooo`3oool08@3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P820
0?ooo`3oool0803oool01@20P8000000000000000000@41006X0oooo000E0?ooo`@000008`3oool0
0`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool08P3oool4
000006T0oooo000E0?ooo`030820P00000000000008000008P3oool00`20P80000000000000:0000
0600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool08P3oool00`20P8000000000000020000
06P0oooo000F0?ooo`050820P0000000000000000010@4008@3oool00`20P80000000000000:0000
0600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool08`3oool01@20P8000000000000000000
@41006L0oooo000H0?ooo`@00000803oool00`20P80000000000000:00000600oooo2@00001L0?oo
o`d000009P3oool00`20P800000000000002000006H0oooo000H0?ooo`030<30`000000000000080
000000<0`<300?ooo`3oool0703oool00`20P80000000000000:00000600oooo2@00001L0?ooo`h0
000000<0P8200?ooo`3oool08`3oool01020P800000000000000001V0?ooo`006P3oool4000001h0
oooo00<0P8200000000000002P00001P0?ooo`T00000G03oool?000000030820P03oool0oooo02@0
oooo0P00001V0?ooo`006P3oool00`20P800000000000002000001d0oooo00<0P820000000000000
2P00001P0?ooo`T00000G03oool@000002H0oooo00<0P8200000003oool0I@3oool001/0oooo00<0
P8200000000000000P0000000`30`<00oooo0?ooo`0I0?ooo`030820P0000000000000X00000H03o
ool9000005`0oooo300000000`10@400000000000002000000030<30`03oool0oooo02<0oooo00<0
P8200?ooo`3oool0I03oool001d0oooo1000000K0?ooo`030820P0000000000000X00000H03oool9
000005`0oooo300000000`20P800oooo00000003000008`0oooo000M0?ooo`030820P00000000000
008000006P3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?oo
o`3oool01000002;0?ooo`007P3oool01@20P8000000000000000000@41001T0oooo00<0P8200000
000000002P00001P0?ooo`T00000G03oool<000000040820P03oool0oooo0<30`0@0000000<0`<30
0?ooo`3oool0Q`3oool00200oooo1000000H0?ooo`030820P0000000000000X00000H03oool90000
05`0oooo300000000`20P800oooo0?ooo`020?ooo`@00000R@3oool00200oooo00<0`<3000000000
00000P0000000`30`<00oooo0?ooo`0D0?ooo`030820P0000000000000X00000H03oool9000005`0
oooo300000000`20P800oooo0?ooo`020?ooo`030<30`000000000000080000000<0P8200?ooo`3o
ool0Q@3oool00280oooo1000000F0?ooo`030820P0000000000000X00000H03oool9000005`0oooo
300000000`20P800oooo0?ooo`040?ooo`@0000000<0P8200?ooo`3oool0Q03oool00280oooo00<0
P8200000000000000P00000E0?ooo`030820P0000000000000X00000a@3oool<000000030820P03o
ool0oooo00D0oooo100000260?ooo`008`3oool00`20P800000000000002000000030<30`03oool0
oooo0140oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool01@3oool0
0`30`<00000000000002000000030<30`03oool0oooo0880oooo000U0?ooo`@000004`3oool00`20
P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`070?ooo`@00000Q03oool002D0
oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`0?0?ooo`030820P0000000000000X0
0000a@3oool<000000030820P03oool0oooo00P0oooo00D0@41000000000000000000820P0220?oo
o`009`3oool400000140oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3o
ool02@3oool4000000030820P03oool0oooo07l0oooo000X0?ooo`@00000403oool00`20P8000000
0000000:00000<D0oooo300000000`20P800oooo0?ooo`0:0?ooo`@00000P@3oool002P0oooo00<0
`<300000000000000P0000000`30`<00oooo0?ooo`0<0?ooo`030820P0000000000000X00000a@3o
ool<000000030820P03oool0oooo00X0oooo00<0`<300000000000000P0000000`30`<00oooo0?oo
o`1m0?ooo`00:P3oool4000000h0oooo00<0P8200000000000002P0000350?ooo``0000000<0P820
0?ooo`3oool0303oool4000007l0oooo000Z0?ooo`030820P00000000000008000003@3oool00`20
P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`0=0?ooo`@00000OP3oool002/0
oooo00D0P82000000000000000000410@00<0?ooo`030820P0000000000000X00000a@3oool<0000
00030820P03oool0oooo00d0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`1j0?oo
o`00;@3oool4000000/0oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3o
ool03`3oool4000007`0oooo000]0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0
1`3oool00`20P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`0?0?ooo`030<30
`000000000000080000000<0P8200?ooo`3oool0N03oool002l0oooo100000090?ooo`030820P000
0000000000X00000a@3oool<000000030820P03oool0oooo0140oooo100000000`20P800oooo0?oo
o`1g0?ooo`00;`3oool00`20P800000000000002000000P0oooo00<0P8200000000000002P000035
0?ooo``0000000<0P8200?ooo`3oool04P3oool4000007T0oooo000`0?ooo`030820P00000000000
0080000000<0`<300?ooo`3oool0103oool00`20P80000000000000:00000<D0oooo300000000`20
P800oooo0?ooo`0B0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0M@3oool00380
oooo100000060?ooo`030820P0000000000000X00000<`3oool00`000000oooo0?ooo`2?0?ooo``0
000000<0P8200?ooo`3oool0503oool4000007L0oooo000b0?ooo`030820P0000000000000800000
1@3oool00`20P80000000000000:00000380oooo00<0P820000000000000?03oool00`000000oooo
0?ooo`1A0?ooo``0000000<0P8200?ooo`3oool05@3oool4000007H0oooo000c0?ooo`050820P000
0000000000000010@400103oool00`20P80000000000000:000001<0oooo0P0000000`30`<00oooo
0?ooo`0J0?ooo`030410@0000000oooo03`0oooo0P0000000`20P800oooo0?ooo`1?0?ooo``00000
00<0P8200?ooo`3oool05@3oool00`30`<00000000000002000000030<30`03oool0oooo0780oooo
000e0?ooo`@000000`3oool00`20P80000000000000:000001<0oooo0`00000L0?ooo`030000003o
ool0oooo03`0oooo1000001@0?ooo``0000000<0P8200?ooo`3oool05`3oool4000007@0oooo000e
0?ooo`030<30`000000000000080000000<0`<300?ooo`20P8003000000C0?ooo`D0000000<0`<30
0?ooo`3oool05P3oool00`000000@4100?ooo`0m0?ooo`030410@020P80000000080000000<0`<30
0?ooo`3oool0C03oool<000000030820P03oool0oooo01L0oooo00<0`<300000000000000P000000
0`30`<00oooo0?ooo`1`0?ooo`00=`3oool4000000030?ooo`20P800000000/000004`3oool50000
00030820P03oool0oooo01D0oooo0P0000000`20P800oooo0?ooo`0l0?ooo`030820P03oool0oooo
00<00000CP3oool<000000030820P03oool0oooo01T0oooo1000001b0?ooo`00=`3oool00`20P800
000000000002000000030820P0000000000000X000004`3oool6000001L0oooo0P0000000`20P800
oooo0?ooo`0Y0?ooo`030820P03oool0oooo01@0oooo0`00000H0?ooo`030820P03oool0oooo0380
oooo300000000`20P800oooo0?ooo`0J0?ooo`@00000L@3oool003P0oooo00<0P820000000000000
3P00000C0?ooo`L000005@3oool00`30`<0000000000000/0?ooo`040<30`000000000000<30`1@0
oooo00<0@41000000010@4005`3oool00`20P80000000820P00b0?ooo``0000000<0P8200?ooo`3o
ool06P3oool00`30`<00000000000002000000030<30`03oool0oooo06d0oooo000j0?ooo`l00000
4`3oool8000001@0oooo00<0P820000000000000;P3oool3000001@0oooo0`00000F0?ooo`040820
P000000000000820P340oooo300000000`20P800oooo0?ooo`0L0?ooo`@00000K`3oool003X0oooo
00<0`<300000000000003000000C0?ooo`030410@0000000000000D0000000<0`<300?ooo`3oool0
4@3oool200000300oooo00@0`<30000000000000`<304`3oool01010@400000000000030`<0E0?oo
o`040820P000000000000820P300oooo300000000`20P800oooo0?ooo`0L0?ooo`030<30`0000000
00000080000000<0P8200?ooo`3oool0J`3oool001D0oooo00<0P8200?ooo`3oool0903oool=0000
01<0oooo00<0P8200000000000001@0000000`20P800oooo0?ooo`0A0?ooo`800000<P3oool00`00
0000P8200?ooo`0C0?ooo`<000005P3oool3000000030820P03oool0oooo02d0oooo300000000`20
P800oooo0?ooo`0N0?ooo`@0000000<0P8200?ooo`3oool0JP3oool001D0oooo00<000000?ooo`3o
ool0903oool00`20P80000000000000:000001<0oooo00<0P8200000000000001P00000B0?ooo`<0
0000<P3oool2000001D0oooo0`00000F0?ooo`<00000;`3oool<000000030820P03oool0oooo01l0
oooo1000001/0?ooo`005@3oool2000000030820P03oool0oooo0280oooo00<0P820000000000000
2P00000D0?ooo`P0000000<0P8200?ooo`3oool03P3oool01030`<00000000000020P80c0?ooo`80
00005@3oool00`10@40000000000000E0?ooo`050<30`0000000000000000020P800;@3oool<0000
00030820P03oool0oooo01l0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`1X0?oo
o`005@3oool3000000030820P03oool0oooo0240oooo00<0P8200000000000002P00000D0?ooo`T0
0000403oool00`20P80000000000000d0?ooo`80000000<0P8200?ooo`3oool04`3oool200000003
0820P03oool0oooo01<0oooo100000000`20P800oooo0?ooo`0Z0?ooo``0000000<0P8200?ooo`3o
ool08@3oool4000006X0oooo000E0?ooo`@000008`3oool00`20P80000000000000:000001@0oooo
2@0000000`20P800oooo0?ooo`0=0?ooo`030820P0000000000003@0oooo0P0000000`20P800oooo
0?ooo`0C0?ooo`<000005P3oool4000002`0oooo300000000`20P800oooo0?ooo`0R0?ooo`@00000
J@3oool001D0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`0O0?ooo`030820P000
0000000000X000005@3oool8000000030820P03oool0oooo00d0oooo00<0@4100000000000003`3o
ool01@10@400000000000010@400P82000d0oooo00D0@410000000000000@4100820P00<0?ooo`05
0820P0000000000000000010@4005@3oool4000000030<30`03oool0oooo0180oooo00D0@4100000
0000000000000820P00[0?ooo``0000000<0P8200?ooo`3oool08P3oool00`30`<00000000000002
000000030<30`03oool0oooo06D0oooo000G0?ooo`@000008@3oool00`20P80000000000000:0000
01D0oooo2@00000?0?ooo`<000003`3oool5000000030820P03oool0oooo00T0oooo1`00000:0?oo
o`030820P0000000000000<000005@3oool5000001D0oooo100000000`20P800oooo0?ooo`0X0?oo
o``0000000<0P8200?ooo`3oool0903oool4000006L0oooo000H0?ooo`050410@000000000000000
0020P8007`3oool00`20P80000000000000:000001D0oooo00<0P8200000000000001P00000?0?oo
o`<000003`3oool6000000030820P03oool0oooo00L0oooo00<0`<300000000000001@0000000`10
@400oooo0?ooo`070?ooo`H00000503oool00`30`<00000000000004000000030820P03oool0oooo
0140oooo00<0P8200000000000000P00000Z0?ooo`d0000000<0P8200?ooo`3oool08`3oool00`30
`<00000000000002000006H0oooo000I0?ooo`@0000000<0P8200?ooo`3oool0703oool00`20P800
00000000000:000001D0oooo00<0P8200000000000001`00000>0?ooo`<000003`3oool8000000P0
oooo00<0P8200000000000001`0000080?ooo`H00000503oool00`20P800000000000005000001@0
oooo1@00000Y0?ooo`l000009P3oool3000006H0oooo000J0?ooo`@000007P3oool00`20P8000000
0000000:000001D0oooo00<0P8200000000000001`00000=0?ooo`@000003`3oool3000000030820
P03oool0P8200080000000<0P8200?ooo`3oool01@3oool00`20P800000000000002000000030820
P03oool0oooo0080000000<0P8200?ooo`3oool01@3oool6000001@0oooo00<0P820000000000000
1@0000000`20P800oooo0?ooo`0B0?ooo`D00000:03oool?000000030820P03oool0oooo02@0oooo
0P00001V0?ooo`006P3oool00`30`<00000000000002000000030820P03oool0oooo01X0oooo00<0
P8200000000000002P00000F0?ooo`T000003@3oool4000000l0oooo0P0000001`20P800oooo0?oo
o`3oool0P82000000010@4001`3oool5000000060820P03oool0oooo0<30`0000000@4101`3oool0
0`20P800000000000002000000030<30`03oool0oooo0180oooo00<0P8200000000000000`000000
103oool0P82000000020P80C0?ooo`030410@000000000000080000000<0P8200?ooo`3oool09@3o
ool@000000030820P03oool0oooo02<0oooo00<0`<300000003oool0I@3oool001`0oooo10000000
0`20P800oooo0?ooo`0I0?ooo`030820P0000000000000X000005P3oool:000000`0oooo1000000F
0?ooo`<000001P3oool5000000D0oooo0P0000080?ooo`8000005P3oool00`20P800000000000003
00000080oooo0P0000000`20P800oooo0?ooo`0@0?ooo`030820P0000000000000<000009`3oool<
000000030820P000000000000080000000<0P8200?ooo`3oool0RP3oool001d0oooo1000000K0?oo
o`030820P0000000000000X000005`3oool9000000`0oooo1@00000F0?ooo`8000001P3oool50000
00D0oooo00<0P8200000003oool07`3oool00`20P80000000000000300000080oooo00<0P8200000
0020P8004`3oool5000002L0oooo300000000`20P800oooo00000003000008`0oooo000M0?ooo`03
0<30`000000000000080000000<0`<300?ooo`3oool05`3oool00`20P80000000000000:000001L0
oooo2@0000000`30`<00oooo0?ooo`090?ooo`D000005P3oool00`30`<0000000410@0040?ooo`H0
00001P3oool00`000000P8200?ooo`0N0?ooo`030820P000000000000080000000L0@4100?ooo`3o
ool0oooo0820P0000000P8200180oooo1P00000V0?ooo``0000000@0P8200?ooo`3oool0@4100`00
00000`20P800oooo0?ooo`280?ooo`007`3oool4000001T0oooo00<0P8200000000000002P00000G
0?ooo`T0000000<0P8200?ooo`3oool02@3oool5000001L0oooo0P0000040?ooo`D00000:03oool0
0`20P800000000000002000000030820P03oool0oooo0080oooo0`00000B0?ooo`H000009@3oool<
000000040820P03oool0oooo0?ooo`@0000000<0P8200?ooo`3oool0Q`3oool00200oooo00D0@410
00000000000000000820P00G0?ooo`030820P0000000000000X00000603oool8000000030820P03o
ool0oooo00T0oooo1@00000H0?ooo`050410@0000000oooo0?ooo`20P8001@00000X0?ooo`030820
P000000000000080000000<0P8200?ooo`3oool00P3oool01030`<00000000000030`<0A0?ooo`03
0410@0000000000000<0000000<0`<300?ooo`3oool08P3oool<000000030820P03oool0oooo0080
oooo00D0@41000000000000000000820P0280?ooo`008@3oool4000000030820P03oool0oooo01@0
oooo00<0P8200000000000002P00000H0?ooo`T000002`3oool5000001P0oooo00@0P82000000000
0000oooo1@00000Y0?ooo`D0000000<0P8200?ooo`3oool0103oool200000140oooo00<0P8200000
000000000`0000000`20P800oooo0?ooo`0R0?ooo``0000000<0P8200?ooo`3oool00`3oool50000
08L0oooo000R0?ooo`@000005P3oool00`20P80000000000000:000001P0oooo00<0P82000000000
00001P00000;0?ooo`H00000603oool2000000030?ooo`000000000000<00000:@3oool500000003
0820P03oool0oooo00@0oooo0P00000A0?ooo`030820P0000000000000@00000903oool<00000003
0820P03oool0oooo00@0oooo100000000`20P800oooo0?ooo`240?ooo`008P3oool00`30`<000000
00000002000000030820P03oool0oooo0180oooo00<0P8200000000000002P00000H0?ooo`030820
P0000000000000H0000000<0P8200?ooo`3oool0203oool6000001P0oooo00<0P82000000010@400
1@00000Y0?ooo`D0000000<0P8200?ooo`3oool01@3oool00`10@40000000820P00@0?ooo`H00000
903oool<000000030820P03oool0oooo00D0oooo00D0@41000000000000000000820P0250?ooo`00
903oool4000000030820P03oool0oooo0140oooo00<0P8200000000000002P00000H0?ooo`030820
P0000000000000L000002P3oool6000001X0oooo1@0000000`20P800oooo0?ooo`0W0?ooo`D00000
00<0P8200?ooo`3oool01@3oool00`20P80000000000000@0?ooo`L000008`3oool<000000030820
P03oool0oooo00H0oooo100000000`20P800oooo0?ooo`220?ooo`009@3oool01@10@40000000000
00000000P8200180oooo00<0P8200000000000002P00000I0?ooo`T000002`3oool5000000030820
P03oool0oooo01L0oooo00<0@4100000000000000P0000000`20P800oooo0?ooo`0W0?ooo`D00000
00<0P8200?ooo`3oool01P3oool00`20P80000000410@00@0?ooo`H000008`3oool<000000030820
P03oool0oooo00L0oooo00D0P82000000000000000000820P0230?ooo`009P3oool4000000030820
P03oool0oooo00l0oooo00<0P8200000000000002P00000I0?ooo`T0000000<0P8200?ooo`3oool0
203oool5000000030820P03oool0oooo01L0oooo1@0000000`20P800oooo0?ooo`0W0?ooo`D00000
2P3oool200000100oooo1P00000S0?ooo``0000000<0P8200?ooo`3oool0203oool00`20P8000000
0000000200000880oooo000W0?ooo`@000004@3oool00`20P80000000000000:000001T0oooo2@00
00000`20P800oooo0?ooo`080?ooo`D0000000<0P8200?ooo`3oool05`3oool5000002X0oooo1@00
000;0?ooo`8000003`3oool6000000030820P03oool0oooo0200oooo300000000`20P800oooo0?oo
o`090?ooo`@0000000<0P8200?ooo`3oool0O`3oool002P0oooo00D0@41000000000000000000820
P00?0?ooo`030820P0000000000000X000006P3oool8000000030410@03oool0oooo00P0oooo00<0
@4100000000000000`00000H0?ooo`030820P0000000000000<00000:P3oool5000000/0oooo00<0
P82000000020P8003`3oool5000000030820P03oool0oooo0200oooo300000000`20P800oooo0?oo
o`0:0?ooo`050410@0000000000000000020P800P03oool002T0oooo100000000`20P800oooo0?oo
o`0<0?ooo`030820P0000000000000X000006P3oool9000000X0oooo00<0P8200000000000000`00
000H0?ooo`D00000:P3oool6000000`0oooo0P00000?0?ooo`D0000000<0P8200?ooo`3oool0803o
ool<000000030820P03oool0oooo00/0oooo100000000`20P800oooo0?ooo`1m0?ooo`00:P3oool4
000000h0oooo00<0P8200000000000002P00000K0?ooo`P000002P3oool00`20P800000000000003
000001P0oooo1P00000Y0?ooo`H00000303oool2000000l0oooo1@0000000`20P800oooo0?ooo`0P
0?ooo``0000000<0P8200?ooo`3oool0303oool4000007l0oooo000Z0?ooo`030<30`00000000000
0080000000<0`<300?ooo`3oool02P3oool00`20P80000000000000:000001/0oooo200000000`20
P800oooo0?ooo`070?ooo`030<30`0000000000000@000005P3oool00`20P8000000000000040000
00030820P03oool0oooo02H0oooo1P00000=0?ooo`80000000<0P8200?ooo`3oool02`3oool00`20
P80000000000000300000280oooo300000000`20P800oooo0?ooo`0=0?ooo`050410@00000000000
00000020P800O@3oool002`0oooo1000000<0?ooo`030820P0000000000000X000006`3oool90000
00X0oooo1P00000F0?ooo`D0000000<0P820000000000000:03oool6000000d0oooo00<0P8200000
000000003@3oool00`20P80000000000000300000280oooo300000000`20P800oooo0?ooo`0>0?oo
o`@0000000<0P8200?ooo`3oool0NP3oool002d0oooo00D0@41000000000000000000820P00:0?oo
o`030820P0000000000000X000006`3oool00`20P800000000000006000000X0oooo00<0P8200000
000000001000000D0?ooo`030<30`0000000000000<0000000@0P8200?ooo`00000000009`3oool6
000000h0oooo0P0000000`30`<00oooo0?ooo`0:0?ooo`030<30`0000000000000<000008P3oool<
000000030820P03oool0oooo00l0oooo00D0@41000000000000000000820P01k0?ooo`00;P3oool4
000000030820P03oool0oooo00L0oooo00<0P8200000000000002P00000K0?ooo`030820P0000000
000000L000002P3oool6000000030820P03oool0oooo0140oooo00<0P8200000000000000`000000
0`20P800oooo0820P002000002H0oooo1P00000>0?ooo`80000000<0P8200?ooo`3oool02`3oool5
00000280oooo300000000`20P800oooo0?ooo`0@0?ooo`D00000NP3oool002l0oooo100000090?oo
o`030820P0000000000000X00000703oool9000000X0oooo00<0P8200000000000000`0000000`20
P800oooo0?ooo`0A0?ooo`030820P0000000000000<000000`3oool2000000030820P03oool0oooo
02<0oooo1@00000?0?ooo`80000000<0P8200?ooo`3oool02`3oool500000280oooo300000000`20
P800oooo0?ooo`0A0?ooo`@0000000<0P8200?ooo`3oool0M`3oool002l0oooo00<0`<3000000000
00000P0000000`20P800oooo0?ooo`050?ooo`030820P0000000000000X00000703oool900000003
0<30`03oool0oooo00L0oooo00<0`<300000000000000`0000000`10@400oooo0?ooo`0A0?ooo`H0
00000`3oool01020P800000000000020P8040?ooo`<0P820703oool6000000h0oooo00@0@4100000
0000000000003@3oool500000280oooo300000000`20P800oooo0?ooo`0B0?ooo`050410@0000000
000000000020P800N03oool00340oooo100000000`20P800oooo0?ooo`040?ooo`030820P0000000
000000X00000703oool9000000030820P03oool0oooo00P0oooo1P00000B0?ooo`H000001P3oool3
00000080oooo1@00000K0?ooo`H000003@3oool5000000d0oooo1@00000R0?ooo``0000000<0P820
0?ooo`3oool04`3oool4000000030820P03oool0oooo07D0oooo000b0?ooo`@000001P3oool00`20
P80000000000000:000001d0oooo200000000`20P800oooo0?ooo`090?ooo`H00000403oool00`20
P800000000000004000000H0oooo00<0P8200000000000001`0000000`20P800oooo0?ooo`0G0?oo
o`030820P0000000000000@00000303oool00`20P800000000000003000000d0oooo1@00000R0?oo
o``0000000<0P8200?ooo`3oool0503oool4000007L0oooo000b0?ooo`030<30`000000000000080
000000<0`<300?ooo`3oool00P3oool00`20P80000000000000:000001`0oooo00<0P82000000000
00001P0000000`10@400oooo0?ooo`090?ooo`030820P0000000000000<000002`3oool40820P0L0
000000<0P8200?ooo`3oool0103oool00`30`<00000000000007000000030820P03oool0oooo0180
oooo1@20P806000000030410@03oool0oooo00X0oooo00<0P8200000000000000`00000>0?ooo`@0
00008P3oool<000000030820P03oool0oooo01D0oooo00D0@41000000000000000000820P01e0?oo
o`00=03oool4000000@0oooo00<0P8200000000000002P00000K0?ooo`030820P0000000000000P0
0000303oool5000000030820P03oool0oooo00P0oooo2`0000090?ooo`P0000000<0P8200?ooo`3o
ool04P3oool;000000030820P03oool0oooo00X0oooo00<0P8200000000000000`00000>0?ooo`@0
00008P3oool<000000030820P03oool0oooo01H0oooo100000000`20P800oooo0?ooo`1b0?ooo`00
=@3oool01@10@4000000000000000000P8200080oooo00<0P8200000000000002P00000H0?ooo`03
0<30`020P800P82000/0000000<0P8200?ooo`3oool02@3oool00`30`<0000000000000200000003
0410@03oool0oooo00T0oooo1020P805000000030<30`03oool0oooo00P0oooo00<0`<3000000000
0000100000000`30`<00oooo0?ooo`0C0?ooo`@0P8201P0000000`30`<00oooo0?ooo`0:0?ooo`03
0<30`000000000000080000000<0`<300?ooo`3oool0303oool3000000030410@03oool0oooo0200
oooo300000000`20P800oooo0?ooo`0G0?ooo`050410@0000000000000000020P800L`3oool003H0
oooo100000000`20P800oooo0820P00<000001l0oooo2000000<0?ooo`D000004@3oool00`20P800
00000000000=0?ooo`040820P00000000000000001h0oooo00<0P8200000000000003`3oool20000
0100oooo0`0000000`20P800oooo0?ooo`0P0?ooo``0000000<0P8200?ooo`3oool0603oool40000
00030820P03oool0oooo0700oooo000g0?ooo`@0000000<0oooo0820P00000002`00000R0?ooo`03
0820P00000000000008000003@3oool5000006H0oooo0`0000000`20P800oooo0?ooo`0P0?ooo``0
000000<0P8200?ooo`3oool06@3oool400000780oooo000g0?ooo`030<30`0000000000000800000
00<0@4100000000000002P00000e0?ooo`030410@0000000000000800000I@3oool3000000030820
P03oool0oooo0200oooo300000000`20P800oooo0?ooo`0J0?ooo`050410@0000000000000000020
P800L03oool003T0oooo4000000f0?ooo`@0000000<0P8200?ooo`3oool0HP3oool3000002<0oooo
300000000`20P800oooo0?ooo`0K0?ooo`@0000000<0P8200?ooo`3oool0K@3oool003X0oooo00<0
@4100000000000003000000f0?ooo`050820P0000000000000000010@400I03oool3000002<0oooo
300000000`20P800oooo0?ooo`0L0?ooo`050410@0000000000000000020P800KP3oool003/0oooo
3P00000g0?ooo`030820P0000000000000800000H`3oool2000002@0oooo300000000`20P800oooo
0?ooo`0M0?ooo`D00000K@3oool001D0oooo00<0P8200?ooo`3oool0903oool=000003P0oooo1000
001R0?ooo`<00000903oool<000000030820P03oool0oooo01h0oooo100000000`20P800oooo0?oo
o`1Z0?ooo`005@3oool00`000000P8200?ooo`0T0?ooo`030820P0000000000000X000008@3oool4
0820P0030<30`03oool0oooo0140oooo00@0P820000000000000@410H@3oool2000000030410@03o
ool0oooo0280oooo300000000`20P800oooo0?ooo`0O0?ooo`050410@0000000000000000020P800
J`3oool001D0oooo0`00000T0?ooo`030820P0000000000000X00000803oool00`20P80000000000
0003000001@0oooo00@0P8200000000000000000H03oool2000000030820P03oool0oooo0280oooo
300000000`20P800oooo0?ooo`0P0?ooo`@0000000<0P8200?ooo`3oool0J03oool001D0oooo0`00
00000`20P800oooo0?ooo`0Q0?ooo`030820P0000000000000X00000803oool7000001@0oooo0`00
001P0?ooo`80000000<0P8200?ooo`3oool08P3oool<000000030820P03oool0oooo0240oooo1000
001Z0?ooo`005@3oool01@10@4000000000000000000P8200280oooo00<0P8200000000000002P00
000N0?ooo`030820P0000000000000L0000000<0`<300?ooo`3oool04@3oool01010@40000000000
0030`<1M0?ooo`030820P0000000000002D0oooo300000000`20P800oooo0?ooo`0R0?ooo`050410
@0000000000000000020P800J03oool001H0oooo100000000`20P800oooo0?ooo`0O0?ooo`030820
P0000000000000X000007P3oool:000000030820P03oool0oooo0180oooo0`00001M0?ooo`030820
P0000000oooo02D0oooo300000000`20P800oooo0?ooo`0S0?ooo`@0000000<0P8200?ooo`3oool0
I@3oool001L0oooo00D0P82000000000000000000820P00P0?ooo`030820P0000000000000X00000
7P3oool:000000030820P03oool0oooo01<0oooo00@0P820000000000000P820F`3oool2000002H0
oooo300000000`10@400oooo0?ooo`0T0?ooo`050410@0000000000000000020P800IP3oool001P0
oooo00<0P8200000000000000P00000O0?ooo`030820P0000000000000X000007P3oool:00000003
0820P03oool0oooo01D0oooo0P0000000`20P800oooo0?ooo`1G0?ooo`8000009`3oool>000002H0
oooo1000001V0?ooo`006@3oool4000000030820P03oool0oooo01`0oooo00<0P820000000000000
2P00000N0?ooo`X0000000<0P8200?ooo`3oool05P3oool2000005T0oooo0P00000W0?ooo`l00000
9P3oool3000006H0oooo000J0?ooo`050410@0000000000000000020P8007@3oool00`20P8000000
0000000:000001l0oooo00<0P8200000000000001@0000000`20P800oooo0?ooo`0H0?ooo`030410
@0000000P82005H0oooo00<0P82000000020P8009`3oool?000000030410@03oool0oooo02@0oooo
00<0@4100000003oool0I@3oool001/0oooo1@00000L0?ooo`030820P0000000000000X00000803o
ool00`20P800000000000003000001h0oooo0P00001E0?ooo`800000:03oool<000000030820P000
00000000008000009P3oool00`000000oooo0?ooo`1T0?ooo`00703oool4000000030820P03oool0
oooo01T0oooo00<0P8200000000000002P00000Q0?ooo`@0000000<0P8200?ooo`3oool0703oool0
0`20P80000000000001C0?ooo`030820P0000000000002P0oooo300000000`20P800oooo00000002
000000030820P03oool0oooo08X0oooo000M0?ooo`050410@0000000000000000020P8006P3oool0
0`20P80000000000000:000004D0oooo00<0P8200?ooo`3oool0D`3oool00`20P800oooo0?ooo`0W
0?ooo``0000000@0P8200?ooo`3oool0@4100P0000000`20P800oooo0?ooo`290?ooo`007P3oool4
000000030820P03oool0oooo01L0oooo00<0P8200000000000002P0000350?ooo``0000000@0P820
0?ooo`3oool0oooo1000002:0?ooo`007`3oool01@20P8000000000000000000P82001P0oooo00<0
P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool00P3oool01010@40000000000
0010@4290?ooo`00803oool00`20P800000000000002000001L0oooo00<0P8200000000000002P00
00350?ooo``0000000<0P8200?ooo`3oool00`3oool4000008P0oooo000Q0?ooo`@0000000<0P820
0?ooo`3oool0503oool00`20P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`04
0?ooo`@00000Q`3oool00280oooo00D0@41000000000000000000820P00E0?ooo`030820P0000000
000000X00000a@3oool<000000030820P03oool0oooo00D0oooo00@0@410000000000000@410QP3o
ool002<0oooo1@00000D0?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0
oooo00H0oooo100000250?ooo`00903oool01@20P8000000000000000000@41001<0oooo00<0P820
0000000000002P0000350?ooo``0000000<0P8200?ooo`3oool01`3oool01020P800000000000010
@4240?ooo`009@3oool00`20P80000000000000200000180oooo00<0P8200000000000002P000035
0?ooo``0000000<0P8200?ooo`3oool0203oool01020P80000000000000000230?ooo`009P3oool4
000000030820P03oool0oooo00l0oooo00<0P8200000000000002P0000350?ooo``0000000<0P820
0?ooo`3oool02@3oool400000880oooo000W0?ooo`050820P0000000000000000020P800403oool0
0`20P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`0:0?ooo`040410@0000000
00000410@840oooo000X0?ooo`030820P00000000000008000003`3oool00`20P80000000000000:
00000<D0oooo300000000`20P800oooo0?ooo`0;0?ooo`@00000P03oool002T0oooo100000000`20
P800oooo0?ooo`0<0?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0oooo
00`0oooo0`0000000`20P800oooo0?ooo`1m0?ooo`00:P3oool01@10@4000000000000000000P820
00d0oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool03@3oool01010
@400000000000020P81n0?ooo`00:`3oool4000000030820P03oool0oooo00X0oooo00<0P8200000
000000002P0000350?ooo``0000000<0P8200?ooo`3oool03P3oool4000007d0oooo000/0?ooo`05
0820P0000000000000000020P8002`3oool00`20P80000000000000:00000<D0oooo300000000`20
P800oooo0?ooo`0?0?ooo`040410@000000000000410@7`0oooo000]0?ooo`030820P00000000000
008000002P3oool00`20P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`0@0?oo
o`@00000N`3oool002h0oooo100000000`20P800oooo0?ooo`070?ooo`030820P0000000000000X0
0000a@3oool<000000030820P03oool0oooo0140oooo1000001j0?ooo`00;`3oool01@10@4000000
000000000000P82000P0oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3o
ool04P3oool01010@400000000000010@41i0?ooo`00<03oool5000000L0oooo00<0P82000000000
00002P0000350?ooo``0000000<0P8200?ooo`3oool04`3oool4000007P0oooo000a0?ooo`050820
P0000000000000000010@4001P3oool00`20P80000000000000:00000<D0oooo300000000`20P800
oooo0?ooo`0D0?ooo`040820P000000000000410@7L0oooo000b0?ooo`030820P000000000000080
00001@3oool00`20P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`0E0?ooo`04
0820P00000000000000007H0oooo000c0?ooo`@0000000<0P8200?ooo`3oool00P3oool00`20P800
00000000000:00000<D0oooo300000000`20P800oooo0?ooo`0F0?ooo`@00000M@3oool003@0oooo
00D0P82000000000000000000820P0030?ooo`030820P0000000000000X00000H03oool9000005`0
oooo300000000`20P800oooo0?ooo`0G0?ooo`040410@000000000000410@7@0oooo000e0?ooo`03
0820P00000000000008000000P3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0
000000<0P8200?ooo`3oool0603oool4000007<0oooo000f0?ooo`@0000000<0P8200?ooo`20P800
3000001P0?ooo`T00000G03oool<000000030820P03oool0oooo01T0oooo0`0000000`20P800oooo
0?ooo`1`0?ooo`00=`3oool01010@40000000000000000020820P0`00000H03oool9000005`0oooo
300000000`20P800oooo0?ooo`0J0?ooo`040410@000000000000820P740oooo000h0?oooa400000
H03oool9000005`0oooo300000000`20P800oooo0?ooo`0K0?ooo`@00000L03oool003T0oooo00<0
P8200000000000003@00001P0?ooo`T00000G03oool<000000030820P03oool0oooo01`0oooo00@0
@410000000000000@410K`3oool003X0oooo00<0P8200000000000003000001P0?ooo`T00000G03o
ool<000000030820P03oool0oooo01d0oooo1000001^0?ooo`00>`3oool>00000600oooo2@00001L
0?ooo``0000000<0P8200?ooo`3oool07P3oool4000006d0oooo000E0?ooo`030410@03oool0oooo
02@0oooo00<0@4100000000000002P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo
01l0oooo00@0@410000000000000@410K03oool001D0oooo0P00000U0?ooo`030820P00000000000
00X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0P0?ooo`@00000J`3oool001D0
oooo0`00000T0?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000000`20P800
oooo0?ooo`0Q0?ooo`<0000000<0P8200?ooo`3oool0J03oool001D0oooo0`0000000`10@400oooo
0?ooo`0Q0?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000000`20P800oooo
0?ooo`0R0?ooo`040410@000000000000820P6T0oooo000E0?ooo`030820P0000000000000800000
8P3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool0
8`3oool4000006P0oooo000F0?ooo`050820P0000000000000000010@4008@3oool00`20P8000000
0000000:00000600oooo2@00001L0?ooo``0000000<0@4100?ooo`3oool0903oool01010@4000000
00000010@41W0?ooo`00603oool400000200oooo00<0P8200000000000002P00001P0?ooo`T00000
G03oool>000002H0oooo1000001V0?ooo`00603oool00`20P800000000000002000001l0oooo00<0
P8200000000000002P00001P0?ooo`T00000G03oool?000002H0oooo0`00001V0?ooo`006@3oool0
1@20P8000000000000000000@41001h0oooo00<0P8200000000000002P00001P0?ooo`T00000G03o
ool?000000030410@03oool0oooo02@0oooo00<0@4100000003oool0I@3oool001X0oooo00<0P820
0000000000000P00000M0?ooo`030820P0000000000000X00000H03oool9000005`0oooo4@00000V
0?ooo`030000003oool0oooo06@0oooo000K0?ooo`030820P000000000000080000000<0`<300?oo
o`3oool06@3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``000000P20P8030000
00030410@03oool0oooo08X0oooo000M0?ooo`@000006`3oool00`20P80000000000000:00000600
oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool01000002;0?ooo`007@3oool00`20P8000000
00000002000001X0oooo00<0P8200000000000002P00001P0?ooo`T00000G03oool<000000040820
P03oool0oooo0820P0@00000RP3oool001h0oooo00D0P82000000000000000000410@00I0?ooo`03
0820P0000000000000X00000H03oool9000005`0oooo300000001@20P800oooo0?ooo`3oool0P820
00<0000000<0@4100?ooo`3oool0Q`3oool00200oooo1000000H0?ooo`030820P0000000000000X0
0000H03oool9000005`0oooo300000000`20P800oooo0?ooo`020?ooo`030820P000000000000080
0000R03oool00200oooo00<0P8200000000000000P00000G0?ooo`030820P0000000000000X00000
H03oool9000005`0oooo300000000`20P800oooo0?ooo`030?ooo`D00000Q`3oool00240oooo00D0
P82000000000000000000410@00F0?ooo`030820P0000000000000X00000H03oool9000005`0oooo
300000000`20P800oooo0?ooo`040?ooo`050820P0000000000000000010@400QP3oool00280oooo
00<0P8200000000000000P00000E0?ooo`030820P0000000000000X00000H03oool9000005`0oooo
300000000`20P800oooo0?ooo`050?ooo`030820P0000000000000800000Q@3oool002<0oooo00<0
P8200000000000000P0000000`30`<00oooo0?ooo`0A0?ooo`030820P0000000000000X00000H03o
ool9000005`0oooo300000000`20P800oooo0?ooo`060?ooo`050820P0000000000000000010@400
Q03oool002D0oooo1000000C0?ooo`030820P0000000000000X00000H03oool9000005`0oooo3000
00000`20P800oooo0?ooo`080?ooo`@00000P`3oool002D0oooo00<0P8200000000000000P00000B
0?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`08
0?ooo`030820P0000000000000800000PP3oool002H0oooo00D0P82000000000000000000410@00A
0?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`09
0?ooo`050820P0000000000000000010@400P@3oool002P0oooo1000000@0?ooo`030820P0000000
000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0:0?ooo`030820P0000000
000000800000P03oool002P0oooo00<0P8200000000000000P00000?0?ooo`030820P00000000000
00X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0;0?ooo`@0000000<0P8200?oo
o`3oool0O@3oool002T0oooo00D0P82000000000000000000410@00>0?ooo`030820P00000000000
00X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0<0?ooo`050820P00000000000
00000020P800OP3oool002X0oooo00<0P8200000000000000P00000=0?ooo`030820P00000000000
00X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0=0?ooo`030820P00000000000
00800000O@3oool002/0oooo00D0P82000000000000000000410@00<0?ooo`030820P00000000000
00X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0>0?ooo`050820P00000000000
00000010@400O03oool002d0oooo1000000;0?ooo`030820P0000000000000X00000H03oool90000
05`0oooo300000000`20P800oooo0?ooo`0?0?ooo`030820P0000000000000800000N`3oool002d0
oooo00<0P8200000000000000P00000:0?ooo`030820P0000000000000X00000H03oool9000005`0
oooo300000000`20P800oooo0?ooo`0@0?ooo`D00000NP3oool002h0oooo00D0P820000000000000
00000410@0090?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000000`20P800
oooo0?ooo`0A0?ooo`050820P0000000000000000010@400N@3oool002l0oooo00<0P82000000000
00000P0000080?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000000`20P800
oooo0?ooo`0B0?ooo`030820P0000000000000800000N03oool00300oooo00<0P820000000000000
0P0000000`30`<00oooo0?ooo`040?ooo`030820P0000000000000X00000H03oool9000005`0oooo
300000000`20P800oooo0?ooo`0C0?ooo`050820P0000000000000000010@400M`3oool00380oooo
100000060?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000000`20P800oooo
0?ooo`0E0?ooo`@00000MP3oool00380oooo00<0P8200000000000000P0000050?ooo`030820P000
0000000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0E0?ooo`030820P000
0000000000800000M@3oool003<0oooo00D0P82000000000000000000410@0040?ooo`030820P000
0000000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0F0?ooo`050820P000
0000000000000010@400M03oool003D0oooo100000030?ooo`030820P0000000000000X00000H03o
ool9000005`0oooo300000000`20P800oooo0?ooo`0G0?ooo`030820P0000000000000800000L`3o
ool003D0oooo00<0P8200000000000000P0000020?ooo`030820P0000000000000X00000H03oool9
000005`0oooo300000000`20P800oooo0?ooo`0H0?ooo`@0000000<0P8200?ooo`3oool0L03oool0
03H0oooo00L0P82000000000000000000410@03oool0P82000`00000H03oool9000005`0oooo3000
00000`20P800oooo0?ooo`0I0?ooo`050820P0000000000000000020P800L@3oool003L0oooo00<0
P8200000000000000P0000000`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0
P8200?ooo`3oool06P3oool00`20P80000000000000200000700oooo000h0?ooo`030820P0000000
000000h00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0K0?ooo`050820P0000000
000000000010@400K`3oool003X0oooo3`00001P0?ooo`T00000G03oool<000000030820P03oool0
oooo01`0oooo00<0P8200000000000000P00001^0?ooo`00>P3oool00`20P80000000000000<0000
0600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool07@3oool5000006d0oooo000E0?ooo`03
0<30`03oool0oooo02<0oooo00<0P8200000000000002`00001P0?ooo`T00000G03oool<00000003
0820P03oool0oooo01h0oooo00D0P82000000000000000000410@01/0?ooo`005@3oool00`000000
oooo0?ooo`0T0?ooo`030820P0000000000000X00000H03oool9000005`0oooo300000000`20P800
oooo0?ooo`0O0?ooo`030820P0000000000000800000J`3oool001D0oooo0P00000U0?ooo`030820
P0000000000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0P0?ooo`@00000
00<0P8200?ooo`3oool0J03oool001D0oooo0`0000000`30`<00oooo0?ooo`0Q0?ooo`030820P000
0000000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0Q0?ooo`050820P000
0000000000000020P800J@3oool001D0oooo1000000S0?ooo`030820P0000000000000X00000H03o
ool9000005`0oooo300000000`20P800oooo0?ooo`0R0?ooo`030820P0000000000000800000J03o
ool001D0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`0O0?ooo`030820P0000000
000000X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0S0?ooo`050820P0000000
000000000010@400I`3oool001L0oooo1000000Q0?ooo`030820P0000000000000X00000H03oool9
000005`0oooo3@00000V0?ooo`030820P0000000000000800000IP3oool001P0oooo1000000P0?oo
o`030820P0000000000000X00000H03oool9000005`0oooo3P00000V0?ooo`@00000IP3oool001P0
oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`0L0?ooo`030820P0000000000000X0
0000H03oool9000005`0oooo3`0000000`30`<00oooo0?ooo`0S0?ooo`030820P0000000000006H0
oooo000J0?ooo`@000007P3oool00`20P80000000000000:00000600oooo2@00001L0?oooa000000
9P3oool00`20P80000000?ooo`1U0?ooo`006P3oool00`30`<00000000000002000000030820P03o
ool0oooo01X0oooo00<0P8200000000000002P00001P0?ooo`T00000G03oool<000000030410@000
000000000080000000<0`<300?ooo`3oool08`3oool00`20P800oooo0?ooo`1T0?ooo`00703oool4
000000030820P03oool0oooo01T0oooo00<0P8200000000000002P00001P0?ooo`T00000G03oool<
000000030820P03oool0000000<00000S03oool001d0oooo1000000K0?ooo`030820P00000000000
00X00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`04000008/0oooo000M0?ooo`03
0<30`000000000000080000000<0`<300?ooo`3oool05`3oool00`20P80000000000000:00000600
oooo2@00001L0?ooo``0000000@0P8200?ooo`3oool0`<30100000000`30`<00oooo0?ooo`270?oo
o`007`3oool4000001T0oooo00<0P8200000000000002P00001P0?ooo`T00000G03oool<00000003
0820P03oool0oooo0080oooo100000290?ooo`00803oool4000001P0oooo00<0P820000000000000
2P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo0080oooo00<0P820000000000000
0P0000280?ooo`00803oool00`30`<00000000000002000000030<30`03oool0oooo01@0oooo00<0
P8200000000000002P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo00<0oooo00<0
P8200000000000000P0000000`30`<00oooo0?ooo`240?ooo`008P3oool4000001H0oooo00<0P820
0000000000002P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo00D0oooo10000026
0?ooo`008P3oool00`30`<00000000000002000000030820P03oool0oooo0180oooo00<0P8200000
000000002P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo00D0oooo00<0`<300000
000000000P0000000`30`<00oooo0?ooo`220?ooo`00903oool4000000030820P03oool0oooo0140
oooo00<0P8200000000000002P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo00L0
oooo100000240?ooo`009@3oool4000001<0oooo00<0P8200000000000002P00001P0?ooo`T00000
G03oool<000000030820P03oool0oooo00P0oooo100000230?ooo`009@3oool00`30`<0000000000
0002000000030<30`03oool0oooo00l0oooo00<0P8200000000000002P00001P0?ooo`T00000G03o
ool<000000030820P03oool0oooo00P0oooo00<0`<300000000000000P0000000`30`<00oooo0?oo
o`1o0?ooo`009`3oool400000140oooo00<0P8200000000000002P00001P0?ooo`T00000G03oool<
000000030820P03oool0oooo00X0oooo100000210?ooo`00:03oool400000100oooo00<0P8200000
000000002P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo00X0oooo00<0P8200000
000000000P0000200?ooo`00:03oool00`30`<00000000000002000000030<30`03oool0oooo00`0
oooo00<0P8200000000000002P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo00/0
oooo00D0P82000000000000000000410@01o0?ooo`00:P3oool4000000h0oooo00<0P82000000000
00002P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo00d0oooo1000001n0?ooo`00
:P3oool00`30`<00000000000002000000030<30`03oool0oooo00X0oooo00<0P820000000000000
2P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo00d0oooo00<0`<30000000000000
0P0000000`30`<00oooo0?ooo`1j0?ooo`00;03oool4000000`0oooo00<0P8200000000000002P00
001P0?ooo`T00000G03oool<000000030820P03oool0oooo00l0oooo1000001l0?ooo`00;@3oool4
000000/0oooo00<0P8200000000000002P00001P0?ooo`T00000G03oool<000000030820P03oool0
oooo00l0oooo00<0P8200000000000000P00001k0?ooo`00;@3oool00`30`<000000000000020000
00030<30`03oool0oooo00L0oooo00<0P8200000000000002P00001P0?ooo`T00000G03oool<0000
00030820P03oool0oooo0100oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`1g0?oo
o`00;`3oool4000000T0oooo00<0P8200000000000002P00001P0?ooo`T00000G03oool<00000003
0820P03oool0oooo0180oooo1000001i0?ooo`00;`3oool00`30`<00000000000002000000030820
P03oool0oooo00D0oooo00<0P8200000000000002P00001P0?ooo`T00000G03oool<000000030820
P03oool0oooo0180oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`1e0?ooo`00<@3o
ool4000000030820P03oool0oooo00@0oooo00<0P8200000000000002P00001P0?ooo`T00000G03o
ool<000000030820P03oool0oooo01@0oooo1000001g0?ooo`00<P3oool4000000H0oooo00<0P820
0000000000002P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo01D0oooo1000001f
0?ooo`00<P3oool00`30`<00000000000002000000030<30`03oool0oooo0080oooo00<0P8200000
000000002P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo01D0oooo00<0`<300000
000000000P0000000`30`<00oooo0?ooo`1b0?ooo`00=03oool4000000@0oooo00<0P82000000000
00002P00001P0?ooo`T00000G03oool<000000030820P03oool0oooo01L0oooo1000001d0?ooo`00
=@3oool4000000<0oooo00<0P8200000000000002P00001P0?ooo`T00000G03oool<000000030820
P03oool0oooo01L0oooo00<0P8200000000000000P00001c0?ooo`00=@3oool00`30`<0000000000
0002000000030<30`03oool0P82000`00000H03oool9000005`0oooo300000000`20P800oooo0?oo
o`0H0?ooo`050820P0000000000000000010@400LP3oool003L0oooo100000000`3oool0P8200000
000;00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool06P3oool400000740oooo000g
0?ooo`030<30`000000000000080000000<0@4100000000000002P00001P0?ooo`T00000G03oool<
000000030820P03oool0oooo01X0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`1]
0?ooo`00>@3oool@00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool0703oool40000
06l0oooo000j0?ooo`l00000H03oool9000005`0oooo300000000`20P800oooo0?ooo`0L0?ooo`03
0820P0000000000000800000KP3oool003X0oooo00<0`<300000000000003000001P0?ooo`T00000
G03oool<000000030820P03oool0oooo01d0oooo00<0P8200000000000000P0000000`30`<00oooo
0?ooo`1Z0?ooo`005@3oool00`20P800oooo0?ooo`0T0?ooo`d00000H03oool9000005`0oooo3000
00000`20P800oooo0?ooo`0O0?ooo`@00000K03oool001D0oooo00<000000?ooo`3oool0903oool0
0`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool07`3oool0
0`20P800000000000002000006/0oooo000E0?ooo`80000000<0P8200?ooo`3oool08P3oool00`20
P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool0803oool01@20
P8000000000000000000@41006X0oooo000E0?ooo`<0000000<0P8200?ooo`3oool08@3oool00`20
P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool08P3oool40000
06T0oooo000E0?ooo`050410@0000000000000000020P8008P3oool00`20P80000000000000:0000
0600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool08P3oool00`30`<000000000000020000
00030<30`03oool0oooo06D0oooo000F0?ooo`@0000000<0P8200?ooo`3oool07`3oool00`20P800
00000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool0903oool4000006L0
oooo000G0?ooo`@000008@3oool00`20P80000000000000:00000600oooo2@00001L0?ooo`d00000
9P3oool00`20P800000000000002000006H0oooo000H0?ooo`050410@0000000000000000020P800
7`3oool00`20P80000000000000:00000600oooo2@00001L0?ooo`h0000000<0P8200?ooo`3oool0
8`3oool01020P800000000000000001V0?ooo`006@3oool4000000030820P03oool0oooo01`0oooo
00<0P8200000000000002P00001P0?ooo`T00000G03oool?000000030820P03oool0oooo02@0oooo
0P00001V0?ooo`006P3oool01@10@4000000000000000000P82001d0oooo00<0P820000000000000
2P00001P0?ooo`T00000G03oool@000000030820P03oool0oooo02<0oooo00<0`<300000003oool0
I@3oool001/0oooo1@00000L0?ooo`030820P0000000000000X00000H03oool9000005`0oooo3000
00000`20P800000000000002000000030820P03oool0oooo08X0oooo000L0?ooo`@0000000<0P820
0?ooo`3oool06@3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P820
0?ooo`0000000`00002<0?ooo`007@3oool01@10@4000000000000000000P82001X0oooo00<0P820
0000000000002P00001P0?ooo`T00000G03oool<000000040820P03oool0oooo0410@0<0000000<0
P8200?ooo`3oool0R03oool001h0oooo100000000`20P800oooo0?ooo`0G0?ooo`030820P0000000
000000X00000H03oool9000005`0oooo300000001020P800oooo0?ooo`3oool4000000030820P03o
ool0oooo08L0oooo000O0?ooo`@000006@3oool00`20P80000000000000:00000600oooo2@00001L
0?ooo``0000000<0P8200?ooo`3oool00P3oool4000008T0oooo000P0?ooo`050410@00000000000
00000020P8005`3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P820
0?ooo`3oool00P3oool00`30`<00000000000002000000030820P03oool0oooo08D0oooo000Q0?oo
o`@0000000<0P8200?ooo`3oool0503oool00`20P80000000000000:00000600oooo2@00001L0?oo
o``0000000<0P8200?ooo`3oool0103oool4000000030820P03oool0oooo08@0oooo000R0?ooo`05
0410@0000000000000000020P8005@3oool00`20P80000000000000:00000600oooo2@00001L0?oo
o``0000000<0P8200?ooo`3oool01@3oool01@10@4000000000000000000P82008D0oooo000S0?oo
o`D00000503oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?oo
o`3oool01P3oool4000000030820P03oool0oooo0880oooo000T0?ooo`@0000000<0P8200?ooo`3o
ool04@3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3o
ool01`3oool4000008@0oooo000U0?ooo`050410@0000000000000000020P8004P3oool00`20P800
00000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool0203oool01@10@400
0000000000000000P8200880oooo000V0?ooo`@0000000<0P8200?ooo`3oool03`3oool00`20P800
00000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool02@3oool400000003
0820P03oool0oooo07l0oooo000W0?ooo`@000004@3oool00`20P80000000000000:00000600oooo
2@00001L0?ooo``0000000<0P8200?ooo`3oool02P3oool400000840oooo000X0?ooo`050410@000
0000000000000020P8003`3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``00000
00<0P8200?ooo`3oool02P3oool00`30`<00000000000002000000030<30`03oool0oooo07d0oooo
000Y0?ooo`@0000000<0P8200?ooo`3oool0303oool00`20P80000000000000:00000600oooo2@00
001L0?ooo``0000000<0P8200?ooo`3oool0303oool4000007l0oooo000Z0?ooo`050410@0000000
000000000020P8003@3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0
P8200?ooo`3oool03@3oool01@10@4000000000000000000P82007d0oooo000[0?ooo`@0000000<0
P8200?ooo`3oool02P3oool00`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0
P8200?ooo`3oool03P3oool4000000030820P03oool0oooo07X0oooo000/0?ooo`@00000303oool0
0`20P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool03`3oool4
000007`0oooo000]0?ooo`050410@0000000000000000020P8002P3oool00`20P80000000000000:
00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool03`3oool00`30`<00000000000002
000000030820P03oool0oooo07P0oooo000^0?ooo`@0000000<0P8200?ooo`3oool01`3oool00`20
P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool04@3oool40000
00030820P03oool0oooo07L0oooo000_0?ooo`050410@0000000000000000020P800203oool00`20
P80000000000000:00000600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool04P3oool01@10
@4000000000000000000P82007P0oooo000`0?ooo`D000001`3oool00`20P80000000000000:0000
0600oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool04`3oool4000000030820P03oool0oooo
07D0oooo000a0?ooo`@0000000<0P8200?ooo`3oool0103oool00`20P80000000000000:00000600
oooo2@00001L0?ooo``0000000<0P8200?ooo`3oool0503oool4000007L0oooo000b0?ooo`050410
@0000000000000000020P8001@3oool00`20P80000000000000:00000<D0oooo300000000`20P800
oooo0?ooo`0E0?ooo`050410@0000000000000000020P800M@3oool003<0oooo100000000`20P800
oooo0?ooo`020?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0oooo01H0
oooo100000000`20P800oooo0?ooo`1b0?ooo`00=03oool4000000@0oooo00<0P820000000000000
2P0000350?ooo``0000000<0P8200?ooo`3oool05`3oool4000007@0oooo000e0?ooo`050410@000
0000000000000020P8000P3oool00`20P80000000000000:00000<D0oooo300000000`20P800oooo
0?ooo`0G0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0L03oool003H0oooo1000
00000`20P800oooo0820P00<00000<D0oooo300000000`20P800oooo0?ooo`0I0?ooo`@00000LP3o
ool003L0oooo00@0@41000000000000000000P20P80<00000<D0oooo300000000`20P800oooo0?oo
o`0J0?ooo`050410@0000000000000000020P800L03oool003P0oooo4@0000350?ooo``0000000<0
P8200?ooo`3oool06`3oool4000000030820P03oool0oooo06d0oooo000i0?oooa000000a@3oool<
000000030820P03oool0oooo01`0oooo1000001_0?ooo`00>P3oool00`10@40000000000000<0000
0<D0oooo300000000`20P800oooo0?ooo`0L0?ooo`030<30`000000000000080000000<0P8200?oo
o`3oool0J`3oool003/0oooo3P0000350?ooo``0000000<0P8200?ooo`3oool07P3oool400000003
0820P03oool0oooo06X0oooo000E0?ooo`030820P03oool0oooo02@0oooo3@0000350?ooo``00000
00<0P8200?ooo`3oool07`3oool4000006`0oooo000E0?ooo`0300000020P800oooo02@0oooo00<0
P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool07`3oool00`30`<0000000000
0002000000030<30`03oool0oooo06P0oooo000E0?ooo`<00000903oool00`20P80000000000000:
00000<D0oooo300000000`20P800oooo0?ooo`0Q0?ooo`@00000JP3oool001D0oooo0`0000000`10
@400oooo0?ooo`0Q0?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0oooo
0280oooo00D0@41000000000000000000820P01X0?ooo`005@3oool00`20P8000000000000020000
0280oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool08`3oool40000
00030820P03oool0oooo06D0oooo000F0?ooo`@0000000<0P8200?ooo`3oool07`3oool00`20P800
00000000000:00000<D0oooo300000000`20P800oooo0?ooo`0T0?ooo`@00000I`3oool001L0oooo
00D0P82000000000000000000820P00P0?ooo`030820P0000000000000X00000a@3oool=00000003
0820P03oool0oooo02<0oooo00<0`<300000000000000P00001V0?ooo`00603oool00`20P8000000
00000002000001l0oooo00<0P8200000000000002P0000350?ooo`l000009P3oool3000006H0oooo
000I0?ooo`050820P0000000000000000010@4007P3oool00`20P80000000000000:00000<D0oooo
3`0000000`10@400oooo0?ooo`0T0?ooo`030410@0000000oooo06D0oooo000J0?ooo`030820P000
00000000008000007@3oool00`20P80000000000000:00000<D0oooo4@00000V0?ooo`030000003o
ool0oooo06@0oooo000K0?ooo`D00000703oool00`20P80000000000000:00000<D0oooo30000000
0`20P800000000000002000000030820P03oool0oooo08X0oooo000L0?ooo`050820P00000000000
00000010@4006`3oool00`20P80000000000000:00000<D0oooo300000000`20P800oooo0820P003
000000030820P03oool0oooo08T0oooo000M0?ooo`030820P00000000000008000006P3oool00`20
P80000000000000:00000<D0oooo300000001020P800oooo0?ooo`20P804000008X0oooo000N0?oo
o`@0000000<0P8200?ooo`3oool05`3oool00`20P80000000000000:00000<D0oooo300000001020
P800oooo0?ooo`3oool4000000030820P03oool0oooo08L0oooo000O0?ooo`050820P00000000000
00000020P800603oool00`20P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`02
0?ooo`050410@0000000000000000020P800R03oool00200oooo00<0P8200000000000000P00000G
0?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0oooo00<0oooo1@000027
0?ooo`008@3oool01@20P8000000000000000000@41001H0oooo00<0P8200000000000002P000035
0?ooo``0000000<0P8200?ooo`3oool0103oool01@20P8000000000000000000@41008H0oooo000R
0?ooo`030820P00000000000008000005@3oool00`20P80000000000000:00000<D0oooo30000000
0`20P800oooo0?ooo`050?ooo`030820P0000000000000800000Q@3oool002<0oooo1@00000D0?oo
o`030820P0000000000000X00000a@3oool<000000030820P03oool0oooo00H0oooo100000000`20
P800oooo0?ooo`220?ooo`00903oool01@20P8000000000000000000@41001<0oooo00<0P8200000
000000002P0000350?ooo``0000000<0P8200?ooo`3oool01`3oool01@20P8000000000000000000
P82008<0oooo000U0?ooo`030820P00000000000008000004P3oool00`20P80000000000000:0000
0<D0oooo300000000`20P800oooo0?ooo`080?ooo`030820P0000000000000800000PP3oool002H0
oooo00D0P82000000000000000000410@00A0?ooo`030820P0000000000000X00000a@3oool<0000
00030820P03oool0oooo00T0oooo00D0P82000000000000000000410@0210?ooo`00:03oool40000
0100oooo00<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool02P3oool00`20
P80000000000000200000800oooo000X0?ooo`030820P00000000000008000003`3oool00`20P800
00000000000:00000<D0oooo300000000`20P800oooo0?ooo`0;0?ooo`@0000000<0P8200?ooo`3o
ool0O@3oool002T0oooo00D0P82000000000000000000410@00>0?ooo`030820P0000000000000X0
0000a@3oool<000000030820P03oool0oooo00`0oooo00D0P82000000000000000000820P01n0?oo
o`00:P3oool00`20P800000000000002000000d0oooo00<0P8200000000000002P0000350?ooo``0
000000<0P8200?ooo`3oool03@3oool00`20P800000000000002000007d0oooo000[0?ooo`@00000
00<0P8200?ooo`3oool02P3oool00`20P80000000000000:00000<D0oooo300000000`20P800oooo
0?ooo`0>0?ooo`@0000000<0P8200?ooo`3oool0NP3oool002`0oooo00D0P8200000000000000000
0820P00;0?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0oooo00l0oooo
00D0@41000000000000000000820P01k0?ooo`00;@3oool00`20P800000000000002000000X0oooo
00<0P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool0403oool5000007X0oooo
000^0?ooo`050820P0000000000000000010@4002@3oool00`20P80000000000000:00000<D0oooo
300000000`20P800oooo0?ooo`0A0?ooo`050820P0000000000000000010@400N@3oool002l0oooo
00<0P8200000000000000P0000080?ooo`030820P0000000000000X00000a@3oool<000000030820
P03oool0oooo0180oooo00<0P8200000000000000P00001h0?ooo`00<03oool5000000L0oooo00<0
P8200000000000002P0000350?ooo``0000000<0P8200?ooo`3oool04`3oool4000000030820P03o
ool0oooo07D0oooo000a0?ooo`050820P0000000000000000010@4001P3oool00`20P80000000000
000:00000<D0oooo300000000`20P800oooo0?ooo`0D0?ooo`050820P0000000000000000020P800
MP3oool00380oooo00<0P8200000000000000P0000050?ooo`030820P0000000000000X00000a@3o
ool<000000030820P03oool0oooo01D0oooo00<0P8200000000000000P00001e0?ooo`00<`3oool4
000000030820P03oool0oooo0080oooo00<0P8200000000000002P0000350?ooo``0000000<0P820
0?ooo`3oool05P3oool4000000030820P03oool0oooo0780oooo000d0?ooo`050820P00000000000
00000020P8000`3oool00`20P80000000000000:00000<D0oooo300000000`20P800oooo0?ooo`0G
0?ooo`050410@0000000000000000020P800L`3oool003D0oooo00<0P8200000000000000P000002
0?ooo`030820P0000000000000X00000a@3oool<000000030820P03oool0oooo01P0oooo10000000
0`20P800oooo0?ooo`1`0?ooo`00=P3oool01`20P8000000000000000000@4100?ooo`20P8003000
00350?ooo``0000000<0P8200?ooo`3oool06@3oool01@20P8000000000000000000P8200740oooo
000g0?ooo`030820P000000000000080000000<0P8200000000000002P0000350?ooo``0000000<0
P8200?ooo`3oool06P3oool00`20P80000000000000200000700oooo000h0?oooa400000a@3oool<
000000030820P03oool0oooo01/0oooo100000000`20P800oooo0?ooo`1]0?ooo`00>@3oool00`20
P80000000000000=00000<D0oooo300000000`20P800oooo0?ooo`0L0?ooo`050410@00000000000
00000020P800KP3oool003X0oooo00<0P820000000000000300000350?ooo``0000000<0P8200?oo
o`3oool07@3oool5000006d0oooo000B0?ooo`80P8201P0000020820P1l0oooo00<0P82000000000
00002`0000350?ooo``0000000<0P8200?ooo`3oool07P3oool01@20P8000000000000000000@410
06`0oooo000@0?ooo`030820P0000000000000<000000`3oool5000001h0oooo00<0P82000000000
00002P0000350?ooo``0000000<0P8200?ooo`3oool07`3oool00`20P800000000000002000006/0
oooo000?0?ooo`@0000000@0P8200?ooo`0000000000103oool4000001d0oooo00<0P82000000000
00002P0000350?ooo``0000000<0P8200?ooo`3oool0803oool4000000030820P03oool0oooo06P0
oooo000=0?ooo`050410@0000000000000000020P8000`3oool3000000030<30`03oool0oooo0080
oooo00@0@410000000000000@4106`3oool00`20P80000000000000:00000<D0oooo300000000`20
P800oooo0?ooo`0Q0?ooo`050820P0000000000000000020P800J@3oool000`0oooo1@0000040?oo
o`@000001@3oool4000000030820P03oool0oooo01L0oooo00<0P8200000000000002P0000350?oo
o``0000000<0P8200?ooo`3oool08P3oool00`20P800000000000002000006P0oooo000=0?ooo`D0
00000`3oool00`20P800000000000002000000D0oooo1000000I0?ooo`030820P0000000000000X0
0000a@3oool<000000030820P03oool0oooo02<0oooo100000000`20P800oooo0?ooo`1U0?ooo`00
3@3oool5000000@0oooo00D0P82000000000000000000410@0050?ooo`050410@000000000000000
0020P8005`3oool00`20P80000000000000:00000<D0oooo300000000`10@400oooo0?ooo`0T0?oo
o`050410@0000000000000000020P800IP3oool000d0oooo00<0P8200000000000000`0000050?oo
o`@000001@3oool4000001L0oooo00<0P8200000000000002P0000350?ooo`h000009P3oool40000
06H0oooo000=0?ooo`030820P0000000000000<000001@3oool00`30`<0000000000000200000005
0<30`03oool0oooo0?ooo`20P8000`0000000`10@400oooo0?ooo`0D0?ooo`030820P00000000000
00X00000a@3oool?000000030<30`03oool0oooo02<0oooo00<0P820000000000000IP3oool000d0
oooo00<0P8200000000000000`0000070?ooo`@00000103oool5000001D0oooo00<0P82000000000
00002P0000350?oooa0000009P3oool00`20P80000000?ooo`1U0?ooo`003P3oool5000000030820
P03oool0oooo00@0oooo00<0P8200000000000000P0000030?ooo`030820P0000000000000800000
5@3oool00`20P80000000000000:00000<D0oooo4@00000V0?ooo`030000003oool0oooo06@0oooo
000>0?ooo`D0000000<0P8200?ooo`3oool01@3oool00`20P800000000000002000000030<30`03o
ool0`<3000D0000000<0`<300?ooo`3oool04@3oool00`20P80000000000000:00000<D0oooo3000
00020820P0<0000000<0@4100?ooo`3oool0RP3oool000l0oooo1@0000090?ooo`@000000P3oool5
000000030820P03oool0oooo0140oooo00<0P8200000000000002P0000350?ooo``0000000<0P820
0?ooo`3oool01000002;0?ooo`003`3oool5000000T0oooo00<0P8200000000000000P0000000`3o
ool0000000000004000001<0oooo00<0P8200000000000002P0000350?ooo``0000000@0P8200?oo
o`3oool0P8201000002:0?ooo`003`3oool5000000X0oooo00H0P82000000000000000000410@03o
ool5000001<0oooo00<0P8200000000000002P0000350820P0`0000000D0P8200?ooo`3oool0oooo
0820P003000000030410@03oool0oooo08L0oooo000@0?ooo`D000002`3oool:00000180oooo00<0
P820000000000000f`0000000`20P800oooo0?ooo`020?ooo`030820P0000000000000800000R03o
ool00100oooo1@00000;0?ooo`030<30`0000000000000L0000000<0`<300?ooo`3oool03`3oool0
0`20P80000000000003K000000030820P03oool0oooo00<0oooo00<0P8200000000000000P000000
0`30`<00oooo0?ooo`240?ooo`00403oool00`20P800000000000002000000030820P03oool0oooo
00X0oooo200000000`20P800oooo0?ooo`0?0?ooo`030820P000000000000=/0000000<0P8200?oo
o`3oool01@3oool4000008H0oooo000@0?ooo`030820P000000000000080000000<0P8200?ooo`3o
ool02P3oool00`20P800000000000005000000030820P03oool0oooo00l0oooo00<0P82000000000
0000f`0000000`20P800oooo0?ooo`050?ooo`030820P0000000000000800000Q@3oool00100oooo
00<0P8200000000000000P0000000`10@400oooo0?ooo`0;0?ooo`030820P0000000000000@00000
00<0@4100?ooo`3oool03`3oool00`20P80000000000003K000000030820P03oool0oooo00H0oooo
00D0P82000000000000000000410@0240?ooo`004@3oool5000000l0oooo1P00000A0?ooo`030820
P000000000000=/0000000<0P8200?ooo`3oool0203oool4000008<0oooo000A0?ooo`D0000000<0
P8200?ooo`3oool0303oool00`10@40000000000000300000140oooo00<0P820000000000000f`00
00000`20P800oooo0?ooo`080?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0O`3o
ool00180oooo1@00000>0?ooo`H000004@3oool00`20P80000000000003K000000030820P03oool0
oooo00X0oooo100000210?ooo`004P3oool6000000d0oooo1`00000@0?ooo`030820P00000000000
0=/0000000<0P8200?ooo`3oool02P3oool00`20P80000000000000200000800oooo000B0?ooo`H0
000000<0`<300?ooo`3oool02P3oool600000140oooo00<0P820000000000000f`0000000`20P800
oooo0?ooo`2?0?ooo`004`3oool6000000`0oooo1P00000A0?ooo`030820P000000000000=/00000
00<0P8200?ooo`3oool0S`3oool001<0oooo1`00000:0?ooo`L000005P3oool3000000030820P03o
ool0oooo0?l0ooooIP3oool001<0oooo00<0@4100000000000000P0000001020P80000000410@020
P8060?ooo`030<30`0000000000000D0000000<0P8200?ooo`3oool0503oool3000000030820P03o
ool0oooo0:l0oooo1@20P8000`30`<00oooo0?ooo`2^0?ooo`004`3oool00`20P800000000000002
000000030820P03oool000000080000000<0P8200?ooo`3oool00P3oool8000000030820P03oool0
oooo01@0oooo0`0000000`20P800oooo0?ooo`2/0?ooo`030820P0000000000000P00000[P3oool0
01<0oooo00<0P8200000000000000P0000000`10@400oooo0<30`00>000000030820P03oool0oooo
01D0oooo0`0000000`20P800oooo0?ooo`2Z0?ooo`030820P000000000000080000000<0@4100820
P03oool00P3oool00`30`<00P82000000002000000030820P03oool0oooo0:T0oooo000D0?ooo`D0
00000`3oool=000001P0oooo0`0000000`20P800oooo0?ooo`2Y0?ooo`030820P0000000000000<0
0000203oool500000:T0oooo000D0?ooo`D00000103oool;000001T0oooo0`0000000`20P800oooo
0?ooo`2Y0?ooo`D000002P3oool4000000030820P03oool0oooo0:H0oooo000D0?ooo`030820P000
000000000080000000<0P8200?ooo`3oool00P3oool20820P0030410@000000000000080000000<0
@4100820P03oool06@3oool3000000030820P03oool0oooo0:P0oooo1@0000000`20P800oooo0?oo
o`090?ooo`D0000000<0`<300?ooo`3oool0Y03oool001D0oooo1@00000W0?ooo`<0000000<0P820
0?ooo`3oool0Y`3oool00`20P800000000000003000000`0oooo00<0P8200000000000000`00002V
0?ooo`005@3oool5000002L0oooo0`0000000`20P800oooo0?ooo`0O0?ooo`030820P00000000000
0080000000<0P8200?ooo`3oool0P03oool00`20P800000000000003000000d0oooo1P00002U0?oo
o`005@3oool00`10@400000000000002000000030820P03oool0oooo02@0oooo0`0000000`20P800
oooo0?ooo`0O0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0P03oool00`10@400
000000000003000000h0oooo1P00002T0?ooo`005@3oool00`20P800000000000002000000030820
P03oool0oooo02@0oooo0`0000000`20P800oooo0?ooo`0O0?ooo`030820P0000000000000800000
00<0P8200?ooo`3oool0P03oool5000000030820P03oool0oooo00d0oooo1@0000000`20P800oooo
0?ooo`2Q0?ooo`005@3oool00`30`<00000000000002000000030410@03oool0oooo02@0oooo0`00
00000`20P800oooo0?ooo`0P0?ooo`D00000PP3oool6000000l0oooo00<0@4100000000000000`00
002S0?ooo`005P3oool5000002H0oooo0`0000000`20P800oooo0?ooo`0P0?ooo`D00000PP3oool6
000000l0oooo00<0P8200000000000001000002R0?ooo`005P3oool5000002H0oooo0`0000000`20
P800oooo0?ooo`0P0?ooo`D00000PP3oool600000100oooo1P00002R0?ooo`005P3oool00`20P800
000000000003000002D0oooo0`0000000`20P800oooo0?ooo`0P0?ooo`030820P000000000000080
000000<0P8200?ooo`3oool0O`3oool600000100oooo1P0000000`20P800oooo0?ooo`2O0?ooo`00
5`3oool5000002D0oooo0`0000000`20P800oooo0?ooo`0Q0?ooo`D00000P@3oool600000140oooo
1P00002Q0?ooo`005`3oool00`20P800000000000003000002@0oooo0`0000000`20P800oooo0?oo
o`0Q0?ooo`D00000P@3oool00`10@400000000000003000000030820P03oool0oooo00h0oooo00<0
@4100000000000000`0000000`20P800oooo0?ooo`2N0?ooo`00603oool5000002@0oooo0`000000
0`20P800oooo0?ooo`0Q0?ooo`D00000P@3oool00`20P80000000000000400000100oooo00<0P820
0000000000001000002P0?ooo`00603oool5000002@0oooo0`0000000`20P800oooo0?ooo`0R0?oo
o`D00000P03oool00`20P80000000000000400000100oooo00<0P8200000000000001000002P0?oo
o`00603oool00`10@400000000000002000000030820P03oool0oooo0240oooo0`0000000`20P800
oooo0?ooo`0R0?ooo`D00000P@3oool6000000030820P03oool0oooo00d0oooo00<0`<3000000000
0000100000000`20P800oooo0?ooo`2M0?ooo`00603oool5000000030820P03oool0oooo0240oooo
0`0000000`20P800oooo0?ooo`0R0?ooo`D00000P@3oool700000100oooo1`00002O0?ooo`00603o
ool6000002<0oooo0`0000000`20P800oooo0?ooo`0R0?ooo`D00000PP3oool6000000030820P03o
ool0oooo00d0oooo1`00002O0?ooo`004`3oool;000002<0oooo0`0000000`20P800oooo0?ooo`0R
0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0F@3oool20820P0030<30`03oool0
oooo0240oooo00<0@4100000000000000`0000000`20P800oooo0?ooo`0=0?ooo`L00000W`3oool0
01D0oooo2@00000S0?ooo`<0000000<0P8200?ooo`3oool0803oool:000005T0oooo0P0000000`20
P800oooo0?ooo`0Q0?ooo`030820P0000000000000@000003`3oool7000009l0oooo000I0?ooo`@0
P8200P00000R0?ooo`<0000000<0P8200?ooo`3oool07@3oool00`10@40000000000000<00000003
0410@020P800oooo05@0oooo0`0000000`20P800oooo0?ooo`0Q0?ooo`030820P0000000000000<0
000000<0P8200?ooo`3oool0303oool7000009l0oooo00110?ooo`<0000000<0P8200?ooo`3oool0
6`3oool7000000030?ooo`000000000000<000000P3oool5000000030820P03oool0oooo0580oooo
0`00000T0?ooo`H000003`3oool6000009l0oooo00110?ooo`<0000000<0P8200?ooo`3oool06P3o
ool00`20P800000000000003000000<0oooo1@0000030?ooo`H00000D`3oool3000000030820P03o
ool0oooo0280oooo1@0000000`20P800oooo0?ooo`0<0?ooo`H00000W`3oool00440oooo0`000000
0`20P800oooo0?ooo`0I0?ooo`030820P0000000000000<0000000@0`<300?ooo`3oool0oooo1@00
00040?ooo`030<30`000000000000080000000<0@4100?ooo`3oool0D03oool4000000030820P03o
ool0oooo0240oooo00<0`<300000000000000`00000=0?ooo`H00000X03oool00440oooo0`000000
0`20P800oooo0?ooo`0I0?ooo`H000001@3oool4000000H0oooo1@00001A0?ooo`D000009@3oool5
000000`0oooo1P00002P0?ooo`00@@3oool3000000030820P03oool0oooo01P0oooo1P0000060?oo
o`D000001P3oool500000500oooo1P00000U0?ooo`D000002`3oool500000:40oooo00110?ooo`<0
000000<0P8200?ooo`3oool05`3oool00`20P800000000000004000000H0oooo1@0000060?ooo`03
0820P000000000000080000000<0@4100?ooo`3oool0C@3oool6000000030410@03oool0oooo0280
oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`070?ooo`030<30`000000000000080
000000<0@4100?ooo`3oool0W`3oool00440oooo0`0000000`20P800oooo0?ooo`0G0?ooo`030820
P0000000000000<0000000<0P8200?ooo`3oool0103oool5000000L0oooo1P00001>0?ooo`L00000
9P3oool00`20P800000000000002000000P0oooo1@00002R0?ooo`00@@3oool3000000030820P03o
ool0oooo01L0oooo1P0000000`20P800oooo0?ooo`040?ooo`030820P0000000000000800000203o
ool5000000030820P03oool0oooo04/0oooo200000000`20P800oooo0?ooo`0S0?ooo`80P8200P00
00000`10@400P8200?ooo`030?ooo`030<30`000000000000080000000<0@4100?ooo`3oool0X@3o
ool00440oooo0`0000000`20P800oooo0?ooo`0G0?ooo`H0000000<0P8200?ooo`3oool0103oool0
0`20P800000000000003000000L0oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`1;
0?ooo`P0000000<0P8200?ooo`3oool09P3oool:00000:D0oooo00110?ooo`<0000000<0P8200?oo
o`3oool05`3oool6000000030820P03oool0oooo00@0oooo00<0P8200000000000000`0000070?oo
o`030820P0000000000000<0000000<0P8200?ooo`3oool0B`3oool5000000040820P00000000000
0820P2X0oooo1P00002W0?ooo`00@@3oool3000000030820P03oool0oooo01L0oooo1P0000000`20
P800oooo0?ooo`050?ooo`D00000203oool6000004d0oooo1@0000001@20P800oooo000000000000
P8200=H0oooo00110?ooo`<0000000<0P8200?ooo`3oool05`3oool6000000030820P03oool0oooo
00D0oooo1@0000080?ooo`H00000C@3oool5000000030820P03oool0oooo00800000eP3oool00440
oooo0`0000000`20P800oooo0?ooo`0G0?ooo`H0000000<0P8200?ooo`3oool01@3oool00`20P800
000000000002000000030<30`03oool0oooo00H0oooo1P00001<0?ooo`D0000000H0P8200?ooo`3o
ool0`<3000000010@43E0?ooo`00@@3oool3000000030820P03oool0oooo01L0oooo1P0000000`20
P800oooo0?ooo`060?ooo`@0000000<0P8200?ooo`3oool01P3oool6000004`0oooo1@0000001020
P800oooo0?ooo`3oool300000=@0oooo00110?ooo`<0000000<0P8200?ooo`3oool05`3oool00`20
P800000000000004000000P0oooo100000000`20P800oooo0?ooo`060?ooo`H00000C03oool50000
00030820P03oool0oooo0080oooo0P00003D0?ooo`00@@3oool3000000030820P03oool0oooo01L0
oooo00<0P820000000000000100000080?ooo`@0000000<0P8200?ooo`3oool01`3oool500000003
0820P03oool0oooo0180oooo00<0P8200000000000008`00000A0?ooo`D0000000<0@4100?ooo`3o
ool00P3oool01030`<00000000000030`<3B0?ooo`00@@3oool3000000030820P03oool0oooo01L0
oooo00<0P820000000000000100000090?ooo`@000002@3oool5000000030820P03oool0oooo0180
oooo00<0P8200000000000008`00000A0?ooo`030820P0000000000000<000001@3oool300000=80
oooo00110?ooo`<0000000<0P8200?ooo`3oool0603oool6000000T0oooo100000090?ooo`D00000
00<0P8200?ooo`3oool0B@3oool00`20P800000000000003000000H0oooo0P00003B0?ooo`00@@3o
ool3000000030820P03oool0oooo01P0oooo1`0000080?ooo`@000002@3oool5000000030820P03o
ool0oooo04T0oooo00<0P8200000000000000`0000070?ooo`80000000<0P8200?ooo`3oool0cP3o
ool00440oooo0`0000000`20P800oooo0?ooo`0I0?ooo`H00000203oool01020P800000000000000
00090?ooo`D0000000<0P8200?ooo`3oool0B@3oool00`20P800000000000003000000L0oooo00@0
P820000000000000P820c`3oool00440oooo0`0000000`20P800oooo0?ooo`0I0?ooo`030820P000
0000000000<0000000<0P8200?ooo`3oool01@3oool01@20P8000000000000000000P82000P0oooo
1@0000000`20P800oooo0?ooo`190?ooo`030820P0000000000000<00000203oool00`20P8000000
0410@03?0?ooo`00@@3oool3000000030820P03oool0oooo01X0oooo1P0000070?ooo`030820P000
0000000000800000203oool5000000030820P03oool0oooo04T0oooo00<0P8200000000000000`00
00090?ooo`<00000cP3oool00440oooo0`0000000`20P800oooo0?ooo`0J0?ooo`030820P0000000
000000<000001`3oool00`20P800000000000002000000P0oooo1@0000000`20P800oooo0?ooo`19
0?ooo`030820P0000000000000<000002P3oool200000<h0oooo00110?ooo`<0000000<0P8200?oo
o`3oool06P3oool00`30`<00000000000004000000030820P03oool0oooo00@0oooo100000070?oo
o`030820P0000000000000<00000C03oool00`20P800000000000003000000030820P03oool0oooo
00L0oooo00<0`<3000000010@400c@3oool00440oooo0`0000000`20P800oooo0?ooo`0L0?ooo`H0
00001P3oool4000000L0oooo1P00001=0?ooo`H000002P3oool300000<`0oooo00110?ooo`<00000
00<0P8200?ooo`3oool07@3oool5000000030820P03oool0oooo00<0oooo100000000`20P800oooo
0?ooo`030?ooo`H00000CP3oool6000000/0oooo0P00003<0?ooo`00@@3oool3000000030820P03o
ool0oooo01d0oooo00<0`<300000000000000`0000000`20P800oooo0?ooo`030?ooo`<0000000<0
P8200?ooo`3oool00P3oool00`30`<00000000000003000000030410@03oool0oooo01@0oooo00<0
P8200000000000008`00000B0?ooo`H000002`3oool01030`<00000000000030`<3:0?ooo`00@@3o
ool3000000030820P03oool0oooo01l0oooo1@0000000`20P800oooo0?ooo`020?ooo`<0000000<0
P8200?ooo`3oool00P3oool6000001L0oooo00<0P8200000000000008`00000B0?ooo`H00000303o
ool300000<X0oooo00110?ooo`<0000000<0P8200?ooo`3oool07`3oool00`30`<00P82000000004
000000030820P030`<00oooo00<0000000@0P8200?ooo`3oool0P8201@0000000`20P800oooo0?oo
o`1>0?ooo`H000003@3oool00`20P80000000820P0390?ooo`00@@3oool3000000030820P03oool0
oooo0280oooo00<0P8200000000000003`0000000`20P800oooo0?ooo`1?0?ooo`H000003P3oool0
0`20P80000000820P0380?ooo`00@@3oool3000000030820P03oool0oooo02@0oooo3`00001C0?oo
o`H000003P3oool00`20P80000000820P0380?ooo`00@@3oool3000000030820P03oool0oooo02L0
oooo0`20P803000000<0P820EP3oool6000000030820P03oool0oooo00`0oooo00<0P82000000020
P800a`3oool00440oooo0`0000000`20P800oooo0?ooo`0Z0?ooo`030820P0000000000005X0oooo
1P00000?0?ooo`030820P000000000000<H0oooo00110?ooo`<0000000<0P8200?ooo`3oool0:P3o
ool01020P800000000000000001I0?ooo`H000003`3oool01030`<00000000000030`<350?ooo`00
@@3oool3000000030820P03oool0oooo02X0oooo00@0P8200000000000000000F@3oool600000140
oooo0P0000350?ooo`00@@3oool3000000030820P03oool0oooo02X0oooo00@0P820000000000000
0000F@3oool600000140oooo0`0000340?ooo`00@@3oool3000000030820P03oool0oooo02/0oooo
0`00001I0?ooo`H000004P3oool00`10@40000000820P0330?ooo`00@@3oool3000000030820P03o
ool0oooo02/0oooo1000001H0?ooo`H000004P3oool01020P800000000000020P8320?ooo`00@@3o
ool3000000030820P03oool0oooo02/0oooo1000001H0?ooo`H000004`3oool300000<80oooo0011
0?ooo`<0000000<0P8200?ooo`3oool0;03oool3000005P0oooo1P0000000`30`<00oooo0?ooo`0A
0?ooo`80000000<0P8200?ooo`3oool0_`3oool00440oooo0`0000000`20P800oooo0?ooo`0/0?oo
o`<00000F03oool00`20P800000000000003000000030820P03oool0oooo0180oooo0P0000000`20
P800oooo0?ooo`2n0?ooo`00@@3oool3000000030820P03oool0oooo02`0oooo00@0@41000000000
0000`<30E`3oool00`10@400000000000003000000030820P03oool0oooo0180oooo0`0000000`20
P800oooo0?ooo`2m0?ooo`00@@3oool3000000030820P03oool0oooo02`0oooo00@0P82000000000
0000P820E`3oool7000001@0oooo1@00002n0?ooo`00@@3oool3000000030820P03oool0oooo02`0
oooo00@0P820000000000000P820E`3oool7000001@0oooo1@0000000`20P800oooo0?ooo`2k0?oo
o`00@@3oool3000000030820P03oool0oooo02`0oooo00@0P820000000000000P820E@3oool00`20
P800000000000007000000030820P03oool0oooo00h0oooo0P20P807000000030820P03oool0oooo
0;T0oooo00110?ooo`<0000000<0P8200?ooo`3oool0;@3oool300000540oooo4`00000:0?ooo`h0
000000<0P8200?ooo`3oool0]P3oool00440oooo0`0000000`20P800oooo0?ooo`210?oooa<00000
2`3oool=000000030820P03oool0oooo0;H0oooo00110?ooo`<0000000<0P8200?ooo`3oool0o`3o
oomV0?ooo`00@@3oool3000000030820P03oool0oooo0?l0ooooIP3oool00440oooo0`0000000`20
P800oooo0?ooo`3o0?ooofH0oooo00110?ooo`<0000000<0P8200?ooo`3oool0o`3ooomV0?ooo`00
@@3oool3000000030820P03oool0oooo0?l0ooooIP3oool00440oooo0`0000000`20P800oooo0?oo
o`3o0?ooofH0oooo00110?ooo`<0000000<0P8200?ooo`3oool0o`3ooomV0?ooo`00@@3oool30000
00030820P03oool0oooo0?l0ooooIP3oool00440oooo0`0000000`20P800oooo0?ooo`3o0?ooofH0
oooo00110?ooo`<0000000<0P8200?ooo`3oool0o`3ooomV0?ooo`00@@3oool3000000030820P03o
ool0oooo0?l0ooooIP3oool00440oooo0`0000000`20P800oooo0?ooo`3o0?ooofH0oooo00110?oo
o`<0000000<0P8200?ooo`3oool0o`3ooomV0?ooo`00@@3oool3000000030820P03oool0oooo0?l0
ooooIP3oool00440oooo0`0000000`20P800oooo0?ooo`3o0?ooofH0oooo00110?ooo`<0000000<0
P8200?ooo`3oool0o`3ooomV0?ooo`00@@3oool3000000030820P03oool0oooo0?l0ooooIP3oool0
0440oooo0`0000000`20P800oooo0?ooo`3o0?ooofH0oooo00110?ooo`<0000000<0P8200?ooo`3o
ool0o`3ooomV0?ooo`00@@3oool3000000030820P03oool0oooo0?l0ooooIP3oool00440oooo0`00
00000`20P800oooo0?ooo`3o0?ooofH0oooo00110?ooo`<0000000<0P8200?ooo`3oool0o`3ooomV
0?ooo`00@@3oool3000000030820P03oool0oooo0?l0ooooIP3oool00440oooo0`0000000`20P800
oooo0?ooo`3o0?ooofH0oooo00110?ooo`<0000000<0P8200?ooo`3oool0o`3ooomV0?ooo`00@@3o
ool3000000030820P03oool0oooo0?l0ooooIP3oool00440oooo0`0000000`20P800oooo0?ooo`3o
0?ooofH0oooo00110?ooo`<0000000<0P8200?ooo`3oool0o`3ooomV0?ooo`00@@3oool300000003
0820P03oool0oooo0?l0ooooIP3oool00440oooo0`0000000`20P800oooo0?ooo`3o0?ooofH0oooo
00110?ooo`<0000000<0P8200?ooo`3oool0o`3ooomV0?ooo`00@@3oool3000000030820P03oool0
oooo0?l0ooooIP3oool00440oooo0`0000000`20P800oooo0?ooo`3o0?ooofH0oooo00110?ooo`<0
000000<0P8200?ooo`3oool0o`3ooomV0?ooo`00@@3oool3000000030820P03oool0oooo0?l0oooo
IP3oool00440oooo0`0000000`20P800oooo0?ooo`3o0?ooofH0oooo00110?ooo`<0000000<0P820
0?ooo`3oool0o`3ooomV0?ooo`00@@3oool3000000030820P03oool0oooo0?l0ooooIP3oool00440
oooo0`0000000`20P800oooo0?ooo`3o0?ooofH0oooo00110?ooo`<0000000<0P8200?ooo`3oool0
o`3ooomV0?ooo`00@@3oool3000000030820P03oool0oooo0?l0ooooIP3oool00440oooo0`000000
0`20P800oooo0?ooo`3o0?ooofH0oooo00110?ooo`<0000000<0P8200?ooo`3oool0o`3ooomV0?oo
o`00@@3oool3000000030820P03oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`00
@@3oool3000000030820P03oool0oooo01D0oooo0P0000000`20P800oooo0?ooo`3o0?oood`0oooo
00110?ooo`<0000000<0P8200?ooo`3oool05@3oool400000?l0ooooC@3oool00440oooo0`000000
0`20P800oooo0?ooo`0E0?ooo`D00000o`3ooom<0?ooo`00@@3oool3000000030820P03oool0oooo
01D0oooo00<0P8200?ooo`20P8000P0000000`10@400oooo0?ooo`3o0?ooodT0oooo00110?ooo`<0
000000<0P8200?ooo`3oool06@3oool300000?l0ooooBP3oool00440oooo0`0000000`20P800oooo
0?ooo`0J0?ooo`040410@000000000000<30`?l0ooooB03oool00440oooo0`0000000`20P800oooo
0?ooo`0K0?ooo`<00000o`3ooom80?ooo`00@@3oool3000000030820P03oool0oooo01`0oooo0`00
003o0?ooodL0oooo00110?ooo`<0000000<0P8200?ooo`3oool07@3oool00`10@40000000410@03o
0?ooodH0oooo00110?ooo`<0000000<0P8200?ooo`3oool07P3oool300000?l0ooooA@3oool00440
oooo0`0000000`20P800oooo0?ooo`0O0?ooo`<00000o`3ooom40?ooo`00@@3oool3000000030820
P03oool0oooo01l0oooo00@0`<30000000000000`<30o`3ooom30?ooo`00@@3oool3000000030820
P03oool0oooo0200oooo0`00003o0?oood<0oooo00110?ooo`<0000000<0P8200?ooo`3oool0803o
ool4000000030<30`03oool0oooo0?l0oooo?`3oool00440oooo0`0000000`20P800oooo0?ooo`0P
0?ooo`D00000o`3ooom10?ooo`00@@3oool3000000030820P03oool0oooo0200oooo1P00003o0?oo
od00oooo00110?ooo`<0000000<0P8200?ooo`3oool07`3oool00`20P80000000000000500000?l0
oooo?`3oool00440oooo0`0000000`20P800oooo0?ooo`0O0?ooo`030820P0000000000000D00000
00<0P8200?ooo`3oool0o`3oooll0?ooo`00@@3oool3000000030820P03oool0oooo01l0oooo00<0
P8200000000000000`000000103oool0P82000000020P83o0?ooocd0oooo00110?ooo`<0000000<0
P8200?ooo`3oool07`3oool00`20P80000000000000300000080oooo0`00003o0?oooc`0oooo0011
0?ooo`<0000000<0P8200?ooo`3oool07`3oool00`20P80000000000000300000080oooo00<0P820
000000000000o`3oooll0?ooo`00@@3oool3000000030820P03oool0oooo01l0oooo00<0P8200000
000000000P0000001`10@400oooo0?ooo`3oool0P82000000010@400o`3ooolk0?ooo`00@@3oool3
000000030820P03oool0oooo01l0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`02
0?ooo`<00000o`3ooolj0?ooo`00@@3oool3000000030820P03oool0oooo01l0oooo00<0P8200000
000000000P0000000`20P800oooo0?ooo`030?ooo`800000o`3ooolj0?ooo`00@@3oool300000003
0820P03oool0oooo01l0oooo00<0@4100000000000000P0000000`20P800oooo0?ooo`030?ooo`03
0<30`0000000@4100?l0oooo>@3oool00440oooo0`0000000`20P800oooo0?ooo`0O0?ooo`D00000
00<0P8200?ooo`3oool0103oool200000?l0oooo>@3oool00440oooo0`0000000`20P800oooo0?oo
o`0O0?ooo`D0000000<0P8200?ooo`3oool01@3oool00`10@40000000820P03o0?ooocL0oooo0011
0?ooo`<0000000<0P8200?ooo`3oool07`3oool5000000030820P03oool0oooo00D0oooo00<0P820
000000000000o`3ooolg0?ooo`00>`3oool?000001`0oooo1@0000000`20P800oooo0?ooo`060?oo
o`80000000<0P8200?ooo`3oool0o`3ooold0?ooo`00=`3oool00`30`<00P8200000000B00000003
0410@020P800P82001L0oooo1@0000000`30`<00oooo0?ooo`070?ooo`800000o`3ooolf0?ooo`00
=`3ooolH000001L0oooo1@00000;0?ooo`800000o`3ooole0?ooo`00=`3oool00`20P80000000000
000D000001P0oooo1@00000;0?ooo`030820P0000000P8200?l0oooo=03oool003L0oooo00<0P820
0000000000005000000G0?ooo`030820P0000000000000<000002`3oool00`30`<0000000410@03o
0?oooc@0oooo000h0?oooaD00000603oool6000000`0oooo0P00003o0?oooc@0oooo000h0?oooa@0
000000<0@4100?ooo`3oool05P3oool6000000d0oooo0P0000000`20P800oooo0?ooo`3o0?oooc00
oooo000i0?oooa<0000000<0P8200?ooo`3oool05P3oool6000000d0oooo00<0P820000000000000
o`3ooolb0?ooo`00>@3ooolC000000030820P03oool0oooo01H0oooo1P00000>0?ooo`800000o`3o
oolb0?ooo`00>@3oool00`20P80000000000000@000001T0oooo1P00000>0?ooo`80000000<0P820
0?ooo`3oool0o`3oool_0?ooo`00>P3ooolB000001T0oooo1@00000?0?ooo`80000000<0P8200?oo
o`3oool0o`3oool_0?ooo`00>P3oool00`10@40000000000000>000001T0oooo00<0P82000000000
00000`00000>0?ooo`040410@0000000000000000?l0oooo<@3oool003X0oooo00<0P82000000000
00003P00000I0?ooo`030820P0000000000000<000003@3oool500000?l0oooo<@3oool003X0oooo
00<0P8200000000000003@00000J0?ooo`H00000303oool00`20P80000000000000300000?l0oooo
<@3oool003/0oooo3P0000000`10@400oooo0?ooo`0B0?ooo`D0P8201P0000000`10@400oooo0?oo
o`0:0?ooo`030820P0000000000000<00000o`3ooola0?ooo`00>`3oool>000000030820P03oool0
oooo0180oooo2`0000000`20P800oooo0?ooo`0:0?ooo`030820P0000000000000<00000o`3ooola
0?ooo`00?03oool=000000030820P03oool0oooo01<0oooo2P0000000`20P800oooo0?ooo`0:0?oo
o`030820P000000000000080000000<0P8200?ooo`3oool0o`3oool_0?ooo`00?03oool=000001X0
oooo0`20P8000`10@40000000000000>0?ooo`040820P000000000000820P?l0oooo<P3oool003`0
oooo00<0P8200000000000002P00003o0?ooof@0oooo000l0?ooo`030<30`0000000000000T00000
o`3ooomU0?ooo`00?@3oool:000000030820P03oool0oooo0?l0ooooH`3oool003d0oooo2P000000
0`20P800oooo0?ooo`3o0?ooof<0oooo000n0?ooo`T0000000<0P8200?ooo`3oool0o`3ooomS0?oo
o`00?P3oool900000?l0ooooIP3oool003l0oooo2000003o0?ooofH0oooo000o0?ooo`L0000000<0
P8200?ooo`3oool0o`3ooomT0?ooo`00?`3oool00`20P80000000000000400000?l0ooooI`3oool0
03l0oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`3o0?ooofD0oooo00100?ooo`D0
0000o`3ooomX0?ooo`00@03oool4000000030820P03oool0oooo0?l0ooooIP3oool00400oooo00D0
P82000000000000000000820P03o0?ooofP0oooo00110?ooo`<00000o`3ooomY0?ooo`00@@3oool0
0`20P80000000000003o0?ooofT0oooo00120?ooo`030000003oool0oooo0?l0ooooJ03oool00480
oooo00<000000?ooo`3oool0o`3ooomX0?ooo`00@P3oool00`30`<00oooo0?ooo`3o0?ooofP0oooo
003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo
003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo
003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo
003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo
003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo
003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo
003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo003o0?ooojd0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{82.125, 165.5},
  ImageMargins->{{0, 0}, {0, 2.375}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 3.10 Current density in a wire", "Caption",
  CellTags->"Fig. 3.10"],

Cell["\<\
\tThe boundary conditions on the top and bottom faces of the wire \
are set by the applied potentials: \
\>", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, 0) = 0\)]],
  ",\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, b) = V\_o\)]],
  "."
}], "Text"],

Cell[TextData[{
  "However, the boundary conditions on the two insulated sides are determined \
by the fact that no current flows through these sides, so the current runs \
parallel to these faces. Therefore, according to Ohm's law, ",
  Cell[BoxData[
      \(TraditionalForm\`j\_x = \(\[Sigma]\ E\_x = \(\(-\[Sigma]\) \
\[PartialD]\[Phi]\/\[PartialD]x = 0\)\)\)]],
  " along these faces, so we have von Neumann conditions on these faces:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\[PartialD]\[Phi]\/\[PartialD]x\) \((0, 
          y)\) = \(\(\[PartialD]\[Phi]\/\[PartialD]x\) \((a, y)\) = 
        0\)\)]]], "NE2",
  CellTags->"(3.2.13)"],

Cell[TextData[{
  "Furthermore, the potential in the interior of the conductor must satisfy \
Laplace's equation. This is because there are no sources or sinks of current \
in the interior of the rod, so ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Del]", 
            RowBox[{"\[CenterDot]", 
              StyleBox["j",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " [recall the discussion surrounding Eq. ",
  ButtonBox["(1.2.12)",
    ButtonData:>{"Chapter1.nb", "(1.2.12)"},
    ButtonStyle->"Hyperlink"],
  "]. Then Ohm's law implies"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Del]", 
            RowBox[{"\[CenterDot]", 
              StyleBox[
                RowBox[{"\[Sigma]", 
                  StyleBox["E",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{\(-\[Sigma]\), 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox[\(\[Del]\^2 \[Phi]\),
                FontWeight->"Plain"]}], 
            StyleBox["=",
              FontWeight->"Plain"], 
            StyleBox["0",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe can now solve this Laplace's equation for the potential, using \
separation of variables. Given the boundary conditions of Eq. ",
  ButtonBox["(3.2.13)",
    ButtonData:>"(3.2.13)",
    ButtonStyle->"Hyperlink"],
  ",  we expect from our standard separation-of-variables argument that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  " will consist of a sum of terms of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y(y)\)\ \(X(x)\)\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(X(x)\)\(\ \)\)\)]],
  " being an eigenmode of the von Neumann form,  ",
  Cell[BoxData[
      \(TraditionalForm\`X(x)\  = \ cos(n\ \[Pi]\ x/a)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2, \(\(...\)\(.\)\)\)]],
  "  Substitution of this form into ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Del]\^2 \[Phi] = 0\),
          FontWeight->"Plain"], TraditionalForm]]],
  " then implies that ",
  Cell[BoxData[
      \(TraditionalForm\`Y(y)\)]],
  " satisfies"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 Y\/\[DifferentialD]y\^2 - \
\(\((\(n\ \[Pi]\)\/a)\)\^2\) Y = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`n > 0\)]],
  " the solution that is zero at ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`Y(y) = \ \(A\_n\) \(sinh(n\ \[Pi]\ y/a)\)\)]],
  ". However, we must be careful; the ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  " term must also be kept. For ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  " the solution that is zero at ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`Y(y) = \(A\_o\) y\)]],
  ". Therefore, the potential has the form"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, 
          y) = \[Sum]\+\(n = 1\)\%\[Infinity]\( A\_n\) 
            sinh\ \((n\ \[Pi]\ y/a)\)\ \(cos(n\ \[Pi]\ x/a)\)\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`A\_o\ y\)]],
  "."
}], "NE2",
  CellTags->"(3.2.14)"],

Cell[TextData[{
  "This solution matches the boundary conditions on the bottom and sides. The \
constants ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A\_n\)\(\ \)\)\)]],
  "are then determined by satisfying the boundary condition on the top face, \
",
  Cell[BoxData[
      \(TraditionalForm\`V\_o\  = \[Sum]\+\(n = 1\)\%\[Infinity]\( A\_n\) 
              sinh\ \((n\ \[Pi]\ b/a)\)\ \(cos(n\ \[Pi]\ x/a)\)\  + \ 
          A\_o\ b\)]],
  ". This is simply a Fourier cosine series in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". The Fourier coefficients are ",
  Cell[BoxData[
      \(TraditionalForm\`A\_o\  = \ V\_o/b\)]],
  " and"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\  = \ \(V\_o\/\(sinh(
                n\ \[Pi]\ a/b)\)\) \(\[Integral]\_0\%b\( cos(
                n\ \[Pi]\ y/b)\) \[DifferentialD]y\), \ n > 0\)]]
}], "Text"],

Cell[TextData[{
  "However, the integral over the cosine  equals zero, so the only nonzero \
Fourier coefficient is ",
  Cell[BoxData[
      \(TraditionalForm\`A\_o\  = \ V\_o/b\)]],
  ". Therefore, the solution for the potential interior to the wire  is \
simply ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y) = V\_o\ y/b\)]],
  ". The electric field in the wire is uniform, of magnitude ",
  Cell[BoxData[
      \(TraditionalForm\`V\_o/b\)]],
  ". The current density runs vertically and uniformly throughout the \
conductor, with magnitude ",
  Cell[BoxData[
      \(TraditionalForm\`j = \[Sigma]\ V\_o/b\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2.3 2D Cylindrical Geometry", "Subsubtitle",
  CellTags->"c:31"],

Cell[CellGroupData[{

Cell["Separation of Variables", "Section",
  CellTags->{"i:65", "c:32"}],

Cell[TextData[{
  " The general solution to Laplace's equation can also be found in \
cylindrical geometry ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \ \[Theta], z)\)\)]],
  ". The cylindrical radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " and the angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " are defined by the coordinate transformation ",
  Cell[BoxData[
      \(TraditionalForm\`x = r\ cos\[Theta]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = r\ sin\[Theta]\)]],
  ". At first, for simplicity, we consider the case where the potential is \
independent of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", so that  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = \[Phi](r, \[Theta])\)]],
  ".  In these 2D cylindrical coordinates, the method of separation of \
variables can again be used to solve Laplace's equation. We assume that the \
potential takes the form"
}], "Text",
  CellTags->"i:75"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](
          r, \[Theta])\  = \ \(R(r)\)\ \(\[CapitalTheta](\[Theta])\)\)]],
  "."
}], "NE2",
  CellTags->"(3.2.15)"],

Cell[TextData[{
  "In cylindrical coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " is given by "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\(\(=\)\(\ \)\(\(1\/r\) \(\[PartialD]\/\
\[PartialD]r\) \((r \[PartialD]\/\[PartialD]r)\) + \(1\/r\^2\) \[PartialD]\^2\
\/\[PartialD]\[Theta]\^2 + \[PartialD]\^2\/\[PartialD]z\^2\)\)\)]],
  "."
}], "NE2",
  CellTags->{"i:109", "(3.2.16)"}],

Cell[TextData[{
  "Applying ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " to Eq. ",
  ButtonBox["(3.2.15)",
    ButtonData:>"(3.2.15)",
    ButtonStyle->"Hyperlink"],
  " and dividing by  ",
  Cell[BoxData[
      \(TraditionalForm\`\(R(r)\)\ \(\[CapitalTheta](\[Theta])\)\)]],
  " yields"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(1\/\(r\ \(R(
                  r)\)\)\) \(\[PartialD]\/\[PartialD]r\) \((r \[PartialD]R\/\
\[PartialD]r)\) + \(1\/\(\(r\^2\) \(\[CapitalTheta](\[Theta])\)\)\) \
\[PartialD]\^2 \[CapitalTheta]\/\[PartialD]\[Theta]\^2 = 0. \)]]], "NE2",
  CellTags->"(3.2.17)"],

Cell[TextData[{
  "Following the standard procedure, this equation can be separated into two \
equations for the ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " dependence. The expression ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(\[CapitalTheta](\[Theta])\)\) \[PartialD]\^2 \
\[CapitalTheta]\/\[PartialD]\[Theta]\^2\)]],
  " must equal some function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  ", which we call ",
  Cell[BoxData[
      \(TraditionalForm\`f(\[Theta])\)]],
  ". Equation ",
  ButtonBox["(3.2.17)",
    ButtonData:>"(3.2.17)",
    ButtonStyle->"Hyperlink"],
  " can then be written as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(r\ \(R(
                    r)\)\)\) \(\[PartialD]\/\[PartialD]r\) \((r \
\[PartialD]R\/\[PartialD]r)\) + \(f(\[Theta])\)\/r\^2 = 0. \)]],
  " "
}], "NE2",
  CellTags->"(3.2.18)"],

Cell[TextData[{
  "However, as the rest of the equation is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  ", it can only be satisfied if ",
  Cell[BoxData[
      \(TraditionalForm\`f(\[Theta])\)]],
  " is a constant, ",
  Cell[BoxData[
      \(TraditionalForm\`f(\[Theta]) = \(-m\^2\)\)]],
  " (where we have anticipated that the constant will be nonpositive). Then \
the equation for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta](\[Theta])\)]],
  " is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 \
\[CapitalTheta]\/\[PartialD]\[Theta]\^2 = \(-m\^2\)\ \(\[CapitalTheta](\
\[Theta])\)\)]],
  ". "
}], "NE2",
  CellTags->"(3.2.19)"],

Cell[TextData[{
  "The boundary conditions on this equation arise from the fact that the \
variable ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " is periodic: the angles  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] + 2  \[Pi]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " are equivalent. This implies that we must require ",
  StyleBox["periodic boundary conditions, ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta](\[Theta] + 
            2  \[Pi]) = \[CapitalTheta](\[Theta])\)]],
  ".  With these boundary conditions, we again have an eigenvalue problem, \
because these boundary conditions allow only the trivial solution ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta](\[Theta]) = 0\)]],
  ", except for special values of ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ". These values may be found by examining the general solution to Eq. ",
  ButtonBox["(3.2.19)",
    ButtonData:>"(3.2.19)",
    ButtonStyle->"Hyperlink"],
  ","
}], "Text",
  CellTags->"i:105"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta](\[Theta]) = 
        A\ \[ExponentialE]\^\(\(\[ImaginaryI]\)\(\ \)\(m\)\(\ \
\)\(\[Theta]\)\(\ \)\) + \ 
          B\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ m\ \[Theta]\)\)]],
  ". "
}], "NE2",
  CellTags->"(3.2.20)"],

Cell[TextData[{
  "For nonzero ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  ", the periodic boundary conditions imply that ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\(\ \
\)\(m\)\(\ \)\(\[Theta]\)\(\ \)\) = \[ExponentialE]\^\(\(\[PlusMinus]\
\[ImaginaryI]\)\ m\ \((\[Theta]\  + 2  \[Pi])\)\)\)]],
  ", which requires that ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\
\ \ 2  \[Pi]\ m\) = 1\)]],
  ". This can only be satisfied if ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is an integer. Therefore, we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta](\[Theta])\  = \ \[ExponentialE]\^\(\
\[ImaginaryI]\ m\ \[Theta]\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`m\  \[Element] \ Integers\)]]
}], "NE2",
  CellTags->"(3.2.21)"],

Cell[TextData[{
  "[Allowing ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " to run over both positive and negative integers accommodates both \
independent solutions in Eq. ",
  ButtonBox["(3.2.20)",
    ButtonData:>"(3.2.20)",
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text"],

Cell[TextData[{
  "\tTurning to the radial equation, we find that  for ",
  Cell[BoxData[
      \(TraditionalForm\`f(\[Theta]) = \ \(-m\^2\)\)]],
  ", Eq. ",
  ButtonBox["(3.2.18)",
    ButtonData:>"(3.2.18)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(\(r\)\(\ \)\)\) \(\[PartialD]\/\[PartialD]r\) \
\((r \[PartialD]R\/\[PartialD]r)\) - \(m\^2\/r\^2\) \(R(r)\)\  = \ 0\)]],
  "."
}], "NE2",
  CellTags->"(3.2.22)"],

Cell["This equation has the following general solution,", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(R(r)\), " ", "=", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->16], 
              StyleBox[GridBox[{
                    {
                      
                      RowBox[{\(A\_m\ \ r\^\(\(|\)\(m\)\(|\)\)\  + \ 
                          B\_m\ /r\^\(\(|\)\(m\)\(|\)\)\), ",", "   ", 
                        FormBox[\(\(m \[NotEqual] \ 0\)\(,\)\),
                          "TraditionalForm"]}]},
                    {\(A\_o\ \  + \ 
                        B\_o\ \ ln\ r, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ m = 
                        0. \)}
                    }],
                ShowAutoStyles->True]}],
            (#&)]}], TraditionalForm]]],
  " \n "
}], "NE2",
  CellTags->"(3.2.23)"],

Cell["\<\
 The general solution to the Laplace equation in cylindrical \
coordinates is a sum of these independent solutions:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta]) = 
        A\_o\ \  + \ \(B\_o\) 
            ln\ r + \ \[Sum]\+\(m = \(-\[Infinity]\)\[IndentingNewLine]
              m \[NotEqual] \ 0\)\%\[Infinity]\(\((\(A\_m\) 
                    r\^\(\(|\)\(m\)\(|\)\) + 
                  B\_m/r\^\(\(|\)\(m\)\(|\)\))\) \(\[ExponentialE]\^\(\
\[ImaginaryI]\ m\ \[Theta]\)\)\(\ \)\)\)]],
  "."
}], "NE2",
  CellTags->"(3.2.24)"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example", "Section",
  CellTags->"c:33"],

Cell[TextData[{
  "\tThe general solution to Laplace's equation in cylindrical coordinates is \
useful when boundary conditions are provided on the surface of a cylinder or \
cylinders. For instance, say the potential is specified on a",
  StyleBox[" ",
    FontSlant->"Italic"],
  " cylinder of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " :"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi](
        a, \[Theta]) = \(\(\(V\_a\)(\[Theta])\)\(.\)\)\)]]], "NE2",
  CellTags->"(3.2.25)"],

Cell[TextData[{
  "\tWe require a solution to Laplace's equation in ",
  Cell[BoxData[
      \(TraditionalForm\`0\  \[LessEqual] \ r \[LessEqual] \ a\)]],
  ". This solution is given by Eq. ",
  ButtonBox["(3.2.24)",
    ButtonData:>"(3.2.24)",
    ButtonStyle->"Hyperlink"],
  "; we only need to match the boundary conditions to determine the constants \
",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n\)]],
  ". First, the fact that the potential must be finite at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  " implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            FormBox["B",
              "TraditionalForm"], "n"], "=", "0"}], TraditionalForm]]],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". Next, Eqs. ",
  ButtonBox["(3.2.24)",
    ButtonData:>"(3.2.24)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.2.25)",
    ButtonData:>"(3.2.25)",
    ButtonStyle->"Hyperlink"],
  " imply that "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[CapitalSigma]\+\(m = \(-\[Infinity]\)\)\%\
\[Infinity]\) \(A\_m\) \(a\^\(\(|\)\(m\)\(|\)\)\) \[ExponentialE]\^\(\
\[ImaginaryI]\ m\ \[Theta]\) = \(V\_a\)(\[Theta])\)\(,\)\)\)]]
}], "Text"],

Cell[TextData[{
  "This is an exponential Fourier series, so  the Fourier coefficients can be \
determined using Eq. ",
  ButtonBox["(2.2.3)",
    ButtonData:>{"Chapter2.nb", "(2.2.3)"},
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(A\_m\) 
          a\^\(\(|\)\(m\)\(|\)\) = \(1\/\(2\ \[Pi]\)\) \(\[Integral]\_0\%\(2\ \
\[Pi]\)\(\(V\_a\)(\[Theta])\) \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ m\ \
\[Theta]\)\) \[DifferentialD]\[Theta]\)\)]],
  "."
}], "NE2",
  CellTags->"(3.2.26)"],

Cell[TextData[{
  "The solution for the potential is \n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](
          r, \[Theta])\  = \(\(\[CapitalSigma]\+\(m = \(-\[Infinity]\)\)\%\
\[Infinity]\) \(A\_m\) \(r\^\(\(|\)\(m\)\(|\)\)\) \(\[ExponentialE]\^\(\
\[ImaginaryI]\ m\ \[Theta]\)\)\(\ \)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "For instance, if ",
  Cell[BoxData[
      \(TraditionalForm\`\(V\_a\)(\[Theta])\  = \ \(V\_o\) sin\ \[Theta]\)]],
  ", then only the ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(\(\[PlusMinus]1\)\(\ \)\)\)]],
  " terms in the sum contribute to the solution, and the rest are zero. This \
is because ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ \[Theta]\)]],
  " contains only ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(\[PlusMinus]1\)\)]],
  " Fourier components.  The solution is then clearly of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta])\  = \ A\ r\ sin\ \[Theta]\)]],
  ", and the constant ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " can be determined by matching the boundary condition that ",
  Cell[BoxData[
      \(TraditionalForm\`V(
          a, \[Theta])\  = \(\(V\_o\) \(sin\)\(\ \)\(\[Theta]\)\(\ \)\)\)]],
  ". The result is "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta])\  = \ 
        V\_o\ \(\(r\)\(\ \)\)\/a\ sin\ \[Theta]\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2.4 Spherical Geometry", "Subsubtitle",
  CellTags->"c:34"],

Cell[CellGroupData[{

Cell["Separation of Variables", "Section",
  CellTags->{"i:67", "c:35"}],

Cell[TextData[{
  "We next consider the solution to Laplace's equation written in spherical \
coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta], \[Phi])\)\)]],
  ". These coordinates are defined by  the transformation ",
  Cell[BoxData[
      \(TraditionalForm\`x = r\ sin\ \[Theta]\ cos\[Phi]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y = r\ sin\ \[Theta]\ sin\[Phi]\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`z = r\ cos\[Theta]\)]],
  " (see Fig. ",
  ButtonBox["3.11",
    ButtonData:>"Fig. 3.11",
    ButtonStyle->"Hyperlink"],
  ") . In these coordinates Laplace's equation becomes"
}], "Text",
  CellTags->"i:78"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[CapitalPsi] = \(1\/r\^2\) \
\(\[PartialD]\/\[PartialD]r\) \((\(r\^2\) \[PartialD]\[CapitalPsi]\/\
\[PartialD]r)\) + \(1\/\(\(r\^2\) 
                  sin\[Theta]\)\) \(\[PartialD]\/\[PartialD]\[Theta]\) \((sin\
\[Theta] \[PartialD]\[CapitalPsi]\/\[PartialD]\[Theta])\) + \(1\/\(\(r\^2\) \
\(sin\^2\) \[Theta]\)\) \[PartialD]\^2 \
\[CapitalPsi]\/\[PartialD]\[Phi]\^2\)]],
  "."
}], "NE2",
  CellTags->{"i:110", "(3.2.27)"}],

Cell[TextData[{
  "(We use the symbol \[CapitalPsi]  for potential in this section so as not \
to confuse it with the azimuthal angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  ".) We again employ  the method of separation of variables",
  StyleBox[", ",
    FontSlant->"Italic"],
  "writing"
}], "Text"],

Cell[TextData[{
  "\t\t  ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPsi](
          r, \[Theta], \[Phi]) = \(R(
            r)\) \(\[CapitalTheta](\[Theta])\) \(\[CapitalPhi](\[Phi])\)\)]],
  ".",
  StyleBox[" ",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "Then the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Del]\^2 \[CapitalPsi]\ )\)/\[CapitalPsi]\  = \ 
        0\)]],
  " is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(\(r\^2\) 
                  R\)\) \(\[PartialD]\/\[PartialD]r\) \((\(r\^2\) \
\[PartialD]R\/\[PartialD]r)\) + \(1\/\(\(r\^2\) 
                  sin\[Theta]\ \[CapitalTheta]\)\) \(\[PartialD]\/\[PartialD]\
\[Theta]\) \((sin\[Theta] \[PartialD]\[CapitalTheta]\/\[PartialD]\[Theta])\) \
+ \(1\/\(\(r\^2\) \(sin\^2\) \[Theta]\ \[CapitalPhi]\)\) \[PartialD]\^2 \
\[CapitalPhi]\/\[PartialD]\[Phi]\^2 = 0\)]],
  "."
}], "NE2",
  CellTags->"(3.2.28)"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007/00027b000`400?l00000o`00003oo`3oooo]
0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]
0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]
0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]
0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]
0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]
0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]
0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]
0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]
0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]
0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]
0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`00o`3oooo]0?ooo`002`3oool3
000000d0oooo00<0P820000000000000o`3oooo?0?ooo`002`3oool3000000030410@020P800oooo
00T0oooo00<0P8200000000000000P0000000`10@400oooo0?ooo`3o0?oool/0oooo000;0?ooo`D0
000000<0P8200?ooo`3oool01`3oool700000?l0ooooc03oool000/0oooo1P0000080?ooo`030820
P0000000000000H0000000<0`<300?ooo`3oool0o`3oooo80?ooo`002`3oool3000000040?ooo`00
00000000000000L0oooo00<0P8200000000000000P0000030?ooo`800000o`3oooo:0?ooo`002`3o
ool00`000000@4100?ooo`020?ooo`030410@0000000@41000H0oooo1@0000040?ooo`030410@020
P800oooo00X0oooo00<0`<300?ooo`3oool0o`3ooonk0?ooo`004@3oool2000000H0oooo10000000
0`20P800oooo0?ooo`030?ooo`0300000020P800oooo00T0oooo00<0P8200000003oool0o`3ooonk
0?ooo`004P3oool2000000D0oooo100000000`20P800oooo0?ooo`030?ooo`0300000020P800oooo
00T0oooo00<0P820000000000000o`3ooonk0?ooo`004P3oool00`20P80000000820P0030?ooo`D0
000000<0`<300?ooo`3oool0103oool00`20P800oooo0?ooo`090?ooo`<0000000<0P8200?ooo`3o
ool0o`3ooong0?ooo`004`3oool2000000<0oooo1@00000C0?ooo`D00000o`3ooonh0?ooo`00503o
ool010000000P8200?ooo`20P805000001<0oooo00<0P8200000000000000`0000000`10@400oooo
0?ooo`3o0?oook@0oooo000D0?ooo`040820P000000000000820P0@000005@3oool7000000030820
P03oool0oooo0?l0oooo/P3oool001D0oooo0P0000000`10@400000000000002000001D0oooo00<0
@4100000000000001@0000000`20P800`<300?ooo`3o0?oook40oooo000F0?ooo`D0000000<0P820
0?ooo`3oool04`3oool00`20P80000000000000700000?l0oooo/P3oool001H0oooo00<0P8200000
000000000P0000000`20P800oooo0?ooo`0C0?ooo`030<30`0000000000000P0000000<0@4100?oo
o`3oool0o`3ooon^0?ooo`005P3oool5000000030820P03oool0oooo01@0oooo300000000`20P800
oooo0?ooo`3o0?oooc@0oooo0`00001e0?ooo`005P3oool5000001L0oooo3@0000020820P?l0oooo
=03oool3000007D0oooo000E0?ooo`H00000603oool>000000030820P03oool0oooo0?l0oooo:03o
ool00`000000oooo0?ooo`060?ooo`<00000M@3oool001D0oooo1P00000H0?oooa000000o`3ooolW
0?ooo`<00000203oool3000007D0oooo000D0?ooo`030<30`0000000000000@0000000<0P8200?oo
o`3oool05@3oool@000000030410@020P800oooo0?l0oooo8P3oool00`20P8000000000000030000
00L0oooo0`00001e0?ooo`00503oool00`20P800000000000003000000030?ooo`000000oooo01H0
oooo00<0P8200000000000003`0000000`20P800oooo0?ooo`3o0?oooal0oooo1P0000080?ooo`<0
0000M@3oool001@0oooo00<0@4100000000000000P0000001@20P800oooo0410@0000000`<3001D0
oooo00<0`<300000000000004@0000000`30`<00oooo0?ooo`3o0?oooa/0oooo00<0P82000000000
00000`0000000`20P800oooo0?ooo`070?ooo`<00000M@3oool001@0oooo1@0000001@20P800oooo
0820P0000000P82001H0oooo5@00003o0?oooa`0oooo00D0P82000000000000000000820P0230?oo
o`004`3oool00`20P800000000000003000000<0oooo00<0P82000000020P8001@3oool20820P0h0
oooo00<0P8200000000000004P0000000`10@400P8200?ooo`3o0?oooaX0oooo0P0000000`20P800
oooo0?ooo`220?ooo`004`3oool6000000@0oooo0`0000020?ooo`050820P0000000000000000020
P8003P3ooolF00000?l0ooooXP3oool00140oooo00<0P8200410@0000000100000000`20P800oooo
0?ooo`020?ooo`030<30`0000000000000L000003P3oool00`20P80000000000000A000000030410
@03oool0oooo0?l0ooooX@3oool000d0oooo2`0000070?ooo`P000003`3ooolC000000030820P03o
ool0oooo0?l0ooooX@3oool000d0oooo00<0P8200410@00000001`0000000`20P800oooo0?ooo`05
0?ooo`030<30`0000000000000D000003`3ooolB000000030820P03oool0oooo0?l0ooooXP3oool0
0140oooo1P00000:0?ooo`D0000000<0P8200?ooo`3oool03@3oool00`20P80000000000000?0000
0?l0ooooY@3oool001@0oooo0P00000<0?ooo`040820P0000000000000000100oooo00<0P8200000
000000003P0000000`20P800oooo0?ooo`3o0?oooj<0oooo000f0?ooo`030820P0000000000000d0
000000<0P8200?ooo`3oool0o`3oool?0?ooo`030<30`020P800oooo0980oooo000g0?ooo`h00000
00<0P8200?ooo`3oool0o`3oool?0?ooo`<00000T`3oool003L0oooo3P0000000`30`<00oooo0?oo
o`3o0?ooo`d0oooo00<0P8200410@00000000P0000000`30`<00oooo0?ooo`2@0?ooo`00>03oool=
000000030820P03oool0oooo0?l0oooo303oool4000000030820P03oool0oooo0980oooo000h0?oo
o`P0000000@0P8200<30`03oool0P8200P0000000`20P800oooo0?ooo`3o0?ooo`T0oooo00H0P820
0410@000000000000410@020P82E0?ooo`00>03oool00`20P800000000000003000000030820P03o
ool0oooo00<0oooo0`0000000`20P800oooo0?ooo`3o0?ooo`T0oooo0`00002G0?ooo`00>03oool0
0`30`<000000000000020820P0P0oooo00<0@41000000010@400o`3oool;0?ooo`80P820803oool3
0820P7D0oooo00150?ooo`040820P0000000000000000?l0oooo;03oool3000007D0oooo00160?oo
o`040820P000000000000820P?l0oooo:`3oool3000007D0oooo00170?ooo`030820P00000000000
0?l0oooo:`3oool3000007D0oooo00170?ooo`040820P0000000000000000?l0oooo:P3oool30000
07D0oooo00180?ooo`040820P0000000000000000?l0oooo:@3oool3000007D0oooo00190?ooo`04
0820P000000000000820P?l0oooo:03oool3000007D0oooo00190?ooo`050<30`000000000000000
0020P800m@3oool00`20P80000000410@00^0?ooo`<00000M@3oool004/0oooo0`0000000`20P800
oooo0?ooo`3a0?ooo`@00000;P3oool3000007D0oooo001<0?ooo`030410@0000000@4100?40oooo
00<0P8200000000000000`0000000`20P800oooo0?ooo`2S0?ooo`00C03oool01020P80000000000
0000003_0?ooo`H00000Y`3oool004d0oooo00@0P820000000000000P820k@3oool00`10@4000000
00000002000000030<30`03oool0oooo0:H0oooo001>0?ooo`030820P000000000000>d0oooo00@0
P820000000000000P820ZP3oool004h0oooo00D0`<3000000000000000000<30`03/0?ooo`80P820
Z`3oool00500oooo0P0000000`20P800oooo0?ooo`3o0?oooiP0oooo001@0?ooo`030820P0000000
00000?l0ooooVP3oool00500oooo00D0`<3000000000000000000<30`03o0?oooiP0oooo001B0?oo
o`80000000<0P8200?ooo`3oool0o`3ooonF0?ooo`00DP3oool01020P800000000000020P81=0?oo
o`D00000o`3ooom50?ooo`00D`3oool4000004`0oooo1@0000000`20P800oooo0?ooo`3o0?oood80
oooo001D0?ooo`040410@000000000000<30`4`0oooo100000000`20P800oooo0?ooo`250?ooo`03
0820P010@40000000;T0oooo001D0?ooo`040820P00000000000000004`0oooo100000000`20P800
oooo0?ooo`240?ooo`@0000000<0P8200?ooo`3oool0]P3oool005D0oooo00D0P820000000000000
00000<30`01:0?ooo`@0000000<0@4100?ooo`3oool0PP3oool01P20P8000000000000000000@410
0820P;T0oooo001G0?ooo`80000000<0P8200?ooo`3oool0B03oool00`20P8000000000000020000
08<0oooo100000140?ooo`<00000M@3oool005L0oooo00@0P820000000000000P820B@3oool00`20
P80000000000000200000880oooo00D0@410000000000000P8200<30`0140?ooo`<00000M@3oool0
05P0oooo0`0000000`20P800oooo0?ooo`160?ooo`030820P0000000000000800000PP3oool00`20
P80000000820P0160?ooo`<00000M@3oool005T0oooo0P0000000`20P800oooo0?ooo`160?ooo`03
0820P0000000000000<00000bP3oool3000007D0oooo001I0?ooo`040820P000000000000820P4P0
oooo1@00003:0?ooo`<00000M@3oool005X0oooo0`0000000`20P800oooo0?ooo`150?ooo`D00000
bP3oool3000007D0oooo001K0?ooo`030410@0000000@41004L0oooo1@0000000`20P800oooo0?oo
o`370?ooo`<00000M@3oool005/0oooo00@0P8200000000000000000A`3oool500000<T0oooo0`00
001e0?ooo`00G03oool01020P800000000000020P8140?ooo`80P8201@0000020820P<L0oooo0`00
001e0?ooo`00G@3oool00`20P8000000000000120?ooo`d0000000<0P8200?ooo`3oool0K03oool2
00000<`0oooo001M0?ooo`050<30`0000000000000000020P800?@3oool00`20P800@41000000003
000000030820P010@400000000<0000000<0@4100000000000000`0000000`20P800oooo0?ooo`1W
0?ooo`030<30`020P80000000080000000<0`<300?ooo`3oool0b@3oool005l0oooo0`00000l0?oo
o`H000000P3oool00`20P800000000000002000000030820P03oool0oooo00D00000J03oool50000
00030820P03oool0oooo0<T0oooo001O0?ooo`040820P000000000000410@3X0oooo00<0P8200000
000000000P0000001@10@400oooo0?ooo`3oool0P82000@0000000D0P8200?ooo`3oool0oooo0410
@004000000030820P03oool0oooo0680oooo00<0@4100000000000000P0000020820P<`0oooo001P
0?ooo`@00000>@3oool5000000030820P03oool0oooo0080oooo100000000`20P800oooo0?ooo`02
0?ooo`H00000H@3oool00`20P800000000000003000000030820P03oool0oooo0<`0oooo001Q0?oo
o`<00000>@3oool5000000D0oooo1@0000050?ooo`D0000000<0P8200?ooo`3oool0G`3oool40000
0=00oooo001R0?ooo`80000000<0@4100?ooo`3oool0=@3oool5000000030820P03oool0oooo00<0
oooo1@0000050?ooo`030<30`0000000000000<0000000<0P8200?ooo`3oool0G`3oool200000003
0<30`03oool0oooo0<h0oooo001R0?ooo`040820P00000000000000003D0oooo00<0P82000000000
00000`0000070?ooo`@000001P3oool600000?l0oooo=@3oool006<0oooo00@0P820000000000000
P820=03oool00`20P800000000000003000000L0oooo100000070?ooo`030410@000000000000080
000000<0P8200?ooo`3oool0o`3ooolb0?ooo`00I03oool00`20P80000000000000d0?ooo`030820
P0000000000000<000001`3oool5000000H0oooo00<0P8200000000000000`00003o0?oooc@0oooo
001T0?ooo`050<30`0000000000000000030`<00<P3oool00`20P800000000000003000000L0oooo
00<0@4100000000000000P0000060?ooo`030<30`0000000000000<0000000<0P8200?ooo`3oool0
o`3ooola0?ooo`00IP3oool2000000030820P03oool0oooo0300oooo00<0P8200000000000000`00
00070?ooo`030820P00000000000008000001`3oool600000?l0oooo<`3oool006H0oooo00@0P820
000000000000P820<@3oool00`20P800000000000003000000L0oooo00<0P8200000000000000P00
00080?ooo`D0000000<0`<300?ooo`3oool0o`3oool`0?ooo`00I`3oool400000300oooo00<0P820
0000000000000`0000080?ooo`@0000000<0P8200?ooo`3oool01@3oool5000000030820P03oool0
oooo04h0oooo00<000000820P03oool0gP3oool006P0oooo00@0@410000000000000`<30;`3oool0
0`30`<00000000000003000000030820P03oool0oooo00D0oooo100000000`20P800oooo0?ooo`05
0?ooo`D0000000<0P8200?ooo`3oool0C03oool01010@400000000000010@41W0?ooo`<00000M@3o
ool006P0oooo00@0P8200000000000000000<03oool6000000L0oooo100000000`20P800oooo0?oo
o`060?ooo`D00000C03oool00`20P800000000000002000000030820P03oool0oooo06D0oooo0`00
001e0?ooo`00J@3oool4000002l0oooo1P0000070?ooo`@0000000<0P8200?ooo`3oool01P3oool5
000004`0oooo1000001Y0?ooo`<00000M@3oool006X0oooo00@0P820000000000000`<30;P3oool0
0`20P800000000000003000000030<30`03oool0oooo00D0oooo0`0000000`10@400oooo0?ooo`06
0?ooo`D00000BP3oool01@20P8000000000000000000P82006X0oooo0`00001e0?ooo`00J`3oool3
000002l0oooo1@0000000`20P800oooo0?ooo`050?ooo`@00000203oool5000004X0oooo00<0P820
000000000000K03oool3000007D0oooo001[0?ooo`040<30`00000000000000002h0oooo00<0@410
0000000000000P0000000`10@400oooo0?ooo`050?ooo`040820P00000000000000000P0oooo1@00
001:0?ooo`030<30`020P800`<3006`0oooo0`00001e0?ooo`00K@3oool2000000030820P03oool0
oooo02/0oooo00<0P8200000000000000`0000080?ooo`<00000203oool500000;T0oooo0`00001e
0?ooo`00K@3oool01010@400000000000020P80]0?ooo`030820P0000000000000<000001`3oool4
000000L0oooo100000000`10@400oooo0?ooo`2g0?ooo`<00000M@3oool006h0oooo0`00000^0?oo
o`D0000000<0P8200?ooo`3oool0103oool4000000H0oooo1@0000000`20P800oooo0?ooo`2g0?oo
o`<00000M@3oool006l0oooo0P0000000`10@400oooo0?ooo`0/0?ooo`030410@000000000000080
000000<0P8200?ooo`3oool00`3oool01020P80000000000000000060?ooo`D0000000<0`<300?oo
o`3oool0o`3oool`0?ooo`00K`3oool01020P800000000000000000^0?ooo`D000001@3oool01020
P80000000000000000050?ooo`H00000o`3ooolc0?ooo`00L03oool01020P800000000000020P80^
0?ooo`030410@000000000000080000000D0P8200?ooo`3oool0oooo0<30`003000000050820P03o
ool0oooo0?ooo`20P800100000000`10@400oooo0?ooo`0m0?ooo`030820P03oool0oooo0?40oooo
001a0?ooo`030820P0000000000002l0oooo1@0000001020P800oooo0?ooo`3oool3000000030820
P03oool0oooo00H00000?P3oool01020P800000000000000003b0?ooo`00L@3oool01020P8000000
00000000000_0?ooo`030820P0000000000000@0000000H0oooo00000000000000000820P03oool6
000003l0oooo1000003b0?ooo`00LP3oool01020P800000000000000000`0?ooo`030820P0000000
000000`0000000<0P8200<30`03oool0>`3oool00`30`<00000000000004000000030<30`03oool0
oooo0>l0oooo001c0?ooo`040820P000000000000820P380oooo2P0000100?ooo`D0000000<0P820
0?ooo`3oool0l@3oool007<0oooo00D0`<3000000000000000000820P00e0?ooo`<00000@@3oool0
0`30`<00000000000002000000030410@03oool0oooo0?<0oooo001e0?ooo`<00000=@3oool30000
0480oooo0`00003g0?ooo`00MP3oool2000000030410@03oool0oooo0380oooo00<0P82000000000
0000@`3oool00`20P800oooo0?ooo`3f0?ooo`00MP3oool01020P800000000000000000c0?ooo`04
0820P0000000000000000?l0oooo?03oool007L0oooo00@0P820000000000000`<30<P3oool01030
`<00000000000000003o0?oooc`0oooo001h0?ooo`<00000<`3oool300000?l0oooo?03oool007P0
oooo00@0`<300000000000000000<P3oool3000000030<30`03oool0oooo0?l0oooo>@3oool007X0
oooo0P0000000`20P800oooo0?ooo`0_0?ooo`<0000000<0P8200?ooo`3oool0`03oool3000007D0
oooo001j0?ooo`<00000<P3oool2000000030820P03oool0oooo0<00oooo0`00001e0?ooo`00NP3o
ool01030`<00000000000000000a0?ooo`80000000<0P8200?ooo`3oool0<03oool00`20P8000000
0820P02=0?ooo`<00000M@3oool007`0oooo0P0000000`20P800oooo0?ooo`0^0?ooo`80000000<0
P8200?ooo`3oool0;P3oool00`20P800000000000002000008d0oooo0`00001e0?ooo`00O03oool0
1010@400000000000020P80_0?ooo`030820P0000000000002h0oooo00<0`<300820P00000000P00
00000`20P800`<300?ooo`2<0?ooo`<00000M@3oool007d0oooo100000040?ooo`030820P0000000
000001H00000@P3oool4000000030820P03oool0oooo08d0oooo0`00001e0?ooo`00OP3oool00`10
@40000000000000Q00000080P82000<0`<300?ooo`3oool0=`3oool01@20P8000000000000000000
@4100940oooo0`00001e0?ooo`00OP3oool00`20P80000000000000W000003P0oooo0P00002B0?oo
o`<00000M@3oool007l0oooo00@0P82000000000000000002020P80C0?ooo`<0P8202P0000030820
P<H0oooo0`20P81e0?ooo`00P@3oool2000000030820P03oool0oooo01h0oooo00<0P82000000000
00002P00003o0?oooc`0oooo00210?ooo`040410@000000000000820P280oooo0`20P80800000080
P820o`3oooli0?ooo`00PP3oool3000002P0oooo00<0P8200000000000001P00003o0?ooocL0oooo
00230?ooo`80000000<0P8200?ooo`3oool0:03oool800000?l0oooo=@3oool008<0oooo00@0@410
000000000000P820:P3oool00`30`<00P82000000005000000030820P030`<00oooo0?l0oooo<@3o
ool008@0oooo0`00000^0?ooo`L000005P3oool00`000000oooo0?ooo`3o0?oooaP0oooo00250?oo
o`80000000<0@4100?ooo`3oool0;03oool00`30`<00P82000000004000000030820P03oool0oooo
0100oooo00@0@410000000000000P820o`3ooolI0?ooo`00Q@3oool01020P800000000000000000`
0?ooo`H000003`3oool00`20P80000000000000300000?l0oooo6@3oool008H0oooo00@0P8200000
00000000`<30<03oool00`30`<00P82000000004000000`0oooo00<0P8200000000000000P000000
0`20P800oooo0?ooo`3o0?oooaP0oooo00270?ooo`<00000<P3oool00`20P8000000000000020000
00030820P03oool0oooo00P0oooo1@00003o0?oooa`0oooo00270?ooo`050<30`000000000000000
0020P800<P3oool00`20P800000000000002000000030<30`03oool0oooo00H0oooo00@0P8200000
00000000P820o`3ooolM0?ooo`00R@3oool3000003@0oooo1@0000080?ooo`0300000020P800oooo
0?l0oooo7@3oool008T0oooo00@0P820000000000000@410=03oool01P30`<000000000000000000
@4100820P?l0oooo9P3oool008X0oooo1000000e0?ooo`@0000000<0P8200?ooo`3oool0o`3ooolS
0?ooo`00R`3oool3000003D0oooo00@0P8200000000000000000[@3oool3000007D0oooo002<0?oo
o`80000000<0@4100?ooo`3oool0=03oool00`20P800oooo0?ooo`2/0?ooo`<00000M@3oool008`0
oooo00@0P8200000000000000000i03oool3000007D0oooo002=0?ooo`040820P000000000000<30
`><0oooo0`00001e0?ooo`00SP3oool3000002d0oooo00<0P8200000003oool0/`3oool3000007D0
oooo002>0?ooo`040<30`00000000000000002X0oooo00D0`<3000000000000000000820P02c0?oo
o`<00000M@3oool00900oooo0P0000000`20P800oooo0?ooo`0V0?ooo`D00000]03oool3000007D0
oooo002@0?ooo`040410@000000000000820P2H0oooo00D0@41000000000000000000<30`02e0?oo
o`<00000M@3oool00940oooo0`00000T0?ooo`050820P0000000000000000020P800]`3oool30000
07D0oooo002B0?ooo`80000000<0@4100?ooo`3oool08P3oool2000000030820P03oool0oooo0?l0
oooo;`3oool00980oooo00@0P8200000000000000000o`3ooomG0?ooo`00T`3oool300000?l0oooo
E`3oool009@0oooo0`0000000`30`<00oooo0?ooo`3o0?oooe<0oooo002D0?ooo`040820P0000000
000000000?l0ooooE@3oool009D0oooo00@0P8200000000000000000o`3ooomD0?ooo`00U`3oool2
000000030820P03oool0oooo0?l0ooooD@3oool009L0oooo00@0@410000000000000P820403oool0
0`30`<00P8200?ooo`3o0?ooocl0oooo002H0?ooo`<000003`3oool3000000030820P03oool0oooo
0?l0oooo?@3oool009T0oooo0P0000000`10@400oooo0?ooo`0:0?ooo`030820P000000000000080
000000<0@4100?ooo`3oool0o`3ooolm0?ooo`00V@3oool01020P800000000000000000:0?ooo`H0
000000<0P8200?ooo`3oool0o`3ooolm0?ooo`00VP3oool01020P800000000000030`<070?ooo`03
0820P010@400000000<0000000<0P8200?ooo`3oool0j`3oool01P30`<000000000000000000@410
0820P4d0oooo002K0?ooo`<00000203oool400000>l0oooo00<0P820000000000000100000000`20
P800oooo0?ooo`190?ooo`00V`3oool01020P80000000000000000070?ooo`80000000<0P8200?oo
o`3oool0kP3oool00`20P800000000000006000004X0oooo002L0?ooo`040820P000000000000820
P0H0oooo00<0`<300820P03oool0b`3oool300000280oooo2`0000000`10@400P8200820P00H0?oo
o`0300000020P800`<3002X0oooo002M0?ooo`<0000000<0P8200?ooo`3oool0d@3oool300000280
oooo4000000F0?ooo`<00000:P3oool009d0oooo00@0`<300000000000000000d`3oool300000280
oooo4P0000020820P180oooo100000000`10@400oooo0?ooo`0V0?ooo`00W`3oool300000=80oooo
0`00000Q0?oooaH000004@3oool00`000000oooo0820P003000002L0oooo002O0?ooo`040820P000
000000000410@080oooo00<0P8200<30`03oool0c03oool300000240oooo600000000`20P800`<30
0?ooo`0?0?ooo`040820P010@40000000410@2H0oooo002P0?ooo`050820P000000000000?ooo`20
P8000`00003<0?ooo`<000008@3ooolL00000100oooo0`00000U0?ooo`00X@3oool3000000050410
@0000000000000000010@400b`20P80300000240P8207P0000000`10@400P8200?ooo`0<0?ooo`03
0410@0000000@41002@0oooo002R0?ooool000006000000=0?ooo`800000903oool00:80ooooo`00
000E000000030410@020P800`<3000h0oooo00<0@41000000020P8008P3oool00:80oooo2`000000
0`20P800oooo0?ooo`3X0?oooa`00000503oool2000000030820P03oool0oooo01l0oooo002Q0?oo
o`d00000jP3ooolJ000001L0oooo0P00000Q0?ooo`00X03oool00`30`<0000000000000<00000003
0410@03oool0oooo0>H0oooo5P0000020820P1X0oooo0P0000000`30`<00oooo0?ooo`0M0?ooo`00
XP3oool?00000>L0oooo5000000N0?ooo`<000007`3oool00:80oooo400000000`20P800oooo0?oo
o`3T0?ooo`l0000000<0@4100820P020P8007`3oool4000000030<30`03oool0oooo01/0oooo002R
0?ooo`80000000<0P8200000000000003@00003U0?ooo`d0000000<0P8200?ooo`3oool08@3oool5
000001d0oooo002R0?ooo`80000000<0P8200?ooo`20P8003P0000000`20P800oooo0?ooo`3Q0?oo
o`030410@0000000000000H0000000<0@4100820P030`<00903oool7000001`0oooo002R0?ooo`80
000000@0P8200?ooo`3oool0oooo3`00003R0?ooo`030820P0000000000000@0000000<0P8200?oo
o`3oool09P3oool7000000030820P03oool0oooo01T0oooo002R0?ooo`80000000H0P8200?ooo`3o
ool0oooo0<30`020P80>000000030<30`03oool0oooo0=h0oooo00<0`<300000000000000P20P80[
0?ooo`D000000P20P8000`000000P8200?ooo`0I0?ooo`00XP3oool2000000030820P03oool0oooo
00@0oooo3`00003o0?oooa00oooo1@0000001@20P800oooo0820P0000000P82001T0oooo002R0?oo
o`80000000<0P8200?ooo`3oool0103oool00`30`<00P8200000000<000000030410@03oool0oooo
0?l0oooo3@3oool5000000050820P03oool0`<3000000010@4006@3oool00:80oooo0P0000000`20
P800oooo0?ooo`060?ooo`030820P0000000000000`0000000<0P8200?ooo`3oool0o`3oool;0?oo
o`D00000103oool2000001P0oooo002R0?ooo`80000000<0P8200?ooo`3oool0203oool>00000?l0
oooo3@3oool5000000@0oooo00<0P8200000000000005`3oool00:80oooo0P0000000`20P800oooo
0?ooo`080?ooo`030<30`0000000000000`0000000<0@4100?ooo`3oool0o`3oool90?ooo`D00000
103oool01030`<00000000000030`<0F0?ooo`00XP3oool2000000030820P03oool0oooo00X0oooo
00<0P8200000000000003000002d0?ooo`<00000D@3oool6000000H0oooo0P00000F0?ooo`00XP3o
ool2000000030820P03oool0oooo00/0oooo00<0P820000000000000300000000`10@400oooo0?oo
o`2`0?ooo`<00000D@3oool6000000L0oooo0P00000E0?ooo`00XP3oool2000000030820P03oool0
oooo00d0oooo3`00002a0?ooo`<00000D@3oool6000000L0oooo00<0P82000000020P800503oool0
0:80oooo0P0000000`20P800oooo0?ooo`0>0?ooo`030820P010@400000000`0000000<0P8200?oo
o`3oool0[@3oool300000540oooo1P0000080?ooo`800000503oool00:80oooo0P0000000`20P800
oooo0?ooo`0@0?ooo`l00000[P3oool300000540oooo1P0000090?ooo`8000004`3oool00:80oooo
0P0000000`20P800oooo0?ooo`0A0?ooo`030820P0000000000000`0000000<0`<300?ooo`3oool0
ZP3oool300000540oooo1@00000:0?ooo`030820P0000000P8200180oooo002R0?ooo`80000000<0
P8200?ooo`3oool04`3oool?00000:/0oooo0`00001A0?ooo`D000002`3oool200000180oooo002R
0?ooo`80000000<0P8200?ooo`3oool04`3oool00`30`<00P8200000000<000000030410@03oool0
oooo0:P0oooo0`00001@0?ooo`030<30`0000000000000<00000303oool200000140oooo002R0?oo
o`80000000<0P8200?ooo`3oool05@3oool00`20P80000000000000=00000?/0oooo00<0P8200000
000000000`00000<0?ooo`030820P0000000P8200100oooo002R0?ooo`80000000<0P8200?ooo`3o
ool05`3oool>000000030820P03oool0oooo0?P0oooo00<0P8200000000000000`00000<0?ooo`03
0820P0000000P8200100oooo002R0?ooo`80000000<0P8200?ooo`3oool05`3oool00`30`<000000
0000000<000000030820P030`<00oooo0?L0oooo00<0P8200000000000000`00000=0?ooo`800000
403oool00:80oooo0P0000000`20P800oooo0?ooo`0J0?ooo`h00000n03oool00`20P80000000000
0003000000d0oooo0P00000@0?ooo`00XP3oool2000000030820P03oool0oooo01X0oooo00<0`<30
000000000000300000000`10@400oooo0?ooo`3d0?ooo`030410@000000000000080000000<0P820
0?ooo`3oool02P3oool01030`<00000000000000000?0?ooo`00XP3oool2000000030820P03oool0
oooo01`0oooo00<0P8200000000000003000003e0?ooo`D0000000<0P8200?ooo`3oool02@3oool5
000000l0oooo002R0?ooo`80000000<0P8200?ooo`3oool07@3oool00`20P800@4100000000<0000
00030820P03oool0oooo0>l0oooo00<0`<300820P0000000100000000`20P800oooo0?ooo`080?oo
o`030<30`0000000000000<000003`3oool00:80oooo0P0000000`20P800oooo0?ooo`0O0?ooo`h0
000000<0P8200?ooo`3oool0jP3oool00`20P800000000000008000000030820P03oool0oooo00P0
oooo00<0P8200000000000000`00000?0?ooo`00XP3oool2000000030820P03oool0oooo0200oooo
00<0P820000000000000300000000`20P800oooo0?ooo`3X0?ooo`030<30`020P800000000P00000
2`3oool00`20P800000000000002000000030820P03oool0oooo00d0oooo002R0?ooo`80000000<0
P8200?ooo`3oool08P3oool?00000>h0oooo1@00000=0?ooo`@00000403oool00:80oooo0P000000
0`20P800oooo0?ooo`0R0?ooo`030<30`020P800000000d0000000<0`<300?ooo`3oool0k@3oool2
0820P0h0oooo0P20P80A0?ooo`00XP3oool2000000030820P03oool0oooo02D0oooo3`00003o0?oo
oa80oooo002R0?ooo`80000000<0P8200?ooo`3oool09P3oool>000000030820P03oool0oooo0?l0
oooo3`3oool00:80oooo0P0000000`20P800oooo0?ooo`0W0?ooo`030410@0000000000000/00000
00<0P8200<30`03oool0o`3oool>0?ooo`00XP3oool2000000030820P03oool0oooo02T0oooo3P00
003o0?ooo`l0oooo002R0?ooo`80000000<0P8200?ooo`3oool0:@3oool00`30`<0000000000000<
000000030820P030`<00oooo0980oooo0`00001e0?ooo`00XP3oool2000000030820P03oool0oooo
02/0oooo3`00002C0?ooo`<00000M@3oool00:80oooo0P0000000`20P800oooo0?ooo`0Z0?oooa40
000000<0@4100?ooo`3oool0S`3oool3000007D0oooo002R0?ooo`80000000<0P8200?ooo`3oool0
:@3oool01@20P8000000000000000000oooo00l00000T03oool3000007D0oooo002R0?ooo`800000
00<0P8200?ooo`3oool0:@3oool01010@400000000000020P8020?ooo`030820P010@400000000`0
000000<0P8200?ooo`3oool0S03oool3000007D0oooo002R0?ooo`80000000<0P8200?ooo`3oool0
:03oool4000000D0oooo3P0000000`20P800oooo0?ooo`2;0?ooo`<00000M@3oool00:80oooo0P00
00000`20P800oooo0?ooo`0W0?ooo`050<30`0000000000000000020P8001P3oool00`20P8000000
0000000<000000030<30`03oool0oooo08T0oooo0`00001e0?ooo`00XP3oool2000000030820P03o
ool0oooo02L0oooo100000090?ooo`l00000RP3oool3000007D0oooo002R0?ooo`80000000<0P820
0?ooo`3oool09P3oool5000000X0oooo3`0000290?ooo`<00000M@3oool00:80oooo0P0000000`20
P800oooo0?ooo`0U0?ooo`050820P0000000000000000010@400303oool00`10@40000000000000;
000000030410@020P800oooo0?h0oooo002R0?ooo`80000000<0P8200?ooo`3oool09@3oool40000
00l0oooo3P0000000`20P800oooo0?ooo`3l0?ooo`00XP3oool2000000030820P03oool0oooo02@0
oooo1000000A0?ooo`030410@0000000000000/0000000<0P8200<30`03oool0n`3oool00:80oooo
0P0000000`20P800oooo0?ooo`0S0?ooo`@0000000<0P8200?ooo`3oool04@3oool>00000?`0oooo
002R0?ooo`80000000<0P8200?ooo`3oool08P3oool01@10@4000000000000000000P82001@0oooo
00<0`<300820P0000000300000000`20P800oooo0?ooo`3h0?ooo`00XP3oool2000000030820P03o
ool0oooo0240oooo100000000`20P800oooo0?ooo`0E0?ooo`030820P0000000000000`00000n@3o
ool00:80oooo0P0000000`20P800oooo0?ooo`0P0?ooo`050410@0000000000000000020P8006@3o
ool00`20P800@4100000000<000000030820P03oool0oooo0?D0oooo002R0?ooo`80000000<0P820
0?ooo`3oool07`3oool4000001d0oooo3`00003f0?ooo`00XP3oool2000000030820P03oool0oooo
01h0oooo00D0@41000000000000000000<30`00N0?ooo`030820P0000000000000`0000000<0P820
0?ooo`3oool0lP3oool00:80oooo0P0000000`20P800oooo0?ooo`0M0?ooo`@000008P3oool>0000
00030820P03oool0oooo0?40oooo002R0?ooo`80000000<0P8200?ooo`3oool0703oool01@20P800
0000000000000000P82002<0oooo3`00003b0?ooo`00XP3oool2000000030820P03oool0oooo01X0
oooo00H0`<3000000000000000000410@020P80U0?ooo`030820P0000000000000/0000000<0@410
0820P03oool0k`3oool00:80oooo0P0000000`20P800oooo0?ooo`0I0?ooo`D00000:@3oool>0000
00030820P03oool0oooo0>d0oooo002R0?ooo`80000000<0P8200?ooo`3oool05`3oool00`10@400
000000000002000000030820P03oool0oooo02T0oooo00<0@4100000000000002`0000000`20P800
`<300?ooo`1d0?ooo`<0P820M@3oool00:80oooo0P0000000`20P800oooo0?ooo`0E0?ooo`030820
P0000000000000<00000;`3oool>000007D0oooo0`00001e0?ooo`00XP3oool2000000030820P03o
ool0oooo01<0oooo00<0`<300820P00000000`0000000`20P800oooo0?ooo`0^0?ooo`030<30`000
0000000000`0000000<0P8200<30`03oool0L@3oool3000007D0oooo002R0?ooo`80000000<0P820
0?ooo`3oool04@3oool00`20P800000000000003000000030820P03oool0oooo0380oooo00<0P820
0000000000003000001b0?ooo`<00000M@3oool00:80oooo0P0000000`20P800oooo0?ooo`0<0?oo
o`040<30`020P800P8200410@0D0000000<0P8200?ooo`3oool0=@3oool20820P0d0000000<0P820
0?ooo`3oool0KP3oool3000007D0oooo002R0?ooo`80000000<0P8200?ooo`3oool02`3oool80000
00030820P03oool0oooo03T0oooo00<0P8200000000000003000001_0?ooo`<00000M@3oool00:80
oooo0P0000000`20P800oooo0?ooo`060?ooo`80P82000<0@4100000000000001@0000000`20P800
`<300?ooo`0m0?ooo`030820P010@400000000`0000000<0P8200?ooo`3oool0J`3oool3000007D0
oooo002R0?ooo`80000000<0P8200?ooo`0000003P0000140?ooo`h0000000<0P8200?ooo`3oool0
JP3oool3000007D0oooo002R0?ooo`80000000<0P8200?ooo`0000002@0000030820P4L0oooo00<0
P820000000000000300000000`30`<00oooo0?ooo`1X0?ooo`<00000M@3oool00:80oooo0P000000
0`20P800oooo00000006000000030820P03oool0oooo04`0oooo3P00003R0?ooo`00XP3oool20000
00030820P03oool0oooo01d0oooo1P00000c0?ooo`l00000h03oool00:80oooo0P0000000`20P800
oooo0?ooo`0J0?ooo`050820P0000000000000000010@4000`20P8001@10@400000000000010@400
P8200300oooo00<0@4100000000000002`0000000`10@400P8200?ooo`3M0?ooo`00XP3oool20000
00030820P03oool0oooo01T0oooo100000070?ooo`@00000<@3oool>000000030820P03oool0oooo
0=/0oooo002R0?ooo`80000000<0P8200?ooo`3oool05`3oool00`30`<0000000000000200000003
0<30`03oool0oooo00H0oooo00D0`<3000000000000000000<30`00`0?ooo`030410@00000000000
00/0000000<0P8200<30`03oool0fP3oool00:80oooo0P0000000`20P800oooo0?ooo`0G0?ooo`03
0820P00000000000008000002`3oool300000380oooo3P00003K0?ooo`00XP3oool2000000030820
P03oool0oooo01L0oooo1000000<0?ooo`050820P0000000000000000030`<00<03oool00`30`<00
P8200000000<000000030820P03oool0oooo0=L0oooo002R0?ooo`80000000<0P8200?ooo`3oool0
5P3oool5000000d0oooo1000000b0?ooo`030820P0000000000000`00000f03oool00:80oooo0P00
00000`20P800oooo0?ooo`0F0?ooo`D000003@3oool00`20P80000000000000200000380oooo00<0
P8200410@0000000300000000`10@400oooo0?ooo`3D0?ooo`00XP3oool2000000030820P03oool0
oooo01D0oooo00<0P8200000000000000`00000>0?ooo`@0000000<0P8200?ooo`3oool0<@3oool?
00000=D0oooo002R0?ooo`80000000<0P8200?ooo`3oool05@3oool00`20P8000000000000030000
00h0oooo00D0@41000000000000000000410@00d0?ooo`030820P0000000000000`0000000<0P820
0?ooo`3oool0d@3oool00:80oooo0P0000000`20P800oooo0?ooo`0E0?ooo`030820P00000000000
00<000003P3oool00`20P800000000000003000003D0oooo3P0000000`20P800oooo0?ooo`3@0?oo
o`00XP3oool2000000030820P03oool0oooo01D0oooo00<0P8200000000000000`00000>0?ooo`03
0820P0000000000000<00000=P3oool00`20P80000000000000<00000=40oooo002R0?ooo`800000
00<0P8200?ooo`3oool05@3oool00`20P800000000000003000000l0oooo1@0000000`20P800oooo
0?ooo`0d0?ooo`030820P0000000000000/0000000<0@4100?ooo`3oool0cP3oool00:80oooo0P00
00000`20P800oooo0?ooo`0E0?ooo`030820P0000000000000<000003`3oool6000003P0oooo3P00
00000`20P800oooo0?ooo`3<0?ooo`00XP3oool2000000030820P03oool0oooo01D0oooo00<0P820
0000000000000`00000@0?ooo`D0000000<0P8200?ooo`3oool0=P3oool00`10@40000000000000;
00000080P820E03oool3000007D0oooo002R0?ooo`80000000<0P8200?ooo`3oool05@3oool00`20
P80000000000000300000100oooo1P00000j0?ooo`h0000000<0P8200?ooo`3oool0D@3oool30000
07D0oooo002R0?ooo`80000000<0P8200?ooo`3oool05@3oool00`20P800000000000004000000l0
oooo00<0@4100000000000000`00000j0?ooo`030<30`020P800000000`0000000<0P8200<30`03o
ool0D03oool3000007D0oooo002R0?ooo`80000000<0P8200?ooo`3oool05@3oool00`20P8000000
00000004000000l0oooo00<0P8200000000000000`00000m0?ooo`h00000D@3oool3000007D0oooo
002R0?ooo`80000000<0P8200?ooo`3oool05@3oool00`30`<00000000000004000000l0oooo00<0
P8200000000000001000000l0?ooo`030<30`020P800000000`0000000<0P8200?ooo`3oool0C@3o
ool3000007D0oooo002R0?ooo`80000000<0P8200?ooo`3oool05P3oool6000000030820P03oool0
oooo00`0oooo00<0P8200000000000001000000n0?ooo`030820P0000000000000`00000CP3oool3
000007D0oooo002R0?ooo`80000000<0P8200?ooo`3oool05P3oool6000000030820P03oool0oooo
00d0oooo1P0000000`20P800oooo0?ooo`0l0?ooo`030820P010@400000000`0000000<0P8200?oo
o`3oool0BP3oool3000007D0oooo002R0?ooo`80000000<0P8200?ooo`3oool05P3oool600000003
0820P03oool0oooo00d0oooo1P0000000`20P800oooo0?ooo`0n0?ooo`h0000000<0P8200?ooo`3o
ool0B@3oool3000007D0oooo002R0?ooo`80000000<0P8200?ooo`3oool05P3ooolL000000030820
P03oool0oooo03l0oooo00<0P820000000000000300000320?ooo`00XP3oool2000000030820P03o
ool0oooo01H0oooo00<0P8200000000000006@0000000`10@400oooo0?ooo`100?ooo`030820P000
0000000000`0000000<0`<300?ooo`3oool0_P3oool00:80oooo0P0000000`20P800oooo0?ooo`0G
0?oooa`00000A03oool?00000;l0oooo002R0?ooo`80000000<0P8200?ooo`3oool05`3oool60000
0100oooo1P0000150?ooo`030820P0000000000000/0000000<0@4100?ooo`3oool0_03oool00:80
oooo0P0000000`20P800oooo0?ooo`0G0?ooo`030820P0000000000000@000003`3oool00`20P800
000000000003000004L0oooo3P0000000`20P800oooo0?ooo`2j0?ooo`00XP3oool2000000030820
P03oool0oooo01L0oooo00<0P8200000000000001000000?0?ooo`030820P0000000000000@00000
A`3oool00`20P80000000000000;000000030820P030`<00oooo0;T0oooo002R0?ooo`80000000<0
P8200?ooo`3oool0603oool6000000l0oooo00<0P820000000000000100000190?ooo`h00000^P3o
ool00:80oooo0P0000000`20P800oooo0?ooo`0H0?ooo`H0000000<0P8200?ooo`3oool0303oool0
0`30`<00000000000004000004T0oooo00<0`<300820P0000000300000000`20P800oooo0?ooo`2f
0?ooo`00XP3oool2000000030820P03oool0oooo01T0oooo1@0000000`20P800oooo0?ooo`0=0?oo
o`H00000B`3oool00`20P80000000000000<00000;L0oooo002R0?ooo`80000000<0P8200?ooo`3o
ool06@3oool5000000030410@03oool0oooo00d0oooo1P00001<0?ooo`030820P010@400000000`0
000000<0P8200?ooo`3oool0/`3oool00:80oooo0P0000000`20P800oooo0?ooo`0J0?ooo`D00000
3`3oool6000004h0oooo3`00002d0?ooo`00XP3oool2000000030820P03oool0oooo01X0oooo1@00
000?0?ooo`H00000C`3oool?00000;<0oooo002R0?ooo`80000000<0P8200?ooo`3oool06P3oool0
0`20P800000000000003000000h0oooo1P00001@0?ooo`030<30`0000000000000`0000000<0`<30
0?ooo`3oool0[`3oool00:80oooo0P0000000`20P800oooo0?ooo`0K0?ooo`D000003P3oool60000
0580oooo00<0P8200000000000003000002`0?ooo`00XP3oool2000000030820P03oool0oooo01/0
oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0;0?ooo`D0000000<0P8200?ooo`3o
ool0D@3oool00`20P80000000000000;000000030410@03oool0oooo03D0oooo0`20P81e0?ooo`00
XP3oool2000000030820P03oool0oooo01`0oooo00<0P8200000000000000P00000=0?ooo`D00000
EP3oool>000000030820P03oool0oooo03<0oooo0`00001e0?ooo`00XP3oool2000000030820P03o
ool0oooo01`0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`0:0?ooo`D00000E`3o
ool00`10@40000000000000;000000030820P03oool0oooo0380oooo0`00001e0?ooo`00XP3oool2
000000030820P03oool0oooo01h0oooo1000000<0?ooo`@0000000<0P8200?ooo`3oool0E`3oool>
000000030820P03oool0oooo0300oooo0`00001e0?ooo`00XP3oool2000000030820P03oool0oooo
01h0oooo00D0`<3000000000000000000410@00:0?ooo`030<30`000000000000080000000<0`<30
0?ooo`3oool0E`3oool00`30`<00P8200000000<000000030820P030`<00oooo02l0oooo0`00001e
0?ooo`00XP3oool2000000030820P03oool0oooo0200oooo100000090?ooo`030820P00000000000
00800000G@3oool>00000300oooo0`00001e0?ooo`00XP3oool2000000030820P03oool0oooo0200
oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`040?ooo`050820P000000000000000
0010@400GP3oool00`30`<00P8200000000<000000030820P03oool0oooo02`0oooo0`00001e0?oo
o`00XP3oool2000000030820P03oool0oooo0280oooo00<0P8200000000000000P0000040?ooo`D0
0000H@3oool00`20P80000000000000<000002d0oooo0`00001e0?ooo`00XP3oool2000000030820
P03oool0oooo02@0oooo2P00001T0?ooo`h0000000<0P8200?ooo`3oool0:P3oool3000007D0oooo
002R0?ooo`80000000<0P8200?ooo`3oool09P3oool60820P6L0oooo00<0`<300000000000003000
00000`30`<00oooo0?ooo`0X0?ooo`<0P820M@3oool00:80oooo0P0000000`20P800oooo0?ooo`2E
0?ooo`030820P0000000000000`00000X@3oool00:80oooo0P0000000`20P800oooo0?ooo`2F0?oo
o`030820P0000000000000`0000000<0`<300?ooo`3oool0W@3oool00:80oooo0P0000000`20P800
oooo0?ooo`1a0?ooo`D000008P3oool?000009h0oooo002R0?ooo`80000000<0P8200?ooo`3oool0
L@3oool00`20P800000000000002000000030820P03oool0oooo0200oooo00<0P820000000000000
2`0000000`10@400oooo0?ooo`2K0?ooo`00XP3oool2000000030820P03oool0oooo0780oooo1000
00000`20P800oooo0?ooo`0R0?ooo`h0000000<0P8200?ooo`3oool0V@3oool00:80oooo0P000000
0`20P800oooo0?ooo`1b0?ooo`030410@00000000000008000009@3oool00`20P80000000000000;
000000030820P03oool0oooo09P0oooo002R0?ooo`80000000<0P8200?ooo`3oool0LP3oool00`20
P800000000000002000002L0oooo3P00002I0?ooo`00XP3oool2000000030820P03oool0oooo0780
oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0T0?ooo`030<30`020P800000000`0
000000<0P8200<30`03oool0U@3oool00:80oooo0P0000000`20P800oooo0?ooo`1c0?ooo`D00000
:03oool00`20P80000000000000<000000X0oooo00<0P8200000003oool0R@3oool00:80oooo0P00
00000`20P800oooo0?ooo`1c0?ooo`H00000:03oool?000000P0oooo0`00002:0?ooo`00XP3oool2
000000030820P03oool0oooo07<0oooo00<0P8200000000000000`00000Y0?ooo`030<30`0000000
000000`0000000<0P8200?ooo`3oool00P3oool00`20P800000000000002000000030410@03oool0
oooo08L0oooo002R0?ooo`80000000<0P8200?ooo`3oool0M03oool5000000030820P03oool0oooo
02T0oooo3@0000000`20P800oooo0?ooo`07000008T0oooo002R0?ooo`80000000<0P8200?ooo`3o
ool0M03oool5000000030410@03oool0oooo02T0oooo00<0`<30000000000000300000000`10@400
000000000006000008P0oooo002R0?ooo`80000000<0P8200?ooo`3oool0M03oool00`20P8000000
00000003000002d0oooo00<0P8200000000000004`0000000`20P800oooo0?ooo`0=0?ooo`<00000
M@3oool00:80oooo0P0000000`20P800oooo0?ooo`1d0?ooo`030820P0000000000000@00000;@3o
ool00`20P80000000000000C000000030820P03oool0oooo00`0oooo0`00001e0?ooo`00XP3oool2
000000030820P03oool0oooo07D0oooo1P0000000`20P800oooo0?ooo`0/0?oooaD0000000<0P820
0?ooo`3oool02`3oool3000007D0oooo002R0?ooo`80000000<0P8200?ooo`3oool0M@3oool50000
00030820P010@400oooo02h0oooo00<0P8200000000000004@0000000`10@400oooo0?ooo`0;0?oo
o`<00000M@3oool00:80oooo0P0000000`20P800oooo0?ooo`1e0?ooo`H0000000<0P8200000003o
ool0;`3ooolD000000`0oooo0`00001e0?ooo`00XP3oool2000000030820P03oool0oooo07H0oooo
1@0000000`30`<0000000<30`00`0?ooo`030820P000000000000100000000<0`<300?ooo`3oool0
2@3oool3000007D0oooo002R0?ooo`80000000<0P8200?ooo`3oool0MP3oool5000000030?ooo`00
000000000340oooo4`00000;0?ooo`<00000M@3oool00:80oooo0P0000000`20P800oooo0?ooo`1f
0?ooo`030820P000000000000080000000@0P8200?ooo`0000000000;`3oool00`20P80000000000
000A000000/0oooo0`00001e0?ooo`00XP3oool2000000030820P03oool0oooo07H0oooo00<0P820
0000000000000P0000001@20P800oooo0820P0000000`<3002h0oooo00<0@4100000000000004P00
00000`20P800oooo0?ooo`070?ooo`<00000M@3oool00:80oooo0P0000000`20P800oooo0?ooo`1f
0?ooo`030820P0000000000000<000000P3oool2000000H0oooo0P00000V0?oooaH0000000<0P820
0?ooo`3oool0OP3oool00:80oooo0P0000000`20P800oooo0?ooo`1g0?ooo`D000000`3oool20000
00040<30`03oool0oooo0?ooo`<0000000<0@4100?ooo`3oool08P3oool00`20P80000000000000D
000000030410@03oool0oooo07h0oooo002R0?ooo`80000000<0P8200?ooo`3oool0M`3oool50000
00<0oooo00<0P8200000000000000`3oool4000002@0oooo6@00001o0?ooo`00XP3oool200000003
0820P03oool0oooo07L0oooo00<0P8200000000000000`0000030?ooo`050820P000000000000820
P010@400100000000`20P800oooo0?ooo`0P0?ooo`030820P0000000000001L0000000<0`<300?oo
o`3oool0O03oool00:80oooo0P0000000`20P800oooo0?ooo`1h0?ooo`D00000103oool00`20P800
000000000006000002@0oooo00<0P8200000000000005`00001m0?ooo`00XP3oool2000000030820
P03oool0oooo07L0oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`020?ooo`030820
P0000000000000D000009P3oool00`30`<00P8200410@00E000000030410@03oool0oooo07X0oooo
002R0?ooo`80000000<0P8200?ooo`3oool0L`3oool:000000030820P03oool0oooo00@0oooo1P00
000[0?oooaD0000000<0P8200?ooo`3oool0N03oool00:80oooo0P0000000`20P800oooo0?ooo`1c
0?ooo`<0P820200000060?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0:`3oool2
0820P0030410@0000000000000h0000000<0@4100?ooo`3oool0N03oool00:80oooo0P0000000`20
P800oooo0?ooo`1k0?ooo`030820P0000000000000P0oooo00<0P820000000000000<P3oool00`20
P80000000000000<000000030820P03oool0oooo07P0oooo002R0?ooo`80000000<0P8200?ooo`3o
ool0_@3oool00`20P80000000000000:000007/0oooo002R0?ooo`80000000<0P8200?ooo`3oool0
_`3oool00`30`<00P8200410@008000000030820P03oool0oooo07P0oooo002R0?ooo`80000000<0
P8200?ooo`3oool0``3oool8000007X0oooo002R0?ooo`80000000<0P8200?ooo`3oool0a03oool0
1@10@400000000000020P800@4100080000000<0P8200?ooo`3oool0M`3oool00:80oooo0P000000
0`20P800oooo0?ooo`360?ooo`070000003oool0oooo0?ooo`20P80000000820P01h0?ooo`00XP3o
ool2000000030820P03oool0oooo0?l0ooooAP3oool00:80oooo0P0000000`20P800oooo0?ooo`3o
0?ooodH0oooo002R0?ooo`80000000<0P8200?ooo`3oool0o`3ooom60?ooo`00XP3oool200000003
0820P03oool0oooo0?l0ooooAP3oool00:80oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo
002R0?ooo`80000000<0P8200?ooo`3oool0o`3ooom60?ooo`00XP3oool2000000030820P03oool0
oooo0?l0ooooAP3oool00:80oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo002R0?ooo`80
000000<0P8200?ooo`3oool0o`3ooom60?ooo`00XP3oool2000000030820P03oool0oooo0?l0oooo
AP3oool00:80oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo002R0?ooo`80000000<0P820
0?ooo`3oool0o`3ooom60?ooo`00XP3oool2000000030820P03oool0oooo0?l0ooooAP3oool00:80
oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo002R0?ooo`80000000<0P8200?ooo`3oool0
o`3ooom60?ooo`00XP3oool2000000030820P03oool0oooo0?l0ooooAP3oool00:80oooo0P000000
0`20P800oooo0?ooo`3o0?ooodH0oooo002R0?ooo`80000000<0P8200?ooo`3oool0o`3ooom60?oo
o`00XP3oool2000000030820P03oool0oooo0?l0ooooAP3oool00:80oooo0P0000000`20P800oooo
0?ooo`3o0?ooodH0oooo002R0?ooo`80000000<0P8200?ooo`3oool0o`3ooom60?ooo`00XP3oool2
000000030820P03oool0oooo0?l0ooooAP3oool00:80oooo0P0000000`20P800oooo0?ooo`3o0?oo
odH0oooo002R0?ooo`80000000<0P8200?ooo`3oool0o`3ooom60?ooo`00XP3oool2000000030820
P03oool0oooo0?l0ooooAP3oool00:80oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo002R
0?ooo`80000000<0P8200?ooo`3oool0o`3ooom60?ooo`00XP3oool2000000030820P03oool0oooo
0?l0ooooAP3oool00:80oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo002R0?ooo`800000
00<0P8200?ooo`3oool0o`3ooom60?ooo`00XP3oool2000000030820P03oool0oooo0?l0ooooAP3o
ool00:80oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo002R0?ooo`80000000<0P8200?oo
o`3oool0o`3ooom60?ooo`00XP3oool2000000030820P03oool0oooo0?l0ooooAP3oool00:80oooo
0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo002R0?ooo`80000000<0P8200?ooo`3oool0o`3o
oom60?ooo`00XP3oool2000000030820P03oool0oooo0?l0ooooAP3oool00:80oooo0P0000000`20
P800oooo0?ooo`3o0?ooodH0oooo002R0?ooo`80000000<0P8200?ooo`3oool0o`3ooom60?ooo`00
XP3oool2000000030820P03oool0oooo0?l0ooooAP3oool00:80oooo0P0000000`20P800oooo0?oo
o`3o0?ooodH0oooo002R0?ooo`80000000<0P8200?ooo`3oool0o`3ooom60?ooo`00XP3oool20000
00030820P03oool0oooo0?l0ooooAP3oool00:80oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0
oooo002R0?ooo`80000000<0P8200?ooo`3oool0o`3ooom60?ooo`00XP3oool2000000030820P03o
ool0oooo0?l0ooooAP3oool00:80oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo002R0?oo
o`80000000<0P8200?ooo`3oool0o`3ooom60?ooo`00XP3oool2000000030820P03oool0oooo0?l0
ooooAP3oool00:80oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo002R0?ooo`80000000<0
P8200?ooo`3oool0o`3ooom60?ooo`00XP3oool2000000030820P03oool0oooo0?l0ooooAP3oool0
0:80oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo002R0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooom60?ooo`00XP3oool2000000030820P03oool0oooo0?l0ooooAP3oool00:80oooo0P00
00000`20P800oooo0?ooo`3o0?ooodH0oooo002R0?ooo`80000000<0P8200?ooo`3oool0o`3ooom6
0?ooo`00XP3oool2000000030820P03oool0oooo0?l0ooooAP3oool00:80oooo0P0000000`20P800
oooo0?ooo`3o0?ooodH0oooo002R0?ooo`80000000<0P8200?ooo`3oool0o`3ooom60?ooo`00XP3o
ool2000000030820P03oool0oooo0?l0ooooAP3oool00:80oooo0P0000000`20P800oooo0?ooo`3o
0?ooodH0oooo002R0?ooo`80000000<0P8200?ooo`3oool0o`3ooom60?ooo`00XP3oool200000003
0820P03oool0oooo0?l0ooooAP3oool00:80oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo
002R0?ooo`80000000<0P8200?ooo`3oool0o`3ooom60?ooo`00XP3oool2000000030820P03oool0
oooo0?l0ooooAP3oool00:80oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo002R0?ooo`80
000000<0P8200?ooo`3oool0o`3ooom60?ooo`00XP3oool2000000030820P03oool0oooo0?l0oooo
AP3oool00:80oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo002R0?ooo`80000000<0P820
0?ooo`3oool0o`3ooom60?ooo`00XP3oool2000000030820P03oool0oooo0?l0ooooAP3oool00:80
oooo0P0000000`20P800oooo0?ooo`3o0?ooodH0oooo002R0?ooo`80000000<0P8200?ooo`3oool0
o`3ooom60?ooo`00W`3oool30820P080000000<0@4100820P03oool0o`3ooom60?ooo`00W03oool>
00000?l0oooo@`3oool009P0oooo0P20P80B00000080P820o`3ooolo0?ooo`00V03ooolF00000?l0
oooo?`3oool009T0oooo5@00000=0?oooa<0P82000<0`<300?ooo`3oool0o`3ooolL0?ooo`00V@3o
oolD000000030820P03oool0oooo00/0oooo5000003o0?oooah0oooo002I0?ooo`030820P0000000
00000140000000<0P8200?ooo`3oool02`3ooolD00000?l0oooo7P3oool009T0oooo00<0P8200000
000000004@00000?0?oooa<00000o`3ooolN0?ooo`00VP3ooolC000000l0oooo00<0P82000000000
00004@00003o0?oooad0oooo002J0?oooa80000000<0P8200?ooo`3oool03P3oool00`20P8000000
0000000=0820P0<00000o`3ooolM0?ooo`00V`3ooolA00000180oooo00<0P8200000000000003@3o
ool2000000030820P03oool0oooo0?l0oooo6P3oool009/0oooo00<0@4100000000000003@000000
0`10@400oooo0?ooo`0A0?ooo`030820P0000000@41000`0oooo00<0`<3000000020P800o`3ooolL
0?ooo`00V`3oool00`20P80000000000000=000000030820P03oool0oooo01<0oooo0P00000<0?oo
o`800000o`3ooolL0?ooo`00V`3oool00`30`<0000000000000=000000030<30`03oool0oooo01<0
oooo00<0`<3000000010@400303oool00`20P800oooo0?ooo`3o0?oooaX0oooo002L0?ooo`l00000
603oool200000?l0oooo:03oool009`0oooo00<0P8200000000000002`00000I0?ooo`030<30`000
0000@4100?l0oooo9`3oool009d0oooo3@00000K0?ooo`800000o`3ooolV0?ooo`00W@3oool00`10
@400000000000009000001`0oooo00<0`<3000000010@400o`3ooolU0?ooo`00W@3oool00`20P800
000000000009000001h0oooo0P00003o0?ooob@0oooo002M0?ooo`030820P0000000000000P00000
00<0P8200?ooo`3oool0703oool00`20P80000000820P03o0?ooob<0oooo002N0?ooo`X0000000<0
`<300?ooo`3oool07@3oool00`20P80000000820P03o0?ooob80oooo002N0?ooo`X000008@3oool0
0`20P80000000000003o0?ooob40oooo002O0?ooo`P0000000<0P8200?ooo`3oool0803oool00`20
P80000000410@03o0?ooob00oooo002O0?ooo`P000009@3oool200000?l0oooo7`3oool00:00oooo
1P0000000`20P800oooo0?ooo`0F0?ooo`80P8202`3oool00`30`<0000000410@03o0?oooah0oooo
002P0?ooo`H0000000<0P8200?ooo`3oool05P3oool2000000030820P03oool0oooo00X0oooo0P00
003o0?oooad0oooo002P0?ooo`030820P0000000000000<000006P3oool2000000030820P03oool0
oooo00T0oooo00<0`<3000000010@400o`3ooolL0?ooo`00X@3oool4000001/0oooo0`0000000`20
P800oooo0?ooo`0:0?ooo`800000o`3ooolK0?ooo`00X@3oool4000001`0oooo4@0000000`10@400
oooo0?ooo`3o0?oooaP0oooo002R0?ooo`80000000<0P8200?ooo`3oool06P3ooolC00000?l0oooo
6@3oool00:80oooo0P0000000`20P800oooo0?ooo`0J0?ooo`030820P000000000000100000000<0
P8200?ooo`3oool0o`3ooolF0?ooo`00XP3oool00`10@40000000<30`00L0?ooo`030820P0000000
000001400000o`3ooolH0?ooo`00XP3oool00`20P80000000?ooo`0M0?oooa<00000o`3ooolH0?oo
o`00XP3oool00`30`<00P8200?ooo`3o0?ooodP0oooo003o0?ooond0oooo003o0?ooond0oooo003o
0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o
0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o
0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o
0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o
0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o
0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o
0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o
0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o
0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o
0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o
0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o
0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o
0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o0?ooond0oooo003o
0?ooond0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{119, 131.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 3.11 Spherical coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta], \[Phi])\)\)]],
  "."
}], "Caption",
  CellTags->"Fig. 3.11"],

Cell[TextData[{
  "The separation-of-variables analysis proceeds just as before. One finds \
that Eq ",
  ButtonBox["(3.2.28)",
    ButtonData:>"(3.2.28)",
    ButtonStyle->"Hyperlink"],
  " separates into three ODEs for ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta]\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[PartialD]\^2 \[CapitalPhi]\/\[PartialD]\[Phi]\^2 \
= \(-m\^2\) \(\[CapitalPhi](\[Phi])\)\)\(,\)\)\)]]], "NE2",
  CellTags->"(3.2.29)"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(\(sin\[Theta]\)\(\ \ \)\)\) \(\[PartialD]\/\
\[PartialD]\[Theta]\) \((sin\[Theta] \[PartialD]\[CapitalTheta]\/\[PartialD]\
\[Theta])\) - \(m\^2\/\(\(sin\^2\) \(\[Theta]\)\(\ \)\)\) \(\[CapitalTheta](\
\[Theta])\) = \[Lambda]\ \(\[CapitalTheta](\[Theta])\)\)]],
  ","
}], "NE2",
  CellTags->"(3.2.30)"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/r\^2\) \(\[PartialD]\/\[PartialD]r\) \
\((\(r\^2\) \[PartialD]R\/\[PartialD]r)\)\  + \[Lambda]\/r\^2\ \(R(r)\) = 
        0\)]],
  ","
}], "NE2",
  CellTags->"(3.2.31)"],

Cell[TextData[{
  "where we have  introduced the separation constants ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ".  Just as in cylindrical coordinates, periodicity of the angle \[Phi] \
implies that ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " must be an integer, so that the eigenvalue problem posed by Eq. ",
  ButtonBox["(3.2.29)",
    ButtonData:>"(3.2.29)",
    ButtonStyle->"Hyperlink"],
  " has the solution"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi](\[Phi])\  = \ \[ExponentialE]\^\(\
\[ImaginaryI]\ m\ \[Phi]\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Element] \ Integers\)]],
  "."
}], "NE2",
  CellTags->"(3.2.32)"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Eigenmodes in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  ": Associated Legendre Functions"
}], "Section",
  CellTags->"c:36"],

Cell[TextData[{
  Cell[BoxData[
      FormBox["", TraditionalForm]]],
  "Turning to Eq. ",
  ButtonBox["(3.2.30)",
    ButtonData:>"(3.2.30)",
    ButtonStyle->"Hyperlink"],
  ", we make a coordinate transformation to the variable ",
  Cell[BoxData[
      \(TraditionalForm\`x = cos\[Theta]\)]],
  ". Then by the chain rule, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\[PartialD]\[CapitalTheta]\/\[PartialD]\[Theta]\),
            "TraditionalForm"], "=", 
          RowBox[{
            RowBox[{
              FormBox[\(\[PartialD]x\/\[PartialD]\[Theta]\),
                "TraditionalForm"], 
              FormBox[\(\[PartialD]\[CapitalTheta]\/\[PartialD]x\),
                "TraditionalForm"]}], 
            "=", \(\(-sin\[Theta]\)\ \[PartialD]\[CapitalTheta]\/\[PartialD]x \
= \(-\@\(1 - x\^2\)\) \[PartialD]\[CapitalTheta]\/\[PartialD]x\)}]}], 
        TraditionalForm]]],
  ". When written in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", Eq. ",
  ButtonBox["(3.2.30)",
    ButtonData:>"(3.2.30)",
    ButtonStyle->"Hyperlink"],
  "  becomes "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\[PartialD]\/\[PartialD]x\) \((\((1 - 
                  x\^2)\) \[PartialD]\[CapitalTheta]\/\[PartialD]x)\) - \
\(m\^2\/\(1 - x\^2\)\) \(\[CapitalTheta](x)\) = \[Lambda]\ \(\[CapitalTheta](
          x)\)\)]]], "NE2",
  CellTags->"(3.2.33)"],

Cell[TextData[{
  "This ODE has regular singular points at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\[PlusMinus]1\)\)]],
  ". Its general solution is in terms of special functions called ",
  StyleBox["hypergeometric functions",
    FontSlant->"Italic"],
  ". In general, these functions are singular at the end points because of \
the regular singular points there.  However, ",
  StyleBox["for special values of ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)],
    FontSlant->"Italic"],
  ", the solution is finite at both ends. Again, we have an eigenvalue \
problem. In this case, the eigenvalues are"
}], "Text",
  CellTags->"i:69"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\  = \ \(-\(l(l + 1)\)\)\)]],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " a positive integer taking on the values  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(l\)\(\[GreaterEqual]\)\)\  | m | \)]],
  "."
}], "NE2",
  CellTags->"(3.2.34)"],

Cell[TextData[{
  "The corresponding eigenmodes are special cases of the hypergeometric \
functions called ",
  StyleBox["associated Legendre functions, ",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"i:70"],

Cell[TextData[{
  StyleBox["\t\t",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta](\[Theta]) = \(P\_l\%m\)(x)\)]],
  "   ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(,\)\(x = cos\ \[Theta]\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\)\(=\)\(0\)\(\ \)\)\)]],
  " the functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_l\%m\)(x)\)]],
  " are simple polynomials called Legendre polynomials,  but for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\)\(\[NotEqual]\)\(\ \)\(0\)\(\ \)\)\)]],
  ", they have the form of a polynomial of order ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(l\)\(-\)\) | m | \)]],
  " multiplied by the factor ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 - \
x\^2)\)\^\(\(|\)\(m\)\(|\)\(\(/\)\(2\)\)\)\)]],
  ". Some of these functions are listed in Table ",
  ButtonBox["3.2",
    ButtonData:>"Table 3.2",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      StyleBox["Table",
        FontSize->10], 
      StyleBox[" ",
        FontSize->10], 
      StyleBox["3",
        FontSize->10], 
      StyleBox[".2",
        FontSize->10], 
      StyleBox[
        RowBox[{
          StyleBox[" ",
            FontSize->10], " "}]], 
      StyleBox["Associated",
        FontSize->10], 
      StyleBox[" ",
        FontSize->10], 
      StyleBox["Legendre",
        FontSize->10], 
      StyleBox[" ",
        FontSize->10], 
      StyleBox["Functions",
        FontSize->10], 
      StyleBox[" ",
        FontSize->10], Cell[TextData[Cell[BoxData[
          \(TraditionalForm\`\(P\_l\%m\)(x)\)],
        FontFamily->"Times"]]]}], "\n", 
    StyleBox[
      InterpretationBox[GridBox[{
            {
              StyleBox["l",
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox["m",
                  FontSlant->"Italic"], "=", \(-2\)}], \(-1\), "0", "1", 
              "2"},
            {"0", "\<\"\"\>", "\<\"\"\>", "1", "\<\"\"\>", "\<\"\"\>"},
            {"1", "\<\"\"\>", 
              FractionBox[
                SqrtBox[
                  RowBox[{"1", "-", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontSlant->"Italic"], "2"]}]], "2"], 
              StyleBox["x",
                FontSlant->"Italic"], 
              RowBox[{"-", 
                SqrtBox[
                  RowBox[{"1", "-", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontSlant->"Italic"], "2"]}]]}], "\<\"\"\>"},
            {"2", 
              RowBox[{\(1\/8\), " ", 
                RowBox[{"(", 
                  RowBox[{"1", "-", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontSlant->"Italic"], "2"]}], ")"}]}], 
              RowBox[{\(1\/2\), " ", 
                StyleBox["x",
                  FontSlant->"Italic"], " ", 
                SqrtBox[
                  RowBox[{"1", "-", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontSlant->"Italic"], "2"]}]]}], 
              RowBox[{\(-\(1\/2\)\), "+", 
                FractionBox[
                  RowBox[{"3", " ", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontSlant->"Italic"], "2"]}], "2"]}], 
              RowBox[{\(-3\), " ", 
                StyleBox["x",
                  FontSlant->"Italic"], " ", 
                SqrtBox[
                  RowBox[{"1", "-", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontSlant->"Italic"], "2"]}]]}], 
              RowBox[{"3", " ", 
                RowBox[{"(", 
                  RowBox[{"1", "-", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontSlant->"Italic"], "2"]}], ")"}]}]}
            },
          RowSpacings->1,
          ColumnSpacings->1.5,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{1}, {
          Times[ 
            Rational[ 1, 2], 
            Power[ 
              Plus[ 1, 
                Times[ -1, 
                  Power[ x, 2]]], 
              Rational[ 1, 2]]], x, 
          Times[ -1, 
            Power[ 
              Plus[ 1, 
                Times[ -1, 
                  Power[ x, 2]]], 
              Rational[ 1, 2]]]}, {
          Times[ 
            Rational[ 1, 8], 
            Plus[ 1, 
              Times[ -1, 
                Power[ x, 2]]]], 
          Times[ 
            Rational[ 1, 2], x, 
            Power[ 
              Plus[ 1, 
                Times[ -1, 
                  Power[ x, 2]]], 
              Rational[ 1, 2]]], 
          Plus[ 
            Rational[ -1, 2], 
            Times[ 
              Rational[ 3, 2], 
              Power[ x, 2]]], 
          Times[ -3, x, 
            Power[ 
              Plus[ 1, 
                Times[ -1, 
                  Power[ x, 2]]], 
              Rational[ 1, 2]]], 
          Times[ -3, 
            Plus[ -1, 
              Power[ x, 2]]]}}]],
      FontFamily->"Times"]}], "Text",
  Background->GrayLevel[0.849989],
  CellTags->"Table 3.2"],

Cell["", "Text"],

Cell[TextData[{
  "The table shows, among other things,  that the functional form of ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_l\%m\)(x)\)]],
  " differs only by a constant from ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_l\%\(-m\)\)(x)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "We can see using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that the associated Legendre functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_l\%m\)(x)\)]],
  " satisfy Eq. ",
  ButtonBox["(3.2.33)",
    ButtonData:>"(3.2.33)",
    ButtonStyle->"Hyperlink"],
  ".  In ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "these functions are  called ",
  StyleBox["LegendreP[l,m,x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The following cell tests whether each Legendre function satisfies Eq. ",
  ButtonBox["(3.2.33)",
    ButtonData:>"(3.2.33)",
    ButtonStyle->"Hyperlink"],
  ",  up to ",
  Cell[BoxData[
      \(TraditionalForm\`l = 5\)]],
  ":"
}], "Text",
  CellTags->"i:83"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[CapitalTheta][x_]\  = \ LegendreP[l, m, x];\)\), "\n", 
    \(Table[
      Table[Simplify[
          D[\((1 - x^2)\) D[LegendreP[l, m, x], x], x]\  - \ 
              m^2\ \[CapitalTheta][
                    x]/\((1 - x^2)\)\  \[Equal] \ \(-l\) \((l + 
                  1)\) \[CapitalTheta][x]], {m, \(-l\), l}], {l, 0, 
        5}]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.19"],

Cell[BoxData[
    \({{True}, {True, True, True}, {True, True, True, True, True}, {True, 
        True, True, True, True, True, True}, {True, True, True, True, True, 
        True, True, True, True}, {True, True, True, True, True, True, True, 
        True, True, True, True}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Turning to the radial dependence of the potential, we require the solution \
of Eq. ",
  ButtonBox["(3.2.31)",
    ButtonData:>{"Chapter3.nb", "(3.2.31)"},
    ButtonStyle->"Hyperlink"],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = \(-\(l(l + 1)\)\)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[
      R[r] /. \(DSolve[
            1/r^2\ D[\ r^2\ \ D[R[r], r], r] - 
                l \((l + 1)\) R[r]/r^2 \[Equal] 0, R[r], r]\)[\([1]\)], 
      l > 0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.20"],

Cell[BoxData[
    \(r\^\(\(-1\) - l\)\ C[1] + r\^l\ C[2]\)], "Output"]
}, Open  ]],

Cell["Thus,", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`R(r) = A/r\^\(l + 1\) + \ B\ r\^l\)]],
  ","
}], "Text"],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " are constants."
}], "Text"],

Cell[TextData[{
  "\t Since ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " can take on different values, we have actually found an infinite number \
of independent solutions to Laplace's equation. We can sum them  together to \
obtain the general solution in spherical coordinates:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[CapitalPsi](r, \[Theta], \[Phi])\), "=", 
        RowBox[{
          
          FormBox[\(\[Sum]\+\(l = 0\)\%\[Infinity]\(\[Sum]\+\(m = \(-l\)\)\%l\
\((A\_\(l\ m\)/r\^\(l + 1\) + \ 
                      B\_\(l\ m\)\ r\^l)\) \(\[ExponentialE]\^\(\[ImaginaryI]\
\ m\ \[Phi]\)\) \(\(P\_l\%m\)(cos\ \[Theta])\)\)\),
            "TraditionalForm"], "."}]}], TraditionalForm]]]], "NE2",
  CellTags->"(3.2.35)"],

Cell[TextData[{
  "\tFinally, we are left with the task of determining the constants ",
  Cell[BoxData[
      \(TraditionalForm\`A\_\(l\ m\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(l\ m\)\)]],
  " in terms of the boundary conditions. Say, for example, we know the \
potential on the surface of a sphere of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " to be ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPsi](a, \[Theta], \[Phi])\  = 
        V(\[Theta], \[Phi])\)]],
  ".  If we require the solution within the sphere, we must then set ",
  Cell[BoxData[
      \(TraditionalForm\`A\_\(l\ m\) = 0\)]],
  " in order to keep the solution finite at the origin. At ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  " we have"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Sum]\+\(l = 0\)\%\[Infinity]\(\[Sum]\+\(m = \
\(-l\)\)\%l\ 
            B\_\(l\ m\)\ a\^l\ \(\[ExponentialE]\^\(\[ImaginaryI]\ m\ \
\[Phi]\)\) \(\(P\_l\%m\)(
                cos\ \[Theta])\)\)\)\(\ \)\(=\)\(V(\[Theta], \[Phi])\)\(\ \
\)\)\)]],
  "."
}], "NE2",
  CellTags->"(3.2.36)"],

Cell["\<\
It would be useful if the associated Legendre functions formed an \
orthogonal set, so that we could determine the Fourier coefficients by \
extracting a single term from the sum.  Amazingly,  the associated Legendre \
functions do satisfy an orthogonality relation:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Pi]\(\( P\_l\%m\)(
              cos\ \[Theta])\)\ \(\(P\_\(l\&_\)\%m\)(cos\ \[Theta])\) 
            sin\ \[Theta] \[DifferentialD]\[Theta] = \(2\/\(2  l + 
                1\)\) \(\(\((l + m)\)!\)\/\(\((l - 
                    m)\)!\)\) \[Delta]\_\(l, l\&_\)\)]],
  "."
}], "NE2",
  CellTags->{"i:72", "(3.2.37)"}],

Cell[TextData[{
  "Thus, we can determine ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(l\ m\)\)]],
  " by multiplying both sides of Eq. ",
  ButtonBox["(3.2.36)",
    ButtonData:>"(3.2.36)",
    ButtonStyle->"Hyperlink"],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\(\ \)\(m\)\(\
\ \)\(\[Phi]\)\(\ \)\)\) \(\(P\_l\%m\)(cos\ \[Theta])\)\)]],
  ", and then integrating over the surface of the sphere, (i.e., applying  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Pi] 
          sin\[Theta]\ \[DifferentialD]\[Theta] \(\[Integral]\_0\%\(2  \
\[Pi]\)\[DifferentialD]\[Phi]\)\)]],
  " ). This causes all terms in the sum to vanish except one, providing us \
with an equation for ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(l\ m\)\)]],
  ": "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi] \( 
              2\/\(2  l + 
                1\)\) \(\(\((l + m)\)!\)\/\(\((l - 
                    m)\)!\)\) \(B\_\(\(l\)\(\ \)\(m\)\(\ \)\)\) 
          a\^l = \[Integral]\_0\%\[Pi] 
            sin\[Theta]\ \[DifferentialD]\[Theta] \(\[Integral]\_0\%\(2  \
\[Pi]\)\[DifferentialD]\[Phi]\ \ \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ m\ \
\[Phi]\)\) \(\(P\_l\%m\)(cos\ \[Theta])\) \(V(\[Theta], \[Phi])\)\)\)]],
  ","
}], "NE2",
  CellTags->"(3.2.38)"],

Cell[TextData[{
  "where on the ",
  "left-hand",
  " side we have used Eq. ",
  ButtonBox["(3.2.37)",
    ButtonData:>"(3.2.37)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tAgain, we observe the surprising fact that the nontrigonometric \
eigenmodes ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_l\%m\)(cos\ \[Theta])\)]],
  " form an orthogonal set on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Theta] < \[Pi]\)]],
  ", just like trigonometric Fourier modes, but with respect to the integral \
given in Eq. ",
  ButtonBox["(3.2.37)",
    ButtonData:>"(3.2.37)",
    ButtonStyle->"Hyperlink"],
  ". The reasons for this will be discussed in Chapter ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Spherical Harmonics",
  FontWeight->"Bold"]], "Section",
  CellTags->{"i:71", "c:37"}],

Cell[TextData[{
  "\tIt is often convenient to combine the associated Legendre functions with \
the Fourier modes ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Phi]\)\)]],
  ". It is conventional to normalize the resulting functions of \[Theta] and \
\[Phi], creating an orthonormal set called the ",
  StyleBox["spherical harmonics",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_\(l, m\)\)(\[Theta], \[Phi])\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_\(l, 
              m\)\)(\[Theta], \[Phi]) = \(\@\(\(\(2  l + 
                      1\)\/\(4  \[Pi]\)\) \(\((l - m)\)!\)\/\(\((l + \
m)\)!\)\)\) \(\(P\_l\%m\)(
            cos\[Theta])\) \[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Phi]\)\)]],
  "."
}], "NE2",
  CellTags->"(3.2.39)"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has already defined these functions, with the intrinsic function ",
  StyleBox["SphericalHarmonicY[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["l",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["m",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[",\[Theta],\[Phi]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The spherical harmonics obey the following orthonormality condition with \
respect to an integral  over the surface of a unit sphere:"
}], "Text",
  CellTags->"i:84"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            
            FormBox[\(\[Integral]\_0\%\(2  \[Pi]\)\[DifferentialD]\[Phi] \(\
\[Integral]\_0\%\[Pi]\[DifferentialD]\[Theta]\ sin\[Theta]\)\),
              "TraditionalForm"], " ", \(Y\_\(l\&_, \ m\&_\)\^*\), "  ", 
            FormBox[\(Y\_\(l, \ m\)\),
              "TraditionalForm"]}], " ", 
          "=", \(\(\[Delta]\_\(l\ l\&_\)\) \[Delta]\_\(m\ m\&_\)\)}], 
        TraditionalForm]]],
  "."
}], "NE2",
  CellTags->{"i:73", "(3.2.40)"}],

Cell[TextData[{
  "\tWe have already seen in Eq. ",
  ButtonBox["(3.2.38)",
    ButtonData:>"(3.2.38)",
    ButtonStyle->"Hyperlink"],
  " that spherical harmonics are useful in decomposing functions defined on \
the surface of a sphere, ",
  Cell[BoxData[
      \(TraditionalForm\`f(\[Theta], \[Phi])\)]],
  ", such as the potential on a spherical conductor. The spherical harmonics \
also enter in many other problems with spherical symmetry. For instance, they \
describe some of the normal modes of oscillation of a rubber ball, and this \
example provides a useful method for visualizing the spherical harmonics."
}], "Text"],

Cell[TextData[{
  "\tThe plots in Cell ",
  ButtonBox["3.21",
    ButtonData:>"Cell 3.21",
    ButtonStyle->"Hyperlink"],
  " show the distortion of the ball for the ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  " modes, and for ",
  Cell[BoxData[
      \(TraditionalForm\`l = 0,  ... , 5\)]],
  ".  These modes are cylindrically-symmetric because they have ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  ". In each case the dashed line is the unperturbed spherical surface of the \
ball. We then add to this surface a distortion proportional to the given \
spherical harmonic."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = 0;\)\), "\n", 
    \(\(Do[
        r[\[Theta]_, \[Phi]_] = 
          1\  + \ 0.2 
               Re[SphericalHarmonicY[l, 
                  m, \[Theta], \[Phi]]]; \[IndentingNewLine]a = 
          ParametricPlot[{Sin[\[Theta]], Cos[\[Theta]]}, {\[Theta], 0, 
              2  Pi}, DisplayFunction \[Rule] Identity, 
            PlotStyle \[Rule] Dashing[{0.03, 0.03}]]; \[IndentingNewLine]b = 
          ParametricPlot[
            r[\[Theta], 0] {Sin[\[Theta]] Cos[0], Cos[\[Theta]]}, {\[Theta], 
              0, Pi}, DisplayFunction \[Rule] 
              Identity]; \[IndentingNewLine]c = 
          ParametricPlot[
            r[\[Theta], Pi] {Sin[\[Theta]] Cos[Pi], 
                Cos[\[Theta]]}, {\[Theta], 0, Pi}, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]d[l]\  = \ 
          Show[a, b, c, PlotRange \[Rule] {{\(-1.2\), 1.2}, {\(-1.2\), 1.2}}, 
            AspectRatio \[Rule] 1, Frame \[Rule] True, 
            FrameLabel \[Rule] "\<m=\>" <> ToString[m] <> "\<,l=\>" <> 
                ToString[l], RotateLabel \[Rule] False, 
            AxesLabel \[Rule] {"\<x\>", "\<z\>"}], {l, 0, 5}];\)\), "\n", 
    \(\ \ \ \(Show[GraphicsArray[{{d[0], d[1]}, {d[2], d[3]}, {d[4], d[5]}}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        PlotLabel \[Rule] "\<m=\>" <> 
            ToString[m] <> \ "\< Spherical Harmonics\>"];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.21"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.52381 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0362812 0.47619 [
[.5 1.53631 -71.0625 0 ]
[.5 1.53631 71.0625 12 ]
[ 0 0 0 0 ]
[ 1 1.52381 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.53631 -132.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
87.125 13.000 moveto
(Spherical) show
147.125 13.000 moveto
(Harmonics) show
201.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.52381 L
0 1.52381 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0362812 0.477324 0.489796 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.416667 0.5 0.416667 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.29167 -0.0125 -12 -9 ]
[.29167 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70833 -0.0125 -9 -9 ]
[.70833 -0.0125 9 0 ]
[.91667 -0.0125 -3 -9 ]
[.91667 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .29167 -24 -4.5 ]
[-0.0125 .29167 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .70833 -18 -4.5 ]
[-0.0125 .70833 0 4.5 ]
[-0.0125 .91667 -6 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -70.125 -6 ]
[-0.01875 .5 -24 6 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-1)] .08333 -0.0125 0 1 Mshowa
.29167 0 m
.29167 .00625 L
s
[(-0.5)] .29167 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70833 0 m
.70833 .00625 L
s
[(0.5)] .70833 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(1)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.125 0 m
.125 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.875 0 m
.875 .00375 L
s
.04167 0 m
.04167 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(-1)] -0.0125 .08333 1 0 Mshowa
0 .29167 m
.00625 .29167 L
s
[(-0.5)] -0.0125 .29167 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .70833 m
.00625 .70833 L
s
[(0.5)] -0.0125 .70833 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(1)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .125 m
.00375 .125 L
s
0 .16667 m
.00375 .16667 L
s
0 .20833 m
.00375 .20833 L
s
0 .25 m
.00375 .25 L
s
0 .33333 m
.00375 .33333 L
s
0 .375 m
.00375 .375 L
s
0 .41667 m
.00375 .41667 L
s
0 .45833 m
.00375 .45833 L
s
0 .54167 m
.00375 .54167 L
s
0 .58333 m
.00375 .58333 L
s
0 .625 m
.00375 .625 L
s
0 .66667 m
.00375 .66667 L
s
0 .75 m
.00375 .75 L
s
0 .79167 m
.00375 .79167 L
s
0 .83333 m
.00375 .83333 L
s
0 .875 m
.00375 .875 L
s
0 .04167 m
.00375 .04167 L
s
0 .95833 m
.00375 .95833 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -131.125 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
93.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
105.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.29167 .99375 m
.29167 1 L
s
.5 .99375 m
.5 1 L
s
.70833 .99375 m
.70833 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.125 .99625 m
.125 1 L
s
.16667 .99625 m
.16667 1 L
s
.20833 .99625 m
.20833 1 L
s
.25 .99625 m
.25 1 L
s
.33333 .99625 m
.33333 1 L
s
.375 .99625 m
.375 1 L
s
.41667 .99625 m
.41667 1 L
s
.45833 .99625 m
.45833 1 L
s
.54167 .99625 m
.54167 1 L
s
.58333 .99625 m
.58333 1 L
s
.625 .99625 m
.625 1 L
s
.66667 .99625 m
.66667 1 L
s
.75 .99625 m
.75 1 L
s
.79167 .99625 m
.79167 1 L
s
.83333 .99625 m
.83333 1 L
s
.875 .99625 m
.875 1 L
s
.04167 .99625 m
.04167 1 L
s
.95833 .99625 m
.95833 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .29167 m
1 .29167 L
s
.99375 .5 m
1 .5 L
s
.99375 .70833 m
1 .70833 L
s
.99375 .91667 m
1 .91667 L
s
.125 Mabswid
.99625 .125 m
1 .125 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .20833 m
1 .20833 L
s
.99625 .25 m
1 .25 L
s
.99625 .33333 m
1 .33333 L
s
.99625 .375 m
1 .375 L
s
.99625 .41667 m
1 .41667 L
s
.99625 .45833 m
1 .45833 L
s
.99625 .54167 m
1 .54167 L
s
.99625 .58333 m
1 .58333 L
s
.99625 .625 m
1 .625 L
s
.99625 .66667 m
1 .66667 L
s
.99625 .75 m
1 .75 L
s
.99625 .79167 m
1 .79167 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .875 m
1 .875 L
s
.99625 .04167 m
1 .04167 L
s
.99625 .95833 m
1 .95833 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ .03 .03 ] 0 setdash
.5 .91667 m
.50323 .91665 L
.50617 .91662 L
.50956 .91656 L
.51277 .91647 L
.51847 .91626 L
.52466 .91594 L
.53147 .91548 L
.53867 .91487 L
.55157 .91346 L
.56483 .91159 L
.57719 .90945 L
.60506 .9032 L
.63298 .89488 L
.65795 .88557 L
.71167 .8589 L
.75485 .82964 L
.7974 .79183 L
.83267 .75089 L
.86409 .70261 L
.87699 .67745 L
.88899 .64933 L
.89767 .62437 L
.90536 .5964 L
.90831 .58304 L
.91098 .56862 L
.91287 .55609 L
.9145 .5424 L
.91525 .53435 L
.9158 .5269 L
.9162 .51976 L
.91635 .51616 L
.91649 .51218 L
.91658 .50861 L
.91663 .50533 L
.91666 .50173 L
.91667 .49992 L
.91666 .49794 L
.91663 .49459 L
.91657 .49101 L
.91648 .48764 L
.91638 .48457 L
.9161 .47823 L
.91567 .47126 L
.91446 .4572 L
.91292 .44423 L
.9111 .43213 L
.90572 .40511 L
.89796 .37654 L
.88882 .35024 L
Mistroke
.87689 .32233 L
.85009 .27406 L
.81783 .23056 L
.7776 .18928 L
.731 .15323 L
.68292 .12563 L
.65838 .11461 L
.63177 .10472 L
.60629 .09712 L
.5827 .09162 L
.55695 .08724 L
.54269 .08553 L
.53612 .0849 L
.52914 .08435 L
.52318 .08398 L
.52001 .08381 L
.5166 .08366 L
.51347 .08355 L
.51061 .08347 L
.50787 .08341 L
.50499 .08336 L
.50184 .08334 L
.49849 .08334 L
.49532 .08336 L
.49244 .0834 L
.48906 .08348 L
.48539 .08359 L
.47874 .08388 L
.47225 .08426 L
.46529 .08478 L
.45275 .08602 L
.43789 .08799 L
.42441 .09025 L
.39541 .09667 L
.3684 .10466 L
.31782 .12527 L
.27375 .15011 L
.23254 .18051 L
.19173 .21968 L
.15859 .26114 L
.12907 .31021 L
.10731 .3607 L
.09893 .38708 L
.09499 .40215 L
.09178 .41651 L
.08929 .42981 L
.08707 .44431 L
.0855 .45755 L
.08443 .46981 L
.08399 .47667 L
Mistroke
.08368 .4831 L
.08354 .48678 L
.08345 .49015 L
.08341 .49201 L
.08338 .49404 L
.08335 .49596 L
.08334 .49774 L
.08333 .4996 L
.08334 .50161 L
.08335 .50351 L
.08337 .50526 L
.08342 .50858 L
.08351 .51208 L
.08363 .51584 L
.08378 .51936 L
.08423 .52733 L
.08476 .53447 L
.08536 .54107 L
.08711 .55594 L
.08909 .569 L
.09164 .58279 L
.09715 .60641 L
.10481 .63205 L
.12485 .68131 L
.15328 .73107 L
.18679 .77479 L
.22796 .8156 L
.27128 .84828 L
.31507 .87338 L
.34145 .88532 L
.36703 .89488 L
.39079 .9021 L
.41635 .90818 L
.4369 .91186 L
.44865 .91349 L
.45967 .91471 L
.46981 .91557 L
.47909 .91614 L
.48422 .91637 L
.48693 .91646 L
.48982 .91654 L
.49259 .9166 L
.4951 .91664 L
.49763 .91666 L
.5 .91667 L
Mfstroke
[ ] 0 setdash
.5 .98719 m
.50189 .98718 L
.50361 .98716 L
.50559 .98711 L
.50747 .98705 L
.5108 .9869 L
.51441 .98667 L
.51839 .98634 L
.5226 .98591 L
.53012 .9849 L
.53785 .98358 L
.54504 .98206 L
.56121 .97767 L
.57732 .97189 L
.59166 .96552 L
.62223 .94785 L
.64663 .92939 L
.6708 .9069 L
.71133 .85945 L
.7443 .81441 L
.77738 .77062 L
.81101 .73199 L
.84596 .69521 L
.88355 .65251 L
.90083 .62888 L
.91515 .60522 L
.92664 .58106 L
.93187 .56708 L
.93589 .55387 L
.93926 .53937 L
.94063 .53165 L
.94176 .52339 L
.94213 .51994 L
.94246 .51621 L
.9427 .51299 L
.94289 .50945 L
.94298 .50742 L
.94304 .50554 L
.94306 .50449 L
.94308 .50354 L
.9431 .50244 L
.94311 .50141 L
.94311 .49957 L
.9431 .49787 L
.94307 .496 L
.94305 .49506 L
.94302 .49403 L
.94296 .49214 L
.94288 .49038 L
.94266 .48642 L
Mistroke
.94239 .48292 L
.94204 .47921 L
.94119 .47213 L
.9402 .46576 L
.93698 .45035 L
.93292 .4361 L
.92217 .40873 L
.90956 .38494 L
.87655 .33888 L
.84147 .30005 L
.80511 .26161 L
.77282 .22368 L
.73987 .17944 L
.70559 .13314 L
.66632 .0886 L
.64327 .06783 L
.61527 .04761 L
.60163 .03961 L
.5864 .032 L
.57282 .02635 L
.55763 .02124 L
.54331 .01755 L
.52981 .01505 L
.52228 .01406 L
.51543 .01341 L
.51162 .01315 L
.50961 .01304 L
.50749 .01295 L
.50563 .01289 L
.50359 .01284 L
.50174 .01282 L
.5 .01281 L
Mfstroke
.5 .98719 m
.49811 .98718 L
.49639 .98716 L
.49441 .98711 L
.49253 .98705 L
.4892 .9869 L
.48559 .98667 L
.48161 .98634 L
.4774 .98591 L
.46988 .9849 L
.46215 .98358 L
.45496 .98206 L
.43879 .97767 L
.42268 .97189 L
.40834 .96552 L
.37777 .94785 L
.35337 .92939 L
.3292 .9069 L
.28867 .85945 L
.2557 .81441 L
.22262 .77062 L
.18899 .73199 L
.15404 .69521 L
.11645 .65251 L
.09917 .62888 L
.08485 .60522 L
.07336 .58106 L
.06813 .56708 L
.06411 .55387 L
.06074 .53937 L
.05937 .53165 L
.05824 .52339 L
.05787 .51994 L
.05754 .51621 L
.0573 .51299 L
.05711 .50945 L
.05702 .50742 L
.05696 .50554 L
.05694 .50449 L
.05692 .50354 L
.0569 .50244 L
.05689 .50141 L
.05689 .49957 L
.0569 .49787 L
.05693 .496 L
.05695 .49506 L
.05698 .49403 L
.05704 .49214 L
.05712 .49038 L
.05734 .48642 L
Mistroke
.05761 .48292 L
.05796 .47921 L
.05881 .47213 L
.0598 .46576 L
.06302 .45035 L
.06708 .4361 L
.07783 .40873 L
.09044 .38494 L
.12345 .33888 L
.15853 .30005 L
.19489 .26161 L
.22718 .22368 L
.26013 .17944 L
.29441 .13314 L
.33368 .0886 L
.35673 .06783 L
.38473 .04761 L
.39837 .03961 L
.4136 .032 L
.42718 .02635 L
.44237 .02124 L
.45669 .01755 L
.47019 .01505 L
.47772 .01406 L
.48457 .01341 L
.48838 .01315 L
.49039 .01304 L
.49251 .01295 L
.49437 .01289 L
.49641 .01284 L
.49826 .01282 L
.5 .01281 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0362812 0.97619 0.489796 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.416667 0.5 0.416667 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.29167 -0.0125 -12 -9 ]
[.29167 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70833 -0.0125 -9 -9 ]
[.70833 -0.0125 9 0 ]
[.91667 -0.0125 -3 -9 ]
[.91667 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .29167 -24 -4.5 ]
[-0.0125 .29167 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .70833 -18 -4.5 ]
[-0.0125 .70833 0 4.5 ]
[-0.0125 .91667 -6 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -70.125 -6 ]
[-0.01875 .5 -24 6 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-1)] .08333 -0.0125 0 1 Mshowa
.29167 0 m
.29167 .00625 L
s
[(-0.5)] .29167 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70833 0 m
.70833 .00625 L
s
[(0.5)] .70833 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(1)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.125 0 m
.125 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.875 0 m
.875 .00375 L
s
.04167 0 m
.04167 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(-1)] -0.0125 .08333 1 0 Mshowa
0 .29167 m
.00625 .29167 L
s
[(-0.5)] -0.0125 .29167 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .70833 m
.00625 .70833 L
s
[(0.5)] -0.0125 .70833 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(1)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .125 m
.00375 .125 L
s
0 .16667 m
.00375 .16667 L
s
0 .20833 m
.00375 .20833 L
s
0 .25 m
.00375 .25 L
s
0 .33333 m
.00375 .33333 L
s
0 .375 m
.00375 .375 L
s
0 .41667 m
.00375 .41667 L
s
0 .45833 m
.00375 .45833 L
s
0 .54167 m
.00375 .54167 L
s
0 .58333 m
.00375 .58333 L
s
0 .625 m
.00375 .625 L
s
0 .66667 m
.00375 .66667 L
s
0 .75 m
.00375 .75 L
s
0 .79167 m
.00375 .79167 L
s
0 .83333 m
.00375 .83333 L
s
0 .875 m
.00375 .875 L
s
0 .04167 m
.00375 .04167 L
s
0 .95833 m
.00375 .95833 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -131.125 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
93.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
105.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.29167 .99375 m
.29167 1 L
s
.5 .99375 m
.5 1 L
s
.70833 .99375 m
.70833 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.125 .99625 m
.125 1 L
s
.16667 .99625 m
.16667 1 L
s
.20833 .99625 m
.20833 1 L
s
.25 .99625 m
.25 1 L
s
.33333 .99625 m
.33333 1 L
s
.375 .99625 m
.375 1 L
s
.41667 .99625 m
.41667 1 L
s
.45833 .99625 m
.45833 1 L
s
.54167 .99625 m
.54167 1 L
s
.58333 .99625 m
.58333 1 L
s
.625 .99625 m
.625 1 L
s
.66667 .99625 m
.66667 1 L
s
.75 .99625 m
.75 1 L
s
.79167 .99625 m
.79167 1 L
s
.83333 .99625 m
.83333 1 L
s
.875 .99625 m
.875 1 L
s
.04167 .99625 m
.04167 1 L
s
.95833 .99625 m
.95833 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .29167 m
1 .29167 L
s
.99375 .5 m
1 .5 L
s
.99375 .70833 m
1 .70833 L
s
.99375 .91667 m
1 .91667 L
s
.125 Mabswid
.99625 .125 m
1 .125 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .20833 m
1 .20833 L
s
.99625 .25 m
1 .25 L
s
.99625 .33333 m
1 .33333 L
s
.99625 .375 m
1 .375 L
s
.99625 .41667 m
1 .41667 L
s
.99625 .45833 m
1 .45833 L
s
.99625 .54167 m
1 .54167 L
s
.99625 .58333 m
1 .58333 L
s
.99625 .625 m
1 .625 L
s
.99625 .66667 m
1 .66667 L
s
.99625 .75 m
1 .75 L
s
.99625 .79167 m
1 .79167 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .875 m
1 .875 L
s
.99625 .04167 m
1 .04167 L
s
.99625 .95833 m
1 .95833 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ .03 .03 ] 0 setdash
.5 .91667 m
.50323 .91665 L
.50617 .91662 L
.50956 .91656 L
.51277 .91647 L
.51847 .91626 L
.52466 .91594 L
.53147 .91548 L
.53867 .91487 L
.55157 .91346 L
.56483 .91159 L
.57719 .90945 L
.60506 .9032 L
.63298 .89488 L
.65795 .88557 L
.71167 .8589 L
.75485 .82964 L
.7974 .79183 L
.83267 .75089 L
.86409 .70261 L
.87699 .67745 L
.88899 .64933 L
.89767 .62437 L
.90536 .5964 L
.90831 .58304 L
.91098 .56862 L
.91287 .55609 L
.9145 .5424 L
.91525 .53435 L
.9158 .5269 L
.9162 .51976 L
.91635 .51616 L
.91649 .51218 L
.91658 .50861 L
.91663 .50533 L
.91666 .50173 L
.91667 .49992 L
.91666 .49794 L
.91663 .49459 L
.91657 .49101 L
.91648 .48764 L
.91638 .48457 L
.9161 .47823 L
.91567 .47126 L
.91446 .4572 L
.91292 .44423 L
.9111 .43213 L
.90572 .40511 L
.89796 .37654 L
.88882 .35024 L
Mistroke
.87689 .32233 L
.85009 .27406 L
.81783 .23056 L
.7776 .18928 L
.731 .15323 L
.68292 .12563 L
.65838 .11461 L
.63177 .10472 L
.60629 .09712 L
.5827 .09162 L
.55695 .08724 L
.54269 .08553 L
.53612 .0849 L
.52914 .08435 L
.52318 .08398 L
.52001 .08381 L
.5166 .08366 L
.51347 .08355 L
.51061 .08347 L
.50787 .08341 L
.50499 .08336 L
.50184 .08334 L
.49849 .08334 L
.49532 .08336 L
.49244 .0834 L
.48906 .08348 L
.48539 .08359 L
.47874 .08388 L
.47225 .08426 L
.46529 .08478 L
.45275 .08602 L
.43789 .08799 L
.42441 .09025 L
.39541 .09667 L
.3684 .10466 L
.31782 .12527 L
.27375 .15011 L
.23254 .18051 L
.19173 .21968 L
.15859 .26114 L
.12907 .31021 L
.10731 .3607 L
.09893 .38708 L
.09499 .40215 L
.09178 .41651 L
.08929 .42981 L
.08707 .44431 L
.0855 .45755 L
.08443 .46981 L
.08399 .47667 L
Mistroke
.08368 .4831 L
.08354 .48678 L
.08345 .49015 L
.08341 .49201 L
.08338 .49404 L
.08335 .49596 L
.08334 .49774 L
.08333 .4996 L
.08334 .50161 L
.08335 .50351 L
.08337 .50526 L
.08342 .50858 L
.08351 .51208 L
.08363 .51584 L
.08378 .51936 L
.08423 .52733 L
.08476 .53447 L
.08536 .54107 L
.08711 .55594 L
.08909 .569 L
.09164 .58279 L
.09715 .60641 L
.10481 .63205 L
.12485 .68131 L
.15328 .73107 L
.18679 .77479 L
.22796 .8156 L
.27128 .84828 L
.31507 .87338 L
.34145 .88532 L
.36703 .89488 L
.39079 .9021 L
.41635 .90818 L
.4369 .91186 L
.44865 .91349 L
.45967 .91471 L
.46981 .91557 L
.47909 .91614 L
.48422 .91637 L
.48693 .91646 L
.48982 .91654 L
.49259 .9166 L
.4951 .91664 L
.49763 .91666 L
.5 .91667 L
Mfstroke
[ ] 0 setdash
.5 .99463 m
.50192 .99462 L
.50366 .99459 L
.50568 .99452 L
.50758 .99444 L
.51096 .99422 L
.51463 .99391 L
.51866 .99345 L
.52292 .99284 L
.53053 .99145 L
.53832 .98961 L
.54555 .98751 L
.5617 .98148 L
.57761 .97362 L
.59157 .96509 L
.62065 .94206 L
.66483 .89268 L
.69958 .84583 L
.71794 .82289 L
.73518 .80461 L
.7743 .77366 L
.82068 .74483 L
.86646 .71222 L
.88777 .6917 L
.89745 .68017 L
.9067 .66701 L
.91423 .65392 L
.92 .64146 L
.92467 .62849 L
.92803 .61588 L
.92936 .60929 L
.9305 .60196 L
.93094 .59825 L
.93133 .59424 L
.93161 .59044 L
.93171 .58876 L
.93179 .58695 L
.93186 .58524 L
.9319 .58369 L
.93193 .58212 L
.93194 .58065 L
.93195 .57892 L
.93193 .57733 L
.9319 .57559 L
.93185 .57374 L
.93179 .57209 L
.93171 .57031 L
.93152 .56711 L
.93123 .5633 L
.93089 .55982 L
Mistroke
.93004 .55281 L
.92887 .54537 L
.92615 .53211 L
.91765 .50284 L
.89572 .44805 L
.88503 .42215 L
.87653 .39867 L
.86937 .37399 L
.86412 .35023 L
.85971 .32516 L
.855 .29644 L
.84983 .26968 L
.84208 .2404 L
.83654 .2247 L
.83041 .21058 L
.82311 .19679 L
.81524 .18452 L
.79726 .16334 L
.78623 .15361 L
.77327 .14448 L
.76077 .13756 L
.74628 .13144 L
.73869 .12894 L
.73041 .1267 L
.72303 .12511 L
.71512 .1238 L
.71123 .12329 L
.70693 .12283 L
.70301 .12251 L
.69933 .12228 L
.69709 .12218 L
.69599 .12214 L
.69497 .1221 L
.69307 .12206 L
.69206 .12204 L
.69099 .12203 L
.68993 .12202 L
.68879 .12202 L
.68772 .12203 L
.68673 .12204 L
.68563 .12205 L
.68443 .12208 L
.68318 .12211 L
.68201 .12215 L
.67791 .12233 L
.67404 .12257 L
.66681 .1232 L
.65904 .12412 L
.65067 .12538 L
.63625 .12814 L
Mistroke
.62074 .13185 L
.59082 .14061 L
.56309 .14944 L
.55164 .15287 L
.53957 .15608 L
.52879 .15843 L
.52363 .15934 L
.51899 .16002 L
.51423 .16058 L
.50976 .16096 L
.50732 .16111 L
.50507 .16121 L
.50389 .16125 L
.5026 .16128 L
.50126 .16129 L
.5 .1613 L
Mfstroke
.5 .99463 m
.49808 .99462 L
.49634 .99459 L
.49432 .99452 L
.49242 .99444 L
.48904 .99422 L
.48537 .99391 L
.48134 .99345 L
.47708 .99284 L
.46947 .99145 L
.46168 .98961 L
.45445 .98751 L
.4383 .98148 L
.42239 .97362 L
.40843 .96509 L
.37935 .94206 L
.33517 .89268 L
.30042 .84583 L
.28206 .82289 L
.26482 .80461 L
.2257 .77366 L
.17932 .74483 L
.13354 .71222 L
.11223 .6917 L
.10255 .68017 L
.0933 .66701 L
.08577 .65392 L
.08 .64146 L
.07533 .62849 L
.07197 .61588 L
.07064 .60929 L
.0695 .60196 L
.06906 .59825 L
.06867 .59424 L
.06839 .59044 L
.06829 .58876 L
.06821 .58695 L
.06814 .58524 L
.0681 .58369 L
.06807 .58212 L
.06806 .58065 L
.06805 .57892 L
.06807 .57733 L
.0681 .57559 L
.06815 .57374 L
.06821 .57209 L
.06829 .57031 L
.06848 .56711 L
.06877 .5633 L
.06911 .55982 L
Mistroke
.06996 .55281 L
.07113 .54537 L
.07385 .53211 L
.08235 .50284 L
.10428 .44805 L
.11497 .42215 L
.12347 .39867 L
.13063 .37399 L
.13588 .35023 L
.14029 .32516 L
.145 .29644 L
.15017 .26968 L
.15792 .2404 L
.16346 .2247 L
.16959 .21058 L
.17689 .19679 L
.18476 .18452 L
.20274 .16334 L
.21377 .15361 L
.22673 .14448 L
.23923 .13756 L
.25372 .13144 L
.26131 .12894 L
.26959 .1267 L
.27697 .12511 L
.28488 .1238 L
.28877 .12329 L
.29307 .12283 L
.29699 .12251 L
.30067 .12228 L
.30291 .12218 L
.30401 .12214 L
.30503 .1221 L
.30693 .12206 L
.30794 .12204 L
.30901 .12203 L
.31007 .12202 L
.31121 .12202 L
.31228 .12203 L
.31327 .12204 L
.31437 .12205 L
.31557 .12208 L
.31682 .12211 L
.31799 .12215 L
.32209 .12233 L
.32596 .12257 L
.33319 .1232 L
.34096 .12412 L
.34933 .12538 L
.36375 .12814 L
Mistroke
.37926 .13185 L
.40918 .14061 L
.43691 .14944 L
.44836 .15287 L
.46043 .15608 L
.47121 .15843 L
.47637 .15934 L
.48101 .16002 L
.48577 .16058 L
.49024 .16096 L
.49268 .16111 L
.49493 .16121 L
.49611 .16125 L
.4974 .16128 L
.49874 .16129 L
.5 .1613 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.535147 0.477324 0.988662 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.416667 0.5 0.416667 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.29167 -0.0125 -12 -9 ]
[.29167 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70833 -0.0125 -9 -9 ]
[.70833 -0.0125 9 0 ]
[.91667 -0.0125 -3 -9 ]
[.91667 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .29167 -24 -4.5 ]
[-0.0125 .29167 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .70833 -18 -4.5 ]
[-0.0125 .70833 0 4.5 ]
[-0.0125 .91667 -6 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -70.125 -6 ]
[-0.01875 .5 -24 6 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-1)] .08333 -0.0125 0 1 Mshowa
.29167 0 m
.29167 .00625 L
s
[(-0.5)] .29167 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70833 0 m
.70833 .00625 L
s
[(0.5)] .70833 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(1)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.125 0 m
.125 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.875 0 m
.875 .00375 L
s
.04167 0 m
.04167 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(-1)] -0.0125 .08333 1 0 Mshowa
0 .29167 m
.00625 .29167 L
s
[(-0.5)] -0.0125 .29167 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .70833 m
.00625 .70833 L
s
[(0.5)] -0.0125 .70833 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(1)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .125 m
.00375 .125 L
s
0 .16667 m
.00375 .16667 L
s
0 .20833 m
.00375 .20833 L
s
0 .25 m
.00375 .25 L
s
0 .33333 m
.00375 .33333 L
s
0 .375 m
.00375 .375 L
s
0 .41667 m
.00375 .41667 L
s
0 .45833 m
.00375 .45833 L
s
0 .54167 m
.00375 .54167 L
s
0 .58333 m
.00375 .58333 L
s
0 .625 m
.00375 .625 L
s
0 .66667 m
.00375 .66667 L
s
0 .75 m
.00375 .75 L
s
0 .79167 m
.00375 .79167 L
s
0 .83333 m
.00375 .83333 L
s
0 .875 m
.00375 .875 L
s
0 .04167 m
.00375 .04167 L
s
0 .95833 m
.00375 .95833 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -131.125 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
93.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
105.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.29167 .99375 m
.29167 1 L
s
.5 .99375 m
.5 1 L
s
.70833 .99375 m
.70833 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.125 .99625 m
.125 1 L
s
.16667 .99625 m
.16667 1 L
s
.20833 .99625 m
.20833 1 L
s
.25 .99625 m
.25 1 L
s
.33333 .99625 m
.33333 1 L
s
.375 .99625 m
.375 1 L
s
.41667 .99625 m
.41667 1 L
s
.45833 .99625 m
.45833 1 L
s
.54167 .99625 m
.54167 1 L
s
.58333 .99625 m
.58333 1 L
s
.625 .99625 m
.625 1 L
s
.66667 .99625 m
.66667 1 L
s
.75 .99625 m
.75 1 L
s
.79167 .99625 m
.79167 1 L
s
.83333 .99625 m
.83333 1 L
s
.875 .99625 m
.875 1 L
s
.04167 .99625 m
.04167 1 L
s
.95833 .99625 m
.95833 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .29167 m
1 .29167 L
s
.99375 .5 m
1 .5 L
s
.99375 .70833 m
1 .70833 L
s
.99375 .91667 m
1 .91667 L
s
.125 Mabswid
.99625 .125 m
1 .125 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .20833 m
1 .20833 L
s
.99625 .25 m
1 .25 L
s
.99625 .33333 m
1 .33333 L
s
.99625 .375 m
1 .375 L
s
.99625 .41667 m
1 .41667 L
s
.99625 .45833 m
1 .45833 L
s
.99625 .54167 m
1 .54167 L
s
.99625 .58333 m
1 .58333 L
s
.99625 .625 m
1 .625 L
s
.99625 .66667 m
1 .66667 L
s
.99625 .75 m
1 .75 L
s
.99625 .79167 m
1 .79167 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .875 m
1 .875 L
s
.99625 .04167 m
1 .04167 L
s
.99625 .95833 m
1 .95833 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ .03 .03 ] 0 setdash
.5 .91667 m
.50323 .91665 L
.50617 .91662 L
.50956 .91656 L
.51277 .91647 L
.51847 .91626 L
.52466 .91594 L
.53147 .91548 L
.53867 .91487 L
.55157 .91346 L
.56483 .91159 L
.57719 .90945 L
.60506 .9032 L
.63298 .89488 L
.65795 .88557 L
.71167 .8589 L
.75485 .82964 L
.7974 .79183 L
.83267 .75089 L
.86409 .70261 L
.87699 .67745 L
.88899 .64933 L
.89767 .62437 L
.90536 .5964 L
.90831 .58304 L
.91098 .56862 L
.91287 .55609 L
.9145 .5424 L
.91525 .53435 L
.9158 .5269 L
.9162 .51976 L
.91635 .51616 L
.91649 .51218 L
.91658 .50861 L
.91663 .50533 L
.91666 .50173 L
.91667 .49992 L
.91666 .49794 L
.91663 .49459 L
.91657 .49101 L
.91648 .48764 L
.91638 .48457 L
.9161 .47823 L
.91567 .47126 L
.91446 .4572 L
.91292 .44423 L
.9111 .43213 L
.90572 .40511 L
.89796 .37654 L
.88882 .35024 L
Mistroke
.87689 .32233 L
.85009 .27406 L
.81783 .23056 L
.7776 .18928 L
.731 .15323 L
.68292 .12563 L
.65838 .11461 L
.63177 .10472 L
.60629 .09712 L
.5827 .09162 L
.55695 .08724 L
.54269 .08553 L
.53612 .0849 L
.52914 .08435 L
.52318 .08398 L
.52001 .08381 L
.5166 .08366 L
.51347 .08355 L
.51061 .08347 L
.50787 .08341 L
.50499 .08336 L
.50184 .08334 L
.49849 .08334 L
.49532 .08336 L
.49244 .0834 L
.48906 .08348 L
.48539 .08359 L
.47874 .08388 L
.47225 .08426 L
.46529 .08478 L
.45275 .08602 L
.43789 .08799 L
.42441 .09025 L
.39541 .09667 L
.3684 .10466 L
.31782 .12527 L
.27375 .15011 L
.23254 .18051 L
.19173 .21968 L
.15859 .26114 L
.12907 .31021 L
.10731 .3607 L
.09893 .38708 L
.09499 .40215 L
.09178 .41651 L
.08929 .42981 L
.08707 .44431 L
.0855 .45755 L
.08443 .46981 L
.08399 .47667 L
Mistroke
.08368 .4831 L
.08354 .48678 L
.08345 .49015 L
.08341 .49201 L
.08338 .49404 L
.08335 .49596 L
.08334 .49774 L
.08333 .4996 L
.08334 .50161 L
.08335 .50351 L
.08337 .50526 L
.08342 .50858 L
.08351 .51208 L
.08363 .51584 L
.08378 .51936 L
.08423 .52733 L
.08476 .53447 L
.08536 .54107 L
.08711 .55594 L
.08909 .569 L
.09164 .58279 L
.09715 .60641 L
.10481 .63205 L
.12485 .68131 L
.15328 .73107 L
.18679 .77479 L
.22796 .8156 L
.27128 .84828 L
.31507 .87338 L
.34145 .88532 L
.36703 .89488 L
.39079 .9021 L
.41635 .90818 L
.4369 .91186 L
.44865 .91349 L
.45967 .91471 L
.46981 .91557 L
.47909 .91614 L
.48422 .91637 L
.48693 .91646 L
.48982 .91654 L
.49259 .9166 L
.4951 .91664 L
.49763 .91666 L
.5 .91667 L
Mfstroke
[ ] 0 setdash
.5 .96923 m
.50182 .96923 L
.50348 .96921 L
.50539 .96919 L
.50719 .96916 L
.5104 .96908 L
.51389 .96896 L
.51773 .96878 L
.52179 .96856 L
.52907 .96803 L
.53658 .96732 L
.54359 .96652 L
.55948 .96416 L
.57554 .96102 L
.59008 .95751 L
.62211 .9474 L
.64897 .93626 L
.67704 .92177 L
.72755 .88704 L
.76969 .84709 L
.80695 .79947 L
.83551 .75027 L
.85658 .7012 L
.86504 .676 L
.87276 .64822 L
.87874 .62146 L
.88303 .59708 L
.8864 .57185 L
.8878 .55799 L
.88884 .54486 L
.88958 .53242 L
.88986 .52614 L
.8901 .51921 L
.89025 .51332 L
.89031 .51001 L
.89033 .50843 L
.89035 .50697 L
.89036 .50557 L
.89037 .5043 L
.89038 .50288 L
.89038 .50137 L
.89038 .49992 L
.89038 .49834 L
.89038 .49686 L
.89037 .49548 L
.89036 .49387 L
.89034 .49234 L
.8903 .48946 L
.89024 .48637 L
.89016 .483 L
Mistroke
.88998 .47694 L
.88975 .47132 L
.88906 .45843 L
.88803 .4447 L
.88675 .43139 L
.88504 .417 L
.88105 .39089 L
.87589 .36501 L
.86905 .3377 L
.85275 .28867 L
.82917 .23746 L
.7998 .19021 L
.76107 .14373 L
.71656 .10433 L
.66766 .07304 L
.64041 .05991 L
.61025 .04847 L
.59643 .04424 L
.58134 .0403 L
.56816 .03744 L
.55363 .03488 L
.54015 .03307 L
.52758 .03185 L
.52059 .03137 L
.51425 .03106 L
.51073 .03093 L
.50887 .03088 L
.50692 .03084 L
.5052 .03081 L
.50332 .03078 L
.5016 .03077 L
.5 .03077 L
Mfstroke
.5 .96923 m
.49818 .96923 L
.49652 .96921 L
.49461 .96919 L
.49281 .96916 L
.4896 .96908 L
.48611 .96896 L
.48227 .96878 L
.47821 .96856 L
.47093 .96803 L
.46342 .96732 L
.45641 .96652 L
.44052 .96416 L
.42446 .96102 L
.40992 .95751 L
.37789 .9474 L
.35103 .93626 L
.32296 .92177 L
.27245 .88704 L
.23031 .84709 L
.19305 .79947 L
.16449 .75027 L
.14342 .7012 L
.13496 .676 L
.12724 .64822 L
.12126 .62146 L
.11697 .59708 L
.1136 .57185 L
.1122 .55799 L
.11116 .54486 L
.11042 .53242 L
.11014 .52614 L
.1099 .51921 L
.10975 .51332 L
.10969 .51001 L
.10967 .50843 L
.10965 .50697 L
.10964 .50557 L
.10963 .5043 L
.10962 .50288 L
.10962 .50137 L
.10962 .49992 L
.10962 .49834 L
.10962 .49686 L
.10963 .49548 L
.10964 .49387 L
.10966 .49234 L
.1097 .48946 L
.10976 .48637 L
.10984 .483 L
Mistroke
.11002 .47694 L
.11025 .47132 L
.11094 .45843 L
.11197 .4447 L
.11325 .43139 L
.11496 .417 L
.11895 .39089 L
.12411 .36501 L
.13095 .3377 L
.14725 .28867 L
.17083 .23746 L
.2002 .19021 L
.23893 .14373 L
.28344 .10433 L
.33234 .07304 L
.35959 .05991 L
.38975 .04847 L
.40357 .04424 L
.41866 .0403 L
.43184 .03744 L
.44637 .03488 L
.45985 .03307 L
.47242 .03185 L
.47941 .03137 L
.48575 .03106 L
.48927 .03093 L
.49113 .03088 L
.49308 .03084 L
.4948 .03081 L
.49668 .03078 L
.4984 .03077 L
.5 .03077 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.535147 0.97619 0.988662 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.416667 0.5 0.416667 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.29167 -0.0125 -12 -9 ]
[.29167 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70833 -0.0125 -9 -9 ]
[.70833 -0.0125 9 0 ]
[.91667 -0.0125 -3 -9 ]
[.91667 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .29167 -24 -4.5 ]
[-0.0125 .29167 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .70833 -18 -4.5 ]
[-0.0125 .70833 0 4.5 ]
[-0.0125 .91667 -6 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -70.125 -6 ]
[-0.01875 .5 -24 6 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-1)] .08333 -0.0125 0 1 Mshowa
.29167 0 m
.29167 .00625 L
s
[(-0.5)] .29167 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70833 0 m
.70833 .00625 L
s
[(0.5)] .70833 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(1)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.125 0 m
.125 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.875 0 m
.875 .00375 L
s
.04167 0 m
.04167 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(-1)] -0.0125 .08333 1 0 Mshowa
0 .29167 m
.00625 .29167 L
s
[(-0.5)] -0.0125 .29167 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .70833 m
.00625 .70833 L
s
[(0.5)] -0.0125 .70833 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(1)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .125 m
.00375 .125 L
s
0 .16667 m
.00375 .16667 L
s
0 .20833 m
.00375 .20833 L
s
0 .25 m
.00375 .25 L
s
0 .33333 m
.00375 .33333 L
s
0 .375 m
.00375 .375 L
s
0 .41667 m
.00375 .41667 L
s
0 .45833 m
.00375 .45833 L
s
0 .54167 m
.00375 .54167 L
s
0 .58333 m
.00375 .58333 L
s
0 .625 m
.00375 .625 L
s
0 .66667 m
.00375 .66667 L
s
0 .75 m
.00375 .75 L
s
0 .79167 m
.00375 .79167 L
s
0 .83333 m
.00375 .83333 L
s
0 .875 m
.00375 .875 L
s
0 .04167 m
.00375 .04167 L
s
0 .95833 m
.00375 .95833 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -131.125 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
93.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
105.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.29167 .99375 m
.29167 1 L
s
.5 .99375 m
.5 1 L
s
.70833 .99375 m
.70833 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.125 .99625 m
.125 1 L
s
.16667 .99625 m
.16667 1 L
s
.20833 .99625 m
.20833 1 L
s
.25 .99625 m
.25 1 L
s
.33333 .99625 m
.33333 1 L
s
.375 .99625 m
.375 1 L
s
.41667 .99625 m
.41667 1 L
s
.45833 .99625 m
.45833 1 L
s
.54167 .99625 m
.54167 1 L
s
.58333 .99625 m
.58333 1 L
s
.625 .99625 m
.625 1 L
s
.66667 .99625 m
.66667 1 L
s
.75 .99625 m
.75 1 L
s
.79167 .99625 m
.79167 1 L
s
.83333 .99625 m
.83333 1 L
s
.875 .99625 m
.875 1 L
s
.04167 .99625 m
.04167 1 L
s
.95833 .99625 m
.95833 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .29167 m
1 .29167 L
s
.99375 .5 m
1 .5 L
s
.99375 .70833 m
1 .70833 L
s
.99375 .91667 m
1 .91667 L
s
.125 Mabswid
.99625 .125 m
1 .125 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .20833 m
1 .20833 L
s
.99625 .25 m
1 .25 L
s
.99625 .33333 m
1 .33333 L
s
.99625 .375 m
1 .375 L
s
.99625 .41667 m
1 .41667 L
s
.99625 .45833 m
1 .45833 L
s
.99625 .54167 m
1 .54167 L
s
.99625 .58333 m
1 .58333 L
s
.99625 .625 m
1 .625 L
s
.99625 .66667 m
1 .66667 L
s
.99625 .75 m
1 .75 L
s
.99625 .79167 m
1 .79167 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .875 m
1 .875 L
s
.99625 .04167 m
1 .04167 L
s
.99625 .95833 m
1 .95833 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ .03 .03 ] 0 setdash
.5 .91667 m
.50323 .91665 L
.50617 .91662 L
.50956 .91656 L
.51277 .91647 L
.51847 .91626 L
.52466 .91594 L
.53147 .91548 L
.53867 .91487 L
.55157 .91346 L
.56483 .91159 L
.57719 .90945 L
.60506 .9032 L
.63298 .89488 L
.65795 .88557 L
.71167 .8589 L
.75485 .82964 L
.7974 .79183 L
.83267 .75089 L
.86409 .70261 L
.87699 .67745 L
.88899 .64933 L
.89767 .62437 L
.90536 .5964 L
.90831 .58304 L
.91098 .56862 L
.91287 .55609 L
.9145 .5424 L
.91525 .53435 L
.9158 .5269 L
.9162 .51976 L
.91635 .51616 L
.91649 .51218 L
.91658 .50861 L
.91663 .50533 L
.91666 .50173 L
.91667 .49992 L
.91666 .49794 L
.91663 .49459 L
.91657 .49101 L
.91648 .48764 L
.91638 .48457 L
.9161 .47823 L
.91567 .47126 L
.91446 .4572 L
.91292 .44423 L
.9111 .43213 L
.90572 .40511 L
.89796 .37654 L
.88882 .35024 L
Mistroke
.87689 .32233 L
.85009 .27406 L
.81783 .23056 L
.7776 .18928 L
.731 .15323 L
.68292 .12563 L
.65838 .11461 L
.63177 .10472 L
.60629 .09712 L
.5827 .09162 L
.55695 .08724 L
.54269 .08553 L
.53612 .0849 L
.52914 .08435 L
.52318 .08398 L
.52001 .08381 L
.5166 .08366 L
.51347 .08355 L
.51061 .08347 L
.50787 .08341 L
.50499 .08336 L
.50184 .08334 L
.49849 .08334 L
.49532 .08336 L
.49244 .0834 L
.48906 .08348 L
.48539 .08359 L
.47874 .08388 L
.47225 .08426 L
.46529 .08478 L
.45275 .08602 L
.43789 .08799 L
.42441 .09025 L
.39541 .09667 L
.3684 .10466 L
.31782 .12527 L
.27375 .15011 L
.23254 .18051 L
.19173 .21968 L
.15859 .26114 L
.12907 .31021 L
.10731 .3607 L
.09893 .38708 L
.09499 .40215 L
.09178 .41651 L
.08929 .42981 L
.08707 .44431 L
.0855 .45755 L
.08443 .46981 L
.08399 .47667 L
Mistroke
.08368 .4831 L
.08354 .48678 L
.08345 .49015 L
.08341 .49201 L
.08338 .49404 L
.08335 .49596 L
.08334 .49774 L
.08333 .4996 L
.08334 .50161 L
.08335 .50351 L
.08337 .50526 L
.08342 .50858 L
.08351 .51208 L
.08363 .51584 L
.08378 .51936 L
.08423 .52733 L
.08476 .53447 L
.08536 .54107 L
.08711 .55594 L
.08909 .569 L
.09164 .58279 L
.09715 .60641 L
.10481 .63205 L
.12485 .68131 L
.15328 .73107 L
.18679 .77479 L
.22796 .8156 L
.27128 .84828 L
.31507 .87338 L
.34145 .88532 L
.36703 .89488 L
.39079 .9021 L
.41635 .90818 L
.4369 .91186 L
.44865 .91349 L
.45967 .91471 L
.46981 .91557 L
.47909 .91614 L
.48422 .91637 L
.48693 .91646 L
.48982 .91654 L
.49259 .9166 L
.4951 .91664 L
.49763 .91666 L
.5 .91667 L
Mfstroke
[ ] 0 setdash
.5 .97886 m
.50186 .97886 L
.50355 .97884 L
.5055 .97881 L
.50734 .97876 L
.51062 .97865 L
.51417 .97849 L
.51808 .97825 L
.52223 .97794 L
.52965 .97723 L
.53728 .97627 L
.5444 .97518 L
.56048 .97201 L
.57665 .96779 L
.59118 .96311 L
.62277 .94982 L
.6487 .93547 L
.67515 .91727 L
.7209 .87573 L
.75743 .8313 L
.78951 .78245 L
.81591 .73565 L
.83903 .6913 L
.86244 .64412 L
.88391 .5973 L
.90245 .54973 L
.91115 .5219 L
.91761 .49566 L
.9202 .48236 L
.92248 .4677 L
.92332 .46093 L
.92407 .45371 L
.9246 .44736 L
.92503 .44065 L
.9252 .43729 L
.92527 .43551 L
.92533 .4336 L
.92539 .43184 L
.92542 .43025 L
.92545 .42864 L
.92547 .42712 L
.92549 .42535 L
.92549 .42347 L
.92549 .42186 L
.92547 .4201 L
.92544 .4182 L
.92542 .41714 L
.9254 .41616 L
.92529 .41248 L
.92514 .4091 L
Mistroke
.92498 .40596 L
.92447 .39887 L
.92388 .39261 L
.92311 .38596 L
.92078 .37109 L
.91736 .35516 L
.91324 .34033 L
.90869 .32692 L
.89772 .30155 L
.88261 .27529 L
.86555 .25232 L
.84458 .23005 L
.82248 .21139 L
.79649 .19401 L
.77006 .18017 L
.74481 .16984 L
.71975 .1619 L
.69202 .15537 L
.66614 .15108 L
.65176 .14933 L
.63874 .1481 L
.62605 .14717 L
.61439 .14653 L
.60176 .14604 L
.59476 .14584 L
.58846 .1457 L
.58246 .1456 L
.5792 .14556 L
.57617 .14552 L
.57082 .14548 L
.568 .14546 L
.56498 .14545 L
.56341 .14544 L
.56175 .14543 L
.55993 .14543 L
.55912 .14543 L
.55825 .14543 L
.55669 .14543 L
.55523 .14542 L
.55439 .14542 L
.5535 .14542 L
.55274 .14542 L
.55191 .14542 L
.55035 .14543 L
.54894 .14543 L
.54731 .14543 L
.54578 .14543 L
.54009 .14544 L
.5 .14553 L
Mfstroke
.5 .97886 m
.49814 .97886 L
.49645 .97884 L
.4945 .97881 L
.49266 .97876 L
.48938 .97865 L
.48583 .97849 L
.48192 .97825 L
.47777 .97794 L
.47035 .97723 L
.46272 .97627 L
.4556 .97518 L
.43952 .97201 L
.42335 .96779 L
.40882 .96311 L
.37723 .94982 L
.3513 .93547 L
.32485 .91727 L
.2791 .87573 L
.24257 .8313 L
.21049 .78245 L
.18409 .73565 L
.16097 .6913 L
.13756 .64412 L
.11609 .5973 L
.09755 .54973 L
.08885 .5219 L
.08239 .49566 L
.0798 .48236 L
.07752 .4677 L
.07668 .46093 L
.07593 .45371 L
.0754 .44736 L
.07497 .44065 L
.0748 .43729 L
.07473 .43551 L
.07467 .4336 L
.07461 .43184 L
.07458 .43025 L
.07455 .42864 L
.07453 .42712 L
.07451 .42535 L
.07451 .42347 L
.07451 .42186 L
.07453 .4201 L
.07456 .4182 L
.07458 .41714 L
.0746 .41616 L
.07471 .41248 L
.07486 .4091 L
Mistroke
.07502 .40596 L
.07553 .39887 L
.07612 .39261 L
.07689 .38596 L
.07922 .37109 L
.08264 .35516 L
.08676 .34033 L
.09131 .32692 L
.10228 .30155 L
.11739 .27529 L
.13445 .25232 L
.15542 .23005 L
.17752 .21139 L
.20351 .19401 L
.22994 .18017 L
.25519 .16984 L
.28025 .1619 L
.30798 .15537 L
.33386 .15108 L
.34824 .14933 L
.36126 .1481 L
.37395 .14717 L
.38561 .14653 L
.39824 .14604 L
.40524 .14584 L
.41154 .1457 L
.41754 .1456 L
.4208 .14556 L
.42383 .14552 L
.42918 .14548 L
.432 .14546 L
.43502 .14545 L
.43659 .14544 L
.43825 .14543 L
.44007 .14543 L
.44088 .14543 L
.44175 .14543 L
.44331 .14543 L
.44477 .14542 L
.44561 .14542 L
.4465 .14542 L
.44726 .14542 L
.44809 .14542 L
.44965 .14543 L
.45106 .14543 L
.45269 .14543 L
.45422 .14543 L
.45991 .14544 L
.5 .14553 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.03401 0.477324 1.48753 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.416667 0.5 0.416667 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.29167 -0.0125 -12 -9 ]
[.29167 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70833 -0.0125 -9 -9 ]
[.70833 -0.0125 9 0 ]
[.91667 -0.0125 -3 -9 ]
[.91667 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .29167 -24 -4.5 ]
[-0.0125 .29167 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .70833 -18 -4.5 ]
[-0.0125 .70833 0 4.5 ]
[-0.0125 .91667 -6 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -70.125 -6 ]
[-0.01875 .5 -24 6 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-1)] .08333 -0.0125 0 1 Mshowa
.29167 0 m
.29167 .00625 L
s
[(-0.5)] .29167 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70833 0 m
.70833 .00625 L
s
[(0.5)] .70833 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(1)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.125 0 m
.125 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.875 0 m
.875 .00375 L
s
.04167 0 m
.04167 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(-1)] -0.0125 .08333 1 0 Mshowa
0 .29167 m
.00625 .29167 L
s
[(-0.5)] -0.0125 .29167 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .70833 m
.00625 .70833 L
s
[(0.5)] -0.0125 .70833 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(1)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .125 m
.00375 .125 L
s
0 .16667 m
.00375 .16667 L
s
0 .20833 m
.00375 .20833 L
s
0 .25 m
.00375 .25 L
s
0 .33333 m
.00375 .33333 L
s
0 .375 m
.00375 .375 L
s
0 .41667 m
.00375 .41667 L
s
0 .45833 m
.00375 .45833 L
s
0 .54167 m
.00375 .54167 L
s
0 .58333 m
.00375 .58333 L
s
0 .625 m
.00375 .625 L
s
0 .66667 m
.00375 .66667 L
s
0 .75 m
.00375 .75 L
s
0 .79167 m
.00375 .79167 L
s
0 .83333 m
.00375 .83333 L
s
0 .875 m
.00375 .875 L
s
0 .04167 m
.00375 .04167 L
s
0 .95833 m
.00375 .95833 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -131.125 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
93.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
105.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.29167 .99375 m
.29167 1 L
s
.5 .99375 m
.5 1 L
s
.70833 .99375 m
.70833 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.125 .99625 m
.125 1 L
s
.16667 .99625 m
.16667 1 L
s
.20833 .99625 m
.20833 1 L
s
.25 .99625 m
.25 1 L
s
.33333 .99625 m
.33333 1 L
s
.375 .99625 m
.375 1 L
s
.41667 .99625 m
.41667 1 L
s
.45833 .99625 m
.45833 1 L
s
.54167 .99625 m
.54167 1 L
s
.58333 .99625 m
.58333 1 L
s
.625 .99625 m
.625 1 L
s
.66667 .99625 m
.66667 1 L
s
.75 .99625 m
.75 1 L
s
.79167 .99625 m
.79167 1 L
s
.83333 .99625 m
.83333 1 L
s
.875 .99625 m
.875 1 L
s
.04167 .99625 m
.04167 1 L
s
.95833 .99625 m
.95833 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .29167 m
1 .29167 L
s
.99375 .5 m
1 .5 L
s
.99375 .70833 m
1 .70833 L
s
.99375 .91667 m
1 .91667 L
s
.125 Mabswid
.99625 .125 m
1 .125 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .20833 m
1 .20833 L
s
.99625 .25 m
1 .25 L
s
.99625 .33333 m
1 .33333 L
s
.99625 .375 m
1 .375 L
s
.99625 .41667 m
1 .41667 L
s
.99625 .45833 m
1 .45833 L
s
.99625 .54167 m
1 .54167 L
s
.99625 .58333 m
1 .58333 L
s
.99625 .625 m
1 .625 L
s
.99625 .66667 m
1 .66667 L
s
.99625 .75 m
1 .75 L
s
.99625 .79167 m
1 .79167 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .875 m
1 .875 L
s
.99625 .04167 m
1 .04167 L
s
.99625 .95833 m
1 .95833 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ .03 .03 ] 0 setdash
.5 .91667 m
.50323 .91665 L
.50617 .91662 L
.50956 .91656 L
.51277 .91647 L
.51847 .91626 L
.52466 .91594 L
.53147 .91548 L
.53867 .91487 L
.55157 .91346 L
.56483 .91159 L
.57719 .90945 L
.60506 .9032 L
.63298 .89488 L
.65795 .88557 L
.71167 .8589 L
.75485 .82964 L
.7974 .79183 L
.83267 .75089 L
.86409 .70261 L
.87699 .67745 L
.88899 .64933 L
.89767 .62437 L
.90536 .5964 L
.90831 .58304 L
.91098 .56862 L
.91287 .55609 L
.9145 .5424 L
.91525 .53435 L
.9158 .5269 L
.9162 .51976 L
.91635 .51616 L
.91649 .51218 L
.91658 .50861 L
.91663 .50533 L
.91666 .50173 L
.91667 .49992 L
.91666 .49794 L
.91663 .49459 L
.91657 .49101 L
.91648 .48764 L
.91638 .48457 L
.9161 .47823 L
.91567 .47126 L
.91446 .4572 L
.91292 .44423 L
.9111 .43213 L
.90572 .40511 L
.89796 .37654 L
.88882 .35024 L
Mistroke
.87689 .32233 L
.85009 .27406 L
.81783 .23056 L
.7776 .18928 L
.731 .15323 L
.68292 .12563 L
.65838 .11461 L
.63177 .10472 L
.60629 .09712 L
.5827 .09162 L
.55695 .08724 L
.54269 .08553 L
.53612 .0849 L
.52914 .08435 L
.52318 .08398 L
.52001 .08381 L
.5166 .08366 L
.51347 .08355 L
.51061 .08347 L
.50787 .08341 L
.50499 .08336 L
.50184 .08334 L
.49849 .08334 L
.49532 .08336 L
.49244 .0834 L
.48906 .08348 L
.48539 .08359 L
.47874 .08388 L
.47225 .08426 L
.46529 .08478 L
.45275 .08602 L
.43789 .08799 L
.42441 .09025 L
.39541 .09667 L
.3684 .10466 L
.31782 .12527 L
.27375 .15011 L
.23254 .18051 L
.19173 .21968 L
.15859 .26114 L
.12907 .31021 L
.10731 .3607 L
.09893 .38708 L
.09499 .40215 L
.09178 .41651 L
.08929 .42981 L
.08707 .44431 L
.0855 .45755 L
.08443 .46981 L
.08399 .47667 L
Mistroke
.08368 .4831 L
.08354 .48678 L
.08345 .49015 L
.08341 .49201 L
.08338 .49404 L
.08335 .49596 L
.08334 .49774 L
.08333 .4996 L
.08334 .50161 L
.08335 .50351 L
.08337 .50526 L
.08342 .50858 L
.08351 .51208 L
.08363 .51584 L
.08378 .51936 L
.08423 .52733 L
.08476 .53447 L
.08536 .54107 L
.08711 .55594 L
.08909 .569 L
.09164 .58279 L
.09715 .60641 L
.10481 .63205 L
.12485 .68131 L
.15328 .73107 L
.18679 .77479 L
.22796 .8156 L
.27128 .84828 L
.31507 .87338 L
.34145 .88532 L
.36703 .89488 L
.39079 .9021 L
.41635 .90818 L
.4369 .91186 L
.44865 .91349 L
.45967 .91471 L
.46981 .91557 L
.47909 .91614 L
.48422 .91637 L
.48693 .91646 L
.48982 .91654 L
.49259 .9166 L
.4951 .91664 L
.49763 .91666 L
.5 .91667 L
Mfstroke
[ ] 0 setdash
.5 .94017 m
.50171 .94017 L
.50326 .94016 L
.50505 .94015 L
.50675 .94012 L
.50976 .94007 L
.51303 .93998 L
.51663 .93986 L
.52045 .9397 L
.52729 .93933 L
.53435 .93883 L
.54095 .93827 L
.55595 .9366 L
.57118 .93438 L
.58503 .93188 L
.6159 .92464 L
.64224 .91656 L
.67037 .90587 L
.72309 .87945 L
.77008 .84758 L
.81507 .80739 L
.85283 .76318 L
.88336 .71631 L
.8965 .69116 L
.90902 .66264 L
.91915 .63442 L
.92668 .60814 L
.93276 .58047 L
.93533 .56509 L
.93727 .55045 L
.93866 .5365 L
.93919 .52944 L
.93964 .52164 L
.93992 .51501 L
.94003 .51128 L
.94007 .50951 L
.9401 .50786 L
.94013 .50628 L
.94015 .50484 L
.94016 .50325 L
.94017 .50155 L
.94017 .49991 L
.94017 .49813 L
.94016 .49645 L
.94015 .49491 L
.94012 .49309 L
.94009 .49136 L
.94001 .48812 L
.93991 .48464 L
.93976 .48084 L
Mistroke
.93941 .47401 L
.93899 .46769 L
.93768 .45324 L
.93577 .4379 L
.93341 .42312 L
.93029 .40725 L
.92317 .37883 L
.91427 .35122 L
.90293 .3228 L
.8776 .27379 L
.84412 .22553 L
.80611 .18369 L
.76018 .14495 L
.71134 .11388 L
.66089 .09028 L
.63379 .08065 L
.60441 .07239 L
.59111 .06936 L
.5767 .06656 L
.56417 .06453 L
.55042 .06272 L
.53771 .06144 L
.52588 .06059 L
.51932 .06025 L
.51337 .06003 L
.51006 .05994 L
.50833 .0599 L
.50649 .05987 L
.50488 .05985 L
.50311 .05984 L
.5015 .05983 L
.5 .05983 L
Mfstroke
.5 .94017 m
.49829 .94017 L
.49674 .94016 L
.49495 .94015 L
.49325 .94012 L
.49024 .94007 L
.48697 .93998 L
.48337 .93986 L
.47955 .9397 L
.47271 .93933 L
.46565 .93883 L
.45905 .93827 L
.44405 .9366 L
.42882 .93438 L
.41497 .93188 L
.3841 .92464 L
.35776 .91656 L
.32963 .90587 L
.27691 .87945 L
.22992 .84758 L
.18493 .80739 L
.14717 .76318 L
.11664 .71631 L
.1035 .69116 L
.09098 .66264 L
.08085 .63442 L
.07332 .60814 L
.06724 .58047 L
.06467 .56509 L
.06273 .55045 L
.06134 .5365 L
.06081 .52944 L
.06036 .52164 L
.06008 .51501 L
.05997 .51128 L
.05993 .50951 L
.0599 .50786 L
.05987 .50628 L
.05985 .50484 L
.05984 .50325 L
.05983 .50155 L
.05983 .49991 L
.05983 .49813 L
.05984 .49645 L
.05985 .49491 L
.05988 .49309 L
.05991 .49136 L
.05999 .48812 L
.06009 .48464 L
.06024 .48084 L
Mistroke
.06059 .47401 L
.06101 .46769 L
.06232 .45324 L
.06423 .4379 L
.06659 .42312 L
.06971 .40725 L
.07683 .37883 L
.08573 .35122 L
.09707 .3228 L
.1224 .27379 L
.15588 .22553 L
.19389 .18369 L
.23982 .14495 L
.28866 .11388 L
.33911 .09028 L
.36621 .08065 L
.39559 .07239 L
.40889 .06936 L
.4233 .06656 L
.43583 .06453 L
.44958 .06272 L
.46229 .06144 L
.47412 .06059 L
.48068 .06025 L
.48663 .06003 L
.48994 .05994 L
.49167 .0599 L
.49351 .05987 L
.49512 .05985 L
.49689 .05984 L
.4985 .05983 L
.5 .05983 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 1.03401 0.97619 1.48753 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.416667 0.5 0.416667 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.29167 -0.0125 -12 -9 ]
[.29167 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70833 -0.0125 -9 -9 ]
[.70833 -0.0125 9 0 ]
[.91667 -0.0125 -3 -9 ]
[.91667 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .29167 -24 -4.5 ]
[-0.0125 .29167 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .70833 -18 -4.5 ]
[-0.0125 .70833 0 4.5 ]
[-0.0125 .91667 -6 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -70.125 -6 ]
[-0.01875 .5 -24 6 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-1)] .08333 -0.0125 0 1 Mshowa
.29167 0 m
.29167 .00625 L
s
[(-0.5)] .29167 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70833 0 m
.70833 .00625 L
s
[(0.5)] .70833 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(1)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.125 0 m
.125 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.875 0 m
.875 .00375 L
s
.04167 0 m
.04167 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(-1)] -0.0125 .08333 1 0 Mshowa
0 .29167 m
.00625 .29167 L
s
[(-0.5)] -0.0125 .29167 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .70833 m
.00625 .70833 L
s
[(0.5)] -0.0125 .70833 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(1)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .125 m
.00375 .125 L
s
0 .16667 m
.00375 .16667 L
s
0 .20833 m
.00375 .20833 L
s
0 .25 m
.00375 .25 L
s
0 .33333 m
.00375 .33333 L
s
0 .375 m
.00375 .375 L
s
0 .41667 m
.00375 .41667 L
s
0 .45833 m
.00375 .45833 L
s
0 .54167 m
.00375 .54167 L
s
0 .58333 m
.00375 .58333 L
s
0 .625 m
.00375 .625 L
s
0 .66667 m
.00375 .66667 L
s
0 .75 m
.00375 .75 L
s
0 .79167 m
.00375 .79167 L
s
0 .83333 m
.00375 .83333 L
s
0 .875 m
.00375 .875 L
s
0 .04167 m
.00375 .04167 L
s
0 .95833 m
.00375 .95833 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -131.125 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
93.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
105.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.29167 .99375 m
.29167 1 L
s
.5 .99375 m
.5 1 L
s
.70833 .99375 m
.70833 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.125 .99625 m
.125 1 L
s
.16667 .99625 m
.16667 1 L
s
.20833 .99625 m
.20833 1 L
s
.25 .99625 m
.25 1 L
s
.33333 .99625 m
.33333 1 L
s
.375 .99625 m
.375 1 L
s
.41667 .99625 m
.41667 1 L
s
.45833 .99625 m
.45833 1 L
s
.54167 .99625 m
.54167 1 L
s
.58333 .99625 m
.58333 1 L
s
.625 .99625 m
.625 1 L
s
.66667 .99625 m
.66667 1 L
s
.75 .99625 m
.75 1 L
s
.79167 .99625 m
.79167 1 L
s
.83333 .99625 m
.83333 1 L
s
.875 .99625 m
.875 1 L
s
.04167 .99625 m
.04167 1 L
s
.95833 .99625 m
.95833 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .29167 m
1 .29167 L
s
.99375 .5 m
1 .5 L
s
.99375 .70833 m
1 .70833 L
s
.99375 .91667 m
1 .91667 L
s
.125 Mabswid
.99625 .125 m
1 .125 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .20833 m
1 .20833 L
s
.99625 .25 m
1 .25 L
s
.99625 .33333 m
1 .33333 L
s
.99625 .375 m
1 .375 L
s
.99625 .41667 m
1 .41667 L
s
.99625 .45833 m
1 .45833 L
s
.99625 .54167 m
1 .54167 L
s
.99625 .58333 m
1 .58333 L
s
.99625 .625 m
1 .625 L
s
.99625 .66667 m
1 .66667 L
s
.99625 .75 m
1 .75 L
s
.99625 .79167 m
1 .79167 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .875 m
1 .875 L
s
.99625 .04167 m
1 .04167 L
s
.99625 .95833 m
1 .95833 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ .03 .03 ] 0 setdash
.5 .91667 m
.50323 .91665 L
.50617 .91662 L
.50956 .91656 L
.51277 .91647 L
.51847 .91626 L
.52466 .91594 L
.53147 .91548 L
.53867 .91487 L
.55157 .91346 L
.56483 .91159 L
.57719 .90945 L
.60506 .9032 L
.63298 .89488 L
.65795 .88557 L
.71167 .8589 L
.75485 .82964 L
.7974 .79183 L
.83267 .75089 L
.86409 .70261 L
.87699 .67745 L
.88899 .64933 L
.89767 .62437 L
.90536 .5964 L
.90831 .58304 L
.91098 .56862 L
.91287 .55609 L
.9145 .5424 L
.91525 .53435 L
.9158 .5269 L
.9162 .51976 L
.91635 .51616 L
.91649 .51218 L
.91658 .50861 L
.91663 .50533 L
.91666 .50173 L
.91667 .49992 L
.91666 .49794 L
.91663 .49459 L
.91657 .49101 L
.91648 .48764 L
.91638 .48457 L
.9161 .47823 L
.91567 .47126 L
.91446 .4572 L
.91292 .44423 L
.9111 .43213 L
.90572 .40511 L
.89796 .37654 L
.88882 .35024 L
Mistroke
.87689 .32233 L
.85009 .27406 L
.81783 .23056 L
.7776 .18928 L
.731 .15323 L
.68292 .12563 L
.65838 .11461 L
.63177 .10472 L
.60629 .09712 L
.5827 .09162 L
.55695 .08724 L
.54269 .08553 L
.53612 .0849 L
.52914 .08435 L
.52318 .08398 L
.52001 .08381 L
.5166 .08366 L
.51347 .08355 L
.51061 .08347 L
.50787 .08341 L
.50499 .08336 L
.50184 .08334 L
.49849 .08334 L
.49532 .08336 L
.49244 .0834 L
.48906 .08348 L
.48539 .08359 L
.47874 .08388 L
.47225 .08426 L
.46529 .08478 L
.45275 .08602 L
.43789 .08799 L
.42441 .09025 L
.39541 .09667 L
.3684 .10466 L
.31782 .12527 L
.27375 .15011 L
.23254 .18051 L
.19173 .21968 L
.15859 .26114 L
.12907 .31021 L
.10731 .3607 L
.09893 .38708 L
.09499 .40215 L
.09178 .41651 L
.08929 .42981 L
.08707 .44431 L
.0855 .45755 L
.08443 .46981 L
.08399 .47667 L
Mistroke
.08368 .4831 L
.08354 .48678 L
.08345 .49015 L
.08341 .49201 L
.08338 .49404 L
.08335 .49596 L
.08334 .49774 L
.08333 .4996 L
.08334 .50161 L
.08335 .50351 L
.08337 .50526 L
.08342 .50858 L
.08351 .51208 L
.08363 .51584 L
.08378 .51936 L
.08423 .52733 L
.08476 .53447 L
.08536 .54107 L
.08711 .55594 L
.08909 .569 L
.09164 .58279 L
.09715 .60641 L
.10481 .63205 L
.12485 .68131 L
.15328 .73107 L
.18679 .77479 L
.22796 .8156 L
.27128 .84828 L
.31507 .87338 L
.34145 .88532 L
.36703 .89488 L
.39079 .9021 L
.41635 .90818 L
.4369 .91186 L
.44865 .91349 L
.45967 .91471 L
.46981 .91557 L
.47909 .91614 L
.48422 .91637 L
.48693 .91646 L
.48982 .91654 L
.49259 .9166 L
.4951 .91664 L
.49763 .91666 L
.5 .91667 L
Mfstroke
[ ] 0 setdash
.5 .95738 m
.50177 .95738 L
.50339 .95737 L
.50525 .95735 L
.50701 .95733 L
.51014 .95726 L
.51354 .95717 L
.51728 .95703 L
.52125 .95685 L
.52835 .95643 L
.53568 .95587 L
.54253 .95522 L
.55809 .95335 L
.57387 .95084 L
.58821 .94802 L
.62005 .93986 L
.6471 .93078 L
.6758 .91881 L
.72897 .88945 L
.77538 .85441 L
.81859 .81083 L
.8535 .76369 L
.88031 .71459 L
.89145 .68811 L
.90116 .65952 L
.90828 .63245 L
.91326 .60694 L
.91536 .59233 L
.91688 .57848 L
.91739 .57245 L
.91784 .56604 L
.91803 .5627 L
.91821 .55902 L
.91835 .55565 L
.91845 .55252 L
.91854 .54924 L
.91857 .54751 L
.9186 .54566 L
.91861 .54473 L
.91862 .54371 L
.91863 .54188 L
.91863 .54009 L
.91863 .53844 L
.91862 .5369 L
.9186 .53546 L
.91858 .53388 L
.91855 .53219 L
.91847 .52873 L
.91837 .52557 L
.91806 .51847 L
Mistroke
.91758 .51076 L
.91699 .50349 L
.91634 .49677 L
.91455 .48229 L
.91241 .46877 L
.90725 .44386 L
.90003 .41751 L
.89193 .39392 L
.87016 .34578 L
.84399 .30296 L
.81111 .26167 L
.7752 .22654 L
.73317 .19452 L
.68959 .16913 L
.64543 .14994 L
.62195 .14208 L
.59665 .13528 L
.57288 .1304 L
.5504 .12707 L
.53824 .12579 L
.53159 .12524 L
.52541 .12482 L
.52011 .12453 L
.51445 .1243 L
.51122 .1242 L
.50963 .12416 L
.50817 .12413 L
.50686 .12411 L
.50543 .12409 L
.50399 .12407 L
.50246 .12406 L
.50127 .12405 L
.5 .12405 L
Mfstroke
.5 .95738 m
.49823 .95738 L
.49661 .95737 L
.49475 .95735 L
.49299 .95733 L
.48986 .95726 L
.48646 .95717 L
.48272 .95703 L
.47875 .95685 L
.47165 .95643 L
.46432 .95587 L
.45747 .95522 L
.44191 .95335 L
.42613 .95084 L
.41179 .94802 L
.37995 .93986 L
.3529 .93078 L
.3242 .91881 L
.27103 .88945 L
.22462 .85441 L
.18141 .81083 L
.1465 .76369 L
.11969 .71459 L
.10855 .68811 L
.09884 .65952 L
.09172 .63245 L
.08674 .60694 L
.08464 .59233 L
.08312 .57848 L
.08261 .57245 L
.08216 .56604 L
.08197 .5627 L
.08179 .55902 L
.08165 .55565 L
.08155 .55252 L
.08146 .54924 L
.08143 .54751 L
.0814 .54566 L
.08139 .54473 L
.08138 .54371 L
.08137 .54188 L
.08137 .54009 L
.08137 .53844 L
.08138 .5369 L
.0814 .53546 L
.08142 .53388 L
.08145 .53219 L
.08153 .52873 L
.08163 .52557 L
.08194 .51847 L
Mistroke
.08242 .51076 L
.08301 .50349 L
.08366 .49677 L
.08545 .48229 L
.08759 .46877 L
.09275 .44386 L
.09997 .41751 L
.10807 .39392 L
.12984 .34578 L
.15601 .30296 L
.18889 .26167 L
.2248 .22654 L
.26683 .19452 L
.31041 .16913 L
.35457 .14994 L
.37805 .14208 L
.40335 .13528 L
.42712 .1304 L
.4496 .12707 L
.46176 .12579 L
.46841 .12524 L
.47459 .12482 L
.47989 .12453 L
.48555 .1243 L
.48878 .1242 L
.49037 .12416 L
.49183 .12413 L
.49314 .12411 L
.49457 .12409 L
.49601 .12407 L
.49754 .12406 L
.49873 .12405 L
.5 .12405 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{443.188, 675.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008Y0003C2000`400?l00000o`00003ooooooooo
ooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo
003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooo
oooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool0
0?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oooooooooo
ool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00
ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooooooooooo
ob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003o
oooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo
:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oo
ooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[
ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooo
ooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_o
oooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooo
oooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:ooo
ool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oooooo
ooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[oooo
o`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00Noooool4
o`000003oa0@4?oooooooooo00gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0@
ooooo`Co000000?o410@ooooooooool0Uoooool4o`000003oa0@4?oooooooooo00gooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0@ooooo`Co000000?o410@ooooooooool0:oooool0
07gooooo00?o0000ooooooooool03oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool04Oooool00ol0003ooooo
ooooo`2Kooooo`03o`000?oooooooooo00oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo017ooooo00?o0000
ooooooooool0;Oooool007;ooooo1_l00005ooooo`03o`000?oooooooooo00Oooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`09ooooo`05oa0@4?oooooo
ooooooooool@41003oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`2@ooooo`Ko00001Oooool00ol0003oooooooooo`07ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool02Oooool01Ol@413o
oooooooooooooooo410@00oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0;Oooool007gooooo00?o0000ooooooooool03oooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool02_ooool01Ol0003ooooooooooooo
oooo000000oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo017ooooo
00?o0000ooooooooool0Voooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0:ooooo`05o`000?ooooooooooooooool000003oooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool04Oooool00ol0003oooooooooo`0]
ooooo`00OOooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00_ooooo00Go0000ooooooooooooooooo`00000?ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01;ooooo00?o0000oooo
ooooool0Voooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00_ooooo00Go0000ooooooooooooooooo`00000?ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01;ooooo00?o0000oooo
ooooool0;Oooool007gooooo00?o0000ooooooooool03oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00oooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Vooo
ool00ol0003oooooooooo`0?ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0]ooooo`00OOooool00ol0003o
ooooooooo`0?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0=oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo02gooooo001kooooo`03oeEEEOmVIVKo0000017ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004Oooool00omEEEGoIVIVo`00002Kooooo`03oeEEEOmV
IVKo0000017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004Oooool00omE
EEGoIVIVo`00000_ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool006koooooRol0
0021ooooohco00008oooool006kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Q
ooooo`00K_ooool00ol0003oooooooooo`0mooooo`_o0000?oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Qoooo
o`00K_ooool00ol0003oooooooooo`0iooooo`Co00001Oooool00ol0003oooooooooo`03ooooo`Co
0000>oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0gooooo`;o0000
2Oooool00ol0003oooooooooo`07ooooo`;o0000>Oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Qooooo`00K_oo
ool00ol0003oooooooooo`0eooooo`;o00002oooool00ol0003oooooooooo`09ooooo`;o0000=ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0cooooo`;o00003Oooool0
0ol0003oooooooooo`0;ooooo`;o0000=?ooool2o`00087ooooo0_l00014ooooo`03o`000?oooooo
oooo047ooooo0_l0000Sooooo`00K_ooool00ol0003oooooooooo`0aooooo`;o00003oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool08Oooool006ko
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Qooooo`00I_ooool4o`000005oa0@
4?ooooooooooooooool00000<Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1hooooo`Co000000Co410@oooooooo
oooo0000AOooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo027ooooo001Xooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo013ooooo0_l0000`ooooo`03o`000?oooooooooo07[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool08Oooool005gooooo1_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`1_ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Qooooo`00J?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?oo
ool5o`0000;ooooo1_l0000@ooooo`03o`000?oooooooooo02_ooooo0_l0001looooo`03o`000?oo
oooooooo00;ooooo0_l0000mooooo`Go00000_ooool6o`0003kooooo0_l0000Sooooo`00J?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01oooool3
o`0000[ooooo00?o0000ooooooooool01_ooool4o`0000[ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`1jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_ooool3
o`0000[ooooo00?o0000ooooooooool01_ooool4o`0003Sooooo00?o0000ooooooooool08Oooool0
06Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00Kooooo0_l0000=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0dooooo`;o00003Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool08Oooool006Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo0_l0000Booooo`03o`000?oooooooooo00ko
oooo1?l00003ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02oooooo0_l0000Booooo`03o`000?oooooooooo00ko
oooo1?l0000`ooooo`03o`000?oooooooooo027ooooo001Vooooo`03oeEEEOmVIVKo000000Gooooo
00?o0000ooooooooool0:?ooool01?l0003oooooooooooooool2o`0001Cooooo00?o0000oooooooo
ool04_ooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool0N?ooool00omE
EEGoIVIVo`000004ooooo`03o`000?oooooooooo02gooooo0_l0000Dooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003o
ooooooooo`0Wooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Uoooo
o`Wo00005Oooool00ol0003oooooooooo`0Booooo`Wo00009oooool00ol0003oooooooooo`0Qoooo
o`00K_ooool00ol0003oooooooooo`0Vooooo`;o00006_ooool00ol0003oooooooooo`0Fooooo`?o
0000:?ooool2o`00087ooooo0_l0000Qooooo`Go00000_ooool2o`0000Gooooo1?l0000Aooooo`03
o`000?oooooooooo00kooooo1?l00004ooooo`;o00000oooool6o`00023ooooo0_l0000Sooooo`00
K_ooool00ol0003oooooooooo`0Tooooo`;o00007?ooool00ol0003oooooooooo`0Hooooo`;o0000
:?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01kooooo0_l00005ooooo`;o0000
2oooool3o`0000kooooo00?o0000ooooooooool02oooool3o`0000[ooooo0_l00007ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool08ooo
ool00ol0003oooooo`00000Looooo`03o`000?oooooooooo01Wooooo0_l0000Wooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00kooooo1?l0000:ooooo`03o`000?oooooooooo00Oooooo1?l0000?ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Qooooo`00K_ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Jooooo`Co00001_ooool00ol0003oooooooooo`03ooooo`Co00007?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo0000
02Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Jooooo`;o00008Oooool4o`00
00;ooooo00?o0000ooooool000000ol0000Jooooo`03o`000?oooooooooo00Cooooo0_l0000Loooo
o`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo01oooooo0_l000000ooooooo
0000ooooo`0Nooooo`03o`000?oooooooooo01cooooo00?o0000ooooool000008_ooool2o`00087o
oooo0_l0000Jooooo`03o`000?oooooooooo00Cooooo0_l0000Oooooo`Go00007_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Sooooo0_l0000Sooooo`00K_ooool00ol0003ooooo
ooooo`0Nooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooo`00000Rooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08Oooool006kooooo
00?o0000ooooooooool07Oooool01?l0003oooooooooool0000Qooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooool000008Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo027o
oooo001^ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Tooooo`05o`000?ooooooooooooooool00000
6Oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0Jooooo`05o`000?oo
ooooooooooooool000008oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo
001^ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Hooooo`;o0000POooool2o`0001Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Dooooo`;o00008oooool006kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0E
ooooo`05o`000?ooooooooooooooool00000:Oooool00ol0003oooooooooo`0Vooooo`05o`000?oo
ooooooooooooool000005oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`0Dooooo`05o`000?ooooooooooooooool00000:_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08Ooo
ool006kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo02Wooooo00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`0Qooooo`00K_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool000006?ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool00000;Oooool00ol0003ooooooooo
o`0Yooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool08Oooool006kooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool09_ooool01Ol0003ooooooooooooooooo000001Kooooo0_l00021ooooo`;o0000
5?ooool2o`0002kooooo00?o0000ooooooooool0:_ooool00ol0003oooooo`00000Dooooo`;o0000
8oooool006kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool09oooool01Ol0003ooooooooooooooooo000001Kooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0:oooool2o`0001Gooooo00?o0000ooooooooool08Oooool006kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`0Booooo`;o0000;oooool00ol0003ooooooooo
o`0/ooooo`;o00005?ooool00ol0003oooooooooo`0Qooooo`00EOooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool00ol0003ooooo
ooooo`0Booooo`05o`000?ooooooooooooooool00000:oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ioooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool00ol0003oooooooooo`0B
ooooo`;o0000;oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool08Oooool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`02ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Ioooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`05ogMgMolb<S;oooooooooool00000
5?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Qooooo`00COooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400@ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo02[ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo
05oooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool01?l0003oooooooooool0
000Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo027ooooo001Eooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`02ooooo`03o`000?oooooooooo013ooooo00Co0000oooooooooooo0000
;_ooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0001;ooooo0_l0001Yooooo`05
o`000?ooooooooooooooool000003oooool01?mgMgOo<S8booooooooool2o`0001;ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo013ooooo0_l0000S
ooooo`00EOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c003ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000;oooool00ol0003ooooo
ooooo`0/ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool0Ioooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`03o`000?oooooo
oooo013ooooo0_l0000aooooo`03o`000?oooooooooo02kooooo0_l0000Booooo`03o`000?oooooo
oooo027ooooo001Eooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooool000004_ooool00ol0003oooooooooo`1Wooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooool00000<Oooool00ol0003oooooooooo`0^ooooo`;o00004_ooool00ol0003ooooo
ooooo`0Qooooo`00EOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooo`00033ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo06Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0
003oooooo`00000aooooo`03o`000?oooooooooo02kooooo00?o0000ooooool000004Oooool00ol0
003oooooooooo`0Qooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00004oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooool00000<Oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Ioooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00003ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool00000<Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08Oooool0
06kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool03_ooool2o`00087ooooo0_l0000Booooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0@ooooo`;o00008oooool006ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo037o
oooo0_l0000?ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00Go0000ooooooooooooooooo`00000?oooo
o`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0aooooo`;o00003oooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0_ooooo`04
o`000?ooooooooooo`0000oooooo00?o0000ooooooooool08Oooool006kooooo00?o0000oooooooo
ool03?ooool2o`0003Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool0000boooo
o`03o`000?oooooooooo02oooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`0Q
ooooo`00K_ooool00ol0003oooooooooo`0;ooooo`;o0000=Oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0<oooo
o`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo0000<oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool0
06kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool02_ooool2o`00087ooooo0_l0000=ooooo`04o`000?oooooooooo
o`0003?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`02o`0000cooooo0_l0000S
ooooo`00K_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo033ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0dooooo`;o00003?ooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0aooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool08Oooool0
06kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0aooooo`05o`000?oooooooooo
ooooool000003?ooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooo000003Oooooo00?o0000ooooooooool0=Oooool2o`0000_ooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool000003?ooool0
0ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooo
o`0003Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000003Cooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo027ooooo001^
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000>?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00Oooooo0_l00021ooooo`;o00002oooool01Ol0003ooooooooooooo
oooo000003Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0<ooooo`;o00008ooo
ool006kooooo00?o0000ooooooooool01oooool00ol0003oooooo`00000hooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooo0000=Oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool01_ooool0
1?l0003oooooooooool0000hooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo
0000=Oooool00ol0003oooooooooo`0booooo`04o`000?ooooooooooo`0000cooooo00?o0000oooo
ooooool08Oooool006kooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool0000hoooo
o`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool00000=_ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool08Oooool006kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ool000002Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0cooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool08Oooool006kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0c
ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Kooooo00Co0000
oooooooooooo00001oooool2o`00087ooooo0_l0000<ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0=?ooool00ol0003oooooo`00000:ooooo`;o00008oooool002kooooo00?o0000
okZj^_ooool0?Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0003Wooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo043ooooo00?o
0000okZj^_ooool0??ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000003Oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo000^
ooooo`;o<S8b?_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0003Wooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo043ooooo0_lb
<S8mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool00000=oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool001Kooooo0_l00002
ooooo`05o`000?ooooooooooo`000?l@41001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00?oQhN7o`000?nj^[X01?ooool5o`0000cooooo0_l000000ol@413oooooooooo`0Jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`04ooooo`;o00000_ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`;o00000_ooool2o`0001kooooo0_l00002ooooo`05o`000?ooooooooooo`00
0?l@41001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X01?ooool5
o`0000_ooooo00GoA4A4o`000?l0003o<S8bomgMg@0Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool00ol0003oooooooooo`09ooooo`;o0000>?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01?ooool2o`0000;ooooo0_l0000Gooooo`005ooo
ool01?l0003oooooooooool00002ooooo`Oo00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00?oc<c<o`000?l@41001_ooool00ol0003oooooooooo`02ooooo`Ko00001Oooool00ol0003o
ooooooooo`0Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0fooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`04ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003o
gMgM7oooool01?l0003oooooooooool00002ooooo`Oo00000_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00?oc<c<o`000?l@41001_ooool00ol0003oooooooooo`02ooooo`Ko00001_ooool0
0omgMgOo<S8booooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003ooooooooo
o`09ooooo`;o0000>?ooool00ol0003oooooooooo`0eooooo`;o00002oooool00ol0003ooooooooo
o`04ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5oooool001Oooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`0:ooooo`Go00007?ooool01Ol@413ooooooooooooooooo410@00CoooooRol00007
ooooo`04omgMgOl0003o410@olc<c23ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`06ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01Wooooo00Go410@oooooooooooooooooa0@4003ooooohco00001oooool01?oM
gMgo0000oa0@4?o<c<`Hooooo`005oooool01?l0003oooooooooool00002ooooo`Oo00000_ooool0
1Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool00_ooool6o`0000;ooooo00Co
A4A4omgMgOoooooo00007Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Kooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00Gooooo00Cok^k^ob4Q8Ol@413ok^k^8?ooool0
1?l0003oooooooooool00002ooooo`Oo00000_ooool01Ol0003ooooooooooooooooo000000cooooo
00?o0000ooooooooool00_ooool6o`0000Kooooo00?oMgMgoc8b<_ooool06_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`04
onk^k_lQ8B7o410@onk^kQSooooo000Gooooo`07o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8@08
ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0:ooooo`04omgMgOmE
EEGoooooo`0001gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0fooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`05ooooo`04ob4Q8OmgMgOoMgMgoc8b<R3ooooo00Oo0000
olc<c?o<c<co0000ojVYZOoMgMgo8B4Q00Sooooo00Go0000ooooooooooooooooo`00000<ooooo`03
o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00Co8B4Q
ogMgMomgMgOo<S8b6?ooool001Kooooo00So410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZ@So
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00_ooooo00?oMgMgolc<
c?l000007Oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool01?ooool2
o`0000;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0fooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`04ooooo`;o00000_ooool2o`0001kooooo00So
410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZ@Sooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`;o00000_oo
ool2o`0001Oooooo000Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`0;ooooo`03onk^k_m4A4Co000001gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooo0000>Oooool00ol0003oooooooooo`0fooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo00Sooooo0_l0000iooooo`03o`000?oo
oooooooo03Kooooo0_l0000:ooooo`03o`000?oooooooooo027ooooo000Vooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool00ol0003oooooooooo`0<ooooo`03ogMgMol0003ooooo01cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
0000>Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o0000ooooooooool02oooool4o`00
01cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00Sooooo0_l0000i
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Q
ooooo`00=Oooool00ol@413o0000o`00000fooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo0000>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Gooooo0_l00019
ooooo`03oa0@4?l0003o000003Gooooo0_l00009ooooo`;o0000>Oooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00Oooooo0_l0000Sooooo`00K_ooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`0003Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool00ol0003oooooo`00000i
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Q
ooooo`00K_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0=_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0=_ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`0Q
ooooo`00K_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool0=Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Gooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0=Oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool01?l0003ooooo
ooooool0000hooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000003So
oooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool00008ooooo`;o0000POooool2o`00
00Sooooo00Co0000oooooooooooo0000>?ooool00ol0003oooooooooo`0eooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0000Sooooo`00K_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
000003Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0000hooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`00K_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooo000003Oooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool0
1Ol0003ooooooooooooooooo000003Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooool00000=oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000=ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Ooo
ool006kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooool000002oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`05o`000?oooooo
ooooooooool000002Oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=?ooool2o`0000cooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool0=?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool08Ooo
ool006kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool02_ooool2o`00087ooooo0_l00009ooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0=?ooool01?l0003oooooooooool00009ooooo`;o00008ooo
ool006kooooo00?o0000ooooooooool02_ooool2o`0003Kooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool02?ooool0
1Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool0=?ooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000
=_ooool00ol0003oooooooooo`0cooooo`05o`000?ooooooooooooooool000002_ooool00ol0003o
ooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo
001^ooooo`03o`000?oooooooooo00cooooo0_l0000dooooo`03o`000?oooooooooo037ooooo0_l0
000?ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000003Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00gooooo0_l0000cooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool03_ooool2o`00087ooooo0_l0000:ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00Sooooo0_l0000Sooooo`00K_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0;oooool00ol0003oooooo`00000@ooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool02_ooool2o`0003Oooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`02o`0000cooooo00?o0000ooooooooool08Oooool006kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00Co0000oooo
oooooooo00004?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000000kooooo00?o0000
ooooooooool08Oooool006kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo033ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`0Qooooo`00EOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0oooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool00000;oooool00ol0003o
ooooooooo`0/ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`1Woooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool00000<oooool00ol0003ooooooooo
o`0_ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool08Oooool005Gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`02ooooo`03o`00
0?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Wooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00GoMgMgoc8b<_ooooooooooo`00000@ooooo`;o0000<oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool0
05Gooooo00Go410@oooooooooooooooooa0@400@ooooo`05o`000?ooooooooooooooool000004Ooo
ool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0Cooooo`;o0000JOooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00_l0000@ooooo`;o0000<_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00ko
oooo0_l0000Sooooo`00EOooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00_ooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Ioooool01Ol0
003ooooooooooooooooo000000oooooo00GoMgMgoc8b<_ooooooooooo`00000Booooo`;o0000<Ooo
ool00ol0003oooooooooo`0^ooooo`;o00004_ooool00ol0003oooooooooo`0Qooooo`00EOooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c003ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Zooooo`04o`00
0?ooooooooooo`0001Cooooo00?o0000ooooooooool0Ioooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool08Oooool005Gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo02Wooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo06Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4oooool2o`0002kooooo00?o0000ooooooooool0:oooool3o`0001Cooooo00?o0000ooooooooool0
8Oooool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo
00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo06Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool000005Oooool00ol0
003oooooooooo`0Qooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00004oooo
o`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000Zooooo`03o`000?oooooo
oooo02Oooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo06Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00000oooool00ol0003oooooooooo`0Dooooo`04o`00
0?oooooo0000o`0002_ooooo00?o0000ooooooooool0:?ooool2o`000003ooooool0003ooooo01Go
oooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Hooooo`;o0000POooool2o`0001Gooooo00Co0000oooooooooooooooo0_l0000Yooooo`03
o`000?oooooooooo02Kooooo0_l0000Iooooo`;o00008oooool006kooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool00_ooool2o`0002Kooooo00?o0000ooooooooool08ooo
ool2o`0001gooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003o
ooooooooo`0Hooooo`05o`000?ooooooooooooooool000009Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo01Wooooo00Go0000oooooooo
ooooooooo`00000Tooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Hooooo`;o0000POooool2o`0001_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Hooooo`;o00008oooool006kooooo00?o0000ooooooooool06_ooool01Ol0003o
oooooooooooooooo000002?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo01_ooooo00Go0000oooooooo
ooooooooo`00000Rooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`00000N
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool08Oooool006kooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01kooooo00Go0000oooo
ooooooooooooo`00000Oooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Nooooo`04o`000?oooooooooo
o`00023ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool07_ooool2o`00
0003ooooool0003ooooo01oooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool0000Q
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool07oooool2o`0000Cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooo000001oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Roooo
o`;o0000POooool2o`0002;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09Oooool2o`0002?ooooo001^ooooo`03
o`000?oooooooooo027ooooo0_l0000Oooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool06oooool2o`0002Gooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`02o`0002Gooooo00?o0000ooooooooool08Oooool006kooooo00?o
0000ooooooooool09?ooool3o`0001_ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool09_ooool3o`0001[ooooo00?o
0000ooooooooool05oooool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo027ooooo
001^ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00006_ooool00ol0003ooooo
ooooo`0Iooooo`;o00009oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo02Sooooo
0_l0000Iooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000:?ooool00ol0003o
ooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o0000
6?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Gooooo0_l00021ooooo`;o0000
:_ooool2o`0001Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Yooooo`;o0000
8oooool006kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Cooooo0_l00002ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05?oo
ool2o`0002cooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`02ooooo`?o00004oooool00ol0003oooooooooo`0Aooooo`?o00000oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0:oooool0
0ol0003oooooo`000002o`0001?ooooo00?o0000ooooooooool04Oooool4o`0002gooooo00?o0000
ooooooooool08Oooool006kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04oooo
o`;o00004Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`0/ooooo`04o`000?ooooooooooooooo`;o00004Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool08Oooool0
06Kooooo1?l000001Ol@413ooooooooooooooooo000002_ooooo00?o0000ooooooooool02?ooool2
o`0000cooooo00?o0000ooooooooool02_ooool4o`0000Oooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1hooooo`Co000000Co410@oooooooooooo0000;_ooool00ol0003ooooooooo
o`06ooooo`;o00003?ooool00ol0003oooooooooo`0:ooooo`Co00001Oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo027ooooo001Xooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`09ooooo`?o00002Oooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00Oooooo0ol00009ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool08Oooool006Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00kooooo1ol0
0003ooooo`Co00003_ooool00ol0003oooooooooo`0[ooooo`;o0000O?ooool00ol0003ooooooooo
o`02ooooo`;o0000;oooool00ol0003oooooooooo`0<ooooo`Oo00000oooool4o`0000cooooo00?o
0000ooooooooool0;Oooool2o`0002?ooooo001Xooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Qooooo`00J?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02gooooo0_l0000Cooooo`03o`000?oooooooooo013ooooo0_l0000`oooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo027ooooo001Xooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0;oooool2o`00017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo07[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo027ooooo001Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
<Oooool2o`0000oooooo00?o0000ooooooooool03Oooool2o`0003?ooooo00?o0000ooooooooool0
N_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03;ooooo0_l0000?ooooo`03o`00
0?oooooooooo00cooooo0_l0000dooooo`03o`000?oooooooooo027ooooo001Vooooo`03oeEEEOmV
IVKo000000Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo0_l0000eooooo`03o`000?oooooooooo07Sooooo00?oEEEEofIVI_l000001?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo03Cooooo0_l00021ooooo`;o0000=_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0=?ooool2o`0002?ooooo001^ooooo`03o`000?oooooooooo
03Gooooo0_l0000;ooooo`03o`000?oooooooooo00Sooooo0_l0000hooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0=_ooool2o`0000_ooooo00?o0000ooooooooool02?ooool2o`00
03Sooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool0=oooool4o`0000Oo
oooo00?o0000ooooooooool01?ooool4o`0003[ooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`0hooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`;o0000>_ooool00ol0003o
ooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0kooooo`?o00001?ooool01?l0003ooooo
ooooooooool3o`0003kooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0jooooo`;o
00001oooool00ol0003oooooooooo`04ooooo`;o0000??ooool00ol0003oooooooooo`0Qooooo`00
K_ooool00ol0003oooooooooo`0nooooo`So0000@Oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo03cooooo0ol00004ooooo`04o`000?ooooooooooooooo`?o0000?_ooool00ol0003o
ooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000007o`000003ooooool0003ooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`00K_oooon;o`00087oooooS?l0
000Sooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00
ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooooooooooo
ob_ooooo002`ooooo`Go0000ooooool9ooooo`Go0000Ioooool00;3ooooo0_mgMgL2ooooo`03o`00
0?oooooooooo0?oooooo1oooool2ogMgM`;ooooo00?o0000ooooooooool0IOooool00;7ooooo00?o
EEEEoiRHV?ooool0ooooool;ooooo`03oeEEEOnHV9Sooooo06Sooooo002booooo`03oeEEEOnHV9So
oooo0?oooooo2oooool00omEEEGoV9RHooooo`1Wooooo`00/?ooool01Ol0003ooooooooooolb<S;o
QhN70?oooooo2Oooool01Ol0003ooooooooooolb<S;oQhN706Oooooo002`ooooo`Go0000ooooool9
ooooo`Go0000Ioooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo
:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oo
ooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[
ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooo
ooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_o
oooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooo
oooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:ooo
ool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oooooo
ooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[oooo
o`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooooooo
ooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo
003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooo
oooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool0
0?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oooooooooo
ool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00
ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooooooooooo
ob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003o
oooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo
:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oo
ooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[
ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooo
ooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_o
oooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooo
oooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:ooo
ool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oooooo
ooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[oooo
o`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooooooo
ooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo
003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooo
oooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool0
0?ooooooooooool[ooooo`00Noooool4o`000003oa0@4?oooooooooo00gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00_ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@0@ooooo`Co000000?o410@ooooooooool0Uoooool4o`000003
oa0@4?oooooooooo00gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0@ooooo`Co
000000?o410@ooooooooool0:oooool007gooooo00?o0000ooooooooool03oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool04Oooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0:ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo017ooooo00?o0000ooooooooool0;Oooool007;ooooo1_l00005ooooo`03o`00
0?oooooooooo00Oooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`09ooooo`05oa0@4?ooooooooooooooool@41003oooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2@ooooo`Ko00001Oooool0
0ol0003oooooooooo`07ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool02Oooool01Ol@413ooooooooooooooooo410@00oooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;Oooool007gooooo
00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool02_ooool01Ol0003ooooooooooooooooo000000oooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo017ooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0?
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0:ooooo`05o`000?oo
ooooooooooooool000003oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool04Oooool00ol0003oooooooooo`0]ooooo`00OOooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00_ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<01;ooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00_ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<01;ooooo00?o0000ooooooooool0;Oooool007gooooo00?o0000ooooooooool03ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool03Oooool01Ol@413ooooo
oooooooooooo410@00oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0?ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0]ooooo`00OOooool00ol0003oooooooooo`0?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`0=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Koooo
o`03o`000?oooooooooo00oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo00gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02gooooo001kooooo`03oeEEEOmV
IVKo0000017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004Oooool00omE
EEGoIVIVo`00002Kooooo`03oeEEEOmVIVKo0000017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00004Oooool00omEEEGoIVIVo`00000_ooooo`00ooooooooooooob_ooooo003o
oooooooooooo:oooool006koooooRol00021ooooohco00008oooool006kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooo
oooo047ooooo0ol00013ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo
03Oooooo2_l000000ooooooo0000o`000009o`0003[ooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool08Oooool006ko
oooo00?o0000ooooooooool0<oooool4o`0000_ooooo00?o0000ooooooooool02?ooool4o`0003Go
oooo0_l00021ooooo`;o0000A?ooool00ol0003oooooooooo`11ooooo`;o00008oooool006kooooo
00?o0000ooooooooool0<Oooool2o`0000oooooo00?o0000ooooooooool03?ooool2o`0003Cooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool0;oooool2o`00017ooooo00?o
0000ooooooooool03_ooool2o`0003;ooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool08Oooool006Kooooo1?l00000
1Ol@413ooooooooooooooooo000002kooooo0ol0000Cooooo`03o`000?oooooooooo013ooooo0ol0
000_ooooo`03o`000?oooooooooo07Sooooo1?l000001?l@413oooooooooool00015ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool08Oooool006Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Yooooo`?o00005_ooool00ol0003oooooooooo`0Cooooo`?o0000;?oo
ool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo027ooooo001Mooooo`Ko00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Koooool6
o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool08Oooool006Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo1Ol00002ooooo`Ko00005?ooool2o`00
02Sooooo0_l0001looooo`03o`000?oooooooooo00;ooooo0_l0000mooooo`Go00000_ooool6o`00
03kooooo0_l0000Sooooo`00J?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool03?ooool3o`0000[ooooo00?o0000ooooooooool01_ooool5o`0000ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0=_ooool3o`0000[ooooo00?o0000ooooooooool01_ooool5o`0003Oo
oooo00?o0000ooooooooool08Oooool006Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00_ooooo0_l0000=ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0=?ooool2o`0000gooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`0Qooooo`00J?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo0_l0
0009ooooo`;o00004_ooool00ol0003oooooooooo`0>ooooo`Co00002Oooool2o`0002Gooooo00?o
0000ooooooooool0N_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo0_l0
000Booooo`03o`000?oooooooooo00kooooo1?l0000`ooooo`03o`000?oooooooooo027ooooo001V
ooooo`03oeEEEOmVIVKo000000Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07
ooooo`;o00005?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`1hooooo`03oeEEEOmVIVKo000000Cooooo00?o0000
ooooooooool0;Oooool2o`0001Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo027ooooo001^ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool2o`0001[ooooo00?o0000oooooooo
ool05_ooool2o`0000Oooooo00?o0000ooooooooool07oooool2o`00087ooooo0_l0000Xooooo`;o
00006_ooool00ol0003oooooooooo`0Fooooo`;o0000:Oooool2o`0002?ooooo001^ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Sooooo0_l00006ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`0Uooooo`;o00007?ooool00ol0003oooooooooo`0Hooooo`;o0000
:?ooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool02ooooolRo`0000cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0:_ooool8o`00017ooooo00?o0000ooooooooool03_ooool9
o`0002_ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool09_ooool4o`00
01Wooooo00?o0000ooooooooool05oooool3o`0000?ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;o
00008Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06oooool2o`00087ooooo0_l0000Qooooo`;o000000Coooooo`000?l0003o00007Oooool00ol0
003oooooooooo`0Jooooo`Go00008_ooool2o`0002?ooooo001^ooooo`03o`000?oooooooooo01_o
oooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
01oooooo1?l0000Pooooo`03o`000?oooooooooo01kooooo0ol0000Qooooo`03o`000?oooooooooo
027ooooo001^ooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo00009?ooool00ol0
003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000007Oooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo01cooooo0ol0000Tooooo`03o`000?oooooooooo023ooooo1?l0000N
ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool09?ooool2o`0001cooooo00?o0000ooooooooool08Oooool006kooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool0
00006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01Wooooo0_l0000Xooooo`03
o`000?oooooooooo02Cooooo00Co0000ooooool0003o00006_ooool00ol0003oooooooooo`0Qoooo
o`00K_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000002Oooooo00?o0000oooooooo
ool09Oooool2o`0001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Gooooo`;o
00000_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00Go0000oooooooo
ooooooooo`00000Iooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooool00000:?ooool00ol0003oooooooooo`0Vooooo`;o00006Oooool2o`00087o
oooo0_l0000Gooooo`05o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`0Uoooo
o`05o`000?ooooooooooooooool000005oooool2o`0002?ooooo001^ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooool00000:Oooool00ol0003oooooooooo`0Wooooo`;o00006Oooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000Y
ooooo`03o`000?oooooooooo02Kooooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oo
oooooooo027ooooo001^ooooo`03o`000?oooooooooo01Kooooo0_l0000Zooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo01Cooooo00Go0000ooooooooooooooooo`00000Zooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Q
ooooo`00K_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0:Oooool2o`0001Oooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0:Oooool01Ol0003ooooooooooooooooo
000001Cooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo02Wooooo0_l0000Gooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000002gooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool08Oooool006kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo02[ooooo0_l0000Eooooo`;o0000POooool2o`00017ooooo00Go0000oooo
ooooooooooooo`00000^ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0?ooooo`;o00008oooool006kooooo00?o0000ooooooooool04_ooool2o`00
02kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0000_ooooo`03o`000?oooooo
oooo02_ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo027ooooo001^
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0?
ooooo`05o`000?ooooooooooooooool00000;oooool00ol0003oooooooooo`0/ooooo`05o`000?oo
ooooooooooooool000004Oooool00ol0003oooooooooo`0Qooooo`00EOooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo06Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Qooooo`00EOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1W
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00GoMgMgoc8b<_oooooooooo
o`00000@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo027ooooo001=ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;Oooool2o`0001?ooooo00?o0000ooooooooool0Goooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`04o`000?ooooooooooo`0000oooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0^ooooo`05o`000?ooooooooooooooool000003ooo
ool00ol0003oooooooooo`0Qooooo`00EOooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool00_ooool00ol0003oooooooooo`0@ooooo`;o0000<?ooool00ol0003ooooooooo
o`0]ooooo`;o00004_ooool2o`0006Wooooo00Go0000ooooooooooooooooo`00000?ooooo`04ogMg
Molb<S;oooooooooo`;o00003_ooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo0_l0000Soooo
o`00EOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c003
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool00000<?ooool00ol0003oooooooooo`0^
ooooo`;o00004_ooool00ol0003oooooooooo`1Wooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00?o0000ooooooooool03?ooool01Ol0003ooooo
oooooooooooo000003;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool005Gooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooo`00000aooooo`03o`000?oooooooooo02kooooo0_l0000Booooo`03o`000?oooooooooo06Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03?ooool01?l0003oooooooooool0000cooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo001Eoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooool00000<Oooool00ol0003oooooooooo`0_ooooo`;o00004Oooool0
0ol0003oooooooooo`1Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000cooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo027ooooo001Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooo`00000aooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Wooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo0_l00021ooooo`;o0000
2oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
2Oooool2o`0002?ooooo001^ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0<_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool08Oooool006kooooo00?o
0000ooooooooool03?ooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo033ooooo
00?o0000ooooool000003oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Wooooo
00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo03;ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00co
oooo00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo0000
00oooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooo
ooooool00000=Oooool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool000002ooo
ool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo
ooooo`0003?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000fooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`00K_oo
ool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0003?ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0
2?ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00_ooooo
00Co0000oooooooooooo0000<oooool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`00
00cooooo0_l00021ooooo`;o00002Oooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000
ooooooooool0<oooool2o`0000;ooooo00?o0000ooooooooool01oooool2o`0002?ooooo001^oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0aoooo
o`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0=?ooool01?l0003oooooooooool0
000:ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0000gooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool0=?ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo027ooooo
001^ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0aooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooo000000[ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool02_oo
ool01?l0003oooooooooool0000dooooo`03o`000?oooooooooo037ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooo`00000hooooo`03o`000?oooooooooo03Gooooo00?o0000ooooool000002_ooool00ol0003o
ooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000003Gooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool02?ooool00ol0003oooooo`00000hooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003ooooooooo
o`09ooooo`04o`000?ooooooooooo`0003Gooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0<ooooo`;o0000POooool2o`0000Wooooo00?o0000ooooool00000>?ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00Oooooo0_l0000Sooooo`00K_ooool00ol0003ooooooooo
o`09ooooo`04o`000?ooooooooooo`0003Gooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
o`00000hooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Qooooo`00K_ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0003Gooooo
00?o0000ooooooooool0<_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooo`00000hooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooool000002_ooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<_ooool01?l0003ooooo
ooooool0000<ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo03Gooooo00?o0000ooooool000002_ooool00ol0003o
ooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0=_ooool2o`0000[ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03;ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo03Kooooo0_l0000:ooooo`03o`000?oooooooooo027o
oooo001^ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0booooo`05o`000?ooooooooooooooool000002_ooool2o`00087ooooo0_l00009ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0=_ooool2o`0000Wooooo0_l0000Sooooo`00
;_ooool00ol0003o^[Zjooooo`0mooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooo
ooooo`00000eooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`10ooooo`03o`000?nj^[[ooooo03cooooo00?o0000ooooooooool02?ooool2o`0003Wo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027o
oooo000^ooooo`;o<S8b?_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool0
0000=Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0@?ooool2oc8b<Sgooooo00?o0000ooooooooool02?ooool2o`0003Wooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo000Fooooo`;o0000
0_ooool01Ol0003oooooooooool0003o410@00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`03ohN7Qol0003o^[Zj00Cooooo1Ol0000:ooooo`Go00007?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Cooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000003Gooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo0_l0
0002ooooo`;o00007_ooool2o`0000;ooooo00Go0000oooooooooooo0000oa0@4007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P04ooooo`Go00002_ooool01OnHV9So
410@o`000?lb<S;oc<c<01cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooo
oooo00Sooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`04ooooo`;o00000_ooool2o`0001Oooooo000Gooooo`04o`000?oooooooooo
o`0000;ooooo1ol00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@
4006ooooo`03o`000?oooooooooo00;ooooo1_l00002ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
7?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool02?ooool01Ol0003o
oooooooooooooooo000003Gooooo00?o0000ooooooooool0<oooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00Cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdOooooo`04o`00
0?ooooooooooo`0000;ooooo1ol00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<
c<co0000oa0@4006ooooo`03o`000?oooooooooo00;ooooo1_l00002ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S807?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool02?oo
ool2o`0003Wooooo00?o0000ooooooooool0=_ooool2o`0000[ooooo00?o0000ooooooooool01?oo
ool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAOooooo000Gooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool02oooool00onHV9So8B4Qonk^kP0Mooooo`05oa0@4?ooooooooooooooool@41001?oooon;
o`0000Oooooo00CogMgMo`000?l@413oc<c<8?ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@00?oooooS?l00007oooo
o`04omgMgOl0003o410@olc<c1Sooooo000Gooooo`04o`000?ooooooooooo`0000;ooooo1ol00002
ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`02ooooo`Ko00001?oo
ool00onHV9So8B4Qonk^kP0Looooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool01?l0003ooooo
ooooool0000;ooooo`03o`000?oooooooooo00Gooooo00Cok^k^ob4Q8Ol@413ok^k^8?ooool01?l0
003oooooooooool00002ooooo`Oo00000_ooool01Ol0003ooooooooooooooooo000000cooooo00?o
0000ooooooooool00_ooool6o`0000Gooooo00?oZJVYoa0@4?ooool06oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`04onk^
k_lQ8B7o410@onk^kQSooooo000Gooooo`07o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8@08oooo
o`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKo
oooo01_ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0cooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool01Oooool01?lQ8B7oMgMgogMgMolb<S8Pooooo`07o`000?o<c<coc<c<o`00
0?nYZJWogMgMob4Q8@08ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003ooooooooo
o`0<ooooo`03oa0@4?l0003o^[Zj01cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0eooooo`;o0000
2oooool00ol0003oooooooooo`05ooooo`04ob4Q8OmgMgOoMgMgoc8b<QSooooo000Fooooo`08oa0@
4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJT8ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooo
oa0@4004ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000eooooo`03
o`000?oooooooooo03?ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`04oooo
o`;o00000_ooool2o`0001kooooo00So410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZ@Sooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00gooooo00?o^[Zjob4Q8Ooo
ool06oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool02Oooool2o`00
03Sooooo00?o0000ooooooooool0=Oooool2o`0000_ooooo00?o0000ooooooooool01?ooool2o`00
00;ooooo0_l0000Gooooo`009_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@01cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`04ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000eooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?nHV9SooooookZj
^_l000007?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool02Oooool2
o`0003Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo027ooooo000Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00ol0003oooooooooo`0:
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`07?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo
00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000003Gooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`03o`000?oooooooooo00[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0L
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`09ooooo`;o0000>?oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Ooo
ool003Gooooo00?o410@o`000?l00000=_ooool00ol0003oooooooooo`08ooooo`05o`000?oooooo
ooooooooool00000=Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00cooooo0_l0
0019ooooo`03oa0@4?l0003o000003Gooooo0_l0000:ooooo`03o`000?oooooo000003Oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0:ooooo`;o00008oooool006kooooo00?o0000
ooooooooool02?ooool01Ol0003ooooooooooooooooo000003Gooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooo`00000gooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0=?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo027ooooo001^
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0b
ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooo000000_ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo00003?oo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool08Ooo
ool006kooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000eooooo`03o`000?oo
oooooooo03;ooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooool00000=_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooo000000cooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooool0000eooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo
00002oooool2o`00087ooooo0_l0000;ooooo`03o`000?oooooo000003Kooooo00?o0000oooooooo
ool0<oooool00ol0003oooooo`00000;ooooo`;o00008oooool006kooooo00?o0000ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000003Cooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool02_ooool01?l0003o
ooooooooool0000eooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`00
03Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000eooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003o
ooooooooo`0:ooooo`04o`000?ooooooooooo`0003Cooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool02oooool00ol0
003oooooo`00000eooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0<Oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
037ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<Oooool01?l0
003oooooooooool0000=ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo037ooooo00Co0000oooooooooooo00003Ooo
ool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0<Oooool01?l0003oooooooooool0000<ooooo`;o0000POoo
ool2o`00013ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0`ooooo`05o`000?oo
ooooooooooooool000003?ooool2o`0002?ooooo001^ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooool00000=?ooool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0000gooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0003?o
oooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000oooo
ooooool08Oooool006kooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000coooo
o`03o`000?oooooooooo033ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000booooo`03o`000?oo
oooooooo02oooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo027ooooo
001^ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool00000<oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`0=ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooool00000<oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool00000
<Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
8Oooool006kooooo00?o0000ooooooooool03Oooool2o`0003?ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0>ooooo`;o0000POooool2o`0000oooooo00Co0000oooooooooooo0000
<Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo013ooooo0_l0000Sooooo`00K_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00Go0000oooooooooooooooo
o`00000@ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool08Oooool006kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooool000004?ooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/
ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`0Qooooo`00EOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo0000037ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo06Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0:oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool08Oooool0
05Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`02
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooool00000<Oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Ioooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`05ogMgMolb<S;oooooooooool000004Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo027ooooo001Eooooo`05oa0@4?ooooooooooooooool@4100
4?ooool01Ol0003ooooooooooooooooo0000017ooooo0_l0000aooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool04?ooool2o`0006Wooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Dooooo`;o00008oooool005Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00;ooooo00?o0000oooo
ooooool04?ooool2o`00033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo06Oooooo00Go0000ooooooooooooooooo`00000?ooooo`05ogMgMolb<S;o
ooooooooool000004oooool01Ol0003ooooooooooooooooo000002gooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo027ooooo001Eooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`1Wooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oo
oooooooo027ooooo001Eooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0/ooooo`;o00005?ooool00ol0003oooooooooo`1Wooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool000005?ooool00ol0003o
ooooooooo`0Qooooo`00EOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo02Sooooo00Go0000ooooooooooooooooo`00000E
ooooo`03o`000?oooooooooo027ooooo001Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Cooooo00?o0000ooooooooool04_ooool2o`0002kooooo00?o0000ooooooooool0:oooool2
o`0001Gooooo00?o0000ooooooooool0Ioooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0003ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo0000:oooool00ol0003ooooo
ooooo`0Xooooo`04o`000?ooooooooooo`0001Kooooo00?o0000ooooooooool08Oooool006kooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool04oooool2o`00087ooooo0_l0000Eooooo`05o`000?ooooooooooooooool0
0000:_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Oooooo0_l0000Sooooo`00
K_ooool00ol0003oooooooooo`0Cooooo`;o0000;Oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Eooooo`05o`00
0?ooooooooooooooool00000:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool05?ooool2o`0002cooooo
00?o0000ooooooooool0:?ooool00ol0003oooooo`00000Gooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool05_ooool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooool000006Oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
o`00000Gooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooool000006Oooool00ol0003ooooo
ooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool09oooool00ol0003oooooo`00000Hooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooool000006_ooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooo000002Wooooo00?o0000ooooooooool09oooool2o`0001Wooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo000002Oooooo00?o0000
ooooooooool09Oooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo027ooooo001^oooo
o`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooo000001Sooooo0_l00021ooooo`;o00006oooool00ol0003oooooo`00000V
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool000006_ooool2o`0002?ooooo001^oooo
o`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00009oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0K
ooooo`;o00009_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool08Oooool006kooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo
000002Kooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000001[ooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`0Looooo`;o00009Oooool00ol0003ooooooooo
o`0Rooooo`;o00007_ooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08_ooool01Ol0003ooooooooooooo
oooo000001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo027ooooo001^ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Qooooo`05o`000?ooooooooooooooool000007?ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08Oooool006kooooo00?o0000
ooooooooool06_ooool01?l0003oooooooooooooool2o`0002;ooooo00?o0000ooooooooool08?oo
ool01Ol0003ooooooooooooooooo000001cooooo0_l00021ooooo`;o00008?ooool2o`0002;ooooo
00?o0000ooooooooool07oooool2o`00023ooooo0_l0000Sooooo`00K_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooo0000027ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool08?ooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo01cooooo00Co0000
oooooooooooo00008_ooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0
000Sooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool01?ooool2o`0001_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0R
ooooo`04o`000?ooooooooooooooo`;o00006oooool00ol0003oooooooooo`0Jooooo`04o`000?oo
ooooooooo`0002Cooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool0
8Oooool006kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`05ooooo`;o00006?oo
ool00ol0003oooooooooo`0Dooooo`;o00002?ooool00ol0003oooooooooo`0Pooooo`;o0000POoo
ool2o`0002Gooooo00?o0000ooooooooool00_ooool2o`0001Sooooo00?o0000ooooooooool05?oo
ool2o`0000Gooooo00?o0000ooooooooool08oooool2o`0002?ooooo001^ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0
003oooooooooo`0Rooooo`;o00002?ooool3o`0001?ooooo00?o0000ooooooooool04Oooool2o`00
00Sooooo0_l0000Uooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`04ooooo`?o00004oooool00ol0003oooooooooo`0Aooooo`;o00001_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo027ooooo001Vooooo`Co000000Go410@oooooooo
ooooooooo`00000Vooooo`03o`000?oooooooooo00Sooooo0_l0000Aooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1hooooo`Co000000Co410@oooo
oooooooo0000:Oooool00ol0003oooooooooo`06ooooo`;o00004Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08Oooool006Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Uooooo`;o00003Oooool2o`0000cooooo00?o0000oooo
ooooool02_ooool4o`0000[ooooo0_l0000Xooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo0_l0000<oooo
o`03o`000?oooooooooo00[ooooo1?l00009ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool08Oooool006Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00cooooo0ol00009ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0N_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool3o`00
00Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`00J?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool7o`0000?ooooo1?l0000Aoooo
o`03o`000?oooooooooo02Sooooo0_l0001looooo`03o`000?oooooooooo00;ooooo0_l0000[oooo
o`;o00004Oooool7o`0000?ooooo1?l0000?ooooo`;o0000:oooool2o`0002?ooooo001Xooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0:Oooool2o`0001Oooooo00?o0000oooooooo
ool05?ooool2o`0002cooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool08Oooool006Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0[ooooo`;o00005Oooool00ol0003oooooooooo`0Booooo`;o0000
;_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Qooooo`00J?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02gooooo0ol0000Booooo`03o`000?oooooooooo00oooooo0ol0000`ooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`;o00004ooo
ool00ol0003oooooooooo`0@ooooo`;o0000<?ooool00ol0003oooooooooo`0Qooooo`00I_ooool0
0omEEEGoIVIVo`000005ooooo`03o`000?oooooooooo033ooooo0ol0000?ooooo`03o`000?oooooo
oooo00cooooo0ol0000cooooo`03o`000?oooooooooo07Sooooo00?oEEEEofIVI_l000001?ooool0
0ol0003oooooooooo`0`ooooo`;o00004Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool0<oooool2o`00
00gooooo00?o0000ooooooooool02_ooool2o`0003Kooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`0booooo`?o00003_ooool00ol0003oooooooooo`0<ooooo`?o0000<oooool00ol0
003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0eooooo`Co00002Oooool00ol0003o
ooooooooo`06ooooo`Co0000=oooool2o`00087ooooo0_l0000fooooo`?o00002oooool00ol0003o
ooooooooo`08ooooo`Co0000=Oooool2o`0002?ooooo001^ooooo`03o`000?oooooooooo03Wooooo
4_l0000looooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0>?ooool2o`0000Wooooo
00?o0000ooooooooool01_ooool2o`0003[ooooo00?o0000ooooooooool08Oooool006kooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0>_ooool8o`000003ooooool0003ooooo00Oo0000??ooool00ol0003ooooooooo
o`0Qooooo`00K_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`11ooooo`Co0000@oooool00ol0003oooooooooo`0Q
ooooo`00K_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool08Oooool006koooooRol00021ooooohco00008oooool00?ooooooooooool[ooooo`00oooo
ooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_o
oooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo002`oooo
o`Go0000ooooool9ooooo`Go0000Ioooool00;3ooooo0_mgMgL2ooooo`03o`000?oooooooooo0?oo
oooo1oooool2ogMgM`;ooooo00?o0000ooooooooool0IOooool00;7ooooo00?oEEEEoiRHV?ooool0
ooooool;ooooo`03oeEEEOnHV9Sooooo06Sooooo002booooo`03oeEEEOnHV9Sooooo0?oooooo2ooo
ool00omEEEGoV9RHooooo`1Wooooo`00/?ooool01Ol0003ooooooooooolb<S;oQhN70?oooooo2Ooo
ool01Ol0003ooooooooooolb<S;oQhN706Oooooo002`ooooo`Go0000ooooool9ooooo`Go0000Iooo
ool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oooooo
ooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[oooo
o`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooooooo
ooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo
003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooo
oooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool0
0?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oooooooooo
ool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00
ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooooooooooo
ob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003o
oooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo
:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oo
ooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[
ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooo
ooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_o
oooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooo
oooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:ooo
ool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oooooo
ooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[oooo
o`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooooooo
ooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo
003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooo
oooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool0
0?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oooooooooo
ool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00
ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooooooooooo
ob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003o
oooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo
:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oo
ooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool007_ooooo1?l00000
0ol@413oooooooooo`0=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd04?ooool4
o`000003oa0@4?oooooooooo09Oooooo1?l000000ol@413oooooooooo`0=ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd04?ooool4o`000003oa0@4?oooooooooo02_ooooo001moooo
o`03o`000?oooooooooo00oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`0:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo017ooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`0?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool02_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Aooooo`03o`000?oooooo
oooo02gooooo001booooo`Ko00001Oooool00ol0003oooooooooo`07ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool02Oooool01Ol@413ooooooooooooo
oooo410@00oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0T?ooool6o`0000Gooooo00?o0000ooooooooool01oooool6o`0000;ooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo02gooooo001mooooo`03o`000?oooooooooo00oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00[ooooo00Go0000ooooooooooooooooo`00
000?ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Aooooo`03o`00
0?oooooooooo09_ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool02_ooool01Ol0003ooooooooooooooooo000000oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo017ooooo00?o0000ooooooooool0;Oooool0
07gooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00;ooooo`05o`000?ooooooooooooooool000003oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Booooo`03o`000?oooooooooo
09_ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00;ooooo`05o`000?ooooooooooooooool000003oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Booooo`03o`000?oooooooooo
02gooooo001mooooo`03o`000?oooooooooo00oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400?ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo09_ooooo00?o
0000ooooooooool03oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
3Oooool01Ol@413ooooooooooooooooo410@00oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;Oooool007gooooo00?o0000oooooooo
ool03oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0?ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0=ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0]ooooo`00Noooool00omEEEGoIVIVo`00000Aooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`00017ooooo00?oEEEEofIVI_l00000Voooool00omEEEGoIVIVo`00
000Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00017ooooo00?oEEEEofIV
I_l00000;oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:ooo
ool006koooooRol00021ooooohco00008oooool006kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`11ooooo`;o0000POooool2o`0004Cooooo00?o0000oooo
ooooool0@Oooool2o`0002?ooooo001^ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0oooooo`Ko0000
@_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`0Qooooo`00I_ooool4o`000005oa0@4?ooooooooooooooool00000
>?ooool9o`0000?ooooo00?o0000ooooooooool02Ol0000iooooo`03o`000?oooooooooo07Sooooo
1?l000001?l@413oooooooooool00015ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool08Oooool006Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`Go0000
3?ooool00ol0003oooooooooo`09ooooo`Go0000=?ooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo027ooooo001Mooooo`Ko00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02kooooo0ol0000Aooooo`03o`000?oooooooooo00kooooo0ol0000aooooo`03o`000?oo
oooooooo06oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo027ooooo001Xooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0;?ooool2o`0000gooooo1Ol00002ooooo`Ko00003_ooool2
o`0002kooooo0_l0001looooo`03o`000?oooooooooo00;ooooo0_l0000mooooo`Go00000_ooool6
o`0003kooooo0_l0000Sooooo`00J?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02[ooooo0_l00009ooooo`?o00002_ooool00ol0003oooooooooo`06ooooo`Go00002?ooool2o`00
02gooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03Kooooo0ol0000:ooooo`03o`000?oooooooooo00Kooooo1Ol0000gooooo`03o`000?oooooooooo
027ooooo001Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool3o`0000Wo
oooo0_l0000=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool3o`0002[o
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Co
oooo0_l0000=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0Qooooo`00J?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo
0_l00006ooooo`?o00004_ooool00ol0003oooooooooo`0?ooooo`?o00001_ooool2o`0002Sooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo
0ol0000Booooo`03o`000?oooooooooo00oooooo0ol0000`ooooo`03o`000?oooooooooo027ooooo
001Vooooo`03oeEEEOmVIVKo000000Gooooo00?o0000ooooooooool08oooool2o`0000Kooooo0_l0
000Eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool2o`0002Kooooo00?o
0000ooooooooool0N?ooool00omEEEGoIVIVo`000004ooooo`03o`000?oooooooooo02cooooo0_l0
000Eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0Qooooo`00K_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool07?ooool2o`0002?ooooo0_l00021ooooo`;o0000?oooool:o`0003oooooo0_l0000S
ooooo`00K_ooool00ol0003oooooooooo`0Pooooo`;o00001?ooool2o`0001[ooooo00?o0000oooo
ooooool05_ooool2o`0000Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo02Oooooo0_l0000>ooooo`Oo00001Oooool00ol0003oooooooooo`02oooo
o`So00003?ooool2o`0002[ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`02ooooo`;o00007?ooool00ol0003oooooooooo`0Hooooo`;o
00001Oooool2o`00027ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Uooooo`;o
00003Oooool3o`0000cooooo00?o0000ooooooooool02_ooool3o`0000_ooooo0_l0000Xooooo`03
o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo01gooooo0_l00004ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00Wooooo1?l0000?ooooo`03o`000?oooooooooo00gooooo0ol0000:ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo02gooooo0ol0000Cooooo`03o`000?oo
oooooooo013ooooo0ol0000_ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Mooooo`;o00001?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0:oooool2
o`0001Kooooo00?o0000ooooooooool04oooool2o`0000Sooooo0_l0000Sooooo`03o`000?oooooo
oooo027ooooo001^ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool2o`00
027ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01[ooooo0_l00021ooooo`;o00008Oooool2o`0000Oooooo0_l0000Hooooo`03o`000?oooooooooo
01Gooooo0_l00008ooooo`03o`000?oooooooooo01oooooo0_l0000Sooooo`00K_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool2o`0001[o
oooo00?o0000ooooooooool05oooool2o`0000Oooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo
0_l0000Looooo`03o`000?oooooooooo01Wooooo0_l0000Wooooo`03o`000?oooooooooo027ooooo
001^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`0Sooooo`;o00007_ooool00ol0003oooooooooo`0Kooooo`;o00009Oooool00ol0003ooooooooo
o`0Qooooo`00K_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool09?ooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`0Qooooo`;o00008?ooool00ol0003oooooooooo`0Mooooo`;o00001Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo02Gooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool08Oooool006kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooo
oooo000001Kooooo0_l00021ooooo`;o00006oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool08?ooool2o`0000?ooooo00?o0000ooooooooool06Ooo
ool2o`0002?ooooo001^ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`00
000Fooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08_ooool01Ol0003ooooooooo
oooooooo000001_ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo027ooooo001^ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Yooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0U
ooooo`05o`000?ooooooooooooooool000006?ooool00ol0003oooooooooo`0Qooooo`00K_ooool0
0ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003ooooooooo
o`0Zooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Kooooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo027o
oooo001^ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000^ooooo`03
o`000?oooooooooo02_ooooo00Go0000ooooooooooooooooo`00000Aooooo`;o0000POooool2o`00
01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
02Oooooo00Go0000ooooooooooooooooo`00000Eooooo`;o00008oooool006kooooo00?o0000oooo
ooooool03oooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo02cooooo00Co0000
oooooooooooo00004_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo00Go
0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oo
oooooooo00kooooo00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Qooooo`00EOooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo06Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Qooooo`00EOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1W
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00GoMgMgoc8b<_oooooooooo
o`00000Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo027ooooo001=ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0;_ooool01Ol0003ooooooooooooooooo000000kooooo0_l0001Qoooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_l0000F
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:_ooool01Ol0003ooooooooooooo
oooo000001;ooooo0_l0000Sooooo`00EOooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool00_ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool00000
<Oooool00ol0003oooooooooo`0^ooooo`05o`000?ooooooooooooooool000003oooool00ol0003o
ooooooooo`1Wooooo`05o`000?ooooooooooooooool000003oooool01OmgMgOo<S8boooooooooooo
000001?ooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`0[ooooo`04o`000?oo
ooooooooo`0001?ooooo00?o0000ooooooooool08Oooool005Gooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00oooool00ol0003oooooooooo`0;ooooo`05
o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`0_ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`1Wooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00?o0000ooooooooool04?ooool01?l0003ooooo
ooooool0000_ooooo`03o`000?oooooooooo02cooooo00Co0000oooooooooooo00004_ooool00ol0
003oooooooooo`0Qooooo`00EOooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0003?ooooo00?o0000
ooooooooool0<?ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo06Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooooooool0;?ooool01Ol0003o
oooooooooooooooo0000017ooooo00?o0000ooooooooool08Oooool005Gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool01?l0
003oooooooooool0000cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000<?ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08Oooool005Gooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001?ooool00ol0003oooooooooo`0:ooooo`05o`00
0?ooooooooooooooool00000<oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0Ioooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00003oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooool00000<Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool02_ooool2o`00087ooooo0_l0000Booooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0@ooooo`;o00008oooool006kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo
00003?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0_ooooo`04o`000?ooooooooooo`0000oooooo00?o0000oooo
ooooool08Oooool006kooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000eoooo
o`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool00000<oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool08Oooool006kooooo00?o0000oooo
ooooool02?ooool01Ol0003ooooooooooooooooo000003Gooooo00?o0000ooooooooool0<_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooo000003?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooo`00
000?ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00Sooooo00Co0000
oooooooooooo0000=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo000003Cooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo027ooooo001^
ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo0000=_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooo000003Cooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00Oooooo00Go0000
ooooooooooooooooo`00000fooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooooooo0000
2Oooool2o`00087ooooo0_l0000=ooooo`;o0000=Oooool00ol0003oooooooooo`0booooo`?o0000
3?ooool2o`0002?ooooo001^ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0dooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0dooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooo`00000=ooooo`03o`00
0?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
<oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oo
oooooooo00Kooooo00Go0000ooooooooooooooooo`00000gooooo`03o`000?oooooooooo03Gooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooool00000=_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo000000co
oooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool02_ooool2o`0003Oooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`00
0?oooooooooo00Kooooo00Co0000oooooooooooo0000>?ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00Gooooo0_l00021ooooo`;o00002oooool2o`0003Oooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0:ooooo`;o00008oooool006kooooo00?o0000ooooooooool0
1_ooool01?l0003oooooooooool0000hooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00[ooooo0_l0000gooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`00
K_ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0003Sooooo00?o0000oooooooo
ool0=Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0eooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool08Oooool006kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo03Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0eoooo
o`;o00002oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0=_ooool01?l0003oooooooooool00007oooo
o`;o0000POooool2o`0000_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0eoooo
o`;o00002_ooool2o`0002?ooooo001^ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo0000>Oooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`09ooooo`;o0000>?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool002kooooo00?o0000okZj
^_ooool0?Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0003Wooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo043ooooo00?o0000
okZj^_ooool0??ooool00ol0003oooooooooo`09ooooo`;o0000>?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool002kooooo0_lb<S8noooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000>Oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@?ooool2oc8b<Sgooooo00?o0000
ooooooooool02Oooool2o`0003Sooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo027ooooo000Fooooo`;o00000_ooool01Ol0003oooooooooool0003o
410@00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00Cooooo1Ol0
000:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Co
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`;o00000_ooool2o`00
01kooooo0_l00002ooooo`05o`000?ooooooooooo`000?l@41001oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X01?ooool5o`0000_ooooo1?l000000ol@413ooooooooo
o`0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Cooooo0_l00002ooooo`;o00005oooool001Oooooo00Co0000oooooooooooo0000
0_ooool7o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00Ko
oooo00?o0000ooooooooool00_ooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Loooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0=_ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooooooo00Cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdOooooo`04o`000?ooooooooooo`00
00;ooooo1ol00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@4006
ooooo`03o`000?oooooooooo00;ooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?oo
ool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAOooooo000Gooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool02_ooool01Ol@413ooooooooooooooooo410@01cooooo00Go410@oooooooooooooooooa0@
4004oooooh_o00001oooool01?oMgMgo0000oa0@4?o<c<`Pooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41000ooooon<
o`0000Oooooo00CogMgMo`000?l@413oc<c<6?ooool001Oooooo00Co0000oooooooooooo00000_oo
ool7o`0000;ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00;ooooo
1_l00002ooooo`05o`000?ooooooooooooooool000007?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
03Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`05ooooo`04onk^k_lQ8B7o
410@onk^kR3ooooo00Co0000oooooooooooo00000_ooool7o`0000;ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooooooo00;ooooo1_l00005ooooo`03o`000?oooooooooo01_o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01Oooool01?o^k^ko8B4Qoa0@4?o^k^hHooooo`005oooool01ol0003oc<c<olc<c?l0003o
ZJVYomgMgOlQ8B402?ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0
2_ooool01Ol0003ooooooooooooooooo000001cooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0foooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Oooool01?lQ8B7oMgMgogMgMolb
<S8Pooooo`07o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8@08ooooo`05o`000?oooooooooooooo
ool000003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
1?lQ8B7oMgMgogMgMolb<S8Hooooo`005_ooool02?l@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003o
ZJVY2?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool02_ooool01Ol@
413ooooooooooooooooo410@01cooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo0000>Oooool00ol0003oooooooooo`0fooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool01?ooool2o`0000;ooooo0_l0000Nooooo`08
oa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJT8ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool2o`0000;o
oooo0_l0000Gooooo`009_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool02_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000>Oooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Kooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027o
oooo000Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00ol0003oooooooooo`0:ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool00ol0003oooooooooo`0;ooooo`03oeEEEOmVIVKo000001gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool003Gooooo
00?o410@o`000?l00000=_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0003Wo
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`05ooooo`;o0000BOooool00ol@413o
0000o`00000eooooo`;o00002_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02?ooool2o`0002?ooooo001^ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo0000>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027o
oooo001^ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0fooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027o
oooo001^ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0eooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0eooooo`;o
00002oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`06ooooo`04o`00
0?ooooooooooo`0003Sooooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool02Oooool2o`0003Sooooo00?o0000oooo
ooooool0=Oooool2o`0000_ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000oooooooo
ool01_ooool01?l0003oooooooooool0000hooooo`03o`000?oooooooooo03Gooooo00Co0000oooo
oooooooo00002?ooool2o`00087ooooo0_l0000:ooooo`;o0000>?ooool00ol0003oooooooooo`0e
ooooo`;o00002_ooool2o`0002?ooooo001^ooooo`03o`000?oooooooooo00Kooooo00Co0000oooo
oooooooo0000>?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`09ooooo`;o0000>?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool006kooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooool0000gooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooool00000=oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08Oooool006kooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0000g
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool00000=oooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool006kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Cooooo00Go0000oooo
ooooooooooooo`000009ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool000002oooool0
0ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool0=?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0=?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo027ooooo001^oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0doooo
o`04o`000?ooooooooooo`0000Wooooo0_l00021ooooo`;o00002oooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo03Cooooo0_l0000;ooooo`;o00008oooool006kooooo00?o0000oooo
ooooool02?ooool01?l0003oooooooooool0000fooooo`03o`000?oooooooooo03?ooooo00Go0000
ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooo`00000fooooo`03o`000?oooooooooo03?ooooo00?o0000ooooool000003?oo
ool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`08ooooo`04o`000?oooooo
ooooo`0003Kooooo00?o0000ooooooooool0<oooool01Ol0003ooooooooooooooooo000000[ooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000003Kooooo
00?o0000ooooooooool0<oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo027ooooo
001^ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000eooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooool00000=Oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooool0000eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000
=Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
8Oooool006kooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000003Cooooo
00?o0000ooooooooool0<Oooool01Ol0003ooooooooooooooooo000000_ooooo0_l00021ooooo`;o
00003?ooool01?l0003oooooooooool0000dooooo`03o`000?oooooooooo037ooooo00Co0000oooo
oooooooo00003?ooool2o`0002?ooooo001^ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool000003?ooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool08Ooo
ool006kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo037ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooo000000kooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool02_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00?o0000ooooooooool0<Oooool01?l0003ooooooooo
ool0000=ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool03?ooool01?l0003ooooo
ooooool0000cooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooo00003_ooool00ol0
003oooooooooo`0Qooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd00oooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo
ooooo`0003?ooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0000>ooooo`03o`00
0?oooooooooo06Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0000c
ooooo`03o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo027ooooo001Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool00_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
<_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
Ioooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`05ogMgMolb<S;ooooooooo
ool000003oooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Qooooo`00EOooool01Ol@413ooooooooooooooooo
410@013ooooo00Go0000ooooooooooooooooo`00000>ooooo`04o`000?ooooooooooo`0003;ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0<ooooo`;o0000JOooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00_l0000>ooooo`04o`000?ooooooooooo`00
03;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0<ooooo`;o00008oooool005Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00;ooooo00?o0000oooo
ooooool03Oooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1Wooooo`05o`000?ooooooooooooooool000003ooo
ool01OmgMgOo<S8boooooooooooo0000013ooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool005Gooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Ioooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0]ooooo`05o`000?oo
ooooooooooooool000004?ooool00ol0003oooooooooo`0Qooooo`00EOooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0;Oooool01Ol0003ooooooooooooooooo0000013o
oooo00?o0000ooooooooool0Ioooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0;Oooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo027ooooo001Eoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0/ooooo`05o`000?oooooo
ooooooooool000004Oooool00ol0003oooooooooo`1Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0/ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003o
ooooooooo`0Qooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00004ooooo`03
o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000^ooooo`03o`000?oooooooooo
02_ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo06Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00000oooool00ol0003oooooooooo`0@ooooo`05o`000?oo
ooooooooooooool00000;_ooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool0
00004_ooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0@ooooo`04o`00
0?ooooooooooo`0002kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`;o
0000POooool2o`0001;ooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo013ooooo0_l0000Sooooo`00K_ooool00ol0003oooooooooo`0@ooooo`05
o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Aooooo`05o`000?oooooooooo
ooooool00000;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool08Oooool006kooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo
000002cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Booooo`05o`000?oooooo
ooooooooool00000;?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08Oooool006kooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo001^ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool09oooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000
ooooooooool08Oooool006kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo
000001Kooooo0_l00021ooooo`;o00005_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01?ooooo0_l0000Sooooo`00K_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool08Oooool006kooooo00?o0000ooooooooool05_ooool2o`0000?o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Sooooo`04o`000?oooooooooooooo
o`;o00006Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo001^ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`05
o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Qooooo`05o`000?ooooooooooooooool000007?ooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo023ooooo00Go0000oooooooo
ooooooooo`00000Looooo`;o0000POooool2o`0001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Hooooo`;o00008oooool006kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo01cooooo
0_l00003ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`02ooooo`;o00007oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo027ooooo
001^ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo01cooooo0_l0000Uooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool01?ooool2o`0001kooooo00?o0000ooooooooool08Oooool006kooooo00?o0000
ooooooooool07oooool2o`0000Cooooo0_l0000Kooooo`03o`000?oooooooooo01[ooooo00Co0000
oooooooooooooooo0_l0000Rooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`05ooooo`;o00006oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Qooooo`00K_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000009?ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo01oooooo0_l00007ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`;o00008Oooool00ol0003ooooooooo
o`0Qooooo`00K_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo0_l0000H
ooooo`03o`000?oooooooooo01Cooooo0_l00006ooooo`03o`000?oooooooooo02;ooooo0_l00021
ooooo`;o00008_ooool00ol0003oooooooooo`05ooooo`;o00006?ooool00ol0003oooooooooo`0D
ooooo`;o00002?ooool00ol0003oooooooooo`0Pooooo`;o00008oooool006kooooo00?o0000oooo
ooooool08oooool2o`0001gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04oooo
o`;o00009_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Qooooo`00K_ooool00ol0003oooooooooo`0Uooooo`?o
00001?ooool3o`0001?ooooo00?o0000ooooooooool04Oooool2o`0000Cooooo0ol0000Xooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool08oooool2o`0000Sooooo0ol0000Cooooo`03
o`000?oooooooooo017ooooo0_l00008ooooo`;o00009Oooool00ol0003oooooooooo`0Qooooo`00
I_ooool4o`000005oa0@4?ooooooooooooooool00000:_ooool2o`0000Gooooo0_l0000Aooooo`03
o`000?oooooooooo00cooooo0_l00007ooooo`;o0000:oooool00ol0003oooooooooo`1hooooo`Co
000000Co410@oooooooooooo00009oooool2o`0000Wooooo0_l0000Aooooo`03o`000?oooooooooo
00cooooo0_l0000;ooooo`;o00009oooool00ol0003oooooooooo`0Qooooo`00J?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02[ooooo0_l00008ooooo`;o00003?ooool00ol0003o
ooooooooo`09ooooo`?o00001oooool2o`0002gooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02oooool2o`0000co
oooo00?o0000ooooooooool02Oooool3o`0000cooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Qooooo`00J?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02cooooo
0_l00008ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`?o00002oooool2o`0002oooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo
0_l0000=ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`?o00004?ooool2o`0002[ooooo
00?o0000ooooooooool08Oooool006Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0^ooooo`?o00002oooool7o`0000?ooooo0_l0000<ooooo`;o0000<?ooool2o`0007cooooo00?o
0000ooooooooool00_ooool2o`0002_ooooo0_l0000Aooooo`Oo00000oooool2o`00017ooooo0_l0
000[ooooo`;o00008oooool006Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0a
ooooo`Co00003Oooool00ol0003oooooooooo`0;ooooo`Co0000<oooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool2o`0001Gooooo00?o0000
ooooooooool04_ooool2o`0002kooooo00?o0000ooooooooool08Oooool006Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0eooooo`Go00002?ooool00ol0003oooooooooo`05oooo
o`Ko0000=oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0;_ooool3o`0001;ooooo00?o0000ooooooooool03oooool3o`00033ooooo00?o0000oooo
ooooool08Oooool006Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0joooooa3o
0000?Oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0<Oooool4o`0000kooooo00?o0000ooooooooool02oooool4o`0003?ooooo00?o0000oooooooo
ool08Oooool006Kooooo00?oEEEEofIVI_l000001Oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0N?ooool00omEEEGoIVIVo`000004ooooo`03o`00
0?oooooooooo03Gooooo0ol0000;ooooo`03o`000?oooooooooo00Sooooo0ol0000gooooo`03o`00
0?oooooooooo027ooooo001^ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo03Sooooo5_l0000jooooo`03o`000?oo
oooooooo027ooooo001^ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@Oooool2
o`00087ooooo0_l00014ooooo`03o`000?oooooooooo047ooooo0_l0000Sooooo`00K_ooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool08Oooool006ko
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo027o
oooo001^ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`0Qooooo`00K_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool08Oooool006koooooRol00021ooooohco00008oooool00?ooooooooooool[oooo
o`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooooooo
ooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo
002`ooooo`Go0000ooooool9ooooo`Go0000Ioooool00;3ooooo0_mgMgL2ooooo`03o`000?oooooo
oooo0?oooooo1oooool2ogMgM`;ooooo00?o0000ooooooooool0IOooool00;7ooooo00?oEEEEoiRH
V?ooool0ooooool;ooooo`03oeEEEOnHV9Sooooo06Sooooo002booooo`03oeEEEOnHV9Sooooo0?oo
oooo2oooool00omEEEGoV9RHooooo`1Wooooo`00/?ooool01Ol0003ooooooooooolb<S;oQhN70?oo
oooo2Oooool01Ol0003ooooooooooolb<S;oQhN706Oooooo002`ooooo`Go0000ooooool9ooooo`Go
0000Ioooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool0
0?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oooooooooo
ool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00
ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooooooooooo
ob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003o
oooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo
:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oo
ooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[
ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooo
ooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_o
oooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooo
oooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:ooo
ool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oooooo
ooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[oooo
o`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00oooooooo
ooooob_ooooo003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo
003ooooooooooooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooo
oooo:oooool00?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool0
0?ooooooooooool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00?oooooooooo
ool[ooooo`00ooooooooooooob_ooooo003ooooooooooooo:oooool00>Gooooo00Co410@o`000?l0
003o0000oooooom1ooooo`00i_ooool00ol0003oooooooooo`3ooooood7ooooo003Vooooo`03o`00
0?oooooooooo0?oooooo@Oooool00;kooooo0_l00002ooooo`05o`000?ooooooooooo`000?l@4100
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00Ko410@ob4Q8Ol0003o0000odA4A?oMgMd3
ooooo`08o`000?mgMgOo0000o`000?mEEEGok^k^ooooool@4102o`000007ooooool0003o0000oa0@
4?ooooook^k^oeEEE@02o`000004odA4A?nj^[[ooooooa0@40Go00001?ooool5o`0000?ooooo00Go
IVIVo`000?l0003oA4A4olc<c002ooooo`06oiRHV?l0003o0000ogMgMol@413o00000_ooool5o`00
00Gooooo00Co410@o`000?l0003ooooo0_l000001?l@413ooooooooooonHV9P2o`000005ogMgMol@
413o0000ooooool@41001Ol00002ooooo`;o00000_ooool01ol0003oooooooooool0003o410@onk^
k_mEEED00_l000001OmEEEGok^k^oooooooooooo410@00;o000000Coooooo`000?l0003o410@0_oo
ool5o`0000?ooooo00GoIVIVo`000?l0003oA4A4olc<c002ooooo`06oa0@4?lb<S;o0000o`000?l@
413oZJVY^oooool00;oooooo00Co0000oooooooooooo00000_ooool7o`0000;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0:ooooo`06o`000?n7QhOooooooooooon7QhOo8B4Q0oooool01_l0003oEEEE
onk^k_ooooooMgMgoeEEE@;ooooo00Go0000ooooooooooooooooo`000002ooooo`06oeEEEOmgMgOo
ooooonk^k_mgMgOo410@0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00KoIVIVogMgMoooooooooooohN7Qol@4102ooooo`05o`000?o<c<cok^k^ohN7Qol000001Oooool0
0ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oc<c<onk^
k_n7QhOo000000Cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooEEEEogMgM`;ooooo00?oMgMgoeEEEOooool00_ooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool00_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@40;ooooo
00Ko0000ojVYZOoooooooooookZj^_l0002kooooo`00_oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00Kooooo00Go410@oooooooooooooooooa0@400:ooooo`06ob4Q8Ooooooo
ooooooooooo^k^ko00000oooool00ol0003ok^k^ooooo`02ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool01Ol@413oQhN7ooooooo^k^ko000000Gooooo00?o0000
ooooooooool01_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@ohN7Qoooooook^k^
o`000004ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Onj^[[oQhN7ofIVI_mVIVKo
410@0;_ooooo002oooooo`04o`000?ooooooooooo`0000;ooooo1ol00002ooooo`05o`000?oooooo
ooooooooool000002oooool01OoMgMgoV9RHogMgMol@413oIVIV00?ooooo00?o0000onk^k_ooool0
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Ko00000oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00onj^[[o
410@o`000002o`0000Gooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o^[Zjoa0@4?l000000_l00004ooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^k[_ooooo002oooooo`07o`000?o<c<coc<c<o`000?nY
ZJWogMgMob4Q8@08ooooo`05o`000?ooooooooooooooool000002_ooool01OmVIVKo410@oeEEEOn7
QhOo^[Zj00Cooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVH2ooooo`05o`000?mgMgOoooooojVY
ZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01ooo
ool00ol0003oooooooooo`02ooooo`06ofIVI_mgMgOooooooooooon7QhOo00001Oooool00oo<c<co
0000ooooo`04ooooo`03o`000?oooooooooo00Kooooo1Ol00006ooooo`03olc<c?l0003ooooo00?o
oooo00?o0000oc8b<_oMgMd01?ooool02_l0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B7ooooooeEE
EOmgMgL2ooooo`03ogMgMomEEEGooooo00;ooooo00Go0000ohN7QoooooooZJVYo`000005ooooo`03
o`000?oooooooooo00;ooooo00KoIVIVogMgMoooooooooooohN7Qol00002ooooo`06o`000?nj^[[o
ooooonk^k_mgMgOo0000^oooool00;kooooo00So410@o`000?lQ8B7o0000ogMgMol@413o0000ojVY
Z@Sooooo00Go410@oooooooooooooooooa0@400:ooooo`06o`000?o^k^koooooooooooo<c<co0000
0_ooool00ol@413o0000ogMgM`02o`000006ofIVI_o^k^koooooooooool0003oMgMg0_l000001OnH
V9Soooooooooooo^k^koEEEE00;o000000CoA4A4onk^k_oooooooooo0_l000001?nYZJWo8B4Qo`00
0?lQ8B43ooooo`03oa0@4?l0003o000000Cooooo00Kok^k^ofIVI_l0003o0000odA4A?l00003oooo
o`04oc8b<_l0003o0000oiRHV0Gooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Co<S8bo`000?l0003oV9RH0oooool2o`00000@ojVYZOlQ8B7o0000ob4Q8Ooo
oooo410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@;o000000OoEEEEonk^
k_oooooooooooa0@4?l0003oMgMg00;o000000GoV9RHoooooooooooooooooa0@4002o`0000Cooooo
00Kok^k^ofIVI_l0003o0000odA4A?l00002ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o0000^ooo
ool00<kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`06oc8b<_n7QhOoooooonk^k_mVIVKo
00002oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooo
ooooooooo`00003looooo`00c_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00Kok^k^odA4
A?l0003o0000oc8b<_l@410;ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`05ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
:oooool00ol0003oooooooooo`3;ooooo`00kOooool00ol@413o0000ooooo`0Hooooo`03oa0@4?oo
oooooooo01;ooooo00?o410@o`000?l00000>oooool00ol@413oooooooooo`3;ooooo`00oooooooo
ooooob_ooooo003ooooooooooooo:oooool00001\
\>"],
  ImageRangeCache->{{{0, 552.938}, {843.125, 0}} -> {-0.0770916, -0.0762067, \
0.00486987, 0.00486987}, {{19.75, 264.188}, {823.562, 579.062}} -> {-3.10981, \
-2.41461, 0.0217026, 0.0217026}, {{288.688, 533.125}, {823.562, 579.062}} -> \
{-7.77912, -2.41461, 0.0217026, 0.0217026}, {{19.75, 264.188}, {554.625, \
310.188}} -> {-3.10981, -7.08338, 0.0217026, 0.0217026}, {{288.688, 533.125}, \
{554.625, 310.188}} -> {-7.77912, -7.08338, 0.0217026, 0.0217026}, {{19.75, \
264.188}, {285.75, 41.25}} -> {-3.10981, -11.7522, 0.0217026, 0.0217026}, \
{{288.688, 533.125}, {285.75, 41.25}} -> {-7.77912, -11.7522, 0.0217026, \
0.0217026}}]
}, Open  ]],

Cell[TextData[{
  "One can see that the ",
  Cell[BoxData[
      \(TraditionalForm\`l = 0, m = 0\)]],
  " harmonic corresponds to a spherically-symmetric expansion (or \
contraction) of the surface; the ",
  Cell[BoxData[
      \(TraditionalForm\`l = 1, m = 0\)]],
  " harmonic is a displacement of the sphere along the ",
  StyleBox["z",
    FontSlant->"Italic"],
  "-axis; the ",
  Cell[BoxData[
      \(TraditionalForm\`l = 2, m = 0\)]],
  " harmonic is an elliptical distortion of the surface; and higher-order \
harmonics correspond to more complicated distortions. The higher-order \
distortions have the appearance of sinusoidal oscillations along the surface \
of the sphere. As one travels from pole to pole along the sphere, the number \
of times each oscillation passes through zero equals ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\)\(\[NotEqual]\)\(\ \)\(0\)\(\ \)\)\)]],
  "spherical harmonics are similar to the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\)\(=\)\(0\)\(\ \)\)\)]],
  "harmonics with the same ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " , except that the distortions are tilted away from the ",
  StyleBox["z-",
    FontSlant->"Italic"],
  "axis. For a given value of ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", larger ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " corresponds to a smaller tilt. For ",
  Cell[BoxData[
      \(TraditionalForm\`l = \(\(|\)\(m\)\(|\)\)\)]],
  ", the tilt is ",
  Cell[BoxData[
      \(TraditionalForm\`90\ \[Degree]\)]],
  ", that is, the maximum distortion is in the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-",
  StyleBox["y",
    FontSlant->"Italic"],
  " plane. In Fig. ",
  ButtonBox["3.12",
    ButtonData:>"Fig. 3.12",
    ButtonStyle->"Hyperlink"],
  " are some pictures of the real part of the ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1\)]],
  " modes. The reader is invited to modify the commands in Cell ",
  ButtonBox["3.21",
    ButtonData:>"Cell 3.21",
    ButtonStyle->"Hyperlink"],
  " and display other modes. "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.416667 0.5 0.416667 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.29167 -0.0125 -12 -9 ]
[.29167 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70833 -0.0125 -9 -9 ]
[.70833 -0.0125 9 0 ]
[.91667 -0.0125 -3 -9 ]
[.91667 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .29167 -24 -4.5 ]
[-0.0125 .29167 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .70833 -18 -4.5 ]
[-0.0125 .70833 0 4.5 ]
[-0.0125 .91667 -6 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -70.125 -6 ]
[-0.01875 .5 -24 6 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-1)] .08333 -0.0125 0 1 Mshowa
.29167 0 m
.29167 .00625 L
s
[(-0.5)] .29167 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70833 0 m
.70833 .00625 L
s
[(0.5)] .70833 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(1)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.125 0 m
.125 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.875 0 m
.875 .00375 L
s
.04167 0 m
.04167 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(-1)] -0.0125 .08333 1 0 Mshowa
0 .29167 m
.00625 .29167 L
s
[(-0.5)] -0.0125 .29167 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .70833 m
.00625 .70833 L
s
[(0.5)] -0.0125 .70833 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(1)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .125 m
.00375 .125 L
s
0 .16667 m
.00375 .16667 L
s
0 .20833 m
.00375 .20833 L
s
0 .25 m
.00375 .25 L
s
0 .33333 m
.00375 .33333 L
s
0 .375 m
.00375 .375 L
s
0 .41667 m
.00375 .41667 L
s
0 .45833 m
.00375 .45833 L
s
0 .54167 m
.00375 .54167 L
s
0 .58333 m
.00375 .58333 L
s
0 .625 m
.00375 .625 L
s
0 .66667 m
.00375 .66667 L
s
0 .75 m
.00375 .75 L
s
0 .79167 m
.00375 .79167 L
s
0 .83333 m
.00375 .83333 L
s
0 .875 m
.00375 .875 L
s
0 .04167 m
.00375 .04167 L
s
0 .95833 m
.00375 .95833 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -131.125 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
93.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
105.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.29167 .99375 m
.29167 1 L
s
.5 .99375 m
.5 1 L
s
.70833 .99375 m
.70833 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.125 .99625 m
.125 1 L
s
.16667 .99625 m
.16667 1 L
s
.20833 .99625 m
.20833 1 L
s
.25 .99625 m
.25 1 L
s
.33333 .99625 m
.33333 1 L
s
.375 .99625 m
.375 1 L
s
.41667 .99625 m
.41667 1 L
s
.45833 .99625 m
.45833 1 L
s
.54167 .99625 m
.54167 1 L
s
.58333 .99625 m
.58333 1 L
s
.625 .99625 m
.625 1 L
s
.66667 .99625 m
.66667 1 L
s
.75 .99625 m
.75 1 L
s
.79167 .99625 m
.79167 1 L
s
.83333 .99625 m
.83333 1 L
s
.875 .99625 m
.875 1 L
s
.04167 .99625 m
.04167 1 L
s
.95833 .99625 m
.95833 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .29167 m
1 .29167 L
s
.99375 .5 m
1 .5 L
s
.99375 .70833 m
1 .70833 L
s
.99375 .91667 m
1 .91667 L
s
.125 Mabswid
.99625 .125 m
1 .125 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .20833 m
1 .20833 L
s
.99625 .25 m
1 .25 L
s
.99625 .33333 m
1 .33333 L
s
.99625 .375 m
1 .375 L
s
.99625 .41667 m
1 .41667 L
s
.99625 .45833 m
1 .45833 L
s
.99625 .54167 m
1 .54167 L
s
.99625 .58333 m
1 .58333 L
s
.99625 .625 m
1 .625 L
s
.99625 .66667 m
1 .66667 L
s
.99625 .75 m
1 .75 L
s
.99625 .79167 m
1 .79167 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .875 m
1 .875 L
s
.99625 .04167 m
1 .04167 L
s
.99625 .95833 m
1 .95833 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ .03 .03 ] 0 setdash
.5 .91667 m
.50323 .91665 L
.50617 .91662 L
.50956 .91656 L
.51277 .91647 L
.51847 .91626 L
.52466 .91594 L
.53147 .91548 L
.53867 .91487 L
.55157 .91346 L
.56483 .91159 L
.57719 .90945 L
.60506 .9032 L
.63298 .89488 L
.65795 .88557 L
.71167 .8589 L
.75485 .82964 L
.7974 .79183 L
.83267 .75089 L
.86409 .70261 L
.87699 .67745 L
.88899 .64933 L
.89767 .62437 L
.90536 .5964 L
.90831 .58304 L
.91098 .56862 L
.91287 .55609 L
.9145 .5424 L
.91525 .53435 L
.9158 .5269 L
.9162 .51976 L
.91635 .51616 L
.91649 .51218 L
.91658 .50861 L
.91663 .50533 L
.91666 .50173 L
.91667 .49992 L
.91666 .49794 L
.91663 .49459 L
.91657 .49101 L
.91648 .48764 L
.91638 .48457 L
.9161 .47823 L
.91567 .47126 L
.91446 .4572 L
.91292 .44423 L
.9111 .43213 L
.90572 .40511 L
.89796 .37654 L
.88882 .35024 L
Mistroke
.87689 .32233 L
.85009 .27406 L
.81783 .23056 L
.7776 .18928 L
.731 .15323 L
.68292 .12563 L
.65838 .11461 L
.63177 .10472 L
.60629 .09712 L
.5827 .09162 L
.55695 .08724 L
.54269 .08553 L
.53612 .0849 L
.52914 .08435 L
.52318 .08398 L
.52001 .08381 L
.5166 .08366 L
.51347 .08355 L
.51061 .08347 L
.50787 .08341 L
.50499 .08336 L
.50184 .08334 L
.49849 .08334 L
.49532 .08336 L
.49244 .0834 L
.48906 .08348 L
.48539 .08359 L
.47874 .08388 L
.47225 .08426 L
.46529 .08478 L
.45275 .08602 L
.43789 .08799 L
.42441 .09025 L
.39541 .09667 L
.3684 .10466 L
.31782 .12527 L
.27375 .15011 L
.23254 .18051 L
.19173 .21968 L
.15859 .26114 L
.12907 .31021 L
.10731 .3607 L
.09893 .38708 L
.09499 .40215 L
.09178 .41651 L
.08929 .42981 L
.08707 .44431 L
.0855 .45755 L
.08443 .46981 L
.08399 .47667 L
Mistroke
.08368 .4831 L
.08354 .48678 L
.08345 .49015 L
.08341 .49201 L
.08338 .49404 L
.08335 .49596 L
.08334 .49774 L
.08333 .4996 L
.08334 .50161 L
.08335 .50351 L
.08337 .50526 L
.08342 .50858 L
.08351 .51208 L
.08363 .51584 L
.08378 .51936 L
.08423 .52733 L
.08476 .53447 L
.08536 .54107 L
.08711 .55594 L
.08909 .569 L
.09164 .58279 L
.09715 .60641 L
.10481 .63205 L
.12485 .68131 L
.15328 .73107 L
.18679 .77479 L
.22796 .8156 L
.27128 .84828 L
.31507 .87338 L
.34145 .88532 L
.36703 .89488 L
.39079 .9021 L
.41635 .90818 L
.4369 .91186 L
.44865 .91349 L
.45967 .91471 L
.46981 .91557 L
.47909 .91614 L
.48422 .91637 L
.48693 .91646 L
.48982 .91654 L
.49259 .9166 L
.4951 .91664 L
.49763 .91666 L
.5 .91667 L
Mfstroke
[ ] 0 setdash
.5 .91667 m
.55125 .89998 L
.60288 .87697 L
.648 .85303 L
.68946 .82899 L
.73275 .8023 L
.77422 .77458 L
.81772 .7412 L
.85753 .70357 L
.89155 .66136 L
.90661 .63722 L
.9202 .61002 L
.93028 .58349 L
.93728 .55774 L
.94013 .54285 L
.94123 .53545 L
.94206 .52855 L
.94266 .52231 L
.94314 .51564 L
.94334 .51183 L
.94341 .50995 L
.94347 .50823 L
.94351 .50669 L
.94355 .505 L
.94358 .5033 L
.94359 .5015 L
.9436 .4996 L
.94359 .49783 L
.94358 .49691 L
.94357 .49589 L
.94355 .49483 L
.94353 .49384 L
.94342 .49034 L
.94334 .48838 L
.94326 .48658 L
.94284 .47996 L
.94223 .47301 L
.94135 .46549 L
.94035 .45852 L
.93741 .44283 L
.93372 .42793 L
.92949 .41408 L
.91972 .3889 L
.90676 .36305 L
.89283 .34052 L
.8581 .29704 L
.82045 .26111 L
.7782 .22825 L
.73692 .20037 L
.69285 .17304 L
Mistroke
.6496 .14787 L
.60614 .12465 L
.55661 .10214 L
.50502 .08467 L
.5 .08333 L
Mfstroke
.5 .91667 m
.48757 .91967 L
.47375 .9225 L
.45913 .9249 L
.44534 .92659 L
.43737 .92731 L
.43345 .9276 L
.42981 .92782 L
.42658 .92798 L
.423 .92812 L
.42127 .92817 L
.41941 .92822 L
.41838 .92824 L
.41744 .92826 L
.41559 .92829 L
.41455 .92829 L
.41362 .9283 L
.41253 .9283 L
.41151 .9283 L
.4097 .92829 L
.40867 .92828 L
.40773 .92827 L
.40574 .92824 L
.40355 .92818 L
.40127 .92811 L
.39914 .92803 L
.39158 .92761 L
.38734 .9273 L
.38347 .92696 L
.36887 .92521 L
.35543 .92293 L
.34079 .91968 L
.32542 .91538 L
.29815 .90528 L
.27363 .89318 L
.24812 .87703 L
.22644 .85984 L
.20457 .83839 L
.18643 .81651 L
.15692 .76868 L
.1447 .74145 L
.13566 .71621 L
.1282 .68993 L
.12203 .66145 L
.11771 .63442 L
.116 .62075 L
.1145 .60615 L
.11335 .59256 L
.1125 .58022 L
.11185 .56858 L
Mistroke
.1113 .55625 L
.11087 .54344 L
.11058 .5316 L
.11045 .52437 L
.1104 .52083 L
.11036 .51758 L
.11033 .51467 L
.11031 .51148 L
.11029 .50828 L
.11028 .50653 L
.11027 .5049 L
.11027 .50327 L
.11027 .50245 L
.11027 .50154 L
.11027 .49994 L
.11027 .49844 L
.11027 .49758 L
.11027 .49668 L
.11027 .49506 L
.11028 .49333 L
.11029 .49143 L
.11031 .48823 L
.11034 .48482 L
.11041 .47867 L
.11051 .47221 L
.11063 .46611 L
.11092 .45468 L
.11137 .44202 L
.112 .42855 L
.1136 .40421 L
.11471 .39161 L
.11615 .37801 L
.11951 .35323 L
.1249 .32426 L
.13177 .29668 L
.14052 .26954 L
.15054 .24476 L
.16384 .21826 L
.17862 .19439 L
.21448 .15131 L
.23701 .13134 L
.25952 .11526 L
.2841 .10128 L
.31249 .089 L
.34043 .08041 L
.35638 .07689 L
.36347 .07563 L
.37101 .07449 L
.378 .07361 L
.3857 .07284 L
Mistroke
.38908 .07257 L
.39271 .07231 L
.39611 .07212 L
.39927 .07197 L
.4032 .07183 L
.40527 .07177 L
.40633 .07175 L
.40748 .07173 L
.40858 .07172 L
.40959 .07171 L
.41055 .0717 L
.41157 .0717 L
.41334 .0717 L
.41527 .07171 L
.41718 .07174 L
.41892 .07177 L
.42092 .07182 L
.42282 .07187 L
.42618 .072 L
.42984 .07218 L
.43692 .07265 L
.44355 .07323 L
.45853 .07501 L
.47295 .07735 L
.48827 .08049 L
.5 .08333 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.416667 0.5 0.416667 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.29167 -0.0125 -12 -9 ]
[.29167 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70833 -0.0125 -9 -9 ]
[.70833 -0.0125 9 0 ]
[.91667 -0.0125 -3 -9 ]
[.91667 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .29167 -24 -4.5 ]
[-0.0125 .29167 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .70833 -18 -4.5 ]
[-0.0125 .70833 0 4.5 ]
[-0.0125 .91667 -6 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -70.125 -6 ]
[-0.01875 .5 -24 6 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-1)] .08333 -0.0125 0 1 Mshowa
.29167 0 m
.29167 .00625 L
s
[(-0.5)] .29167 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70833 0 m
.70833 .00625 L
s
[(0.5)] .70833 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(1)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.125 0 m
.125 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.875 0 m
.875 .00375 L
s
.04167 0 m
.04167 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(-1)] -0.0125 .08333 1 0 Mshowa
0 .29167 m
.00625 .29167 L
s
[(-0.5)] -0.0125 .29167 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .70833 m
.00625 .70833 L
s
[(0.5)] -0.0125 .70833 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(1)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .125 m
.00375 .125 L
s
0 .16667 m
.00375 .16667 L
s
0 .20833 m
.00375 .20833 L
s
0 .25 m
.00375 .25 L
s
0 .33333 m
.00375 .33333 L
s
0 .375 m
.00375 .375 L
s
0 .41667 m
.00375 .41667 L
s
0 .45833 m
.00375 .45833 L
s
0 .54167 m
.00375 .54167 L
s
0 .58333 m
.00375 .58333 L
s
0 .625 m
.00375 .625 L
s
0 .66667 m
.00375 .66667 L
s
0 .75 m
.00375 .75 L
s
0 .79167 m
.00375 .79167 L
s
0 .83333 m
.00375 .83333 L
s
0 .875 m
.00375 .875 L
s
0 .04167 m
.00375 .04167 L
s
0 .95833 m
.00375 .95833 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -131.125 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
93.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
105.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.29167 .99375 m
.29167 1 L
s
.5 .99375 m
.5 1 L
s
.70833 .99375 m
.70833 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.125 .99625 m
.125 1 L
s
.16667 .99625 m
.16667 1 L
s
.20833 .99625 m
.20833 1 L
s
.25 .99625 m
.25 1 L
s
.33333 .99625 m
.33333 1 L
s
.375 .99625 m
.375 1 L
s
.41667 .99625 m
.41667 1 L
s
.45833 .99625 m
.45833 1 L
s
.54167 .99625 m
.54167 1 L
s
.58333 .99625 m
.58333 1 L
s
.625 .99625 m
.625 1 L
s
.66667 .99625 m
.66667 1 L
s
.75 .99625 m
.75 1 L
s
.79167 .99625 m
.79167 1 L
s
.83333 .99625 m
.83333 1 L
s
.875 .99625 m
.875 1 L
s
.04167 .99625 m
.04167 1 L
s
.95833 .99625 m
.95833 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .29167 m
1 .29167 L
s
.99375 .5 m
1 .5 L
s
.99375 .70833 m
1 .70833 L
s
.99375 .91667 m
1 .91667 L
s
.125 Mabswid
.99625 .125 m
1 .125 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .20833 m
1 .20833 L
s
.99625 .25 m
1 .25 L
s
.99625 .33333 m
1 .33333 L
s
.99625 .375 m
1 .375 L
s
.99625 .41667 m
1 .41667 L
s
.99625 .45833 m
1 .45833 L
s
.99625 .54167 m
1 .54167 L
s
.99625 .58333 m
1 .58333 L
s
.99625 .625 m
1 .625 L
s
.99625 .66667 m
1 .66667 L
s
.99625 .75 m
1 .75 L
s
.99625 .79167 m
1 .79167 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .875 m
1 .875 L
s
.99625 .04167 m
1 .04167 L
s
.99625 .95833 m
1 .95833 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ .03 .03 ] 0 setdash
.5 .91667 m
.50323 .91665 L
.50617 .91662 L
.50956 .91656 L
.51277 .91647 L
.51847 .91626 L
.52466 .91594 L
.53147 .91548 L
.53867 .91487 L
.55157 .91346 L
.56483 .91159 L
.57719 .90945 L
.60506 .9032 L
.63298 .89488 L
.65795 .88557 L
.71167 .8589 L
.75485 .82964 L
.7974 .79183 L
.83267 .75089 L
.86409 .70261 L
.87699 .67745 L
.88899 .64933 L
.89767 .62437 L
.90536 .5964 L
.90831 .58304 L
.91098 .56862 L
.91287 .55609 L
.9145 .5424 L
.91525 .53435 L
.9158 .5269 L
.9162 .51976 L
.91635 .51616 L
.91649 .51218 L
.91658 .50861 L
.91663 .50533 L
.91666 .50173 L
.91667 .49992 L
.91666 .49794 L
.91663 .49459 L
.91657 .49101 L
.91648 .48764 L
.91638 .48457 L
.9161 .47823 L
.91567 .47126 L
.91446 .4572 L
.91292 .44423 L
.9111 .43213 L
.90572 .40511 L
.89796 .37654 L
.88882 .35024 L
Mistroke
.87689 .32233 L
.85009 .27406 L
.81783 .23056 L
.7776 .18928 L
.731 .15323 L
.68292 .12563 L
.65838 .11461 L
.63177 .10472 L
.60629 .09712 L
.5827 .09162 L
.55695 .08724 L
.54269 .08553 L
.53612 .0849 L
.52914 .08435 L
.52318 .08398 L
.52001 .08381 L
.5166 .08366 L
.51347 .08355 L
.51061 .08347 L
.50787 .08341 L
.50499 .08336 L
.50184 .08334 L
.49849 .08334 L
.49532 .08336 L
.49244 .0834 L
.48906 .08348 L
.48539 .08359 L
.47874 .08388 L
.47225 .08426 L
.46529 .08478 L
.45275 .08602 L
.43789 .08799 L
.42441 .09025 L
.39541 .09667 L
.3684 .10466 L
.31782 .12527 L
.27375 .15011 L
.23254 .18051 L
.19173 .21968 L
.15859 .26114 L
.12907 .31021 L
.10731 .3607 L
.09893 .38708 L
.09499 .40215 L
.09178 .41651 L
.08929 .42981 L
.08707 .44431 L
.0855 .45755 L
.08443 .46981 L
.08399 .47667 L
Mistroke
.08368 .4831 L
.08354 .48678 L
.08345 .49015 L
.08341 .49201 L
.08338 .49404 L
.08335 .49596 L
.08334 .49774 L
.08333 .4996 L
.08334 .50161 L
.08335 .50351 L
.08337 .50526 L
.08342 .50858 L
.08351 .51208 L
.08363 .51584 L
.08378 .51936 L
.08423 .52733 L
.08476 .53447 L
.08536 .54107 L
.08711 .55594 L
.08909 .569 L
.09164 .58279 L
.09715 .60641 L
.10481 .63205 L
.12485 .68131 L
.15328 .73107 L
.18679 .77479 L
.22796 .8156 L
.27128 .84828 L
.31507 .87338 L
.34145 .88532 L
.36703 .89488 L
.39079 .9021 L
.41635 .90818 L
.4369 .91186 L
.44865 .91349 L
.45967 .91471 L
.46981 .91557 L
.47909 .91614 L
.48422 .91637 L
.48693 .91646 L
.48982 .91654 L
.49259 .9166 L
.4951 .91664 L
.49763 .91666 L
.5 .91667 L
Mfstroke
[ ] 0 setdash
.5 .91667 m
.5505 .89413 L
.60044 .86801 L
.64504 .84597 L
.68874 .82773 L
.73797 .80909 L
.78741 .78778 L
.81243 .77429 L
.83854 .757 L
.86183 .73749 L
.88103 .71696 L
.89712 .6947 L
.905 .68101 L
.91127 .668 L
.91631 .65537 L
.92085 .64123 L
.9229 .63336 L
.92453 .62598 L
.92594 .61834 L
.92699 .61126 L
.92783 .60387 L
.92818 .59997 L
.92847 .59584 L
.92867 .59224 L
.9288 .58889 L
.92885 .58696 L
.92889 .5852 L
.9289 .58423 L
.92891 .58317 L
.92892 .58125 L
.92891 .57957 L
.9289 .57799 L
.92887 .57625 L
.92882 .57439 L
.92876 .57253 L
.92869 .57058 L
.92851 .5671 L
.92808 .56087 L
.92744 .55407 L
.92652 .54642 L
.92546 .53923 L
.92303 .5259 L
.91571 .49669 L
.89793 .44601 L
.87716 .39569 L
.85855 .34849 L
.84221 .30188 L
.82393 .24971 L
.80149 .19819 L
.78586 .17078 L
Mistroke
.7683 .14612 L
.74821 .12383 L
.72716 .1056 L
.70111 .08865 L
.67558 .07684 L
.66119 .07197 L
.64767 .06845 L
.63989 .06687 L
.63258 .06565 L
.62491 .06466 L
.62053 .06422 L
.61647 .06389 L
.61278 .06365 L
.60887 .06347 L
.60684 .06341 L
.60493 .06336 L
.60384 .06334 L
.60284 .06333 L
.60175 .06332 L
.60059 .06332 L
.59879 .06332 L
.59687 .06334 L
.59506 .06338 L
.59341 .06342 L
.59147 .06349 L
.58937 .06358 L
.58557 .06379 L
.57847 .06435 L
.57099 .06515 L
.55767 .06714 L
.54369 .06997 L
.52893 .07375 L
.50305 .08219 L
.5 .08333 L
Mfstroke
.5 .91667 m
.47357 .92554 L
.45969 .92923 L
.44459 .93245 L
.43646 .93382 L
.42903 .93484 L
.42152 .93566 L
.41813 .93595 L
.4144 .93621 L
.41036 .93643 L
.40815 .93652 L
.40608 .93659 L
.40415 .93664 L
.40238 .93667 L
.4014 .93668 L
.40033 .93668 L
.39839 .93668 L
.39721 .93667 L
.3961 .93666 L
.39511 .93664 L
.39403 .93662 L
.39161 .93654 L
.38938 .93646 L
.38531 .93623 L
.38103 .93592 L
.37355 .93516 L
.36677 .93425 L
.35165 .93139 L
.33788 .92775 L
.32511 .92342 L
.29783 .91077 L
.27446 .89562 L
.25296 .87731 L
.232 .85426 L
.2137 .82852 L
.19946 .80364 L
.17684 .75232 L
.15875 .70095 L
.14235 .65396 L
.12327 .60536 L
.10345 .55746 L
.09366 .53185 L
.08417 .50292 L
.08037 .48895 L
.07693 .4739 L
.07455 .46086 L
.07353 .45394 L
.0726 .44635 L
.0722 .44242 L
.07189 .43876 L
Mistroke
.07161 .43498 L
.07141 .43154 L
.07126 .42815 L
.07121 .4266 L
.07116 .42496 L
.07112 .4232 L
.0711 .42159 L
.07108 .41985 L
.07108 .41794 L
.07109 .41696 L
.0711 .41588 L
.07111 .41487 L
.07113 .41394 L
.07117 .41217 L
.07123 .41029 L
.0714 .40639 L
.07166 .4021 L
.07195 .39844 L
.07233 .3945 L
.07319 .3874 L
.07557 .37353 L
.07731 .36575 L
.0792 .3586 L
.08412 .34345 L
.08982 .32956 L
.10422 .3032 L
.12044 .28127 L
.14081 .26005 L
.16165 .24286 L
.21026 .21337 L
.25841 .19232 L
.30772 .17363 L
.3525 .15514 L
.39908 .13224 L
.4461 .10759 L
.49578 .08496 L
.5 .08333 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.416667 0.5 0.416667 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.29167 -0.0125 -12 -9 ]
[.29167 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70833 -0.0125 -9 -9 ]
[.70833 -0.0125 9 0 ]
[.91667 -0.0125 -3 -9 ]
[.91667 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .29167 -24 -4.5 ]
[-0.0125 .29167 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .70833 -18 -4.5 ]
[-0.0125 .70833 0 4.5 ]
[-0.0125 .91667 -6 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -70.125 -6 ]
[-0.01875 .5 -24 6 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-1)] .08333 -0.0125 0 1 Mshowa
.29167 0 m
.29167 .00625 L
s
[(-0.5)] .29167 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70833 0 m
.70833 .00625 L
s
[(0.5)] .70833 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(1)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.125 0 m
.125 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.875 0 m
.875 .00375 L
s
.04167 0 m
.04167 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(-1)] -0.0125 .08333 1 0 Mshowa
0 .29167 m
.00625 .29167 L
s
[(-0.5)] -0.0125 .29167 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .70833 m
.00625 .70833 L
s
[(0.5)] -0.0125 .70833 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(1)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .125 m
.00375 .125 L
s
0 .16667 m
.00375 .16667 L
s
0 .20833 m
.00375 .20833 L
s
0 .25 m
.00375 .25 L
s
0 .33333 m
.00375 .33333 L
s
0 .375 m
.00375 .375 L
s
0 .41667 m
.00375 .41667 L
s
0 .45833 m
.00375 .45833 L
s
0 .54167 m
.00375 .54167 L
s
0 .58333 m
.00375 .58333 L
s
0 .625 m
.00375 .625 L
s
0 .66667 m
.00375 .66667 L
s
0 .75 m
.00375 .75 L
s
0 .79167 m
.00375 .79167 L
s
0 .83333 m
.00375 .83333 L
s
0 .875 m
.00375 .875 L
s
0 .04167 m
.00375 .04167 L
s
0 .95833 m
.00375 .95833 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -131.125 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
93.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
105.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.29167 .99375 m
.29167 1 L
s
.5 .99375 m
.5 1 L
s
.70833 .99375 m
.70833 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.125 .99625 m
.125 1 L
s
.16667 .99625 m
.16667 1 L
s
.20833 .99625 m
.20833 1 L
s
.25 .99625 m
.25 1 L
s
.33333 .99625 m
.33333 1 L
s
.375 .99625 m
.375 1 L
s
.41667 .99625 m
.41667 1 L
s
.45833 .99625 m
.45833 1 L
s
.54167 .99625 m
.54167 1 L
s
.58333 .99625 m
.58333 1 L
s
.625 .99625 m
.625 1 L
s
.66667 .99625 m
.66667 1 L
s
.75 .99625 m
.75 1 L
s
.79167 .99625 m
.79167 1 L
s
.83333 .99625 m
.83333 1 L
s
.875 .99625 m
.875 1 L
s
.04167 .99625 m
.04167 1 L
s
.95833 .99625 m
.95833 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .29167 m
1 .29167 L
s
.99375 .5 m
1 .5 L
s
.99375 .70833 m
1 .70833 L
s
.99375 .91667 m
1 .91667 L
s
.125 Mabswid
.99625 .125 m
1 .125 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .20833 m
1 .20833 L
s
.99625 .25 m
1 .25 L
s
.99625 .33333 m
1 .33333 L
s
.99625 .375 m
1 .375 L
s
.99625 .41667 m
1 .41667 L
s
.99625 .45833 m
1 .45833 L
s
.99625 .54167 m
1 .54167 L
s
.99625 .58333 m
1 .58333 L
s
.99625 .625 m
1 .625 L
s
.99625 .66667 m
1 .66667 L
s
.99625 .75 m
1 .75 L
s
.99625 .79167 m
1 .79167 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .875 m
1 .875 L
s
.99625 .04167 m
1 .04167 L
s
.99625 .95833 m
1 .95833 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ .03 .03 ] 0 setdash
.5 .91667 m
.50323 .91665 L
.50617 .91662 L
.50956 .91656 L
.51277 .91647 L
.51847 .91626 L
.52466 .91594 L
.53147 .91548 L
.53867 .91487 L
.55157 .91346 L
.56483 .91159 L
.57719 .90945 L
.60506 .9032 L
.63298 .89488 L
.65795 .88557 L
.71167 .8589 L
.75485 .82964 L
.7974 .79183 L
.83267 .75089 L
.86409 .70261 L
.87699 .67745 L
.88899 .64933 L
.89767 .62437 L
.90536 .5964 L
.90831 .58304 L
.91098 .56862 L
.91287 .55609 L
.9145 .5424 L
.91525 .53435 L
.9158 .5269 L
.9162 .51976 L
.91635 .51616 L
.91649 .51218 L
.91658 .50861 L
.91663 .50533 L
.91666 .50173 L
.91667 .49992 L
.91666 .49794 L
.91663 .49459 L
.91657 .49101 L
.91648 .48764 L
.91638 .48457 L
.9161 .47823 L
.91567 .47126 L
.91446 .4572 L
.91292 .44423 L
.9111 .43213 L
.90572 .40511 L
.89796 .37654 L
.88882 .35024 L
Mistroke
.87689 .32233 L
.85009 .27406 L
.81783 .23056 L
.7776 .18928 L
.731 .15323 L
.68292 .12563 L
.65838 .11461 L
.63177 .10472 L
.60629 .09712 L
.5827 .09162 L
.55695 .08724 L
.54269 .08553 L
.53612 .0849 L
.52914 .08435 L
.52318 .08398 L
.52001 .08381 L
.5166 .08366 L
.51347 .08355 L
.51061 .08347 L
.50787 .08341 L
.50499 .08336 L
.50184 .08334 L
.49849 .08334 L
.49532 .08336 L
.49244 .0834 L
.48906 .08348 L
.48539 .08359 L
.47874 .08388 L
.47225 .08426 L
.46529 .08478 L
.45275 .08602 L
.43789 .08799 L
.42441 .09025 L
.39541 .09667 L
.3684 .10466 L
.31782 .12527 L
.27375 .15011 L
.23254 .18051 L
.19173 .21968 L
.15859 .26114 L
.12907 .31021 L
.10731 .3607 L
.09893 .38708 L
.09499 .40215 L
.09178 .41651 L
.08929 .42981 L
.08707 .44431 L
.0855 .45755 L
.08443 .46981 L
.08399 .47667 L
Mistroke
.08368 .4831 L
.08354 .48678 L
.08345 .49015 L
.08341 .49201 L
.08338 .49404 L
.08335 .49596 L
.08334 .49774 L
.08333 .4996 L
.08334 .50161 L
.08335 .50351 L
.08337 .50526 L
.08342 .50858 L
.08351 .51208 L
.08363 .51584 L
.08378 .51936 L
.08423 .52733 L
.08476 .53447 L
.08536 .54107 L
.08711 .55594 L
.08909 .569 L
.09164 .58279 L
.09715 .60641 L
.10481 .63205 L
.12485 .68131 L
.15328 .73107 L
.18679 .77479 L
.22796 .8156 L
.27128 .84828 L
.31507 .87338 L
.34145 .88532 L
.36703 .89488 L
.39079 .9021 L
.41635 .90818 L
.4369 .91186 L
.44865 .91349 L
.45967 .91471 L
.46981 .91557 L
.47909 .91614 L
.48422 .91637 L
.48693 .91646 L
.48982 .91654 L
.49259 .9166 L
.4951 .91664 L
.49763 .91666 L
.5 .91667 L
Mfstroke
[ ] 0 setdash
.5 .91667 m
.51231 .91563 L
.52572 .91408 L
.53963 .91201 L
.55249 .90966 L
.5795 .90334 L
.60771 .89465 L
.65903 .87287 L
.7049 .84585 L
.74512 .8148 L
.78314 .77698 L
.81466 .73654 L
.83994 .69455 L
.85178 .6701 L
.86118 .64716 L
.86951 .62269 L
.87587 .59959 L
.88096 .57579 L
.88322 .56231 L
.88493 .54955 L
.88624 .537 L
.88681 .52991 L
.88722 .52339 L
.88749 .51788 L
.88762 .51471 L
.88771 .51182 L
.88778 .50877 L
.88782 .50709 L
.88784 .5055 L
.88786 .50403 L
.88787 .50267 L
.88787 .50118 L
.88788 .49959 L
.88787 .49814 L
.88786 .49654 L
.88784 .49488 L
.88782 .49334 L
.88777 .49057 L
.88769 .4876 L
.88757 .48412 L
.88744 .48084 L
.88711 .47469 L
.88628 .4635 L
.88505 .45139 L
.88347 .43937 L
.88133 .42621 L
.87572 .39983 L
.86903 .37577 L
.86025 .35039 L
.83811 .30199 L
Mistroke
.81098 .25818 L
.77978 .21927 L
.74145 .18203 L
.69999 .15087 L
.65164 .12348 L
.62591 .11215 L
.60153 .10326 L
.57758 .09615 L
.55076 .09 L
.5382 .08776 L
.52465 .08578 L
.51178 .08432 L
.5 .08333 L
Mfstroke
.5 .91667 m
.49361 .91706 L
.48764 .91734 L
.48421 .91746 L
.48108 .91754 L
.47935 .91758 L
.47747 .91761 L
.4757 .91763 L
.47406 .91765 L
.47248 .91765 L
.47078 .91766 L
.46918 .91765 L
.46772 .91764 L
.466 .91762 L
.46413 .91759 L
.46073 .91752 L
.45718 .91741 L
.45339 .91727 L
.44658 .91692 L
.43899 .9164 L
.43079 .91567 L
.41594 .91395 L
.40152 .91175 L
.3883 .90928 L
.36256 .90317 L
.33472 .89457 L
.28199 .87205 L
.23429 .84351 L
.18794 .80623 L
.14853 .76417 L
.11629 .71873 L
.10232 .69414 L
.08885 .66592 L
.07795 .63799 L
.06973 .61172 L
.06309 .58413 L
.06035 .56947 L
.05803 .55393 L
.05646 .54 L
.05578 .53218 L
.05529 .52507 L
.05495 .51842 L
.0548 .51466 L
.05469 .5112 L
.05462 .50817 L
.05459 .50645 L
.05457 .50484 L
.05455 .50314 L
.05455 .50159 L
.05454 .4998 L
Mistroke
.05455 .4981 L
.05456 .49626 L
.05457 .49523 L
.05458 .49428 L
.05461 .49253 L
.05465 .49068 L
.05473 .48748 L
.05485 .48398 L
.05522 .4762 L
.05569 .46896 L
.05687 .45596 L
.05857 .44209 L
.06091 .4273 L
.06404 .41134 L
.07132 .38272 L
.08042 .35516 L
.09212 .32671 L
.11823 .27813 L
.15265 .23085 L
.1915 .1905 L
.23805 .15391 L
.28701 .12542 L
.33696 .10465 L
.36347 .09658 L
.39216 .08995 L
.40632 .08746 L
.4217 .08532 L
.42877 .08453 L
.43625 .08383 L
.44326 .08329 L
.44966 .08291 L
.45276 .08276 L
.45613 .08262 L
.45904 .08253 L
.46225 .08244 L
.464 .08241 L
.46565 .08238 L
.46739 .08236 L
.46836 .08236 L
.46926 .08235 L
.47077 .08234 L
.47242 .08235 L
.47414 .08235 L
.47574 .08237 L
.47726 .08239 L
.47891 .08241 L
.4819 .08248 L
.4848 .08256 L
.48748 .08266 L
.49357 .08294 L
Mistroke
.5 .08333 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.416667 0.5 0.416667 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.29167 -0.0125 -12 -9 ]
[.29167 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70833 -0.0125 -9 -9 ]
[.70833 -0.0125 9 0 ]
[.91667 -0.0125 -3 -9 ]
[.91667 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .29167 -24 -4.5 ]
[-0.0125 .29167 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .70833 -18 -4.5 ]
[-0.0125 .70833 0 4.5 ]
[-0.0125 .91667 -6 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -70.125 -6 ]
[-0.01875 .5 -24 6 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-1)] .08333 -0.0125 0 1 Mshowa
.29167 0 m
.29167 .00625 L
s
[(-0.5)] .29167 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70833 0 m
.70833 .00625 L
s
[(0.5)] .70833 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(1)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.125 0 m
.125 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.875 0 m
.875 .00375 L
s
.04167 0 m
.04167 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(-1)] -0.0125 .08333 1 0 Mshowa
0 .29167 m
.00625 .29167 L
s
[(-0.5)] -0.0125 .29167 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .70833 m
.00625 .70833 L
s
[(0.5)] -0.0125 .70833 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(1)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .125 m
.00375 .125 L
s
0 .16667 m
.00375 .16667 L
s
0 .20833 m
.00375 .20833 L
s
0 .25 m
.00375 .25 L
s
0 .33333 m
.00375 .33333 L
s
0 .375 m
.00375 .375 L
s
0 .41667 m
.00375 .41667 L
s
0 .45833 m
.00375 .45833 L
s
0 .54167 m
.00375 .54167 L
s
0 .58333 m
.00375 .58333 L
s
0 .625 m
.00375 .625 L
s
0 .66667 m
.00375 .66667 L
s
0 .75 m
.00375 .75 L
s
0 .79167 m
.00375 .79167 L
s
0 .83333 m
.00375 .83333 L
s
0 .875 m
.00375 .875 L
s
0 .04167 m
.00375 .04167 L
s
0 .95833 m
.00375 .95833 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -131.125 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
93.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
105.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.29167 .99375 m
.29167 1 L
s
.5 .99375 m
.5 1 L
s
.70833 .99375 m
.70833 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.125 .99625 m
.125 1 L
s
.16667 .99625 m
.16667 1 L
s
.20833 .99625 m
.20833 1 L
s
.25 .99625 m
.25 1 L
s
.33333 .99625 m
.33333 1 L
s
.375 .99625 m
.375 1 L
s
.41667 .99625 m
.41667 1 L
s
.45833 .99625 m
.45833 1 L
s
.54167 .99625 m
.54167 1 L
s
.58333 .99625 m
.58333 1 L
s
.625 .99625 m
.625 1 L
s
.66667 .99625 m
.66667 1 L
s
.75 .99625 m
.75 1 L
s
.79167 .99625 m
.79167 1 L
s
.83333 .99625 m
.83333 1 L
s
.875 .99625 m
.875 1 L
s
.04167 .99625 m
.04167 1 L
s
.95833 .99625 m
.95833 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .29167 m
1 .29167 L
s
.99375 .5 m
1 .5 L
s
.99375 .70833 m
1 .70833 L
s
.99375 .91667 m
1 .91667 L
s
.125 Mabswid
.99625 .125 m
1 .125 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .20833 m
1 .20833 L
s
.99625 .25 m
1 .25 L
s
.99625 .33333 m
1 .33333 L
s
.99625 .375 m
1 .375 L
s
.99625 .41667 m
1 .41667 L
s
.99625 .45833 m
1 .45833 L
s
.99625 .54167 m
1 .54167 L
s
.99625 .58333 m
1 .58333 L
s
.99625 .625 m
1 .625 L
s
.99625 .66667 m
1 .66667 L
s
.99625 .75 m
1 .75 L
s
.99625 .79167 m
1 .79167 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .875 m
1 .875 L
s
.99625 .04167 m
1 .04167 L
s
.99625 .95833 m
1 .95833 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ .03 .03 ] 0 setdash
.5 .91667 m
.50323 .91665 L
.50617 .91662 L
.50956 .91656 L
.51277 .91647 L
.51847 .91626 L
.52466 .91594 L
.53147 .91548 L
.53867 .91487 L
.55157 .91346 L
.56483 .91159 L
.57719 .90945 L
.60506 .9032 L
.63298 .89488 L
.65795 .88557 L
.71167 .8589 L
.75485 .82964 L
.7974 .79183 L
.83267 .75089 L
.86409 .70261 L
.87699 .67745 L
.88899 .64933 L
.89767 .62437 L
.90536 .5964 L
.90831 .58304 L
.91098 .56862 L
.91287 .55609 L
.9145 .5424 L
.91525 .53435 L
.9158 .5269 L
.9162 .51976 L
.91635 .51616 L
.91649 .51218 L
.91658 .50861 L
.91663 .50533 L
.91666 .50173 L
.91667 .49992 L
.91666 .49794 L
.91663 .49459 L
.91657 .49101 L
.91648 .48764 L
.91638 .48457 L
.9161 .47823 L
.91567 .47126 L
.91446 .4572 L
.91292 .44423 L
.9111 .43213 L
.90572 .40511 L
.89796 .37654 L
.88882 .35024 L
Mistroke
.87689 .32233 L
.85009 .27406 L
.81783 .23056 L
.7776 .18928 L
.731 .15323 L
.68292 .12563 L
.65838 .11461 L
.63177 .10472 L
.60629 .09712 L
.5827 .09162 L
.55695 .08724 L
.54269 .08553 L
.53612 .0849 L
.52914 .08435 L
.52318 .08398 L
.52001 .08381 L
.5166 .08366 L
.51347 .08355 L
.51061 .08347 L
.50787 .08341 L
.50499 .08336 L
.50184 .08334 L
.49849 .08334 L
.49532 .08336 L
.49244 .0834 L
.48906 .08348 L
.48539 .08359 L
.47874 .08388 L
.47225 .08426 L
.46529 .08478 L
.45275 .08602 L
.43789 .08799 L
.42441 .09025 L
.39541 .09667 L
.3684 .10466 L
.31782 .12527 L
.27375 .15011 L
.23254 .18051 L
.19173 .21968 L
.15859 .26114 L
.12907 .31021 L
.10731 .3607 L
.09893 .38708 L
.09499 .40215 L
.09178 .41651 L
.08929 .42981 L
.08707 .44431 L
.0855 .45755 L
.08443 .46981 L
.08399 .47667 L
Mistroke
.08368 .4831 L
.08354 .48678 L
.08345 .49015 L
.08341 .49201 L
.08338 .49404 L
.08335 .49596 L
.08334 .49774 L
.08333 .4996 L
.08334 .50161 L
.08335 .50351 L
.08337 .50526 L
.08342 .50858 L
.08351 .51208 L
.08363 .51584 L
.08378 .51936 L
.08423 .52733 L
.08476 .53447 L
.08536 .54107 L
.08711 .55594 L
.08909 .569 L
.09164 .58279 L
.09715 .60641 L
.10481 .63205 L
.12485 .68131 L
.15328 .73107 L
.18679 .77479 L
.22796 .8156 L
.27128 .84828 L
.31507 .87338 L
.34145 .88532 L
.36703 .89488 L
.39079 .9021 L
.41635 .90818 L
.4369 .91186 L
.44865 .91349 L
.45967 .91471 L
.46981 .91557 L
.47909 .91614 L
.48422 .91637 L
.48693 .91646 L
.48982 .91654 L
.49259 .9166 L
.4951 .91664 L
.49763 .91666 L
.5 .91667 L
Mfstroke
[ ] 0 setdash
.5 .91667 m
.52559 .91189 L
.55193 .90524 L
.6054 .88619 L
.65049 .86406 L
.69503 .83626 L
.73464 .80597 L
.77337 .77036 L
.80747 .73284 L
.83718 .6937 L
.86509 .64863 L
.8877 .60182 L
.90471 .55374 L
.91135 .52801 L
.91672 .49963 L
.91862 .48567 L
.91943 .47824 L
.92015 .47029 L
.92068 .46262 L
.92104 .45564 L
.92117 .45227 L
.92123 .45049 L
.92128 .44861 L
.92132 .44696 L
.92135 .44515 L
.92138 .4435 L
.92139 .44196 L
.9214 .44017 L
.9214 .43927 L
.9214 .43827 L
.9214 .43651 L
.92138 .43486 L
.92137 .43391 L
.92136 .43291 L
.92132 .43113 L
.92128 .42921 L
.92122 .42711 L
.9211 .42358 L
.92093 .41981 L
.92053 .413 L
.91999 .40586 L
.91934 .39912 L
.91781 .38652 L
.91563 .37267 L
.91274 .35806 L
.90605 .33209 L
.89684 .30503 L
.88624 .28035 L
.85764 .23085 L
.83869 .20593 L
Mistroke
.81868 .18391 L
.77579 .14708 L
.75156 .13096 L
.72447 .11609 L
.69762 .10419 L
.66776 .0939 L
.65348 .08998 L
.63831 .08648 L
.62402 .0838 L
.61097 .08185 L
.59741 .08031 L
.58995 .07968 L
.58289 .07921 L
.57973 .07905 L
.57638 .0789 L
.57348 .0788 L
.57036 .07871 L
.56862 .07867 L
.56703 .07864 L
.56551 .07862 L
.5639 .07861 L
.56214 .0786 L
.56051 .0786 L
.55871 .0786 L
.55771 .07861 L
.5568 .07862 L
.5551 .07864 L
.55351 .07867 L
.54991 .07876 L
.5464 .07887 L
.54265 .07903 L
.53587 .07941 L
.5297 .07985 L
.5148 .08132 L
.5008 .08321 L
.5 .08333 L
Mfstroke
.5 .91667 m
.48761 .91839 L
.47392 .91984 L
.46697 .9204 L
.46314 .92065 L
.45951 .92086 L
.45613 .92102 L
.45245 .92117 L
.4491 .92127 L
.44601 .92134 L
.44422 .92137 L
.44258 .92139 L
.44167 .92139 L
.44069 .9214 L
.43889 .9214 L
.43721 .9214 L
.43542 .92139 L
.43373 .92137 L
.4322 .92134 L
.43023 .92131 L
.42843 .92126 L
.42434 .92113 L
.42074 .92098 L
.41693 .92078 L
.4093 .92027 L
.40218 .91965 L
.38599 .91774 L
.3711 .91535 L
.35705 .91252 L
.33096 .90571 L
.30346 .89623 L
.27868 .88545 L
.2288 .8562 L
.18585 .82058 L
.1646 .79795 L
.14697 .77564 L
.11732 .72695 L
.10582 .70166 L
.09556 .67319 L
.08809 .64566 L
.08487 .63009 L
.08253 .61589 L
.08074 .60165 L
.08008 .59486 L
.07957 .58851 L
.07914 .58165 L
.07897 .57802 L
.07882 .57411 L
.07876 .57216 L
.0787 .57003 L
Mistroke
.07866 .56802 L
.07863 .56616 L
.07861 .56432 L
.0786 .56265 L
.0786 .56172 L
.0786 .56072 L
.0786 .55891 L
.07862 .55714 L
.07864 .55553 L
.07867 .55368 L
.07871 .55192 L
.07879 .54881 L
.07891 .54543 L
.07929 .53778 L
.07977 .53073 L
.08113 .51645 L
.08311 .50145 L
.08801 .47488 L
.09406 .45055 L
.11109 .4011 L
.13458 .35197 L
.16157 .30812 L
.19093 .26909 L
.22549 .2308 L
.26183 .19702 L
.30383 .16453 L
.34774 .13693 L
.39327 .11438 L
.41755 .10471 L
.44513 .09562 L
.47215 .08861 L
.49803 .08364 L
.5 .08333 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{420, 420},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009f0002MR000`400?l00000o`00003ooooooooo
ooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo
003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003ooooooooo
ooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool0
0?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooo
oomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00
ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00oooooooooooo
ogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003o
ooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003ooooooooooooo
N?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oo
oooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomh
ooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00oooo
ooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSo
oooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003ooooo
ooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?oo
ool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooo
oooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhoooo
o`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00oooooooo
ooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo
002:ooooo`Co000000?o410@ooooooooool04Oooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEE
EOl0003oEEEE00Cooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h>ooooo`04okZj^_l@413o0000
ogMgMaCooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06oiRHV?l@
413o0000o`000?m4A4Cok^k^4oooool4o`000003oa0@4?oooooooooo0;Cooooo1?l000000ol@413o
ooooooooo`0Aooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool01_nH
V9So410@o`000?l0003oA4A4onk^kPkooooo00Co^[Zjoa0@4?l0003oMgMg5?ooool01?nj^[[o410@
o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^hC
ooooo`Co000000?o410@ooooooooool0;?ooool008cooooo00?o0000ooooooooool04_ooool01_o<
c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`06oa0@4?n7QhOooooooooooomgMgOo
A4A43Oooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZA;ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q
8OnYZJT5ooooo`?o00001?ooool01_l@413oQhN7ooooooooooooMgMgodA4A1Gooooo00?o0000oooo
ooooool0^?ooool00ol0003oooooooooo`0Booooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Ooo
ool3o`0000Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@=ooooo`06olc<c?lb<S;ok^k^onk^
k_lQ8B7oZJVY4_ooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`06oa0@
4?n7QhOooooooooooomgMgOoA4A45Oooool00ol0003oooooooooo`0^ooooo`00S?ooool00ol0003o
ooooooooo`0Booooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@09
ooooo`03o`000?oooooooooo00_ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S8Booooo`06odA4
A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@09ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Booooo`06odA4A?nYZJWooooo
oooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@09ooooo`03o`000?oooooooooo00_ooooo00Ko
A4A4ojVYZOooooooooooojVYZOlb<S8Booooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool0
0omEEEGo0000oeEEE@09ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;_ooool0
083ooooo1ol00005ooooo`03o`000?oooooooooo00Wooooo1ol00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03_ooool00oo^k^ko0000ooooo`0<ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00kooooo00?ok^k^o`000?ooool05?ooool00ol0003oooooooooo`2/ooooo`Oo00001Oooool00ol0
003oooooooooo`09ooooo`Oo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00kooooo00?ok^k^o`000?ooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03onk^k_l0003ooooo
01Cooooo00?o0000ooooooooool0;_ooool008cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH=
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00[ooooo00Ko410@oiRHV?ooooooooooogMgMomVIVHEooooo`03o`00
0?oooooooooo0;Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00[ooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH=ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00[ooooo00Ko410@oiRHV?ooooooooooogMgMomVIVHEooooo`03o`000?oooooooooo02kooooo002<
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:
ooooo`05o`000?lQ8B7o0000o`000?mVIVH03_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?lQ
8B7o0000o`000?mVIVH05_ooool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000o`000?mV
IVH03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000o`000?mVIVH05_ooool00ol0
003oooooooooo`0^ooooo`00S?ooool00ol0003oooooooooo`0Booooo`06odA4A?nYZJWooooooooo
oonYZJWoA4A43?ooool00ol0003oooooooooo`0@ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A4
4_ooool01_m4A4CoZJVYooooooooooooZJVYodA4A0cooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`2hooooo`03o`000?oooooooooo01;ooooo00KoA4A4ojVYZOooooooooooojVYZOm4
A4@<ooooo`03o`000?oooooooooo013ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@Booooo`06
odA4A?nYZJWooooooooooonYZJWoA4A43?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo02kooooo002:ooooo`03o`000?m4A4Co000001Cooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<
c<`<ooooo`03o`000?oooooooooo013ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`Booooo`06
olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool00ol0003oooooooooo`0Fooooo`03o`000?m4A4Co
00000;Sooooo00?o0000odA4A?l000005?ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo
00?o0000ooooooooool04?ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c1;ooooo00Koc<c<oc8b
<_o^k^kok^k^oc8b<_o<c<`<ooooo`03o`000?oooooooooo01Kooooo00?o0000odA4A?l00000<?oo
ool008[ooooo00?oc<c<oeEEEOl000005Oooool01?nj^[[o410@oa0@4?o<c<`=ooooo`Go00003ooo
ool01?nj^[[o410@oa0@4?o<c<`Dooooo`04okZj^_l@413o410@olc<c0gooooo1Ol0000Dooooo`03
olc<c?mEEEGo00000;Sooooo00?oc<c<oeEEEOl000005Oooool01?nj^[[o410@oa0@4?o<c<`=oooo
o`Go00003oooool01?nj^[[o410@oa0@4?o<c<`Dooooo`04okZj^_l@413o410@olc<c0gooooo1Ol0
000Dooooo`03olc<c?mEEEGo0000033ooooo003oooooooooooooN?ooool00?oooooooooooomhoooo
o`00ooooooooooooogSooooo001koooooioo0000V_oooonPo`0002;ooooo001kooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo09Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0V?ooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool08?ooool007_ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo09Sooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo023ooooo
001kooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0Boooool2o`0009[ooooo0_l0
001=ooooo`03o`000?oooooooooo04cooooo0_l0000Rooooo`00Noooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo09Sooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo023ooooo001kooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2Hooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Pooooo`00
L_ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo08oooooo1?l000000ol@413oooooooooo`02ooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool01_ooool?o`0003Sooooo00?o0000ooooooooool0
8?ooool007Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0hooooo`go00001ooo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1<ooooo`04o`000?ooooooooooooooo`Go00003oooool4o`0003Cooooo
00?o0000ooooooooool08?ooool007Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0dooooo`Co00003Oooool5o`0000;ooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`2Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C?ooool01?l0003oooooo`00
0?l0000Hooooo`;o0000<_ooool00ol0003oooooooooo`0Pooooo`00J?ooool7o`0000Gooooo00?o
0000ooooooooool01?ooool2o`00037ooooo1?l0000@ooooo`oo0000Aoooool2o`0008Oooooo1ol0
0005ooooo`03o`000?oooooooooo00Cooooo0_l00016ooooo`Go000000?oooooo`000?l000001ol0
000Fooooo`;o0000;oooool2o`0002;ooooo001dooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0;Oooool3o`0000gooooo0ol0000<ooooo`03o`000?oooooooooo00?o00001Oooool4
o`00043ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03kooooo0ol00008ooooo`;o000000?oooooo`000?ooool02_ooool4o`00013ooooo0_l0000^
ooooo`03o`000?oooooooooo023ooooo001dooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0:oooool2o`0000kooooo0_l0000?ooooo`03o`000?oooooooooo00?ooooo0ol00006oooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03_ooooo0ol00009ooooo`;o00000oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Poooo
o`00M?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo0_l0000Qooooo`03
o`000?oooooooooo00Kooooo0_l00009ooooo`?o0000>?ooool00ol0003oooooooooo`2Aooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0AOooool2o`0000Gooooo00?o0000oooooooo
ool04_ooool2o`0000cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Pooooo`00
L_ooool00ol0003oA4A4o`000006ooooo`03o`000?oooooooooo02Oooooo0_l0000;ooooo`?o0000
5Oooool00ol0003oooooooooo`08ooooo`;o00002_ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo08oooooo00?o0000odA4A?l000001_ooool00ol0003oooooooooo`0eooooo`?o0000
2oooool2o`0000Oooooo00?o0000ooooooooool05?ooool2o`0000_ooooo0_l0000Zooooo`03o`00
0?oooooooooo023ooooo001booooo`03olc<c?mEEEGo000000Kooooo00?o0000ooooooooool09Ooo
ool2o`0000_ooooo0_l0000Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo08oooooo00?oc<c<oeEEEOl000001_oo
ool00ol0003oooooooooo`0cooooo`;o00003?ooool2o`0000Wooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0:ooooo`;o0000:?ooool00ol0003oooooooooo`0Pooooo`00Noooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02oooool2
o`0003oooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo023ooooo001kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_ooool2o`00
01kooooo00?o0000ooooooooool03Oooool2o`0000_ooooo0_l0000_ooooo`;o0000V_ooool2o`00
02kooooo0_l0000?ooooo`;o00003?ooool00ol0003oooooooooo`0Kooooo`;o00002?ooool00ol0
003oooooooooo`0Tooooo`;o00008_ooool007_ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03oooool3o`0000[o
oooo0_l0000^ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0=ooooo`;o00003_ooool00ol0003oooooooooo`0Mooooo`;o00001oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01;ooooo
0_l0000:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0V?ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00_ooooo0ol0000@ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo
001kooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01Cooooo0_l0000fooooo`03o`000?oooooooooo09Sooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`09ooooo`?o00004oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Kooooo0_l0000d
ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0=?ooool2o`0001Kooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo001koooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool2o`0002Sooooo00?o0000oooo
ooooool0V?ooool00ol0003oooooooooo`0Uooooo`;o00002_ooool3o`0001Sooooo00?o0000oooo
ooooool08oooool2o`0000Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Poooo
o`00Noooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Iooooo`;o00002Oooool00ol0003oooooooooo`0Tooooo`;o
0000V_ooool2o`0002Gooooo00?o0000ooooooooool02?ooool2o`0001_ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo0_l0000Rooooo`00
Noooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Kooooo`;o00002?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo09Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07ooooo`;o0000
7Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2Hooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool01Oooool3o`0001oooooo00?o0000ooooooooool09ooo
ool01Ol0003ooooooooooooooooo0000027ooooo00?o0000ooooooooool08?ooool007_ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01kooooo0_l0
000/ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool09oooool3o`0002;ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo023ooooo001k
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0U
ooooo`;o00009Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool08?ooool007_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05oooo
o`;o00008Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01oooooo00Co0000oooo
oooooooooooo0_l0000Wooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooo00007ooo
ool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Rooooo`;o00001oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool07oooool0
1?l0003oooooooooool0000Yooooo`03o`000?oooooooooo02_ooooo00?o0000ooooool000007ooo
ool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Tooooo`;o00001_ooool0
0ol0003oooooooooo`0Looooo`;o0000V_ooool2o`0001oooooo00Co0000ooooool0003o0000:_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooo000001gooooo0_l0000Rooooo`00Noooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01gooooo0ol0000/ooooo`03o`000?oooooo
oooo02gooooo0_l0000Nooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo
01Oooooo00Go0000ooooooooooooooooo`00000`ooooo`03o`000?oooooooooo02Oooooo0_l0000S
ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool07?ooool2o`0002kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo023ooooo001koooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yoooo
o`;o00008Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01[ooooo0_l0000`oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Poooo
o`00Noooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo09Sooooo00?o0000oooooooo
ool06?ooool2o`0003;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0/ooooo`05o`000?ooooooooooooooool000006oooool00ol0003o
ooooooooo`2Hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0`ooooo`;o00006oooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003ooooo
ooooo`0Dooooo`05o`000?ooooooooooooooool00000<oooool00ol0003oooooooooo`0]ooooo`05
o`000?ooooooooooooooool000006Oooool2o`0009[ooooo0_l0000Gooooo`04o`000?oooooo0000
o`0003;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`;o00008_ooool0
07_ooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool0000dooooo`03o`000?oooooo
oooo02kooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo09Sooooo00?o
0000ooooooooool05Oooool00ol0003oooooo`00000dooooo`03o`000?oooooooooo037ooooo0_l0
000Jooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo01?ooooo00Co0000
oooooooooooo0000=Oooool00ol0003oooooooooo`0_ooooo`05o`000?ooooooooooooooool00000
6?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01?ooooo0_l000000ooooooo0000
ooooo`0dooooo`03o`000?oooooooooo03;ooooo0_l0000Iooooo`03o`000?oooooooooo023ooooo
001kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool00000=_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0V?ooool00ol0003ooooooooo
o`0Booooo`05o`000?ooooooooooooooool00000=Oooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool08?ooool0063ooooo00Co^[Zjoa0@4?l0003oMgMg
1_ooool00omEEEGo0000oeEEE@04ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo07gooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool0
0omEEEGo0000oeEEE@04ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo023ooooo001Oooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7o
ZJVY1Oooool3o`0000Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@4ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0O?ooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo
0ol00004ooooo`06oa0@4?n7QhOooooooooooomgMgOoA4A41?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo023ooooo001Oooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool0
0omEEEGo0000oeEEE@09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo03?ooooo00?o0000ooooool000005_ooool0
0ol0003oooooooooo`1looooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000
oeEEE@09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo03?ooooo00Co0000oooooooooooo00005_ooool00ol0003o
ooooooooo`0Pooooo`00E_ooool7o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0>ooooo`03onk^k_l0003ooooo00?ooooo0_l0000Cooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0=?ooool2o`0001Gooooo0_l0001eooooo`Oo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00kooooo00?ok^k^o`000?ooool00oooool2o`00013ooooo
00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo03?ooooo00Co0000oooooooo
oooo00005Oooool2o`0002;ooooo001Oooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02_ooool01_l@413oV9RHooooooooooooMgMgofIVIPCooooo00?o0000ooooooooool04Oooool2
o`0003Wooooo00?o0000ooooooooool0=Oooool2o`0001Gooooo00?o0000ooooooooool0O?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko410@oiRHV?ooooooooooogMg
MomVIVH4ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000hooooo`03
o`000?oooooooooo03Cooooo00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`0Poooo
o`00Goooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0
003o0000ofIVIP05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool0O?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o0000ofIVIP05
ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000iooooo`03o`000?oo
oooooooo03Cooooo00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`0Pooooo`00Gooo
ool01_m4A4CoZJVYooooooooooooZJVYodA4A0cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooo`00000Cooooo`03o`000?oooooooooo07cooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooo
oooo000003Wooooo00?o0000ooooooooool0=?ooool01Ol0003ooooooooooooooooo000001Cooooo
00?o0000ooooooooool08?ooool005oooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool2o`0003[ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07cooooo00Koc<c<oc8b<_o^
k^kok^k^oc8b<_o<c<`<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo023ooooo001Pooooo`04okZj^_l@413o410@
olc<c0gooooo1Ol00005ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0OOooool0
1?nj^[[o410@oa0@4?o<c<`=ooooo`Go00001Oooool00ol0003oooooooooo`0=ooooo`05o`000?oo
ooooooooooooool00000>_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`2Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool03_ooool2o`0009[ooooo0_l0000=ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Dooooo`;o00008_ooool007_ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03[ooooo0_l0000@oooo
o`03o`000?oooooooooo09Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo03Kooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooo
oooo023ooooo001kooooo`03o`000?oooooooooo00kooooo0_l0000looooo`03o`000?oooooooooo
03[ooooo0_l0000@ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool02oooool01Ol0
003ooooooooooooooooo000003cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000oooo
ooooool03_ooool2o`0003cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo09Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo00kooooo0_l0000looooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Hooooo`03
o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000mooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003o
ooooooooo`0>ooooo`;o0000??ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0:ooooo`05o`000?oooooooooooooo
ool00000?Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool08?ooool007_ooooo00?o0000ooooooooool03Oooool00ol0003oooooo`00000looooo`03
o`000?oooooooooo03_ooooo0_l000000ooooooo0000ooooo`0;ooooo`;o0000V_ooool2o`0000[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03So
oooo00Go0000ooooooooooooooooo`00000?ooooo`;o00008_ooool007_ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03cooooo00?o0000ooooool0
00003Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0hooooo`05o`000?ooooooooooooooool000004?ooool00ol0
003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool0??ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo
09Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
023ooooo001kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool0V?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0>Oooool01Ol0003o
oooooooooooooooo000000oooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03gooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0iooooo`05o`000?ooooooooooooooool000003oooool0
0ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooo
ooooool00000??ooool00ol0003oooooooooo`0mooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooooooool0V?ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0003oooooo
00?o0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool08?ooool007_ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000003co
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo09So
oooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000oooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003o
ooooooooo`0;ooooo`05o`000?ooooooooooooooool00000??ooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo00Oooooo0_l0002Jooooo`;o00002_ooool01?l0003oooooooooool0000o
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03oooool2o`0002;ooooo001koooo
o`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo0000?Oooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`09
ooooo`04o`000?ooooooooooo`0003oooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo00_ooooo00Co0000
oooooooooooo0000?Oooool00ol0003oooooooooo`0nooooo`04o`000?ooooooooooo`0000[ooooo
00?o0000ooooooooool0V?ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0003oo
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02o`0000gooooo00?o0000oooooooo
ool08?ooool007_ooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000mooooo`03
o`000?oooooooooo03kooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo
09Sooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000010ooooo`03o`000?oooooooooo
03_ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0?_ooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0??ooool01?l0003oooooooooool0
000=ooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0nooooo`05o`000?ooooooooooooooool000002Ooo
ool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`0looooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool0
8?ooool007_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo03kooooo00Go0000ooooooooooooooooo`000008ooooo`;o0000V_ooool2o`0000[ooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo000000cooooo
0_l0000Rooooo`00<?ooool00ol0003o^[Zjooooo`18ooooo`03o`000?oooooooooo00[ooooo00Go
0000ooooooooooooooooo`00000mooooo`03o`000?oooooooooo03kooooo00Go0000oooooooooooo
ooooo`000009ooooo`03o`000?oooooooooo04gooooo00?o0000okZj^_ooool0B?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooo0000043ooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooo`00000=ooooo`03o`000?oooooooooo023ooooo000`ooooo`03ob4Q8OmEEEGooooo04Sooooo
00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000003gooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04gooooo00?o8B4QoeEEEOoo
ool0B?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo0000043ooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo023ooooo000Aooooo`09oa0@
4?l0003o0000ooooool0003o410@ooooool0003o410@00cooooo1?l000000ol@413oooooooooo`03
ooooo`03ofIVI_l0003ok^k^00Cooooo00?o410@o`000?l000001?l0000;ooooo`06ojVYZOlQ8B7o
0000o`000?mEEEGok^k^;?ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool0
0000?Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool01ol@413o0000oa0@4?oooooo410@o`000?l@41008oooool02Ol@413o0000o`000?oo
oooo0000oa0@4?oooooo0000oa0@400;ooooo`Co000000?o410@ooooooooool00oooool00omVIVKo
0000onk^kP04ooooo`03oa0@4?l0003o000000Co00003_ooool2o`000003oa0@4?oooooooooo02[o
oooo00?o0000ooooooooool02_ooool2o`00043ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00Oo410@o`000?l@413ooooooa0@4?l0003o
410@01Cooooo000Booooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool6
o`0000Gooooo00?o0000ooooooooool01Oooool00onHV9So0000ogMgM`07ooooo`03o`000?oooooo
oooo00Cooooo1_l00002ooooo`06oa0@4?nYZJWooooooooooomgMgOo<S8b8oooool01?nj^[[o410@
o`000?mgMgL5ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000moooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`06oc8b<_n7QhOooooookZj^_l0003ok^k^9?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`03oiRHV?l0003oMgMg00Oo
oooo00?o0000ooooooooool01?ooool6o`0000Kooooo00?o0000ooooooooool08_ooool01?nj^[[o
410@o`000?mgMgL5ooooo`03o`000?oooooooooo00[ooooo0_l00010ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`06oc8b<_n7QhOooooo
okZj^_l0003ok^k^5?ooool001;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Gooooo00?ogMgMo`000?l@41001oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo023ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT4ooooo`03
o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000mooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`05onk^k_lQ8B7oc<c<
ob4Q8Oo<c<`09Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool00ooMgMgo0000oa0@4007ooooo`03o`000?oooooooooo00cooooo1_l0
000Rooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1?ooool00ol0003oooooooooo`0:ooooo`;o
0000@?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01_ooool01Oo^k^ko8B4Qolc<c?lQ8B7oc<c<01Gooooo000Booooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
013ooooo00?oMgMgob4Q8Oooool08Oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PCooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03oooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Oooooo00?o^[Zjo`000?n7QhL0
9_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0<ooooo`05ofIVI_nYZJWoooooooooool000008oooool01_m4
A4CoZJVYooooooooooooZJVYoc8b<PCooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`03okZj^_l0003oQhN701Kooooo000Booooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool6o`0000Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`04ooooo`Ko00001?ooool01?lQ8B7o0000o`000?nj^[XRooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_oooonOo`0000Sooooo00Gok^k^oc8b<_o<c<co<S8bonk^kP0Uooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo1_l00005ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01?ooool6o`0000;ooooo00Gok^k^ob4Q8Oo^k^koooooo`00
000Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oooonPo`0000Sooooo00Go
k^k^oc8b<_o<c<co<S8bonk^kP0Eooooo`004_ooool01ol0003oc<c<olc<c?l0003oQhN7olc<c?l0
00003oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?ok^k^ogMgMolb
<S808_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03oooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooooooo00Kooooo00GoEEEEogMgMoooooooQhN7oeEEE@0U
ooooo`07o`000?o<c<coc<c<o`000?n7QhOoc<c<o`00000>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03Oooool01?nYZJWoIVIVooooool0000Sooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Ko
oooo00GoEEEEogMgMoooooooQhN7oeEEE@0Eooooo`004Oooool02?l@413o0000ob4Q8Ol0003oMgMg
oa0@4?l0003oQhN73oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03oooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Gooooo00Oo410@o`000?l@413o
oooooa0@4?l0003o410@02?ooooo00So410@o`000?lQ8B7o0000ogMgMol@413o0000ohN7Q`kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03odA4A?o<c<co000002?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`;o00003?ooool00ol0003ooooo
ooooo`05ooooo`07oa0@4?l0003o410@ooooool@413o0000oa0@400Dooooo`009_ooool00ol0003o
A4A4o`00000Aooooo`03o`000?oooooooooo00cooooo00Ko8B4QohN7QoooooooooooofIVI_lb<S8R
ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A41?ooool00ol0003oooooooooo`0:ooooo`05o`00
0?ooooooooooooooool00000?Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`13ooooo`03o`000?m4A4Co0000017o
oooo00?o0000ooooooooool03_ooool00ooMgMgoA4A4o`00000Sooooo`06odA4A?nYZJWooooooooo
oonYZJWoA4A41?ooool00ol0003oooooooooo`0;ooooo`;o0000?oooool00ol0003oooooooooo`0o
ooooo`;o00003?ooool00ol0003oooooooooo`0Pooooo`009_ooool00oo<c<coEEEEo`00000Aoooo
o`03o`000?oooooooooo00cooooo00Ko^[ZjodA4A?l0003o0000odA4A?o^k^hRooooo`06olc<c?lb
<S;ok^k^onk^k_lb<S;oc<c<1?ooool00ol0003oooooooooo`0:ooooo`05o`000?oooooooooooooo
ool00000?Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0@oooool00oo<c<coEEEEo`00000Aooooo`03o`000?oooooooooo00oooooo00?oQhN7o`00
0?ooool08_ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0Cooooo00?o0000ooooooooool02ooo
ool2o`0003oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo023ooooo000hooooo`03oa0@4?l0003o000003Oooooo00Co^[Zjoa0@4?l@413oc<c<1Ooo
ool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool00000?Oooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0EOooool00ol@413o0000
o`00000gooooo`04okZj^_l@413o410@olc<c0Gooooo00?o0000ooooooooool02oooool2o`0003oo
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023o
oooo001kooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000mooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool01_ooool2o`0009[ooooo0_l0000<ooooo`;o
0000?oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Sooooo0_l0000Rooooo`00
Noooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool00000?Oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0V?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooo000003kooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`05o`000?ooooooooooooooool0
00002Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo000000_ooooo00?o0000oooooooo
ool08?ooool007_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo03kooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo09So
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooool000002oooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0?_ooool01Ol0003ooooo
oooooooooooo000000Wooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0?oooool00ol0003oooooo`00000;ooooo`03
o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0nooooo`05o`000?ooooooooooooooool000002Oooool00ol0003o
ooooooooo`2Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0nooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool08?ooool007_o
oooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000mooooo`03o`000?oooooooooo
03kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooo
oooo00cooooo00Co0000oooooooooooo0000??ooool00ol0003oooooooooo`0nooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool02ooo
ool01?l0003oooooooooool0000mooooo`03o`000?oooooooooo03gooooo00Go0000oooooooooooo
ooooo`000009ooooo`;o0000V_ooool2o`0000gooooo00Co0000oooooooooooo0000??ooool00ol0
003oooooooooo`0nooooo`04o`000?ooooooooooo`0000[ooooo0_l0000Rooooo`00Noooool00ol0
003oooooooooo`0;ooooo`04o`000?ooooooooooo`0003gooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000003_ooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo00_ooooo00Go0000
ooooooooooooooooo`00000looooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00cooooo00Go0000oooooooooooooooo
o`00000kooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Pooooo`00Noooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0003cooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo09Sooooo
00?o0000ooooooooool03Oooool01?l0003oooooooooool0000kooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003ooooo
ooooo`0<ooooo`04o`000?ooooooooooo`0003cooooo00?o0000ooooooooool0??ooool01?l0003o
ooooooooool0000<ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool03Oooool01Ol0
003ooooooooooooooooo000003[ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooo
oooo000000_ooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo03cooooo00Co0000oooooooooooo00003?oo
ool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0mooooo`05o`000?ooooooooooooooool000002oooool00ol0003ooooo
ooooo`0Pooooo`00Noooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0??ooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo09Sooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo001k
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooo000000cooooo0_l0002Jooooo`;o00004oooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08
ooooo`;o00008_ooool007_ooooo00?o0000ooooooooool03Oooool00ol0003oooooo`00000loooo
o`03o`000?oooooooooo03cooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`2Hoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo03cooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooo
oooo023ooooo001kooooo`03o`000?oooooooooo00gooooo00?o0000ooooool00000??ooool00ol0
003oooooooooo`0kooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool0V?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0looooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0P
ooooo`00Noooool00ol0003oooooooooo`0>ooooo`;o0000??ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0?oooo
o`05o`000?ooooooooooooooool00000>?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooo`00000kooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`2Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo000003_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09So
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023o
oooo001kooooo`03o`000?oooooooooo00oooooo0_l0000kooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooool000003oooool2o`0009[ooooo0_l0000Aooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02_ooool2o`0002;ooooo001kooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0iooooo`;o00004Oooool00ol0003ooooooooo
o`2Hooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Pooooo`00Noooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0>?ooool2o`0001;ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Pooooo`00H?ooool01?nj^[[o410@o`000?mgMgL6oooo
o`03oeEEEOl0003oEEEE00Cooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h4ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0OOooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEE
EOl0003oEEEE00Cooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo
01;ooooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo023ooooo001Ooooo
o`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7Qooooooooooo
ogMgMom4A4@4ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0fooooo`;o00005?ooool00ol0003oooooooooo`1looooo`06olc<c?lb<S;ok^k^onk^
k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@4ooooo`03o`00
0?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo03So
oooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo023ooooo001Oooooo`06
odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@09ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04Oooool2o`0003Wooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07cooooo00KoA4A4ojVYZOooooooooooojVY
ZOlb<S85ooooo`03oeEEEOl0003oEEEE00Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Cooooo`05o`000?ooooooooooooooool00000=?ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool08?ooool005oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0>ooooo`03onk^k_l0003ooooo00?ooooo0_l0000Cooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Dooooo`;o0000
O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?ok^k^o`000?ooool0
0oooool2o`0001Cooooo00Go0000ooooooooooooooooo`00000dooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool03_ooool2o`0002;ooooo001Oooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02_ooool01_l@413oV9RHooooooooooooMgMgofIVIPCooooo00?o0000oooo
ooooool04_ooool2o`0003Sooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo07cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:oooo
o`06oa0@4?nHV9SooooooooooomgMgOoIVIV1?ooool00ol0003oooooooooo`0Dooooo`04o`000?oo
ooooooooo`0003Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo023ooooo001Oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool01Ol0003o8B4Qo`000?l0003oIVIV00Gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo03;ooooo00?o0000ooooool000005oooool00ol0003ooooo
ooooo`1looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Q
o`000?l0003oIVIV00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo03Gooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo
023ooooo001Oooooo`06odA4A?nYZJWooooooooooonYZJWoA4A43?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0a
ooooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool0O?ooool01_m4A4CoZJVYoooo
ooooooooZJVYodA4A0cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool0000Doooo
o`03o`000?oooooooooo023ooooo001Oooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0`ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool0O?oo
ool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0=?ooool01?l0003o
ooooooooool0000Eooooo`03o`000?oooooooooo023ooooo001Pooooo`04okZj^_l@413o410@olc<
c0gooooo1Ol00005ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000=Oooool0
0ol0003oooooooooo`0^ooooo`;o00000oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo07gooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool5o`0000Gooooo00?o0000ooooooooool05ooo
ool2o`0003?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooo`00000Fooooo`03o`000?oo
oooooooo023ooooo001kooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000=Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_oo
ool2o`0009[ooooo0_l0000Hooooo`03o`000?oooooo000003;ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooo`00000Fooooo`;o00008_ooool007_ooooo00?o0000ooooooooool05?ooool0
1?l0003oooooooooool0000dooooo`03o`000?oooooooooo02_ooooo0_l0000Oooooo`03o`000?oo
oooooooo09Sooooo00?o0000ooooooooool06?ooool2o`0003;ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooo
oooo01Cooooo00Go0000ooooooooooooooooo`00000cooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0booooo`;o00006Oooool00ol0003ooooooooo
o`0Pooooo`00Noooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool00000<_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0`ooooo`;o00006oooool00ol0003oooooooooo`0Pooooo`00Noooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09oooool2
o`0000Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`?o00007?ooool0
0ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0;?ooool2o`000003ooooool0003ooooo01cooooo00?o0000oooo
ooooool08?ooool007_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool09?ooool2o`0000Oooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01_ooooo00?o0000ooooool0
0000;_ooool00ol0003oooooooooo`0Zooooo`;o00000_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Looooo`;o0000V_ooool2o`0001gooooo0_l0000^ooooo`03o`00
0?oooooooooo02Sooooo0_l00003ooooo`03o`000?oooooooooo01cooooo0_l0000Rooooo`00Nooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0V?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooo000002gooooo00?o0000ooooooooool09_oo
ool2o`0002Gooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool08?ooool2
o`0002[ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
000002cooooo00?o0000ooooooooool09?ooool2o`0002Oooooo00?o0000ooooooooool08?ooool0
07_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Mooooo`04o`000?oooooooooo
o`0002_ooooo00?o0000ooooooooool08_ooool2o`0000Gooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool07Oooool2o`0000Sooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`2Hooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0Oooooo`?o00001_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
023ooooo001kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`2Hooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Looooo`?o00002?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023o
oooo001kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01?ooool2o`0002Oooooo
00?o0000ooooooooool06_ooool2o`0000Wooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`2Hooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool2o`0002Kooooo
00?o0000ooooooooool06_ooool2o`0000[ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Hooooo`;o0000<Oooool2o`0009[ooooo0_l0
000Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Gooooo`?o0000<_ooool2o`0002;ooooo001kooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Gooooo0_l0000f
ooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Gooooo0_l00009oooo
o`;o0000:_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01?ooooo0_l0000<oooo
o`;o0000:_ooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool04oooool2o`0000[ooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0@ooooo`?o00003Oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo023ooooo0_l00009ooooo`;o0000
7oooool00ol0003oooooooooo`0@ooooo`?o00002_ooool2o`0002gooooo00?o0000ooooooooool0
V?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo0_l0000Nooooo`03o`00
0?oooooooooo00kooooo0_l0000>ooooo`;o0000;Oooool00ol0003oooooooooo`0Pooooo`00Nooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0>ooooo`;o0000??ooool00ol0003oooooooooo`2Hooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00cooooo0_l0000oooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool02?ooool2o`0001cooooo00?o0000ooooooooool03?ooool2
o`0000[ooooo0_l0000aooooo`;o0000V_ooool2o`0002Gooooo00?o0000ooooooooool02?ooool2
o`0001_ooooo00?o0000ooooooooool02_ooool2o`0000cooooo0_l0000booooo`;o00008_ooool0
07_ooooo00?o0000ooooooooool09?ooool2o`0002Kooooo00?o0000ooooooooool02_ooool2o`00
00_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo
02Gooooo0_l0000Uooooo`03o`000?oooooooooo00Sooooo0_l0000=ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool09_ooool2o`0000_o
oooo0ol0000Fooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`?o0000=Oooool00ol0003o
ooooooooo`2Hooooo`03o`000?oooooooooo02Oooooo0_l0000;ooooo`?o00005Oooool00ol0003o
ooooooooo`06ooooo`;o00003Oooool2o`0003Kooooo00?o0000ooooooooool08?ooool007_ooooo
00?o0000ooooooooool0:?ooool2o`0000cooooo0_l0000Dooooo`03o`000?oooooooooo00Kooooo
0_l00014ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0:Oooool2o`0000cooooo
0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l00017ooooo`03o`000?oooooooooo023ooooo
001booooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`0Zooooo`;o00003?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`;o0000>ooo
ool00ol0003oooooooooo`2?ooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`02ooooo`;o00003?ooool2o`0003_ooooo00?o0000ooooooooool08?ooool007Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0/ooooo`;o00003_ooool5o`0000_ooooo00Co0000
oooooooooooooooo0ol00007ooooo`Co0000?Oooool00ol0003oooooooooo`2Aooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0>ooooo`Go00002_oo
ool00ol0003oooooooooo`02o`0000[ooooo1?l0000mooooo`03o`000?oooooooooo023ooooo001d
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool2o`00017ooooo00?o0000
ooooooooool02?ooool4o`0000;ooooo1?l00015ooooo`03o`000?oooooooooo097ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0]ooooo`;o00004oooool00ol0003oooooooooo`07
ooooo`?o00001?ooool4o`0004Gooooo00?o0000ooooooooool08?ooool007Cooooo00?o0000oooo
ooooool01?ooool2o`00037ooooo1Ol0000Aooooo`Oo00001?ooool00ol0003oooooooooo`16oooo
o`;o0000Toooool00ol0003oooooooooo`04ooooo`;o0000<?ooool2o`0001Kooooo1ol00004oooo
o`03o`000?oooooooooo04Kooooo0_l0000Rooooo`00M?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03Gooooo1_l00007ooooo`Oo00000oooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo097ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0aooooo`;o
00005?ooool3o`0000;ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Pooooo`00
M?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo1ol0000:ooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03?ooooo1?l0000;ooooo`Go00001Oooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo023ooooo001dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0gooooo`_o00002_ooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo023ooooo001booooo`03o`000?m4A4Co000000Kooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo08oooooo00?o0000odA4A?l000001_ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool08?ooool0
07;ooooo00?oc<c<oeEEEOl000001_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0Soooool00oo<c<coEEEEo`000006ooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo04_ooooo0_l0002Jooooo`;o0000COooool00ol0003o
ooooooooo`1<ooooo`;o00008_ooool007_ooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo09Sooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo023ooooo001kooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2Hooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Pooooo`00
Noooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo001koooooioo0000V_oo
oonPo`0002;ooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSo
oooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003ooooo
ooooooooN?ooool00?oooooooooooomhooooo`00aoooool6o`000?oooooo=Oooool6o`0006oooooo
0037ooooo`03oiRHV?mEEEGooooo00;ooooo00?o0000ooooooooool0oooooolcooooo`03oiRHV?mE
EEGooooo00;ooooo00?o0000ooooooooool0KOooool00<Sooooo00?oV9RHoeEEEOooool0oooooolh
ooooo`03oiRHV?mEEEGooooo077ooooo0039ooooo`03oiRHV?mEEEGooooo0?oooooo>?ooool00onH
V9SoEEEEooooo`1`ooooo`00b_ooool00onHV9SoEEEEooooo`3oooooocSooooo00?oV9RHoeEEEOoo
ool0Koooool00<Oooooo00Ko0000oooooooooooooooooiRHV?mEEEGoooooocGooooo00Ko0000oooo
oooooooooooooiRHV?mEEEE_ooooo`00aoooool6o`000?oooooo=Oooool6o`0006oooooo003ooooo
ooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?oo
ool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooo
oooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhoooo
o`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00oooooooo
ooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo
003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003ooooooooo
ooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool0
0?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooo
oomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00
ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00oooooooooooo
ogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003o
ooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003ooooooooooooo
N?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oo
oooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomh
ooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00oooo
ooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSo
oooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003ooooo
ooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?oo
ool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooo
oooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhoooo
o`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00oooooooo
ooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo
003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003ooooooooo
ooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool0
0?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooo
oomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00
ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00oooooooooooo
ogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003o
ooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003ooooooooooooo
N?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oo
oooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomh
ooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00oooo
ooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSo
oooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003ooooo
ooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?oo
ool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooo
oooooomhooooo`00R_ooool4o`000003oa0@4?oooooooooo017ooooo00Co^[Zjoa0@4?l0003oMgMg
1_ooool00omEEEGo0000oeEEE@04ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^3_ooool01?nj
^[[o410@o`000?mgMgLDooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?oo
ool01_nHV9So410@o`000?l0003oA4A4onk^kQ?ooooo1?l000000ol@413oooooooooo`2dooooo`Co
000000?o410@ooooooooool04Oooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE
00Cooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h>ooooo`04okZj^_l@413o0000ogMgMaCooooo
00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06oiRHV?l@413o0000o`00
0?m4A4Cok^k^4oooool4o`000003oa0@4?oooooooooo02cooooo002<ooooo`03o`000?oooooooooo
01;ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool01_l@413oQhN7oooo
ooooooooMgMgodA4A0gooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJTBooooo`06olc<c?lb<S;o
k^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@Eoooo
o`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool04_ooool01_o<c<co<S8bonk^k_o^k^ko
8B4QojVYZ@Gooooo0ol00004ooooo`06oa0@4?n7QhOooooooooooomgMgOoA4A43Oooool01_o<c<co
<S8bonk^k_o^k^ko8B4QojVYZA;ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o0000
1?ooool01_l@413oQhN7ooooooooooooMgMgodA4A1Gooooo00?o0000ooooooooool0;_ooool008co
oooo00?o0000ooooooooool04_ooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEE
o`000?mEEED02Oooool00ol0003oooooooooo`0;ooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b
4_ooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED02Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool04_ooool01_m4
A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED02Oooool00ol0003ooooooooo
o`0;ooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b4_ooool01_m4A4CoZJVYooooooooooooZJVY
oc8b<PGooooo00?oEEEEo`000?mEEED02Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo02kooooo0020ooooo`Oo00001Oooool00ol0003oooooooooo`09ooooo`Oo00000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?ok^k^o`000?ooool03?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0>ooooo`03onk^k_l0003ooooo01Cooooo00?o0000ooooooooool0[?ooool7o`00
00Gooooo00?o0000ooooooooool02Oooool7o`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0>ooooo`03onk^k_l0003ooooo00cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00oo^
k^ko0000ooooo`0Dooooo`03o`000?oooooooooo02kooooo002<ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`06oa0@4?nHV9Sooooooooo
oomgMgOoIVIV3Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV
5Oooool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0:ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV3Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV5Oooool00ol0003ooooooooo
o`0^ooooo`00S?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02_ooool01Ol0003o8B4Qo`000?l0003oIVIV00kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool01Ol0003o8B4Qo`000?l0003oIVIV01Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Q
o`000?l0003oIVIV00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?l0003oIVIV
01Kooooo00?o0000ooooooooool0;_ooool008cooooo00?o0000ooooooooool04_ooool01_m4A4Co
ZJVYooooooooooooZJVYodA4A0cooooo00?o0000ooooooooool04?ooool01_m4A4CoZJVYoooooooo
ooooZJVYodA4A1;ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Booooo`06odA4A?nYZJWooooo
oooooonYZJWoA4A43?ooool00ol0003oooooooooo`0@ooooo`06odA4A?nYZJWooooooooooonYZJWo
A4A44_ooool01_m4A4CoZJVYooooooooooooZJVYodA4A0cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0^ooooo`00R_ooool00ol0003oA4A4o`00000Dooooo`06olc<c?lb<S;ok^k^
onk^k_lb<S;oc<c<3?ooool00ol0003oooooooooo`0@ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;o
c<c<4_ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00?o0000ooooooooool05_ooool0
0ol0003oA4A4o`00002hooooo`03o`000?m4A4Co000001Cooooo00Koc<c<oc8b<_o^k^kok^k^oc8b
<_o<c<`<ooooo`03o`000?oooooooooo013ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`Boooo
o`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool00ol0003oooooooooo`0Fooooo`03o`000?m4
A4Co0000033ooooo002:ooooo`03olc<c?mEEEGo000001Gooooo00Co^[Zjoa0@4?l@413oc<c<3Ooo
ool5o`0000oooooo00Co^[Zjoa0@4?l@413oc<c<5?ooool01?nj^[[o410@oa0@4?o<c<`=ooooo`Go
00005?ooool00oo<c<coEEEEo`00002hooooo`03olc<c?mEEEGo000001Gooooo00Co^[Zjoa0@4?l@
413oc<c<3Oooool5o`0000oooooo00Co^[Zjoa0@4?l@413oc<c<5?ooool01?nj^[[o410@oa0@4?o<
c<`=ooooo`Go00005?ooool00oo<c<coEEEEo`00000`ooooo`00ooooooooooooogSooooo003ooooo
ooooooooN?ooool00?oooooooooooomhooooo`00NooooonOo`0009[oooooX?l0000Rooooo`00Nooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0V?ooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool08?ooool007_o
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo09So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo023o
oooo001kooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`2Hooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`0Pooooo`00Noooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04_ooooo0_l0
002Jooooo`;o0000COooool00ol0003oooooooooo`1<ooooo`;o00008_ooool007_ooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo09Sooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo023ooooo001koooo
o`03o`000?oooooooooo04cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2Hoooo
o`03o`000?oooooooooo04cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Poooo
o`00Noooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool0V?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool08?ooool007;ooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2?ooooo`Co000000?o410@ooooooooool0
0_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
8?ooool007Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Pooooo`00M?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`2Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooo`00000?o`0003kooooo00?o0000ooooooooool08?ooool006Sooooo1ol00005oooo
o`03o`000?oooooooooo00Cooooo0_l0000moooooaOo0000Aoooool2o`0008Oooooo1ol00005oooo
o`03o`000?oooooooooo00Cooooo0_l00016ooooo`oo00002_ooool7o`0003Kooooo0_l0000Roooo
o`00M?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo0ol000001?oooooo
0000o`000?l0000<ooooo`03o`000?oooooooooo00?ooooo2Ol00010ooooo`03o`000?oooooooooo
097ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`?o00001Oooool4o`00
00;ooooo00?o0000ooooooooool02Oooool4o`0000Wooooo1?l0000cooooo`03o`000?oooooooooo
023ooooo001dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool5o`0000;o
oooo0_l0000?ooooo`03o`000?oooooooooo00Sooooo1Ol0000oooooo`03o`000?oooooooooo097o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0kooooo`?o00001?ooool4o`0000Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`?o0000<?ooool00ol0003o
ooooooooo`0Pooooo`00M?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo037ooooo
0ol000000ooooooo0000o`00000Eooooo`03o`000?oooooooooo00cooooo1?l000001?oooooo0000
o`000?l0000hooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0fooooo`;o00001_ooool4o`0000[ooooo00?o0000ooooooooool04_ooool2o`0000Wo
oooo0_l0000^ooooo`03o`000?oooooooooo023ooooo001booooo`03o`000?m4A4Co000000Kooooo
00?o0000ooooooooool0;_ooool3o`0000;ooooo0_l0000Gooooo`03o`000?oooooooooo013ooooo
0ol000000ooooooo0000ooooo`0fooooo`03o`000?oooooooooo08oooooo00?o0000odA4A?l00000
1_ooool00ol0003oooooooooo`0dooooo`;o00001oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01Cooooo0_l00009ooooo`;o0000;?ooool00ol0003oooooooooo`0Pooooo`00L_oo
ool00oo<c<coEEEEo`000006ooooo`03o`000?oooooooooo02_ooooo0ol00004ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool04oooool3o`0003Kooooo00?o0000ooooooooool0Sooo
ool00oo<c<coEEEEo`000006ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01Ooo
ool2o`0000oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`;o0000:_oo
ool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Yooooo`;o00008Oooool0
0ol0003oooooooooo`0Eooooo`;o0000=?ooool2o`0009[ooooo0_l0000iooooo`?o00004Oooool0
0ol0003oooooooooo`0Sooooo`;o00009oooool2o`0002;ooooo001kooooo`03o`000?oooooooooo
02Sooooo00Co0000oooooooooooooooo0_l0000Nooooo`03o`000?oooooooooo01Oooooo0_l00000
0ooooooo0000o`00000`ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0;Oooool2
o`0000Kooooo0ol0000Dooooo`03o`000?oooooooooo01_ooooo0_l00008ooooo`;o00009_ooool0
0ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Vooooo`;o00000oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_l0000^oooo
o`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`04oooo
o`;o00005oooool00ol0003oooooooooo`0Mooooo`;o00002?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo02Cooooo0_l00004ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool06_ooool2o`0000;ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo001kooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo01cooooo0_l0000^ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`03ooooo`;o00006_ooool00ol0003oooooooooo`0Yooooo`;o0000
8_ooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Qooooo`;o0000:Ooo
ool00ol0003oooooooooo`0Nooooo`04o`000?ooooooooooooooo`;o0000:?ooool00ol0003ooooo
ooooo`2Hooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Sooooo`;o00001_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo023ooooo
001kooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo01oooooo0_l00003ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0V?ooool00ol0003oooooooooo`0Uooooo`;o00001oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo027ooooo00Go0000
ooooooooooooooooo`00000Uooooo`;o0000V_ooool2o`0002Gooooo00?o0000ooooooooool01Ooo
ool2o`0001kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01cooooo0_l0000Rooooo`00Noooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Rooooo`05o`000?oooooo
ooooooooool000009Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo023ooooo001k
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2H
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0P
ooooo`00Noooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo09Sooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo0000
02;ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool06_ooool01Ol0003o
oooooooooooooooo000002gooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo
0000027ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00Cooooo0_l0000Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo
01Wooooo00Go0000ooooooooooooooooo`00000^ooooo`03o`000?oooooooooo02Oooooo00Go0000
ooooooooooooooooo`00000Pooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08?oo
ool007_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000002oooooo00?o
0000ooooooooool0:?ooool01Ol0003ooooooooooooooooo000001kooooo0_l0002Jooooo`;o0000
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo0_l0000Rooooo`00Nooo
ool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool00000<?ooool00ol0003ooooo
ooooo`0Yooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`2Hooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo09Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`00Noooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0V?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool0
07_ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000003?ooooo00?o0000
ooooooooool0;?ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0V?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0]ooooo`05o`000?oooooo
ooooooooool000006Oooool2o`0009[ooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04Oooool2o`0002;ooooo001kooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02kooooo00Go0000
ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08?oo
ool007_ooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000003Gooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0V?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0A
ooooo`05o`000?ooooooooooooooool00000=_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool08?ooool0063ooooo00Co^[Zjoa0@4?l0003oMgMg1_oo
ool00omEEEGo0000oeEEE@04ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo07gooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omE
EEGo0000oeEEE@04ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo023ooooo001Oooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY
1Oooool3o`0000Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@4ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0O?ooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol0
0004ooooo`06oa0@4?n7QhOooooooooooomgMgOoA4A41?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo023ooooo001Oooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omE
EEGo0000oeEEE@09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo037ooooo00Go0000ooooooooooooooooo`00000F
ooooo`03o`000?oooooooooo07cooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEE
EOl0003oEEEE00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool08?ooool005Kooooo1ol00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03_ooool00oo^k^ko0000ooooo`03ooooo`;o00003ooo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool0<Oooool01Ol0003ooooo
oooooooooooo000001Gooooo0_l0001eooooo`Oo00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00kooooo00?ok^k^o`000?ooool00oooool2o`0001Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0>ooooo`;o00008_ooool005oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0:ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV1?ooool00ol0
003oooooooooo`0>ooooo`05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0b
ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`1looooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool01_l@413oV9RHooooooooooooMgMgofIVIPCo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool08?ooool005oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0:ooooo`05o`000?lQ8B7o0000o`000?mVIVH01Oooool00ol0003oooooooooo`0=ooooo`05
o`000?ooooooooooooooool00000>_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?l0003oIVIV00Gooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool08?ooool005oooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0O?ooool01_m4A4CoZJVYooooooooooooZJVYodA4A0co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0hooooo`05o`000?oooooooooooooo
ool000004?ooool00ol0003oooooooooo`0Pooooo`00Goooool01_o<c<co<S8bonk^k_o^k^ko<S8b
olc<c0cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`05o`000?oooooo
ooooooooool00000>oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0O?ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool08?ooool0063ooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool5o`0000Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1mooooo`04okZj^_l@413o410@olc<c0gooooo1Ol00005oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool05?ooool2o`0009[ooooo0_l0000Fooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0;ooooo`;o00008_ooool007_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
8?ooool007_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo09Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo03[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo023ooooo
001kooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000mooooo`03o`00
0?oooooooooo03Kooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo09So
oooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000oooo
ooooool0>oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool08?ooool0
07_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
09Sooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo001koooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Hoooo
o`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000iooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0V?ooool00ol0
003oooooooooo`0>ooooo`05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0=oooool01?l0003oooooooooooooool2o`0000kooooo0_l0002Jooooo`;o00003oooool0
1?l0003oooooooooool0000jooooo`03o`000?oooooooooo03cooooo00Co0000oooooooooooo0000
3?ooool2o`0002;ooooo001kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0looooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool0
8?ooool007_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo09Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0Pooooo`00Nooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0V?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0?Ooo
ool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Hooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooo000000cooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool01oooool0
1Ol0003ooooooooooooooooo0000043ooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool03?ooool01?l0003ooooooooo
ool0000looooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Pooooo`00Noooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000
@?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
V?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo000003gooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`000010ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool03oooool2o`0009[ooooo0_l0000=ooooo`03o`000?oooooo000003gooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`09ooooo`;o00008_ooool007_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo09Sooooo00?o
0000ooooooooool03?ooool00ol0003oooooo`00000mooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2H
ooooo`03o`000?oooooooooo00_ooooo0ol0000nooooo`03o`000?oooooooooo03kooooo0ol0000<
ooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo000000cooooo00?o0000oooo
ooooool08?ooool007_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo09Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo03oooooo0_l0000<ooooo`03o`000?oooooooooo023ooooo001kooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0jooooo`05o`00
0?ooooooooooooooool000003Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0oooooo`;o00003?ooool00ol0003o
ooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo000000cooooo0_l0002Jooooo`;o
00003Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo0_l0000;ooooo`;o
00008_ooool0033ooooo00?o0000okZj^_ooool0B?ooool00ol0003oooooooooo`06ooooo`05o`00
0?ooooooooooooooool00000@Oooool00ol0003oooooooooo`0jooooo`05o`000?oooooooooooooo
ool000003Oooool00ol0003oooooooooo`1=ooooo`03o`000?nj^[[ooooo04Sooooo00?o0000oooo
ooooool02oooool2o`0003oooooo00?o0000ooooooooool0?oooool2o`0000cooooo00?o0000oooo
ooooool08?ooool0033ooooo00?o8B4QoeEEEOooool0B?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0COooool00olQ8B7oEEEEooooo`18ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool08?ooool0017ooooo00Wo410@o`000?l0003o
ooooo`000?l@413oooooo`000?l@41003?ooool4o`000003oa0@4?oooooooooo00?ooooo00?oIVIV
o`000?o^k^h01?ooool00ol@413o0000o`000004o`0000cooooo1?l000000ol@413oooooooooo`0Z
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05
ooooo`07oa0@4?l0003o410@ooooool@413o0000oa0@400Sooooo`09oa0@4?l0003o0000ooooool0
003o410@ooooool0003o410@00_ooooo1?l000000ol@413oooooooooo`03ooooo`03ofIVI_l0003o
k^k^00Cooooo00?o410@o`000?l000001?l0000;ooooo`Ko0000;?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Gooooo00Oo410@o`000?l@413ooooooa0@4?l0003o410@01Cooooo
000Booooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool6o`0000Gooooo
00?o0000ooooooooool01Oooool00onHV9So0000ogMgM`07ooooo`03o`000?oooooooooo00Cooooo
1_l00005ooooo`03o`000?oooooooooo02?ooooo00Co^[Zjoa0@4?l0003oMgMg1Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool01_lb<S;o
QhN7oooooonj^[[o0000onk^kRCooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ooooool6o`0000Gooooo00?o0000ooooooooool01Oooool00onHV9So0000ogMgM`07ooooo`03o`00
0?oooooooooo00Cooooo1_l00002ooooo`03oiRHV?l0003oc<c<00;ooooo00?o410@ooooooooool0
8Oooool01?nj^[[o410@o`000?mgMgL5ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01_ooool01_lb<S;oQhN7oooooonj^[[o0000onk^kQCooooo000Booooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03omgMgOl0003o
410@00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Rooooo`06olc<c?lb<S;o
k^k^onk^k_lQ8B7oZJVY1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`05onk^k_lQ8B7oc<c<ob4Q8Oo<
c<`09Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01Oooool00ooMgMgo0000oa0@4007ooooo`03o`000?oooooooooo00gooooo00?oV9RHo`00
0?o<c<`09?ooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03oooooo0_l0000<ooooo`03o`000?oo
oooooooo00Kooooo00Gok^k^ob4Q8Oo<c<co8B4Qolc<c00Eooooo`004_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo02;ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S84oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07oooo
o`03okZj^_l0003oQhN702Kooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00onYZJWo410@olc<c00S
ooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o^[Zjo`000?n7QhL05_ooool001;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Cooooo1_l00005ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02oooooioo00002?ooool01Oo^k^ko<S8bolc<c?lb<S;ok^k^02Go
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooooooool6o`0000Gooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`04ooooo`Ko00001Oooool00oo<c<co410@olc<c00R
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oooonPo`0000Sooooo00Gok^k^
oc8b<_o<c<co<S8bonk^kP0Eooooo`004_ooool01ol0003oc<c<olc<c?l0003oQhN7olc<c?l00000
3oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00GoEEEEogMgMooooooo
QhN7oeEEE@0Uooooo`07o`000?o<c<coc<c<o`000?n7QhOoc<c<o`00000>ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04?ooool00onYZJWo<S8booooo`0Qooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Kooooo00GoEEEEogMgMoooooooQhN7oeEEE@0Eooooo`004Oooool02?l@413o0000ob4Q8Ol0
003oMgMgoa0@4?l0003oQhN73oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool01ol@413o0000oa0@4?oooooo410@o`000?l@41008oooool0
2?l@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oQhN73_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool2o`00043ooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00Oo410@o`000?l@
413ooooooa0@4?l0003o410@01Cooooo000Vooooo`03o`000?m4A4Co0000017ooooo00?o0000oooo
ooooool03Oooool00ol0003oA4A4o`00000Tooooo`06odA4A?nYZJWooooooooooonYZJWoA4A41?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0jooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooo
ooooo`13ooooo`03o`000?m4A4Co0000017ooooo00?o0000ooooooooool03?ooool01_l0003oQhN7
onk^k_ooooooMgMgoc8b<R;ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@4ooooo`03o`000?oo
oooooooo00[ooooo0_l00010ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Pooooo`009_ooool00oo<c<coEEEEo`00000Aooooo`03o`000?oooooo
oooo00gooooo00?oc<c<oeEEEOl000009?ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04?ooooo
00?oc<c<oeEEEOl000004Oooool00ol0003oooooooooo`0<ooooo`06ojVYZOlb<S;o0000o`000?mE
EEGok^k^8_ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0Cooooo00?o0000ooooooooool02_oo
ool2o`00043ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo023ooooo000hooooo`03oa0@4?l0003o000003Oooooo00Co^[Zjoa0@4?l@413oc<c<1Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0EOoo
ool00ol@413o0000o`00000gooooo`04okZj^_l@413o410@olc<c0Gooooo00?o0000ooooooooool0
2_ooool2o`00043ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo023ooooo001kooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`000011ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03_ooool2o`0009[ooooo
0_l0000;ooooo`;o0000@?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00_ooooo
0_l0000Rooooo`00Noooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
@Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
V?ooool00ol0003oooooooooo`0:ooooo`;o0000@?ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo03[ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo03gooooo00?o0000ooooool000003Oooool00ol0003ooooo
ooooo`0Pooooo`00Noooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0
V?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
?Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2Hooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooo000000gooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo03cooooo00?o0000ooooool000003_ooool0
0ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooool00000?oooool00ol0003oooooooooo`0looooo`03o`000?oooooo0000
00kooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool01oooool01Ol0003o
oooooooooooooooo0000043ooooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo
000000gooooo0_l0002Jooooo`;o00002oooool00ol0003oooooo`00000oooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooool000003Oooool2o`0002;ooooo001kooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`000010ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooool00000?oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool08?ooool007_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo09Sooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000n
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0P
ooooo`00Noooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000?oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0V?ooool0
0ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0hooooo`05o`000?oooooo
ooooooooool000003oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000oooooo00?o
0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo03[ooooo00Co0000oooooooooooo00003oooool00ol0003ooooooooo
o`0Pooooo`00Noooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo0_l0002J
ooooo`;o00002oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooool000003oooool2o`0002;ooooo001kooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0iooooo`04o`000?ooooooooooo`00013ooooo00?o0000
ooooooooool08?ooool007_ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo
000003kooooo00?o0000ooooooooool0=oooool01Ol0003ooooooooooooooooo0000013ooooo00?o
0000ooooooooool0V?ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0003gooooo
00?o0000ooooooooool0>?ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000oooooooo
ool08?ooool007_ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000003ko
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`00
03gooooo00?o0000ooooooooool0>?ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000
ooooooooool08?ooool007_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo09Sooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo
000003cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo023ooooo001kooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000m
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2H
ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000looooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Pooooo`00Noooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0V?ooool0
0ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool00000>oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03Gooooo00Go0000
ooooooooooooooooo`00000Aooooo`;o0000V_ooool2o`0000gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0fooooo`05o`000?ooooooooooooooool000004Oooool2o`0002;ooooo
001kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`2Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Pooooo`00Noooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool0=?ooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool0V?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08?oo
ool007_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo09Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo023ooooo001Pooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool0
1_nHV9So410@o`000?l0003oA4A4onk^kPCooooo00?o0000ooooooooool03Oooool01Ol0003ooooo
oooooooooooo000003[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0OOooool01?nj^[[o410@o`000?mgMgL6oooo
o`03oeEEEOl0003oEEEE00Cooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h4ooooo`03o`000?oo
oooooooo00kooooo00Go0000ooooooooooooooooo`00000iooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo023ooooo
001Oooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7Qooo
ooooooooogMgMom4A4@4ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00
000jooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1looooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7Qooo
ooooooooogMgMom4A4@4ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00
000iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Pooooo`00Goooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED0
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooo
ooooo`00000iooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`1looooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@09
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo023ooooo001Oooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03_ooool00oo^k^ko0000ooooo`03ooooo`;o00003oooool01Ol0003ooooooooooooooooo
000003Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Gooooo`;o0000O_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?ok^k^o`000?ooool00oooool2
o`0000oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool06?ooool2o`0002;ooooo001Oooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02_ooool01_l@413oV9RHooooooooooooMgMgofIVIPCooooo00?o
0000ooooooooool03oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool0
<?ooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000ooooooooool0O?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH4
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo023ooooo001Oooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02_ooool01Ol0003o8B4Qo`000?l0003oIVIV00Gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000o`000?mVIVH01Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08?ooool005oooooo00KoA4A4
ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo00Go0000oooooooooooo
ooooo`00000Hooooo`03o`000?oooooooooo07cooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo023ooooo001Oooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`1looooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Pooooo`00H?ooool01?nj^[[o410@oa0@4?o<c<`=ooooo`Go00001Oooool00ol0003o
ooooooooo`0Booooo`05o`000?ooooooooooooooool00000=Oooool00ol0003oooooooooo`0^oooo
o`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`1mooooo`04okZj^_l@413o
410@olc<c0gooooo1Ol00005ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooo
oooo01;ooooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool06oooool2o`0009[ooooo0_l0000Cooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01gooooo0_l0
000Rooooo`00Noooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool00000=?oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0V?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08?oo
ool007_ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000003?ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo09Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo023ooooo001k
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09Sooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo001kooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Hooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`00
Noooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`;o0000V_oo
ool2o`0001Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`;o00008_oo
ool007_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo09Sooooo00?o0000ooooooooool05oooool2o`0000Kooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08?ooool0
07_ooooo00?o0000ooooooooool06_ooool2o`0000?ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0V?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Rooooo`;o0000:Oooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool08_ooool2o`0000Co
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0V?ooool00ol0003ooooo
ooooo`0Kooooo`;o0000;oooool00ol0003oooooooooo`0Oooooo`;o00001oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo01kooooo0_l0
0003ooooo`;o00009oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01?ooool2o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo0_l0002J
ooooo`;o00007oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo0_l0000R
ooooo`00Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0V?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Kooooo`;o0000<?ooool00ol0003oooooooooo`0Poooo
o`00Noooool00ol0003oooooooooo`0Rooooo`;o00000oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo01cooooo0_l0000^ooooo`03o`000?oooooooooo09Sooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool06Oooool2o`0003;ooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
0_ooool2o`0002[ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`06ooooo`;o0000
:_ooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Uooooo`;o00009Ooo
ool00ol0003oooooooooo`0Iooooo`;o00000oooool2o`0002cooooo00?o0000ooooooooool0V?oo
ool00ol0003oooooooooo`0Rooooo`;o0000:?ooool00ol0003oooooooooo`0Fooooo`;o00001ooo
ool2o`0002cooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000ooooooooool09oooool0
1?l0003oooooooooooooool2o`0001oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0V?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00Gooooo0_l0000Nooooo`03o`000?oooooooooo01Cooooo0_l0
0008ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo09Sooooo00?o0000
ooooooooool09Oooool2o`0000Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0B
ooooo`;o0000>Oooool00ol0003oooooooooo`0Pooooo`00Noooool00ol0003oooooooooo`0Yoooo
o`?o00000_ooool2o`0001cooooo00?o0000ooooooooool05Oooool2o`000003ooooool0003o0000
037ooooo0_l0002Jooooo`;o0000:?ooool00ol0003oooooooooo`05ooooo`;o00006oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo0_l0000booooo`;o00008_ooool007_o
oooo00?o0000ooooooooool0;?ooool3o`0001gooooo00?o0000ooooooooool04_ooool3o`0000;o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0?ooooo`;o00001_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo023ooooo001kooooo`03o`000?oooooooooo02oooooo
0ol000001?oooooo0000o`000?l0000Fooooo`03o`000?oooooooooo00oooooo0ol00002ooooo`?o
0000=Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo02Wooooo0ol00008ooooo`?o
00005Oooool00ol0003oooooooooo`0=ooooo`;o00001_ooool2o`0003Kooooo00?o0000oooooooo
ool08?ooool007_ooooo00?o0000ooooooooool0<_ooool3o`000003ooooool0003o000001Cooooo
00?o0000ooooooooool03?ooool3o`0003gooooo00?o0000ooooooooool0V?ooool00ol0003ooooo
ooooo`0/ooooo`?o00002?ooool2o`0001?ooooo00?o0000ooooooooool02_ooool3o`00043ooooo
00?o0000ooooooooool08?ooool007;ooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oo
oooooooo03Gooooo1?l0000Cooooo`03o`000?oooooooooo00Oooooo2_l0000kooooo`03o`000?oo
oooooooo08oooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo02oooooo0ol0
0007ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool3o`0000?ooooo1Ol0
000kooooo`03o`000?oooooooooo023ooooo001dooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0>Oooool8o`0000_ooooo00?o0000ooooooooool01?ooool3o`0000Cooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0<_ooool3o`0000Sooooo1Ol0000:ooooo`03o`000?oooooooooo00Cooooo0ol00005
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool08?ooool007Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0looooo`Ko00001?ooool2o`0000?ooooo2ol00015oooo
o`03o`000?oooooooooo097ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0eoooo
o`Go00002?ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo2?l00015oooo
o`03o`000?oooooooooo023ooooo001dooooo`03o`000?oooooooooo00Cooooo0_l00013ooooo`_o
0000COooool2o`0009?ooooo00?o0000ooooooooool01?ooool2o`0003_ooooo5Ol0001<ooooo`;o
00008_ooool007Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Pooooo`00M?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo023ooooo001dooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo097ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool08?ooool007;ooooo00?o0000odA4A?l000001_ooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0Soooool00ol0
003oA4A4o`000006ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0Pooooo`00L_ooool00oo<c<coEEEEo`000006ooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2?ooooo`03olc<c?mEEEGo000000Ko
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo023o
oooo001kooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0Boooool2o`0009[ooooo
0_l0001=ooooo`03o`000?oooooooooo04cooooo0_l0000Rooooo`00Noooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0V?ooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool08?ooool007_ooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo09Sooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo023ooooo001koooo
o`03o`000?oooooooooo04cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2Hoooo
o`03o`000?oooooooooo04cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Poooo
o`00Noooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool0V?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool08?ooool007_ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo09Sooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo023ooooo001kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08?oo
ool007_oooooWol0002Joooooj3o00008_ooool00?oooooooooooomhooooo`00ooooooooooooogSo
oooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003ooooo
ooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo0037ooooo`Ko0000oooo
ooleooooo`Ko0000Koooool00<Oooooo00?oV9RHoeEEEOooool00_ooool00ol0003oooooooooo`3o
oooooc?ooooo00?oV9RHoeEEEOooool00_ooool00ol0003oooooooooo`1]ooooo`00b?ooool00onH
V9SoEEEEooooo`3oooooocSooooo00?oV9RHoeEEEOooool0LOooool00<Wooooo00?oV9RHoeEEEOoo
ool0oooooolhooooo`03oiRHV?mEEEGooooo073ooooo003:ooooo`03oiRHV?mEEEGooooo0?oooooo
>?ooool00onHV9SoEEEEooooo`1_ooooo`00aoooool01_l0003oooooooooooooooooV9RHoeEEEOoo
oooo=Oooool01_l0003oooooooooooooooooV9RHoeEEEFoooooo0037ooooo`Ko0000ooooooleoooo
o`Ko0000Koooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?oo
ool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooo
oooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhoooo
o`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00oooooooo
ooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo
003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003ooooooooo
ooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool0
0?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooo
oomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00
ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00oooooooooooo
ogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003o
ooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003ooooooooooooo
N?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oo
oooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomh
ooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00oooo
ooooooooogSooooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSo
oooo003oooooooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003ooooo
ooooooooN?ooool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?oo
ool00?oooooooooooomhooooo`00ooooooooooooogSooooo003oooooooooooooN?ooool00001\
\>"],
  ImageRangeCache->{{{0, 629}, {629, 0}} -> {-0.0500105, -0.0500105, \
0.005008, 0.005008}, {{14.9375, 300.188}, {614, 328.75}} -> {-3.06805, \
-2.343, 0.0227643, 0.0227643}, {{328.75, 614}, {614, 328.75}} -> {-7.83054, \
-2.343, 0.0227643, 0.0227643}, {{14.9375, 300.188}, {300.188, 14.9375}} -> \
{-3.06805, -7.10549, 0.0227643, 0.0227643}, {{328.75, 614}, {300.188, \
14.9375}} -> {-7.83054, -7.10549, 0.0227643, 0.0227643}}],

Cell[TextData[{
  "Fig. 3.12 ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1\)]],
  " Spherical harmonics"
}], "Caption",
  CellTags->"Fig. 3.12"],

Cell[TextData[{
  "\tOne can see that the",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(l = 1, \ m = \(\[PlusMinus]1\)\)\)\)]],
  " distortions correspond to displacements of the ball in the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-",
  StyleBox["y",
    FontSlant->"Italic"],
  " plane ; the ",
  Cell[BoxData[
      \(TraditionalForm\`l = 2, \ m = \(\[PlusMinus]1\)\)]],
  " modes correspond to a tilted elliptical distortion. The distortion can be \
rotated about the ",
  StyleBox["z-",
    FontSlant->"Italic"],
  "axis through any angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_o\)]],
  " by multiplying the spherical harmonic by a complex number ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\[Phi]\_o\)\)]],
  " before taking the real part. Three -dimensional visualizations of some of \
these modes can also be found in Sec. ",
  ButtonBox["4.4.2",
    ButtonData:>{"Chapter4.nb", "c:40"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example", "Section",
  CellTags->"c:38"],

Cell[TextData[{
  "\tConsider a hollow conducting sphere where the upper half is grounded and \
the lower half is held at potential ",
  Cell[BoxData[
      \(TraditionalForm\`V\_o\)]],
  ":"
}], "Text"],

Cell[TextData[{
  " \t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(V(\[Theta], \[Phi])\), " ", "=", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->16], 
              StyleBox[GridBox[{
                    {\(V\_o, \ \ \ 0\  < \ \[Theta] < \[Pi]/2, \)},
                    {\(0\ \ \ \ \ \ \ \ \ \ \ \ \(\(otherwise\)\(.\)\)\)}
                    }],
                ShowAutoStyles->True]}],
            (#&)], " "}], TraditionalForm]]],
  "   "
}], "Text"],

Cell[TextData[{
  " The potential within the sphere is found by first dropping terms in Eq. \
",
  ButtonBox["(3.2.35)",
    ButtonData:>"(3.2.35)",
    ButtonStyle->"Hyperlink"],
  "  proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`1/r\^\(l + 1\)\)]],
  " :"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[CapitalPsi](r, \[Theta], \[Phi])\), "=", 
        RowBox[{
          
          FormBox[\(\[Sum]\+\(l = 0\)\%\[Infinity]\(\[Sum]\+\(m = \(-l\)\)\%l \
B\_\(l\ m\)\ r\^l\ \(\(Y\_\(l, \ m\)\)(\[Theta], \[Phi])\)\)\),
            "TraditionalForm"], "."}]}], TraditionalForm]]]], "NE2",
  CellTags->"(3.2.41)"],

Cell[TextData[{
  "Matching this solution to  ",
  Cell[BoxData[
      \(TraditionalForm\`V(\[Theta], \[Phi])\)]],
  ", we obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(l = 0\)\%\[Infinity]\(\[Sum]\+\(m = \(-l\)\
\)\%l B\_\(l\ m\)\ a\^l\ \(\(Y\_\(l, \ m\)\)(\[Theta], \[Phi])\)\) = 
        V(\[Theta], \[Phi])\)]],
  ". Multiplying both sides by the complex conjugate of a spherical harmonic \
and integrating over the unit sphere, we pick out a single term in the sum \
according to Eq. ",
  ButtonBox["(3.2.40)",
    ButtonData:>"(3.2.40)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`B\_\(l\ m\)\ a\^l = \[Integral]\_0\%\(2\ \[Pi]\)\
\[DifferentialD]\[Phi] \(\[Integral]\_0\%\[Pi] 
              sin\ \[Theta] \[DifferentialD]\[Theta]\ \(\(Y\_\(l, \ m\)\^*\)(\
\[Theta], \[Phi])\) \(\(V(\[Theta], \[Phi])\)\(\ \)\(.\)\)\)\)]]], "NE2",
  CellTags->"(3.2.42)"],

Cell[TextData[{
  "This result is equivalent to Eq. ",
  ButtonBox["(3.2.38)",
    ButtonData:>"(3.2.38)",
    ButtonStyle->"Hyperlink"],
  " but is more compact, thanks to the orthonormality of the spherical \
harmonics. Evaluating the integral over \[Phi] for our example, we obtain "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(l\ m\)\ a\^l = 
        2\ \[Pi]\ \(V\_o\) \(\[Delta]\_\(m\ \ 0\)\) \
\(\[Integral]\_0\%\(\[Pi]/2\)sin\[Theta] \[DifferentialD]\[Theta]\ \
\(\(Y\_\(l, \ 0\)\)(\[Theta], \[Phi])\)\)\)]]
}], "Text"],

Cell[TextData[{
  "Thanks to the cylindrical symmetry of the boundary condition, only ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\)\(=\)\(0\)\(\ \)\)\)]],
  " spherical harmonics enter in the expansion of the potential. The integral \
over \[Theta] can be evaluated analytically by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for given values of ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ": "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vlist = \ 
      2\ Pi\ \(V\_o\) 
        Table[Integrate[
            Sin[\[Theta]]\ SphericalHarmonicY[l, 
                0, \[Theta], \[Phi]], {\[Theta], 0, Pi/2}], {l, 0, 
            20}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.22"],

Cell[BoxData[
    \({\@\[Pi]\ V\_o, 1\/2\ \@\(3\ \[Pi]\)\ V\_o, 
      0, \(-\(1\/8\)\)\ \@\(7\ \[Pi]\)\ V\_o, 0, 
      1\/16\ \@\(11\ \[Pi]\)\ V\_o, 
      0, \(-\(5\/128\)\)\ \@\(15\ \[Pi]\)\ V\_o, 0, 
      7\/256\ \@\(19\ \[Pi]\)\ V\_o, 
      0, \(-\(\(21\ \@\(23\ \[Pi]\)\ V\_o\)\/1024\)\), 
      0, \(99\ \@\(3\ \[Pi]\)\ V\_o\)\/2048, 
      0, \(-\(\(429\ \@\(31\ \[Pi]\)\ V\_o\)\/32768\)\), 
      0, \(715\ \@\(35\ \[Pi]\)\ V\_o\)\/65536, 
      0, \(-\(\(2431\ \@\(39\ \[Pi]\)\ V\_o\)\/262144\)\), 0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This list of integrals can then be used to construct the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPsi]\)]],
  " using Eq. ",
  ButtonBox["(3.2.41)",
    ButtonData:>"(3.2.41)",
    ButtonStyle->"Hyperlink"],
  ",  keeping terms up to ",
  Cell[BoxData[
      \(TraditionalForm\`l = 20\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\[CapitalPsi][r_, \[Theta]_, \[Phi]_]\  = \ 
        Sum[vlist[\([l + 1]\)] 
            SphericalHarmonicY[l, 0, \[Theta], \[Phi]]\ \((r/a)\)^l, {l, 0, 
            20}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.23"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["3.24",
    ButtonData:>"Cell 3.24",
    ButtonStyle->"Hyperlink"],
  " we plot the solution as a surface plot  in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - z\)]],
  " plane, taking ",
  Cell[BoxData[
      \(TraditionalForm\`V\_o = 1\ Volt\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a = 1;\)\), "\n", 
    \(\(V\_o\  = \ 1;\)\), "\n", 
    \(\(ParametricPlot3D[{r\ Sin[\[Theta]], r\ Cos[\[Theta]], 
          Evaluate[\[CapitalPsi][r, \[Theta], 0]]}, {r, 0, 
          a}, {\[Theta], \(-Pi\), Pi}, 
        AxesLabel \[Rule] {"\<x\>", "\<z\>", "\<\>"}, \ \n
        PlotLabel \[Rule] "\<Potential inside a sphere\>", 
        PlotPoints \[Rule] {20, 100}, \ 
        ViewPoint -> {2.557, \ \(-0.680\), \ 1.414}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.24"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85725 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.109305 1.1093 -0.068643 1.1093 [
[.5 .86975 -77 0 ]
[.5 .86975 77 12 ]
[.02352 .4158 -12 -5.07164 ]
[.02352 .4158 0 3.92836 ]
[.04171 .3337 -24 -5.10866 ]
[.04171 .3337 0 3.89134 ]
[.06234 .24057 -6 -5.15082 ]
[.06234 .24057 0 3.84918 ]
[.08594 .13405 -18 -5.19924 ]
[.08594 .13405 0 3.80076 ]
[.1132 .01101 -6 -5.25546 ]
[.1132 .01101 0 3.74454 ]
[-0.00628 .23065 -10 -6.86776 ]
[-0.00628 .23065 0 5.13224 ]
[.15197 -0.01026 -5.54033 -9 ]
[.15197 -0.01026 6.45967 0 ]
[.35737 .02459 -11.7268 -9 ]
[.35737 .02459 12.2732 0 ]
[.55461 .05809 -3.08409 -9 ]
[.55461 .05809 2.91591 0 ]
[.74416 .09032 -9.68429 -9 ]
[.74416 .09032 8.31571 0 ]
[.92647 .12134 -3.36439 -9 ]
[.92647 .12134 2.63561 0 ]
[.55257 -0.01123 -5.14003 -12 ]
[.55257 -0.01123 4.85997 0 ]
[.964 .17578 0 -3.75512 ]
[.964 .17578 6 5.24488 ]
[.97435 .25774 0 -3.79383 ]
[.97435 .25774 24 5.20617 ]
[.98513 .34313 0 -3.83426 ]
[.98513 .34313 18 5.16574 ]
[.99636 .43215 0 -3.8765 ]
[.99636 .43215 24 5.1235 ]
[1.00809 .52505 0 -3.9207 ]
[1.00809 .52505 6 5.0793 ]
[ 0 0 0 0 ]
[ 1 .85725 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .86975 -138 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Potential) show
123.000 13.000 moveto
(inside) show
165.000 13.000 moveto
(a) show
177.000 13.000 moveto
(sphere) show
213.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03558 .4252 m
.12983 0 L
s
.03728 .41755 m
.04416 .41843 L
s
[(-1)] .02352 .4158 1 .12703 Mshowa
.05545 .33556 m
.06232 .33649 L
s
[(-0.5)] .04171 .3337 1 .13526 Mshowa
.07606 .24256 m
.08293 .24355 L
s
[(0)] .06234 .24057 1 .14463 Mshowa
.09964 .13618 m
.10649 .13724 L
s
[(0.5)] .08594 .13405 1 .15539 Mshowa
.12688 .01331 m
.13371 .01446 L
s
[(1)] .1132 .01101 1 .16788 Mshowa
.125 Mabswid
.04074 .40194 m
.04487 .40247 L
s
.04428 .38595 m
.04841 .38648 L
s
.04792 .36956 m
.05204 .37011 L
s
.05164 .35277 m
.05576 .35332 L
s
.05936 .3179 m
.06349 .31847 L
s
.06338 .2998 m
.0675 .30037 L
s
.0675 .28122 m
.07162 .28179 L
s
.07172 .26214 m
.07584 .26273 L
s
.08052 .22244 m
.08464 .22304 L
s
.08511 .20177 m
.08922 .20238 L
s
.08982 .18051 m
.09393 .18113 L
s
.09466 .15866 m
.09877 .15929 L
s
.10477 .11304 m
.10888 .11369 L
s
.11005 .08921 m
.11416 .08987 L
s
.11549 .06467 m
.1196 .06534 L
s
.1211 .03938 m
.1252 .04006 L
s
gsave
-0.00628 .23065 -71 -10.8678 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.12983 0 m
.94587 .1381 L
s
.15091 .00357 m
.15038 .01048 L
s
[(-1)] .15197 -0.01026 -0.07661 1 Mshowa
.35705 .03846 m
.3569 .04539 L
s
[(-0.5)] .35737 .02459 -0.02277 1 Mshowa
.55499 .07195 m
.55519 .07888 L
s
[(0)] .55461 .05809 .02803 1 Mshowa
.74521 .10415 m
.74574 .11106 L
s
[(0.5)] .74416 .09032 .07603 1 Mshowa
.92814 .1351 m
.92898 .14199 L
s
[(1)] .92647 .12134 .12146 1 Mshowa
.125 Mabswid
.19282 .01066 m
.19254 .01481 L
s
.23438 .01769 m
.23415 .02185 L
s
.27561 .02467 m
.27542 .02883 L
s
.3165 .03159 m
.31636 .03575 L
s
.39728 .04526 m
.39723 .04942 L
s
.43719 .05202 m
.43718 .05618 L
s
.47677 .05872 m
.4768 .06288 L
s
.51604 .06536 m
.51611 .06952 L
s
.59364 .07849 m
.5938 .08265 L
s
.63198 .08498 m
.63218 .08914 L
s
.67002 .09142 m
.67026 .09557 L
s
.70776 .09781 m
.70804 .10196 L
s
.78237 .11043 m
.78272 .11458 L
s
.81923 .11667 m
.81962 .12081 L
s
.85582 .12286 m
.85625 .127 L
s
.89212 .12901 m
.89258 .13314 L
s
gsave
.55257 -0.01123 -66.14 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.94587 .1381 m
1 .56832 L
s
.95032 .17352 m
.94348 .17239 L
s
[(0)] .964 .17578 -1 -0.16553 Mshowa
.96065 .25559 m
.9538 .25452 L
s
[(0.25)] .97435 .25774 -1 -0.15693 Mshowa
.97141 .3411 m
.96455 .34008 L
s
[(0.5)] .98513 .34313 -1 -0.14794 Mshowa
.98263 .43025 m
.97576 .4293 L
s
[(0.75)] .99636 .43215 -1 -0.13855 Mshowa
.99433 .52328 m
.98746 .5224 L
s
[(1)] 1.00809 .52505 -1 -0.12873 Mshowa
.125 Mabswid
.95236 .18967 m
.94825 .189 L
s
.9544 .20595 m
.9503 .20528 L
s
.95647 .22236 m
.95236 .22171 L
s
.95855 .23891 m
.95444 .23826 L
s
.96277 .27241 m
.95866 .27178 L
s
.9649 .28937 m
.96079 .28874 L
s
.96705 .30647 m
.96294 .30585 L
s
.96922 .32371 m
.96511 .3231 L
s
.97362 .35863 m
.9695 .35803 L
s
.97584 .37631 m
.97172 .37571 L
s
.97808 .39414 m
.97396 .39355 L
s
.98035 .41212 m
.97623 .41154 L
s
.98493 .44854 m
.98081 .44797 L
s
.98725 .46698 m
.98313 .46643 L
s
.98959 .48559 m
.98547 .48504 L
s
.99195 .50435 m
.98783 .50382 L
s
.94831 .1575 m
.9442 .15681 L
s
.94631 .1416 m
.94221 .14091 L
s
.99674 .54238 m
.99261 .54186 L
s
.99916 .56164 m
.99503 .56113 L
s
.25 Mabswid
.03558 .4252 m
0 .79557 L
s
0 .79557 m
.68636 .85725 L
s
.68636 .85725 m
.66829 .50509 L
s
.66829 .50509 m
.03558 .4252 L
s
.12983 0 m
.94587 .1381 L
s
.94587 .1381 m
1 .56832 L
s
1 .56832 m
.09237 .4558 L
s
.09237 .4558 m
.12983 0 L
s
.03558 .4252 m
0 .79557 L
s
0 .79557 m
.09237 .4558 L
s
.09237 .4558 m
.12983 0 L
s
.12983 0 m
.03558 .4252 L
s
.66829 .50509 m
.94587 .1381 L
s
.94587 .1381 m
1 .56832 L
s
1 .56832 m
.68636 .85725 L
s
.68636 .85725 m
.66829 .50509 L
s
0 0 m
1 0 L
1 .85725 L
0 .85725 L
closepath
clip
newpath
.5 Mabswid
.33593 .51535 m .33186 .47185 L .34931 .54533 L p .969 .648 .306 r
F P
0 g
s
.33186 .47185 m .33593 .51535 L .31854 .49113 L p .827 .492 .422 r
F P
0 g
s
.31854 .49113 m .31348 .45834 L .33186 .47185 L p .827 .492 .422 r
F P
0 g
s
.31348 .45834 m .31854 .49113 L .301 .48633 L p .502 .149 .3 r
F P
0 g
s
.301 .48633 m .29442 .47648 L .31348 .45834 L p .502 .149 .3 r
F P
0 g
s
.29442 .47648 m .301 .48633 L .28379 .4833 L p 0 0 0 r
F P
0 g
s
.29153 .48784 m .28379 .4833 L .28686 .48384 L p .452 0 0 r
F P
0 g
s
.28686 .48384 m .301 .48633 L p .29153 .48784 L .452 0 0 r
F P
0 g
s
.29153 .48784 m .29933 .49435 L .29635 .49197 L p 0 .218 .651 r
F P
0 g
s
.28379 .4833 m .29153 .48784 L .28554 .48389 L p 0 .304 .717 r
F P
0 g
s
.28211 .48274 m .29442 .47648 L p .28379 .4833 L 0 0 0 r
F P
0 g
s
.28456 .48259 m .27587 .4775 L .29153 .48784 L p 0 .218 .651 r
F P
0 g
s
.29635 .49197 m .28456 .48259 L p .29153 .48784 L 0 .218 .651 r
F P
0 g
s
.28554 .48389 m .27587 .4775 L p .28379 .4833 L 0 .304 .717 r
F P
0 g
s
.28379 .4833 m .27589 .48591 L .28211 .48274 L p 0 0 0 r
F P
0 g
s
.35738 .58031 m .35315 .56977 L .3707 .64489 L p 0 0 .339 r
F P
0 g
s
.35315 .56977 m .35738 .58031 L .35349 .57064 L p .883 .537 .043 r
F P
0 g
s
.35281 .56893 m .35317 .57134 L p .35315 .56977 L 0 0 .127 r
F P
0 g
s
.35317 .57134 m .36684 .66338 L p .35333 .571 L 0 0 .127 r
F P
0 g
s
.35315 .56977 m .35317 .57134 L .35333 .571 L 0 0 .127 r
F
.36684 .66338 m .3707 .64489 L .35315 .56977 L p F P
0 g
s
.35349 .57064 m .34066 .5387 L p .35315 .56977 L .883 .537 .043 r
F P
0 g
s
.35315 .56977 m .34931 .54533 L .35281 .56893 L p 0 0 .127 r
F P
0 g
s
.34931 .54533 m .35315 .56977 L .33593 .51535 L p .969 .648 .306 r
F P
0 g
s
.34066 .5387 m .33593 .51535 L .34365 .53977 L p .883 .537 .043 r
F P
0 g
s
.34365 .53977 m .35315 .56977 L p .34066 .5387 L .883 .537 .043 r
F P
0 g
s
.34579 .55068 m .34066 .5387 L .34756 .55588 L p 0 0 .295 r
F P
0 g
s
.34756 .55588 m .35349 .57064 L p .34579 .55068 L 0 0 .295 r
F P
0 g
s
.34579 .55068 m .35117 .55614 L .34393 .54525 L p 0 0 .486 r
F P
0 g
s
.34066 .5387 m .34579 .55068 L .33751 .53757 L p .782 .338 0 r
F P
0 g
s
.33751 .53757 m .33002 .52571 L p .34066 .5387 L .782 .338 0 r
F P
0 g
s
.34393 .54525 m .33621 .53363 L p .34579 .55068 L 0 0 .486 r
F P
0 g
s
.35349 .57064 m .35738 .58031 L p .35355 .57052 L 0 0 .295 r
F P
0 g
s
.34579 .55068 m .35349 .57064 L .35355 .57052 L 0 0 .295 r
F
.3241 .51238 m .31854 .49113 L .33593 .51535 L p .895 .485 .213 r
F P
0 g
s
.31854 .49113 m .3241 .51238 L .30766 .4979 L p .721 .249 .126 r
F P
0 g
s
.30766 .4979 m .301 .48633 L .31854 .49113 L p .721 .249 .126 r
F P
0 g
s
.27589 .48591 m .28379 .4833 L .26727 .47356 L p .132 .474 .895 r
F P
0 g
s
.26727 .47356 m .25869 .47225 L .27589 .48591 L p .132 .474 .895 r
F P
0 g
s
.33593 .51535 m .34066 .5387 L .3241 .51238 L p .895 .485 .213 r
F P
0 g
s
.301 .48633 m .30766 .4979 L .29153 .48784 L p .452 0 0 r
F P
0 g
s
.25869 .47225 m .26727 .47356 L .25139 .46132 L p 0 .056 .596 r
F P
0 g
s
.26073 .467 m .25139 .46132 L .26727 .47356 L p 0 .225 .689 r
F P
0 g
s
.25139 .46132 m .26073 .467 L .25513 .46361 L p 0 .286 .669 r
F P
0 g
s
.2478 .45912 m .25869 .47225 L p .25139 .46132 L 0 .056 .596 r
F P
0 g
s
.25139 .46132 m .24234 .45253 L .2478 .45912 L p 0 .056 .596 r
F P
0 g
s
.24234 .45253 m .25139 .46132 L .23588 .45329 L p .563 0 0 r
F P
0 g
s
.24607 .45813 m .23588 .45329 L .25139 .46132 L p 0 .286 .669 r
F P
0 g
s
.25513 .46361 m .24607 .45813 L p .25139 .46132 L 0 .286 .669 r
F P
0 g
s
.23588 .45329 m .22597 .44585 L .24234 .45253 L p .563 0 0 r
F P
0 g
s
.27587 .4775 m .26727 .47356 L .28379 .4833 L p 0 .304 .717 r
F P
0 g
s
.22597 .44585 m .23588 .45329 L .22078 .44921 L p .087 0 0 r
F P
0 g
s
.22078 .44921 m .23194 .45082 L .22929 .44931 L p .292 .701 .974 r
F P
0 g
s
.2125 .4491 m .22597 .44585 L p .22078 .44921 L .087 0 0 r
F P
0 g
s
.22929 .44931 m .21845 .44314 L p .22078 .44921 L .292 .701 .974 r
F P
0 g
s
.22078 .44921 m .20964 .44979 L .2125 .4491 L p .087 0 0 r
F P
0 g
s
.26727 .47356 m .27587 .4775 L .26073 .467 L p 0 .225 .689 r
F P
0 g
s
.33002 .52571 m .3241 .51238 L .34066 .5387 L p .782 .338 0 r
F P
0 g
s
.3241 .51238 m .33002 .52571 L .31452 .5079 L p .716 .191 0 r
F P
0 g
s
.31452 .5079 m .30766 .4979 L .3241 .51238 L p .716 .191 0 r
F P
0 g
s
.30766 .4979 m .31452 .5079 L .29933 .49435 L p .521 0 0 r
F P
0 g
s
.29933 .49435 m .29153 .48784 L .30766 .4979 L p .521 0 0 r
F P
0 g
s
.23588 .45329 m .24607 .45813 L .23194 .45082 L p 0 .541 .811 r
F P
0 g
s
.23194 .45082 m .22078 .44921 L .23588 .45329 L p 0 .541 .811 r
F P
0 g
s
.20964 .44979 m .22078 .44921 L .2064 .44338 L p .541 .874 .991 r
F P
0 g
s
.2064 .44338 m .19422 .44784 L .20964 .44979 L p .541 .874 .991 r
F P
0 g
s
.27587 .4775 m .28456 .48259 L .27026 .47185 L p 0 .288 .732 r
F P
0 g
s
.27026 .47185 m .26073 .467 L .27587 .4775 L p 0 .288 .732 r
F P
0 g
s
.26073 .467 m .27026 .47185 L .25645 .4622 L p 0 .38 .791 r
F P
0 g
s
.25645 .4622 m .24607 .45813 L .26073 .467 L p 0 .38 .791 r
F P
0 g
s
.3707 .64489 m .3745 .63161 L .35738 .58031 L p 0 0 .339 r
F P
0 g
s
.36185 .58352 m .35738 .58031 L .3745 .63161 L p 0 0 .515 r
F P
0 g
s
.35738 .58031 m .36185 .58352 L .34579 .55068 L p 0 0 .295 r
F P
0 g
s
.3707 .64489 m .36684 .66338 L .38575 .7703 L p .162 .127 .568 r
F P
0 g
s
.32158 .51543 m .31452 .5079 L .33002 .52571 L p 0 0 .507 r
F P
0 g
s
.30729 .50053 m .29933 .49435 L .31452 .5079 L p 0 .112 .603 r
F P
0 g
s
.31452 .5079 m .32158 .51543 L .30729 .50053 L p 0 .112 .603 r
F P
0 g
s
.33621 .53363 m .33002 .52571 L .34579 .55068 L p 0 0 .486 r
F P
0 g
s
.33002 .52571 m .33621 .53363 L .32158 .51543 L p 0 0 .507 r
F P
0 g
s
.21845 .44314 m .2064 .44338 L .22078 .44921 L p .292 .701 .974 r
F P
0 g
s
.29933 .49435 m .30729 .50053 L .2934 .48777 L p 0 .233 .705 r
F P
0 g
s
.2934 .48777 m .28456 .48259 L .29933 .49435 L p 0 .233 .705 r
F P
0 g
s
.24607 .45813 m .25645 .4622 L .24319 .45341 L p .027 .514 .877 r
F P
0 g
s
.24319 .45341 m .23194 .45082 L .24607 .45813 L p .027 .514 .877 r
F P
0 g
s
.19422 .44784 m .2064 .44338 L .19297 .433 L p .452 .609 .914 r
F P
0 g
s
.19297 .433 m .18029 .43306 L .19422 .44784 L p .452 .609 .914 r
F P
0 g
s
.35117 .55614 m .34579 .55068 L .36185 .58352 L p 0 0 .546 r
F P
0 g
s
.38575 .7703 m .38913 .71425 L .3707 .64489 L p .162 .127 .568 r
F P
0 g
s
.3745 .63161 m .3707 .64489 L .38913 .71425 L p .17 .164 .609 r
F P
0 g
s
.28456 .48259 m .2934 .48777 L .27995 .4764 L p 0 .323 .778 r
F P
0 g
s
.27995 .4764 m .27026 .47185 L .28456 .48259 L p 0 .323 .778 r
F P
0 g
s
.27026 .47185 m .27995 .4764 L .26699 .46609 L p 0 .408 .837 r
F P
0 g
s
.26699 .46609 m .25645 .4622 L .27026 .47185 L p 0 .408 .837 r
F P
0 g
s
.2064 .44338 m .21845 .44314 L .20573 .434 L p .344 .631 .959 r
F P
0 g
s
.20573 .434 m .19297 .433 L .2064 .44338 L p .344 .631 .959 r
F P
0 g
s
.18029 .43306 m .19297 .433 L .1804 .42146 L p .236 .467 .878 r
F P
0 g
s
.1804 .42146 m .16732 .41614 L .18029 .43306 L p .236 .467 .878 r
F P
0 g
s
.23194 .45082 m .24319 .45341 L .23054 .44477 L p .189 .602 .944 r
F P
0 g
s
.23054 .44477 m .21845 .44314 L .23194 .45082 L p .189 .602 .944 r
F P
0 g
s
.3745 .63161 m .3783 .62093 L .36185 .58352 L p 0 0 .515 r
F P
0 g
s
.36646 .58277 m .36185 .58352 L .3783 .62093 L p 0 .102 .632 r
F P
0 g
s
.36185 .58352 m .36646 .58277 L .35117 .55614 L p 0 0 .546 r
F P
0 g
s
.38913 .71425 m .39224 .6799 L .3745 .63161 L p .17 .164 .609 r
F P
0 g
s
.3783 .62093 m .3745 .63161 L .39224 .6799 L p .189 .212 .653 r
F P
0 g
s
.32884 .52051 m .32158 .51543 L .33621 .53363 L p 0 .14 .681 r
F P
0 g
s
.32158 .51543 m .32884 .52051 L .31542 .50554 L p 0 .206 .722 r
F P
0 g
s
.31542 .50554 m .30729 .50053 L .32158 .51543 L p 0 .206 .722 r
F P
0 g
s
.25645 .4622 m .26699 .46609 L .25457 .45651 L p .057 .492 .891 r
F P
0 g
s
.25457 .45651 m .24319 .45341 L .25645 .4622 L p .057 .492 .891 r
F P
0 g
s
.34261 .53783 m .33621 .53363 L .35117 .55614 L p 0 .112 .665 r
F P
0 g
s
.33621 .53363 m .34261 .53783 L .32884 .52051 L p 0 .14 .681 r
F P
0 g
s
.30729 .50053 m .31542 .50554 L .3024 .4924 L p 0 .283 .772 r
F P
0 g
s
.3024 .4924 m .2934 .48777 L .30729 .50053 L p 0 .283 .772 r
F P
0 g
s
.2934 .48777 m .3024 .4924 L .28981 .48063 L p 0 .354 .819 r
F P
0 g
s
.28981 .48063 m .27995 .4764 L .2934 .48777 L p 0 .354 .819 r
F P
0 g
s
.16732 .41614 m .1804 .42146 L .16846 .41296 L p .016 .514 .87 r
F P
0 g
s
.16846 .41296 m .15457 .40901 L .16732 .41614 L p .016 .514 .87 r
F P
0 g
s
.35673 .55772 m .35117 .55614 L .36646 .58277 L p 0 .14 .677 r
F P
0 g
s
.35117 .55614 m .35673 .55772 L .34261 .53783 L p 0 .112 .665 r
F P
0 g
s
.19297 .433 m .20573 .434 L .19379 .4243 L p .283 .577 .939 r
F P
0 g
s
.19379 .4243 m .1804 .42146 L .19297 .433 L p .283 .577 .939 r
F P
0 g
s
.21845 .44314 m .23054 .44477 L .21858 .43578 L p .267 .609 .955 r
F P
0 g
s
.21858 .43578 m .20573 .434 L .21845 .44314 L p .267 .609 .955 r
F P
0 g
s
.39224 .6799 m .39522 .65667 L .3783 .62093 L p .189 .212 .653 r
F P
0 g
s
.38212 .61156 m .3783 .62093 L .39522 .65667 L p .214 .262 .696 r
F P
0 g
s
.3783 .62093 m .38212 .61156 L .36646 .58277 L p 0 .102 .632 r
F P
0 g
s
.24319 .45341 m .25457 .45651 L .24274 .4473 L p .16 .553 .929 r
F P
0 g
s
.24274 .4473 m .23054 .44477 L .24319 .45341 L p .16 .553 .929 r
F P
0 g
s
.27995 .4764 m .28981 .48063 L .27769 .46987 L p .011 .421 .86 r
F P
0 g
s
.27769 .46987 m .26699 .46609 L .27995 .4764 L p .011 .421 .86 r
F P
0 g
s
.37119 .5798 m .36646 .58277 L .38212 .61156 L p .077 .215 .706 r
F P
0 g
s
.36646 .58277 m .37119 .5798 L .35673 .55772 L p 0 .14 .677 r
F P
0 g
s
.40628 .8157 m .40853 .75455 L .38913 .71425 L p .595 .45 .655 r
F P
0 g
s
.38913 .71425 m .38575 .7703 L .40628 .8157 L p .595 .45 .655 r
F P
0 g
s
.39224 .6799 m .38913 .71425 L .40853 .75455 L p .522 .419 .679 r
F P
0 g
s
.26699 .46609 m .27769 .46987 L .2661 .45985 L p .09 .481 .895 r
F P
0 g
s
.2661 .45985 m .25457 .45651 L .26699 .46609 L p .09 .481 .895 r
F P
0 g
s
.40853 .75455 m .41061 .71404 L .39224 .6799 L p .522 .419 .679 r
F P
0 g
s
.39522 .65667 m .39224 .6799 L .41061 .71404 L p .456 .398 .704 r
F P
0 g
s
.20573 .434 m .21858 .43578 L .20735 .42662 L p .284 .605 .953 r
F P
0 g
s
.20735 .42662 m .19379 .4243 L .20573 .434 L p .284 .605 .953 r
F P
0 g
s
.1804 .42146 m .19379 .4243 L .18259 .41543 L p .248 .623 .958 r
F P
0 g
s
.18259 .41543 m .16846 .41296 L .1804 .42146 L p .248 .623 .958 r
F P
0 g
s
.33628 .5235 m .32884 .52051 L .34261 .53783 L p 0 .25 .762 r
F P
0 g
s
.32884 .52051 m .33628 .5235 L .32373 .50914 L p 0 .286 .787 r
F P
0 g
s
.32373 .50914 m .31542 .50554 L .32884 .52051 L p 0 .286 .787 r
F P
0 g
s
.23054 .44477 m .24274 .4473 L .23155 .43818 L p .231 .583 .945 r
F P
0 g
s
.23155 .43818 m .21858 .43578 L .23054 .44477 L p .231 .583 .945 r
F P
0 g
s
.31542 .50554 m .32373 .50914 L .31157 .49617 L p 0 .333 .816 r
F P
0 g
s
.31157 .49617 m .3024 .4924 L .31542 .50554 L p 0 .333 .816 r
F P
0 g
s
.34919 .53943 m .34261 .53783 L .35673 .55772 L p 0 .237 .748 r
F P
0 g
s
.34261 .53783 m .34919 .53943 L .33628 .5235 L p 0 .25 .762 r
F P
0 g
s
.15457 .40901 m .16846 .41296 L .15724 .40665 L p .223 .741 .85 r
F P
0 g
s
.15724 .40665 m .14223 .40848 L .15457 .40901 L p .223 .741 .85 r
F P
0 g
s
.3024 .4924 m .31157 .49617 L .29983 .48436 L p .022 .384 .846 r
F P
0 g
s
.29983 .48436 m .28981 .48063 L .3024 .4924 L p .022 .384 .846 r
F P
0 g
s
.39522 .65667 m .39816 .63933 L .38212 .61156 L p .214 .262 .696 r
F P
0 g
s
.38597 .60286 m .38212 .61156 L .39816 .63933 L p .24 .308 .733 r
F P
0 g
s
.38212 .61156 m .38597 .60286 L .37119 .5798 L p .077 .215 .706 r
F P
0 g
s
.46858 .76348 m .46973 .77477 L .49087 .78978 L p .358 .488 .853 r
F P
0 g
s
.46973 .77477 m .46858 .76348 L .44853 .76224 L p .717 .705 .838 r
F P
0 g
s
.44853 .76224 m .44869 .77773 L .46973 .77477 L p .717 .705 .838 r
F P
0 g
s
.41061 .71404 m .4126 .68519 L .39522 .65667 L p .456 .398 .704 r
F P
0 g
s
.39816 .63933 m .39522 .65667 L .4126 .68519 L p .407 .39 .728 r
F P
0 g
s
.44869 .77773 m .44853 .76224 L .42847 .76466 L p .825 .674 .695 r
F P
0 g
s
.42847 .76466 m .42752 .80293 L .44869 .77773 L p .825 .674 .695 r
F P
0 g
s
.36243 .55688 m .35673 .55772 L .37119 .5798 L p .063 .252 .745 r
F P
0 g
s
.35673 .55772 m .36243 .55688 L .34919 .53943 L p 0 .237 .748 r
F P
0 g
s
.25457 .45651 m .2661 .45985 L .25506 .4503 L p .163 .529 .921 r
F P
0 g
s
.25506 .4503 m .24274 .4473 L .25457 .45651 L p .163 .529 .921 r
F P
0 g
s
.28981 .48063 m .29983 .48436 L .28855 .47345 L p .074 .433 .873 r
F P
0 g
s
.28855 .47345 m .27769 .46987 L .28981 .48063 L p .074 .433 .873 r
F P
0 g
s
.376 .57549 m .37119 .5798 L .38597 .60286 L p .161 .293 .752 r
F P
0 g
s
.37119 .5798 m .376 .57549 L .36243 .55688 L p .063 .252 .745 r
F P
0 g
s
.19379 .4243 m .20735 .42662 L .19687 .41765 L p .302 .633 .964 r
F P
0 g
s
.19687 .41765 m .18259 .41543 L .19379 .4243 L p .302 .633 .964 r
F P
0 g
s
.21858 .43578 m .23155 .43818 L .22105 .4291 L p .274 .6 .951 r
F P
0 g
s
.22105 .4291 m .20735 .42662 L .21858 .43578 L p .274 .6 .951 r
F P
0 g
s
.42847 .76466 m .4294 .732 L .41061 .71404 L p .677 .544 .695 r
F P
0 g
s
.41061 .71404 m .40853 .75455 L .42847 .76466 L p .677 .544 .695 r
F P
0 g
s
.4126 .68519 m .41061 .71404 L .4294 .732 L p .594 .504 .722 r
F P
0 g
s
.42752 .80293 m .42847 .76466 L .40853 .75455 L p .763 .59 .664 r
F P
0 g
s
.40853 .75455 m .40628 .8157 L .42752 .80293 L p .763 .59 .664 r
F P
0 g
s
.48864 .77005 m .49087 .78978 L .51194 .79778 L p .573 .553 .794 r
F P
0 g
s
.49087 .78978 m .48864 .77005 L .46858 .76348 L p .358 .488 .853 r
F P
0 g
s
.27769 .46987 m .28855 .47345 L .27778 .46325 L p .128 .477 .897 r
F P
0 g
s
.27778 .46325 m .2661 .45985 L .27769 .46987 L p .128 .477 .897 r
F P
0 g
s
.4126 .68519 m .41455 .66319 L .39816 .63933 L p .407 .39 .728 r
F P
0 g
s
.40108 .62523 m .39816 .63933 L .41455 .66319 L p .376 .394 .752 r
F P
0 g
s
.39816 .63933 m .40108 .62523 L .38597 .60286 L p .24 .308 .733 r
F P
0 g
s
.16846 .41296 m .18259 .41543 L .17219 .40716 L p .342 .723 .985 r
F P
0 g
s
.17219 .40716 m .15724 .40665 L .16846 .41296 L p .342 .723 .985 r
F P
0 g
s
.24274 .4473 m .25506 .4503 L .24464 .44103 L p .222 .561 .936 r
F P
0 g
s
.24464 .44103 m .23155 .43818 L .24274 .4473 L p .222 .561 .936 r
F P
0 g
s
.44837 .74015 m .44853 .76224 L .46858 .76348 L p .682 .618 .777 r
F P
0 g
s
.44853 .76224 m .44837 .74015 L .4294 .732 L p .727 .606 .722 r
F P
0 g
s
.4294 .732 m .42847 .76466 L .44853 .76224 L p .727 .606 .722 r
F P
0 g
s
.4294 .732 m .43031 .70472 L .4126 .68519 L p .594 .504 .722 r
F P
0 g
s
.41455 .66319 m .4126 .68519 L .43031 .70472 L p .524 .475 .744 r
F P
0 g
s
.46739 .74572 m .46858 .76348 L .48864 .77005 L p .592 .583 .812 r
F P
0 g
s
.46858 .76348 m .46739 .74572 L .44837 .74015 L p .682 .618 .777 r
F P
0 g
s
.38987 .59451 m .38597 .60286 L .40108 .62523 L p .265 .348 .763 r
F P
0 g
s
.38597 .60286 m .38987 .59451 L .376 .57549 L p .161 .293 .752 r
F P
0 g
s
.34388 .52479 m .33628 .5235 L .34919 .53943 L p .079 .324 .802 r
F P
0 g
s
.33628 .5235 m .34388 .52479 L .33221 .5114 L p .07 .345 .82 r
F P
0 g
s
.33221 .5114 m .32373 .50914 L .33628 .5235 L p .07 .345 .82 r
F P
0 g
s
.32373 .50914 m .33221 .5114 L .32092 .49899 L p .079 .375 .84 r
F P
0 g
s
.32092 .49899 m .31157 .49617 L .32373 .50914 L p .079 .375 .84 r
F P
0 g
s
.43031 .70472 m .4294 .732 L .44837 .74015 L p .646 .558 .742 r
F P
0 g
s
.3559 .53919 m .34919 .53943 L .36243 .55688 L p .108 .317 .79 r
F P
0 g
s
.34919 .53943 m .3559 .53919 L .34388 .52479 L p .079 .324 .802 r
F P
0 g
s
.2661 .45985 m .27778 .46325 L .26754 .45355 L p .18 .515 .915 r
F P
0 g
s
.26754 .45355 m .25506 .4503 L .2661 .45985 L p .18 .515 .915 r
F P
0 g
s
.50862 .77409 m .51194 .79778 L .53261 .78806 L p .727 .639 .76 r
F P
0 g
s
.51194 .79778 m .50862 .77409 L .48864 .77005 L p .573 .553 .794 r
F P
0 g
s
.31157 .49617 m .32092 .49899 L .31003 .48747 L p .101 .41 .86 r
F P
0 g
s
.31003 .48747 m .29983 .48436 L .31157 .49617 L p .101 .41 .86 r
F P
0 g
s
.54785 .76627 m .5529 .77445 L .57317 .77287 L p .579 .75 .959 r
F P
0 g
s
.5529 .77445 m .54785 .76627 L .52837 .77139 L p .768 .713 .801 r
F P
0 g
s
.52837 .77139 m .53261 .78806 L .5529 .77445 L p .768 .713 .801 r
F P
0 g
s
.53261 .78806 m .52837 .77139 L .50862 .77409 L p .727 .639 .76 r
F P
0 g
s
.4864 .75108 m .48864 .77005 L .50862 .77409 L p .612 .59 .805 r
F P
0 g
s
.48864 .77005 m .4864 .75108 L .46739 .74572 L p .592 .583 .812 r
F P
0 g
s
.36825 .55447 m .36243 .55688 L .376 .57549 L p .156 .325 .783 r
F P
0 g
s
.36243 .55688 m .36825 .55447 L .3559 .53919 L p .108 .317 .79 r
F P
0 g
s
.4482 .71721 m .44837 .74015 L .46739 .74572 L p .64 .579 .77 r
F P
0 g
s
.44837 .74015 m .4482 .71721 L .43031 .70472 L p .646 .558 .742 r
F P
0 g
s
.43031 .70472 m .43121 .6818 L .41455 .66319 L p .524 .475 .744 r
F P
0 g
s
.41648 .64531 m .41455 .66319 L .43121 .6818 L p .471 .46 .764 r
F P
0 g
s
.41455 .66319 m .41648 .64531 L .40108 .62523 L p .376 .394 .752 r
F P
0 g
s
.20735 .42662 m .22105 .4291 L .21128 .4201 L p .309 .622 .959 r
F P
0 g
s
.21128 .4201 m .19687 .41765 L .20735 .42662 L p .309 .622 .959 r
F P
0 g
s
.14223 .40848 m .15724 .40665 L .14708 .39811 L p .596 .832 .989 r
F P
0 g
s
.14708 .39811 m .13128 .40154 L .14223 .40848 L p .596 .832 .989 r
F P
0 g
s
.43121 .6818 m .43031 .70472 L .4482 .71721 L p .58 .526 .759 r
F P
0 g
s
.23155 .43818 m .24464 .44103 L .23487 .43193 L p .267 .585 .945 r
F P
0 g
s
.23487 .43193 m .22105 .4291 L .23155 .43818 L p .267 .585 .945 r
F P
0 g
s
.29983 .48436 m .31003 .48747 L .29959 .4767 L p .132 .445 .879 r
F P
0 g
s
.29959 .4767 m .28855 .47345 L .29983 .48436 L p .132 .445 .879 r
F P
0 g
s
.18259 .41543 m .19687 .41765 L .18719 .4088 L p .354 .674 .977 r
F P
0 g
s
.18719 .4088 m .17219 .40716 L .18259 .41543 L p .354 .674 .977 r
F P
0 g
s
.40402 .61299 m .40108 .62523 L .41648 .64531 L p .36 .405 .773 r
F P
0 g
s
.40108 .62523 m .40402 .61299 L .38987 .59451 L p .265 .348 .763 r
F P
0 g
s
.46617 .72573 m .46739 .74572 L .4864 .75108 L p .614 .581 .794 r
F P
0 g
s
.46739 .74572 m .46617 .72573 L .4482 .71721 L p .64 .579 .77 r
F P
0 g
s
.38089 .57034 m .376 .57549 L .38987 .59451 L p .218 .349 .783 r
F P
0 g
s
.376 .57549 m .38089 .57034 L .36825 .55447 L p .156 .325 .783 r
F P
0 g
s
.50533 .75457 m .50862 .77409 L .52837 .77139 L p .675 .632 .799 r
F P
0 g
s
.50862 .77409 m .50533 .75457 L .4864 .75108 L p .612 .59 .805 r
F P
0 g
s
.56714 .76454 m .57317 .77287 L .59342 .78029 L p .246 .55 .93 r
F P
0 g
s
.57317 .77287 m .56714 .76454 L .54785 .76627 L p .579 .75 .959 r
F P
0 g
s
.25506 .4503 m .26754 .45355 L .25788 .44421 L p .227 .545 .928 r
F P
0 g
s
.25788 .44421 m .24464 .44103 L .25506 .4503 L p .227 .545 .928 r
F P
0 g
s
.44804 .69554 m .4482 .71721 L .46617 .72573 L p .597 .553 .776 r
F P
0 g
s
.4482 .71721 m .44804 .69554 L .43121 .6818 L p .58 .526 .759 r
F P
0 g
s
.28855 .47345 m .29959 .4767 L .28962 .46655 L p .168 .478 .896 r
F P
0 g
s
.28962 .46655 m .27778 .46325 L .28855 .47345 L p .168 .478 .896 r
F P
0 g
s
.48414 .73201 m .4864 .75108 L .50533 .75457 L p .616 .593 .805 r
F P
0 g
s
.4864 .75108 m .48414 .73201 L .46617 .72573 L p .614 .581 .794 r
F P
0 g
s
.5241 .75495 m .52837 .77139 L .54785 .76627 L p .689 .669 .825 r
F P
0 g
s
.52837 .77139 m .5241 .75495 L .50533 .75457 L p .675 .632 .799 r
F P
0 g
s
.4321 .66219 m .43121 .6818 L .44804 .69554 L p .527 .505 .774 r
F P
0 g
s
.43121 .6818 m .4321 .66219 L .41648 .64531 L p .471 .46 .764 r
F P
0 g
s
.15724 .40665 m .17219 .40716 L .16274 .39808 L p .473 .738 .986 r
F P
0 g
s
.16274 .39808 m .14708 .39811 L .15724 .40665 L p .473 .738 .986 r
F P
0 g
s
.39382 .58632 m .38987 .59451 L .40402 .61299 L p .287 .382 .786 r
F P
0 g
s
.38987 .59451 m .39382 .58632 L .38089 .57034 L p .218 .349 .783 r
F P
0 g
s
.41842 .63003 m .41648 .64531 L .4321 .66219 L p .434 .454 .781 r
F P
0 g
s
.41648 .64531 m .41842 .63003 L .40402 .61299 L p .36 .405 .773 r
F P
0 g
s
.54265 .75364 m .54785 .76627 L .56714 .76454 L p .62 .678 .884 r
F P
0 g
s
.54785 .76627 m .54265 .75364 L .5241 .75495 L p .689 .669 .825 r
F P
0 g
s
.46495 .7056 m .46617 .72573 L .48414 .73201 L p .597 .569 .793 r
F P
0 g
s
.46617 .72573 m .46495 .7056 L .44804 .69554 L p .597 .553 .776 r
F P
0 g
s
.22105 .4291 m .23487 .43193 L .2258 .42295 L p .305 .605 .952 r
F P
0 g
s
.2258 .42295 m .21128 .4201 L .22105 .4291 L p .305 .605 .952 r
F P
0 g
s
.27778 .46325 m .28962 .46655 L .28017 .45689 L p .204 .508 .91 r
F P
0 g
s
.28017 .45689 m .26754 .45355 L .27778 .46325 L p .204 .508 .91 r
F P
0 g
s
.50204 .73623 m .50533 .75457 L .5241 .75495 L p .637 .617 .814 r
F P
0 g
s
.50533 .75457 m .50204 .73623 L .48414 .73201 L p .616 .593 .805 r
F P
0 g
s
.19687 .41765 m .21128 .4201 L .20228 .41113 L p .349 .645 .965 r
F P
0 g
s
.20228 .41113 m .18719 .4088 L .19687 .41765 L p .349 .645 .965 r
F P
0 g
s
.35164 .52474 m .34388 .52479 L .3559 .53919 L p .164 .375 .824 r
F P
0 g
s
.34388 .52479 m .35164 .52474 L .34085 .51248 L p .154 .389 .837 r
F P
0 g
s
.34085 .51248 m .33221 .5114 L .34388 .52479 L p .154 .389 .837 r
F P
0 g
s
.33221 .5114 m .34085 .51248 L .33043 .50087 L p .156 .408 .852 r
F P
0 g
s
.33043 .50087 m .32092 .49899 L .33221 .5114 L p .156 .408 .852 r
F P
0 g
s
.36275 .53762 m .3559 .53919 L .36825 .55447 L p .185 .37 .814 r
F P
0 g
s
.3559 .53919 m .36275 .53762 L .35164 .52474 L p .164 .375 .824 r
F P
0 g
s
.44788 .67571 m .44804 .69554 L .46495 .7056 L p .556 .534 .786 r
F P
0 g
s
.44804 .69554 m .44788 .67571 L .4321 .66219 L p .527 .505 .774 r
F P
0 g
s
.24464 .44103 m .25788 .44421 L .24884 .43512 L p .267 .569 .937 r
F P
0 g
s
.24884 .43512 m .23487 .43193 L .24464 .44103 L p .267 .569 .937 r
F P
0 g
s
.40698 .60186 m .40402 .61299 L .41842 .63003 L p .353 .42 .791 r
F P
0 g
s
.40402 .61299 m .40698 .60186 L .39382 .58632 L p .287 .382 .786 r
F P
0 g
s
.32092 .49899 m .33043 .50087 L .3204 .4899 L p .167 .432 .867 r
F P
0 g
s
.3204 .4899 m .31003 .48747 L .32092 .49899 L p .167 .432 .867 r
F P
0 g
s
.37417 .55098 m .36825 .55447 L .38089 .57034 L p .218 .375 .807 r
F P
0 g
s
.36825 .55447 m .37417 .55098 L .36275 .53762 L p .185 .37 .814 r
F P
0 g
s
.48187 .71297 m .48414 .73201 L .50204 .73623 L p .601 .584 .806 r
F P
0 g
s
.48414 .73201 m .48187 .71297 L .46495 .7056 L p .597 .569 .793 r
F P
0 g
s
.17219 .40716 m .18719 .4088 L .1784 .39962 L p .416 .687 .974 r
F P
0 g
s
.1784 .39962 m .16274 .39808 L .17219 .40716 L p .416 .687 .974 r
F P
0 g
s
.433 .645 m .4321 .66219 L .44788 .67571 L p .486 .492 .789 r
F P
0 g
s
.4321 .66219 m .433 .645 L .41842 .63003 L p .434 .454 .781 r
F P
0 g
s
.51979 .73838 m .5241 .75495 L .54265 .75364 L p .64 .638 .832 r
F P
0 g
s
.5241 .75495 m .51979 .73838 L .50204 .73623 L p .637 .617 .814 r
F P
0 g
s
.58621 .76565 m .59342 .78029 L .61315 .7811 L p .545 .605 .864 r
F P
0 g
s
.59342 .78029 m .58621 .76565 L .56714 .76454 L p .246 .55 .93 r
F P
0 g
s
.56096 .75267 m .56714 .76454 L .58621 .76565 L p .537 .646 .904 r
F P
0 g
s
.56714 .76454 m .56096 .75267 L .54265 .75364 L p .62 .678 .884 r
F P
0 g
s
.31003 .48747 m .3204 .4899 L .31079 .47952 L p .184 .457 .881 r
F P
0 g
s
.31079 .47952 m .29959 .4767 L .31003 .48747 L p .184 .457 .881 r
F P
0 g
s
.38587 .56461 m .38089 .57034 L .39382 .58632 L p .259 .389 .805 r
F P
0 g
s
.38089 .57034 m .38587 .56461 L .37417 .55098 L p .218 .375 .807 r
F P
0 g
s
.13128 .40154 m .14708 .39811 L .13819 .38571 L p .545 .625 .883 r
F P
0 g
s
.13819 .38571 m .12214 .38399 L .13128 .40154 L p .545 .625 .883 r
F P
0 g
s
.26754 .45355 m .28017 .45689 L .27126 .44761 L p .239 .534 .921 r
F P
0 g
s
.27126 .44761 m .25788 .44421 L .26754 .45355 L p .239 .534 .921 r
F P
0 g
s
.46372 .68625 m .46495 .7056 L .48187 .71297 L p .57 .555 .798 r
F P
0 g
s
.46495 .7056 m .46372 .68625 L .44788 .67571 L p .556 .534 .786 r
F P
0 g
s
.42036 .61641 m .41842 .63003 L .433 .645 L p .41 .456 .797 r
F P
0 g
s
.41842 .63003 m .42036 .61641 L .40698 .60186 L p .353 .42 .791 r
F P
0 g
s
.49872 .71819 m .50204 .73623 L .51979 .73838 L p .609 .602 .819 r
F P
0 g
s
.50204 .73623 m .49872 .71819 L .48187 .71297 L p .601 .584 .806 r
F P
0 g
s
.29959 .4767 m .31079 .47952 L .30164 .46965 L p .207 .481 .894 r
F P
0 g
s
.30164 .46965 m .28962 .46655 L .29959 .4767 L p .207 .481 .894 r
F P
0 g
s
.53735 .73905 m .54265 .75364 L .56096 .75267 L p .613 .646 .859 r
F P
0 g
s
.54265 .75364 m .53735 .73905 L .51979 .73838 L p .64 .638 .832 r
F P
0 g
s
.39781 .5782 m .39382 .58632 L .40698 .60186 L p .306 .41 .805 r
F P
0 g
s
.39382 .58632 m .39781 .5782 L .38587 .56461 L p .259 .389 .805 r
F P
0 g
s
.44771 .65764 m .44788 .67571 L .46372 .68625 L p .519 .521 .797 r
F P
0 g
s
.44788 .67571 m .44771 .65764 L .433 .645 L p .486 .492 .789 r
F P
0 g
s
.21128 .4201 m .2258 .42295 L .21747 .41402 L p .34 .623 .956 r
F P
0 g
s
.21747 .41402 m .20228 .41113 L .21128 .4201 L p .34 .623 .956 r
F P
0 g
s
.23487 .43193 m .24884 .43512 L .24046 .4262 L p .302 .589 .943 r
F P
0 g
s
.24046 .4262 m .2258 .42295 L .23487 .43193 L p .302 .589 .943 r
F P
0 g
s
.14708 .39811 m .16274 .39808 L .15432 .38761 L p .488 .666 .941 r
F P
0 g
s
.15432 .38761 m .13819 .38571 L .14708 .39811 L p .488 .666 .941 r
F P
0 g
s
.47958 .69432 m .48187 .71297 L .49872 .71819 L p .578 .572 .81 r
F P
0 g
s
.48187 .71297 m .47958 .69432 L .46372 .68625 L p .57 .555 .798 r
F P
0 g
s
.18719 .4088 m .20228 .41113 L .19412 .40204 L p .387 .657 .965 r
F P
0 g
s
.19412 .40204 m .1784 .39962 L .18719 .4088 L p .387 .657 .965 r
F P
0 g
s
.61315 .7811 m .60488 .76435 L .58621 .76565 L p .545 .605 .864 r
F P
0 g
s
.57899 .75212 m .58621 .76565 L .60488 .76435 L p .579 .642 .877 r
F P
0 g
s
.58621 .76565 m .57899 .75212 L .56096 .75267 L p .537 .646 .904 r
F P
0 g
s
.4339 .62956 m .433 .645 L .44771 .65764 L p .455 .487 .803 r
F P
0 g
s
.433 .645 m .4339 .62956 L .42036 .61641 L p .41 .456 .797 r
F P
0 g
s
.51545 .72156 m .51979 .73838 L .53735 .73905 L p .61 .617 .834 r
F P
0 g
s
.51979 .73838 m .51545 .72156 L .49872 .71819 L p .609 .602 .819 r
F P
0 g
s
.25788 .44421 m .27126 .44761 L .26294 .43862 L p .272 .555 .929 r
F P
0 g
s
.26294 .43862 m .24884 .43512 L .25788 .44421 L p .272 .555 .929 r
F P
0 g
s
.40997 .59141 m .40698 .60186 L .42036 .61641 L p .352 .435 .807 r
F P
0 g
s
.40698 .60186 m .40997 .59141 L .39781 .5782 L p .306 .41 .805 r
F P
0 g
s
.28962 .46655 m .30164 .46965 L .29296 .46022 L p .231 .505 .905 r
F P
0 g
s
.29296 .46022 m .28017 .45689 L .28962 .46655 L p .231 .505 .905 r
F P
0 g
s
.60488 .76435 m .61315 .7811 L .63199 .76947 L p .695 .654 .806 r
F P
0 g
s
.55467 .73902 m .56096 .75267 L .57899 .75212 L p .584 .643 .876 r
F P
0 g
s
.56096 .75267 m .55467 .73902 L .53735 .73905 L p .613 .646 .859 r
F P
0 g
s
.46249 .668 m .46372 .68625 L .47958 .69432 L p .539 .542 .806 r
F P
0 g
s
.46372 .68625 m .46249 .668 L .44771 .65764 L p .519 .521 .797 r
F P
0 g
s
.35953 .52362 m .35164 .52474 L .36275 .53762 L p .224 .412 .838 r
F P
0 g
s
.35164 .52474 m .35953 .52362 L .34965 .51255 L p .215 .421 .847 r
F P
0 g
s
.34965 .51255 m .34085 .51248 L .35164 .52474 L p .215 .421 .847 r
F P
0 g
s
.36972 .53504 m .36275 .53762 L .37417 .55098 L p .239 .408 .83 r
F P
0 g
s
.36275 .53762 m .36972 .53504 L .35953 .52362 L p .224 .412 .838 r
F P
0 g
s
.34085 .51248 m .34965 .51255 L .34012 .50189 L p .214 .434 .858 r
F P
0 g
s
.34012 .50189 m .33043 .50087 L .34085 .51248 L p .214 .434 .858 r
F P
0 g
s
.49538 .70032 m .49872 .71819 L .51545 .72156 L p .584 .588 .822 r
F P
0 g
s
.49872 .71819 m .49538 .70032 L .47958 .69432 L p .578 .572 .81 r
F P
0 g
s
.16274 .39808 m .1784 .39962 L .17054 .38994 L p .442 .669 .959 r
F P
0 g
s
.17054 .38994 m .15432 .38761 L .16274 .39808 L p .442 .669 .959 r
F P
0 g
s
.38018 .54671 m .37417 .55098 L .38587 .56461 L p .262 .411 .824 r
F P
0 g
s
.37417 .55098 m .38018 .54671 L .36972 .53504 L p .239 .408 .83 r
F P
0 g
s
.33043 .50087 m .34012 .50189 L .33095 .49167 L p .218 .45 .869 r
F P
0 g
s
.33095 .49167 m .3204 .4899 L .33043 .50087 L p .218 .45 .869 r
F P
0 g
s
.12214 .38399 m .13819 .38571 L .13036 .37299 L p .417 .549 .881 r
F P
0 g
s
.13036 .37299 m .11412 .36641 L .12214 .38399 L p .417 .549 .881 r
F P
0 g
s
.53199 .72349 m .53735 .73905 L .55467 .73902 L p .599 .627 .85 r
F P
0 g
s
.53735 .73905 m .53199 .72349 L .51545 .72156 L p .61 .617 .834 r
F P
0 g
s
.42232 .6039 m .42036 .61641 L .4339 .62956 L p .395 .461 .811 r
F P
0 g
s
.42036 .61641 m .42232 .6039 L .40997 .59141 L p .352 .435 .807 r
F P
0 g
s
.44755 .64106 m .44771 .65764 L .46249 .668 L p .487 .512 .809 r
F P
0 g
s
.44771 .65764 m .44755 .64106 L .4339 .62956 L p .455 .487 .803 r
F P
0 g
s
.28017 .45689 m .29296 .46022 L .28481 .45114 L p .257 .526 .914 r
F P
0 g
s
.28481 .45114 m .27126 .44761 L .28017 .45689 L p .257 .526 .914 r
F P
0 g
s
.62297 .7584 m .63199 .76947 L .65024 .75678 L p .723 .728 .854 r
F P
0 g
s
.63199 .76947 m .62297 .7584 L .60488 .76435 L p .695 .654 .806 r
F P
0 g
s
.39091 .55846 m .38587 .56461 L .39781 .5782 L p .29 .42 .821 r
F P
0 g
s
.38587 .56461 m .39091 .55846 L .38018 .54671 L p .262 .411 .824 r
F P
0 g
s
.2258 .42295 m .24046 .4262 L .23278 .41739 L p .332 .605 .947 r
F P
0 g
s
.23278 .41739 m .21747 .41402 L .2258 .42295 L p .332 .605 .947 r
F P
0 g
s
.3204 .4899 m .33095 .49167 L .32218 .48187 L p .228 .468 .88 r
F P
0 g
s
.32218 .48187 m .31079 .47952 L .3204 .4899 L p .228 .468 .88 r
F P
0 g
s
.47728 .67628 m .47958 .69432 L .49538 .70032 L p .552 .56 .816 r
F P
0 g
s
.47958 .69432 m .47728 .67628 L .46249 .668 L p .539 .542 .806 r
F P
0 g
s
.20228 .41113 m .21747 .41402 L .20993 .40508 L p .371 .635 .957 r
F P
0 g
s
.20993 .40508 m .19412 .40204 L .20228 .41113 L p .371 .635 .957 r
F P
0 g
s
.59665 .7504 m .60488 .76435 L .62297 .7584 L p .642 .664 .856 r
F P
0 g
s
.60488 .76435 m .59665 .7504 L .57899 .75212 L p .579 .642 .877 r
F P
0 g
s
.24884 .43512 m .26294 .43862 L .25525 .42983 L p .302 .573 .935 r
F P
0 g
s
.25525 .42983 m .24046 .4262 L .24884 .43512 L p .302 .573 .935 r
F P
0 g
s
.51107 .70458 m .51545 .72156 L .53199 .72349 L p .585 .601 .834 r
F P
0 g
s
.51545 .72156 m .51107 .70458 L .49538 .70032 L p .584 .588 .822 r
F P
0 g
s
.5717 .73848 m .57899 .75212 L .59665 .7504 L p .588 .646 .875 r
F P
0 g
s
.57899 .75212 m .5717 .73848 L .55467 .73902 L p .584 .643 .876 r
F P
0 g
s
.40186 .57009 m .39781 .5782 L .40997 .59141 L p .322 .433 .82 r
F P
0 g
s
.39781 .5782 m .40186 .57009 L .39091 .55846 L p .29 .42 .821 r
F P
0 g
s
.4348 .61539 m .4339 .62956 L .44755 .64106 L p .432 .485 .815 r
F P
0 g
s
.4339 .62956 m .4348 .61539 L .42232 .6039 L p .395 .461 .811 r
F P
0 g
s
.31079 .47952 m .32218 .48187 L .31383 .47247 L p .242 .486 .89 r
F P
0 g
s
.31383 .47247 m .30164 .46965 L .31079 .47952 L p .242 .486 .89 r
F P
0 g
s
.46125 .65085 m .46249 .668 L .47728 .67628 L p .51 .532 .815 r
F P
0 g
s
.46249 .668 m .46125 .65085 L .44755 .64106 L p .487 .512 .809 r
F P
0 g
s
.13819 .38571 m .15432 .38761 L .14693 .37685 L p .442 .633 .936 r
F P
0 g
s
.14693 .37685 m .13036 .37299 L .13819 .38571 L p .442 .633 .936 r
F P
0 g
s
.54831 .72436 m .55467 .73902 L .5717 .73848 L p .587 .632 .864 r
F P
0 g
s
.55467 .73902 m .54831 .72436 L .53199 .72349 L p .599 .627 .85 r
F P
0 g
s
.1784 .39962 m .19412 .40204 L .18683 .39276 L p .414 .658 .96 r
F P
0 g
s
.18683 .39276 m .17054 .38994 L .1784 .39962 L p .414 .658 .96 r
F P
0 g
s
.49202 .68273 m .49538 .70032 L .51107 .70458 L p .559 .575 .826 r
F P
0 g
s
.49538 .70032 m .49202 .68273 L .47728 .67628 L p .552 .56 .816 r
F P
0 g
s
.64053 .75153 m .65024 .75678 L .66841 .7548 L p .44 .763 .996 r
F P
0 g
s
.65024 .75678 m .64053 .75153 L .62297 .7584 L p .723 .728 .854 r
F P
0 g
s
.27126 .44761 m .28481 .45114 L .2772 .44235 L p .282 .544 .921 r
F P
0 g
s
.2772 .44235 m .26294 .43862 L .27126 .44761 L p .282 .544 .921 r
F P
0 g
s
.413 .58138 m .40997 .59141 L .42232 .6039 L p .355 .45 .821 r
F P
0 g
s
.40997 .59141 m .413 .58138 L .40186 .57009 L p .322 .433 .82 r
F P
0 g
s
.30164 .46965 m .31383 .47247 L .30593 .46343 L p .258 .504 .899 r
F P
0 g
s
.30593 .46343 m .29296 .46022 L .30164 .46965 L p .258 .504 .899 r
F P
0 g
s
.52658 .70741 m .53199 .72349 L .54831 .72436 L p .582 .611 .847 r
F P
0 g
s
.53199 .72349 m .52658 .70741 L .51107 .70458 L p .585 .601 .834 r
F P
0 g
s
.44738 .62569 m .44755 .64106 L .46125 .65085 L p .461 .507 .819 r
F P
0 g
s
.44755 .64106 m .44738 .62569 L .4348 .61539 L p .432 .485 .815 r
F P
0 g
s
.61385 .74677 m .62297 .7584 L .64053 .75153 L p .647 .697 .883 r
F P
0 g
s
.62297 .7584 m .61385 .74677 L .59665 .7504 L p .642 .664 .856 r
F P
0 g
s
.47496 .65897 m .47728 .67628 L .49202 .68273 L p .525 .549 .823 r
F P
0 g
s
.47728 .67628 m .47496 .65897 L .46125 .65085 L p .51 .532 .815 r
F P
0 g
s
.58837 .73706 m .59665 .7504 L .61385 .74677 L p .607 .659 .875 r
F P
0 g
s
.59665 .7504 m .58837 .73706 L .5717 .73848 L p .588 .646 .875 r
F P
0 g
s
.4243 .59212 m .42232 .6039 L .4348 .61539 L p .387 .469 .823 r
F P
0 g
s
.42232 .6039 m .4243 .59212 L .413 .58138 L p .355 .45 .821 r
F P
0 g
s
.21747 .41402 m .23278 .41739 L .22584 .40865 L p .36 .617 .949 r
F P
0 g
s
.22584 .40865 m .20993 .40508 L .21747 .41402 L p .36 .617 .949 r
F P
0 g
s
.24046 .4262 m .25525 .42983 L .24821 .42121 L p .328 .588 .939 r
F P
0 g
s
.24821 .42121 m .23278 .41739 L .24046 .4262 L p .328 .588 .939 r
F P
0 g
s
.36756 .52166 m .35953 .52362 L .36972 .53504 L p .267 .439 .846 r
F P
0 g
s
.35953 .52362 m .36756 .52166 L .3586 .51179 L p .26 .445 .854 r
F P
0 g
s
.3586 .51179 m .34965 .51255 L .35953 .52362 L p .26 .445 .854 r
F P
0 g
s
.11412 .36641 m .13036 .37299 L .12339 .36359 L p .203 .619 .949 r
F P
0 g
s
.12339 .36359 m .10643 .35914 L .11412 .36641 L p .203 .619 .949 r
F P
0 g
s
.50665 .68757 m .51107 .70458 L .52658 .70741 L p .563 .588 .836 r
F P
0 g
s
.51107 .70458 m .50665 .68757 L .49202 .68273 L p .559 .575 .826 r
F P
0 g
s
.3768 .53171 m .36972 .53504 L .38018 .54671 L p .278 .436 .84 r
F P
0 g
s
.36972 .53504 m .3768 .53171 L .36756 .52166 L p .267 .439 .846 r
F P
0 g
s
.15432 .38761 m .17054 .38994 L .16365 .38005 L p .439 .66 .954 r
F P
0 g
s
.16365 .38005 m .14693 .37685 L .15432 .38761 L p .439 .66 .954 r
F P
0 g
s
.34965 .51255 m .3586 .51179 L .34996 .50215 L p .257 .454 .862 r
F P
0 g
s
.34996 .50215 m .34012 .50189 L .34965 .51255 L p .257 .454 .862 r
F P
0 g
s
.56433 .72436 m .5717 .73848 L .58837 .73706 L p .584 .639 .871 r
F P
0 g
s
.5717 .73848 m .56433 .72436 L .54831 .72436 L p .587 .632 .864 r
F P
0 g
s
.3863 .54186 m .38018 .54671 L .39091 .55846 L p .294 .438 .836 r
F P
0 g
s
.38018 .54671 m .3863 .54186 L .3768 .53171 L p .278 .436 .84 r
F P
0 g
s
.29296 .46022 m .30593 .46343 L .29852 .4547 L p .276 .521 .907 r
F P
0 g
s
.29852 .4547 m .28481 .45114 L .29296 .46022 L p .276 .521 .907 r
F P
0 g
s
.34012 .50189 m .34996 .50215 L .34166 .4928 L p .259 .466 .87 r
F P
0 g
s
.34166 .4928 m .33095 .49167 L .34012 .50189 L p .259 .466 .87 r
F P
0 g
s
.19412 .40204 m .20993 .40508 L .20321 .39609 L p .396 .643 .956 r
F P
0 g
s
.20321 .39609 m .18683 .39276 L .19412 .40204 L p .396 .643 .956 r
F P
0 g
s
.26294 .43862 m .2772 .44235 L .27018 .43379 L p .306 .56 .926 r
F P
0 g
s
.27018 .43379 m .25525 .42983 L .26294 .43862 L p .306 .56 .926 r
F P
0 g
s
.46001 .63469 m .46125 .65085 L .47496 .65897 L p .483 .525 .824 r
F P
0 g
s
.46125 .65085 m .46001 .63469 L .44738 .62569 L p .461 .507 .819 r
F P
0 g
s
.39602 .55198 m .39091 .55846 L .40186 .57009 L p .313 .443 .833 r
F P
0 g
s
.39091 .55846 m .39602 .55198 L .3863 .54186 L p .294 .438 .836 r
F P
0 g
s
.54187 .70906 m .54831 .72436 L .56433 .72436 L p .577 .62 .858 r
F P
0 g
s
.54831 .72436 m .54187 .70906 L .52658 .70741 L p .582 .611 .847 r
F P
0 g
s
.43571 .60212 m .4348 .61539 L .44738 .62569 L p .416 .487 .825 r
F P
0 g
s
.4348 .61539 m .43571 .60212 L .4243 .59212 L p .387 .469 .823 r
F P
0 g
s
.48863 .66553 m .49202 .68273 L .50665 .68757 L p .535 .564 .831 r
F P
0 g
s
.49202 .68273 m .48863 .66553 L .47496 .65897 L p .525 .549 .823 r
F P
0 g
s
.33095 .49167 m .34166 .4928 L .33373 .48373 L p .264 .478 .879 r
F P
0 g
s
.33373 .48373 m .32218 .48187 L .33095 .49167 L p .264 .478 .879 r
F P
0 g
s
.40595 .56195 m .40186 .57009 L .413 .58138 L p .335 .452 .832 r
F P
0 g
s
.40186 .57009 m .40595 .56195 L .39602 .55198 L p .313 .443 .833 r
F P
0 g
s
.52112 .69105 m .52658 .70741 L .54187 .70906 L p .563 .598 .846 r
F P
0 g
s
.52658 .70741 m .52112 .69105 L .50665 .68757 L p .563 .588 .836 r
F P
0 g
s
.66841 .7548 m .6577 .74793 L .64053 .75153 L p .44 .763 .996 r
F P
0 g
s
.63056 .74237 m .64053 .75153 L .6577 .74793 L p .559 .71 .942 r
F P
0 g
s
.64053 .75153 m .63056 .74237 L .61385 .74677 L p .647 .697 .883 r
F P
0 g
s
.6577 .74793 m .66841 .7548 L .68634 .7592 L p .102 .543 .912 r
F P
0 g
s
.32218 .48187 m .33373 .48373 L .32619 .47496 L p .273 .492 .887 r
F P
0 g
s
.32619 .47496 m .31383 .47247 L .32218 .48187 L p .273 .492 .887 r
F P
0 g
s
.17054 .38994 m .18683 .39276 L .18046 .38335 L p .427 .659 .957 r
F P
0 g
s
.18046 .38335 m .16365 .38005 L .17054 .38994 L p .427 .659 .957 r
F P
0 g
s
.60463 .73458 m .61385 .74677 L .63056 .74237 L p .604 .674 .889 r
F P
0 g
s
.61385 .74677 m .60463 .73458 L .58837 .73706 L p .607 .659 .875 r
F P
0 g
s
.28481 .45114 m .29852 .4547 L .29162 .44624 L p .294 .536 .913 r
F P
0 g
s
.29162 .44624 m .2772 .44235 L .28481 .45114 L p .294 .536 .913 r
F P
0 g
s
.47263 .64239 m .47496 .65897 L .48863 .66553 L p .5 .541 .83 r
F P
0 g
s
.47496 .65897 m .47263 .64239 L .46001 .63469 L p .483 .525 .824 r
F P
0 g
s
.13036 .37299 m .14693 .37685 L .14052 .367 L p .394 .677 .974 r
F P
0 g
s
.14052 .367 m .12339 .36359 L .13036 .37299 L p .394 .677 .974 r
F P
0 g
s
.44721 .61124 m .44738 .62569 L .46001 .63469 L p .44 .504 .829 r
F P
0 g
s
.44738 .62569 m .44721 .61124 L .43571 .60212 L p .416 .487 .825 r
F P
0 g
s
.58002 .72351 m .58837 .73706 L .60463 .73458 L p .586 .648 .878 r
F P
0 g
s
.58837 .73706 m .58002 .72351 L .56433 .72436 L p .584 .639 .871 r
F P
0 g
s
.41606 .57162 m .413 .58138 L .4243 .59212 L p .358 .464 .832 r
F P
0 g
s
.413 .58138 m .41606 .57162 L .40595 .56195 L p .335 .452 .832 r
F P
0 g
s
.23278 .41739 m .24821 .42121 L .24186 .41271 L p .352 .601 .941 r
F P
0 g
s
.24186 .41271 m .22584 .40865 L .23278 .41739 L p .352 .601 .941 r
F P
0 g
s
.50219 .67069 m .50665 .68757 L .52112 .69105 L p .541 .576 .839 r
F P
0 g
s
.50665 .68757 m .50219 .67069 L .48863 .66553 L p .535 .564 .831 r
F P
0 g
s
.55689 .70972 m .56433 .72436 L .58002 .72351 L p .573 .627 .868 r
F P
0 g
s
.56433 .72436 m .55689 .70972 L .54187 .70906 L p .577 .62 .858 r
F P
0 g
s
.25525 .42983 m .27018 .43379 L .26377 .42543 L p .328 .574 .93 r
F P
0 g
s
.26377 .42543 m .24821 .42121 L .25525 .42983 L p .328 .574 .93 r
F P
0 g
s
.20993 .40508 m .22584 .40865 L .21967 .39993 L p .383 .627 .949 r
F P
0 g
s
.21967 .39993 m .20321 .39609 L .20993 .40508 L p .383 .627 .949 r
F P
0 g
s
.31383 .47247 m .32619 .47496 L .31907 .46646 L p .283 .505 .894 r
F P
0 g
s
.31907 .46646 m .30593 .46343 L .31383 .47247 L p .283 .505 .894 r
F P
0 g
s
.42629 .58084 m .4243 .59212 L .43571 .60212 L p .382 .477 .833 r
F P
0 g
s
.4243 .59212 m .42629 .58084 L .41606 .57162 L p .358 .464 .832 r
F P
0 g
s
.53538 .69334 m .54187 .70906 L .55689 .70972 L p .561 .607 .856 r
F P
0 g
s
.54187 .70906 m .53538 .69334 L .52112 .69105 L p .563 .598 .846 r
F P
0 g
s
.45875 .61938 m .46001 .63469 L .47263 .64239 L p .461 .52 .833 r
F P
0 g
s
.46001 .63469 m .45875 .61938 L .44721 .61124 L p .44 .504 .829 r
F P
0 g
s
.48521 .64881 m .48863 .66553 L .50219 .67069 L p .511 .554 .836 r
F P
0 g
s
.48863 .66553 m .48521 .64881 L .47263 .64239 L p .5 .541 .83 r
F P
0 g
s
.2772 .44235 m .29162 .44624 L .28526 .43801 L p .313 .55 .918 r
F P
0 g
s
.28526 .43801 m .27018 .43379 L .2772 .44235 L p .313 .55 .918 r
F P
0 g
s
.18683 .39276 m .20321 .39609 L .19735 .38705 L p .414 .648 .954 r
F P
0 g
s
.19735 .38705 m .18046 .38335 L .18683 .39276 L p .414 .648 .954 r
F P
0 g
s
.14693 .37685 m .16365 .38005 L .15774 .37033 L p .434 .677 .966 r
F P
0 g
s
.15774 .37033 m .14052 .367 L .14693 .37685 L p .434 .677 .966 r
F P
0 g
s
.37571 .51903 m .36756 .52166 L .3768 .53171 L p .299 .46 .853 r
F P
0 g
s
.36756 .52166 m .37571 .51903 L .3677 .51033 L p .293 .464 .858 r
F P
0 g
s
.3677 .51033 m .3586 .51179 L .36756 .52166 L p .293 .464 .858 r
F P
0 g
s
.5156 .67458 m .52112 .69105 L .53538 .69334 L p .544 .586 .847 r
F P
0 g
s
.52112 .69105 m .5156 .67458 L .50219 .67069 L p .541 .576 .839 r
F P
0 g
s
.38399 .52779 m .3768 .53171 L .3863 .54186 L p .307 .458 .848 r
F P
0 g
s
.3768 .53171 m .38399 .52779 L .37571 .51903 L p .299 .46 .853 r
F P
0 g
s
.30593 .46343 m .31907 .46646 L .3124 .45822 L p .295 .518 .9 r
F P
0 g
s
.3124 .45822 m .29852 .4547 L .30593 .46343 L p .295 .518 .9 r
F P
0 g
s
.43664 .58951 m .43571 .60212 L .44721 .61124 L p .404 .491 .835 r
F P
0 g
s
.43571 .60212 m .43664 .58951 L .42629 .58084 L p .382 .477 .833 r
F P
0 g
s
.3586 .51179 m .3677 .51033 L .35997 .50176 L p .291 .47 .864 r
F P
0 g
s
.35997 .50176 m .34996 .50215 L .3586 .51179 L p .291 .47 .864 r
F P
0 g
s
.3925 .53656 m .3863 .54186 L .39602 .55198 L p .317 .459 .845 r
F P
0 g
s
.3863 .54186 m .3925 .53656 L .38399 .52779 L p .307 .458 .848 r
F P
0 g
s
.6577 .74793 m .64679 .73862 L .63056 .74237 L p .559 .71 .942 r
F P
0 g
s
.62043 .73141 m .63056 .74237 L .64679 .73862 L p .571 .68 .914 r
F P
0 g
s
.63056 .74237 m .62043 .73141 L .60463 .73458 L p .604 .674 .889 r
F P
0 g
s
.59532 .72181 m .60463 .73458 L .62043 .73141 L p .581 .656 .888 r
F P
0 g
s
.60463 .73458 m .59532 .72181 L .58002 .72351 L p .586 .648 .878 r
F P
0 g
s
.34996 .50215 m .35997 .50176 L .35254 .49335 L p .291 .478 .871 r
F P
0 g
s
.35254 .49335 m .34166 .4928 L .34996 .50215 L p .291 .478 .871 r
F P
0 g
s
.68634 .7592 m .6744 .74629 L .6577 .74793 L p .102 .543 .912 r
F P
0 g
s
.64679 .73862 m .6577 .74793 L .6744 .74629 L p .475 .675 .952 r
F P
0 g
s
.57159 .70948 m .58002 .72351 L .59532 .72181 L p .571 .635 .876 r
F P
0 g
s
.58002 .72351 m .57159 .70948 L .55689 .70972 L p .573 .627 .868 r
F P
0 g
s
.40121 .54524 m .39602 .55198 L .40595 .56195 L p .331 .462 .842 r
F P
0 g
s
.39602 .55198 m .40121 .54524 L .3925 .53656 L p .317 .459 .845 r
F P
0 g
s
.47028 .62649 m .47263 .64239 L .48521 .64881 L p .477 .534 .837 r
F P
0 g
s
.47263 .64239 m .47028 .62649 L .45875 .61938 L p .461 .52 .833 r
F P
0 g
s
.4977 .65403 m .50219 .67069 L .5156 .67458 L p .519 .565 .843 r
F P
0 g
s
.50219 .67069 m .4977 .65403 L .48521 .64881 L p .511 .554 .836 r
F P
0 g
s
.10643 .35914 m .12339 .36359 L .11742 .35598 L p .244 .752 .874 r
F P
0 g
s
.11742 .35598 m .09946 .35739 L .10643 .35914 L p .244 .752 .874 r
F P
0 g
s
.34166 .4928 m .35254 .49335 L .34546 .48512 L p .294 .487 .877 r
F P
0 g
s
.34546 .48512 m .33373 .48373 L .34166 .4928 L p .294 .487 .877 r
F P
0 g
s
.24821 .42121 m .26377 .42543 L .258 .41722 L p .348 .586 .933 r
F P
0 g
s
.258 .41722 m .24186 .41271 L .24821 .42121 L p .348 .586 .933 r
F P
0 g
s
.54938 .6946 m .55689 .70972 L .57159 .70948 L p .559 .615 .865 r
F P
0 g
s
.55689 .70972 m .54938 .6946 L .53538 .69334 L p .561 .607 .856 r
F P
0 g
s
.22584 .40865 m .24186 .41271 L .23624 .40429 L p .374 .611 .942 r
F P
0 g
s
.23624 .40429 m .21967 .39993 L .22584 .40865 L p .374 .611 .942 r
F P
0 g
s
.41011 .55376 m .40595 .56195 L .41606 .57162 L p .346 .468 .841 r
F P
0 g
s
.40595 .56195 m .41011 .55376 L .40121 .54524 L p .331 .462 .842 r
F P
0 g
s
.44704 .5975 m .44721 .61124 L .45875 .61938 L p .424 .504 .837 r
F P
0 g
s
.44721 .61124 m .44704 .5975 L .43664 .58951 L p .404 .491 .835 r
F P
0 g
s
.29852 .4547 m .3124 .45822 L .3062 .45022 L p .308 .53 .905 r
F P
0 g
s
.3062 .45022 m .29162 .44624 L .29852 .4547 L p .308 .53 .905 r
F P
0 g
s
.16365 .38005 m .18046 .38335 L .17504 .37394 L p .437 .668 .959 r
F P
0 g
s
.17504 .37394 m .15774 .37033 L .16365 .38005 L p .437 .668 .959 r
F P
0 g
s
.27018 .43379 m .28526 .43801 L .27947 .42999 L p .33 .562 .922 r
F P
0 g
s
.27947 .42999 m .26377 .42543 L .27018 .43379 L p .33 .562 .922 r
F P
0 g
s
.52882 .67734 m .53538 .69334 L .54938 .6946 L p .544 .595 .855 r
F P
0 g
s
.53538 .69334 m .52882 .67734 L .5156 .67458 L p .544 .586 .847 r
F P
0 g
s
.41915 .56201 m .41606 .57162 L .42629 .58084 L p .363 .476 .841 r
F P
0 g
s
.41606 .57162 m .41915 .56201 L .41011 .55376 L p .346 .468 .841 r
F P
0 g
s
.33373 .48373 m .34546 .48512 L .33873 .4771 L p .299 .497 .883 r
F P
0 g
s
.33873 .4771 m .32619 .47496 L .33373 .48373 L p .299 .497 .883 r
F P
0 g
s
.20321 .39609 m .21967 .39993 L .21432 .39123 L p .402 .634 .949 r
F P
0 g
s
.21432 .39123 m .19735 .38705 L .20321 .39609 L p .402 .634 .949 r
F P
0 g
s
.48177 .63258 m .48521 .64881 L .4977 .65403 L p .489 .546 .842 r
F P
0 g
s
.48521 .64881 m .48177 .63258 L .47028 .62649 L p .477 .534 .837 r
F P
0 g
s
.6744 .74629 m .68634 .7592 L .70325 .75566 L p .519 .62 .892 r
F P
0 g
s
.45748 .60474 m .45875 .61938 L .47028 .62649 L p .442 .517 .84 r
F P
0 g
s
.45875 .61938 m .45748 .60474 L .44704 .5975 L p .424 .504 .837 r
F P
0 g
s
.42831 .56991 m .42629 .58084 L .43664 .58951 L p .38 .485 .841 r
F P
0 g
s
.42629 .58084 m .42831 .56991 L .41915 .56201 L p .363 .476 .841 r
F P
0 g
s
.51005 .65813 m .5156 .67458 L .52882 .67734 L p .523 .575 .849 r
F P
0 g
s
.5156 .67458 m .51005 .65813 L .4977 .65403 L p .519 .565 .843 r
F P
0 g
s
.12339 .36359 m .14052 .367 L .13517 .35763 L p .434 .749 .994 r
F P
0 g
s
.13517 .35763 m .11742 .35598 L .12339 .36359 L p .434 .749 .994 r
F P
0 g
s
.32619 .47496 m .33873 .4771 L .33239 .46927 L p .305 .507 .889 r
F P
0 g
s
.33239 .46927 m .31907 .46646 L .32619 .47496 L p .305 .507 .889 r
F P
0 g
s
.64679 .73862 m .63572 .728 L .62043 .73141 L p .571 .68 .914 r
F P
0 g
s
.61017 .71941 m .62043 .73141 L .63572 .728 L p .567 .661 .901 r
F P
0 g
s
.62043 .73141 m .61017 .71941 L .59532 .72181 L p .581 .656 .888 r
F P
0 g
s
.58591 .70844 m .59532 .72181 L .61017 .71941 L p .566 .642 .885 r
F P
0 g
s
.59532 .72181 m .58591 .70844 L .57159 .70948 L p .571 .635 .876 r
F P
0 g
s
.29162 .44624 m .3062 .45022 L .3005 .44243 L p .322 .542 .91 r
F P
0 g
s
.3005 .44243 m .28526 .43801 L .29162 .44624 L p .322 .542 .91 r
F P
0 g
s
.56307 .69496 m .57159 .70948 L .58591 .70844 L p .556 .622 .873 r
F P
0 g
s
.57159 .70948 m .56307 .69496 L .54938 .6946 L p .559 .615 .865 r
F P
0 g
s
.6744 .74629 m .66247 .73518 L .64679 .73862 L p .475 .675 .952 r
F P
0 g
s
.63572 .728 m .64679 .73862 L .66247 .73518 L p .542 .674 .924 r
F P
0 g
s
.18046 .38335 m .19735 .38705 L .19239 .37799 L p .43 .655 .954 r
F P
0 g
s
.19239 .37799 m .17504 .37394 L .18046 .38335 L p .43 .655 .954 r
F P
0 g
s
.43757 .57735 m .43664 .58951 L .44704 .5975 L p .396 .495 .843 r
F P
0 g
s
.43664 .58951 m .43757 .57735 L .42831 .56991 L p .38 .485 .841 r
F P
0 g
s
.54179 .67911 m .54938 .6946 L .56307 .69496 L p .543 .603 .863 r
F P
0 g
s
.54938 .6946 m .54179 .67911 L .52882 .67734 L p .544 .595 .855 r
F P
0 g
s
.24186 .41271 m .258 .41722 L .25292 .40914 L p .367 .596 .934 r
F P
0 g
s
.25292 .40914 m .23624 .40429 L .24186 .41271 L p .367 .596 .934 r
F P
0 g
s
.49317 .63766 m .4977 .65403 L .51005 .65813 L p .497 .556 .847 r
F P
0 g
s
.4977 .65403 m .49317 .63766 L .48177 .63258 L p .489 .546 .842 r
F P
0 g
s
.46792 .61118 m .47028 .62649 L .48177 .63258 L p .456 .529 .843 r
F P
0 g
s
.47028 .62649 m .46792 .61118 L .45748 .60474 L p .442 .517 .84 r
F P
0 g
s
.31907 .46646 m .33239 .46927 L .32646 .46165 L p .313 .517 .894 r
F P
0 g
s
.32646 .46165 m .3124 .45822 L .31907 .46646 L p .313 .517 .894 r
F P
0 g
s
.26377 .42543 m .27947 .42999 L .27428 .42214 L p .347 .573 .924 r
F P
0 g
s
.27428 .42214 m .258 .41722 L .26377 .42543 L p .347 .573 .924 r
F P
0 g
s
.21967 .39993 m .23624 .40429 L .23138 .39594 L p .392 .619 .942 r
F P
0 g
s
.23138 .39594 m .21432 .39123 L .21967 .39993 L p .392 .619 .942 r
F P
0 g
s
.14052 .367 m .15774 .37033 L .15288 .36066 L p .457 .703 .973 r
F P
0 g
s
.15288 .36066 m .13517 .35763 L .14052 .367 L p .457 .703 .973 r
F P
0 g
s
.70325 .75566 m .69033 .74175 L .6744 .74629 L p .519 .62 .892 r
F P
0 g
s
.66247 .73518 m .6744 .74629 L .69033 .74175 L p .546 .662 .912 r
F P
0 g
s
.39129 .5234 m .38399 .52779 L .3925 .53656 L p .328 .474 .854 r
F P
0 g
s
.38399 .52779 m .39129 .5234 L .38399 .51585 L p .323 .476 .858 r
F P
0 g
s
.38399 .51585 m .37571 .51903 L .38399 .52779 L p .323 .476 .858 r
F P
0 g
s
.37571 .51903 m .38399 .51585 L .37693 .50831 L p .319 .479 .862 r
F P
0 g
s
.37693 .50831 m .3677 .51033 L .37571 .51903 L p .319 .479 .862 r
F P
0 g
s
.52221 .6612 m .52882 .67734 L .54179 .67911 L p .526 .584 .856 r
F P
0 g
s
.52882 .67734 m .52221 .6612 L .51005 .65813 L p .523 .575 .849 r
F P
0 g
s
.39879 .53089 m .3925 .53656 L .40121 .54524 L p .336 .475 .851 r
F P
0 g
s
.3925 .53656 m .39879 .53089 L .39129 .5234 L p .328 .474 .854 r
F P
0 g
s
.3677 .51033 m .37693 .50831 L .37012 .50081 L p .317 .483 .866 r
F P
0 g
s
.37012 .50081 m .35997 .50176 L .3677 .51033 L p .317 .483 .866 r
F P
0 g
s
.44687 .58428 m .44704 .5975 L .45748 .60474 L p .412 .506 .844 r
F P
0 g
s
.44704 .5975 m .44687 .58428 L .43757 .57735 L p .396 .495 .843 r
F P
0 g
s
.40647 .53828 m .40121 .54524 L .41011 .55376 L p .345 .477 .85 r
F P
0 g
s
.40121 .54524 m .40647 .53828 L .39879 .53089 L p .336 .475 .851 r
F P
0 g
s
.35997 .50176 m .37012 .50081 L .36359 .4934 L p .316 .489 .871 r
F P
0 g
s
.36359 .4934 m .35254 .49335 L .35997 .50176 L p .316 .489 .871 r
F P
0 g
s
.28526 .43801 m .3005 .44243 L .29532 .43485 L p .335 .552 .913 r
F P
0 g
s
.29532 .43485 m .27947 .42999 L .28526 .43801 L p .335 .552 .913 r
F P
0 g
s
.4783 .6168 m .48177 .63258 L .49317 .63766 L p .468 .539 .847 r
F P
0 g
s
.48177 .63258 m .4783 .6168 L .46792 .61118 L p .456 .529 .843 r
F P
0 g
s
.41431 .5455 m .41011 .55376 L .41915 .56201 L p .355 .481 .849 r
F P
0 g
s
.41011 .55376 m .41431 .5455 L .40647 .53828 L p .345 .477 .85 r
F P
0 g
s
.3124 .45822 m .32646 .46165 L .32095 .45423 L p .322 .527 .899 r
F P
0 g
s
.32095 .45423 m .3062 .45022 L .3124 .45822 L p .322 .527 .899 r
F P
0 g
s
.35254 .49335 m .36359 .4934 L .35736 .48609 L p .318 .495 .876 r
F P
0 g
s
.35736 .48609 m .34546 .48512 L .35254 .49335 L p .318 .495 .876 r
F P
0 g
s
.19735 .38705 m .21432 .39123 L .20981 .38255 L p .419 .64 .948 r
F P
0 g
s
.20981 .38255 m .19239 .37799 L .19735 .38705 L p .419 .64 .948 r
F P
0 g
s
.50444 .64178 m .51005 .65813 L .52221 .6612 L p .503 .566 .852 r
F P
0 g
s
.51005 .65813 m .50444 .64178 L .49317 .63766 L p .497 .556 .847 r
F P
0 g
s
.63572 .728 m .62454 .71651 L .61017 .71941 L p .567 .661 .901 r
F P
0 g
s
.59981 .70668 m .61017 .71941 L .62454 .71651 L p .558 .647 .894 r
F P
0 g
s
.61017 .71941 m .59981 .70668 L .58591 .70844 L p .566 .642 .885 r
F P
0 g
s
.57641 .69449 m .58591 .70844 L .59981 .70668 L p .552 .629 .881 r
F P
0 g
s
.58591 .70844 m .57641 .69449 L .56307 .69496 L p .556 .622 .873 r
F P
0 g
s
.66247 .73518 m .65047 .72431 L .63572 .728 L p .542 .674 .924 r
F P
0 g
s
.62454 .71651 m .63572 .728 L .65047 .72431 L p .553 .663 .91 r
F P
0 g
s
.4562 .59063 m .45748 .60474 L .46792 .61118 L p .427 .516 .847 r
F P
0 g
s
.45748 .60474 m .4562 .59063 L .44687 .58428 L p .412 .506 .844 r
F P
0 g
s
.15774 .37033 m .17504 .37394 L .17061 .36448 L p .455 .678 .96 r
F P
0 g
s
.17061 .36448 m .15288 .36066 L .15774 .37033 L p .455 .678 .96 r
F P
0 g
s
.55447 .67997 m .56307 .69496 L .57641 .69449 L p .541 .61 .871 r
F P
0 g
s
.56307 .69496 m .55447 .67997 L .54179 .67911 L p .543 .603 .863 r
F P
0 g
s
.42229 .55249 m .41915 .56201 L .42831 .56991 L p .367 .486 .848 r
F P
0 g
s
.41915 .56201 m .42229 .55249 L .41431 .5455 L p .355 .481 .849 r
F P
0 g
s
.34546 .48512 m .35736 .48609 L .35145 .4789 L p .32 .502 .88 r
F P
0 g
s
.35145 .4789 m .33873 .4771 L .34546 .48512 L p .32 .502 .88 r
F P
0 g
s
.53414 .66333 m .54179 .67911 L .55447 .67997 L p .526 .592 .863 r
F P
0 g
s
.54179 .67911 m .53414 .66333 L .52221 .6612 L p .526 .584 .856 r
F P
0 g
s
.69033 .74175 m .70325 .75566 L .71876 .74029 L p .67 .646 .817 r
F P
0 g
s
.258 .41722 m .27428 .42214 L .2697 .41445 L p .363 .582 .926 r
F P
0 g
s
.2697 .41445 m .25292 .40914 L .258 .41722 L p .363 .582 .926 r
F P
0 g
s
.43036 .55919 m .42831 .56991 L .43757 .57735 L p .379 .493 .849 r
F P
0 g
s
.42831 .56991 m .43036 .55919 L .42229 .55249 L p .367 .486 .848 r
F P
0 g
s
.23624 .40429 m .25292 .40914 L .24853 .40117 L p .384 .604 .935 r
F P
0 g
s
.24853 .40117 m .23138 .39594 L .23624 .40429 L p .384 .604 .935 r
F P
0 g
s
.69033 .74175 m .67749 .73053 L .66247 .73518 L p .546 .662 .912 r
F P
0 g
s
.65047 .72431 m .66247 .73518 L .67749 .73053 L p .554 .67 .915 r
F P
0 g
s
.48861 .6216 m .49317 .63766 L .50444 .64178 L p .477 .549 .851 r
F P
0 g
s
.49317 .63766 m .48861 .6216 L .4783 .6168 L p .468 .539 .847 r
F P
0 g
s
.3062 .45022 m .32095 .45423 L .3159 .44699 L p .332 .536 .902 r
F P
0 g
s
.3159 .44699 m .3005 .44243 L .3062 .45022 L p .332 .536 .902 r
F P
0 g
s
.33873 .4771 m .35145 .4789 L .34589 .47186 L p .324 .51 .885 r
F P
0 g
s
.34589 .47186 m .33239 .46927 L .33873 .4771 L p .324 .51 .885 r
F P
0 g
s
.46553 .59636 m .46792 .61118 L .4783 .6168 L p .439 .525 .849 r
F P
0 g
s
.46792 .61118 m .46553 .59636 L .4562 .59063 L p .427 .516 .847 r
F P
0 g
s
.27947 .42999 m .29532 .43485 L .29068 .42744 L p .349 .561 .916 r
F P
0 g
s
.29068 .42744 m .27428 .42214 L .27947 .42999 L p .349 .561 .916 r
F P
0 g
s
.51554 .64499 m .52221 .6612 L .53414 .66333 L p .507 .574 .857 r
F P
0 g
s
.52221 .6612 m .51554 .64499 L .50444 .64178 L p .503 .566 .852 r
F P
0 g
s
.43851 .56553 m .43757 .57735 L .44687 .58428 L p .391 .5 .849 r
F P
0 g
s
.43757 .57735 m .43851 .56553 L .43036 .55919 L p .379 .493 .849 r
F P
0 g
s
.17504 .37394 m .19239 .37799 L .18837 .3689 L p .446 .661 .953 r
F P
0 g
s
.18837 .3689 m .17061 .36448 L .17504 .37394 L p .446 .661 .953 r
F P
0 g
s
.21432 .39123 m .23138 .39594 L .22731 .38765 L p .409 .625 .942 r
F P
0 g
s
.22731 .38765 m .20981 .38255 L .21432 .39123 L p .409 .625 .942 r
F P
0 g
s
.09946 .35739 m .11742 .35598 L .11287 .34543 L p .636 .818 .97 r
F P
0 g
s
.11287 .34543 m .09444 .34717 L .09946 .35739 L p .636 .818 .97 r
F P
0 g
s
.33239 .46927 m .34589 .47186 L .34069 .46497 L p .329 .517 .889 r
F P
0 g
s
.34069 .46497 m .32646 .46165 L .33239 .46927 L p .329 .517 .889 r
F P
0 g
s
.62454 .71651 m .61324 .7043 L .59981 .70668 L p .558 .647 .894 r
F P
0 g
s
.58935 .6933 m .59981 .70668 L .61324 .7043 L p .547 .634 .889 r
F P
0 g
s
.59981 .70668 m .58935 .6933 L .57641 .69449 L p .552 .629 .881 r
F P
0 g
s
.71876 .74029 m .70533 .73285 L .69033 .74175 L p .67 .646 .817 r
F P
0 g
s
.67749 .73053 m .69033 .74175 L .70533 .73285 L p .616 .674 .882 r
F P
0 g
s
.56682 .68003 m .57641 .69449 L .58935 .6933 L p .538 .616 .878 r
F P
0 g
s
.57641 .69449 m .56682 .68003 L .55447 .67997 L p .541 .61 .871 r
F P
0 g
s
.11742 .35598 m .13517 .35763 L .13104 .34723 L p .542 .741 .968 r
F P
0 g
s
.13104 .34723 m .11287 .34543 L .11742 .35598 L p .542 .741 .968 r
F P
0 g
s
.65047 .72431 m .63836 .71311 L .62454 .71651 L p .553 .663 .91 r
F P
0 g
s
.61324 .7043 m .62454 .71651 L .63836 .71311 L p .55 .651 .902 r
F P
0 g
s
.4467 .57146 m .44687 .58428 L .4562 .59063 L p .403 .508 .851 r
F P
0 g
s
.44687 .58428 m .4467 .57146 L .43851 .56553 L p .391 .5 .849 r
F P
0 g
s
.49879 .62559 m .50444 .64178 L .51554 .64499 L p .484 .557 .855 r
F P
0 g
s
.50444 .64178 m .49879 .62559 L .48861 .6216 L p .477 .549 .851 r
F P
0 g
s
.4748 .60143 m .4783 .6168 L .48861 .6216 L p .45 .534 .852 r
F P
0 g
s
.4783 .6168 m .4748 .60143 L .46553 .59636 L p .439 .525 .849 r
F P
0 g
s
.5458 .6646 m .55447 .67997 L .56682 .68003 L p .526 .598 .869 r
F P
0 g
s
.55447 .67997 m .5458 .6646 L .53414 .66333 L p .526 .592 .863 r
F P
0 g
s
.3005 .44243 m .3159 .44699 L .31132 .43994 L p .342 .544 .906 r
F P
0 g
s
.31132 .43994 m .29532 .43485 L .3005 .44243 L p .342 .544 .906 r
F P
0 g
s
.3987 .51862 m .39129 .5234 L .39879 .53089 L p .345 .488 .859 r
F P
0 g
s
.39129 .5234 m .3987 .51862 L .3924 .51224 L p .341 .489 .861 r
F P
0 g
s
.3924 .51224 m .38399 .51585 L .39129 .5234 L p .341 .489 .861 r
F P
0 g
s
.38399 .51585 m .3924 .51224 L .3863 .50582 L p .338 .491 .864 r
F P
0 g
s
.3863 .50582 m .37693 .50831 L .38399 .51585 L p .338 .491 .864 r
F P
0 g
s
.40517 .52493 m .39879 .53089 L .40647 .53828 L p .35 .488 .857 r
F P
0 g
s
.39879 .53089 m .40517 .52493 L .3987 .51862 L p .345 .488 .859 r
F P
0 g
s
.67749 .73053 m .66459 .71993 L .65047 .72431 L p .554 .67 .915 r
F P
0 g
s
.63836 .71311 m .65047 .72431 L .66459 .71993 L p .552 .665 .912 r
F P
0 g
s
.37693 .50831 m .3863 .50582 L .38043 .4994 L p .337 .494 .867 r
F P
0 g
s
.38043 .4994 m .37012 .50081 L .37693 .50831 L p .337 .494 .867 r
F P
0 g
s
.13517 .35763 m .15288 .36066 L .14913 .35063 L p .499 .702 .961 r
F P
0 g
s
.14913 .35063 m .13104 .34723 L .13517 .35763 L p .499 .702 .961 r
F P
0 g
s
.25292 .40914 m .2697 .41445 L .26578 .4069 L p .378 .59 .927 r
F P
0 g
s
.26578 .4069 m .24853 .40117 L .25292 .40914 L p .378 .59 .927 r
F P
0 g
s
.52642 .64736 m .53414 .66333 L .5458 .6646 L p .509 .581 .863 r
F P
0 g
s
.53414 .66333 m .52642 .64736 L .51554 .64499 L p .507 .574 .857 r
F P
0 g
s
.19239 .37799 m .20981 .38255 L .20618 .37388 L p .435 .646 .947 r
F P
0 g
s
.20618 .37388 m .18837 .3689 L .19239 .37799 L p .435 .646 .947 r
F P
0 g
s
.41181 .53113 m .40647 .53828 L .41431 .5455 L p .356 .489 .856 r
F P
0 g
s
.40647 .53828 m .41181 .53113 L .40517 .52493 L p .35 .488 .857 r
F P
0 g
s
.32646 .46165 m .34069 .46497 L .33587 .45823 L p .335 .524 .893 r
F P
0 g
s
.33587 .45823 m .32095 .45423 L .32646 .46165 L p .335 .524 .893 r
F P
0 g
s
.70533 .73285 m .71876 .74029 L .73348 .72592 L p .702 .738 .88 r
F P
0 g
s
.37012 .50081 m .38043 .4994 L .3748 .493 L p .336 .498 .871 r
F P
0 g
s
.3748 .493 m .36359 .4934 L .37012 .50081 L p .336 .498 .871 r
F P
0 g
s
.45491 .57694 m .4562 .59063 L .46553 .59636 L p .415 .515 .852 r
F P
0 g
s
.4562 .59063 m .45491 .57694 L .4467 .57146 L p .403 .508 .851 r
F P
0 g
s
.27428 .42214 m .29068 .42744 L .28662 .42021 L p .362 .57 .918 r
F P
0 g
s
.28662 .42021 m .2697 .41445 L .27428 .42214 L p .362 .57 .918 r
F P
0 g
s
.41858 .53717 m .41431 .5455 L .42229 .55249 L p .363 .492 .855 r
F P
0 g
s
.41431 .5455 m .41858 .53717 L .41181 .53113 L p .356 .489 .856 r
F P
0 g
s
.23138 .39594 m .24853 .40117 L .24487 .3933 L p .4 .611 .935 r
F P
0 g
s
.24487 .3933 m .22731 .38765 L .23138 .39594 L p .4 .611 .935 r
F P
0 g
s
.36359 .4934 m .3748 .493 L .36943 .48666 L p .337 .502 .874 r
F P
0 g
s
.36943 .48666 m .35736 .48609 L .36359 .4934 L p .337 .502 .874 r
F P
0 g
s
.484 .60584 m .48861 .6216 L .49879 .62559 L p .458 .542 .855 r
F P
0 g
s
.48861 .6216 m .484 .60584 L .4748 .60143 L p .45 .534 .852 r
F P
0 g
s
.42546 .54301 m .42229 .55249 L .43036 .55919 L p .371 .495 .854 r
F P
0 g
s
.42229 .55249 m .42546 .54301 L .41858 .53717 L p .363 .492 .855 r
F P
0 g
s
.50881 .6288 m .51554 .64499 L .52642 .64736 L p .488 .564 .859 r
F P
0 g
s
.51554 .64499 m .50881 .6288 L .49879 .62559 L p .484 .557 .855 r
F P
0 g
s
.70533 .73285 m .69174 .72416 L .67749 .73053 L p .616 .674 .882 r
F P
0 g
s
.66459 .71993 m .67749 .73053 L .69174 .72416 L p .577 .677 .908 r
F P
0 g
s
.15288 .36066 m .17061 .36448 L .16722 .35489 L p .477 .68 .955 r
F P
0 g
s
.16722 .35489 m .14913 .35063 L .15288 .36066 L p .477 .68 .955 r
F P
0 g
s
.29532 .43485 m .31132 .43994 L .30723 .43306 L p .352 .552 .908 r
F P
0 g
s
.30723 .43306 m .29068 .42744 L .29532 .43485 L p .352 .552 .908 r
F P
0 g
s
.35736 .48609 m .36943 .48666 L .36435 .48039 L p .338 .507 .878 r
F P
0 g
s
.36435 .48039 m .35145 .4789 L .35736 .48609 L p .338 .507 .878 r
F P
0 g
s
.46311 .58192 m .46553 .59636 L .4748 .60143 L p .425 .523 .854 r
F P
0 g
s
.46553 .59636 m .46311 .58192 L .45491 .57694 L p .415 .515 .852 r
F P
0 g
s
.32095 .45423 m .33587 .45823 L .33146 .45165 L p .342 .531 .896 r
F P
0 g
s
.33146 .45165 m .3159 .44699 L .32095 .45423 L p .342 .531 .896 r
F P
0 g
s
.61324 .7043 m .60184 .69146 L .58935 .6933 L p .547 .634 .889 r
F P
0 g
s
.57879 .67935 m .58935 .6933 L .60184 .69146 L p .534 .622 .885 r
F P
0 g
s
.58935 .6933 m .57879 .67935 L .56682 .68003 L p .538 .616 .878 r
F P
0 g
s
.43243 .5486 m .43036 .55919 L .43851 .56553 L p .379 .499 .855 r
F P
0 g
s
.43036 .55919 m .43243 .5486 L .42546 .54301 L p .371 .495 .854 r
F P
0 g
s
.55715 .66509 m .56682 .68003 L .57879 .67935 L p .524 .604 .876 r
F P
0 g
s
.56682 .68003 m .55715 .66509 L .5458 .6646 L p .526 .598 .869 r
F P
0 g
s
.63836 .71311 m .62615 .70136 L .61324 .7043 L p .55 .651 .902 r
F P
0 g
s
.60184 .69146 m .61324 .7043 L .62615 .70136 L p .541 .639 .896 r
F P
0 g
s
.20981 .38255 m .22731 .38765 L .22405 .37942 L p .424 .631 .94 r
F P
0 g
s
.22405 .37942 m .20618 .37388 L .20981 .38255 L p .424 .631 .94 r
F P
0 g
s
.53705 .64893 m .5458 .6646 L .55715 .66509 L p .509 .587 .869 r
F P
0 g
s
.5458 .6646 m .53705 .64893 L .52642 .64736 L p .509 .581 .863 r
F P
0 g
s
.35145 .4789 m .36435 .48039 L .35956 .47422 L p .341 .512 .881 r
F P
0 g
s
.35956 .47422 m .34589 .47186 L .35145 .4789 L p .341 .512 .881 r
F P
0 g
s
.43946 .55391 m .43851 .56553 L .4467 .57146 L p .388 .505 .855 r
F P
0 g
s
.43851 .56553 m .43946 .55391 L .43243 .5486 L p .379 .499 .855 r
F P
0 g
s
.49309 .60958 m .49879 .62559 L .50881 .6288 L p .465 .549 .858 r
F P
0 g
s
.49879 .62559 m .49309 .60958 L .484 .60584 L p .458 .542 .855 r
F P
0 g
s
.66459 .71993 m .65159 .70914 L .63836 .71311 L p .552 .665 .912 r
F P
0 g
s
.62615 .70136 m .63836 .71311 L .65159 .70914 L p .545 .654 .907 r
F P
0 g
s
.17061 .36448 m .18837 .3689 L .18533 .35977 L p .462 .664 .95 r
F P
0 g
s
.18533 .35977 m .16722 .35489 L .17061 .36448 L p .462 .664 .95 r
F P
0 g
s
.73348 .72592 m .71955 .72391 L .70533 .73285 L p .702 .738 .88 r
F P
0 g
s
.69174 .72416 m .70533 .73285 L .71955 .72391 L p .617 .713 .914 r
F P
0 g
s
.47127 .5864 m .4748 .60143 L .484 .60584 L p .434 .53 .856 r
F P
0 g
s
.4748 .60143 m .47127 .5864 L .46311 .58192 L p .425 .523 .854 r
F P
0 g
s
.2697 .41445 m .28662 .42021 L .28314 .41313 L p .374 .577 .919 r
F P
0 g
s
.28314 .41313 m .26578 .4069 L .2697 .41445 L p .374 .577 .919 r
F P
0 g
s
.51864 .63126 m .52642 .64736 L .53705 .64893 L p .491 .571 .864 r
F P
0 g
s
.52642 .64736 m .51864 .63126 L .50881 .6288 L p .488 .564 .859 r
F P
0 g
s
.24853 .40117 m .26578 .4069 L .26253 .39949 L p .392 .596 .927 r
F P
0 g
s
.26253 .39949 m .24487 .3933 L .24853 .40117 L p .392 .596 .927 r
F P
0 g
s
.3159 .44699 m .33146 .45165 L .32748 .44523 L p .349 .538 .898 r
F P
0 g
s
.32748 .44523 m .31132 .43994 L .3159 .44699 L p .349 .538 .898 r
F P
0 g
s
.34589 .47186 m .35956 .47422 L .3551 .46814 L p .344 .518 .884 r
F P
0 g
s
.3551 .46814 m .34069 .46497 L .34589 .47186 L p .344 .518 .884 r
F P
0 g
s
.44653 .5589 m .4467 .57146 L .45491 .57694 L p .397 .51 .856 r
F P
0 g
s
.4467 .57146 m .44653 .5589 L .43946 .55391 L p .388 .505 .855 r
F P
0 g
s
.29068 .42744 m .30723 .43306 L .30366 .42636 L p .362 .559 .91 r
F P
0 g
s
.30366 .42636 m .28662 .42021 L .29068 .42744 L p .362 .559 .91 r
F P
0 g
s
.69174 .72416 m .67802 .71469 L .66459 .71993 L p .577 .677 .908 r
F P
0 g
s
.65159 .70914 m .66459 .71993 L .67802 .71469 L p .555 .669 .914 r
F P
0 g
s
.71955 .72391 m .73348 .72592 L .74818 .72458 L p .197 .704 .902 r
F P
0 g
s
.22731 .38765 m .24487 .3933 L .24197 .38553 L p .414 .616 .934 r
F P
0 g
s
.24197 .38553 m .22405 .37942 L .22731 .38765 L p .414 .616 .934 r
F P
0 g
s
.50202 .61266 m .50881 .6288 L .51864 .63126 L p .47 .556 .861 r
F P
0 g
s
.50881 .6288 m .50202 .61266 L .49309 .60958 L p .465 .549 .858 r
F P
0 g
s
.18837 .3689 m .20618 .37388 L .20346 .36523 L p .449 .649 .944 r
F P
0 g
s
.20346 .36523 m .18533 .35977 L .18837 .3689 L p .449 .649 .944 r
F P
0 g
s
.47935 .59034 m .484 .60584 L .49309 .60958 L p .442 .537 .858 r
F P
0 g
s
.484 .60584 m .47935 .59034 L .47127 .5864 L p .434 .53 .856 r
F P
0 g
s
.60184 .69146 m .59033 .67801 L .57879 .67935 L p .534 .622 .885 r
F P
0 g
s
.56813 .66487 m .57879 .67935 L .59033 .67801 L p .521 .609 .882 r
F P
0 g
s
.57879 .67935 m .56813 .66487 L .55715 .66509 L p .524 .604 .876 r
F P
0 g
s
.45361 .56354 m .45491 .57694 L .46311 .58192 L p .405 .516 .857 r
F P
0 g
s
.45491 .57694 m .45361 .56354 L .44653 .5589 L p .397 .51 .856 r
F P
0 g
s
.34069 .46497 m .3551 .46814 L .35098 .46219 L p .347 .523 .887 r
F P
0 g
s
.35098 .46219 m .33587 .45823 L .34069 .46497 L p .347 .523 .887 r
F P
0 g
s
.62615 .70136 m .61383 .68901 L .60184 .69146 L p .541 .639 .896 r
F P
0 g
s
.59033 .67801 m .60184 .69146 L .61383 .68901 L p .53 .626 .892 r
F P
0 g
s
.54739 .64976 m .55715 .66509 L .56813 .66487 L p .508 .593 .874 r
F P
0 g
s
.55715 .66509 m .54739 .64976 L .53705 .64893 L p .509 .587 .869 r
F P
0 g
s
.09444 .34717 m .11287 .34543 L .10991 .3307 L p .604 .615 .836 r
F P
0 g
s
.10991 .3307 m .09172 .32509 L .09444 .34717 L p .604 .615 .836 r
F P
0 g
s
.11287 .34543 m .13104 .34723 L .12821 .33541 L p .558 .665 .909 r
F P
0 g
s
.12821 .33541 m .10991 .3307 L .11287 .34543 L p .558 .665 .909 r
F P
0 g
s
.40621 .51354 m .3987 .51862 L .40517 .52493 L p .357 .498 .862 r
F P
0 g
s
.3987 .51862 m .40621 .51354 L .40092 .50827 L p .355 .499 .864 r
F P
0 g
s
.40092 .50827 m .3924 .51224 L .3987 .51862 L p .355 .499 .864 r
F P
0 g
s
.3924 .51224 m .40092 .50827 L .39581 .50295 L p .353 .5 .866 r
F P
0 g
s
.39581 .50295 m .3863 .50582 L .3924 .51224 L p .353 .5 .866 r
F P
0 g
s
.41165 .51873 m .40517 .52493 L .41181 .53113 L p .361 .498 .861 r
F P
0 g
s
.40517 .52493 m .41165 .51873 L .40621 .51354 L p .357 .498 .862 r
F P
0 g
s
.3863 .50582 m .39581 .50295 L .39088 .4976 L p .352 .502 .868 r
F P
0 g
s
.39088 .4976 m .38043 .4994 L .3863 .50582 L p .352 .502 .868 r
F P
0 g
s
.41722 .52381 m .41181 .53113 L .41858 .53717 L p .365 .499 .86 r
F P
0 g
s
.41181 .53113 m .41722 .52381 L .41165 .51873 L p .361 .498 .861 r
F P
0 g
s
.31132 .43994 m .32748 .44523 L .32393 .43896 L p .356 .544 .901 r
F P
0 g
s
.32393 .43896 m .30723 .43306 L .31132 .43994 L p .356 .544 .901 r
F P
0 g
s
.65159 .70914 m .63849 .69787 L .62615 .70136 L p .545 .654 .907 r
F P
0 g
s
.61383 .68901 m .62615 .70136 L .63849 .69787 L p .536 .643 .902 r
F P
0 g
s
.52823 .63301 m .53705 .64893 L .54739 .64976 L p .492 .577 .868 r
F P
0 g
s
.53705 .64893 m .52823 .63301 L .51864 .63126 L p .491 .571 .864 r
F P
0 g
s
.71955 .72391 m .70524 .71745 L .69174 .72416 L p .617 .713 .914 r
F P
0 g
s
.67802 .71469 m .69174 .72416 L .70524 .71745 L p .571 .692 .923 r
F P
0 g
s
.38043 .4994 m .39088 .4976 L .38617 .49224 L p .352 .505 .871 r
F P
0 g
s
.38617 .49224 m .3748 .493 L .38043 .4994 L p .352 .505 .871 r
F P
0 g
s
.4229 .52874 m .41858 .53717 L .42546 .54301 L p .369 .5 .86 r
F P
0 g
s
.41858 .53717 m .4229 .52874 L .41722 .52381 L p .365 .499 .86 r
F P
0 g
s
.13104 .34723 m .14913 .35063 L .14655 .34011 L p .517 .678 .938 r
F P
0 g
s
.14655 .34011 m .12821 .33541 L .13104 .34723 L p .517 .678 .938 r
F P
0 g
s
.46067 .56779 m .46311 .58192 L .47127 .5864 L p .413 .522 .859 r
F P
0 g
s
.46311 .58192 m .46067 .56779 L .45361 .56354 L p .405 .516 .857 r
F P
0 g
s
.26578 .4069 m .28314 .41313 L .28028 .40621 L p .386 .583 .919 r
F P
0 g
s
.28028 .40621 m .26253 .39949 L .26578 .4069 L p .386 .583 .919 r
F P
0 g
s
.3748 .493 m .38617 .49224 L .38167 .4869 L p .352 .508 .873 r
F P
0 g
s
.38167 .4869 m .36943 .48666 L .3748 .493 L p .352 .508 .873 r
F P
0 g
s
.33587 .45823 m .35098 .46219 L .34721 .45636 L p .352 .528 .89 r
F P
0 g
s
.34721 .45636 m .33146 .45165 L .33587 .45823 L p .352 .528 .89 r
F P
0 g
s
.42868 .53352 m .42546 .54301 L .43243 .5486 L p .374 .502 .859 r
F P
0 g
s
.42546 .54301 m .42868 .53352 L .4229 .52874 L p .369 .5 .86 r
F P
0 g
s
.48733 .59374 m .49309 .60958 L .50202 .61266 L p .448 .543 .861 r
F P
0 g
s
.49309 .60958 m .48733 .59374 L .47935 .59034 L p .442 .537 .858 r
F P
0 g
s
.28662 .42021 m .30366 .42636 L .30062 .41982 L p .372 .565 .911 r
F P
0 g
s
.30062 .41982 m .28314 .41313 L .28662 .42021 L p .372 .565 .911 r
F P
0 g
s
.20618 .37388 m .22405 .37942 L .22163 .37126 L p .437 .635 .939 r
F P
0 g
s
.22163 .37126 m .20346 .36523 L .20618 .37388 L p .437 .635 .939 r
F P
0 g
s
.67802 .71469 m .66418 .70458 L .65159 .70914 L p .555 .669 .914 r
F P
0 g
s
.63849 .69787 m .65159 .70914 L .66418 .70458 L p .541 .658 .912 r
F P
0 g
s
.51078 .61511 m .51864 .63126 L .52823 .63301 L p .473 .562 .865 r
F P
0 g
s
.51864 .63126 m .51078 .61511 L .50202 .61266 L p .47 .556 .861 r
F P
0 g
s
.24487 .3933 m .26253 .39949 L .25997 .39221 L p .405 .602 .927 r
F P
0 g
s
.25997 .39221 m .24197 .38553 L .24487 .3933 L p .405 .602 .927 r
F P
0 g
s
.43453 .53809 m .43243 .5486 L .43946 .55391 L p .38 .505 .859 r
F P
0 g
s
.43243 .5486 m .43453 .53809 L .42868 .53352 L p .374 .502 .859 r
F P
0 g
s
.36943 .48666 m .38167 .4869 L .37742 .4816 L p .353 .511 .876 r
F P
0 g
s
.37742 .4816 m .36435 .48039 L .36943 .48666 L p .353 .511 .876 r
F P
0 g
s
.14913 .35063 m .16722 .35489 L .16491 .34513 L p .492 .674 .946 r
F P
0 g
s
.16491 .34513 m .14655 .34011 L .14913 .35063 L p .492 .674 .946 r
F P
0 g
s
.4677 .57164 m .47127 .5864 L .47935 .59034 L p .421 .527 .86 r
F P
0 g
s
.47127 .5864 m .4677 .57164 L .46067 .56779 L p .413 .522 .859 r
F P
0 g
s
.30723 .43306 m .32393 .43896 L .32084 .43287 L p .364 .55 .902 r
F P
0 g
s
.32084 .43287 m .30366 .42636 L .30723 .43306 L p .364 .55 .902 r
F P
0 g
s
.44042 .54243 m .43946 .55391 L .44653 .5589 L p .386 .509 .86 r
F P
0 g
s
.43946 .55391 m .44042 .54243 L .43453 .53809 L p .38 .505 .859 r
F P
0 g
s
.74818 .72458 m .7332 .71912 L .71955 .72391 L p .197 .704 .902 r
F P
0 g
s
.70524 .71745 m .71955 .72391 L .7332 .71912 L p .489 .735 .98 r
F P
0 g
s
.36435 .48039 m .37742 .4816 L .37342 .47636 L p .354 .515 .878 r
F P
0 g
s
.37342 .47636 m .35956 .47422 L .36435 .48039 L p .354 .515 .878 r
F P
0 g
s
.59033 .67801 m .57873 .66398 L .56813 .66487 L p .521 .609 .882 r
F P
0 g
s
.55739 .64991 m .56813 .66487 L .57873 .66398 L p .506 .598 .879 r
F P
0 g
s
.56813 .66487 m .55739 .64991 L .54739 .64976 L p .508 .593 .874 r
F P
0 g
s
.61383 .68901 m .60141 .67605 L .59033 .67801 L p .53 .626 .892 r
F P
0 g
s
.57873 .66398 m .59033 .67801 L .60141 .67605 L p .517 .614 .888 r
F P
0 g
s
.33146 .45165 m .34721 .45636 L .3438 .45066 L p .356 .533 .892 r
F P
0 g
s
.3438 .45066 m .32748 .44523 L .33146 .45165 L p .356 .533 .892 r
F P
0 g
s
.53755 .63409 m .54739 .64976 L .55739 .64991 L p .492 .582 .873 r
F P
0 g
s
.54739 .64976 m .53755 .63409 L .52823 .63301 L p .492 .577 .868 r
F P
0 g
s
.16722 .35489 m .18533 .35977 L .18328 .35061 L p .475 .664 .945 r
F P
0 g
s
.18328 .35061 m .16491 .34513 L .16722 .35489 L p .475 .664 .945 r
F P
0 g
s
.49518 .5966 m .50202 .61266 L .51078 .61511 L p .453 .548 .863 r
F P
0 g
s
.50202 .61266 m .49518 .5966 L .48733 .59374 L p .448 .543 .861 r
F P
0 g
s
.63849 .69787 m .62529 .68601 L .61383 .68901 L p .536 .643 .902 r
F P
0 g
s
.60141 .67605 m .61383 .68901 L .62529 .68601 L p .525 .63 .898 r
F P
0 g
s
.70524 .71745 m .69072 .70903 L .67802 .71469 L p .571 .692 .923 r
F P
0 g
s
.66418 .70458 m .67802 .71469 L .69072 .70903 L p .548 .676 .922 r
F P
0 g
s
.44635 .54653 m .44653 .5589 L .45361 .56354 L p .392 .513 .86 r
F P
0 g
s
.44653 .5589 m .44635 .54653 L .44042 .54243 L p .386 .509 .86 r
F P
0 g
s
.22405 .37942 m .24197 .38553 L .23985 .37786 L p .427 .621 .933 r
F P
0 g
s
.23985 .37786 m .22163 .37126 L .22405 .37942 L p .427 .621 .933 r
F P
0 g
s
.35956 .47422 m .37342 .47636 L .3697 .47118 L p .356 .518 .881 r
F P
0 g
s
.3697 .47118 m .3551 .46814 L .35956 .47422 L p .356 .518 .881 r
F P
0 g
s
.47466 .57507 m .47935 .59034 L .48733 .59374 L p .427 .532 .862 r
F P
0 g
s
.47935 .59034 m .47466 .57507 L .4677 .57164 L p .421 .527 .86 r
F P
0 g
s
.51933 .61693 m .52823 .63301 L .53755 .63409 L p .475 .567 .868 r
F P
0 g
s
.52823 .63301 m .51933 .61693 L .51078 .61511 L p .473 .562 .865 r
F P
0 g
s
.28314 .41313 m .30062 .41982 L .29813 .41345 L p .382 .57 .912 r
F P
0 g
s
.29813 .41345 m .28028 .40621 L .28314 .41313 L p .382 .57 .912 r
F P
0 g
s
.66418 .70458 m .65022 .69384 L .63849 .69787 L p .541 .658 .912 r
F P
0 g
s
.62529 .68601 m .63849 .69787 L .65022 .69384 L p .53 .646 .908 r
F P
0 g
s
.26253 .39949 m .28028 .40621 L .27804 .39945 L p .398 .588 .919 r
F P
0 g
s
.27804 .39945 m .25997 .39221 L .26253 .39949 L p .398 .588 .919 r
F P
0 g
s
.45229 .55035 m .45361 .56354 L .46067 .56779 L p .398 .517 .861 r
F P
0 g
s
.45361 .56354 m .45229 .55035 L .44635 .54653 L p .392 .513 .86 r
F P
0 g
s
.32748 .44523 m .3438 .45066 L .34078 .4451 L p .362 .538 .894 r
F P
0 g
s
.34078 .4451 m .32393 .43896 L .32748 .44523 L p .362 .538 .894 r
F P
0 g
s
.18533 .35977 m .20346 .36523 L .20167 .35661 L p .461 .652 .942 r
F P
0 g
s
.20167 .35661 m .18328 .35061 L .18533 .35977 L p .461 .652 .942 r
F P
0 g
s
.3551 .46814 m .3697 .47118 L .36626 .46609 L p .358 .522 .883 r
F P
0 g
s
.36626 .46609 m .35098 .46219 L .3551 .46814 L p .358 .522 .883 r
F P
0 g
s
.30366 .42636 m .32084 .43287 L .31822 .42693 L p .372 .555 .903 r
F P
0 g
s
.31822 .42693 m .30062 .41982 L .30366 .42636 L p .372 .555 .903 r
F P
0 g
s
.09172 .32509 m .10991 .3307 L .1082 .31649 L p .492 .547 .84 r
F P
0 g
s
.1082 .31649 m .09021 .30502 L .09172 .32509 L p .492 .547 .84 r
F P
0 g
s
.50287 .59892 m .51078 .61511 L .51933 .61693 L p .456 .553 .866 r
F P
0 g
s
.51078 .61511 m .50287 .59892 L .49518 .5966 L p .453 .548 .863 r
F P
0 g
s
.48152 .57806 m .48733 .59374 L .49518 .5966 L p .433 .537 .864 r
F P
0 g
s
.48733 .59374 m .48152 .57806 L .47466 .57507 L p .427 .532 .862 r
F P
0 g
s
.45821 .55387 m .46067 .56779 L .4677 .57164 L p .404 .521 .862 r
F P
0 g
s
.46067 .56779 m .45821 .55387 L .45229 .55035 L p .398 .517 .861 r
F P
0 g
s
.7332 .71912 m .718 .71177 L .70524 .71745 L p .489 .735 .98 r
F P
0 g
s
.69072 .70903 m .70524 .71745 L .718 .71177 L p .526 .699 .949 r
F P
0 g
s
.24197 .38553 m .25997 .39221 L .25812 .38506 L p .417 .606 .926 r
F P
0 g
s
.25812 .38506 m .23985 .37786 L .24197 .38553 L p .417 .606 .926 r
F P
0 g
s
.60141 .67605 m .58888 .66249 L .57873 .66398 L p .517 .614 .888 r
F P
0 g
s
.56703 .64943 m .57873 .66398 L .58888 .66249 L p .503 .602 .884 r
F P
0 g
s
.57873 .66398 m .56703 .64943 L .55739 .64991 L p .506 .598 .879 r
F P
0 g
s
.54656 .63454 m .55739 .64991 L .56703 .64943 L p .491 .586 .877 r
F P
0 g
s
.55739 .64991 m .54656 .63454 L .53755 .63409 L p .492 .582 .873 r
F P
0 g
s
.41383 .50819 m .40621 .51354 L .41165 .51873 L p .367 .506 .865 r
F P
0 g
s
.40621 .51354 m .41383 .50819 L .40958 .50401 L p .366 .506 .866 r
F P
0 g
s
.40958 .50401 m .40092 .50827 L .40621 .51354 L p .366 .506 .866 r
F P
0 g
s
.41822 .51231 m .41165 .51873 L .41722 .52381 L p .369 .506 .864 r
F P
0 g
s
.41165 .51873 m .41822 .51231 L .41383 .50819 L p .367 .506 .865 r
F P
0 g
s
.40092 .50827 m .40958 .50401 L .40546 .49976 L p .365 .507 .868 r
F P
0 g
s
.40546 .49976 m .39581 .50295 L .40092 .50827 L p .365 .507 .868 r
F P
0 g
s
.7332 .71912 m .74818 .72458 L .76247 .72974 L p 0 .347 .667 r
F P
0 g
s
.10991 .3307 m .12821 .33541 L .1266 .32366 L p .509 .634 .909 r
F P
0 g
s
.1266 .32366 m .1082 .31649 L .10991 .3307 L p .509 .634 .909 r
F P
0 g
s
.69072 .70903 m .67606 .69956 L .66418 .70458 L p .548 .676 .922 r
F P
0 g
s
.65022 .69384 m .66418 .70458 L .67606 .69956 L p .535 .662 .918 r
F P
0 g
s
.35098 .46219 m .36626 .46609 L .36312 .46109 L p .36 .526 .885 r
F P
0 g
s
.36312 .46109 m .34721 .45636 L .35098 .46219 L p .36 .526 .885 r
F P
0 g
s
.4227 .51632 m .41722 .52381 L .4229 .52874 L p .371 .506 .864 r
F P
0 g
s
.41722 .52381 m .4227 .51632 L .41822 .51231 L p .369 .506 .864 r
F P
0 g
s
.39581 .50295 m .40546 .49976 L .40149 .49548 L p .364 .509 .869 r
F P
0 g
s
.40149 .49548 m .39088 .4976 L .39581 .50295 L p .364 .509 .869 r
F P
0 g
s
.20346 .36523 m .22163 .37126 L .22008 .36317 L p .449 .638 .937 r
F P
0 g
s
.22008 .36317 m .20167 .35661 L .20346 .36523 L p .449 .638 .937 r
F P
0 g
s
.62529 .68601 m .61197 .67353 L .60141 .67605 L p .525 .63 .898 r
F P
0 g
s
.58888 .66249 m .60141 .67605 L .61197 .67353 L p .513 .618 .893 r
F P
0 g
s
.52763 .61815 m .53755 .63409 L .54656 .63454 L p .476 .571 .872 r
F P
0 g
s
.53755 .63409 m .52763 .61815 L .51933 .61693 L p .475 .567 .868 r
F P
0 g
s
.42729 .52022 m .4229 .52874 L .42868 .53352 L p .374 .507 .863 r
F P
0 g
s
.4229 .52874 m .42729 .52022 L .4227 .51632 L p .371 .506 .864 r
F P
0 g
s
.39088 .4976 m .40149 .49548 L .39769 .49117 L p .364 .511 .871 r
F P
0 g
s
.39769 .49117 m .38617 .49224 L .39088 .4976 L p .364 .511 .871 r
F P
0 g
s
.32393 .43896 m .34078 .4451 L .33816 .43969 L p .367 .542 .895 r
F P
0 g
s
.33816 .43969 m .32084 .43287 L .32393 .43896 L p .367 .542 .895 r
F P
0 g
s
.43194 .52398 m .42868 .53352 L .43453 .53809 L p .378 .509 .863 r
F P
0 g
s
.42868 .53352 m .43194 .52398 L .42729 .52022 L p .374 .507 .863 r
F P
0 g
s
.46409 .55708 m .4677 .57164 L .47466 .57507 L p .41 .525 .863 r
F P
0 g
s
.4677 .57164 m .46409 .55708 L .45821 .55387 L p .404 .521 .862 r
F P
0 g
s
.38617 .49224 m .39769 .49117 L .39408 .48687 L p .364 .513 .873 r
F P
0 g
s
.39408 .48687 m .38167 .4869 L .38617 .49224 L p .364 .513 .873 r
F P
0 g
s
.12821 .33541 m .14655 .34011 L .14513 .32956 L p .505 .667 .935 r
F P
0 g
s
.14513 .32956 m .1266 .32366 L .12821 .33541 L p .505 .667 .935 r
F P
0 g
s
.48827 .58062 m .49518 .5966 L .50287 .59892 L p .437 .542 .865 r
F P
0 g
s
.49518 .5966 m .48827 .58062 L .48152 .57806 L p .433 .537 .864 r
F P
0 g
s
.65022 .69384 m .63616 .68248 L .62529 .68601 L p .53 .646 .908 r
F P
0 g
s
.61197 .67353 m .62529 .68601 L .63616 .68248 L p .519 .634 .903 r
F P
0 g
s
.28028 .40621 m .29813 .41345 L .2962 .40725 L p .392 .575 .912 r
F P
0 g
s
.2962 .40725 m .27804 .39945 L .28028 .40621 L p .392 .575 .912 r
F P
0 g
s
.43665 .52759 m .43453 .53809 L .44042 .54243 L p .381 .51 .863 r
F P
0 g
s
.43453 .53809 m .43665 .52759 L .43194 .52398 L p .378 .509 .863 r
F P
0 g
s
.51036 .60072 m .51933 .61693 L .52763 .61815 L p .459 .558 .869 r
F P
0 g
s
.51933 .61693 m .51036 .60072 L .50287 .59892 L p .456 .553 .866 r
F P
0 g
s
.34721 .45636 m .36312 .46109 L .3603 .4562 L p .363 .529 .886 r
F P
0 g
s
.3603 .4562 m .3438 .45066 L .34721 .45636 L p .363 .529 .886 r
F P
0 g
s
.30062 .41982 m .31822 .42693 L .31608 .42117 L p .38 .559 .904 r
F P
0 g
s
.31608 .42117 m .29813 .41345 L .30062 .41982 L p .38 .559 .904 r
F P
0 g
s
.38167 .4869 m .39408 .48687 L .39066 .48258 L p .364 .515 .874 r
F P
0 g
s
.39066 .48258 m .37742 .4816 L .38167 .4869 L p .364 .515 .874 r
F P
0 g
s
.14655 .34011 m .16491 .34513 L .16369 .33535 L p .495 .672 .943 r
F P
0 g
s
.16369 .33535 m .14513 .32956 L .14655 .34011 L p .495 .672 .943 r
F P
0 g
s
.22163 .37126 m .23985 .37786 L .23852 .37031 L p .438 .624 .931 r
F P
0 g
s
.23852 .37031 m .22008 .36317 L .22163 .37126 L p .438 .624 .931 r
F P
0 g
s
.25997 .39221 m .27804 .39945 L .27645 .39285 L p .408 .592 .919 r
F P
0 g
s
.27645 .39285 m .25812 .38506 L .25997 .39221 L p .408 .592 .919 r
F P
0 g
s
.4414 .53102 m .44042 .54243 L .44635 .54653 L p .385 .513 .864 r
F P
0 g
s
.44042 .54243 m .4414 .53102 L .43665 .52759 L p .381 .51 .863 r
F P
0 g
s
.46992 .55997 m .47466 .57507 L .48152 .57806 L p .415 .529 .865 r
F P
0 g
s
.47466 .57507 m .46992 .55997 L .46409 .55708 L p .41 .525 .863 r
F P
0 g
s
.37742 .4816 m .39066 .48258 L .38746 .47832 L p .365 .517 .876 r
F P
0 g
s
.38746 .47832 m .37342 .47636 L .37742 .4816 L p .365 .517 .876 r
F P
0 g
s
.718 .71177 m .70266 .70336 L .69072 .70903 L p .526 .699 .949 r
F P
0 g
s
.67606 .69956 m .69072 .70903 L .70266 .70336 L p .529 .679 .933 r
F P
0 g
s
.32084 .43287 m .33816 .43969 L .33595 .43443 L p .373 .546 .896 r
F P
0 g
s
.33595 .43443 m .31822 .42693 L .32084 .43287 L p .373 .546 .896 r
F P
0 g
s
.67606 .69956 m .66128 .68935 L .65022 .69384 L p .535 .662 .918 r
F P
0 g
s
.63616 .68248 m .65022 .69384 L .66128 .68935 L p .524 .649 .913 r
F P
0 g
s
.58888 .66249 m .57626 .64836 L .56703 .64943 L p .503 .602 .884 r
F P
0 g
s
.55524 .63439 m .56703 .64943 L .57626 .64836 L p .489 .59 .882 r
F P
0 g
s
.56703 .64943 m .55524 .63439 L .54656 .63454 L p .491 .586 .877 r
F P
0 g
s
.44617 .53426 m .44635 .54653 L .45229 .55035 L p .389 .515 .864 r
F P
0 g
s
.44635 .54653 m .44617 .53426 L .4414 .53102 L p .385 .513 .864 r
F P
0 g
s
.76247 .72974 m .74612 .71634 L .7332 .71912 L p 0 .347 .667 r
F P
0 g
s
.718 .71177 m .7332 .71912 L .74612 .71634 L p .375 .678 .976 r
F P
0 g
s
.16491 .34513 m .18328 .35061 L .18227 .34146 L p .483 .665 .942 r
F P
0 g
s
.18227 .34146 m .16369 .33535 L .16491 .34513 L p .483 .665 .942 r
F P
0 g
s
.53565 .6188 m .54656 .63454 L .55524 .63439 L p .476 .575 .876 r
F P
0 g
s
.54656 .63454 m .53565 .6188 L .52763 .61815 L p .476 .571 .872 r
F P
0 g
s
.49488 .58274 m .50287 .59892 L .51036 .60072 L p .441 .546 .867 r
F P
0 g
s
.50287 .59892 m .49488 .58274 L .48827 .58062 L p .437 .542 .865 r
F P
0 g
s
.61197 .67353 m .59856 .66044 L .58888 .66249 L p .513 .618 .893 r
F P
0 g
s
.57626 .64836 m .58888 .66249 L .59856 .66044 L p .5 .605 .889 r
F P
0 g
s
.3438 .45066 m .3603 .4562 L .3578 .45143 L p .367 .533 .888 r
F P
0 g
s
.3578 .45143 m .34078 .4451 L .3438 .45066 L p .367 .533 .888 r
F P
0 g
s
.37342 .47636 m .38746 .47832 L .38447 .4741 L p .365 .519 .878 r
F P
0 g
s
.38447 .4741 m .3697 .47118 L .37342 .47636 L p .365 .519 .878 r
F P
0 g
s
.45095 .53729 m .45229 .55035 L .45821 .55387 L p .393 .518 .865 r
F P
0 g
s
.45229 .55035 m .45095 .53729 L .44617 .53426 L p .389 .515 .864 r
F P
0 g
s
.47566 .56251 m .48152 .57806 L .48827 .58062 L p .419 .533 .866 r
F P
0 g
s
.48152 .57806 m .47566 .56251 L .46992 .55997 L p .415 .529 .865 r
F P
0 g
s
.51763 .60199 m .52763 .61815 L .53565 .6188 L p .46 .562 .872 r
F P
0 g
s
.52763 .61815 m .51763 .60199 L .51036 .60072 L p .459 .558 .869 r
F P
0 g
s
.23985 .37786 m .25812 .38506 L .257 .37806 L p .428 .61 .925 r
F P
0 g
s
.257 .37806 m .23852 .37031 L .23985 .37786 L p .428 .61 .925 r
F P
0 g
s
.63616 .68248 m .62199 .67049 L .61197 .67353 L p .519 .634 .903 r
F P
0 g
s
.59856 .66044 m .61197 .67353 L .62199 .67049 L p .508 .621 .899 r
F P
0 g
s
.18328 .35061 m .20167 .35661 L .20084 .34804 L p .472 .653 .939 r
F P
0 g
s
.20084 .34804 m .18227 .34146 L .18328 .35061 L p .472 .653 .939 r
F P
0 g
s
.3697 .47118 m .38447 .4741 L .38172 .46994 L p .367 .522 .879 r
F P
0 g
s
.38172 .46994 m .36626 .46609 L .3697 .47118 L p .367 .522 .879 r
F P
0 g
s
.29813 .41345 m .31608 .42117 L .31445 .41558 L p .388 .563 .904 r
F P
0 g
s
.31445 .41558 m .2962 .40725 L .29813 .41345 L p .388 .563 .904 r
F P
0 g
s
.27804 .39945 m .2962 .40725 L .29485 .40122 L p .401 .579 .912 r
F P
0 g
s
.29485 .40122 m .27645 .39285 L .27804 .39945 L p .401 .579 .912 r
F P
0 g
s
.45571 .54009 m .45821 .55387 L .46409 .55708 L p .397 .521 .865 r
F P
0 g
s
.45821 .55387 m .45571 .54009 L .45095 .53729 L p .393 .518 .865 r
F P
0 g
s
.09021 .30502 m .1082 .31649 L .1074 .30767 L p .046 .539 .884 r
F P
0 g
s
.1074 .30767 m .08873 .301 L .09021 .30502 L p .046 .539 .884 r
F P
0 g
s
.34078 .4451 m .3578 .45143 L .35564 .44678 L p .371 .536 .889 r
F P
0 g
s
.35564 .44678 m .33816 .43969 L .34078 .4451 L p .371 .536 .889 r
F P
0 g
s
.70266 .70336 m .6872 .69422 L .67606 .69956 L p .529 .679 .933 r
F P
0 g
s
.66128 .68935 m .67606 .69956 L .6872 .69422 L p .525 .665 .925 r
F P
0 g
s
.31822 .42693 m .33595 .43443 L .33416 .42933 L p .379 .55 .897 r
F P
0 g
s
.33416 .42933 m .31608 .42117 L .31822 .42693 L p .379 .55 .897 r
F P
0 g
s
.50132 .58441 m .51036 .60072 L .51763 .60199 L p .443 .55 .869 r
F P
0 g
s
.51036 .60072 m .50132 .58441 L .49488 .58274 L p .441 .546 .867 r
F P
0 g
s
.36626 .46609 m .38172 .46994 L .37922 .46585 L p .368 .524 .881 r
F P
0 g
s
.37922 .46585 m .36312 .46109 L .36626 .46609 L p .368 .524 .881 r
F P
0 g
s
.20167 .35661 m .22008 .36317 L .21942 .35517 L p .46 .64 .935 r
F P
0 g
s
.21942 .35517 m .20084 .34804 L .20167 .35661 L p .46 .64 .935 r
F P
0 g
s
.4813 .56471 m .48827 .58062 L .49488 .58274 L p .423 .536 .867 r
F P
0 g
s
.48827 .58062 m .4813 .56471 L .47566 .56251 L p .419 .533 .866 r
F P
0 g
s
.66128 .68935 m .6464 .67848 L .63616 .68248 L p .524 .649 .913 r
F P
0 g
s
.62199 .67049 m .63616 .68248 L .6464 .67848 L p .514 .637 .908 r
F P
0 g
s
.74612 .71634 m .72996 .70648 L .718 .71177 L p .375 .678 .976 r
F P
0 g
s
.70266 .70336 m .718 .71177 L .72996 .70648 L p .49 .687 .955 r
F P
0 g
s
.46044 .54266 m .46409 .55708 L .46992 .55997 L p .401 .524 .866 r
F P
0 g
s
.46409 .55708 m .46044 .54266 L .45571 .54009 L p .397 .521 .865 r
F P
0 g
s
.57626 .64836 m .56354 .63368 L .55524 .63439 L p .489 .59 .882 r
F P
0 g
s
.54336 .61891 m .55524 .63439 L .56354 .63368 L p .474 .579 .879 r
F P
0 g
s
.55524 .63439 m .54336 .61891 L .53565 .6188 L p .476 .575 .876 r
F P
0 g
s
.25812 .38506 m .27645 .39285 L .27552 .38641 L p .418 .596 .918 r
F P
0 g
s
.27552 .38641 m .257 .37806 L .25812 .38506 L p .418 .596 .918 r
F P
0 g
s
.59856 .66044 m .58504 .64673 L .57626 .64836 L p .5 .605 .889 r
F P
0 g
s
.56354 .63368 m .57626 .64836 L .58504 .64673 L p .486 .593 .886 r
F P
0 g
s
.42157 .50264 m .41383 .50819 L .41822 .51231 L p .374 .512 .868 r
F P
0 g
s
.41383 .50819 m .42157 .50264 L .41835 .4995 L p .374 .512 .868 r
F P
0 g
s
.41835 .4995 m .40958 .50401 L .41383 .50819 L p .374 .512 .868 r
F P
0 g
s
.42488 .5057 m .41822 .51231 L .4227 .51632 L p .375 .512 .867 r
F P
0 g
s
.41822 .51231 m .42488 .5057 L .42157 .50264 L p .374 .512 .868 r
F P
0 g
s
.40958 .50401 m .41835 .4995 L .41524 .49632 L p .373 .513 .869 r
F P
0 g
s
.41524 .49632 m .40546 .49976 L .40958 .50401 L p .373 .513 .869 r
F P
0 g
s
.52466 .60277 m .53565 .6188 L .54336 .61891 L p .46 .565 .875 r
F P
0 g
s
.53565 .6188 m .52466 .60277 L .51763 .60199 L p .46 .562 .872 r
F P
0 g
s
.42827 .5087 m .4227 .51632 L .42729 .52022 L p .377 .512 .867 r
F P
0 g
s
.4227 .51632 m .42827 .5087 L .42488 .5057 L p .375 .512 .867 r
F P
0 g
s
.40546 .49976 m .41524 .49632 L .41225 .4931 L p .373 .514 .87 r
F P
0 g
s
.41225 .4931 m .40149 .49548 L .40546 .49976 L p .373 .514 .87 r
F P
0 g
s
.36312 .46109 m .37922 .46585 L .37697 .46184 L p .37 .527 .882 r
F P
0 g
s
.37697 .46184 m .3603 .4562 L .36312 .46109 L p .37 .527 .882 r
F P
0 g
s
.43173 .5116 m .42729 .52022 L .43194 .52398 L p .378 .513 .866 r
F P
0 g
s
.42729 .52022 m .43173 .5116 L .42827 .5087 L p .377 .512 .867 r
F P
0 g
s
.22008 .36317 m .23852 .37031 L .23801 .36289 L p .449 .627 .929 r
F P
0 g
s
.23801 .36289 m .21942 .35517 L .22008 .36317 L p .449 .627 .929 r
F P
0 g
s
.40149 .49548 m .41225 .4931 L .40938 .48986 L p .372 .515 .871 r
F P
0 g
s
.40938 .48986 m .39769 .49117 L .40149 .49548 L p .372 .515 .871 r
F P
0 g
s
.62199 .67049 m .60772 .65786 L .59856 .66044 L p .508 .621 .899 r
F P
0 g
s
.58504 .64673 m .59856 .66044 L .60772 .65786 L p .496 .609 .894 r
F P
0 g
s
.1082 .31649 m .1266 .32366 L .12613 .31359 L p .41 .682 .973 r
F P
0 g
s
.12613 .31359 m .1074 .30767 L .1082 .31649 L p .41 .682 .973 r
F P
0 g
s
.33816 .43969 m .35564 .44678 L .35382 .44227 L p .374 .539 .89 r
F P
0 g
s
.35382 .44227 m .33595 .43443 L .33816 .43969 L p .374 .539 .89 r
F P
0 g
s
.43524 .51439 m .43194 .52398 L .43665 .52759 L p .38 .513 .866 r
F P
0 g
s
.43194 .52398 m .43524 .51439 L .43173 .5116 L p .378 .513 .866 r
F P
0 g
s
.46513 .54498 m .46992 .55997 L .47566 .56251 L p .405 .527 .867 r
F P
0 g
s
.46992 .55997 m .46513 .54498 L .46044 .54266 L p .401 .524 .866 r
F P
0 g
s
.48682 .56655 m .49488 .58274 L .50132 .58441 L p .426 .54 .869 r
F P
0 g
s
.49488 .58274 m .48682 .56655 L .4813 .56471 L p .423 .536 .867 r
F P
0 g
s
.39769 .49117 m .40938 .48986 L .40666 .48661 L p .372 .516 .872 r
F P
0 g
s
.40666 .48661 m .39408 .48687 L .39769 .49117 L p .372 .516 .872 r
F P
0 g
s
.50756 .58565 m .51763 .60199 L .52466 .60277 L p .445 .553 .872 r
F P
0 g
s
.51763 .60199 m .50756 .58565 L .50132 .58441 L p .443 .55 .869 r
F P
0 g
s
.2962 .40725 m .31445 .41558 L .31332 .41017 L p .395 .567 .904 r
F P
0 g
s
.31332 .41017 m .29485 .40122 L .2962 .40725 L p .395 .567 .904 r
F P
0 g
s
.4388 .51707 m .43665 .52759 L .4414 .53102 L p .382 .514 .866 r
F P
0 g
s
.43665 .52759 m .4388 .51707 L .43524 .51439 L p .38 .513 .866 r
F P
0 g
s
.6872 .69422 m .67164 .68444 L .66128 .68935 L p .525 .665 .925 r
F P
0 g
s
.6464 .67848 m .66128 .68935 L .67164 .68444 L p .517 .652 .919 r
F P
0 g
s
.31608 .42117 m .33416 .42933 L .3328 .42441 L p .385 .553 .897 r
F P
0 g
s
.3328 .42441 m .31445 .41558 L .31608 .42117 L p .385 .553 .897 r
F P
0 g
s
.39408 .48687 m .40666 .48661 L .40409 .48336 L p .373 .518 .873 r
F P
0 g
s
.40409 .48336 m .39066 .48258 L .39408 .48687 L p .373 .518 .873 r
F P
0 g
s
.1266 .32366 m .14513 .32956 L .14487 .3195 L p .481 .686 .957 r
F P
0 g
s
.14487 .3195 m .12613 .31359 L .1266 .32366 L p .481 .686 .957 r
F P
0 g
s
.3603 .4562 m .37697 .46184 L .37498 .45792 L p .372 .529 .883 r
F P
0 g
s
.37498 .45792 m .3578 .45143 L .3603 .4562 L p .372 .529 .883 r
F P
0 g
s
.44239 .51962 m .4414 .53102 L .44617 .53426 L p .385 .516 .867 r
F P
0 g
s
.4414 .53102 m .44239 .51962 L .4388 .51707 L p .382 .514 .866 r
F P
0 g
s
.72996 .70648 m .71379 .69754 L .70266 .70336 L p .49 .687 .955 r
F P
0 g
s
.6872 .69422 m .70266 .70336 L .71379 .69754 L p .514 .677 .939 r
F P
0 g
s
.6464 .67848 m .63141 .66696 L .62199 .67049 L p .514 .637 .908 r
F P
0 g
s
.60772 .65786 m .62199 .67049 L .63141 .66696 L p .503 .624 .903 r
F P
0 g
s
.27645 .39285 m .29485 .40122 L .29409 .39538 L p .41 .582 .911 r
F P
0 g
s
.29409 .39538 m .27552 .38641 L .27645 .39285 L p .41 .582 .911 r
F P
0 g
s
.23852 .37031 m .257 .37806 L .25662 .37121 L p .438 .613 .923 r
F P
0 g
s
.25662 .37121 m .23801 .36289 L .23852 .37031 L p .438 .613 .923 r
F P
0 g
s
.39066 .48258 m .40409 .48336 L .40168 .48012 L p .373 .519 .874 r
F P
0 g
s
.40168 .48012 m .38746 .47832 L .39066 .48258 L p .373 .519 .874 r
F P
0 g
s
.46974 .54704 m .47566 .56251 L .4813 .56471 L p .408 .529 .868 r
F P
0 g
s
.47566 .56251 m .46974 .54704 L .46513 .54498 L p .405 .527 .867 r
F P
0 g
s
.14513 .32956 m .16369 .33535 L .1636 .32572 L p .494 .678 .947 r
F P
0 g
s
.1636 .32572 m .14487 .3195 L .14513 .32956 L p .494 .678 .947 r
F P
0 g
s
.44599 .52203 m .44617 .53426 L .45095 .53729 L p .387 .517 .867 r
F P
0 g
s
.44617 .53426 m .44599 .52203 L .44239 .51962 L p .385 .516 .867 r
F P
0 g
s
.33595 .43443 m .35382 .44227 L .35236 .4379 L p .379 .541 .891 r
F P
0 g
s
.35236 .4379 m .33416 .42933 L .33595 .43443 L p .379 .541 .891 r
F P
0 g
s
.58504 .64673 m .57143 .63244 L .56354 .63368 L p .486 .593 .886 r
F P
0 g
s
.55074 .6185 m .56354 .63368 L .57143 .63244 L p .472 .582 .883 r
F P
0 g
s
.56354 .63368 m .55074 .6185 L .54336 .61891 L p .474 .579 .879 r
F P
0 g
s
.4922 .56804 m .50132 .58441 L .50756 .58565 L p .429 .543 .87 r
F P
0 g
s
.50132 .58441 m .4922 .56804 L .48682 .56655 L p .426 .54 .869 r
F P
0 g
s
.5314 .60306 m .54336 .61891 L .55074 .6185 L p .46 .568 .878 r
F P
0 g
s
.54336 .61891 m .5314 .60306 L .52466 .60277 L p .46 .565 .875 r
F P
0 g
s
.38746 .47832 m .40168 .48012 L .39943 .47691 L p .373 .52 .875 r
F P
0 g
s
.39943 .47691 m .38447 .4741 L .38746 .47832 L p .373 .52 .875 r
F P
0 g
s
.16369 .33535 m .18227 .34146 L .1823 .33238 L p .49 .667 .942 r
F P
0 g
s
.1823 .33238 m .1636 .32572 L .16369 .33535 L p .49 .667 .942 r
F P
0 g
s
.74612 .71634 m .76247 .72974 L .77498 .72273 L p .47 .586 .888 r
F P
0 g
s
.4496 .52429 m .45095 .53729 L .45571 .54009 L p .39 .519 .867 r
F P
0 g
s
.45095 .53729 m .4496 .52429 L .44599 .52203 L p .387 .517 .867 r
F P
0 g
s
.3578 .45143 m .37498 .45792 L .37327 .45411 L p .374 .531 .884 r
F P
0 g
s
.37327 .45411 m .35564 .44678 L .3578 .45143 L p .374 .531 .884 r
F P
0 g
s
.60772 .65786 m .59335 .64459 L .58504 .64673 L p .496 .609 .894 r
F P
0 g
s
.57143 .63244 m .58504 .64673 L .59335 .64459 L p .483 .596 .89 r
F P
0 g
s
.51358 .58647 m .52466 .60277 L .5314 .60306 L p .445 .556 .874 r
F P
0 g
s
.52466 .60277 m .51358 .58647 L .50756 .58565 L p .445 .553 .872 r
F P
0 g
s
.47427 .54883 m .4813 .56471 L .48682 .56655 L p .411 .532 .869 r
F P
0 g
s
.4813 .56471 m .47427 .54883 L .46974 .54704 L p .408 .529 .868 r
F P
0 g
s
.38447 .4741 m .39943 .47691 L .39737 .47374 L p .374 .522 .876 r
F P
0 g
s
.39737 .47374 m .38172 .46994 L .38447 .4741 L p .374 .522 .876 r
F P
0 g
s
.18227 .34146 m .20084 .34804 L .20099 .33956 L p .48 .655 .937 r
F P
0 g
s
.20099 .33956 m .1823 .33238 L .18227 .34146 L p .48 .655 .937 r
F P
0 g
s
.257 .37806 m .27552 .38641 L .27525 .38016 L p .427 .599 .917 r
F P
0 g
s
.27525 .38016 m .25662 .37121 L .257 .37806 L p .427 .599 .917 r
F P
0 g
s
.67164 .68444 m .65596 .67402 L .6464 .67848 L p .517 .652 .919 r
F P
0 g
s
.63141 .66696 m .6464 .67848 L .65596 .67402 L p .507 .639 .913 r
F P
0 g
s
.45319 .52638 m .45571 .54009 L .46044 .54266 L p .392 .521 .868 r
F P
0 g
s
.45571 .54009 m .45319 .52638 L .4496 .52429 L p .39 .519 .867 r
F P
0 g
s
.31445 .41558 m .3328 .42441 L .33188 .41966 L p .391 .556 .897 r
F P
0 g
s
.33188 .41966 m .31332 .41017 L .31445 .41558 L p .391 .556 .897 r
F P
0 g
s
.77498 .72273 m .75783 .70922 L .74612 .71634 L p .47 .586 .888 r
F P
0 g
s
.72996 .70648 m .74612 .71634 L .75783 .70922 L p .505 .654 .926 r
F P
0 g
s
.29485 .40122 m .31332 .41017 L .31271 .40495 L p .403 .57 .904 r
F P
0 g
s
.31271 .40495 m .29409 .39538 L .29485 .40122 L p .403 .57 .904 r
F P
0 g
s
.71379 .69754 m .69756 .68855 L .6872 .69422 L p .514 .677 .939 r
F P
0 g
s
.67164 .68444 m .6872 .69422 L .69756 .68855 L p .515 .666 .93 r
F P
0 g
s
.63141 .66696 m .61632 .65479 L .60772 .65786 L p .503 .624 .903 r
F P
0 g
s
.59335 .64459 m .60772 .65786 L .61632 .65479 L p .491 .611 .899 r
F P
0 g
s
.20084 .34804 m .21942 .35517 L .21967 .34729 L p .469 .642 .932 r
F P
0 g
s
.21967 .34729 m .20099 .33956 L .20084 .34804 L p .469 .642 .932 r
F P
0 g
s
.38172 .46994 m .39737 .47374 L .39549 .47061 L p .374 .523 .877 r
F P
0 g
s
.39549 .47061 m .37922 .46585 L .38172 .46994 L p .374 .523 .877 r
F P
0 g
s
.4974 .56917 m .50756 .58565 L .51358 .58647 L p .43 .545 .872 r
F P
0 g
s
.50756 .58565 m .4974 .56917 L .4922 .56804 L p .429 .543 .87 r
F P
0 g
s
.33416 .42933 m .35236 .4379 L .35126 .43369 L p .383 .544 .891 r
F P
0 g
s
.35126 .43369 m .3328 .42441 L .33416 .42933 L p .383 .544 .891 r
F P
0 g
s
.35564 .44678 m .37327 .45411 L .37184 .45041 L p .377 .533 .884 r
F P
0 g
s
.37184 .45041 m .35382 .44227 L .35564 .44678 L p .377 .533 .884 r
F P
0 g
s
.45676 .5283 m .46044 .54266 L .46513 .54498 L p .395 .523 .868 r
F P
0 g
s
.46044 .54266 m .45676 .5283 L .45319 .52638 L p .392 .521 .868 r
F P
0 g
s
.4787 .55035 m .48682 .56655 L .4922 .56804 L p .414 .534 .87 r
F P
0 g
s
.48682 .56655 m .4787 .55035 L .47427 .54883 L p .411 .532 .869 r
F P
0 g
s
.21942 .35517 m .23801 .36289 L .23833 .35561 L p .458 .629 .927 r
F P
0 g
s
.23833 .35561 m .21967 .34729 L .21942 .35517 L p .458 .629 .927 r
F P
0 g
s
.27552 .38641 m .29409 .39538 L .29392 .38974 L p .418 .585 .91 r
F P
0 g
s
.29392 .38974 m .27525 .38016 L .27552 .38641 L p .418 .585 .91 r
F P
0 g
s
.57143 .63244 m .55774 .6176 L .55074 .6185 L p .472 .582 .883 r
F P
0 g
s
.53785 .60288 m .55074 .6185 L .55774 .6176 L p .458 .571 .88 r
F P
0 g
s
.55074 .6185 m .53785 .60288 L .5314 .60306 L p .46 .568 .878 r
F P
0 g
s
.37922 .46585 m .39549 .47061 L .39381 .46754 L p .375 .525 .878 r
F P
0 g
s
.39381 .46754 m .37697 .46184 L .37922 .46585 L p .375 .525 .878 r
F P
0 g
s
.51936 .58687 m .5314 .60306 L .53785 .60288 L p .445 .558 .876 r
F P
0 g
s
.5314 .60306 m .51936 .58687 L .51358 .58647 L p .445 .556 .874 r
F P
0 g
s
.46028 .53005 m .46513 .54498 L .46974 .54704 L p .397 .525 .869 r
F P
0 g
s
.46513 .54498 m .46028 .53005 L .45676 .5283 L p .395 .523 .868 r
F P
0 g
s
.59335 .64459 m .57889 .6307 L .57143 .63244 L p .483 .596 .89 r
F P
0 g
s
.55774 .6176 m .57143 .63244 L .57889 .6307 L p .469 .584 .887 r
F P
0 g
s
.75783 .70922 m .74091 .69957 L .72996 .70648 L p .505 .654 .926 r
F P
0 g
s
.71379 .69754 m .72996 .70648 L .74091 .69957 L p .516 .675 .936 r
F P
0 g
s
.65596 .67402 m .64019 .66297 L .63141 .66696 L p .507 .639 .913 r
F P
0 g
s
.61632 .65479 m .63141 .66696 L .64019 .66297 L p .497 .626 .908 r
F P
0 g
s
.35382 .44227 m .37184 .45041 L .37069 .44683 L p .379 .535 .885 r
F P
0 g
s
.37069 .44683 m .35236 .4379 L .35382 .44227 L p .379 .535 .885 r
F P
0 g
s
.69756 .68855 m .68123 .67913 L .67164 .68444 L p .515 .666 .93 r
F P
0 g
s
.65596 .67402 m .67164 .68444 L .68123 .67913 L p .509 .653 .924 r
F P
0 g
s
.42941 .4969 m .42157 .50264 L .42488 .5057 L p .38 .516 .869 r
F P
0 g
s
.42157 .50264 m .42941 .4969 L .42725 .49481 L p .379 .517 .87 r
F P
0 g
s
.42725 .49481 m .41835 .4995 L .42157 .50264 L p .379 .517 .87 r
F P
0 g
s
.23801 .36289 m .25662 .37121 L .257 .36454 L p .447 .615 .921 r
F P
0 g
s
.257 .36454 m .23833 .35561 L .23801 .36289 L p .447 .615 .921 r
F P
0 g
s
.43163 .49894 m .42488 .5057 L .42827 .5087 L p .38 .516 .869 r
F P
0 g
s
.42488 .5057 m .43163 .49894 L .42941 .4969 L p .38 .516 .869 r
F P
0 g
s
.37697 .46184 m .39381 .46754 L .39233 .46454 L p .376 .526 .879 r
F P
0 g
s
.39233 .46454 m .37498 .45792 L .37697 .46184 L p .376 .526 .879 r
F P
0 g
s
.483 .5516 m .4922 .56804 L .4974 .56917 L p .416 .536 .871 r
F P
0 g
s
.4922 .56804 m .483 .5516 L .4787 .55035 L p .414 .534 .87 r
F P
0 g
s
.41835 .4995 m .42725 .49481 L .42516 .49269 L p .379 .517 .87 r
F P
0 g
s
.42516 .49269 m .41524 .49632 L .41835 .4995 L p .379 .517 .87 r
F P
0 g
s
.43391 .50093 m .42827 .5087 L .43173 .5116 L p .381 .516 .869 r
F P
0 g
s
.42827 .5087 m .43391 .50093 L .43163 .49894 L p .38 .516 .869 r
F P
0 g
s
.31332 .41017 m .33188 .41966 L .33141 .41509 L p .397 .558 .897 r
F P
0 g
s
.33141 .41509 m .31271 .40495 L .31332 .41017 L p .397 .558 .897 r
F P
0 g
s
.50242 .56996 m .51358 .58647 L .51936 .58687 L p .431 .547 .873 r
F P
0 g
s
.51358 .58647 m .50242 .56996 L .4974 .56917 L p .43 .545 .872 r
F P
0 g
s
.41524 .49632 m .42516 .49269 L .42316 .49054 L p .379 .518 .871 r
F P
0 g
s
.42316 .49054 m .41225 .4931 L .41524 .49632 L p .379 .518 .871 r
F P
0 g
s
.61632 .65479 m .60114 .64196 L .59335 .64459 L p .491 .611 .899 r
F P
0 g
s
.57889 .6307 m .59335 .64459 L .60114 .64196 L p .479 .599 .894 r
F P
0 g
s
.43623 .50286 m .43173 .5116 L .43524 .51439 L p .381 .517 .869 r
F P
0 g
s
.43173 .5116 m .43623 .50286 L .43391 .50093 L p .381 .516 .869 r
F P
0 g
s
.46376 .5316 m .46974 .54704 L .47427 .54883 L p .4 .526 .869 r
F P
0 g
s
.46974 .54704 m .46376 .5316 L .46028 .53005 L p .397 .525 .869 r
F P
0 g
s
.3328 .42441 m .35126 .43369 L .35053 .42964 L p .387 .546 .891 r
F P
0 g
s
.35053 .42964 m .33188 .41966 L .3328 .42441 L p .387 .546 .891 r
F P
0 g
s
.41225 .4931 m .42316 .49054 L .42124 .48836 L p .379 .518 .871 r
F P
0 g
s
.42124 .48836 m .40938 .48986 L .41225 .4931 L p .379 .518 .871 r
F P
0 g
s
.43859 .50471 m .43524 .51439 L .4388 .51707 L p .382 .517 .869 r
F P
0 g
s
.43524 .51439 m .43859 .50471 L .43623 .50286 L p .381 .517 .869 r
F P
0 g
s
.40938 .48986 m .42124 .48836 L .41941 .48618 L p .379 .519 .872 r
F P
0 g
s
.41941 .48618 m .40666 .48661 L .40938 .48986 L p .379 .519 .872 r
F P
0 g
s
.29409 .39538 m .31271 .40495 L .31263 .39993 L p .41 .572 .903 r
F P
0 g
s
.31263 .39993 m .29392 .38974 L .29409 .39538 L p .41 .572 .903 r
F P
0 g
s
.44098 .50649 m .4388 .51707 L .44239 .51962 L p .383 .518 .869 r
F P
0 g
s
.4388 .51707 m .44098 .50649 L .43859 .50471 L p .382 .517 .869 r
F P
0 g
s
.40666 .48661 m .41941 .48618 L .41769 .48399 L p .379 .52 .872 r
F P
0 g
s
.41769 .48399 m .40409 .48336 L .40666 .48661 L p .379 .52 .872 r
F P
0 g
s
.25662 .37121 m .27525 .38016 L .27567 .3741 L p .436 .601 .915 r
F P
0 g
s
.27567 .3741 m .257 .36454 L .25662 .37121 L p .436 .601 .915 r
F P
0 g
s
.37498 .45792 m .39233 .46454 L .39106 .46162 L p .378 .527 .879 r
F P
0 g
s
.39106 .46162 m .37327 .45411 L .37498 .45792 L p .378 .527 .879 r
F P
0 g
s
.44339 .50818 m .44239 .51962 L .44599 .52203 L p .384 .518 .869 r
F P
0 g
s
.44239 .51962 m .44339 .50818 L .44098 .50649 L p .383 .518 .869 r
F P
0 g
s
.74091 .69957 m .72401 .69098 L .71379 .69754 L p .516 .675 .936 r
F P
0 g
s
.69756 .68855 m .71379 .69754 L .72401 .69098 L p .515 .675 .936 r
F P
0 g
s
.46717 .53297 m .47427 .54883 L .4787 .55035 L p .402 .528 .87 r
F P
0 g
s
.47427 .54883 m .46717 .53297 L .46376 .5316 L p .4 .526 .869 r
F P
0 g
s
.40409 .48336 m .41769 .48399 L .41608 .48181 L p .379 .52 .873 r
F P
0 g
s
.41608 .48181 m .40168 .48012 L .40409 .48336 L p .379 .52 .873 r
F P
0 g
s
.35236 .4379 m .37069 .44683 L .36984 .44338 L p .382 .536 .885 r
F P
0 g
s
.36984 .44338 m .35126 .43369 L .35236 .4379 L p .382 .536 .885 r
F P
0 g
s
.55774 .6176 m .54396 .60225 L .53785 .60288 L p .458 .571 .88 r
F P
0 g
s
.52487 .58686 m .53785 .60288 L .54396 .60225 L p .444 .56 .878 r
F P
0 g
s
.53785 .60288 m .52487 .58686 L .51936 .58687 L p .445 .558 .876 r
F P
0 g
s
.48717 .55257 m .4974 .56917 L .50242 .56996 L p .417 .538 .872 r
F P
0 g
s
.4974 .56917 m .48717 .55257 L .483 .5516 L p .416 .536 .871 r
F P
0 g
s
.44581 .50978 m .44599 .52203 L .4496 .52429 L p .386 .519 .869 r
F P
0 g
s
.44599 .52203 m .44581 .50978 L .44339 .50818 L p .384 .518 .869 r
F P
0 g
s
.57889 .6307 m .56434 .61623 L .55774 .6176 L p .469 .584 .887 r
F P
0 g
s
.54396 .60225 m .55774 .6176 L .56434 .61623 L p .456 .573 .883 r
F P
0 g
s
.64019 .66297 m .62433 .65126 L .61632 .65479 L p .497 .626 .908 r
F P
0 g
s
.60114 .64196 m .61632 .65479 L .62433 .65126 L p .486 .613 .903 r
F P
0 g
s
.08873 .301 m .1074 .30767 L .10766 .30263 L p .285 0 0 r
F P
0 g
s
.10766 .30263 m .08774 .30819 L .08873 .301 L p .285 0 0 r
F P
0 g
s
.68123 .67913 m .66481 .66915 L .65596 .67402 L p .509 .653 .924 r
F P
0 g
s
.64019 .66297 m .65596 .67402 L .66481 .66915 L p .5 .641 .918 r
F P
0 g
s
.40168 .48012 m .41608 .48181 L .41458 .47964 L p .379 .521 .874 r
F P
0 g
s
.41458 .47964 m .39943 .47691 L .40168 .48012 L p .379 .521 .874 r
F P
0 g
s
.1074 .30767 m .12613 .31359 L .12688 .30471 L p .357 .768 .981 r
F P
0 g
s
.12688 .30471 m .10766 .30263 L .1074 .30767 L p .357 .768 .981 r
F P
0 g
s
.50724 .57039 m .51936 .58687 L .52487 .58686 L p .431 .549 .875 r
F P
0 g
s
.51936 .58687 m .50724 .57039 L .50242 .56996 L p .431 .547 .873 r
F P
0 g
s
.44823 .51128 m .4496 .52429 L .45319 .52638 L p .387 .52 .869 r
F P
0 g
s
.4496 .52429 m .44823 .51128 L .44581 .50978 L p .386 .519 .869 r
F P
0 g
s
.12613 .31359 m .14487 .3195 L .14582 .3098 L p .486 .722 .975 r
F P
0 g
s
.14582 .3098 m .12688 .30471 L .12613 .31359 L p .486 .722 .975 r
F P
0 g
s
.14487 .3195 m .1636 .32572 L .16465 .31622 L p .502 .689 .951 r
F P
0 g
s
.16465 .31622 m .14582 .3098 L .14487 .3195 L p .502 .689 .951 r
F P
0 g
s
.37327 .45411 m .39106 .46162 L .39 .45879 L p .379 .528 .88 r
F P
0 g
s
.39 .45879 m .37184 .45041 L .37327 .45411 L p .379 .528 .88 r
F P
0 g
s
.60114 .64196 m .58587 .6285 L .57889 .6307 L p .479 .599 .894 r
F P
0 g
s
.56434 .61623 m .57889 .6307 L .58587 .6285 L p .466 .586 .89 r
F P
0 g
s
.27525 .38016 m .29392 .38974 L .29436 .3843 L p .426 .588 .909 r
F P
0 g
s
.29436 .3843 m .27567 .3741 L .27525 .38016 L p .426 .588 .909 r
F P
0 g
s
.1636 .32572 m .1823 .33238 L .18341 .3234 L p .498 .671 .941 r
F P
0 g
s
.18341 .3234 m .16465 .31622 L .1636 .32572 L p .498 .671 .941 r
F P
0 g
s
.4705 .53413 m .4787 .55035 L .483 .5516 L p .403 .53 .87 r
F P
0 g
s
.4787 .55035 m .4705 .53413 L .46717 .53297 L p .402 .528 .87 r
F P
0 g
s
.33188 .41966 m .35053 .42964 L .35018 .42577 L p .392 .548 .891 r
F P
0 g
s
.35018 .42577 m .33141 .41509 L .33188 .41966 L p .392 .548 .891 r
F P
0 g
s
.39943 .47691 m .41458 .47964 L .4132 .4775 L p .379 .522 .874 r
F P
0 g
s
.4132 .4775 m .39737 .47374 L .39943 .47691 L p .379 .522 .874 r
F P
0 g
s
.31271 .40495 m .33141 .41509 L .33139 .41073 L p .402 .56 .897 r
F P
0 g
s
.33139 .41073 m .31263 .39993 L .31271 .40495 L p .402 .56 .897 r
F P
0 g
s
.45064 .51267 m .45319 .52638 L .45676 .5283 L p .389 .521 .87 r
F P
0 g
s
.45319 .52638 m .45064 .51267 L .44823 .51128 L p .387 .52 .869 r
F P
0 g
s
.1823 .33238 m .20099 .33956 L .20214 .33118 L p .489 .657 .935 r
F P
0 g
s
.20214 .33118 m .18341 .3234 L .1823 .33238 L p .489 .657 .935 r
F P
0 g
s
.72401 .69098 m .70705 .68239 L .69756 .68855 L p .515 .675 .936 r
F P
0 g
s
.68123 .67913 m .69756 .68855 L .70705 .68239 L p .51 .666 .933 r
F P
0 g
s
.20099 .33956 m .21967 .34729 L .22083 .33954 L p .478 .644 .93 r
F P
0 g
s
.22083 .33954 m .20214 .33118 L .20099 .33956 L p .478 .644 .93 r
F P
0 g
s
.39737 .47374 m .4132 .4775 L .41195 .47539 L p .379 .523 .875 r
F P
0 g
s
.41195 .47539 m .39549 .47061 L .39737 .47374 L p .379 .523 .875 r
F P
0 g
s
.49119 .55326 m .50242 .56996 L .50724 .57039 L p .418 .54 .873 r
F P
0 g
s
.50242 .56996 m .49119 .55326 L .48717 .55257 L p .417 .538 .872 r
F P
0 g
s
.35126 .43369 m .36984 .44338 L .36929 .44008 L p .385 .538 .885 r
F P
0 g
s
.36929 .44008 m .35053 .42964 L .35126 .43369 L p .385 .538 .885 r
F P
0 g
s
.45303 .51395 m .45676 .5283 L .46028 .53005 L p .39 .522 .87 r
F P
0 g
s
.45676 .5283 m .45303 .51395 L .45064 .51267 L p .389 .521 .87 r
F P
0 g
s
.37184 .45041 m .39 .45879 L .38916 .45606 L p .381 .529 .88 r
F P
0 g
s
.38916 .45606 m .37069 .44683 L .37184 .45041 L p .381 .529 .88 r
F P
0 g
s
.21967 .34729 m .23833 .35561 L .23949 .34849 L p .467 .63 .924 r
F P
0 g
s
.23949 .34849 m .22083 .33954 L .21967 .34729 L p .467 .63 .924 r
F P
0 g
s
.62433 .65126 m .60838 .63888 L .60114 .64196 L p .486 .613 .903 r
F P
0 g
s
.58587 .6285 m .60114 .64196 L .60838 .63888 L p .474 .6 .898 r
F P
0 g
s
.47373 .5351 m .483 .5516 L .48717 .55257 L p .405 .531 .871 r
F P
0 g
s
.483 .5516 m .47373 .5351 L .4705 .53413 L p .403 .53 .87 r
F P
0 g
s
.75783 .70922 m .77498 .72273 L .78506 .69708 L p .664 .602 .776 r
F P
0 g
s
.29392 .38974 m .31263 .39993 L .31308 .39513 L p .416 .574 .902 r
F P
0 g
s
.31308 .39513 m .29436 .3843 L .29392 .38974 L p .416 .574 .902 r
F P
0 g
s
.66481 .66915 m .6483 .65855 L .64019 .66297 L p .5 .641 .918 r
F P
0 g
s
.62433 .65126 m .64019 .66297 L .6483 .65855 L p .491 .628 .912 r
F P
0 g
s
.39549 .47061 m .41195 .47539 L .41084 .47331 L p .38 .523 .875 r
F P
0 g
s
.41084 .47331 m .39381 .46754 L .39549 .47061 L p .38 .523 .875 r
F P
0 g
s
.56434 .61623 m .54972 .6012 L .54396 .60225 L p .456 .573 .883 r
F P
0 g
s
.5301 .58645 m .54396 .60225 L .54972 .6012 L p .442 .562 .88 r
F P
0 g
s
.54396 .60225 m .5301 .58645 L .52487 .58686 L p .444 .56 .878 r
F P
0 g
s
.45539 .51511 m .46028 .53005 L .46376 .5316 L p .392 .523 .87 r
F P
0 g
s
.46028 .53005 m .45539 .51511 L .45303 .51395 L p .39 .522 .87 r
F P
0 g
s
.51182 .57048 m .52487 .58686 L .5301 .58645 L p .43 .551 .876 r
F P
0 g
s
.52487 .58686 m .51182 .57048 L .50724 .57039 L p .431 .549 .875 r
F P
0 g
s
.78506 .69708 m .76807 .69554 L .75783 .70922 L p .664 .602 .776 r
F P
0 g
s
.74091 .69957 m .75783 .70922 L .76807 .69554 L p .613 .657 .87 r
F P
0 g
s
.23833 .35561 m .257 .36454 L .25814 .35806 L p .455 .617 .919 r
F P
0 g
s
.25814 .35806 m .23949 .34849 L .23833 .35561 L p .455 .617 .919 r
F P
0 g
s
.58587 .6285 m .57052 .61441 L .56434 .61623 L p .466 .586 .89 r
F P
0 g
s
.54972 .6012 m .56434 .61623 L .57052 .61441 L p .453 .574 .886 r
F P
0 g
s
.39381 .46754 m .41084 .47331 L .40986 .47128 L p .38 .524 .876 r
F P
0 g
s
.40986 .47128 m .39233 .46454 L .39381 .46754 L p .38 .524 .876 r
F P
0 g
s
.33141 .41509 m .35018 .42577 L .3502 .42209 L p .396 .55 .89 r
F P
0 g
s
.3502 .42209 m .33139 .41073 L .33141 .41509 L p .396 .55 .89 r
F P
0 g
s
.45772 .51616 m .46376 .5316 L .46717 .53297 L p .393 .524 .87 r
F P
0 g
s
.46376 .5316 m .45772 .51616 L .45539 .51511 L p .392 .523 .87 r
F P
0 g
s
.49503 .55368 m .50724 .57039 L .51182 .57048 L p .418 .541 .874 r
F P
0 g
s
.50724 .57039 m .49503 .55368 L .49119 .55326 L p .418 .54 .873 r
F P
0 g
s
.37069 .44683 m .38916 .45606 L .38854 .45343 L p .382 .531 .88 r
F P
0 g
s
.38854 .45343 m .36984 .44338 L .37069 .44683 L p .382 .531 .88 r
F P
0 g
s
.70705 .68239 m .69002 .67341 L .68123 .67913 L p .51 .666 .933 r
F P
0 g
s
.66481 .66915 m .68123 .67913 L .69002 .67341 L p .502 .655 .927 r
F P
0 g
s
.47686 .53586 m .48717 .55257 L .49119 .55326 L p .406 .532 .872 r
F P
0 g
s
.48717 .55257 m .47686 .53586 L .47373 .5351 L p .405 .531 .871 r
F P
0 g
s
.257 .36454 m .27567 .3741 L .27678 .36825 L p .444 .603 .913 r
F P
0 g
s
.27678 .36825 m .25814 .35806 L .257 .36454 L p .444 .603 .913 r
F P
0 g
s
.35053 .42964 m .36929 .44008 L .36904 .43694 L p .389 .539 .885 r
F P
0 g
s
.36904 .43694 m .35018 .42577 L .35053 .42964 L p .389 .539 .885 r
F P
0 g
s
.31263 .39993 m .33139 .41073 L .33182 .40657 L p .408 .562 .896 r
F P
0 g
s
.33182 .40657 m .31308 .39513 L .31263 .39993 L p .408 .562 .896 r
F P
0 g
s
.39233 .46454 m .40986 .47128 L .40902 .4693 L p .381 .525 .876 r
F P
0 g
s
.40902 .4693 m .39106 .46162 L .39233 .46454 L p .381 .525 .876 r
F P
0 g
s
.76807 .69554 m .75075 .69032 L .74091 .69957 L p .613 .657 .87 r
F P
0 g
s
.72401 .69098 m .74091 .69957 L .75075 .69032 L p .558 .678 .919 r
F P
0 g
s
.60838 .63888 m .59235 .62585 L .58587 .6285 L p .474 .6 .898 r
F P
0 g
s
.57052 .61441 m .58587 .6285 L .59235 .62585 L p .462 .588 .893 r
F P
0 g
s
.6483 .65855 m .63171 .6473 L .62433 .65126 L p .491 .628 .912 r
F P
0 g
s
.60838 .63888 m .62433 .65126 L .63171 .6473 L p .48 .615 .907 r
F P
0 g
s
.46 .51707 m .46717 .53297 L .4705 .53413 L p .394 .525 .871 r
F P
0 g
s
.46717 .53297 m .46 .51707 L .45772 .51616 L p .393 .524 .87 r
F P
0 g
s
.27567 .3741 m .29436 .3843 L .29541 .37909 L p .433 .589 .907 r
F P
0 g
s
.29541 .37909 m .27678 .36825 L .27567 .3741 L p .433 .589 .907 r
F P
0 g
s
.43737 .49102 m .42941 .4969 L .43163 .49894 L p .383 .519 .87 r
F P
0 g
s
.42941 .4969 m .43737 .49102 L .43628 .48997 L p .383 .52 .871 r
F P
0 g
s
.43628 .48997 m .42725 .49481 L .42941 .4969 L p .383 .52 .871 r
F P
0 g
s
.43849 .49204 m .43163 .49894 L .43391 .50093 L p .383 .519 .87 r
F P
0 g
s
.43163 .49894 m .43849 .49204 L .43737 .49102 L p .383 .519 .87 r
F P
0 g
s
.54972 .6012 m .53501 .58566 L .5301 .58645 L p .442 .562 .88 r
F P
0 g
s
.51616 .57024 m .5301 .58645 L .53501 .58566 L p .429 .552 .878 r
F P
0 g
s
.5301 .58645 m .51616 .57024 L .51182 .57048 L p .43 .551 .876 r
F P
0 g
s
.42725 .49481 m .43628 .48997 L .43523 .48891 L p .383 .52 .871 r
F P
0 g
s
.43523 .48891 m .42516 .49269 L .42725 .49481 L p .383 .52 .871 r
F P
0 g
s
.36984 .44338 m .38854 .45343 L .38815 .45092 L p .384 .531 .88 r
F P
0 g
s
.38815 .45092 m .36929 .44008 L .36984 .44338 L p .384 .531 .88 r
F P
0 g
s
.43963 .49304 m .43391 .50093 L .43623 .50286 L p .383 .519 .87 r
F P
0 g
s
.43391 .50093 m .43963 .49304 L .43849 .49204 L p .383 .519 .87 r
F P
0 g
s
.47987 .53641 m .49119 .55326 L .49503 .55368 L p .407 .534 .872 r
F P
0 g
s
.49119 .55326 m .47987 .53641 L .47686 .53586 L p .406 .532 .872 r
F P
0 g
s
.42516 .49269 m .43523 .48891 L .43422 .48782 L p .383 .52 .871 r
F P
0 g
s
.43422 .48782 m .42316 .49054 L .42516 .49269 L p .383 .52 .871 r
F P
0 g
s
.4408 .494 m .43623 .50286 L .43859 .50471 L p .383 .519 .87 r
F P
0 g
s
.43623 .50286 m .4408 .494 L .43963 .49304 L p .383 .519 .87 r
F P
0 g
s
.39106 .46162 m .40902 .4693 L .40832 .46739 L p .381 .525 .876 r
F P
0 g
s
.40832 .46739 m .39 .45879 L .39106 .46162 L p .381 .525 .876 r
F P
0 g
s
.42316 .49054 m .43422 .48782 L .43325 .48673 L p .383 .52 .871 r
F P
0 g
s
.43325 .48673 m .42124 .48836 L .42316 .49054 L p .383 .52 .871 r
F P
0 g
s
.57052 .61441 m .55509 .59973 L .54972 .6012 L p .453 .574 .886 r
F P
0 g
s
.53501 .58566 m .54972 .6012 L .55509 .59973 L p .44 .563 .883 r
F P
0 g
s
.46222 .51786 m .4705 .53413 L .47373 .5351 L p .395 .526 .871 r
F P
0 g
s
.4705 .53413 m .46222 .51786 L .46 .51707 L p .394 .525 .871 r
F P
0 g
s
.44199 .49493 m .43859 .50471 L .44098 .50649 L p .384 .52 .87 r
F P
0 g
s
.43859 .50471 m .44199 .49493 L .4408 .494 L p .383 .519 .87 r
F P
0 g
s
.69002 .67341 m .6729 .66388 L .66481 .66915 L p .502 .655 .927 r
F P
0 g
s
.6483 .65855 m .66481 .66915 L .6729 .66388 L p .494 .642 .922 r
F P
0 g
s
.4987 .55381 m .51182 .57048 L .51616 .57024 L p .418 .542 .875 r
F P
0 g
s
.51182 .57048 m .4987 .55381 L .49503 .55368 L p .418 .541 .874 r
F P
0 g
s
.42124 .48836 m .43325 .48673 L .43234 .48563 L p .383 .521 .872 r
F P
0 g
s
.43234 .48563 m .41941 .48618 L .42124 .48836 L p .383 .521 .872 r
F P
0 g
s
.4432 .49582 m .44098 .50649 L .44339 .50818 L p .384 .52 .87 r
F P
0 g
s
.44098 .50649 m .4432 .49582 L .44199 .49493 L p .384 .52 .87 r
F P
0 g
s
.35018 .42577 m .36904 .43694 L .36909 .43395 L p .392 .541 .885 r
F P
0 g
s
.36909 .43395 m .3502 .42209 L .35018 .42577 L p .392 .541 .885 r
F P
0 g
s
.41941 .48618 m .43234 .48563 L .43147 .48453 L p .383 .521 .872 r
F P
0 g
s
.43147 .48453 m .41769 .48399 L .41941 .48618 L p .383 .521 .872 r
F P
0 g
s
.29436 .3843 m .31308 .39513 L .31406 .39056 L p .423 .576 .901 r
F P
0 g
s
.31406 .39056 m .29541 .37909 L .29436 .3843 L p .423 .576 .901 r
F P
0 g
s
.44441 .49666 m .44339 .50818 L .44581 .50978 L p .385 .52 .87 r
F P
0 g
s
.44339 .50818 m .44441 .49666 L .4432 .49582 L p .384 .52 .87 r
F P
0 g
s
.33139 .41073 m .3502 .42209 L .35061 .4186 L p .401 .551 .89 r
F P
0 g
s
.35061 .4186 m .33182 .40657 L .33139 .41073 L p .401 .551 .89 r
F P
0 g
s
.75075 .69032 m .73325 .68347 L .72401 .69098 L p .558 .678 .919 r
F P
0 g
s
.70705 .68239 m .72401 .69098 L .73325 .68347 L p .525 .677 .934 r
F P
0 g
s
.41769 .48399 m .43147 .48453 L .43066 .48343 L p .383 .521 .872 r
F P
0 g
s
.43066 .48343 m .41608 .48181 L .41769 .48399 L p .383 .521 .872 r
F P
0 g
s
.44562 .49746 m .44581 .50978 L .44823 .51128 L p .385 .521 .87 r
F P
0 g
s
.44581 .50978 m .44562 .49746 L .44441 .49666 L p .385 .52 .87 r
F P
0 g
s
.39 .45879 m .40832 .46739 L .40777 .46554 L p .382 .526 .876 r
F P
0 g
s
.40777 .46554 m .38916 .45606 L .39 .45879 L p .382 .526 .876 r
F P
0 g
s
.63171 .6473 m .61504 .63538 L .60838 .63888 L p .48 .615 .907 r
F P
0 g
s
.59235 .62585 m .60838 .63888 L .61504 .63538 L p .469 .602 .901 r
F P
0 g
s
.59235 .62585 m .57624 .61217 L .57052 .61441 L p .462 .588 .893 r
F P
0 g
s
.55509 .59973 m .57052 .61441 L .57624 .61217 L p .45 .576 .889 r
F P
0 g
s
.46438 .51851 m .47373 .5351 L .47686 .53586 L p .396 .527 .871 r
F P
0 g
s
.47373 .5351 m .46438 .51851 L .46222 .51786 L p .395 .526 .871 r
F P
0 g
s
.76807 .69554 m .78506 .69708 L .79379 .66937 L p .772 .714 .798 r
F P
0 g
s
.41608 .48181 m .43066 .48343 L .42991 .48234 L p .383 .522 .872 r
F P
0 g
s
.42991 .48234 m .41458 .47964 L .41608 .48181 L p .383 .522 .872 r
F P
0 g
s
.44684 .49821 m .44823 .51128 L .45064 .51267 L p .386 .521 .871 r
F P
0 g
s
.44823 .51128 m .44684 .49821 L .44562 .49746 L p .385 .521 .87 r
F P
0 g
s
.48275 .53675 m .49503 .55368 L .4987 .55381 L p .407 .534 .873 r
F P
0 g
s
.49503 .55368 m .48275 .53675 L .47987 .53641 L p .407 .534 .872 r
F P
0 g
s
.36929 .44008 m .38815 .45092 L .38798 .44853 L p .386 .532 .88 r
F P
0 g
s
.38798 .44853 m .36904 .43694 L .36929 .44008 L p .386 .532 .88 r
F P
0 g
s
.41458 .47964 m .42991 .48234 L .42922 .48125 L p .383 .522 .873 r
F P
0 g
s
.42922 .48125 m .4132 .4775 L .41458 .47964 L p .383 .522 .873 r
F P
0 g
s
.44805 .4989 m .45064 .51267 L .45303 .51395 L p .386 .521 .871 r
F P
0 g
s
.45064 .51267 m .44805 .4989 L .44684 .49821 L p .386 .521 .871 r
F P
0 g
s
.31308 .39513 m .33182 .40657 L .33271 .40264 L p .413 .564 .895 r
F P
0 g
s
.33271 .40264 m .31406 .39056 L .31308 .39513 L p .413 .564 .895 r
F P
0 g
s
.6729 .66388 m .6557 .65373 L .6483 .65855 L p .494 .642 .922 r
F P
0 g
s
.63171 .6473 m .6483 .65855 L .6557 .65373 L p .484 .629 .916 r
F P
0 g
s
.38916 .45606 m .40777 .46554 L .40737 .46376 L p .383 .526 .876 r
F P
0 g
s
.40737 .46376 m .38854 .45343 L .38916 .45606 L p .383 .526 .876 r
F P
0 g
s
.18341 .3234 m .20214 .33118 L .20429 .32294 L p .498 .657 .931 r
F P
0 g
s
.20214 .33118 m .22083 .33954 L .22292 .33196 L p .487 .644 .927 r
F P
0 g
s
.22292 .33196 m .20429 .32294 L .20214 .33118 L p .487 .644 .927 r
F P
0 g
s
.16465 .31622 m .18341 .3234 L .18561 .3145 L p .51 .672 .937 r
F P
0 g
s
.20429 .32294 m .18561 .3145 L .18341 .3234 L p .498 .657 .931 r
F P
0 g
s
.4132 .4775 m .42922 .48125 L .4286 .48019 L p .383 .522 .873 r
F P
0 g
s
.4286 .48019 m .41195 .47539 L .4132 .4775 L p .383 .522 .873 r
F P
0 g
s
.46647 .51903 m .47686 .53586 L .47987 .53641 L p .397 .528 .872 r
F P
0 g
s
.47686 .53586 m .46647 .51903 L .46438 .51851 L p .396 .527 .871 r
F P
0 g
s
.55509 .59973 m .5396 .5845 L .53501 .58566 L p .44 .563 .883 r
F P
0 g
s
.52024 .56966 m .53501 .58566 L .5396 .5845 L p .428 .553 .88 r
F P
0 g
s
.53501 .58566 m .52024 .56966 L .51616 .57024 L p .429 .552 .878 r
F P
0 g
s
.50216 .55368 m .51616 .57024 L .52024 .56966 L p .417 .543 .876 r
F P
0 g
s
.51616 .57024 m .50216 .55368 L .4987 .55381 L p .418 .542 .875 r
F P
0 g
s
.22083 .33954 m .23949 .34849 L .2415 .34157 L p .475 .631 .922 r
F P
0 g
s
.2415 .34157 m .22292 .33196 L .22083 .33954 L p .475 .631 .922 r
F P
0 g
s
.44925 .49954 m .45303 .51395 L .45539 .51511 L p .387 .522 .871 r
F P
0 g
s
.45303 .51395 m .44925 .49954 L .44805 .4989 L p .386 .521 .871 r
F P
0 g
s
.14582 .3098 m .16465 .31622 L .16687 .30672 L p .523 .694 .946 r
F P
0 g
s
.18561 .3145 m .16687 .30672 L .16465 .31622 L p .51 .672 .937 r
F P
0 g
s
.23949 .34849 m .25814 .35806 L .26005 .35179 L p .463 .618 .916 r
F P
0 g
s
.26005 .35179 m .2415 .34157 L .23949 .34849 L p .463 .618 .916 r
F P
0 g
s
.73325 .68347 m .71565 .67571 L .70705 .68239 L p .525 .677 .934 r
F P
0 g
s
.69002 .67341 m .70705 .68239 L .71565 .67571 L p .508 .668 .935 r
F P
0 g
s
.3502 .42209 m .36909 .43395 L .36945 .43114 L p .395 .542 .884 r
F P
0 g
s
.36945 .43114 m .35061 .4186 L .3502 .42209 L p .395 .542 .884 r
F P
0 g
s
.12688 .30471 m .14582 .3098 L .14804 .29986 L p .543 .738 .966 r
F P
0 g
s
.16687 .30672 m .14804 .29986 L .14582 .3098 L p .523 .694 .946 r
F P
0 g
s
.41195 .47539 m .4286 .48019 L .42804 .47914 L p .383 .522 .873 r
F P
0 g
s
.42804 .47914 m .41084 .47331 L .41195 .47539 L p .383 .522 .873 r
F P
0 g
s
.61504 .63538 m .59829 .62278 L .59235 .62585 L p .469 .602 .901 r
F P
0 g
s
.57624 .61217 m .59235 .62585 L .59829 .62278 L p .457 .589 .896 r
F P
0 g
s
.45044 .50013 m .45539 .51511 L .45772 .51616 L p .388 .522 .871 r
F P
0 g
s
.45539 .51511 m .45044 .50013 L .44925 .49954 L p .387 .522 .871 r
F P
0 g
s
.25814 .35806 m .27678 .36825 L .27857 .36264 L p .451 .604 .911 r
F P
0 g
s
.27857 .36264 m .26005 .35179 L .25814 .35806 L p .451 .604 .911 r
F P
0 g
s
.57624 .61217 m .56006 .59786 L .55509 .59973 L p .45 .576 .889 r
F P
0 g
s
.5396 .5845 m .55509 .59973 L .56006 .59786 L p .437 .564 .885 r
F P
0 g
s
.48549 .53689 m .4987 .55381 L .50216 .55368 L p .407 .535 .873 r
F P
0 g
s
.4987 .55381 m .48549 .53689 L .48275 .53675 L p .407 .534 .873 r
F P
0 g
s
.36904 .43694 m .38798 .44853 L .38805 .44627 L p .388 .533 .88 r
F P
0 g
s
.38805 .44627 m .36909 .43395 L .36904 .43694 L p .388 .533 .88 r
F P
0 g
s
.38854 .45343 m .40737 .46376 L .40712 .46207 L p .384 .527 .876 r
F P
0 g
s
.40712 .46207 m .38815 .45092 L .38854 .45343 L p .384 .527 .876 r
F P
0 g
s
.33182 .40657 m .35061 .4186 L .3514 .41532 L p .405 .552 .889 r
F P
0 g
s
.3514 .41532 m .33271 .40264 L .33182 .40657 L p .405 .552 .889 r
F P
0 g
s
.41084 .47331 m .42804 .47914 L .42756 .47811 L p .383 .523 .873 r
F P
0 g
s
.42756 .47811 m .40986 .47128 L .41084 .47331 L p .383 .523 .873 r
F P
0 g
s
.46847 .51941 m .47987 .53641 L .48275 .53675 L p .398 .528 .872 r
F P
0 g
s
.47987 .53641 m .46847 .51941 L .46647 .51903 L p .397 .528 .872 r
F P
0 g
s
.10766 .30263 m .12688 .30471 L .12904 .29487 L p .576 .849 .996 r
F P
0 g
s
.14804 .29986 m .12904 .29487 L .12688 .30471 L p .543 .738 .966 r
F P
0 g
s
.45161 .50065 m .45772 .51616 L .46 .51707 L p .388 .523 .871 r
F P
0 g
s
.45772 .51616 m .45161 .50065 L .45044 .50013 L p .388 .522 .871 r
F P
0 g
s
.27678 .36825 m .29541 .37909 L .29708 .37412 L p .44 .59 .905 r
F P
0 g
s
.29708 .37412 m .27857 .36264 L .27678 .36825 L p .44 .59 .905 r
F P
0 g
s
.6557 .65373 m .63843 .64293 L .63171 .6473 L p .484 .629 .916 r
F P
0 g
s
.61504 .63538 m .63171 .6473 L .63843 .64293 L p .474 .616 .911 r
F P
0 g
s
.40986 .47128 m .42756 .47811 L .42714 .47711 L p .383 .523 .873 r
F P
0 g
s
.42714 .47711 m .40902 .4693 L .40986 .47128 L p .383 .523 .873 r
F P
0 g
s
.79379 .66937 m .77716 .68086 L .76807 .69554 L p .772 .714 .798 r
F P
0 g
s
.75075 .69032 m .76807 .69554 L .77716 .68086 L p .663 .722 .893 r
F P
0 g
s
.45275 .50111 m .46 .51707 L .46222 .51786 L p .389 .523 .871 r
F P
0 g
s
.46 .51707 m .45275 .50111 L .45161 .50065 L p .388 .523 .871 r
F P
0 g
s
.29541 .37909 m .31406 .39056 L .31557 .38623 L p .429 .577 .899 r
F P
0 g
s
.31557 .38623 m .29708 .37412 L .29541 .37909 L p .429 .577 .899 r
F P
0 g
s
.71565 .67571 m .69795 .66728 L .69002 .67341 L p .508 .668 .935 r
F P
0 g
s
.6729 .66388 m .69002 .67341 L .69795 .66728 L p .496 .656 .931 r
F P
0 g
s
.5396 .5845 m .52404 .56877 L .52024 .56966 L p .428 .553 .88 r
F P
0 g
s
.5054 .55327 m .52024 .56966 L .52404 .56877 L p .416 .544 .877 r
F P
0 g
s
.52024 .56966 m .5054 .55327 L .50216 .55368 L p .417 .543 .876 r
F P
0 g
s
.59829 .62278 m .58148 .60952 L .57624 .61217 L p .457 .589 .896 r
F P
0 g
s
.56006 .59786 m .57624 .61217 L .58148 .60952 L p .446 .577 .891 r
F P
0 g
s
.38815 .45092 m .40712 .46207 L .40703 .46046 L p .385 .527 .876 r
F P
0 g
s
.40703 .46046 m .38798 .44853 L .38815 .45092 L p .385 .527 .876 r
F P
0 g
s
.47039 .51965 m .48275 .53675 L .48549 .53689 L p .398 .529 .872 r
F P
0 g
s
.48275 .53675 m .47039 .51965 L .46847 .51941 L p .398 .528 .872 r
F P
0 g
s
.40902 .4693 m .42714 .47711 L .4268 .47614 L p .383 .523 .873 r
F P
0 g
s
.4268 .47614 m .40832 .46739 L .40902 .4693 L p .383 .523 .873 r
F P
0 g
s
.48808 .53682 m .50216 .55368 L .5054 .55327 L p .406 .536 .874 r
F P
0 g
s
.50216 .55368 m .48808 .53682 L .48549 .53689 L p .407 .535 .873 r
F P
0 g
s
.45387 .5015 m .46222 .51786 L .46438 .51851 L p .39 .524 .871 r
F P
0 g
s
.46222 .51786 m .45387 .5015 L .45275 .50111 L p .389 .523 .871 r
F P
0 g
s
.56006 .59786 m .54383 .58298 L .5396 .5845 L p .437 .564 .885 r
F P
0 g
s
.52404 .56877 m .5396 .5845 L .54383 .58298 L p .425 .554 .881 r
F P
0 g
s
.36909 .43395 m .38805 .44627 L .38834 .44415 L p .391 .534 .88 r
F P
0 g
s
.38834 .44415 m .36945 .43114 L .36909 .43395 L p .391 .534 .88 r
F P
0 g
s
.08774 .30819 m .10766 .30263 L .1096 .29453 L p .436 .849 .677 r
F P
0 g
s
.12904 .29487 m .1096 .29453 L .10766 .30263 L p .576 .849 .996 r
F P
0 g
s
.35061 .4186 m .36945 .43114 L .37011 .42852 L p .398 .543 .884 r
F P
0 g
s
.37011 .42852 m .3514 .41532 L .35061 .4186 L p .398 .543 .884 r
F P
0 g
s
.31406 .39056 m .33271 .40264 L .33407 .39895 L p .419 .565 .893 r
F P
0 g
s
.33407 .39895 m .31557 .38623 L .31406 .39056 L p .419 .565 .893 r
F P
0 g
s
.63843 .64293 m .62108 .63146 L .61504 .63538 L p .474 .616 .911 r
F P
0 g
s
.59829 .62278 m .61504 .63538 L .62108 .63146 L p .463 .603 .905 r
F P
0 g
s
.40832 .46739 m .4268 .47614 L .42653 .47521 L p .383 .523 .874 r
F P
0 g
s
.42653 .47521 m .40777 .46554 L .40832 .46739 L p .383 .523 .874 r
F P
0 g
s
.77716 .68086 m .79379 .66937 L .80277 .66034 L p .594 .928 .72 r
F P
0 g
s
.45495 .50183 m .46438 .51851 L .46647 .51903 L p .39 .524 .871 r
F P
0 g
s
.46438 .51851 m .45495 .50183 L .45387 .5015 L p .39 .524 .871 r
F P
0 g
s
.69795 .66728 m .68019 .65822 L .6729 .66388 L p .496 .656 .931 r
F P
0 g
s
.6557 .65373 m .6729 .66388 L .68019 .65822 L p .487 .643 .926 r
F P
0 g
s
.38798 .44853 m .40703 .46046 L .40709 .45895 L p .386 .528 .876 r
F P
0 g
s
.40709 .45895 m .38805 .44627 L .38798 .44853 L p .386 .528 .876 r
F P
0 g
s
.47221 .51976 m .48549 .53689 L .48808 .53682 L p .398 .529 .872 r
F P
0 g
s
.48549 .53689 m .47221 .51976 L .47039 .51965 L p .398 .529 .872 r
F P
0 g
s
.77716 .68086 m .75952 .68052 L .75075 .69032 L p .663 .722 .893 r
F P
0 g
s
.73325 .68347 m .75075 .69032 L .75952 .68052 L p .571 .705 .932 r
F P
0 g
s
.33271 .40264 m .3514 .41532 L .35257 .41226 L p .409 .553 .888 r
F P
0 g
s
.35257 .41226 m .33407 .39895 L .33271 .40264 L p .409 .553 .888 r
F P
0 g
s
.58148 .60952 m .56461 .59562 L .56006 .59786 L p .446 .577 .891 r
F P
0 g
s
.54383 .58298 m .56006 .59786 L .56461 .59562 L p .434 .565 .887 r
F P
0 g
s
.40777 .46554 m .42653 .47521 L .42634 .47432 L p .384 .523 .874 r
F P
0 g
s
.42634 .47432 m .40737 .46376 L .40777 .46554 L p .384 .523 .874 r
F P
0 g
s
.45599 .50209 m .46647 .51903 L .46847 .51941 L p .39 .524 .872 r
F P
0 g
s
.46647 .51903 m .45599 .50209 L .45495 .50183 L p .39 .524 .871 r
F P
0 g
s
.52404 .56877 m .50842 .5526 L .5054 .55327 L p .416 .544 .877 r
F P
0 g
s
.4905 .53654 m .5054 .55327 L .50842 .5526 L p .406 .536 .875 r
F P
0 g
s
.5054 .55327 m .4905 .53654 L .48808 .53682 L p .406 .536 .874 r
F P
0 g
s
.54383 .58298 m .52753 .56756 L .52404 .56877 L p .425 .554 .881 r
F P
0 g
s
.50842 .5526 m .52404 .56877 L .52753 .56756 L p .414 .544 .878 r
F P
0 g
s
.36945 .43114 m .38834 .44415 L .38887 .44218 L p .393 .535 .879 r
F P
0 g
s
.38887 .44218 m .37011 .42852 L .36945 .43114 L p .393 .535 .879 r
F P
0 g
s
.62108 .63146 m .60367 .61931 L .59829 .62278 L p .463 .603 .905 r
F P
0 g
s
.58148 .60952 m .59829 .62278 L .60367 .61931 L p .452 .59 .899 r
F P
0 g
s
.40737 .46376 m .42634 .47432 L .42622 .47346 L p .384 .523 .873 r
F P
0 g
s
.42622 .47346 m .40712 .46207 L .40737 .46376 L p .384 .523 .873 r
F P
0 g
s
.44544 .48502 m .43737 .49102 L .43849 .49204 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .43628 .48997 L .43737 .49102 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .43849 .49204 L .43963 .49304 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .43523 .48891 L .43628 .48997 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .43963 .49304 L .4408 .494 L closepath p .385 .521 .871 r
F P
0 g
s
.457 .50228 m .46847 .51941 L .47039 .51965 L p .391 .525 .872 r
F P
0 g
s
.46847 .51941 m .457 .50228 L .45599 .50209 L p .39 .524 .872 r
F P
0 g
s
.44544 .48502 m .43422 .48782 L .43523 .48891 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .4408 .494 L .44199 .49493 L closepath p .385 .521 .871 r
F P
0 g
s
.38805 .44627 m .40709 .45895 L .4073 .45753 L p .387 .528 .876 r
F P
0 g
s
.4073 .45753 m .38834 .44415 L .38805 .44627 L p .387 .528 .876 r
F P
0 g
s
.44544 .48502 m .43325 .48673 L .43422 .48782 L closepath p .385 .521 .871 r
F P
0 g
s
.47393 .51972 m .48808 .53682 L .4905 .53654 L p .398 .529 .873 r
F P
0 g
s
.48808 .53682 m .47393 .51972 L .47221 .51976 L p .398 .529 .872 r
F P
0 g
s
.44544 .48502 m .44199 .49493 L .4432 .49582 L closepath p .385 .521 .871 r
F P
0 g
s
.3514 .41532 m .37011 .42852 L .37108 .42609 L p .401 .543 .883 r
F P
0 g
s
.37108 .42609 m .35257 .41226 L .3514 .41532 L p .401 .543 .883 r
F P
0 g
s
.68019 .65822 m .66235 .64853 L .6557 .65373 L p .487 .643 .926 r
F P
0 g
s
.63843 .64293 m .6557 .65373 L .66235 .64853 L p .477 .63 .92 r
F P
0 g
s
.44544 .48502 m .43234 .48563 L .43325 .48673 L closepath p .385 .522 .871 r
F P
0 g
s
.44544 .48502 m .4432 .49582 L .44441 .49666 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .43147 .48453 L .43234 .48563 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .44441 .49666 L .44562 .49746 L closepath p .385 .521 .871 r
F P
0 g
s
.56461 .59562 m .54768 .58111 L .54383 .58298 L p .434 .565 .887 r
F P
0 g
s
.52753 .56756 m .54383 .58298 L .54768 .58111 L p .423 .554 .883 r
F P
0 g
s
.2415 .34157 m .26005 .35179 L .26274 .34577 L p .47 .618 .914 r
F P
0 g
s
.26005 .35179 m .27857 .36264 L .28106 .35728 L p .458 .605 .909 r
F P
0 g
s
.28106 .35728 m .26274 .34577 L .26005 .35179 L p .458 .605 .909 r
F P
0 g
s
.44544 .48502 m .43066 .48343 L .43147 .48453 L closepath p .385 .522 .872 r
F P
0 g
s
.22292 .33196 m .2415 .34157 L .24436 .33487 L p .482 .631 .919 r
F P
0 g
s
.26274 .34577 m .24436 .33487 L .2415 .34157 L p .47 .618 .914 r
F P
0 g
s
.44544 .48502 m .44562 .49746 L .44684 .49821 L closepath p .385 .521 .871 r
F P
0 g
s
.27857 .36264 m .29708 .37412 L .29936 .36941 L p .446 .591 .903 r
F P
0 g
s
.29936 .36941 m .28106 .35728 L .27857 .36264 L p .446 .591 .903 r
F P
0 g
s
.75952 .68052 m .74149 .67556 L .73325 .68347 L p .571 .705 .932 r
F P
0 g
s
.71565 .67571 m .73325 .68347 L .74149 .67556 L p .524 .686 .941 r
F P
0 g
s
.40712 .46207 m .42622 .47346 L .42618 .47266 L p .384 .524 .873 r
F P
0 g
s
.42618 .47266 m .40703 .46046 L .40712 .46207 L p .384 .524 .873 r
F P
0 g
s
.44544 .48502 m .42991 .48234 L .43066 .48343 L closepath p .385 .522 .872 r
F P
0 g
s
.20429 .32294 m .22292 .33196 L .22594 .32458 L p .494 .644 .923 r
F P
0 g
s
.24436 .33487 m .22594 .32458 L .22292 .33196 L p .482 .631 .919 r
F P
0 g
s
.44544 .48502 m .44684 .49821 L .44805 .4989 L closepath p .385 .522 .871 r
F P
0 g
s
.45795 .5024 m .47039 .51965 L .47221 .51976 L p .391 .525 .872 r
F P
0 g
s
.47039 .51965 m .45795 .5024 L .457 .50228 L p .391 .525 .872 r
F P
0 g
s
.29708 .37412 m .31557 .38623 L .31762 .38217 L p .434 .578 .897 r
F P
0 g
s
.31762 .38217 m .29936 .36941 L .29708 .37412 L p .434 .578 .897 r
F P
0 g
s
.44544 .48502 m .42922 .48125 L .42991 .48234 L closepath p .385 .522 .872 r
F P
0 g
s
.60367 .61931 m .58621 .60649 L .58148 .60952 L p .452 .59 .899 r
F P
0 g
s
.56461 .59562 m .58148 .60952 L .58621 .60649 L p .441 .577 .894 r
F P
0 g
s
.44544 .48502 m .44805 .4989 L .44925 .49954 L closepath p .385 .522 .871 r
F P
0 g
s
.18561 .3145 m .20429 .32294 L .20746 .31486 L p .507 .657 .927 r
F P
0 g
s
.22594 .32458 m .20746 .31486 L .20429 .32294 L p .494 .644 .923 r
F P
0 g
s
.1096 .29453 m .08902 .30636 L .08774 .30819 L p .436 .849 .677 r
F P
0 g
s
.52753 .56756 m .51119 .55167 L .50842 .5526 L p .414 .544 .878 r
F P
0 g
s
.49275 .53606 m .50842 .5526 L .51119 .55167 L p .405 .536 .875 r
F P
0 g
s
.50842 .5526 m .49275 .53606 L .4905 .53654 L p .406 .536 .875 r
F P
0 g
s
.44544 .48502 m .4286 .48019 L .42922 .48125 L closepath p .385 .522 .872 r
F P
0 g
s
.31557 .38623 m .33407 .39895 L .33587 .39552 L p .423 .566 .892 r
F P
0 g
s
.33587 .39552 m .31762 .38217 L .31557 .38623 L p .423 .566 .892 r
F P
0 g
s
.44544 .48502 m .44925 .49954 L .45044 .50013 L closepath p .385 .522 .871 r
F P
0 g
s
.37011 .42852 m .38887 .44218 L .38962 .44037 L p .395 .535 .879 r
F P
0 g
s
.38962 .44037 m .37108 .42609 L .37011 .42852 L p .395 .535 .879 r
F P
0 g
s
.38834 .44415 m .4073 .45753 L .40767 .45622 L p .389 .528 .876 r
F P
0 g
s
.40767 .45622 m .38887 .44218 L .38834 .44415 L p .389 .528 .876 r
F P
0 g
s
.47554 .51955 m .4905 .53654 L .49275 .53606 L p .397 .53 .873 r
F P
0 g
s
.4905 .53654 m .47554 .51955 L .47393 .51972 L p .398 .529 .873 r
F P
0 g
s
.44544 .48502 m .42804 .47914 L .4286 .48019 L closepath p .385 .522 .872 r
F P
0 g
s
.66235 .64853 m .64444 .63818 L .63843 .64293 L p .477 .63 .92 r
F P
0 g
s
.62108 .63146 m .63843 .64293 L .64444 .63818 L p .467 .616 .914 r
F P
0 g
s
.44544 .48502 m .45044 .50013 L .45161 .50065 L closepath p .386 .522 .871 r
F P
0 g
s
.40703 .46046 m .42618 .47266 L .42622 .4719 L p .385 .524 .873 r
F P
0 g
s
.42622 .4719 m .40709 .45895 L .40703 .46046 L p .385 .524 .873 r
F P
0 g
s
.16687 .30672 m .18561 .3145 L .18892 .30571 L p .521 .67 .931 r
F P
0 g
s
.20746 .31486 m .18892 .30571 L .18561 .3145 L p .507 .657 .927 r
F P
0 g
s
.45886 .50246 m .47221 .51976 L .47393 .51972 L p .391 .525 .872 r
F P
0 g
s
.47221 .51976 m .45886 .50246 L .45795 .5024 L p .391 .525 .872 r
F P
0 g
s
.33407 .39895 m .35257 .41226 L .35411 .40943 L p .413 .554 .887 r
F P
0 g
s
.35411 .40943 m .33587 .39552 L .33407 .39895 L p .413 .554 .887 r
F P
0 g
s
.54768 .58111 m .53072 .56604 L .52753 .56756 L p .423 .554 .883 r
F P
0 g
s
.51119 .55167 m .52753 .56756 L .53072 .56604 L p .412 .544 .879 r
F P
0 g
s
.44544 .48502 m .42756 .47811 L .42804 .47914 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .45161 .50065 L .45275 .50111 L closepath p .386 .522 .871 r
F P
0 g
s
.74149 .67556 m .72329 .66867 L .71565 .67571 L p .524 .686 .941 r
F P
0 g
s
.69795 .66728 m .71565 .67571 L .72329 .66867 L p .501 .67 .939 r
F P
0 g
s
.44544 .48502 m .42714 .47711 L .42756 .47811 L closepath p .384 .522 .872 r
F P
0 g
s
.58621 .60649 m .5687 .59301 L .56461 .59562 L p .441 .577 .894 r
F P
0 g
s
.54768 .58111 m .56461 .59562 L .5687 .59301 L p .43 .565 .889 r
F P
0 g
s
.44544 .48502 m .45275 .50111 L .45387 .5015 L closepath p .386 .522 .871 r
F P
0 g
s
.14804 .29986 m .16687 .30672 L .1703 .29715 L p .543 .687 .933 r
F P
0 g
s
.18892 .30571 m .1703 .29715 L .16687 .30672 L p .521 .67 .931 r
F P
0 g
s
.40709 .45895 m .42622 .4719 L .42633 .47119 L p .386 .524 .873 r
F P
0 g
s
.42633 .47119 m .4073 .45753 L .40709 .45895 L p .386 .524 .873 r
F P
0 g
s
.44544 .48502 m .4268 .47614 L .42714 .47711 L closepath p .384 .522 .872 r
F P
0 g
s
.35257 .41226 m .37108 .42609 L .37235 .42386 L p .405 .544 .882 r
F P
0 g
s
.37235 .42386 m .35411 .40943 L .35257 .41226 L p .405 .544 .882 r
F P
0 g
s
.44544 .48502 m .45387 .5015 L .45495 .50183 L closepath p .386 .522 .871 r
F P
0 g
s
.45972 .50244 m .47393 .51972 L .47554 .51955 L p .391 .525 .872 r
F P
0 g
s
.47393 .51972 m .45972 .50244 L .45886 .50246 L p .391 .525 .872 r
F P
0 g
s
.64444 .63818 m .62648 .62717 L .62108 .63146 L p .467 .616 .914 r
F P
0 g
s
.60367 .61931 m .62108 .63146 L .62648 .62717 L p .457 .603 .908 r
F P
0 g
s
.51119 .55167 m .49481 .53538 L .49275 .53606 L p .405 .536 .875 r
F P
0 g
s
.47702 .51924 m .49275 .53606 L .49481 .53538 L p .396 .53 .873 r
F P
0 g
s
.49275 .53606 m .47702 .51924 L .47554 .51955 L p .397 .53 .873 r
F P
0 g
s
.38887 .44218 m .40767 .45622 L .40819 .45503 L p .39 .529 .875 r
F P
0 g
s
.40819 .45503 m .38962 .44037 L .38887 .44218 L p .39 .529 .875 r
F P
0 g
s
.44544 .48502 m .42653 .47521 L .4268 .47614 L closepath p .384 .522 .872 r
F P
0 g
s
.44544 .48502 m .45495 .50183 L .45599 .50209 L closepath p .386 .522 .871 r
F P
0 g
s
.53072 .56604 m .51371 .55048 L .51119 .55167 L p .412 .544 .879 r
F P
0 g
s
.49481 .53538 m .51119 .55167 L .51371 .55048 L p .403 .536 .876 r
F P
0 g
s
.5687 .59301 m .55115 .57891 L .54768 .58111 L p .43 .565 .889 r
F P
0 g
s
.53072 .56604 m .54768 .58111 L .55115 .57891 L p .42 .554 .884 r
F P
0 g
s
.12904 .29487 m .14804 .29986 L .15158 .28934 L p .588 .714 .931 r
F P
0 g
s
.1703 .29715 m .15158 .28934 L .14804 .29986 L p .543 .687 .933 r
F P
0 g
s
.44544 .48502 m .42634 .47432 L .42653 .47521 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .45599 .50209 L .457 .50228 L closepath p .386 .522 .872 r
F P
0 g
s
.37108 .42609 m .38962 .44037 L .3906 .43872 L p .397 .536 .878 r
F P
0 g
s
.3906 .43872 m .37235 .42386 L .37108 .42609 L p .397 .536 .878 r
F P
0 g
s
.4073 .45753 m .42633 .47119 L .42653 .47054 L p .386 .524 .873 r
F P
0 g
s
.42653 .47054 m .40767 .45622 L .4073 .45753 L p .386 .524 .873 r
F P
0 g
s
.72329 .66867 m .705 .6608 L .69795 .66728 L p .501 .67 .939 r
F P
0 g
s
.68019 .65822 m .69795 .66728 L .705 .6608 L p .489 .657 .935 r
F P
0 g
s
.46051 .50235 m .47554 .51955 L .47702 .51924 L p .391 .525 .872 r
F P
0 g
s
.47554 .51955 m .46051 .50235 L .45972 .50244 L p .391 .525 .872 r
F P
0 g
s
.44544 .48502 m .42622 .47346 L .42634 .47432 L closepath p .385 .522 .872 r
F P
0 g
s
.80277 .66034 m .78557 .67236 L p .78606 .67373 L .594 .928 .72 r
F P
0 g
s
.78557 .67236 m .80277 .66034 L .81207 .6704 L p .39 0 .15 r
F P
0 g
s
.78557 .67236 m .79328 .67018 L p .78504 .67091 L .196 .719 .861 r
F P
0 g
s
.76734 .67247 m .78557 .67236 L p .78504 .67091 L .196 .719 .861 r
F P
0 g
s
.78557 .67236 m .77716 .68086 L p .78606 .67373 L .594 .928 .72 r
F P
0 g
s
.75952 .68052 m .77716 .68086 L .78557 .67236 L p .593 .852 .993 r
F P
0 g
s
.44544 .48502 m .457 .50228 L .45795 .5024 L closepath p .387 .522 .872 r
F P
0 g
s
.62648 .62717 m .60847 .61547 L .60367 .61931 L p .457 .603 .908 r
F P
0 g
s
.58621 .60649 m .60367 .61931 L .60847 .61547 L p .447 .59 .902 r
F P
0 g
s
.44544 .48502 m .42618 .47266 L .42622 .47346 L closepath p .385 .522 .872 r
F P
0 g
s
.55115 .57891 m .53357 .56423 L .53072 .56604 L p .42 .554 .884 r
F P
0 g
s
.51371 .55048 m .53072 .56604 L .53357 .56423 L p .41 .544 .88 r
F P
0 g
s
.44544 .48502 m .45795 .5024 L .45886 .50246 L closepath p .387 .522 .872 r
F P
0 g
s
.51371 .55048 m .49668 .53451 L .49481 .53538 L p .403 .536 .876 r
F P
0 g
s
.47839 .51879 m .49481 .53538 L .49668 .53451 L p .395 .53 .874 r
F P
0 g
s
.49481 .53538 m .47839 .51879 L .47702 .51924 L p .396 .53 .873 r
F P
0 g
s
.38962 .44037 m .40819 .45503 L .40886 .45394 L p .392 .529 .875 r
F P
0 g
s
.40886 .45394 m .3906 .43872 L .38962 .44037 L p .392 .529 .875 r
F P
0 g
s
.40767 .45622 m .42653 .47054 L .42679 .46995 L p .387 .524 .873 r
F P
0 g
s
.42679 .46995 m .40819 .45503 L .40767 .45622 L p .387 .524 .873 r
F P
0 g
s
.46125 .50219 m .47702 .51924 L .47839 .51879 L p .39 .525 .872 r
F P
0 g
s
.47702 .51924 m .46125 .50219 L .46051 .50235 L p .391 .525 .872 r
F P
0 g
s
.44544 .48502 m .42622 .4719 L .42618 .47266 L closepath p .385 .522 .872 r
F P
0 g
s
.29936 .36941 m .31762 .38217 L .32021 .37839 L p .439 .578 .896 r
F P
0 g
s
.31762 .38217 m .33587 .39552 L .33813 .39235 L p .428 .566 .89 r
F P
0 g
s
.33813 .39235 m .32021 .37839 L .31762 .38217 L p .428 .566 .89 r
F P
0 g
s
.44544 .48502 m .45886 .50246 L .45972 .50244 L closepath p .387 .522 .872 r
F P
0 g
s
.28106 .35728 m .29936 .36941 L .30224 .365 L p .452 .591 .901 r
F P
0 g
s
.32021 .37839 m .30224 .365 L .29936 .36941 L p .439 .578 .896 r
F P
0 g
s
.1096 .29453 m .12904 .29487 L .13272 .28286 L p .679 .758 .911 r
F P
0 g
s
.15158 .28934 m .13272 .28286 L .12904 .29487 L p .588 .714 .931 r
F P
0 g
s
.33587 .39552 m .35411 .40943 L .35604 .40686 L p .417 .555 .886 r
F P
0 g
s
.35604 .40686 m .33813 .39235 L .33587 .39552 L p .417 .555 .886 r
F P
0 g
s
.705 .6608 m .68663 .65221 L .68019 .65822 L p .489 .657 .935 r
F P
0 g
s
.66235 .64853 m .68019 .65822 L .68663 .65221 L p .479 .644 .929 r
F P
0 g
s
.60847 .61547 m .59042 .60309 L .58621 .60649 L p .447 .59 .902 r
F P
0 g
s
.5687 .59301 m .58621 .60649 L .59042 .60309 L p .436 .577 .896 r
F P
0 g
s
.26274 .34577 m .28106 .35728 L .28424 .35221 L p .464 .605 .906 r
F P
0 g
s
.30224 .365 m .28424 .35221 L .28106 .35728 L p .452 .591 .901 r
F P
0 g
s
.35411 .40943 m .37235 .42386 L .37392 .42184 L p .407 .544 .881 r
F P
0 g
s
.37392 .42184 m .35604 .40686 L .35411 .40943 L p .407 .544 .881 r
F P
0 g
s
.53357 .56423 m .51597 .54905 L .51371 .55048 L p .41 .544 .88 r
F P
0 g
s
.49668 .53451 m .51371 .55048 L .51597 .54905 L p .401 .536 .877 r
F P
0 g
s
.44544 .48502 m .42633 .47119 L .42622 .4719 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .45972 .50244 L .46051 .50235 L closepath p .387 .522 .872 r
F P
0 g
s
.24436 .33487 m .26274 .34577 L .26619 .34002 L p .477 .618 .911 r
F P
0 g
s
.28424 .35221 m .26619 .34002 L .26274 .34577 L p .464 .605 .906 r
F P
0 g
s
.37235 .42386 m .3906 .43872 L .3918 .43725 L p .399 .536 .878 r
F P
0 g
s
.3918 .43725 m .37392 .42184 L .37235 .42386 L p .399 .536 .878 r
F P
0 g
s
.40819 .45503 m .42679 .46995 L .42714 .46941 L p .388 .524 .873 r
F P
0 g
s
.42714 .46941 m .40886 .45394 L .40819 .45503 L p .388 .524 .873 r
F P
0 g
s
.49668 .53451 m .47962 .5182 L .47839 .51879 L p .395 .53 .874 r
F P
0 g
s
.46193 .50197 m .47839 .51879 L .47962 .5182 L p .39 .525 .872 r
F P
0 g
s
.47839 .51879 m .46193 .50197 L .46125 .50219 L p .39 .525 .872 r
F P
0 g
s
.44544 .48502 m .42653 .47054 L .42633 .47119 L closepath p .385 .522 .872 r
F P
0 g
s
.59042 .60309 m .57233 .59006 L .5687 .59301 L p .436 .577 .896 r
F P
0 g
s
.55115 .57891 m .5687 .59301 L .57233 .59006 L p .426 .565 .891 r
F P
0 g
s
.44544 .48502 m .46051 .50235 L .46125 .50219 L closepath p .387 .522 .872 r
F P
0 g
s
.51597 .54905 m .49835 .53344 L .49668 .53451 L p .401 .536 .877 r
F P
0 g
s
.47962 .5182 m .49668 .53451 L .49835 .53344 L p .394 .529 .874 r
F P
0 g
s
.3906 .43872 m .40886 .45394 L .40968 .45298 L p .393 .529 .875 r
F P
0 g
s
.40968 .45298 m .3918 .43725 L .3906 .43872 L p .393 .529 .875 r
F P
0 g
s
.22594 .32458 m .24436 .33487 L .24808 .32843 L p .489 .631 .916 r
F P
0 g
s
.26619 .34002 m .24808 .32843 L .24436 .33487 L p .477 .618 .911 r
F P
0 g
s
.68663 .65221 m .6682 .64297 L .66235 .64853 L p .479 .644 .929 r
F P
0 g
s
.64444 .63818 m .66235 .64853 L .6682 .64297 L p .47 .63 .923 r
F P
0 g
s
.44544 .48502 m .42679 .46995 L .42653 .47054 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46125 .50219 L .46193 .50197 L closepath p .386 .522 .872 r
F P
0 g
s
.57233 .59006 m .55422 .57639 L .55115 .57891 L p .426 .565 .891 r
F P
0 g
s
.53357 .56423 m .55115 .57891 L .55422 .57639 L p .416 .554 .886 r
F P
0 g
s
.40886 .45394 m .42714 .46941 L .42756 .46894 L p .388 .525 .873 r
F P
0 g
s
.42756 .46894 m .40968 .45298 L .40886 .45394 L p .388 .525 .873 r
F P
0 g
s
.49835 .53344 m .48072 .51749 L .47962 .5182 L p .394 .529 .874 r
F P
0 g
s
.46254 .50168 m .47962 .5182 L .48072 .51749 L p .389 .525 .872 r
F P
0 g
s
.47962 .5182 m .46254 .50168 L .46193 .50197 L p .39 .525 .872 r
F P
0 g
s
.78557 .67236 m .76734 .67247 L .75952 .68052 L p .593 .852 .993 r
F P
0 g
s
.74149 .67556 m .75952 .68052 L .76734 .67247 L p .53 .74 .971 r
F P
0 g
s
.44544 .48502 m .42714 .46941 L .42679 .46995 L closepath p .386 .522 .872 r
F P
0 g
s
.20746 .31486 m .22594 .32458 L .22991 .31743 L p .501 .644 .92 r
F P
0 g
s
.24808 .32843 m .22991 .31743 L .22594 .32458 L p .489 .631 .916 r
F P
0 g
s
.44544 .48502 m .46193 .50197 L .46254 .50168 L closepath p .386 .522 .872 r
F P
0 g
s
.55422 .57639 m .53609 .56214 L .53357 .56423 L p .416 .554 .886 r
F P
0 g
s
.51597 .54905 m .53357 .56423 L .53609 .56214 L p .407 .544 .881 r
F P
0 g
s
.6682 .64297 m .64973 .63307 L .64444 .63818 L p .47 .63 .923 r
F P
0 g
s
.62648 .62717 m .64444 .63818 L .64973 .63307 L p .46 .617 .917 r
F P
0 g
s
.44544 .48502 m .42756 .46894 L .42714 .46941 L closepath p .386 .522 .872 r
F P
0 g
s
.53609 .56214 m .51795 .54737 L .51597 .54905 L p .407 .544 .881 r
F P
0 g
s
.49835 .53344 m .51597 .54905 L .51795 .54737 L p .4 .536 .877 r
F P
0 g
s
.48072 .51749 m .46308 .50131 L .46254 .50168 L p .389 .525 .872 r
F P
0 g
s
.44544 .48502 m .46254 .50168 L .46308 .50131 L closepath p .386 .522 .872 r
F P
0 g
s
.51795 .54737 m .49981 .53218 L .49835 .53344 L p .4 .536 .877 r
F P
0 g
s
.48072 .51749 m .49835 .53344 L .49981 .53218 L p .393 .529 .875 r
F P
0 g
s
.37392 .42184 m .3918 .43725 L .39323 .43595 L p .401 .536 .877 r
F P
0 g
s
.3918 .43725 m .40968 .45298 L .41064 .45214 L p .394 .529 .874 r
F P
0 g
s
.41064 .45214 m .39323 .43595 L .3918 .43725 L p .394 .529 .874 r
F P
0 g
s
.35604 .40686 m .37392 .42184 L .37579 .42006 L p .41 .545 .88 r
F P
0 g
s
.39323 .43595 m .37579 .42006 L .37392 .42184 L p .401 .536 .877 r
F P
0 g
s
.40968 .45298 m .42756 .46894 L .42805 .46853 L p .389 .525 .872 r
F P
0 g
s
.42805 .46853 m .41064 .45214 L .40968 .45298 L p .389 .525 .872 r
F P
0 g
s
.08902 .30636 m .1096 .29453 L .11355 .2794 L p .818 .805 .84 r
F P
0 g
s
.13272 .28286 m .11355 .2794 L .1096 .29453 L p .679 .758 .911 r
F P
0 g
s
.18892 .30571 m .20746 .31486 L .21166 .30699 L p .513 .656 .924 r
F P
0 g
s
.22991 .31743 m .21166 .30699 L .20746 .31486 L p .501 .644 .92 r
F P
0 g
s
.33813 .39235 m .35604 .40686 L .35833 .40454 L p .42 .555 .884 r
F P
0 g
s
.37579 .42006 m .35833 .40454 L .35604 .40686 L p .41 .545 .88 r
F P
0 g
s
.49981 .53218 m .48167 .51665 L .48072 .51749 L p .393 .529 .875 r
F P
0 g
s
.46308 .50131 m .48072 .51749 L .48167 .51665 L p .389 .525 .873 r
F P
0 g
s
.44544 .48502 m .42805 .46853 L .42756 .46894 L closepath p .386 .522 .872 r
F P
0 g
s
.48167 .51665 m .46355 .50089 L .46308 .50131 L p .389 .525 .873 r
F P
0 g
s
.44544 .48502 m .46308 .50131 L .46355 .50089 L closepath p .386 .522 .872 r
F P
0 g
s
.64973 .63307 m .63121 .6225 L .62648 .62717 L p .46 .617 .917 r
F P
0 g
s
.60847 .61547 m .62648 .62717 L .63121 .6225 L p .45 .603 .911 r
F P
0 g
s
.44544 .48502 m .42861 .46819 L .42805 .46853 L closepath p .386 .522 .872 r
F P
0 g
s
.44544 .48502 m .42924 .46791 L .42861 .46819 L closepath p .386 .522 .872 r
F P
0 g
s
.44544 .48502 m .42993 .46771 L .42924 .46791 L closepath p .386 .522 .872 r
F P
0 g
s
.44544 .48502 m .43069 .46757 L .42993 .46771 L closepath p .387 .522 .872 r
F P
0 g
s
.44544 .48502 m .43151 .4675 L .43069 .46757 L closepath p .387 .522 .872 r
F P
0 g
s
.44544 .48502 m .43238 .4675 L .43151 .4675 L closepath p .387 .522 .872 r
F P
0 g
s
.44544 .48502 m .43331 .46758 L .43238 .4675 L closepath p .387 .522 .872 r
F P
0 g
s
.44544 .48502 m .43429 .46772 L .43331 .46758 L closepath p .387 .522 .872 r
F P
0 g
s
.44544 .48502 m .43531 .46794 L .43429 .46772 L closepath p .386 .522 .872 r
F P
0 g
s
.44544 .48502 m .43638 .46822 L .43531 .46794 L closepath p .386 .522 .871 r
F P
0 g
s
.44544 .48502 m .43748 .46857 L .43638 .46822 L closepath p .386 .522 .871 r
F P
0 g
s
.44544 .48502 m .43862 .469 L .43748 .46857 L closepath p .386 .522 .871 r
F P
0 g
s
.44544 .48502 m .43978 .46948 L .43862 .469 L closepath p .386 .522 .871 r
F P
0 g
s
.44544 .48502 m .44097 .47003 L .43978 .46948 L closepath p .386 .522 .871 r
F P
0 g
s
.44544 .48502 m .44218 .47064 L .44097 .47003 L closepath p .385 .522 .871 r
F P
0 g
s
.44544 .48502 m .4434 .47131 L .44218 .47064 L closepath p .385 .522 .871 r
F P
0 g
s
.44544 .48502 m .44463 .47204 L .4434 .47131 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .44586 .47282 L .44463 .47204 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .4471 .47365 L .44586 .47282 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .44832 .47452 L .4471 .47365 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .44954 .47544 L .44832 .47452 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .45073 .4764 L .44954 .47544 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .45191 .47739 L .45073 .4764 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .45306 .47842 L .45191 .47739 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .45418 .47947 L .45306 .47842 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .45526 .48054 L .45418 .47947 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .45631 .48163 L .45526 .48054 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .45731 .48273 L .45631 .48163 L closepath p .385 .521 .871 r
F P
0 g
s
.44544 .48502 m .45826 .48385 L .45731 .48273 L closepath p .385 .522 .871 r
F P
0 g
s
.44544 .48502 m .45916 .48496 L .45826 .48385 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46 .48608 L .45916 .48496 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46079 .48719 L .46 .48608 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46151 .48829 L .46079 .48719 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46216 .48938 L .46151 .48829 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46275 .49045 L .46216 .48938 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46327 .49149 L .46275 .49045 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46371 .49251 L .46327 .49149 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46408 .4935 L .46371 .49251 L closepath p .384 .522 .872 r
F P
0 g
s
.44544 .48502 m .46438 .49445 L .46408 .4935 L closepath p .384 .522 .872 r
F P
0 g
s
.44544 .48502 m .4646 .49537 L .46438 .49445 L closepath p .384 .522 .872 r
F P
0 g
s
.44544 .48502 m .46474 .49624 L .4646 .49537 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .4648 .49706 L .46474 .49624 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46478 .49784 L .4648 .49706 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46469 .49856 L .46478 .49784 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46452 .49923 L .46469 .49856 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46427 .49985 L .46452 .49923 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46395 .5004 L .46427 .49985 L closepath p .385 .522 .872 r
F P
0 g
s
.44544 .48502 m .46355 .50089 L .46395 .5004 L closepath p .386 .522 .872 r
F P
0 g
s
.32021 .37839 m .33813 .39235 L .34084 .38948 L p .432 .566 .889 r
F P
0 g
s
.35833 .40454 m .34084 .38948 L .33813 .39235 L p .42 .555 .884 r
F P
0 g
s
.41064 .45214 m .42805 .46853 L .42861 .46819 L p .39 .525 .872 r
F P
0 g
s
.30224 .365 m .32021 .37839 L .32331 .37492 L p .444 .578 .893 r
F P
0 g
s
.34084 .38948 m .32331 .37492 L .32021 .37839 L p .432 .566 .889 r
F P
0 g
s
.48249 .51568 m .46395 .5004 L .46355 .50089 L p .388 .524 .873 r
F P
0 g
s
.46355 .50089 m .48167 .51665 L .48249 .51568 L p .388 .524 .873 r
F P
0 g
s
.76734 .67247 m .74873 .66794 L .74149 .67556 L p .53 .74 .971 r
F P
0 g
s
.72329 .66867 m .74149 .67556 L .74873 .66794 L p .503 .695 .955 r
F P
0 g
s
.63121 .6225 m .61265 .61126 L .60847 .61547 L p .45 .603 .911 r
F P
0 g
s
.59042 .60309 m .60847 .61547 L .61265 .61126 L p .441 .59 .904 r
F P
0 g
s
.39323 .43595 m .41064 .45214 L .41175 .45143 L p .395 .53 .874 r
F P
0 g
s
.42861 .46819 m .41175 .45143 L .41064 .45214 L p .39 .525 .872 r
F P
0 g
s
.1703 .29715 m .18892 .30571 L .19333 .29708 L p .528 .667 .926 r
F P
0 g
s
.21166 .30699 m .19333 .29708 L .18892 .30571 L p .513 .656 .924 r
F P
0 g
s
.50105 .53074 m .48249 .51568 L .48167 .51665 L p .392 .529 .875 r
F P
0 g
s
.48167 .51665 m .49981 .53218 L .50105 .53074 L p .392 .529 .875 r
F P
0 g
s
.41175 .45143 m .42861 .46819 L .42924 .46791 L p .39 .525 .872 r
F P
0 g
s
.48315 .51458 m .46427 .49985 L .46395 .5004 L p .387 .524 .873 r
F P
0 g
s
.46395 .5004 m .48249 .51568 L .48315 .51458 L p .387 .524 .873 r
F P
0 g
s
.28424 .35221 m .30224 .365 L .30574 .3609 L p .457 .591 .898 r
F P
0 g
s
.32331 .37492 m .30574 .3609 L .30224 .365 L p .444 .578 .893 r
F P
0 g
s
.61265 .61126 m .59407 .59934 L .59042 .60309 L p .441 .59 .904 r
F P
0 g
s
.57233 .59006 m .59042 .60309 L .59407 .59934 L p .431 .577 .898 r
F P
0 g
s
.51964 .54547 m .50105 .53074 L .49981 .53218 L p .397 .536 .878 r
F P
0 g
s
.49981 .53218 m .51795 .54737 L .51964 .54547 L p .397 .536 .878 r
F P
0 g
s
.37579 .42006 m .39323 .43595 L .39486 .43484 L p .403 .536 .876 r
F P
0 g
s
.41175 .45143 m .39486 .43484 L .39323 .43595 L p .395 .53 .874 r
F P
0 g
s
.59407 .59934 m .57547 .58676 L .57233 .59006 L p .431 .577 .898 r
F P
0 g
s
.55422 .57639 m .57233 .59006 L .57547 .58676 L p .421 .565 .892 r
F P
0 g
s
.42924 .46791 m .41299 .45085 L .41175 .45143 L p .39 .525 .872 r
F P
0 g
s
.41299 .45085 m .42924 .46791 L .42993 .46771 L p .39 .525 .872 r
F P
0 g
s
.53825 .55977 m .51964 .54547 L .51795 .54737 L p .404 .544 .882 r
F P
0 g
s
.51795 .54737 m .53609 .56214 L .53825 .55977 L p .404 .544 .882 r
F P
0 g
s
.48367 .51337 m .46452 .49923 L .46427 .49985 L p .387 .524 .873 r
F P
0 g
s
.46427 .49985 m .48315 .51458 L .48367 .51337 L p .387 .524 .873 r
F P
0 g
s
.57547 .58676 m .55686 .57356 L .55422 .57639 L p .421 .565 .892 r
F P
0 g
s
.53609 .56214 m .55422 .57639 L .55686 .57356 L p .412 .554 .887 r
F P
0 g
s
.55686 .57356 m .53825 .55977 L .53609 .56214 L p .412 .554 .887 r
F P
0 g
s
.35833 .40454 m .37579 .42006 L .37795 .4185 L p .412 .545 .879 r
F P
0 g
s
.39486 .43484 m .37795 .4185 L .37579 .42006 L p .403 .536 .876 r
F P
0 g
s
.26619 .34002 m .28424 .35221 L .28811 .34745 L p .47 .604 .903 r
F P
0 g
s
.30574 .3609 m .28811 .34745 L .28424 .35221 L p .457 .591 .898 r
F P
0 g
s
.74873 .66794 m .72996 .66148 L .72329 .66867 L p .503 .695 .955 r
F P
0 g
s
.705 .6608 m .72329 .66867 L .72996 .66148 L p .489 .673 .946 r
F P
0 g
s
.39486 .43484 m .41175 .45143 L .41299 .45085 L p .396 .53 .874 r
F P
0 g
s
.50208 .52912 m .48315 .51458 L .48249 .51568 L p .391 .529 .875 r
F P
0 g
s
.48249 .51568 m .50105 .53074 L .50208 .52912 L p .391 .529 .875 r
F P
0 g
s
.42993 .46771 m .41437 .45041 L .41299 .45085 L p .39 .525 .872 r
F P
0 g
s
.41437 .45041 m .42993 .46771 L .43069 .46757 L p .391 .525 .872 r
F P
0 g
s
.48403 .51205 m .46469 .49856 L .46452 .49923 L p .386 .524 .873 r
F P
0 g
s
.46452 .49923 m .48367 .51337 L .48403 .51205 L p .386 .524 .873 r
F P
0 g
s
.15158 .28934 m .1703 .29715 L .17492 .28766 L p .549 .677 .923 r
F P
0 g
s
.19333 .29708 m .17492 .28766 L .1703 .29715 L p .528 .667 .926 r
F P
0 g
s
.34084 .38948 m .35833 .40454 L .36099 .4025 L p .423 .555 .883 r
F P
0 g
s
.37795 .4185 m .36099 .4025 L .35833 .40454 L p .412 .545 .879 r
F P
0 g
s
.43069 .46757 m .41588 .4501 L .41437 .45041 L p .391 .525 .872 r
F P
0 g
s
.41588 .4501 m .43069 .46757 L .43151 .4675 L p .391 .525 .872 r
F P
0 g
s
.48423 .51062 m .46478 .49784 L .46469 .49856 L p .385 .524 .873 r
F P
0 g
s
.46469 .49856 m .48403 .51205 L .48423 .51062 L p .385 .524 .873 r
F P
0 g
s
.24808 .32843 m .26619 .34002 L .27041 .33458 L p .483 .617 .908 r
F P
0 g
s
.28811 .34745 m .27041 .33458 L .26619 .34002 L p .47 .604 .903 r
F P
0 g
s
.52104 .54333 m .50208 .52912 L .50105 .53074 L p .395 .535 .879 r
F P
0 g
s
.50105 .53074 m .51964 .54547 L .52104 .54333 L p .395 .535 .879 r
F P
0 g
s
.37795 .4185 m .39486 .43484 L .39671 .43392 L p .404 .536 .876 r
F P
0 g
s
.41299 .45085 m .39671 .43392 L .39486 .43484 L p .396 .53 .874 r
F P
0 g
s
.72996 .66148 m .7111 .65403 L .705 .6608 L p .489 .673 .946 r
F P
0 g
s
.68663 .65221 m .705 .6608 L .7111 .65403 L p .479 .657 .939 r
F P
0 g
s
.39671 .43392 m .41299 .45085 L .41437 .45041 L p .397 .53 .873 r
F P
0 g
s
.50288 .52732 m .48367 .51337 L .48315 .51458 L p .389 .528 .875 r
F P
0 g
s
.48315 .51458 m .50208 .52912 L .50288 .52732 L p .389 .528 .875 r
F P
0 g
s
.43151 .4675 m .41751 .44993 L .41588 .4501 L p .391 .525 .872 r
F P
0 g
s
.41751 .44993 m .43151 .4675 L .43238 .4675 L p .391 .525 .872 r
F P
0 g
s
.48428 .50908 m .4648 .49706 L .46478 .49784 L p .385 .524 .873 r
F P
0 g
s
.46478 .49784 m .48423 .51062 L .48428 .50908 L p .385 .524 .873 r
F P
0 g
s
.32331 .37492 m .34084 .38948 L .34399 .38691 L p .436 .566 .887 r
F P
0 g
s
.36099 .4025 m .34399 .38691 L .34084 .38948 L p .423 .555 .883 r
F P
0 g
s
.43238 .4675 m .41925 .44991 L .41751 .44993 L p .391 .525 .872 r
F P
0 g
s
.41925 .44991 m .43238 .4675 L .43331 .46758 L p .391 .525 .872 r
F P
0 g
s
.48417 .50745 m .46474 .49624 L .4648 .49706 L p .384 .524 .873 r
F P
0 g
s
.4648 .49706 m .48428 .50908 L .48417 .50745 L p .384 .524 .873 r
F P
0 g
s
.54004 .55713 m .52104 .54333 L .51964 .54547 L p .401 .543 .883 r
F P
0 g
s
.51964 .54547 m .53825 .55977 L .54004 .55713 L p .401 .543 .883 r
F P
0 g
s
.13272 .28286 m .15158 .28934 L .15643 .27866 L p .587 .683 .907 r
F P
0 g
s
.17492 .28766 m .15643 .27866 L .15158 .28934 L p .549 .677 .923 r
F P
0 g
s
.7111 .65403 m .69219 .64587 L .68663 .65221 L p .479 .657 .939 r
F P
0 g
s
.6682 .64297 m .68663 .65221 L .69219 .64587 L p .47 .643 .933 r
F P
0 g
s
.22991 .31743 m .24808 .32843 L .25265 .32229 L p .495 .63 .912 r
F P
0 g
s
.27041 .33458 m .25265 .32229 L .24808 .32843 L p .483 .617 .908 r
F P
0 g
s
.36099 .4025 m .37795 .4185 L .38038 .41719 L p .415 .545 .878 r
F P
0 g
s
.39671 .43392 m .38038 .41719 L .37795 .4185 L p .404 .536 .876 r
F P
0 g
s
.41437 .45041 m .39876 .43319 L .39671 .43392 L p .397 .53 .873 r
F P
0 g
s
.39876 .43319 m .41437 .45041 L .41588 .4501 L p .397 .53 .873 r
F P
0 g
s
.43331 .46758 m .4211 .45003 L .41925 .44991 L p .391 .525 .872 r
F P
0 g
s
.4211 .45003 m .43331 .46758 L .43429 .46772 L p .391 .525 .872 r
F P
0 g
s
.50344 .52537 m .48403 .51205 L .48367 .51337 L p .388 .528 .876 r
F P
0 g
s
.48367 .51337 m .50288 .52732 L .50344 .52537 L p .388 .528 .876 r
F P
0 g
s
.4839 .50572 m .4646 .49537 L .46474 .49624 L p .384 .523 .874 r
F P
0 g
s
.46474 .49624 m .48417 .50745 L .4839 .50572 L p .384 .523 .874 r
F P
0 g
s
.30574 .3609 m .32331 .37492 L .32694 .37178 L p .448 .578 .891 r
F P
0 g
s
.34399 .38691 m .32694 .37178 L .32331 .37492 L p .436 .566 .887 r
F P
0 g
s
.55907 .57042 m .54004 .55713 L .53825 .55977 L p .409 .553 .888 r
F P
0 g
s
.53825 .55977 m .55686 .57356 L .55907 .57042 L p .409 .553 .888 r
F P
0 g
s
.69219 .64587 m .67324 .63706 L .6682 .64297 L p .47 .643 .933 r
F P
0 g
s
.64973 .63307 m .6682 .64297 L .67324 .63706 L p .462 .63 .926 r
F P
0 g
s
.52214 .54098 m .50288 .52732 L .50208 .52912 L p .393 .535 .879 r
F P
0 g
s
.50208 .52912 m .52104 .54333 L .52214 .54098 L p .393 .535 .879 r
F P
0 g
s
.38038 .41719 m .39671 .43392 L .39876 .43319 L p .406 .536 .875 r
F P
0 g
s
.43429 .46772 m .42306 .45029 L .4211 .45003 L p .391 .525 .872 r
F P
0 g
s
.42306 .45029 m .43429 .46772 L .43531 .46794 L p .39 .524 .872 r
F P
0 g
s
.48348 .50391 m .46438 .49445 L .4646 .49537 L p .383 .523 .874 r
F P
0 g
s
.4646 .49537 m .4839 .50572 L .48348 .50391 L p .383 .523 .874 r
F P
0 g
s
.57811 .58315 m .55907 .57042 L .55686 .57356 L p .416 .564 .894 r
F P
0 g
s
.55686 .57356 m .57547 .58676 L .57811 .58315 L p .416 .564 .894 r
F P
0 g
s
.67324 .63706 m .65425 .62761 L .64973 .63307 L p .462 .63 .926 r
F P
0 g
s
.63121 .6225 m .64973 .63307 L .65425 .62761 L p .452 .616 .92 r
F P
0 g
s
.43531 .46794 m .42511 .45069 L .42306 .45029 L p .39 .524 .872 r
F P
0 g
s
.42511 .45069 m .43531 .46794 L .43638 .46822 L p .39 .524 .871 r
F P
0 g
s
.4829 .50202 m .46408 .4935 L .46438 .49445 L p .383 .523 .874 r
F P
0 g
s
.46438 .49445 m .48348 .50391 L .4829 .50202 L p .383 .523 .874 r
F P
0 g
s
.41588 .4501 m .401 .43268 L .39876 .43319 L p .397 .53 .873 r
F P
0 g
s
.401 .43268 m .41588 .4501 L .41751 .44993 L p .398 .529 .873 r
F P
0 g
s
.34399 .38691 m .36099 .4025 L .364 .40076 L p .426 .554 .881 r
F P
0 g
s
.38038 .41719 m .364 .40076 L .36099 .4025 L p .415 .545 .878 r
F P
0 g
s
.21166 .30699 m .22991 .31743 L .2348 .31056 L p .507 .643 .916 r
F P
0 g
s
.25265 .32229 m .2348 .31056 L .22991 .31743 L p .495 .63 .912 r
F P
0 g
s
.50378 .52325 m .48423 .51062 L .48403 .51205 L p .386 .528 .876 r
F P
0 g
s
.48403 .51205 m .50344 .52537 L .50378 .52325 L p .386 .528 .876 r
F P
0 g
s
.59715 .59525 m .57811 .58315 L .57547 .58676 L p .425 .576 .9 r
F P
0 g
s
.57547 .58676 m .59407 .59934 L .59715 .59525 L p .425 .576 .9 r
F P
0 g
s
.65425 .62761 m .63523 .61749 L .63121 .6225 L p .452 .616 .92 r
F P
0 g
s
.61265 .61126 m .63121 .6225 L .63523 .61749 L p .443 .603 .913 r
F P
0 g
s
.28811 .34745 m .30574 .3609 L .30982 .35714 L p .462 .591 .896 r
F P
0 g
s
.32694 .37178 m .30982 .35714 L .30574 .3609 L p .448 .578 .891 r
F P
0 g
s
.43638 .46822 m .42724 .45124 L .42511 .45069 L p .39 .524 .871 r
F P
0 g
s
.42724 .45124 m .43638 .46822 L .43748 .46857 L p .389 .524 .871 r
F P
0 g
s
.6162 .60671 m .59715 .59525 L .59407 .59934 L p .434 .589 .907 r
F P
0 g
s
.59407 .59934 m .61265 .61126 L .6162 .60671 L p .434 .589 .907 r
F P
0 g
s
.63523 .61749 m .6162 .60671 L .61265 .61126 L p .443 .603 .913 r
F P
0 g
s
.81207 .6704 m .79328 .67018 L p .78586 .67234 L .39 0 .15 r
F P
0 g
s
.79328 .67018 m .81207 .6704 L .82001 .67892 L p .471 0 0 r
F P
0 g
s
.82001 .67892 m .80096 .66794 L p .79328 .67018 L .471 0 0 r
F P
0 g
s
.80096 .66794 m .79971 .66723 L .79328 .67018 L p .471 0 0 r
F P
0 g
s
.79328 .67018 m .78557 .67236 L p .78586 .67234 L .39 0 .15 r
F P
0 g
s
.48217 .50005 m .46371 .49251 L .46408 .4935 L p .383 .523 .873 r
F P
0 g
s
.46408 .4935 m .4829 .50202 L .48217 .50005 L p .383 .523 .873 r
F P
0 g
s
.11355 .2794 m .13272 .28286 L .13785 .26994 L p .65 .674 .859 r
F P
0 g
s
.15643 .27866 m .13785 .26994 L .13272 .28286 L p .587 .683 .907 r
F P
0 g
s
.54146 .55423 m .52214 .54098 L .52104 .54333 L p .398 .543 .884 r
F P
0 g
s
.52104 .54333 m .54004 .55713 L .54146 .55423 L p .398 .543 .884 r
F P
0 g
s
.43748 .46857 m .42945 .45193 L .42724 .45124 L p .389 .524 .871 r
F P
0 g
s
.42945 .45193 m .43748 .46857 L .43862 .469 L p .389 .523 .871 r
F P
0 g
s
.48129 .49803 m .46327 .49149 L .46371 .49251 L p .383 .523 .873 r
F P
0 g
s
.46371 .49251 m .48217 .50005 L .48129 .49803 L p .383 .523 .873 r
F P
0 g
s
.39876 .43319 m .38309 .41614 L .38038 .41719 L p .406 .536 .875 r
F P
0 g
s
.38309 .41614 m .39876 .43319 L .401 .43268 L p .407 .536 .874 r
F P
0 g
s
.52294 .53841 m .50344 .52537 L .50288 .52732 L p .391 .534 .879 r
F P
0 g
s
.50288 .52732 m .52214 .54098 L .52294 .53841 L p .391 .534 .879 r
F P
0 g
s
.364 .40076 m .38038 .41719 L .38309 .41614 L p .416 .544 .877 r
F P
0 g
s
.41751 .44993 m .40343 .43236 L .401 .43268 L p .398 .529 .873 r
F P
0 g
s
.40343 .43236 m .41751 .44993 L .41925 .44991 L p .398 .529 .872 r
F P
0 g
s
.11355 .2794 m .09363 .28367 L .08902 .30636 L p .818 .805 .84 r
F P
0 g
s
.50387 .52098 m .48428 .50908 L .48423 .51062 L p .385 .527 .876 r
F P
0 g
s
.48423 .51062 m .50378 .52325 L .50387 .52098 L p .385 .527 .876 r
F P
0 g
s
.43862 .469 m .43173 .45275 L .42945 .45193 L p .389 .523 .871 r
F P
0 g
s
.43173 .45275 m .43862 .469 L .43978 .46948 L p .388 .523 .871 r
F P
0 g
s
.48026 .49594 m .46275 .49045 L .46327 .49149 L p .383 .523 .873 r
F P
0 g
s
.46327 .49149 m .48129 .49803 L .48026 .49594 L p .383 .523 .873 r
F P
0 g
s
.32694 .37178 m .34399 .38691 L .34756 .38467 L p .439 .565 .885 r
F P
0 g
s
.364 .40076 m .34756 .38467 L .34399 .38691 L p .426 .554 .881 r
F P
0 g
s
.27041 .33458 m .28811 .34745 L .29265 .34304 L p .475 .603 .9 r
F P
0 g
s
.30982 .35714 m .29265 .34304 L .28811 .34745 L p .462 .591 .896 r
F P
0 g
s
.43978 .46948 m .43407 .45371 L .43173 .45275 L p .388 .523 .871 r
F P
0 g
s
.43407 .45371 m .43978 .46948 L .44097 .47003 L p .387 .522 .871 r
F P
0 g
s
.19333 .29708 m .21166 .30699 L .21688 .29938 L p .519 .655 .92 r
F P
0 g
s
.2348 .31056 m .21688 .29938 L .21166 .30699 L p .507 .643 .916 r
F P
0 g
s
.47909 .49381 m .46216 .48938 L .46275 .49045 L p .383 .522 .873 r
F P
0 g
s
.46275 .49045 m .48026 .49594 L .47909 .49381 L p .383 .522 .873 r
F P
0 g
s
.44097 .47003 m .43646 .45481 L .43407 .45371 L p .387 .522 .871 r
F P
0 g
s
.43646 .45481 m .44097 .47003 L .44218 .47064 L p .387 .522 .871 r
F P
0 g
s
.47777 .49163 m .46151 .48829 L .46216 .48938 L p .383 .522 .873 r
F P
0 g
s
.46216 .48938 m .47909 .49381 L .47777 .49163 L p .383 .522 .873 r
F P
0 g
s
.56082 .567 m .54146 .55423 L .54004 .55713 L p .404 .552 .889 r
F P
0 g
s
.54004 .55713 m .55907 .57042 L .56082 .567 L p .404 .552 .889 r
F P
0 g
s
.41925 .44991 m .40604 .43227 L .40343 .43236 L p .398 .529 .872 r
F P
0 g
s
.40604 .43227 m .41925 .44991 L .4211 .45003 L p .398 .529 .872 r
F P
0 g
s
.50373 .51857 m .48417 .50745 L .48428 .50908 L p .384 .527 .876 r
F P
0 g
s
.48428 .50908 m .50387 .52098 L .50373 .51857 L p .384 .527 .876 r
F P
0 g
s
.44218 .47064 m .43888 .45603 L .43646 .45481 L p .387 .522 .871 r
F P
0 g
s
.43888 .45603 m .44218 .47064 L .4434 .47131 L p .386 .521 .871 r
F P
0 g
s
.47633 .48943 m .46079 .48719 L .46151 .48829 L p .383 .522 .873 r
F P
0 g
s
.46151 .48829 m .47777 .49163 L .47633 .48943 L p .383 .522 .873 r
F P
0 g
s
.4434 .47131 m .44134 .45737 L .43888 .45603 L p .386 .521 .871 r
F P
0 g
s
.44134 .45737 m .4434 .47131 L .44463 .47204 L p .385 .521 .871 r
F P
0 g
s
.47476 .4872 m .46 .48608 L .46079 .48719 L p .383 .521 .872 r
F P
0 g
s
.46079 .48719 m .47633 .48943 L .47476 .4872 L p .383 .521 .872 r
F P
0 g
s
.401 .43268 m .38606 .41536 L .38309 .41614 L p .407 .536 .874 r
F P
0 g
s
.38606 .41536 m .401 .43268 L .40343 .43236 L p .407 .535 .874 r
F P
0 g
s
.52342 .53564 m .50378 .52325 L .50344 .52537 L p .389 .533 .88 r
F P
0 g
s
.50344 .52537 m .52294 .53841 L .52342 .53564 L p .389 .533 .88 r
F P
0 g
s
.44463 .47204 m .44381 .45883 L .44134 .45737 L p .385 .521 .871 r
F P
0 g
s
.44381 .45883 m .44463 .47204 L .44586 .47282 L p .385 .52 .87 r
F P
0 g
s
.34756 .38467 m .364 .40076 L .36736 .39932 L p .428 .554 .88 r
F P
0 g
s
.38309 .41614 m .36736 .39932 L .364 .40076 L p .416 .544 .877 r
F P
0 g
s
.47307 .48496 m .45916 .48496 L .46 .48608 L p .383 .521 .872 r
F P
0 g
s
.46 .48608 m .47476 .4872 L .47307 .48496 L p .383 .521 .872 r
F P
0 g
s
.30982 .35714 m .32694 .37178 L .33107 .36899 L p .452 .577 .889 r
F P
0 g
s
.34756 .38467 m .33107 .36899 L .32694 .37178 L p .439 .565 .885 r
F P
0 g
s
.79328 .67018 m .77416 .66624 L .76734 .67247 L p .196 .719 .861 r
F P
0 g
s
.74873 .66794 m .76734 .67247 L .77416 .66624 L p .444 .736 .989 r
F P
0 g
s
.5425 .55108 m .52294 .53841 L .52214 .54098 L p .395 .542 .884 r
F P
0 g
s
.52214 .54098 m .54146 .55423 L .5425 .55108 L p .395 .542 .884 r
F P
0 g
s
.44586 .47282 m .4463 .46041 L .44381 .45883 L p .385 .52 .87 r
F P
0 g
s
.4463 .46041 m .44586 .47282 L .4471 .47365 L p .384 .52 .87 r
F P
0 g
s
.25265 .32229 m .27041 .33458 L .27539 .32948 L p .488 .616 .904 r
F P
0 g
s
.29265 .34304 m .27539 .32948 L .27041 .33458 L p .475 .603 .9 r
F P
0 g
s
.47126 .48271 m .45826 .48385 L .45916 .48496 L p .383 .521 .872 r
F P
0 g
s
.45916 .48496 m .47307 .48496 L .47126 .48271 L p .383 .521 .872 r
F P
0 g
s
.4211 .45003 m .40881 .43238 L .40604 .43227 L p .398 .529 .872 r
F P
0 g
s
.40881 .43238 m .4211 .45003 L .42306 .45029 L p .397 .528 .872 r
F P
0 g
s
.58022 .57922 m .56082 .567 L .55907 .57042 L p .411 .563 .895 r
F P
0 g
s
.55907 .57042 m .57811 .58315 L .58022 .57922 L p .411 .563 .895 r
F P
0 g
s
.4471 .47365 m .44878 .46208 L .4463 .46041 L p .384 .52 .87 r
F P
0 g
s
.44878 .46208 m .4471 .47365 L .44832 .47452 L p .384 .52 .87 r
F P
0 g
s
.36736 .39932 m .38309 .41614 L .38606 .41536 L p .417 .544 .876 r
F P
0 g
s
.50336 .51601 m .4839 .50572 L .48417 .50745 L p .383 .526 .876 r
F P
0 g
s
.48417 .50745 m .50373 .51857 L .50336 .51601 L p .383 .526 .876 r
F P
0 g
s
.46935 .48047 m .45731 .48273 L .45826 .48385 L p .383 .521 .871 r
F P
0 g
s
.45826 .48385 m .47126 .48271 L .46935 .48047 L p .383 .521 .871 r
F P
0 g
s
.17492 .28766 m .19333 .29708 L .19885 .28871 L p .53 .665 .923 r
F P
0 g
s
.21688 .29938 m .19885 .28871 L .19333 .29708 L p .519 .655 .92 r
F P
0 g
s
.44832 .47452 m .45125 .46385 L .44878 .46208 L p .384 .52 .87 r
F P
0 g
s
.45125 .46385 m .44832 .47452 L .44954 .47544 L p .384 .52 .87 r
F P
0 g
s
.09363 .28367 m .11355 .2794 L .11921 .26118 L p .715 .637 .769 r
F P
0 g
s
.13785 .26994 m .11921 .26118 L .11355 .2794 L p .65 .674 .859 r
F P
0 g
s
.46734 .47824 m .45631 .48163 L .45731 .48273 L p .383 .52 .871 r
F P
0 g
s
.45731 .48273 m .46935 .48047 L .46734 .47824 L p .383 .52 .871 r
F P
0 g
s
.44954 .47544 m .45369 .46571 L .45125 .46385 L p .384 .52 .87 r
F P
0 g
s
.45369 .46571 m .44954 .47544 L .45073 .4764 L p .383 .519 .87 r
F P
0 g
s
.46523 .47604 m .45526 .48054 L .45631 .48163 L p .383 .52 .871 r
F P
0 g
s
.45631 .48163 m .46734 .47824 L .46523 .47604 L p .383 .52 .871 r
F P
0 g
s
.45073 .4764 m .45611 .46765 L .45369 .46571 L p .383 .519 .87 r
F P
0 g
s
.45611 .46765 m .45073 .4764 L .45191 .47739 L p .383 .519 .87 r
F P
0 g
s
.46305 .47387 m .45418 .47947 L .45526 .48054 L p .383 .52 .871 r
F P
0 g
s
.45526 .48054 m .46523 .47604 L .46305 .47387 L p .383 .52 .871 r
F P
0 g
s
.45191 .47739 m .45848 .46967 L .45611 .46765 L p .383 .519 .87 r
F P
0 g
s
.45848 .46967 m .45191 .47739 L .45306 .47842 L p .383 .519 .87 r
F P
0 g
s
.4608 .47174 m .45306 .47842 L .45418 .47947 L p .383 .52 .871 r
F P
0 g
s
.45418 .47947 m .46305 .47387 L .4608 .47174 L p .383 .52 .871 r
F P
0 g
s
.45306 .47842 m .4608 .47174 L .45848 .46967 L p .383 .519 .87 r
F P
0 g
s
.59964 .59084 m .58022 .57922 L .57811 .58315 L p .419 .575 .902 r
F P
0 g
s
.57811 .58315 m .59715 .59525 L .59964 .59084 L p .419 .575 .902 r
F P
0 g
s
.42306 .45029 m .41174 .43272 L .40881 .43238 L p .397 .528 .872 r
F P
0 g
s
.41174 .43272 m .42306 .45029 L .42511 .45069 L p .397 .527 .871 r
F P
0 g
s
.50274 .51334 m .48348 .50391 L .4839 .50572 L p .382 .526 .876 r
F P
0 g
s
.4839 .50572 m .50336 .51601 L .50274 .51334 L p .382 .526 .876 r
F P
0 g
s
.40343 .43236 m .38928 .41484 L .38606 .41536 L p .407 .535 .874 r
F P
0 g
s
.38928 .41484 m .40343 .43236 L .40604 .43227 L p .407 .535 .873 r
F P
0 g
s
.77416 .66624 m .75491 .66065 L .74873 .66794 L p .444 .736 .989 r
F P
0 g
s
.72996 .66148 m .74873 .66794 L .75491 .66065 L p .473 .694 .964 r
F P
0 g
s
.52358 .53267 m .50387 .52098 L .50378 .52325 L p .387 .533 .88 r
F P
0 g
s
.50378 .52325 m .52342 .53564 L .52358 .53267 L p .387 .533 .88 r
F P
0 g
s
.29265 .34304 m .30982 .35714 L .3145 .35376 L p .466 .589 .893 r
F P
0 g
s
.33107 .36899 m .3145 .35376 L .30982 .35714 L p .452 .577 .889 r
F P
0 g
s
.33107 .36899 m .34756 .38467 L .35156 .38278 L p .441 .564 .883 r
F P
0 g
s
.36736 .39932 m .35156 .38278 L .34756 .38467 L p .428 .554 .88 r
F P
0 g
s
.2348 .31056 m .25265 .32229 L .25806 .31647 L p .501 .629 .909 r
F P
0 g
s
.27539 .32948 m .25806 .31647 L .25265 .32229 L p .488 .616 .904 r
F P
0 g
s
.56212 .5633 m .5425 .55108 L .54146 .55423 L p .4 .551 .89 r
F P
0 g
s
.54146 .55423 m .56082 .567 L .56212 .5633 L p .4 .551 .89 r
F P
0 g
s
.61908 .60182 m .59964 .59084 L .59715 .59525 L p .427 .588 .908 r
F P
0 g
s
.59715 .59525 m .6162 .60671 L .61908 .60182 L p .427 .588 .908 r
F P
0 g
s
.42511 .45069 m .41481 .43327 L .41174 .43272 L p .397 .527 .871 r
F P
0 g
s
.41481 .43327 m .42511 .45069 L .42724 .45124 L p .396 .527 .871 r
F P
0 g
s
.75491 .66065 m .73559 .65415 L .72996 .66148 L p .473 .694 .964 r
F P
0 g
s
.7111 .65403 m .72996 .66148 L .73559 .65415 L p .474 .672 .951 r
F P
0 g
s
.15643 .27866 m .17492 .28766 L .18074 .27848 L p .542 .672 .922 r
F P
0 g
s
.19885 .28871 m .18074 .27848 L .17492 .28766 L p .53 .665 .923 r
F P
0 g
s
.50189 .51054 m .4829 .50202 L .48348 .50391 L p .381 .525 .876 r
F P
0 g
s
.48348 .50391 m .50274 .51334 L .50189 .51054 L p .381 .525 .876 r
F P
0 g
s
.54315 .54769 m .52342 .53564 L .52294 .53841 L p .392 .541 .885 r
F P
0 g
s
.52294 .53841 m .5425 .55108 L .54315 .54769 L p .392 .541 .885 r
F P
0 g
s
.38606 .41536 m .37105 .3982 L .36736 .39932 L p .417 .544 .876 r
F P
0 g
s
.37105 .3982 m .38606 .41536 L .38928 .41484 L p .418 .543 .875 r
F P
0 g
s
.63853 .61215 m .61908 .60182 L .6162 .60671 L p .436 .602 .915 r
F P
0 g
s
.6162 .60671 m .63523 .61749 L .63853 .61215 L p .436 .602 .915 r
F P
0 g
s
.35156 .38278 m .36736 .39932 L .37105 .3982 L p .43 .553 .878 r
F P
0 g
s
.73559 .65415 m .71623 .647 L .7111 .65403 L p .474 .672 .951 r
F P
0 g
s
.69219 .64587 m .7111 .65403 L .71623 .647 L p .469 .657 .942 r
F P
0 g
s
.40604 .43227 m .39275 .41461 L .38928 .41484 L p .407 .535 .873 r
F P
0 g
s
.39275 .41461 m .40604 .43227 L .40881 .43238 L p .407 .534 .872 r
F P
0 g
s
.65798 .62182 m .63853 .61215 L .63523 .61749 L p .444 .615 .922 r
F P
0 g
s
.63523 .61749 m .65425 .62761 L .65798 .62182 L p .444 .615 .922 r
F P
0 g
s
.52343 .52952 m .50373 .51857 L .50387 .52098 L p .384 .532 .88 r
F P
0 g
s
.50387 .52098 m .52358 .53267 L .52343 .52952 L p .384 .532 .88 r
F P
0 g
s
.71623 .647 m .69683 .63923 L .69219 .64587 L p .469 .657 .942 r
F P
0 g
s
.67324 .63706 m .69219 .64587 L .69683 .63923 L p .461 .643 .936 r
F P
0 g
s
.42724 .45124 m .41802 .43405 L .41481 .43327 L p .396 .527 .871 r
F P
0 g
s
.41802 .43405 m .42724 .45124 L .42945 .45193 L p .395 .526 .871 r
F P
0 g
s
.67741 .63084 m .65798 .62182 L .65425 .62761 L p .453 .629 .929 r
F P
0 g
s
.65425 .62761 m .67324 .63706 L .67741 .63084 L p .453 .629 .929 r
F P
0 g
s
.69683 .63923 m .67741 .63084 L .67324 .63706 L p .461 .643 .936 r
F P
0 g
s
.50081 .50763 m .48217 .50005 L .4829 .50202 L p .381 .525 .876 r
F P
0 g
s
.4829 .50202 m .50189 .51054 L .50081 .50763 L p .381 .525 .876 r
F P
0 g
s
.27539 .32948 m .29265 .34304 L .29785 .33901 L p .479 .602 .897 r
F P
0 g
s
.3145 .35376 m .29785 .33901 L .29265 .34304 L p .466 .589 .893 r
F P
0 g
s
.5818 .57499 m .56212 .5633 L .56082 .567 L p .406 .562 .896 r
F P
0 g
s
.56082 .567 m .58022 .57922 L .5818 .57499 L p .406 .562 .896 r
F P
0 g
s
.21688 .29938 m .2348 .31056 L .24063 .30401 L p .512 .642 .913 r
F P
0 g
s
.25806 .31647 m .24063 .30401 L .2348 .31056 L p .501 .629 .909 r
F P
0 g
s
.3145 .35376 m .33107 .36899 L .33569 .36658 L p .455 .576 .886 r
F P
0 g
s
.35156 .38278 m .33569 .36658 L .33107 .36899 L p .441 .564 .883 r
F P
0 g
s
.42945 .45193 m .42134 .43504 L .41802 .43405 L p .395 .526 .871 r
F P
0 g
s
.42134 .43504 m .42945 .45193 L .43173 .45275 L p .393 .525 .871 r
F P
0 g
s
.4995 .50462 m .48129 .49803 L .48217 .50005 L p .38 .524 .876 r
F P
0 g
s
.48217 .50005 m .50081 .50763 L .4995 .50462 L p .38 .524 .876 r
F P
0 g
s
.13785 .26994 m .15643 .27866 L .16253 .26853 L p .557 .671 .914 r
F P
0 g
s
.18074 .27848 m .16253 .26853 L .15643 .27866 L p .542 .672 .922 r
F P
0 g
s
.40881 .43238 m .39643 .41467 L .39275 .41461 L p .407 .534 .872 r
F P
0 g
s
.39643 .41467 m .40881 .43238 L .41174 .43272 L p .406 .533 .872 r
F P
0 g
s
.5434 .54407 m .52358 .53267 L .52342 .53564 L p .389 .54 .885 r
F P
0 g
s
.52342 .53564 m .54315 .54769 L .5434 .54407 L p .389 .54 .885 r
F P
0 g
s
.52296 .52618 m .50336 .51601 L .50373 .51857 L p .383 .531 .88 r
F P
0 g
s
.50373 .51857 m .52343 .52952 L .52296 .52618 L p .383 .531 .88 r
F P
0 g
s
.38928 .41484 m .37506 .39741 L .37105 .3982 L p .418 .543 .875 r
F P
0 g
s
.37506 .39741 m .38928 .41484 L .39275 .41461 L p .419 .542 .874 r
F P
0 g
s
.56296 .55932 m .54315 .54769 L .5425 .55108 L p .396 .55 .891 r
F P
0 g
s
.5425 .55108 m .56212 .5633 L .56296 .55932 L p .396 .55 .891 r
F P
0 g
s
.43173 .45275 m .42477 .43625 L .42134 .43504 L p .393 .525 .871 r
F P
0 g
s
.42477 .43625 m .43173 .45275 L .43407 .45371 L p .392 .524 .87 r
F P
0 g
s
.49796 .50152 m .48026 .49594 L .48129 .49803 L p .38 .524 .875 r
F P
0 g
s
.48129 .49803 m .4995 .50462 L .49796 .50152 L p .38 .524 .875 r
F P
0 g
s
.33569 .36658 m .35156 .38278 L .35596 .38126 L p .444 .563 .881 r
F P
0 g
s
.37105 .3982 m .35596 .38126 L .35156 .38278 L p .43 .553 .878 r
F P
0 g
s
.60153 .58611 m .5818 .57499 L .58022 .57922 L p .413 .574 .903 r
F P
0 g
s
.58022 .57922 m .59964 .59084 L .60153 .58611 L p .413 .574 .903 r
F P
0 g
s
.35596 .38126 m .37105 .3982 L .37506 .39741 L p .431 .552 .877 r
F P
0 g
s
.43407 .45371 m .42829 .43767 L .42477 .43625 L p .392 .524 .87 r
F P
0 g
s
.42829 .43767 m .43407 .45371 L .43646 .45481 L p .391 .523 .87 r
F P
0 g
s
.25806 .31647 m .27539 .32948 L .28112 .32476 L p .493 .615 .901 r
F P
0 g
s
.29785 .33901 m .28112 .32476 L .27539 .32948 L p .479 .602 .897 r
F P
0 g
s
.49621 .49834 m .47909 .49381 L .48026 .49594 L p .379 .523 .875 r
F P
0 g
s
.48026 .49594 m .49796 .50152 L .49621 .49834 L p .379 .523 .875 r
F P
0 g
s
.19885 .28871 m .21688 .29938 L .22311 .29208 L p .523 .653 .917 r
F P
0 g
s
.24063 .30401 m .22311 .29208 L .21688 .29938 L p .512 .642 .913 r
F P
0 g
s
.11921 .26118 m .10057 .25163 L .09363 .28367 L p .715 .637 .769 r
F P
0 g
s
.41174 .43272 m .40034 .41502 L .39643 .41467 L p .406 .533 .872 r
F P
0 g
s
.40034 .41502 m .41174 .43272 L .41481 .43327 L p .405 .532 .871 r
F P
0 g
s
.29785 .33901 m .3145 .35376 L .31974 .35078 L p .469 .588 .89 r
F P
0 g
s
.33569 .36658 m .31974 .35078 L .3145 .35376 L p .455 .576 .886 r
F P
0 g
s
.52217 .52268 m .50274 .51334 L .50336 .51601 L p .381 .53 .88 r
F P
0 g
s
.50336 .51601 m .52296 .52618 L .52217 .52268 L p .381 .53 .88 r
F P
0 g
s
.43646 .45481 m .43189 .43929 L .42829 .43767 L p .391 .523 .87 r
F P
0 g
s
.43189 .43929 m .43646 .45481 L .43888 .45603 L p .389 .522 .87 r
F P
0 g
s
.11921 .26118 m .13785 .26994 L .14426 .25841 L p .576 .649 .885 r
F P
0 g
s
.16253 .26853 m .14426 .25841 L .13785 .26994 L p .557 .671 .914 r
F P
0 g
s
.49424 .49509 m .47777 .49163 L .47909 .49381 L p .379 .522 .874 r
F P
0 g
s
.47909 .49381 m .49621 .49834 L .49424 .49509 L p .379 .522 .874 r
F P
0 g
s
.62129 .59662 m .60153 .58611 L .59964 .59084 L p .42 .587 .91 r
F P
0 g
s
.59964 .59084 m .61908 .60182 L .62129 .59662 L p .42 .587 .91 r
F P
0 g
s
.54325 .54022 m .52343 .52952 L .52358 .53267 L p .385 .538 .885 r
F P
0 g
s
.52358 .53267 m .5434 .54407 L .54325 .54022 L p .385 .538 .885 r
F P
0 g
s
.39275 .41461 m .37937 .39697 L .37506 .39741 L p .419 .542 .874 r
F P
0 g
s
.37937 .39697 m .39275 .41461 L .39643 .41467 L p .418 .541 .873 r
F P
0 g
s
.43888 .45603 m .43555 .44112 L .43189 .43929 L p .389 .522 .87 r
F P
0 g
s
.43555 .44112 m .43888 .45603 L .44134 .45737 L p .388 .521 .869 r
F P
0 g
s
.58284 .57047 m .56296 .55932 L .56212 .5633 L p .401 .56 .897 r
F P
0 g
s
.56212 .5633 m .5818 .57499 L .58284 .57047 L p .401 .56 .897 r
F P
0 g
s
.49208 .49179 m .47633 .48943 L .47777 .49163 L p .379 .522 .874 r
F P
0 g
s
.47777 .49163 m .49424 .49509 L .49208 .49179 L p .379 .522 .874 r
F P
0 g
s
.41481 .43327 m .40443 .41566 L .40034 .41502 L p .405 .532 .871 r
F P
0 g
s
.40443 .41566 m .41481 .43327 L .41802 .43405 L p .404 .53 .871 r
F P
0 g
s
.56331 .55509 m .5434 .54407 L .54315 .54769 L p .391 .548 .891 r
F P
0 g
s
.54315 .54769 m .56296 .55932 L .56331 .55509 L p .391 .548 .891 r
F P
0 g
s
.44134 .45737 m .43925 .44315 L .43555 .44112 L p .388 .521 .869 r
F P
0 g
s
.43925 .44315 m .44134 .45737 L .44381 .45883 L p .386 .52 .869 r
F P
0 g
s
.52106 .51902 m .50189 .51054 L .50274 .51334 L p .379 .529 .88 r
F P
0 g
s
.50274 .51334 m .52217 .52268 L .52106 .51902 L p .379 .529 .88 r
F P
0 g
s
.31974 .35078 m .33569 .36658 L .34079 .36459 L p .458 .574 .884 r
F P
0 g
s
.35596 .38126 m .34079 .36459 L .33569 .36658 L p .444 .563 .881 r
F P
0 g
s
.48971 .48844 m .47476 .4872 L .47633 .48943 L p .379 .521 .873 r
F P
0 g
s
.47633 .48943 m .49208 .49179 L .48971 .48844 L p .379 .521 .873 r
F P
0 g
s
.64108 .60649 m .62129 .59662 L .61908 .60182 L p .428 .6 .917 r
F P
0 g
s
.61908 .60182 m .63853 .61215 L .64108 .60649 L p .428 .6 .917 r
F P
0 g
s
.24063 .30401 m .25806 .31647 L .2643 .31104 L p .506 .628 .905 r
F P
0 g
s
.28112 .32476 m .2643 .31104 L .25806 .31647 L p .493 .615 .901 r
F P
0 g
s
.37506 .39741 m .36075 .38012 L .35596 .38126 L p .431 .552 .877 r
F P
0 g
s
.36075 .38012 m .37506 .39741 L .37937 .39697 L p .432 .55 .875 r
F P
0 g
s
.18074 .27848 m .19885 .28871 L .20548 .28066 L p .532 .664 .921 r
F P
0 g
s
.22311 .29208 m .20548 .28066 L .19885 .28871 L p .523 .653 .917 r
F P
0 g
s
.44381 .45883 m .44298 .44536 L .43925 .44315 L p .386 .52 .869 r
F P
0 g
s
.44298 .44536 m .44381 .45883 L .4463 .46041 L p .385 .519 .869 r
F P
0 g
s
.48717 .48506 m .47307 .48496 L .47476 .4872 L p .379 .52 .873 r
F P
0 g
s
.47476 .4872 m .48971 .48844 L .48717 .48506 L p .379 .52 .873 r
F P
0 g
s
.34079 .36459 m .35596 .38126 L .36075 .38012 L p .445 .562 .879 r
F P
0 g
s
.28112 .32476 m .29785 .33901 L .30371 .3354 L p .483 .6 .893 r
F P
0 g
s
.31974 .35078 m .30371 .3354 L .29785 .33901 L p .469 .588 .89 r
F P
0 g
s
.10057 .25163 m .11921 .26118 L .12602 .24693 L p .593 .587 .816 r
F P
0 g
s
.14426 .25841 m .12602 .24693 L .11921 .26118 L p .576 .649 .885 r
F P
0 g
s
.4463 .46041 m .44673 .44774 L .44298 .44536 L p .385 .519 .869 r
F P
0 g
s
.44673 .44774 m .4463 .46041 L .44878 .46208 L p .384 .518 .869 r
F P
0 g
s
.48444 .48167 m .47126 .48271 L .47307 .48496 L p .379 .519 .872 r
F P
0 g
s
.47307 .48496 m .48717 .48506 L .48444 .48167 L p .379 .519 .872 r
F P
0 g
s
.66089 .61572 m .64108 .60649 L .63853 .61215 L p .436 .614 .924 r
F P
0 g
s
.63853 .61215 m .65798 .62182 L .66089 .61572 L p .436 .614 .924 r
F P
0 g
s
.41802 .43405 m .40871 .41662 L .40443 .41566 L p .404 .53 .871 r
F P
0 g
s
.40871 .41662 m .41802 .43405 L .42134 .43504 L p .402 .529 .87 r
F P
0 g
s
.39643 .41467 m .38397 .3969 L .37937 .39697 L p .418 .541 .873 r
F P
0 g
s
.38397 .3969 m .39643 .41467 L .40034 .41502 L p .418 .539 .872 r
F P
0 g
s
.5427 .53615 m .52296 .52618 L .52343 .52952 L p .383 .537 .885 r
F P
0 g
s
.52343 .52952 m .54325 .54022 L .5427 .53615 L p .383 .537 .885 r
F P
0 g
s
.44878 .46208 m .45048 .45029 L .44673 .44774 L p .384 .518 .869 r
F P
0 g
s
.45048 .45029 m .44878 .46208 L .45125 .46385 L p .383 .517 .869 r
F P
0 g
s
.51963 .5152 m .50081 .50763 L .50189 .51054 L p .378 .528 .88 r
F P
0 g
s
.50189 .51054 m .52106 .51902 L .51963 .5152 L p .378 .528 .88 r
F P
0 g
s
.48156 .47828 m .46935 .48047 L .47126 .48271 L p .379 .519 .871 r
F P
0 g
s
.47126 .48271 m .48444 .48167 L .48156 .47828 L p .379 .519 .871 r
F P
0 g
s
.60279 .58108 m .58284 .57047 L .5818 .57499 L p .406 .572 .904 r
F P
0 g
s
.5818 .57499 m .60153 .58611 L .60279 .58108 L p .406 .572 .904 r
F P
0 g
s
.45125 .46385 m .45421 .45299 L .45048 .45029 L p .383 .517 .869 r
F P
0 g
s
.45421 .45299 m .45125 .46385 L .45369 .46571 L p .382 .517 .869 r
F P
0 g
s
.47852 .47491 m .46734 .47824 L .46935 .48047 L p .379 .518 .871 r
F P
0 g
s
.46935 .48047 m .48156 .47828 L .47852 .47491 L p .379 .518 .871 r
F P
0 g
s
.6807 .62431 m .66089 .61572 L .65798 .62182 L p .444 .628 .931 r
F P
0 g
s
.65798 .62182 m .67741 .63084 L .6807 .62431 L p .444 .628 .931 r
F P
0 g
s
.45369 .46571 m .45791 .45583 L .45421 .45299 L p .382 .517 .869 r
F P
0 g
s
.45791 .45583 m .45369 .46571 L .45611 .46765 L p .381 .516 .869 r
F P
0 g
s
.47535 .47156 m .46523 .47604 L .46734 .47824 L p .379 .517 .87 r
F P
0 g
s
.46734 .47824 m .47852 .47491 L .47535 .47156 L p .379 .517 .87 r
F P
0 g
s
.77416 .66624 m .79328 .67018 L .79971 .66723 L p .215 .676 .945 r
F P
0 g
s
.45611 .46765 m .46156 .45879 L .45791 .45583 L p .381 .516 .869 r
F P
0 g
s
.46156 .45879 m .45611 .46765 L .45848 .46967 L p .38 .516 .869 r
F P
0 g
s
.47205 .46826 m .46305 .47387 L .46523 .47604 L p .379 .517 .87 r
F P
0 g
s
.46523 .47604 m .47535 .47156 L .47205 .46826 L p .379 .517 .87 r
F P
0 g
s
.45848 .46967 m .46514 .46186 L .46156 .45879 L p .38 .516 .869 r
F P
0 g
s
.46514 .46186 m .45848 .46967 L .4608 .47174 L p .38 .516 .869 r
F P
0 g
s
.46865 .46502 m .4608 .47174 L .46305 .47387 L p .38 .517 .869 r
F P
0 g
s
.46305 .47387 m .47205 .46826 L .46865 .46502 L p .38 .517 .869 r
F P
0 g
s
.4608 .47174 m .46865 .46502 L .46514 .46186 L p .38 .516 .869 r
F P
0 g
s
.42134 .43504 m .41315 .41787 L .40871 .41662 L p .402 .529 .87 r
F P
0 g
s
.41315 .41787 m .42134 .43504 L .42477 .43625 L p .4 .527 .87 r
F P
0 g
s
.70052 .63229 m .6807 .62431 L .67741 .63084 L p .452 .641 .938 r
F P
0 g
s
.67741 .63084 m .69683 .63923 L .70052 .63229 L p .452 .641 .938 r
F P
0 g
s
.22311 .29208 m .24063 .30401 L .24738 .29783 L p .518 .64 .909 r
F P
0 g
s
.2643 .31104 m .24738 .29783 L .24063 .30401 L p .506 .628 .905 r
F P
0 g
s
.56319 .5506 m .54325 .54022 L .5434 .54407 L p .387 .546 .891 r
F P
0 g
s
.5434 .54407 m .56331 .55509 L .56319 .5506 L p .387 .546 .891 r
F P
0 g
s
.5179 .51125 m .4995 .50462 L .50081 .50763 L p .377 .527 .879 r
F P
0 g
s
.50081 .50763 m .51963 .5152 L .5179 .51125 L p .377 .527 .879 r
F P
0 g
s
.30371 .3354 m .31974 .35078 L .32554 .34823 L p .472 .586 .887 r
F P
0 g
s
.34079 .36459 m .32554 .34823 L .31974 .35078 L p .458 .574 .884 r
F P
0 g
s
.12602 .24693 m .10809 .23096 L .10057 .25163 L p .593 .587 .816 r
F P
0 g
s
.58332 .56567 m .56331 .55509 L .56296 .55932 L p .395 .558 .898 r
F P
0 g
s
.56296 .55932 m .58284 .57047 L .58332 .56567 L p .395 .558 .898 r
F P
0 g
s
.16253 .26853 m .18074 .27848 L .18774 .26971 L p .536 .673 .926 r
F P
0 g
s
.20548 .28066 m .18774 .26971 L .18074 .27848 L p .532 .664 .921 r
F P
0 g
s
.79971 .66723 m .77978 .65956 L .77416 .66624 L p .215 .676 .945 r
F P
0 g
s
.75491 .66065 m .77416 .66624 L .77978 .65956 L p .422 .701 .98 r
F P
0 g
s
.72034 .63967 m .70052 .63229 L .69683 .63923 L p .459 .655 .945 r
F P
0 g
s
.69683 .63923 m .71623 .647 L .72034 .63967 L p .459 .655 .945 r
F P
0 g
s
.37937 .39697 m .36591 .3794 L .36075 .38012 L p .432 .55 .875 r
F P
0 g
s
.36591 .3794 m .37937 .39697 L .38397 .3969 L p .431 .548 .874 r
F P
0 g
s
.40034 .41502 m .38884 .39719 L .38397 .3969 L p .418 .539 .872 r
F P
0 g
s
.38884 .39719 m .40034 .41502 L .40443 .41566 L p .416 .537 .871 r
F P
0 g
s
.54175 .53188 m .52217 .52268 L .52296 .52618 L p .38 .535 .885 r
F P
0 g
s
.52296 .52618 m .5427 .53615 L .54175 .53188 L p .38 .535 .885 r
F P
0 g
s
.74014 .64653 m .72034 .63967 L .71623 .647 L p .464 .669 .952 r
F P
0 g
s
.71623 .647 m .73559 .65415 L .74014 .64653 L p .464 .669 .952 r
F P
0 g
s
.77978 .65956 m .75995 .65303 L .75491 .66065 L p .422 .701 .98 r
F P
0 g
s
.73559 .65415 m .75491 .66065 L .75995 .65303 L p .459 .683 .962 r
F P
0 g
s
.2643 .31104 m .28112 .32476 L .28758 .32047 L p .497 .613 .897 r
F P
0 g
s
.30371 .3354 m .28758 .32047 L .28112 .32476 L p .483 .6 .893 r
F P
0 g
s
.75995 .65303 m .74014 .64653 L .73559 .65415 L p .459 .683 .962 r
F P
0 g
s
.6228 .5911 m .60279 .58108 L .60153 .58611 L p .413 .585 .911 r
F P
0 g
s
.60153 .58611 m .62129 .59662 L .6228 .5911 L p .413 .585 .911 r
F P
0 g
s
.42477 .43625 m .41774 .41942 L .41315 .41787 L p .4 .527 .87 r
F P
0 g
s
.41774 .41942 m .42477 .43625 L .42829 .43767 L p .398 .525 .869 r
F P
0 g
s
.32554 .34823 m .34079 .36459 L .34636 .36302 L p .46 .572 .881 r
F P
0 g
s
.36075 .38012 m .34636 .36302 L .34079 .36459 L p .445 .562 .879 r
F P
0 g
s
.34636 .36302 m .36075 .38012 L .36591 .3794 L p .446 .56 .877 r
F P
0 g
s
.51587 .50717 m .49796 .50152 L .4995 .50462 L p .376 .525 .878 r
F P
0 g
s
.4995 .50462 m .5179 .51125 L .51587 .50717 L p .376 .525 .878 r
F P
0 g
s
.42829 .43767 m .42245 .42128 L .41774 .41942 L p .398 .525 .869 r
F P
0 g
s
.42245 .42128 m .42829 .43767 L .43189 .43929 L p .396 .524 .869 r
F P
0 g
s
.40443 .41566 m .39397 .39786 L .38884 .39719 L p .416 .537 .871 r
F P
0 g
s
.39397 .39786 m .40443 .41566 L .40871 .41662 L p .415 .535 .87 r
F P
0 g
s
.51354 .50298 m .49621 .49834 L .49796 .50152 L p .375 .524 .878 r
F P
0 g
s
.49796 .50152 m .51587 .50717 L .51354 .50298 L p .375 .524 .878 r
F P
0 g
s
.20548 .28066 m .22311 .29208 L .23034 .28513 L p .529 .652 .913 r
F P
0 g
s
.24738 .29783 m .23034 .28513 L .22311 .29208 L p .518 .64 .909 r
F P
0 g
s
.54039 .52741 m .52106 .51902 L .52217 .52268 L p .377 .534 .885 r
F P
0 g
s
.52217 .52268 m .54175 .53188 L .54039 .52741 L p .377 .534 .885 r
F P
0 g
s
.14426 .25841 m .16253 .26853 L .16988 .25917 L p .525 .678 .934 r
F P
0 g
s
.18774 .26971 m .16988 .25917 L .16253 .26853 L p .536 .673 .926 r
F P
0 g
s
.64285 .60052 m .6228 .5911 L .62129 .59662 L p .419 .598 .919 r
F P
0 g
s
.62129 .59662 m .64108 .60649 L .64285 .60052 L p .419 .598 .919 r
F P
0 g
s
.56258 .54586 m .5427 .53615 L .54325 .54022 L p .383 .544 .891 r
F P
0 g
s
.54325 .54022 m .56319 .5506 L .56258 .54586 L p .383 .544 .891 r
F P
0 g
s
.38397 .3969 m .37142 .3791 L .36591 .3794 L p .431 .548 .874 r
F P
0 g
s
.37142 .3791 m .38397 .3969 L .38884 .39719 L p .431 .546 .872 r
F P
0 g
s
.60342 .57575 m .58332 .56567 L .58284 .57047 L p .4 .57 .905 r
F P
0 g
s
.58284 .57047 m .60279 .58108 L .60342 .57575 L p .4 .57 .905 r
F P
0 g
s
.28758 .32047 m .30371 .3354 L .3102 .33224 L p .487 .598 .89 r
F P
0 g
s
.32554 .34823 m .3102 .33224 L .30371 .3354 L p .472 .586 .887 r
F P
0 g
s
.43189 .43929 m .42727 .42343 L .42245 .42128 L p .396 .524 .869 r
F P
0 g
s
.42727 .42343 m .43189 .43929 L .43555 .44112 L p .393 .522 .868 r
F P
0 g
s
.24738 .29783 m .2643 .31104 L .27136 .30602 L p .51 .625 .901 r
F P
0 g
s
.28758 .32047 m .27136 .30602 L .2643 .31104 L p .497 .613 .897 r
F P
0 g
s
.58324 .56059 m .56319 .5506 L .56331 .55509 L p .389 .556 .898 r
F P
0 g
s
.56331 .55509 m .58332 .56567 L .58324 .56059 L p .389 .556 .898 r
F P
0 g
s
.51092 .49868 m .49424 .49509 L .49621 .49834 L p .374 .523 .877 r
F P
0 g
s
.49621 .49834 m .51354 .50298 L .51092 .49868 L p .374 .523 .877 r
F P
0 g
s
.40871 .41662 m .39932 .39893 L .39397 .39786 L p .415 .535 .87 r
F P
0 g
s
.39932 .39893 m .40871 .41662 L .41315 .41787 L p .412 .533 .869 r
F P
0 g
s
.36591 .3794 m .35236 .36193 L .34636 .36302 L p .446 .56 .877 r
F P
0 g
s
.35236 .36193 m .36591 .3794 L .37142 .3791 L p .446 .557 .875 r
F P
0 g
s
.66295 .60932 m .64285 .60052 L .64108 .60649 L p .427 .612 .926 r
F P
0 g
s
.64108 .60649 m .66089 .61572 L .66295 .60932 L p .427 .612 .926 r
F P
0 g
s
.3102 .33224 m .32554 .34823 L .33187 .34617 L p .475 .584 .884 r
F P
0 g
s
.34636 .36302 m .33187 .34617 L .32554 .34823 L p .46 .572 .881 r
F P
0 g
s
.43555 .44112 m .43217 .42586 L .42727 .42343 L p .393 .522 .868 r
F P
0 g
s
.43217 .42586 m .43555 .44112 L .43925 .44315 L p .39 .52 .868 r
F P
0 g
s
.53865 .52276 m .51963 .5152 L .52106 .51902 L p .375 .532 .884 r
F P
0 g
s
.52106 .51902 m .54039 .52741 L .53865 .52276 L p .375 .532 .884 r
F P
0 g
s
.50803 .4943 m .49208 .49179 L .49424 .49509 L p .374 .521 .876 r
F P
0 g
s
.49424 .49509 m .51092 .49868 L .50803 .4943 L p .374 .521 .876 r
F P
0 g
s
.33187 .34617 m .34636 .36302 L .35236 .36193 L p .461 .57 .878 r
F P
0 g
s
.12602 .24693 m .14426 .25841 L .15192 .2489 L p .468 .666 .949 r
F P
0 g
s
.16988 .25917 m .15192 .2489 L .14426 .25841 L p .525 .678 .934 r
F P
0 g
s
.43925 .44315 m .43714 .42858 L .43217 .42586 L p .39 .52 .868 r
F P
0 g
s
.43714 .42858 m .43925 .44315 L .44298 .44536 L p .388 .518 .867 r
F P
0 g
s
.56148 .54088 m .54175 .53188 L .5427 .53615 L p .379 .542 .891 r
F P
0 g
s
.5427 .53615 m .56258 .54586 L .56148 .54088 L p .379 .542 .891 r
F P
0 g
s
.18774 .26971 m .20548 .28066 L .2132 .27294 L p .538 .664 .918 r
F P
0 g
s
.23034 .28513 m .2132 .27294 L .20548 .28066 L p .529 .652 .913 r
F P
0 g
s
.38884 .39719 m .37726 .37926 L .37142 .3791 L p .431 .546 .872 r
F P
0 g
s
.37726 .37926 m .38884 .39719 L .39397 .39786 L p .429 .544 .871 r
F P
0 g
s
.6236 .58529 m .60342 .57575 L .60279 .58108 L p .405 .582 .912 r
F P
0 g
s
.60279 .58108 m .6228 .5911 L .6236 .58529 L p .405 .582 .912 r
F P
0 g
s
.50487 .48985 m .48971 .48844 L .49208 .49179 L p .373 .52 .875 r
F P
0 g
s
.49208 .49179 m .50803 .4943 L .50487 .48985 L p .373 .52 .875 r
F P
0 g
s
.68307 .61749 m .66295 .60932 L .66089 .61572 L p .434 .626 .933 r
F P
0 g
s
.66089 .61572 m .6807 .62431 L .68307 .61749 L p .434 .626 .933 r
F P
0 g
s
.27136 .30602 m .28758 .32047 L .29475 .31665 L p .501 .61 .893 r
F P
0 g
s
.3102 .33224 m .29475 .31665 L .28758 .32047 L p .487 .598 .89 r
F P
0 g
s
.41315 .41787 m .40488 .40039 L .39932 .39893 L p .412 .533 .869 r
F P
0 g
s
.40488 .40039 m .41315 .41787 L .41774 .41942 L p .409 .53 .868 r
F P
0 g
s
.44298 .44536 m .44215 .43155 L .43714 .42858 L p .388 .518 .867 r
F P
0 g
s
.44215 .43155 m .44298 .44536 L .44673 .44774 L p .385 .516 .867 r
F P
0 g
s
.53651 .51792 m .5179 .51125 L .51963 .5152 L p .373 .53 .883 r
F P
0 g
s
.51963 .5152 m .53865 .52276 L .53651 .51792 L p .373 .53 .883 r
F P
0 g
s
.50146 .48534 m .48717 .48506 L .48971 .48844 L p .373 .518 .874 r
F P
0 g
s
.48971 .48844 m .50487 .48985 L .50146 .48534 L p .373 .518 .874 r
F P
0 g
s
.23034 .28513 m .24738 .29783 L .25502 .29206 L p .523 .638 .905 r
F P
0 g
s
.27136 .30602 m .25502 .29206 L .24738 .29783 L p .51 .625 .901 r
F P
0 g
s
.58259 .55524 m .56258 .54586 L .56319 .5506 L p .384 .553 .898 r
F P
0 g
s
.56319 .5506 m .58324 .56059 L .58259 .55524 L p .384 .553 .898 r
F P
0 g
s
.44673 .44774 m .44718 .43478 L .44215 .43155 L p .385 .516 .867 r
F P
0 g
s
.44718 .43478 m .44673 .44774 L .45048 .45029 L p .383 .515 .867 r
F P
0 g
s
.60341 .57013 m .58324 .56059 L .58332 .56567 L p .393 .567 .905 r
F P
0 g
s
.58332 .56567 m .60342 .57575 L .60341 .57013 L p .393 .567 .905 r
F P
0 g
s
.70322 .62505 m .68307 .61749 L .6807 .62431 L p .442 .639 .94 r
F P
0 g
s
.6807 .62431 m .70052 .63229 L .70322 .62505 L p .442 .639 .94 r
F P
0 g
s
.49782 .4808 m .48444 .48167 L .48717 .48506 L p .373 .517 .873 r
F P
0 g
s
.48717 .48506 m .50146 .48534 L .49782 .4808 L p .373 .517 .873 r
F P
0 g
s
.10809 .23096 m .12602 .24693 L .13386 .23855 L p .213 .56 .935 r
F P
0 g
s
.15192 .2489 m .13386 .23855 L .12602 .24693 L p .468 .666 .949 r
F P
0 g
s
.37142 .3791 m .35878 .36132 L .35236 .36193 L p .446 .557 .875 r
F P
0 g
s
.35878 .36132 m .37142 .3791 L .37726 .37926 L p .445 .555 .873 r
F P
0 g
s
.45048 .45029 m .45221 .43823 L .44718 .43478 L p .383 .515 .867 r
F P
0 g
s
.45221 .43823 m .45048 .45029 L .45421 .45299 L p .381 .514 .866 r
F P
0 g
s
.29475 .31665 m .3102 .33224 L .31729 .32959 L p .489 .595 .886 r
F P
0 g
s
.33187 .34617 m .31729 .32959 L .3102 .33224 L p .475 .584 .884 r
F P
0 g
s
.49395 .47624 m .48156 .47828 L .48444 .48167 L p .373 .516 .871 r
F P
0 g
s
.48444 .48167 m .49782 .4808 L .49395 .47624 L p .373 .516 .871 r
F P
0 g
s
.41774 .41942 m .41063 .40224 L .40488 .40039 L p .409 .53 .868 r
F P
0 g
s
.41063 .40224 m .41774 .41942 L .42245 .42128 L p .406 .528 .867 r
F P
0 g
s
.39397 .39786 m .38341 .37987 L .37726 .37926 L p .429 .544 .871 r
F P
0 g
s
.38341 .37987 m .39397 .39786 L .39932 .39893 L p .427 .541 .869 r
F P
0 g
s
.55991 .53568 m .54039 .52741 L .54175 .53188 L p .375 .54 .89 r
F P
0 g
s
.54175 .53188 m .56148 .54088 L .55991 .53568 L p .375 .54 .89 r
F P
0 g
s
.64384 .59425 m .6236 .58529 L .6228 .5911 L p .411 .595 .92 r
F P
0 g
s
.6228 .5911 m .64285 .60052 L .64384 .59425 L p .411 .595 .92 r
F P
0 g
s
.13386 .23855 m .11579 .2272 L .10809 .23096 L p .213 .56 .935 r
F P
0 g
s
.45421 .45299 m .45722 .44191 L .45221 .43823 L p .381 .514 .866 r
F P
0 g
s
.45722 .44191 m .45421 .45299 L .45791 .45583 L p .379 .513 .866 r
F P
0 g
s
.72339 .63203 m .70322 .62505 L .70052 .63229 L p .45 .653 .946 r
F P
0 g
s
.70052 .63229 m .72034 .63967 L .72339 .63203 L p .45 .653 .946 r
F P
0 g
s
.53398 .51291 m .51587 .50717 L .5179 .51125 L p .371 .528 .882 r
F P
0 g
s
.5179 .51125 m .53651 .51792 L .53398 .51291 L p .371 .528 .882 r
F P
0 g
s
.48988 .47169 m .47852 .47491 L .48156 .47828 L p .373 .515 .87 r
F P
0 g
s
.48156 .47828 m .49395 .47624 L .48988 .47169 L p .373 .515 .87 r
F P
0 g
s
.16988 .25917 m .18774 .26971 L .19592 .26126 L p .543 .676 .925 r
F P
0 g
s
.2132 .27294 m .19592 .26126 L .18774 .26971 L p .538 .664 .918 r
F P
0 g
s
.35236 .36193 m .33871 .34461 L .33187 .34617 L p .461 .57 .878 r
F P
0 g
s
.33871 .34461 m .35236 .36193 L .35878 .36132 L p .461 .567 .876 r
F P
0 g
s
.45791 .45583 m .46219 .44577 L .45722 .44191 L p .379 .513 .866 r
F P
0 g
s
.46219 .44577 m .45791 .45583 L .46156 .45879 L p .378 .512 .867 r
F P
0 g
s
.31729 .32959 m .33187 .34617 L .33871 .34461 L p .476 .581 .88 r
F P
0 g
s
.48562 .46716 m .47535 .47156 L .47852 .47491 L p .373 .514 .869 r
F P
0 g
s
.47852 .47491 m .48988 .47169 L .48562 .46716 L p .373 .514 .869 r
F P
0 g
s
.46156 .45879 m .46709 .4498 L .46219 .44577 L p .378 .512 .867 r
F P
0 g
s
.46709 .4498 m .46156 .45879 L .46514 .46186 L p .376 .512 .867 r
F P
0 g
s
.48119 .46268 m .47205 .46826 L .47535 .47156 L p .374 .513 .869 r
F P
0 g
s
.47535 .47156 m .48562 .46716 L .48119 .46268 L p .374 .513 .869 r
F P
0 g
s
.46514 .46186 m .47191 .45398 L .46709 .4498 L p .376 .512 .867 r
F P
0 g
s
.47191 .45398 m .46514 .46186 L .46865 .46502 L p .375 .512 .867 r
F P
0 g
s
.74356 .63849 m .72339 .63203 L .72034 .63967 L p .457 .665 .952 r
F P
0 g
s
.72034 .63967 m .74014 .64653 L .74356 .63849 L p .457 .665 .952 r
F P
0 g
s
.47661 .45828 m .46865 .46502 L .47205 .46826 L p .374 .512 .868 r
F P
0 g
s
.47205 .46826 m .48119 .46268 L .47661 .45828 L p .374 .512 .868 r
F P
0 g
s
.46865 .46502 m .47661 .45828 L .47191 .45398 L p .375 .512 .867 r
F P
0 g
s
.25502 .29206 m .27136 .30602 L .2792 .30149 L p .514 .623 .897 r
F P
0 g
s
.29475 .31665 m .2792 .30149 L .27136 .30602 L p .501 .61 .893 r
F P
0 g
s
.42245 .42128 m .41654 .4045 L .41063 .40224 L p .406 .528 .867 r
F P
0 g
s
.41654 .4045 m .42245 .42128 L .42727 .42343 L p .402 .525 .867 r
F P
0 g
s
.2132 .27294 m .23034 .28513 L .23857 .27858 L p .535 .65 .908 r
F P
0 g
s
.25502 .29206 m .23857 .27858 L .23034 .28513 L p .523 .638 .905 r
F P
0 g
s
.76376 .64456 m .74356 .63849 L .74014 .64653 L p .462 .673 .955 r
F P
0 g
s
.74014 .64653 m .75995 .65303 L .76376 .64456 L p .462 .673 .955 r
F P
0 g
s
.53108 .50775 m .51354 .50298 L .51587 .50717 L p .369 .525 .881 r
F P
0 g
s
.51587 .50717 m .53398 .51291 L .53108 .50775 L p .369 .525 .881 r
F P
0 g
s
.58138 .54962 m .56148 .54088 L .56258 .54586 L p .378 .55 .898 r
F P
0 g
s
.56258 .54586 m .58259 .55524 L .58138 .54962 L p .378 .55 .898 r
F P
0 g
s
.39932 .39893 m .38985 .38097 L .38341 .37987 L p .427 .541 .869 r
F P
0 g
s
.38985 .38097 m .39932 .39893 L .40488 .40039 L p .424 .538 .868 r
F P
0 g
s
.62367 .57918 m .60341 .57013 L .60342 .57575 L p .397 .579 .913 r
F P
0 g
s
.60342 .57575 m .6236 .58529 L .62367 .57918 L p .397 .579 .913 r
F P
0 g
s
.66415 .60262 m .64384 .59425 L .64285 .60052 L p .417 .609 .928 r
F P
0 g
s
.64285 .60052 m .66295 .60932 L .66415 .60262 L p .417 .609 .928 r
F P
0 g
s
.37726 .37926 m .36559 .36124 L .35878 .36132 L p .445 .555 .873 r
F P
0 g
s
.36559 .36124 m .37726 .37926 L .38341 .37987 L p .444 .551 .871 r
F P
0 g
s
.78399 .65061 m .76376 .64456 L .75995 .65303 L p .461 .673 .955 r
F P
0 g
s
.75995 .65303 m .77978 .65956 L .78399 .65061 L p .461 .673 .955 r
F P
0 g
s
.55784 .53024 m .53865 .52276 L .54039 .52741 L p .371 .537 .89 r
F P
0 g
s
.54039 .52741 m .55991 .53568 L .55784 .53024 L p .371 .537 .89 r
F P
0 g
s
.42727 .42343 m .42259 .40715 L .41654 .4045 L p .402 .525 .867 r
F P
0 g
s
.42259 .40715 m .42727 .42343 L .43217 .42586 L p .399 .522 .866 r
F P
0 g
s
.60274 .56423 m .58259 .55524 L .58324 .56059 L p .386 .564 .905 r
F P
0 g
s
.58324 .56059 m .60341 .57013 L .60274 .56423 L p .386 .564 .905 r
F P
0 g
s
.80434 .65769 m .78399 .65061 L .77978 .65956 L p .443 .647 .945 r
F P
0 g
s
.77978 .65956 m .79971 .66723 L .80434 .65769 L p .443 .647 .945 r
F P
0 g
s
.2792 .30149 m .29475 .31665 L .30261 .31335 L p .504 .608 .889 r
F P
0 g
s
.31729 .32959 m .30261 .31335 L .29475 .31665 L p .489 .595 .886 r
F P
0 g
s
.52781 .50245 m .51092 .49868 L .51354 .50298 L p .368 .523 .88 r
F P
0 g
s
.51354 .50298 m .53108 .50775 L .52781 .50245 L p .368 .523 .88 r
F P
0 g
s
.15192 .2489 m .16988 .25917 L .17851 .25016 L p .535 .691 .94 r
F P
0 g
s
.19592 .26126 m .17851 .25016 L .16988 .25917 L p .543 .676 .925 r
F P
0 g
s
.35878 .36132 m .34604 .3436 L .33871 .34461 L p .461 .567 .876 r
F P
0 g
s
.34604 .3436 m .35878 .36132 L .36559 .36124 L p .461 .564 .873 r
F P
0 g
s
.82506 .66854 m .80434 .65769 L .79971 .66723 L p .385 .565 .906 r
F P
0 g
s
.79971 .66723 m .82001 .67892 L .82506 .66854 L p .385 .565 .906 r
F P
0 g
s
.43217 .42586 m .42875 .41018 L .42259 .40715 L p .399 .522 .866 r
F P
0 g
s
.42875 .41018 m .43217 .42586 L .43714 .42858 L p .395 .519 .865 r
F P
0 g
s
.40488 .40039 m .39654 .38257 L .38985 .38097 L p .424 .538 .868 r
F P
0 g
s
.39654 .38257 m .40488 .40039 L .41063 .40224 L p .42 .534 .867 r
F P
0 g
s
.6845 .61038 m .66415 .60262 L .66295 .60932 L p .424 .623 .935 r
F P
0 g
s
.66295 .60932 m .68307 .61749 L .6845 .61038 L p .424 .623 .935 r
F P
0 g
s
.30261 .31335 m .31729 .32959 L .32497 .32749 L p .491 .592 .882 r
F P
0 g
s
.33871 .34461 m .32497 .32749 L .31729 .32959 L p .476 .581 .88 r
F P
0 g
s
.32497 .32749 m .33871 .34461 L .34604 .3436 L p .477 .577 .877 r
F P
0 g
s
.5242 .49702 m .50803 .4943 L .51092 .49868 L p .367 .521 .878 r
F P
0 g
s
.51092 .49868 m .52781 .50245 L .5242 .49702 L p .367 .521 .878 r
F P
0 g
s
.23857 .27858 m .25502 .29206 L .26354 .28676 L p .527 .635 .9 r
F P
0 g
s
.2792 .30149 m .26354 .28676 L .25502 .29206 L p .514 .623 .897 r
F P
0 g
s
.55531 .52459 m .53651 .51792 L .53865 .52276 L p .368 .534 .889 r
F P
0 g
s
.53865 .52276 m .55784 .53024 L .55531 .52459 L p .368 .534 .889 r
F P
0 g
s
.19592 .26126 m .2132 .27294 L .22199 .26558 L p .546 .662 .912 r
F P
0 g
s
.23857 .27858 m .22199 .26558 L .2132 .27294 L p .535 .65 .908 r
F P
0 g
s
.38341 .37987 m .37277 .36171 L .36559 .36124 L p .444 .551 .871 r
F P
0 g
s
.37277 .36171 m .38341 .37987 L .38985 .38097 L p .441 .548 .869 r
F P
0 g
s
.57959 .54375 m .55991 .53568 L .56148 .54088 L p .373 .547 .897 r
F P
0 g
s
.56148 .54088 m .58138 .54962 L .57959 .54375 L p .373 .547 .897 r
F P
0 g
s
.64402 .58769 m .62367 .57918 L .6236 .58529 L p .401 .592 .921 r
F P
0 g
s
.6236 .58529 m .64384 .59425 L .64402 .58769 L p .401 .592 .921 r
F P
0 g
s
.43714 .42858 m .43499 .41359 L .42875 .41018 L p .395 .519 .865 r
F P
0 g
s
.43499 .41359 m .43714 .42858 L .44215 .43155 L p .39 .516 .864 r
F P
0 g
s
.52024 .49148 m .50487 .48985 L .50803 .4943 L p .366 .518 .877 r
F P
0 g
s
.50803 .4943 m .5242 .49702 L .52024 .49148 L p .366 .518 .877 r
F P
0 g
s
.70491 .61755 m .6845 .61038 L .68307 .61749 L p .432 .637 .942 r
F P
0 g
s
.68307 .61749 m .70322 .62505 L .70491 .61755 L p .432 .637 .942 r
F P
0 g
s
.41063 .40224 m .40346 .38466 L .39654 .38257 L p .42 .534 .867 r
F P
0 g
s
.40346 .38466 m .41063 .40224 L .41654 .4045 L p .416 .531 .865 r
F P
0 g
s
.44215 .43155 m .4413 .41735 L .43499 .41359 L p .39 .516 .864 r
F P
0 g
s
.4413 .41735 m .44215 .43155 L .44718 .43478 L p .386 .514 .864 r
F P
0 g
s
.60141 .55804 m .58138 .54962 L .58259 .55524 L p .379 .56 .905 r
F P
0 g
s
.58259 .55524 m .60274 .56423 L .60141 .55804 L p .379 .56 .905 r
F P
0 g
s
.623 .57277 m .60274 .56423 L .60341 .57013 L p .388 .575 .913 r
F P
0 g
s
.60341 .57013 m .62367 .57918 L .623 .57277 L p .388 .575 .913 r
F P
0 g
s
.13386 .23855 m .15192 .2489 L .16094 .23988 L p .477 .712 .973 r
F P
0 g
s
.17851 .25016 m .16094 .23988 L .15192 .2489 L p .535 .691 .94 r
F P
0 g
s
.5523 .51873 m .53398 .51291 L .53651 .51792 L p .365 .531 .887 r
F P
0 g
s
.53651 .51792 m .55531 .52459 L .5523 .51873 L p .365 .531 .887 r
F P
0 g
s
.26354 .28676 m .2792 .30149 L .28782 .29748 L p .518 .62 .892 r
F P
0 g
s
.30261 .31335 m .28782 .29748 L .2792 .30149 L p .504 .608 .889 r
F P
0 g
s
.51596 .48585 m .50146 .48534 L .50487 .48985 L p .365 .516 .875 r
F P
0 g
s
.50487 .48985 m .52024 .49148 L .51596 .48585 L p .365 .516 .875 r
F P
0 g
s
.36559 .36124 m .35383 .34318 L .34604 .3436 L p .461 .564 .873 r
F P
0 g
s
.35383 .34318 m .36559 .36124 L .37277 .36171 L p .459 .56 .87 r
F P
0 g
s
.44718 .43478 m .44763 .42145 L .4413 .41735 L p .386 .514 .864 r
F P
0 g
s
.44763 .42145 m .44718 .43478 L .45221 .43823 L p .383 .511 .864 r
F P
0 g
s
.38985 .38097 m .38029 .36275 L .37277 .36171 L p .441 .548 .869 r
F P
0 g
s
.38029 .36275 m .38985 .38097 L .39654 .38257 L p .438 .544 .867 r
F P
0 g
s
.72535 .62412 m .70491 .61755 L .70322 .62505 L p .44 .65 .948 r
F P
0 g
s
.70322 .62505 m .72339 .63203 L .72535 .62412 L p .44 .65 .948 r
F P
0 g
s
.51139 .48015 m .49782 .4808 L .50146 .48534 L p .365 .514 .873 r
F P
0 g
s
.50146 .48534 m .51596 .48585 L .51139 .48015 L p .365 .514 .873 r
F P
0 g
s
.66446 .59563 m .64402 .58769 L .64384 .59425 L p .407 .605 .929 r
F P
0 g
s
.64384 .59425 m .66415 .60262 L .66446 .59563 L p .407 .605 .929 r
F P
0 g
s
.57723 .53761 m .55784 .53024 L .55991 .53568 L p .368 .543 .896 r
F P
0 g
s
.55991 .53568 m .57959 .54375 L .57723 .53761 L p .368 .543 .896 r
F P
0 g
s
.28782 .29748 m .30261 .31335 L .31113 .31063 L p .506 .604 .885 r
F P
0 g
s
.32497 .32749 m .31113 .31063 L .30261 .31335 L p .491 .592 .882 r
F P
0 g
s
.22199 .26558 m .23857 .27858 L .24775 .27249 L p .54 .647 .904 r
F P
0 g
s
.26354 .28676 m .24775 .27249 L .23857 .27858 L p .527 .635 .9 r
F P
0 g
s
.41654 .4045 m .41057 .38727 L .40346 .38466 L p .416 .531 .865 r
F P
0 g
s
.41057 .38727 m .41654 .4045 L .42259 .40715 L p .411 .527 .864 r
F P
0 g
s
.17851 .25016 m .19592 .26126 L .20528 .25307 L p .558 .675 .916 r
F P
0 g
s
.22199 .26558 m .20528 .25307 L .19592 .26126 L p .546 .662 .912 r
F P
0 g
s
.45221 .43823 m .45396 .42587 L .44763 .42145 L p .383 .511 .864 r
F P
0 g
s
.45396 .42587 m .45221 .43823 L .45722 .44191 L p .379 .509 .863 r
F P
0 g
s
.34604 .3436 m .33321 .32599 L .32497 .32749 L p .477 .577 .877 r
F P
0 g
s
.33321 .32599 m .34604 .3436 L .35383 .34318 L p .477 .574 .874 r
F P
0 g
s
.50653 .47441 m .49395 .47624 L .49782 .4808 L p .364 .512 .872 r
F P
0 g
s
.49782 .4808 m .51139 .48015 L .50653 .47441 L p .364 .512 .872 r
F P
0 g
s
.31113 .31063 m .32497 .32749 L .33321 .32599 L p .493 .589 .879 r
F P
0 g
s
.54883 .51266 m .53108 .50775 L .53398 .51291 L p .362 .528 .886 r
F P
0 g
s
.53398 .51291 m .5523 .51873 L .54883 .51266 L p .362 .528 .886 r
F P
0 g
s
.45722 .44191 m .46027 .43057 L .45396 .42587 L p .379 .509 .863 r
F P
0 g
s
.46027 .43057 m .45722 .44191 L .46219 .44577 L p .376 .508 .863 r
F P
0 g
s
.74581 .6301 m .72535 .62412 L .72339 .63203 L p .45 .663 .953 r
F P
0 g
s
.72339 .63203 m .74356 .63849 L .74581 .6301 L p .45 .663 .953 r
F P
0 g
s
.5014 .46865 m .48988 .47169 L .49395 .47624 L p .365 .51 .87 r
F P
0 g
s
.49395 .47624 m .50653 .47441 L .5014 .46865 L p .365 .51 .87 r
F P
0 g
s
.46219 .44577 m .46653 .43552 L .46027 .43057 L p .376 .508 .863 r
F P
0 g
s
.46653 .43552 m .46219 .44577 L .46709 .4498 L p .373 .507 .864 r
F P
0 g
s
.49604 .4629 m .48562 .46716 L .48988 .47169 L p .365 .508 .868 r
F P
0 g
s
.48988 .47169 m .5014 .46865 L .49604 .4629 L p .365 .508 .868 r
F P
0 g
s
.11579 .2272 m .13386 .23855 L .14313 .23121 L p .089 .609 .881 r
F P
0 g
s
.16094 .23988 m .14313 .23121 L .13386 .23855 L p .477 .712 .973 r
F P
0 g
s
.46709 .4498 m .47271 .4407 L .46653 .43552 L p .373 .507 .864 r
F P
0 g
s
.47271 .4407 m .46709 .4498 L .47191 .45398 L p .37 .506 .864 r
F P
0 g
s
.42259 .40715 m .41786 .39038 L .41057 .38727 L p .411 .527 .864 r
F P
0 g
s
.41786 .39038 m .42259 .40715 L .42875 .41018 L p .406 .523 .863 r
F P
0 g
s
.49047 .45719 m .48119 .46268 L .48562 .46716 L p .366 .507 .867 r
F P
0 g
s
.48562 .46716 m .49604 .4629 L .49047 .45719 L p .366 .507 .867 r
F P
0 g
s
.59943 .55157 m .57959 .54375 L .58138 .54962 L p .371 .556 .904 r
F P
0 g
s
.58138 .54962 m .60141 .55804 L .59943 .55157 L p .371 .556 .904 r
F P
0 g
s
.64338 .58083 m .623 .57277 L .62367 .57918 L p .392 .588 .921 r
F P
0 g
s
.62367 .57918 m .64402 .58769 L .64338 .58083 L p .392 .588 .921 r
F P
0 g
s
.47191 .45398 m .47877 .44606 L .47271 .4407 L p .37 .506 .864 r
F P
0 g
s
.47877 .44606 m .47191 .45398 L .47661 .45828 L p .369 .506 .865 r
F P
0 g
s
.4847 .45157 m .47661 .45828 L .48119 .46268 L p .367 .506 .866 r
F P
0 g
s
.48119 .46268 m .49047 .45719 L .4847 .45157 L p .367 .506 .866 r
F P
0 g
s
.39654 .38257 m .38811 .36439 L .38029 .36275 L p .438 .544 .867 r
F P
0 g
s
.38811 .36439 m .39654 .38257 L .40346 .38466 L p .433 .539 .865 r
F P
0 g
s
.47661 .45828 m .4847 .45157 L .47877 .44606 L p .369 .506 .865 r
F P
0 g
s
.37277 .36171 m .36204 .34339 L .35383 .34318 L p .459 .56 .87 r
F P
0 g
s
.36204 .34339 m .37277 .36171 L .38029 .36275 L p .457 .556 .868 r
F P
0 g
s
.68497 .603 m .66446 .59563 L .66415 .60262 L p .413 .619 .936 r
F P
0 g
s
.66415 .60262 m .6845 .61038 L .68497 .603 L p .413 .619 .936 r
F P
0 g
s
.7663 .63548 m .74581 .6301 L .74356 .63849 L p .463 .672 .954 r
F P
0 g
s
.74356 .63849 m .76376 .64456 L .7663 .63548 L p .463 .672 .954 r
F P
0 g
s
.24775 .27249 m .26354 .28676 L .27291 .28199 L p .531 .632 .896 r
F P
0 g
s
.28782 .29748 m .27291 .28199 L .26354 .28676 L p .518 .62 .892 r
F P
0 g
s
.54492 .50641 m .52781 .50245 L .53108 .50775 L p .36 .524 .884 r
F P
0 g
s
.53108 .50775 m .54883 .51266 L .54492 .50641 L p .36 .524 .884 r
F P
0 g
s
.57431 .53122 m .55531 .52459 L .55784 .53024 L p .363 .539 .895 r
F P
0 g
s
.55784 .53024 m .57723 .53761 L .57431 .53122 L p .363 .539 .895 r
F P
0 g
s
.6216 .56608 m .60141 .55804 L .60274 .56423 L p .38 .571 .913 r
F P
0 g
s
.60274 .56423 m .623 .57277 L .6216 .56608 L p .38 .571 .913 r
F P
0 g
s
.42875 .41018 m .42529 .39399 L .41786 .39038 L p .406 .523 .863 r
F P
0 g
s
.42529 .39399 m .42875 .41018 L .43499 .41359 L p .4 .518 .862 r
F P
0 g
s
.16094 .23988 m .17851 .25016 L .18843 .2411 L p .574 .692 .921 r
F P
0 g
s
.20528 .25307 m .18843 .2411 L .17851 .25016 L p .558 .675 .916 r
F P
0 g
s
.7868 .64014 m .7663 .63548 L .76376 .64456 L p .487 .67 .945 r
F P
0 g
s
.76376 .64456 m .78399 .65061 L .7868 .64014 L p .487 .67 .945 r
F P
0 g
s
.20528 .25307 m .22199 .26558 L .23184 .25866 L p .552 .658 .906 r
F P
0 g
s
.24775 .27249 m .23184 .25866 L .22199 .26558 L p .54 .647 .904 r
F P
0 g
s
.35383 .34318 m .34197 .32513 L .33321 .32599 L p .477 .574 .874 r
F P
0 g
s
.34197 .32513 m .35383 .34318 L .36204 .34339 L p .476 .569 .87 r
F P
0 g
s
.27291 .28199 m .28782 .29748 L .29717 .29405 L p .521 .616 .888 r
F P
0 g
s
.31113 .31063 m .29717 .29405 L .28782 .29748 L p .506 .604 .885 r
F P
0 g
s
.54058 .49998 m .5242 .49702 L .52781 .50245 L p .358 .521 .882 r
F P
0 g
s
.52781 .50245 m .54492 .50641 L .54058 .49998 L p .358 .521 .882 r
F P
0 g
s
.14313 .23121 m .1249 .22621 L .11579 .2272 L p .089 .609 .881 r
F P
0 g
s
.40346 .38466 m .39621 .36664 L .38811 .36439 L p .433 .539 .865 r
F P
0 g
s
.39621 .36664 m .40346 .38466 L .41057 .38727 L p .428 .534 .863 r
F P
0 g
s
.33321 .32599 m .32027 .30853 L .31113 .31063 L p .493 .589 .879 r
F P
0 g
s
.32027 .30853 m .33321 .32599 L .34197 .32513 L p .493 .584 .875 r
F P
0 g
s
.29717 .29405 m .31113 .31063 L .32027 .30853 L p .508 .6 .88 r
F P
0 g
s
.70555 .60978 m .68497 .603 L .6845 .61038 L p .42 .634 .944 r
F P
0 g
s
.6845 .61038 m .70491 .61755 L .70555 .60978 L p .42 .634 .944 r
F P
0 g
s
.80726 .64375 m .7868 .64014 L .78399 .65061 L p .525 .641 .906 r
F P
0 g
s
.78399 .65061 m .80434 .65769 L .80726 .64375 L p .525 .641 .906 r
F P
0 g
s
.43499 .41359 m .43283 .3981 L .42529 .39399 L p .4 .518 .862 r
F P
0 g
s
.43283 .3981 m .43499 .41359 L .4413 .41735 L p .394 .514 .861 r
F P
0 g
s
.38029 .36275 m .37064 .34427 L .36204 .34339 L p .457 .556 .868 r
F P
0 g
s
.37064 .34427 m .38029 .36275 L .38811 .36439 L p .453 .551 .865 r
F P
0 g
s
.57083 .52459 m .5523 .51873 L .55531 .52459 L p .358 .535 .893 r
F P
0 g
s
.55531 .52459 m .57431 .53122 L .57083 .52459 L p .358 .535 .893 r
F P
0 g
s
.66387 .58837 m .64338 .58083 L .64402 .58769 L p .396 .601 .929 r
F P
0 g
s
.64402 .58769 m .66446 .59563 L .66387 .58837 L p .396 .601 .929 r
F P
0 g
s
.5968 .54482 m .57723 .53761 L .57959 .54375 L p .365 .551 .903 r
F P
0 g
s
.57959 .54375 m .59943 .55157 L .5968 .54482 L p .365 .551 .903 r
F P
0 g
s
.53583 .49339 m .52024 .49148 L .5242 .49702 L p .356 .517 .879 r
F P
0 g
s
.5242 .49702 m .54058 .49998 L .53583 .49339 L p .356 .517 .879 r
F P
0 g
s
.23184 .25866 m .24775 .27249 L .25788 .26692 L p .544 .644 .899 r
F P
0 g
s
.27291 .28199 m .25788 .26692 L .24775 .27249 L p .531 .632 .896 r
F P
0 g
s
.4413 .41735 m .44044 .40267 L .43283 .3981 L p .394 .514 .861 r
F P
0 g
s
.44044 .40267 m .4413 .41735 L .44763 .42145 L p .388 .51 .86 r
F P
0 g
s
.82759 .64541 m .80726 .64375 L .80434 .65769 L p .559 .566 .817 r
F P
0 g
s
.80434 .65769 m .82506 .66854 L .82759 .64541 L p .559 .566 .817 r
F P
0 g
s
.41057 .38727 m .40454 .36953 L .39621 .36664 L p .428 .534 .863 r
F P
0 g
s
.40454 .36953 m .41057 .38727 L .41786 .39038 L p .422 .529 .861 r
F P
0 g
s
.61944 .55909 m .59943 .55157 L .60141 .55804 L p .371 .566 .912 r
F P
0 g
s
.60141 .55804 m .6216 .56608 L .61944 .55909 L p .371 .566 .912 r
F P
0 g
s
.64191 .57368 m .6216 .56608 L .623 .57277 L p .381 .583 .921 r
F P
0 g
s
.623 .57277 m .64338 .58083 L .64191 .57368 L p .381 .583 .921 r
F P
0 g
s
.72619 .61598 m .70555 .60978 L .70491 .61755 L p .428 .648 .95 r
F P
0 g
s
.70491 .61755 m .72535 .62412 L .72619 .61598 L p .428 .648 .95 r
F P
0 g
s
.53068 .48666 m .51596 .48585 L .52024 .49148 L p .355 .514 .877 r
F P
0 g
s
.52024 .49148 m .53583 .49339 L .53068 .48666 L p .355 .514 .877 r
F P
0 g
s
.36204 .34339 m .35121 .32496 L .34197 .32513 L p .476 .569 .87 r
F P
0 g
s
.35121 .32496 m .36204 .34339 L .37064 .34427 L p .473 .564 .867 r
F P
0 g
s
.14313 .23121 m .16094 .23988 L .17141 .22987 L p .601 .722 .93 r
F P
0 g
s
.18843 .2411 m .17141 .22987 L .16094 .23988 L p .574 .692 .921 r
F P
0 g
s
.18843 .2411 m .20528 .25307 L .21579 .24525 L p .568 .67 .907 r
F P
0 g
s
.23184 .25866 m .21579 .24525 L .20528 .25307 L p .552 .658 .906 r
F P
0 g
s
.44763 .42145 m .44809 .40769 L .44044 .40267 L p .388 .51 .86 r
F P
0 g
s
.44809 .40769 m .44763 .42145 L .45396 .42587 L p .382 .507 .86 r
F P
0 g
s
.56681 .5177 m .54883 .51266 L .5523 .51873 L p .354 .53 .891 r
F P
0 g
s
.5523 .51873 m .57083 .52459 L .56681 .5177 L p .354 .53 .891 r
F P
0 g
s
.38811 .36439 m .3796 .34585 L .37064 .34427 L p .453 .551 .865 r
F P
0 g
s
.3796 .34585 m .38811 .36439 L .39621 .36664 L p .448 .545 .863 r
F P
0 g
s
.25788 .26692 m .27291 .28199 L .28309 .27782 L p .535 .628 .891 r
F P
0 g
s
.29717 .29405 m .28309 .27782 L .27291 .28199 L p .521 .616 .888 r
F P
0 g
s
.52516 .4798 m .51139 .48015 L .51596 .48585 L p .354 .51 .874 r
F P
0 g
s
.51596 .48585 m .53068 .48666 L .52516 .4798 L p .354 .51 .874 r
F P
0 g
s
.45396 .42587 m .45574 .41313 L .44809 .40769 L p .382 .507 .86 r
F P
0 g
s
.45574 .41313 m .45396 .42587 L .46027 .43057 L p .377 .504 .859 r
F P
0 g
s
.68445 .59535 m .66387 .58837 L .66446 .59563 L p .401 .615 .937 r
F P
0 g
s
.66446 .59563 m .68497 .603 L .68445 .59535 L p .401 .615 .937 r
F P
0 g
s
.34197 .32513 m .33 .30713 L .32027 .30853 L p .493 .584 .875 r
F P
0 g
s
.33 .30713 m .34197 .32513 L .35121 .32496 L p .493 .579 .87 r
F P
0 g
s
.59351 .53778 m .57431 .53122 L .57723 .53761 L p .358 .546 .902 r
F P
0 g
s
.57723 .53761 m .5968 .54482 L .59351 .53778 L p .358 .546 .902 r
F P
0 g
s
.41786 .39038 m .41308 .37306 L .40454 .36953 L p .422 .529 .861 r
F P
0 g
s
.41308 .37306 m .41786 .39038 L .42529 .39399 L p .415 .524 .86 r
F P
0 g
s
.28309 .27782 m .29717 .29405 L .30722 .29129 L p .523 .612 .883 r
F P
0 g
s
.32027 .30853 m .30722 .29129 L .29717 .29405 L p .508 .6 .88 r
F P
0 g
s
.74687 .62156 m .72619 .61598 L .72535 .62412 L p .437 .662 .956 r
F P
0 g
s
.72535 .62412 m .74581 .6301 L .74687 .62156 L p .437 .662 .956 r
F P
0 g
s
.30722 .29129 m .32027 .30853 L .33 .30713 L p .509 .595 .876 r
F P
0 g
s
.51929 .47286 m .50653 .47441 L .51139 .48015 L p .354 .507 .872 r
F P
0 g
s
.51139 .48015 m .52516 .4798 L .51929 .47286 L p .354 .507 .872 r
F P
0 g
s
.46027 .43057 m .46337 .41893 L .45574 .41313 L p .377 .504 .859 r
F P
0 g
s
.46337 .41893 m .46027 .43057 L .46653 .43552 L p .371 .501 .859 r
F P
0 g
s
.56226 .51057 m .54492 .50641 L .54883 .51266 L p .35 .526 .889 r
F P
0 g
s
.54883 .51266 m .56681 .5177 L .56226 .51057 L p .35 .526 .889 r
F P
0 g
s
.51311 .46586 m .5014 .46865 L .50653 .47441 L p .354 .504 .869 r
F P
0 g
s
.50653 .47441 m .51929 .47286 L .51311 .46586 L p .354 .504 .869 r
F P
0 g
s
.46653 .43552 m .47093 .42506 L .46337 .41893 L p .371 .501 .859 r
F P
0 g
s
.47093 .42506 m .46653 .43552 L .47271 .4407 L p .367 .499 .86 r
F P
0 g
s
.21579 .24525 m .23184 .25866 L .24271 .25226 L p .555 .655 .902 r
F P
0 g
s
.25788 .26692 m .24271 .25226 L .23184 .25866 L p .544 .644 .899 r
F P
0 g
s
.50663 .45884 m .49604 .4629 L .5014 .46865 L p .354 .502 .867 r
F P
0 g
s
.5014 .46865 m .51311 .46586 L .50663 .45884 L p .354 .502 .867 r
F P
0 g
s
.37064 .34427 m .36091 .32556 L .35121 .32496 L p .473 .564 .867 r
F P
0 g
s
.36091 .32556 m .37064 .34427 L .3796 .34585 L p .47 .559 .864 r
F P
0 g
s
.47271 .4407 m .4784 .43147 L .47093 .42506 L p .367 .499 .86 r
F P
0 g
s
.4784 .43147 m .47271 .4407 L .47877 .44606 L p .363 .498 .861 r
F P
0 g
s
.39621 .36664 m .38889 .34816 L .3796 .34585 L p .448 .545 .863 r
F P
0 g
s
.38889 .34816 m .39621 .36664 L .40454 .36953 L p .442 .539 .86 r
F P
0 g
s
.42529 .39399 m .42179 .37723 L .41308 .37306 L p .415 .524 .86 r
F P
0 g
s
.42179 .37723 m .42529 .39399 L .43283 .3981 L p .407 .518 .858 r
F P
0 g
s
.61655 .5518 m .5968 .54482 L .59943 .55157 L p .362 .56 .911 r
F P
0 g
s
.59943 .55157 m .61944 .55909 L .61655 .5518 L p .362 .56 .911 r
F P
0 g
s
.66236 .58082 m .64191 .57368 L .64338 .58083 L p .385 .596 .929 r
F P
0 g
s
.64338 .58083 m .66387 .58837 L .66236 .58082 L p .385 .596 .929 r
F P
0 g
s
.49988 .45184 m .49047 .45719 L .49604 .4629 L p .356 .5 .865 r
F P
0 g
s
.49604 .4629 m .50663 .45884 L .49988 .45184 L p .356 .5 .865 r
F P
0 g
s
.47877 .44606 m .48574 .43811 L .4784 .43147 L p .363 .498 .861 r
F P
0 g
s
.48574 .43811 m .47877 .44606 L .4847 .45157 L p .36 .498 .862 r
F P
0 g
s
.7676 .62644 m .74687 .62156 L .74581 .6301 L p .451 .677 .961 r
F P
0 g
s
.74581 .6301 m .7663 .63548 L .7676 .62644 L p .451 .677 .961 r
F P
0 g
s
.49291 .44492 m .4847 .45157 L .49047 .45719 L p .357 .499 .863 r
F P
0 g
s
.49047 .45719 m .49988 .45184 L .49291 .44492 L p .357 .499 .863 r
F P
0 g
s
.4847 .45157 m .49291 .44492 L .48574 .43811 L p .36 .498 .862 r
F P
0 g
s
.17141 .22987 m .18843 .2411 L .1996 .2322 L p .592 .679 .902 r
F P
0 g
s
.21579 .24525 m .1996 .2322 L .18843 .2411 L p .568 .67 .907 r
F P
0 g
s
.63961 .56624 m .61944 .55909 L .6216 .56608 L p .371 .577 .921 r
F P
0 g
s
.6216 .56608 m .64191 .57368 L .63961 .56624 L p .371 .577 .921 r
F P
0 g
s
.70512 .60178 m .68445 .59535 L .68497 .603 L p .407 .63 .945 r
F P
0 g
s
.68497 .603 m .70555 .60978 L .70512 .60178 L p .407 .63 .945 r
F P
0 g
s
.1249 .22621 m .14313 .23121 L .15417 .22002 L p .656 .787 .944 r
F P
0 g
s
.17141 .22987 m .15417 .22002 L .14313 .23121 L p .601 .722 .93 r
F P
0 g
s
.58957 .53046 m .57083 .52459 L .57431 .53122 L p .351 .54 .9 r
F P
0 g
s
.57431 .53122 m .59351 .53778 L .58957 .53046 L p .351 .54 .9 r
F P
0 g
s
.55719 .50321 m .54058 .49998 L .54492 .50641 L p .347 .521 .886 r
F P
0 g
s
.54492 .50641 m .56226 .51057 L .55719 .50321 L p .347 .521 .886 r
F P
0 g
s
.24271 .25226 m .25788 .26692 L .2689 .26194 L p .547 .64 .894 r
F P
0 g
s
.28309 .27782 m .2689 .26194 L .25788 .26692 L p .535 .628 .891 r
F P
0 g
s
.35121 .32496 m .34029 .30648 L .33 .30713 L p .493 .579 .87 r
F P
0 g
s
.34029 .30648 m .35121 .32496 L .36091 .32556 L p .491 .574 .866 r
F P
0 g
s
.43283 .3981 m .43063 .38203 L .42179 .37723 L p .407 .518 .858 r
F P
0 g
s
.43063 .38203 m .43283 .3981 L .44044 .40267 L p .399 .512 .857 r
F P
0 g
s
.78832 .63028 m .7676 .62644 L .7663 .63548 L p .476 .692 .962 r
F P
0 g
s
.7663 .63548 m .7868 .64014 L .78832 .63028 L p .476 .692 .962 r
F P
0 g
s
.40454 .36953 m .39845 .35125 L .38889 .34816 L p .442 .539 .86 r
F P
0 g
s
.39845 .35125 m .40454 .36953 L .41308 .37306 L p .435 .533 .858 r
F P
0 g
s
.2689 .26194 m .28309 .27782 L .29406 .2743 L p .538 .624 .885 r
F P
0 g
s
.30722 .29129 m .29406 .2743 L .28309 .27782 L p .523 .612 .883 r
F P
0 g
s
.33 .30713 m .31794 .28924 L .30722 .29129 L p .509 .595 .876 r
F P
0 g
s
.31794 .28924 m .33 .30713 L .34029 .30648 L p .509 .59 .871 r
F P
0 g
s
.3796 .34585 m .37102 .32695 L .36091 .32556 L p .47 .559 .864 r
F P
0 g
s
.37102 .32695 m .3796 .34585 L .38889 .34816 L p .465 .552 .86 r
F P
0 g
s
.29406 .2743 m .30722 .29129 L .31794 .28924 L p .525 .607 .877 r
F P
0 g
s
.55164 .49562 m .53583 .49339 L .54058 .49998 L p .344 .516 .883 r
F P
0 g
s
.54058 .49998 m .55719 .50321 L .55164 .49562 L p .344 .516 .883 r
F P
0 g
s
.44044 .40267 m .43956 .38744 L .43063 .38203 L p .399 .512 .857 r
F P
0 g
s
.43956 .38744 m .44044 .40267 L .44809 .40769 L p .391 .507 .856 r
F P
0 g
s
.80895 .6321 m .78832 .63028 L .7868 .64014 L p .529 .709 .954 r
F P
0 g
s
.7868 .64014 m .80726 .64375 L .80895 .6321 L p .529 .709 .954 r
F P
0 g
s
.72588 .60764 m .70512 .60178 L .70555 .60978 L p .414 .644 .952 r
F P
0 g
s
.70555 .60978 m .72619 .61598 L .72588 .60764 L p .414 .644 .952 r
F P
0 g
s
.1996 .2322 m .21579 .24525 L .22741 .23799 L p .567 .664 .903 r
F P
0 g
s
.24271 .25226 m .22741 .23799 L .21579 .24525 L p .555 .655 .902 r
F P
0 g
s
.61291 .54421 m .59351 .53778 L .5968 .54482 L p .353 .554 .909 r
F P
0 g
s
.5968 .54482 m .61655 .5518 L .61291 .54421 L p .353 .554 .909 r
F P
0 g
s
.68293 .58744 m .66236 .58082 L .66387 .58837 L p .389 .61 .937 r
F P
0 g
s
.66387 .58837 m .68445 .59535 L .68293 .58744 L p .389 .61 .937 r
F P
0 g
s
.58501 .52284 m .56681 .5177 L .57083 .52459 L p .345 .534 .897 r
F P
0 g
s
.57083 .52459 m .58957 .53046 L .58501 .52284 L p .345 .534 .897 r
F P
0 g
s
.54561 .48782 m .53068 .48666 L .53583 .49339 L p .342 .511 .879 r
F P
0 g
s
.53583 .49339 m .55164 .49562 L .54561 .48782 L p .342 .511 .879 r
F P
0 g
s
.15417 .22002 m .17141 .22987 L .18328 .21935 L p .635 .685 .88 r
F P
0 g
s
.1996 .2322 m .18328 .21935 L .17141 .22987 L p .592 .679 .902 r
F P
0 g
s
.82922 .62918 m .80895 .6321 L .80726 .64375 L p .622 .716 .913 r
F P
0 g
s
.80726 .64375 m .82759 .64541 L .82922 .62918 L p .622 .716 .913 r
F P
0 g
s
.44809 .40769 m .44855 .39343 L .43956 .38744 L p .391 .507 .856 r
F P
0 g
s
.44855 .39343 m .44809 .40769 L .45574 .41313 L p .382 .501 .855 r
F P
0 g
s
.41308 .37306 m .40825 .35512 L .39845 .35125 L p .435 .533 .858 r
F P
0 g
s
.40825 .35512 m .41308 .37306 L .42179 .37723 L p .426 .525 .856 r
F P
0 g
s
.63648 .5585 m .61655 .5518 L .61944 .55909 L p .36 .571 .919 r
F P
0 g
s
.61944 .55909 m .63961 .56624 L .63648 .5585 L p .36 .571 .919 r
F P
0 g
s
.65993 .57298 m .63961 .56624 L .64191 .57368 L p .372 .59 .929 r
F P
0 g
s
.64191 .57368 m .66236 .58082 L .65993 .57298 L p .372 .59 .929 r
F P
0 g
s
.36091 .32556 m .35109 .30666 L .34029 .30648 L p .491 .574 .866 r
F P
0 g
s
.35109 .30666 m .36091 .32556 L .37102 .32695 L p .488 .567 .862 r
F P
0 g
s
.22741 .23799 m .24271 .25226 L .25456 .24646 L p .557 .651 .898 r
F P
0 g
s
.2689 .26194 m .25456 .24646 L .24271 .25226 L p .547 .64 .894 r
F P
0 g
s
.38889 .34816 m .38149 .32921 L .37102 .32695 L p .465 .552 .86 r
F P
0 g
s
.38149 .32921 m .38889 .34816 L .39845 .35125 L p .458 .545 .857 r
F P
0 g
s
.53914 .47984 m .52516 .4798 L .53068 .48666 L p .34 .506 .876 r
F P
0 g
s
.53068 .48666 m .54561 .48782 L .53914 .47984 L p .34 .506 .876 r
F P
0 g
s
.45574 .41313 m .45754 .39995 L .44855 .39343 L p .382 .501 .855 r
F P
0 g
s
.45754 .39995 m .45574 .41313 L .46337 .41893 L p .374 .497 .855 r
F P
0 g
s
.15417 .22002 m .13655 .21335 L .1249 .22621 L p .656 .787 .944 r
F P
0 g
s
.74671 .61294 m .72588 .60764 L .72619 .61598 L p .421 .66 .959 r
F P
0 g
s
.72619 .61598 m .74687 .62156 L .74671 .61294 L p .421 .66 .959 r
F P
0 g
s
.57982 .51493 m .56226 .51057 L .56681 .5177 L p .339 .528 .894 r
F P
0 g
s
.56681 .5177 m .58501 .52284 L .57982 .51493 L p .339 .528 .894 r
F P
0 g
s
.34029 .30648 m .32927 .28799 L .31794 .28924 L p .509 .59 .871 r
F P
0 g
s
.32927 .28799 m .34029 .30648 L .35109 .30666 L p .508 .584 .866 r
F P
0 g
s
.42179 .37723 m .41826 .3598 L .40825 .35512 L p .426 .525 .856 r
F P
0 g
s
.41826 .3598 m .42179 .37723 L .43063 .38203 L p .416 .518 .854 r
F P
0 g
s
.25456 .24646 m .2689 .26194 L .28077 .25763 L p .551 .636 .888 r
F P
0 g
s
.29406 .2743 m .28077 .25763 L .2689 .26194 L p .538 .624 .885 r
F P
0 g
s
.46337 .41893 m .46651 .40696 L .45754 .39995 L p .374 .497 .855 r
F P
0 g
s
.46651 .40696 m .46337 .41893 L .47093 .42506 L p .366 .493 .855 r
F P
0 g
s
.53226 .47169 m .51929 .47286 L .52516 .4798 L p .34 .501 .872 r
F P
0 g
s
.52516 .4798 m .53914 .47984 L .53226 .47169 L p .34 .501 .872 r
F P
0 g
s
.60853 .5363 m .58957 .53046 L .59351 .53778 L p .344 .547 .907 r
F P
0 g
s
.59351 .53778 m .61291 .54421 L .60853 .5363 L p .344 .547 .907 r
F P
0 g
s
.70361 .59353 m .68293 .58744 L .68445 .59535 L p .394 .624 .945 r
F P
0 g
s
.68445 .59535 m .70512 .60178 L .70361 .59353 L p .394 .624 .945 r
F P
0 g
s
.31794 .28924 m .30576 .27153 L .29406 .2743 L p .525 .607 .877 r
F P
0 g
s
.30576 .27153 m .31794 .28924 L .32927 .28799 L p .526 .601 .872 r
F P
0 g
s
.28077 .25763 m .29406 .2743 L .30576 .27153 L p .54 .619 .88 r
F P
0 g
s
.18328 .21935 m .1996 .2322 L .21197 .224 L p .579 .669 .9 r
F P
0 g
s
.22741 .23799 m .21197 .224 L .1996 .2322 L p .567 .664 .903 r
F P
0 g
s
.47093 .42506 m .4754 .41437 L .46651 .40696 L p .366 .493 .855 r
F P
0 g
s
.4754 .41437 m .47093 .42506 L .4784 .43147 L p .359 .49 .855 r
F P
0 g
s
.52499 .46343 m .51311 .46586 L .51929 .47286 L p .34 .497 .869 r
F P
0 g
s
.51929 .47286 m .53226 .47169 L .52499 .46343 L p .34 .497 .869 r
F P
0 g
s
.37102 .32695 m .36235 .30774 L .35109 .30666 L p .488 .567 .862 r
F P
0 g
s
.36235 .30774 m .37102 .32695 L .38149 .32921 L p .483 .56 .858 r
F P
0 g
s
.4784 .43147 m .48419 .42214 L .4754 .41437 L p .359 .49 .855 r
F P
0 g
s
.48419 .42214 m .4784 .43147 L .48574 .43811 L p .354 .489 .856 r
F P
0 g
s
.76761 .61767 m .74671 .61294 L .74687 .62156 L p .426 .678 .968 r
F P
0 g
s
.74687 .62156 m .7676 .62644 L .76761 .61767 L p .426 .678 .968 r
F P
0 g
s
.51738 .45508 m .50663 .45884 L .51311 .46586 L p .34 .493 .866 r
F P
0 g
s
.51311 .46586 m .52499 .46343 L .51738 .45508 L p .34 .493 .866 r
F P
0 g
s
.39845 .35125 m .39229 .33238 L .38149 .32921 L p .458 .545 .857 r
F P
0 g
s
.39229 .33238 m .39845 .35125 L .40825 .35512 L p .45 .537 .854 r
F P
0 g
s
.57404 .50672 m .55719 .50321 L .56226 .51057 L p .334 .521 .891 r
F P
0 g
s
.56226 .51057 m .57982 .51493 L .57404 .50672 L p .334 .521 .891 r
F P
0 g
s
.43063 .38203 m .42841 .36528 L .41826 .3598 L p .416 .518 .854 r
F P
0 g
s
.42841 .36528 m .43063 .38203 L .43956 .38744 L p .406 .51 .852 r
F P
0 g
s
.48574 .43811 m .49282 .43017 L .48419 .42214 L p .354 .489 .856 r
F P
0 g
s
.49282 .43017 m .48574 .43811 L .49291 .44492 L p .349 .488 .858 r
F P
0 g
s
.50945 .44671 m .49988 .45184 L .50663 .45884 L p .342 .491 .862 r
F P
0 g
s
.50663 .45884 m .51738 .45508 L .50945 .44671 L p .342 .491 .862 r
F P
0 g
s
.13655 .21335 m .15417 .22002 L .16685 .20628 L p .699 .676 .824 r
F P
0 g
s
.18328 .21935 m .16685 .20628 L .15417 .22002 L p .635 .685 .88 r
F P
0 g
s
.49291 .44492 m .50125 .43838 L .49282 .43017 L p .349 .488 .858 r
F P
0 g
s
.50125 .43838 m .49291 .44492 L .49988 .45184 L p .345 .489 .86 r
F P
0 g
s
.49988 .45184 m .50945 .44671 L .50125 .43838 L p .345 .489 .86 r
F P
0 g
s
.6325 .55044 m .61291 .54421 L .61655 .5518 L p .349 .564 .918 r
F P
0 g
s
.61655 .5518 m .63648 .5585 L .6325 .55044 L p .349 .564 .918 r
F P
0 g
s
.6804 .57926 m .65993 .57298 L .66236 .58082 L p .375 .604 .937 r
F P
0 g
s
.66236 .58082 m .68293 .58744 L .6804 .57926 L p .375 .604 .937 r
F P
0 g
s
.21197 .224 m .22741 .23799 L .24009 .23138 L p .564 .661 .903 r
F P
0 g
s
.25456 .24646 m .24009 .23138 L .22741 .23799 L p .557 .651 .898 r
F P
0 g
s
.65658 .56485 m .63648 .5585 L .63961 .56624 L p .36 .583 .928 r
F P
0 g
s
.63961 .56624 m .65993 .57298 L .65658 .56485 L p .36 .583 .928 r
F P
0 g
s
.60343 .52806 m .58501 .52284 L .58957 .53046 L p .336 .54 .904 r
F P
0 g
s
.58957 .53046 m .60853 .5363 L .60343 .52806 L p .336 .54 .904 r
F P
0 g
s
.35109 .30666 m .34118 .28763 L .32927 .28799 L p .508 .584 .866 r
F P
0 g
s
.34118 .28763 m .35109 .30666 L .36235 .30774 L p .506 .577 .861 r
F P
0 g
s
.7244 .59909 m .70361 .59353 L .70512 .60178 L p .399 .639 .953 r
F P
0 g
s
.70512 .60178 m .72588 .60764 L .7244 .59909 L p .399 .639 .953 r
F P
0 g
s
.56768 .49821 m .55164 .49562 L .55719 .50321 L p .33 .514 .887 r
F P
0 g
s
.55719 .50321 m .57404 .50672 L .56768 .49821 L p .33 .514 .887 r
F P
0 g
s
.43956 .38744 m .43868 .37154 L .42841 .36528 L p .406 .51 .852 r
F P
0 g
s
.43868 .37154 m .43956 .38744 L .44855 .39343 L p .394 .503 .85 r
F P
0 g
s
.78857 .6218 m .76761 .61767 L .7676 .62644 L p .427 .705 .98 r
F P
0 g
s
.7676 .62644 m .78832 .63028 L .78857 .6218 L p .427 .705 .98 r
F P
0 g
s
.40825 .35512 m .40337 .3365 L .39229 .33238 L p .45 .537 .854 r
F P
0 g
s
.40337 .3365 m .40825 .35512 L .41826 .3598 L p .44 .528 .851 r
F P
0 g
s
.24009 .23138 m .25456 .24646 L .26736 .24131 L p .562 .648 .892 r
F P
0 g
s
.28077 .25763 m .26736 .24131 L .25456 .24646 L p .551 .636 .888 r
F P
0 g
s
.32927 .28799 m .31815 .26958 L .30576 .27153 L p .526 .601 .872 r
F P
0 g
s
.31815 .26958 m .32927 .28799 L .34118 .28763 L p .526 .595 .866 r
F P
0 g
s
.38149 .32921 m .37403 .30979 L .36235 .30774 L p .483 .56 .858 r
F P
0 g
s
.37403 .30979 m .38149 .32921 L .39229 .33238 L p .476 .552 .854 r
F P
0 g
s
.16685 .20628 m .18328 .21935 L .1964 .21001 L p .595 .662 .885 r
F P
0 g
s
.21197 .224 m .1964 .21001 L .18328 .21935 L p .579 .669 .9 r
F P
0 g
s
.26736 .24131 m .28077 .25763 L .29346 .25406 L p .554 .631 .882 r
F P
0 g
s
.30576 .27153 m .29346 .25406 L .28077 .25763 L p .54 .619 .88 r
F P
0 g
s
.29346 .25406 m .30576 .27153 L .31815 .26958 L p .542 .613 .873 r
F P
0 g
s
.44855 .39343 m .44902 .37855 L .43868 .37154 L p .394 .503 .85 r
F P
0 g
s
.44902 .37855 m .44855 .39343 L .45754 .39995 L p .383 .495 .849 r
F P
0 g
s
.56078 .48941 m .54561 .48782 L .55164 .49562 L p .327 .507 .882 r
F P
0 g
s
.55164 .49562 m .56768 .49821 L .56078 .48941 L p .327 .507 .882 r
F P
0 g
s
.80957 .62518 m .78857 .6218 L .78832 .63028 L p .406 .755 .994 r
F P
0 g
s
.78832 .63028 m .80895 .6321 L .80957 .62518 L p .406 .755 .994 r
F P
0 g
s
.6277 .54205 m .60853 .5363 L .61291 .54421 L p .338 .556 .915 r
F P
0 g
s
.61291 .54421 m .6325 .55044 L .6277 .54205 L p .338 .556 .915 r
F P
0 g
s
.59763 .51948 m .57982 .51493 L .58501 .52284 L p .328 .532 .901 r
F P
0 g
s
.58501 .52284 m .60343 .52806 L .59763 .51948 L p .328 .532 .901 r
F P
0 g
s
.701 .58504 m .6804 .57926 L .68293 .58744 L p .379 .618 .945 r
F P
0 g
s
.68293 .58744 m .70361 .59353 L .701 .58504 L p .379 .618 .945 r
F P
0 g
s
.41826 .3598 m .41468 .34161 L .40337 .3365 L p .44 .528 .851 r
F P
0 g
s
.41468 .34161 m .41826 .3598 L .42841 .36528 L p .428 .519 .849 r
F P
0 g
s
.74529 .60413 m .7244 .59909 L .72588 .60764 L p .405 .654 .96 r
F P
0 g
s
.72588 .60764 m .74671 .61294 L .74529 .60413 L p .405 .654 .96 r
F P
0 g
s
.45754 .39995 m .45937 .38625 L .44902 .37855 L p .383 .495 .849 r
F P
0 g
s
.45937 .38625 m .45754 .39995 L .46651 .40696 L p .371 .489 .849 r
F P
0 g
s
.36235 .30774 m .3536 .28825 L .34118 .28763 L p .506 .577 .861 r
F P
0 g
s
.3536 .28825 m .36235 .30774 L .37403 .30979 L p .502 .569 .856 r
F P
0 g
s
.83055 .62726 m .80957 .62518 L .80895 .6321 L p .229 .749 .819 r
F P
0 g
s
.80895 .6321 m .82922 .62918 L .83055 .62726 L p .229 .749 .819 r
F P
0 g
s
.55335 .48034 m .53914 .47984 L .54561 .48782 L p .324 .501 .878 r
F P
0 g
s
.54561 .48782 m .56078 .48941 L .55335 .48034 L p .324 .501 .878 r
F P
0 g
s
.16685 .20628 m .15037 .19199 L .13655 .21335 L p .699 .676 .824 r
F P
0 g
s
.1964 .21001 m .21197 .224 L .22547 .21671 L p .559 .668 .91 r
F P
0 g
s
.24009 .23138 m .22547 .21671 L .21197 .224 L p .564 .661 .903 r
F P
0 g
s
.39229 .33238 m .38608 .3129 L .37403 .30979 L p .476 .552 .854 r
F P
0 g
s
.38608 .3129 m .39229 .33238 L .40337 .3365 L p .468 .543 .85 r
F P
0 g
s
.65229 .55641 m .6325 .55044 L .63648 .5585 L p .346 .575 .926 r
F P
0 g
s
.63648 .5585 m .65658 .56485 L .65229 .55641 L p .346 .575 .926 r
F P
0 g
s
.67685 .5708 m .65658 .56485 L .65993 .57298 L p .361 .596 .936 r
F P
0 g
s
.65993 .57298 m .6804 .57926 L .67685 .5708 L p .361 .596 .936 r
F P
0 g
s
.46651 .40696 m .46969 .39457 L .45937 .38625 L p .371 .489 .849 r
F P
0 g
s
.46969 .39457 m .46651 .40696 L .4754 .41437 L p .36 .483 .848 r
F P
0 g
s
.54544 .471 m .53226 .47169 L .53914 .47984 L p .322 .494 .873 r
F P
0 g
s
.53914 .47984 m .55335 .48034 L .54544 .471 L p .322 .494 .873 r
F P
0 g
s
.34118 .28763 m .33117 .26856 L .31815 .26958 L p .526 .595 .866 r
F P
0 g
s
.33117 .26856 m .34118 .28763 L .3536 .28825 L p .524 .588 .86 r
F P
0 g
s
.42841 .36528 m .42617 .34772 L .41468 .34161 L p .428 .519 .849 r
F P
0 g
s
.42617 .34772 m .42841 .36528 L .43868 .37154 L p .415 .509 .846 r
F P
0 g
s
.15037 .19199 m .16685 .20628 L .18075 .19515 L p .616 .63 .842 r
F P
0 g
s
.1964 .21001 m .18075 .19515 L .16685 .20628 L p .595 .662 .885 r
F P
0 g
s
.59113 .51053 m .57404 .50672 L .57982 .51493 L p .32 .523 .896 r
F P
0 g
s
.57982 .51493 m .59763 .51948 L .59113 .51053 L p .32 .523 .896 r
F P
0 g
s
.22547 .21671 m .24009 .23138 L .2538 .2254 L p .57 .66 .898 r
F P
0 g
s
.26736 .24131 m .2538 .2254 L .24009 .23138 L p .562 .648 .892 r
F P
0 g
s
.4754 .41437 m .47994 .40342 L .46969 .39457 L p .36 .483 .848 r
F P
0 g
s
.47994 .40342 m .4754 .41437 L .48419 .42214 L p .35 .479 .849 r
F P
0 g
s
.53708 .46144 m .52499 .46343 L .53226 .47169 L p .322 .488 .868 r
F P
0 g
s
.53226 .47169 m .54544 .471 L .53708 .46144 L p .322 .488 .868 r
F P
0 g
s
.31815 .26958 m .30691 .25131 L .29346 .25406 L p .542 .613 .873 r
F P
0 g
s
.30691 .25131 m .31815 .26958 L .33117 .26856 L p .543 .607 .867 r
F P
0 g
s
.76629 .60876 m .74529 .60413 L .74671 .61294 L p .406 .669 .968 r
F P
0 g
s
.74671 .61294 m .76761 .61767 L .76629 .60876 L p .406 .669 .968 r
F P
0 g
s
.62209 .5333 m .60343 .52806 L .60853 .5363 L p .327 .547 .912 r
F P
0 g
s
.60853 .5363 m .6277 .54205 L .62209 .5333 L p .327 .547 .912 r
F P
0 g
s
.2538 .2254 m .26736 .24131 L .28104 .23687 L p .568 .644 .885 r
F P
0 g
s
.29346 .25406 m .28104 .23687 L .26736 .24131 L p .554 .631 .882 r
F P
0 g
s
.48419 .42214 m .49006 .4127 L .47994 .40342 L p .35 .479 .849 r
F P
0 g
s
.49006 .4127 m .48419 .42214 L .49282 .43017 L p .342 .476 .85 r
F P
0 g
s
.28104 .23687 m .29346 .25406 L .30691 .25131 L p .557 .625 .875 r
F P
0 g
s
.37403 .30979 m .3665 .28994 L .3536 .28825 L p .502 .569 .856 r
F P
0 g
s
.3665 .28994 m .37403 .30979 L .38608 .3129 L p .496 .56 .851 r
F P
0 g
s
.72173 .59029 m .701 .58504 L .70361 .59353 L p .384 .633 .953 r
F P
0 g
s
.70361 .59353 m .7244 .59909 L .72173 .59029 L p .384 .633 .953 r
F P
0 g
s
.52831 .45172 m .51738 .45508 L .52499 .46343 L p .323 .483 .864 r
F P
0 g
s
.52499 .46343 m .53708 .46144 L .52831 .45172 L p .323 .483 .864 r
F P
0 g
s
.40337 .3365 m .39844 .31714 L .38608 .3129 L p .468 .543 .85 r
F P
0 g
s
.39844 .31714 m .40337 .3365 L .41468 .34161 L p .456 .532 .847 r
F P
0 g
s
.49282 .43017 m .50001 .42227 L .49006 .4127 L p .342 .476 .85 r
F P
0 g
s
.50001 .42227 m .49282 .43017 L .50125 .43838 L p .334 .476 .853 r
F P
0 g
s
.51918 .44189 m .50945 .44671 L .51738 .45508 L p .325 .479 .859 r
F P
0 g
s
.51738 .45508 m .52831 .45172 L .51918 .44189 L p .325 .479 .859 r
F P
0 g
s
.50125 .43838 m .50973 .43204 L .50001 .42227 L p .334 .476 .853 r
F P
0 g
s
.50973 .43204 m .50125 .43838 L .50945 .44671 L p .329 .476 .856 r
F P
0 g
s
.43868 .37154 m .43779 .35484 L .42617 .34772 L p .415 .509 .846 r
F P
0 g
s
.43779 .35484 m .43868 .37154 L .44902 .37855 L p .4 .499 .844 r
F P
0 g
s
.50945 .44671 m .51918 .44189 L .50973 .43204 L p .329 .476 .856 r
F P
0 g
s
.58398 .5012 m .56768 .49821 L .57404 .50672 L p .314 .514 .891 r
F P
0 g
s
.57404 .50672 m .59113 .51053 L .58398 .5012 L p .314 .514 .891 r
F P
0 g
s
.18075 .19515 m .1964 .21001 L .2107 .20243 L p .524 .663 .924 r
F P
0 g
s
.22547 .21671 m .2107 .20243 L .1964 .21001 L p .559 .668 .91 r
F P
0 g
s
.64709 .54763 m .6277 .54205 L .6325 .55044 L p .332 .566 .923 r
F P
0 g
s
.6325 .55044 m .65229 .55641 L .64709 .54763 L p .332 .566 .923 r
F P
0 g
s
.3536 .28825 m .34477 .26856 L .33117 .26856 L p .524 .588 .86 r
F P
0 g
s
.34477 .26856 m .3536 .28825 L .3665 .28994 L p .521 .579 .854 r
F P
0 g
s
.69728 .57629 m .67685 .5708 L .6804 .57926 L p .363 .611 .944 r
F P
0 g
s
.6804 .57926 m .701 .58504 L .69728 .57629 L p .363 .611 .944 r
F P
0 g
s
.78741 .6133 m .76629 .60876 L .76761 .61767 L p .391 .686 .978 r
F P
0 g
s
.76761 .61767 m .78857 .6218 L .78741 .6133 L p .391 .686 .978 r
F P
0 g
s
.18075 .19515 m .1652 .17721 L .15037 .19199 L p .616 .63 .842 r
F P
0 g
s
.44902 .37855 m .44949 .36292 L .43779 .35484 L p .4 .499 .844 r
F P
0 g
s
.44949 .36292 m .44902 .37855 L .45937 .38625 L p .384 .489 .842 r
F P
0 g
s
.67228 .56204 m .65229 .55641 L .65658 .56485 L p .345 .588 .935 r
F P
0 g
s
.65658 .56485 m .67685 .5708 L .67228 .56204 L p .345 .588 .935 r
F P
0 g
s
.41468 .34161 m .41107 .32257 L .39844 .31714 L p .456 .532 .847 r
F P
0 g
s
.41107 .32257 m .41468 .34161 L .42617 .34772 L p .443 .521 .843 r
F P
0 g
s
.61567 .52416 m .59763 .51948 L .60343 .52806 L p .316 .537 .908 r
F P
0 g
s
.60343 .52806 m .62209 .5333 L .61567 .52416 L p .316 .537 .908 r
F P
0 g
s
.38608 .3129 m .37981 .29282 L .3665 .28994 L p .496 .56 .851 r
F P
0 g
s
.37981 .29282 m .38608 .3129 L .39844 .31714 L p .487 .55 .846 r
F P
0 g
s
.57618 .49149 m .56078 .48941 L .56768 .49821 L p .308 .504 .886 r
F P
0 g
s
.56768 .49821 m .58398 .5012 L .57618 .49149 L p .308 .504 .886 r
F P
0 g
s
.33117 .26856 m .32106 .24951 L .30691 .25131 L p .543 .607 .867 r
F P
0 g
s
.32106 .24951 m .33117 .26856 L .34477 .26856 L p .542 .599 .86 r
F P
0 g
s
.2107 .20243 m .22547 .21671 L .2401 .21001 L p .568 .674 .91 r
F P
0 g
s
.2538 .2254 m .2401 .21001 L .22547 .21671 L p .57 .66 .898 r
F P
0 g
s
.74259 .59503 m .72173 .59029 L .7244 .59909 L p .39 .647 .959 r
F P
0 g
s
.7244 .59909 m .74529 .60413 L .74259 .59503 L p .39 .647 .959 r
F P
0 g
s
.45937 .38625 m .46122 .37191 L .44949 .36292 L p .384 .489 .842 r
F P
0 g
s
.46122 .37191 m .45937 .38625 L .46969 .39457 L p .368 .479 .841 r
F P
0 g
s
.30691 .25131 m .29556 .23325 L .28104 .23687 L p .557 .625 .875 r
F P
0 g
s
.29556 .23325 m .30691 .25131 L .32106 .24951 L p .559 .619 .868 r
F P
0 g
s
.2401 .21001 m .2538 .2254 L .26849 .22004 L p .582 .658 .889 r
F P
0 g
s
.28104 .23687 m .26849 .22004 L .2538 .2254 L p .568 .644 .885 r
F P
0 g
s
.26849 .22004 m .28104 .23687 L .29556 .23325 L p .573 .638 .877 r
F P
0 g
s
.80872 .61863 m .78741 .6133 L .78857 .6218 L p .315 .698 .979 r
F P
0 g
s
.78857 .6218 m .80957 .62518 L .80872 .61863 L p .315 .698 .979 r
F P
0 g
s
.56779 .48138 m .55335 .48034 L .56078 .48941 L p .304 .495 .88 r
F P
0 g
s
.56078 .48941 m .57618 .49149 L .56779 .48138 L p .304 .495 .88 r
F P
0 g
s
.42617 .34772 m .4239 .32925 L .41107 .32257 L p .443 .521 .843 r
F P
0 g
s
.4239 .32925 m .42617 .34772 L .43779 .35484 L p .427 .508 .84 r
F P
0 g
s
.3665 .28994 m .35889 .26972 L .34477 .26856 L p .521 .579 .854 r
F P
0 g
s
.35889 .26972 m .3665 .28994 L .37981 .29282 L p .516 .57 .848 r
F P
0 g
s
.1652 .17721 m .18075 .19515 L .19576 .18846 L p .378 .608 .939 r
F P
0 g
s
.2107 .20243 m .19576 .18846 L .18075 .19515 L p .524 .663 .924 r
F P
0 g
s
.46969 .39457 m .47292 .3817 L .46122 .37191 L p .368 .479 .841 r
F P
0 g
s
.47292 .3817 m .46969 .39457 L .47994 .40342 L p .353 .471 .841 r
F P
0 g
s
.64097 .53848 m .62209 .5333 L .6277 .54205 L p .318 .555 .92 r
F P
0 g
s
.6277 .54205 m .64709 .54763 L .64097 .53848 L p .318 .555 .92 r
F P
0 g
s
.60847 .51461 m .59113 .51053 L .59763 .51948 L p .305 .526 .903 r
F P
0 g
s
.59763 .51948 m .61567 .52416 L .60847 .51461 L p .305 .526 .903 r
F P
0 g
s
.39844 .31714 m .39347 .297 L .37981 .29282 L p .487 .55 .846 r
F P
0 g
s
.39347 .297 m .39844 .31714 L .41107 .32257 L p .476 .538 .841 r
F P
0 g
s
.71786 .58127 m .69728 .57629 L .701 .58504 L p .368 .625 .952 r
F P
0 g
s
.701 .58504 m .72173 .59029 L .71786 .58127 L p .368 .625 .952 r
F P
0 g
s
.55884 .47089 m .54544 .471 L .55335 .48034 L p .301 .486 .874 r
F P
0 g
s
.55335 .48034 m .56779 .48138 L .55884 .47089 L p .301 .486 .874 r
F P
0 g
s
.47994 .40342 m .48454 .39217 L .47292 .3817 L p .353 .471 .841 r
F P
0 g
s
.48454 .39217 m .47994 .40342 L .49006 .4127 L p .339 .465 .841 r
F P
0 g
s
.76357 .59931 m .74259 .59503 L .74529 .60413 L p .396 .658 .964 r
F P
0 g
s
.74529 .60413 m .76629 .60876 L .76357 .59931 L p .396 .658 .964 r
F P
0 g
s
.34477 .26856 m .33585 .24877 L .32106 .24951 L p .542 .599 .86 r
F P
0 g
s
.33585 .24877 m .34477 .26856 L .35889 .26972 L p .541 .591 .853 r
F P
0 g
s
.83044 .62703 m .80872 .61863 L .80957 .62518 L p 0 .53 .72 r
F P
0 g
s
.80957 .62518 m .83055 .62726 L .83044 .62703 L p 0 .53 .72 r
F P
0 g
s
.66669 .55297 m .64709 .54763 L .65229 .55641 L p .328 .578 .932 r
F P
0 g
s
.65229 .55641 m .67228 .56204 L .66669 .55297 L p .328 .578 .932 r
F P
0 g
s
.43779 .35484 m .43689 .33719 L .4239 .32925 L p .427 .508 .84 r
F P
0 g
s
.43689 .33719 m .43779 .35484 L .44949 .36292 L p .408 .495 .837 r
F P
0 g
s
.69244 .56728 m .67228 .56204 L .67685 .5708 L p .346 .602 .943 r
F P
0 g
s
.67685 .5708 m .69728 .57629 L .69244 .56728 L p .346 .602 .943 r
F P
0 g
s
.54937 .46005 m .53708 .46144 L .54544 .471 L p .3 .478 .867 r
F P
0 g
s
.54544 .471 m .55884 .47089 L .54937 .46005 L p .3 .478 .867 r
F P
0 g
s
.49006 .4127 m .49602 .40316 L .48454 .39217 L p .339 .465 .841 r
F P
0 g
s
.49602 .40316 m .49006 .4127 L .50001 .42227 L p .326 .461 .843 r
F P
0 g
s
.19576 .18846 m .2107 .20243 L .22621 .19541 L p .536 .69 .939 r
F P
0 g
s
.2401 .21001 m .22621 .19541 L .2107 .20243 L p .568 .674 .91 r
F P
0 g
s
.32106 .24951 m .31085 .23058 L .29556 .23325 L p .559 .619 .868 r
F P
0 g
s
.31085 .23058 m .32106 .24951 L .33585 .24877 L p .559 .611 .861 r
F P
0 g
s
.53943 .44889 m .52831 .45172 L .53708 .46144 L p .3 .47 .861 r
F P
0 g
s
.53708 .46144 m .54937 .46005 L .53943 .44889 L p .3 .47 .861 r
F P
0 g
s
.50001 .42227 m .50731 .41448 L .49602 .40316 L p .326 .461 .843 r
F P
0 g
s
.50731 .41448 m .50001 .42227 L .50973 .43204 L p .316 .46 .846 r
F P
0 g
s
.37981 .29282 m .37347 .27217 L .35889 .26972 L p .516 .57 .848 r
F P
0 g
s
.37347 .27217 m .37981 .29282 L .39347 .297 L p .509 .558 .842 r
F P
0 g
s
.60052 .5046 m .58398 .5012 L .59113 .51053 L p .296 .514 .897 r
F P
0 g
s
.59113 .51053 m .60847 .51461 L .60052 .5046 L p .296 .514 .897 r
F P
0 g
s
.19576 .18846 m .18068 .17455 L .1652 .17721 L p .378 .608 .939 r
F P
0 g
s
.41107 .32257 m .40742 .30259 L .39347 .297 L p .476 .538 .841 r
F P
0 g
s
.40742 .30259 m .41107 .32257 L .4239 .32925 L p .461 .524 .837 r
F P
0 g
s
.52907 .4375 m .51918 .44189 L .52831 .45172 L p .303 .465 .855 r
F P
0 g
s
.52831 .45172 m .53943 .44889 L .52907 .4375 L p .303 .465 .855 r
F P
0 g
s
.50973 .43204 m .51835 .42599 L .50731 .41448 L p .316 .46 .846 r
F P
0 g
s
.51835 .42599 m .50973 .43204 L .51918 .44189 L p .309 .461 .85 r
F P
0 g
s
.29556 .23325 m .28409 .21544 L .26849 .22004 L p .573 .638 .877 r
F P
0 g
s
.28409 .21544 m .29556 .23325 L .31085 .23058 L p .574 .631 .87 r
F P
0 g
s
.51918 .44189 m .52907 .4375 L .51835 .42599 L p .309 .461 .85 r
F P
0 g
s
.22621 .19541 m .2401 .21001 L .25579 .20363 L p .6 .675 .893 r
F P
0 g
s
.26849 .22004 m .25579 .20363 L .2401 .21001 L p .582 .658 .889 r
F P
0 g
s
.25579 .20363 m .26849 .22004 L .28409 .21544 L p .59 .651 .879 r
F P
0 g
s
.44949 .36292 m .44997 .34639 L .43689 .33719 L p .408 .495 .837 r
F P
0 g
s
.44997 .34639 m .44949 .36292 L .46122 .37191 L p .387 .482 .834 r
F P
0 g
s
.63396 .52893 m .61567 .52416 L .62209 .5333 L p .304 .543 .916 r
F P
0 g
s
.62209 .5333 m .64097 .53848 L .63396 .52893 L p .304 .543 .916 r
F P
0 g
s
.78469 .60333 m .76357 .59931 L .76629 .60876 L p .398 .661 .965 r
F P
0 g
s
.76629 .60876 m .78741 .6133 L .78469 .60333 L p .398 .661 .965 r
F P
0 g
s
.73859 .5857 m .71786 .58127 L .72173 .59029 L p .375 .64 .959 r
F P
0 g
s
.72173 .59029 m .74259 .59503 L .73859 .5857 L p .375 .64 .959 r
F P
0 g
s
.35889 .26972 m .35121 .24923 L .33585 .24877 L p .541 .591 .853 r
F P
0 g
s
.35121 .24923 m .35889 .26972 L .37347 .27217 L p .537 .581 .846 r
F P
0 g
s
.59185 .49409 m .57618 .49149 L .58398 .5012 L p .287 .502 .89 r
F P
0 g
s
.58398 .5012 m .60052 .5046 L .59185 .49409 L p .287 .502 .89 r
F P
0 g
s
.4239 .32925 m .42161 .3097 L .40742 .30259 L p .461 .524 .837 r
F P
0 g
s
.42161 .3097 m .4239 .32925 L .43689 .33719 L p .442 .509 .832 r
F P
0 g
s
.46122 .37191 m .46309 .35678 L .44997 .34639 L p .387 .482 .834 r
F P
0 g
s
.46309 .35678 m .46122 .37191 L .47292 .3817 L p .366 .468 .832 r
F P
0 g
s
.39347 .297 m .38844 .27608 L .37347 .27217 L p .509 .558 .842 r
F P
0 g
s
.38844 .27608 m .39347 .297 L .40742 .30259 L p .498 .545 .836 r
F P
0 g
s
.66009 .54354 m .64097 .53848 L .64709 .54763 L p .311 .566 .929 r
F P
0 g
s
.64709 .54763 m .66669 .55297 L .66009 .54354 L p .311 .566 .929 r
F P
0 g
s
.33585 .24877 m .32684 .22899 L .31085 .23058 L p .559 .611 .861 r
F P
0 g
s
.32684 .22899 m .33585 .24877 L .35121 .24923 L p .56 .603 .853 r
F P
0 g
s
.71278 .57205 m .69244 .56728 L .69728 .57629 L p .348 .617 .951 r
F P
0 g
s
.69728 .57629 m .71786 .58127 L .71278 .57205 L p .348 .617 .951 r
F P
0 g
s
.18068 .17455 m .19576 .18846 L .21209 .18238 L p .333 .677 .978 r
F P
0 g
s
.22621 .19541 m .21209 .18238 L .19576 .18846 L p .536 .69 .939 r
F P
0 g
s
.68649 .55799 m .66669 .55297 L .67228 .56204 L p .326 .591 .941 r
F P
0 g
s
.67228 .56204 m .69244 .56728 L .68649 .55799 L p .326 .591 .941 r
F P
0 g
s
.62607 .51891 m .60847 .51461 L .61567 .52416 L p .289 .53 .91 r
F P
0 g
s
.61567 .52416 m .63396 .52893 L .62607 .51891 L p .289 .53 .91 r
F P
0 g
s
.58249 .48307 m .56779 .48138 L .57618 .49149 L p .28 .489 .883 r
F P
0 g
s
.57618 .49149 m .59185 .49409 L .58249 .48307 L p .28 .489 .883 r
F P
0 g
s
.47292 .3817 m .47619 .36823 L .46309 .35678 L p .366 .468 .832 r
F P
0 g
s
.47619 .36823 m .47292 .3817 L .48454 .39217 L p .344 .457 .831 r
F P
0 g
s
.31085 .23058 m .30053 .21183 L .28409 .21544 L p .574 .631 .87 r
F P
0 g
s
.30053 .21183 m .31085 .23058 L .32684 .22899 L p .574 .623 .863 r
F P
0 g
s
.80599 .60773 m .78469 .60333 L .78741 .6133 L p .385 .642 .958 r
F P
0 g
s
.78741 .6133 m .80872 .61863 L .80599 .60773 L p .385 .642 .958 r
F P
0 g
s
.43689 .33719 m .43598 .31841 L .42161 .3097 L p .442 .509 .832 r
F P
0 g
s
.43598 .31841 m .43689 .33719 L .44997 .34639 L p .419 .492 .828 r
F P
0 g
s
.37347 .27217 m .36708 .25104 L .35121 .24923 L p .537 .581 .846 r
F P
0 g
s
.36708 .25104 m .37347 .27217 L .38844 .27608 L p .531 .569 .838 r
F P
0 g
s
.28409 .21544 m .27249 .19786 L .25579 .20363 L p .59 .651 .879 r
F P
0 g
s
.27249 .19786 m .28409 .21544 L .30053 .21183 L p .588 .642 .872 r
F P
0 g
s
.21209 .18238 m .22621 .19541 L .24294 .18781 L p .627 .702 .9 r
F P
0 g
s
.25579 .20363 m .24294 .18781 L .22621 .19541 L p .6 .675 .893 r
F P
0 g
s
.24294 .18781 m .25579 .20363 L .27249 .19786 L p .614 .665 .875 r
F P
0 g
s
.75945 .58949 m .73859 .5857 L .74259 .59503 L p .387 .653 .963 r
F P
0 g
s
.74259 .59503 m .76357 .59931 L .75945 .58949 L p .387 .653 .963 r
F P
0 g
s
.40742 .30259 m .40374 .28162 L .38844 .27608 L p .498 .545 .836 r
F P
0 g
s
.40374 .28162 m .40742 .30259 L .42161 .3097 L p .482 .53 .83 r
F P
0 g
s
.48454 .39217 m .48921 .38056 L .47619 .36823 L p .344 .457 .831 r
F P
0 g
s
.48921 .38056 m .48454 .39217 L .49602 .40316 L p .324 .448 .832 r
F P
0 g
s
.57248 .4715 m .55884 .47089 L .56779 .48138 L p .275 .477 .875 r
F P
0 g
s
.56779 .48138 m .58249 .48307 L .57248 .4715 L p .275 .477 .875 r
F P
0 g
s
.35121 .24923 m .34346 .22859 L .32684 .22899 L p .56 .603 .853 r
F P
0 g
s
.34346 .22859 m .35121 .24923 L .36708 .25104 L p .559 .593 .844 r
F P
0 g
s
.49602 .40316 m .50208 .39353 L .48921 .38056 L p .324 .448 .832 r
F P
0 g
s
.50208 .39353 m .49602 .40316 L .50731 .41448 L p .307 .442 .834 r
F P
0 g
s
.56189 .45939 m .54937 .46005 L .55884 .47089 L p .272 .466 .867 r
F P
0 g
s
.55884 .47089 m .57248 .4715 L .56189 .45939 L p .272 .466 .867 r
F P
0 g
s
.61733 .50838 m .60052 .5046 L .60847 .51461 L p .275 .516 .903 r
F P
0 g
s
.60847 .51461 m .62607 .51891 L .61733 .50838 L p .275 .516 .903 r
F P
0 g
s
.65249 .5337 m .63396 .52893 L .64097 .53848 L p .292 .552 .924 r
F P
0 g
s
.64097 .53848 m .66009 .54354 L .65249 .5337 L p .292 .552 .924 r
F P
0 g
s
.44997 .34639 m .45045 .32874 L .43598 .31841 L p .419 .492 .828 r
F P
0 g
s
.45045 .32874 m .44997 .34639 L .46309 .35678 L p .393 .475 .825 r
F P
0 g
s
.50731 .41448 m .51474 .40689 L .50208 .39353 L p .307 .442 .834 r
F P
0 g
s
.51474 .40689 m .50731 .41448 L .51835 .42599 L p .293 .44 .838 r
F P
0 g
s
.55075 .44677 m .53943 .44889 L .54937 .46005 L p .272 .455 .858 r
F P
0 g
s
.54937 .46005 m .56189 .45939 L .55075 .44677 L p .272 .455 .858 r
F P
0 g
s
.73329 .57628 m .71278 .57205 L .71786 .58127 L p .355 .634 .959 r
F P
0 g
s
.71786 .58127 m .73859 .5857 L .73329 .57628 L p .355 .634 .959 r
F P
0 g
s
.82762 .61428 m .80599 .60773 L .80872 .61863 L p .332 .572 .927 r
F P
0 g
s
.80872 .61863 m .83044 .62703 L .82762 .61428 L p .332 .572 .927 r
F P
0 g
s
.38844 .27608 m .38337 .25442 L .36708 .25104 L p .531 .569 .838 r
F P
0 g
s
.38337 .25442 m .38844 .27608 L .40374 .28162 L p .522 .555 .83 r
F P
0 g
s
.32684 .22899 m .31773 .20934 L .30053 .21183 L p .574 .623 .863 r
F P
0 g
s
.31773 .20934 m .32684 .22899 L .34346 .22859 L p .577 .616 .854 r
F P
0 g
s
.51835 .42599 m .52711 .42036 L .51474 .40689 L p .293 .44 .838 r
F P
0 g
s
.52711 .42036 m .51835 .42599 L .52907 .4375 L p .282 .442 .843 r
F P
0 g
s
.42161 .3097 m .4193 .28896 L .40374 .28162 L p .482 .53 .83 r
F P
0 g
s
.4193 .28896 m .42161 .3097 L .43598 .31841 L p .462 .512 .824 r
F P
0 g
s
.53914 .43371 m .52907 .4375 L .53943 .44889 L p .275 .447 .85 r
F P
0 g
s
.53943 .44889 m .55075 .44677 L .53914 .43371 L p .275 .447 .85 r
F P
0 g
s
.52907 .4375 m .53914 .43371 L .52711 .42036 L p .282 .442 .843 r
F P
0 g
s
.21209 .18238 m .19759 .17301 L .18068 .17455 L p .333 .677 .978 r
F P
0 g
s
.67943 .54837 m .66009 .54354 L .66669 .55297 L p .305 .578 .937 r
F P
0 g
s
.66669 .55297 m .68649 .55799 L .67943 .54837 L p .305 .578 .937 r
F P
0 g
s
.70649 .56261 m .68649 .55799 L .69244 .56728 L p .326 .606 .949 r
F P
0 g
s
.69244 .56728 m .71278 .57205 L .70649 .56261 L p .326 .606 .949 r
F P
0 g
s
.78042 .59244 m .75945 .58949 L .76357 .59931 L p .409 .657 .961 r
F P
0 g
s
.76357 .59931 m .78469 .60333 L .78042 .59244 L p .409 .657 .961 r
F P
0 g
s
.30053 .21183 m .29009 .19326 L .27249 .19786 L p .588 .642 .872 r
F P
0 g
s
.29009 .19326 m .30053 .21183 L .31773 .20934 L p .585 .635 .867 r
F P
0 g
s
.46309 .35678 m .46498 .34065 L .45045 .32874 L p .393 .475 .825 r
F P
0 g
s
.46498 .34065 m .46309 .35678 L .47619 .36823 L p .364 .457 .822 r
F P
0 g
s
.60777 .49725 m .59185 .49409 L .60052 .5046 L p .263 .5 .895 r
F P
0 g
s
.60052 .5046 m .61733 .50838 L .60777 .49725 L p .263 .5 .895 r
F P
0 g
s
.27249 .19786 m .26076 .18034 L .24294 .18781 L p .614 .665 .875 r
F P
0 g
s
.26076 .18034 m .27249 .19786 L .29009 .19326 L p .601 .651 .871 r
F P
0 g
s
.36708 .25104 m .36062 .22954 L .34346 .22859 L p .559 .593 .844 r
F P
0 g
s
.36062 .22954 m .36708 .25104 L .38337 .25442 L p .555 .581 .835 r
F P
0 g
s
.24294 .18781 m .22989 .17308 L .21209 .18238 L p .627 .702 .9 r
F P
0 g
s
.22989 .17308 m .24294 .18781 L .26076 .18034 L p .656 .678 .859 r
F P
0 g
s
.19759 .17301 m .21209 .18238 L .22989 .17308 L p .678 .758 .911 r
F P
0 g
s
.64392 .52338 m .62607 .51891 L .63396 .52893 L p .273 .537 .918 r
F P
0 g
s
.63396 .52893 m .65249 .5337 L .64392 .52338 L p .273 .537 .918 r
F P
0 g
s
.43598 .31841 m .43506 .29828 L .4193 .28896 L p .462 .512 .824 r
F P
0 g
s
.43506 .29828 m .43598 .31841 L .45045 .32874 L p .436 .492 .819 r
F P
0 g
s
.40374 .28162 m .40003 .25962 L .38337 .25442 L p .522 .555 .83 r
F P
0 g
s
.40003 .25962 m .40374 .28162 L .4193 .28896 L p .507 .538 .823 r
F P
0 g
s
.47619 .36823 m .4795 .35399 L .46498 .34065 L p .364 .457 .822 r
F P
0 g
s
.4795 .35399 m .47619 .36823 L .48921 .38056 L p .335 .44 .82 r
F P
0 g
s
.34346 .22859 m .33561 .20797 L .31773 .20934 L p .577 .616 .854 r
F P
0 g
s
.33561 .20797 m .34346 .22859 L .36062 .22954 L p .58 .607 .844 r
F P
0 g
s
.59744 .48546 m .58249 .48307 L .59185 .49409 L p .252 .484 .886 r
F P
0 g
s
.59185 .49409 m .60777 .49725 L .59744 .48546 L p .252 .484 .886 r
F P
0 g
s
.75395 .57983 m .73329 .57628 L .73859 .5857 L p .366 .652 .966 r
F P
0 g
s
.73859 .5857 m .75945 .58949 L .75395 .57983 L p .366 .652 .966 r
F P
0 g
s
.80146 .59404 m .78042 .59244 L .78469 .60333 L p .444 .638 .939 r
F P
0 g
s
.78469 .60333 m .80599 .60773 L .80146 .59404 L p .444 .638 .939 r
F P
0 g
s
.48921 .38056 m .49394 .36851 L .4795 .35399 L p .335 .44 .82 r
F P
0 g
s
.49394 .36851 m .48921 .38056 L .50208 .39353 L p .307 .427 .82 r
F P
0 g
s
.38337 .25442 m .37826 .23212 L .36062 .22954 L p .555 .581 .835 r
F P
0 g
s
.37826 .23212 m .38337 .25442 L .40003 .25962 L p .547 .566 .825 r
F P
0 g
s
.31773 .20934 m .3085 .18996 L .29009 .19326 L p .585 .635 .867 r
F P
0 g
s
.3085 .18996 m .31773 .20934 L .33561 .20797 L p .591 .63 .858 r
F P
0 g
s
.67127 .53836 m .65249 .5337 L .66009 .54354 L p .283 .563 .932 r
F P
0 g
s
.66009 .54354 m .67943 .54837 L .67127 .53836 L p .283 .563 .932 r
F P
0 g
s
.45045 .32874 m .45094 .30969 L .43506 .29828 L p .436 .492 .819 r
F P
0 g
s
.45094 .30969 m .45045 .32874 L .46498 .34065 L p .403 .469 .814 r
F P
0 g
s
.58638 .47295 m .57248 .4715 L .58249 .48307 L p .243 .467 .876 r
F P
0 g
s
.58249 .48307 m .59744 .48546 L .58638 .47295 L p .243 .467 .876 r
F P
0 g
s
.4193 .28896 m .41697 .2669 L .40003 .25962 L p .507 .538 .823 r
F P
0 g
s
.41697 .2669 m .4193 .28896 L .43506 .29828 L p .487 .518 .815 r
F P
0 g
s
.72668 .56677 m .70649 .56261 L .71278 .57205 L p .329 .624 .958 r
F P
0 g
s
.71278 .57205 m .73329 .57628 L .72668 .56677 L p .329 .624 .958 r
F P
0 g
s
.6344 .5125 m .61733 .50838 L .62607 .51891 L p .254 .519 .91 r
F P
0 g
s
.62607 .51891 m .64392 .52338 L .6344 .5125 L p .254 .519 .91 r
F P
0 g
s
.29009 .19326 m .27953 .17464 L .26076 .18034 L p .601 .651 .871 r
F P
0 g
s
.27953 .17464 m .29009 .19326 L .3085 .18996 L p .585 .643 .874 r
F P
0 g
s
.69899 .55289 m .67943 .54837 L .68649 .55799 L p .302 .593 .946 r
F P
0 g
s
.68649 .55799 m .70649 .56261 L .69899 .55289 L p .302 .593 .946 r
F P
0 g
s
.50208 .39353 m .50823 .38385 L .49394 .36851 L p .307 .427 .82 r
F P
0 g
s
.50823 .38385 m .50208 .39353 L .51474 .40689 L p .282 .418 .822 r
F P
0 g
s
.26076 .18034 m .24894 .16234 L .22989 .17308 L p .656 .678 .859 r
F P
0 g
s
.24894 .16234 m .26076 .18034 L .27953 .17464 L p .617 .651 .861 r
F P
0 g
s
.36062 .22954 m .3541 .20784 L .33561 .20797 L p .58 .607 .844 r
F P
0 g
s
.3541 .20784 m .36062 .22954 L .37826 .23212 L p .579 .595 .832 r
F P
0 g
s
.57464 .45965 m .56189 .45939 L .57248 .4715 L p .237 .451 .866 r
F P
0 g
s
.57248 .4715 m .58638 .47295 L .57464 .45965 L p .237 .451 .866 r
F P
0 g
s
.51474 .40689 m .52229 .3996 L .50823 .38385 L p .282 .418 .822 r
F P
0 g
s
.52229 .3996 m .51474 .40689 L .52711 .42036 L p .262 .415 .827 r
F P
0 g
s
.22989 .17308 m .21655 .16079 L .19759 .17301 L p .678 .758 .911 r
F P
0 g
s
.21655 .16079 m .22989 .17308 L .24894 .16234 L p .722 .686 .814 r
F P
0 g
s
.46498 .34065 m .4669 .32323 L .45094 .30969 L p .403 .469 .814 r
F P
0 g
s
.4669 .32323 m .46498 .34065 L .4795 .35399 L p .365 .444 .809 r
F P
0 g
s
.56229 .44557 m .55075 .44677 L .56189 .45939 L p .236 .437 .855 r
F P
0 g
s
.56189 .45939 m .57464 .45965 L .56229 .44557 L p .236 .437 .855 r
F P
0 g
s
.40003 .25962 m .39629 .23664 L .37826 .23212 L p .547 .566 .825 r
F P
0 g
s
.39629 .23664 m .40003 .25962 L .41697 .2669 L p .535 .549 .816 r
F P
0 g
s
.52711 .42036 m .53604 .41535 L .52229 .3996 L p .262 .415 .827 r
F P
0 g
s
.53604 .41535 m .52711 .42036 L .53914 .43371 L p .248 .417 .835 r
F P
0 g
s
.82242 .593 m .80146 .59404 L .80599 .60773 L p .481 .568 .866 r
F P
0 g
s
.80599 .60773 m .82762 .61428 L .82242 .593 L p .481 .568 .866 r
F P
0 g
s
.77473 .58238 m .75395 .57983 L .75945 .58949 L p .391 .674 .973 r
F P
0 g
s
.75945 .58949 m .78042 .59244 L .77473 .58238 L p .391 .674 .973 r
F P
0 g
s
.5494 .43075 m .53914 .43371 L .55075 .44677 L p .239 .425 .844 r
F P
0 g
s
.55075 .44677 m .56229 .44557 L .5494 .43075 L p .239 .425 .844 r
F P
0 g
s
.43506 .29828 m .43413 .27656 L .41697 .2669 L p .487 .518 .815 r
F P
0 g
s
.43413 .27656 m .43506 .29828 L .45094 .30969 L p .458 .494 .808 r
F P
0 g
s
.53914 .43371 m .5494 .43075 L .53604 .41535 L p .248 .417 .835 r
F P
0 g
s
.33561 .20797 m .32767 .18764 L .3085 .18996 L p .591 .63 .858 r
F P
0 g
s
.32767 .18764 m .33561 .20797 L .3541 .20784 L p .602 .623 .845 r
F P
0 g
s
.62397 .50095 m .60777 .49725 L .61733 .50838 L p .236 .5 .901 r
F P
0 g
s
.61733 .50838 m .6344 .5125 L .62397 .50095 L p .236 .5 .901 r
F P
0 g
s
.66204 .52789 m .64392 .52338 L .65249 .5337 L p .259 .546 .926 r
F P
0 g
s
.65249 .5337 m .67127 .53836 L .66204 .52789 L p .259 .546 .926 r
F P
0 g
s
.37826 .23212 m .3731 .20929 L .3541 .20784 L p .579 .595 .832 r
F P
0 g
s
.3731 .20929 m .37826 .23212 L .39629 .23664 L p .573 .579 .821 r
F P
0 g
s
.4795 .35399 m .48285 .33875 L .4669 .32323 L p .365 .444 .809 r
F P
0 g
s
.48285 .33875 m .4795 .35399 L .49394 .36851 L p .324 .42 .806 r
F P
0 g
s
.3085 .18996 m .29916 .17104 L .27953 .17464 L p .585 .643 .874 r
F P
0 g
s
.29916 .17104 m .3085 .18996 L .32767 .18764 L p .598 .645 .868 r
F P
0 g
s
.74707 .57044 m .72668 .56677 L .73329 .57628 L p .332 .645 .967 r
F P
0 g
s
.73329 .57628 m .75395 .57983 L .74707 .57044 L p .332 .645 .967 r
F P
0 g
s
.41697 .2669 m .41462 .24347 L .39629 .23664 L p .535 .549 .816 r
F P
0 g
s
.41462 .24347 m .41697 .2669 L .43413 .27656 L p .516 .528 .806 r
F P
0 g
s
.27953 .17464 m .2689 .15521 L .24894 .16234 L p .617 .651 .861 r
F P
0 g
s
.2689 .15521 m .27953 .17464 L .29916 .17104 L p .554 .637 .888 r
F P
0 g
s
.69029 .54281 m .67127 .53836 L .67943 .54837 L p .276 .576 .94 r
F P
0 g
s
.67943 .54837 m .69899 .55289 L .69029 .54281 L p .276 .576 .94 r
F P
0 g
s
.45094 .30969 m .45144 .28888 L .43413 .27656 L p .458 .494 .808 r
F P
0 g
s
.45144 .28888 m .45094 .30969 L .4669 .32323 L p .419 .465 .801 r
F P
0 g
s
.61267 .48862 m .59744 .48546 L .60777 .49725 L p .219 .479 .89 r
F P
0 g
s
.60777 .49725 m .62397 .50095 L .61267 .48862 L p .219 .479 .89 r
F P
0 g
s
.24894 .16234 m .23708 .14246 L .21655 .16079 L p .722 .686 .814 r
F P
0 g
s
.23708 .14246 m .24894 .16234 L .2689 .15521 L p .638 .632 .828 r
F P
0 g
s
.71877 .55703 m .69899 .55289 L .70649 .56261 L p .301 .609 .954 r
F P
0 g
s
.70649 .56261 m .72668 .56677 L .71877 .55703 L p .301 .609 .954 r
F P
0 g
s
.3541 .20784 m .34751 .18614 L .32767 .18764 L p .602 .623 .845 r
F P
0 g
s
.34751 .18614 m .3541 .20784 L .3731 .20929 L p .606 .611 .83 r
F P
0 g
s
.49394 .36851 m .49874 .3559 L .48285 .33875 L p .324 .42 .806 r
F P
0 g
s
.49874 .3559 m .49394 .36851 L .50823 .38385 L p .284 .4 .805 r
F P
0 g
s
.79555 .58302 m .77473 .58238 L .78042 .59244 L p .446 .703 .976 r
F P
0 g
s
.78042 .59244 m .80146 .59404 L .79555 .58302 L p .446 .703 .976 r
F P
0 g
s
.39629 .23664 m .39252 .2128 L .3731 .20929 L p .573 .579 .821 r
F P
0 g
s
.39252 .2128 m .39629 .23664 L .41462 .24347 L p .563 .561 .81 r
F P
0 g
s
.65176 .51687 m .6344 .5125 L .64392 .52338 L p .233 .525 .917 r
F P
0 g
s
.64392 .52338 m .66204 .52789 L .65176 .51687 L p .233 .525 .917 r
F P
0 g
s
.60055 .47536 m .58638 .47295 L .59744 .48546 L p .204 .457 .878 r
F P
0 g
s
.59744 .48546 m .61267 .48862 L .60055 .47536 L p .204 .457 .878 r
F P
0 g
s
.32767 .18764 m .31962 .16808 L .29916 .17104 L p .598 .645 .868 r
F P
0 g
s
.31962 .16808 m .32767 .18764 L .34751 .18614 L p .629 .645 .848 r
F P
0 g
s
.43413 .27656 m .4332 .25303 L .41462 .24347 L p .516 .528 .806 r
F P
0 g
s
.4332 .25303 m .43413 .27656 L .45144 .28888 L p .488 .501 .797 r
F P
0 g
s
.50823 .38385 m .51448 .37414 L .49874 .3559 L p .284 .4 .805 r
F P
0 g
s
.51448 .37414 m .50823 .38385 L .52229 .3996 L p .249 .387 .807 r
F P
0 g
s
.4669 .32323 m .46883 .30408 L .45144 .28888 L p .419 .465 .801 r
F P
0 g
s
.46883 .30408 m .4669 .32323 L .48285 .33875 L p .37 .431 .794 r
F P
0 g
s
.3731 .20929 m .36789 .18606 L .34751 .18614 L p .606 .611 .83 r
F P
0 g
s
.36789 .18606 m .3731 .20929 L .39252 .2128 L p .598 .593 .818 r
F P
0 g
s
.58766 .46104 m .57464 .45965 L .58638 .47295 L p .194 .435 .864 r
F P
0 g
s
.58638 .47295 m .60055 .47536 L .58766 .46104 L p .194 .435 .864 r
F P
0 g
s
.76763 .5736 m .74707 .57044 L .75395 .57983 L p .335 .676 .977 r
F P
0 g
s
.75395 .57983 m .77473 .58238 L .76763 .5736 L p .335 .676 .977 r
F P
0 g
s
.52229 .3996 m .52998 .39281 L .51448 .37414 L p .249 .387 .807 r
F P
0 g
s
.52998 .39281 m .52229 .3996 L .53604 .41535 L p .221 .382 .813 r
F P
0 g
s
.29916 .17104 m .28969 .1528 L .2689 .15521 L p .554 .637 .888 r
F P
0 g
s
.28969 .1528 m .29916 .17104 L .31962 .16808 L p .577 .661 .894 r
F P
0 g
s
.81618 .5793 m .79555 .58302 L .80146 .59404 L p .555 .732 .958 r
F P
0 g
s
.80146 .59404 m .82242 .593 L .81618 .5793 L p .555 .732 .958 r
F P
0 g
s
.41462 .24347 m .41226 .21875 L .39252 .2128 L p .563 .561 .81 r
F P
0 g
s
.41226 .21875 m .41462 .24347 L .4332 .25303 L p .55 .541 .797 r
F P
0 g
s
.68041 .53232 m .66204 .52789 L .67127 .53836 L p .247 .557 .933 r
F P
0 g
s
.67127 .53836 m .69029 .54281 L .68041 .53232 L p .247 .557 .933 r
F P
0 g
s
.2689 .15521 m .2583 .13274 L .23708 .14246 L p .638 .632 .828 r
F P
0 g
s
.2583 .13274 m .2689 .15521 L .28969 .1528 L p .419 .577 .904 r
F P
0 g
s
.57407 .44557 m .56229 .44557 L .57464 .45965 L p .189 .415 .85 r
F P
0 g
s
.57464 .45965 m .58766 .46104 L .57407 .44557 L p .189 .415 .85 r
F P
0 g
s
.53604 .41535 m .54514 .41124 L .52998 .39281 L p .221 .382 .813 r
F P
0 g
s
.54514 .41124 m .53604 .41535 L .5494 .43075 L p .201 .386 .823 r
F P
0 g
s
.64046 .50514 m .62397 .50095 L .6344 .5125 L p .207 .502 .906 r
F P
0 g
s
.6344 .5125 m .65176 .51687 L .64046 .50514 L p .207 .502 .906 r
F P
0 g
s
.48285 .33875 m .48624 .32211 L .46883 .30408 L p .37 .431 .794 r
F P
0 g
s
.48624 .32211 m .48285 .33875 L .49874 .3559 L p .313 .397 .788 r
F P
0 g
s
.45144 .28888 m .45193 .26588 L .4332 .25303 L p .488 .501 .797 r
F P
0 g
s
.45193 .26588 m .45144 .28888 L .46883 .30408 L p .444 .465 .787 r
F P
0 g
s
.34751 .18614 m .34083 .16474 L .31962 .16808 L p .629 .645 .848 r
F P
0 g
s
.34083 .16474 m .34751 .18614 L .36789 .18606 L p .639 .631 .826 r
F P
0 g
s
.55987 .42893 m .5494 .43075 L .56229 .44557 L p .191 .397 .835 r
F P
0 g
s
.56229 .44557 m .57407 .44557 L .55987 .42893 L p .191 .397 .835 r
F P
0 g
s
.5494 .43075 m .55987 .42893 L .54514 .41124 L p .201 .386 .823 r
F P
0 g
s
.73876 .56084 m .71877 .55703 L .72668 .56677 L p .298 .626 .961 r
F P
0 g
s
.72668 .56677 m .74707 .57044 L .73876 .56084 L p .298 .626 .961 r
F P
0 g
s
.70955 .54693 m .69029 .54281 L .69899 .55289 L p .272 .591 .947 r
F P
0 g
s
.69899 .55289 m .71877 .55703 L .70955 .54693 L p .272 .591 .947 r
F P
0 g
s
.39252 .2128 m .38871 .18827 L .36789 .18606 L p .598 .593 .818 r
F P
0 g
s
.38871 .18827 m .39252 .2128 L .41226 .21875 L p .588 .575 .806 r
F P
0 g
s
.4332 .25303 m .43226 .22759 L .41226 .21875 L p .55 .541 .797 r
F P
0 g
s
.43226 .22759 m .4332 .25303 L .45193 .26588 L p .527 .514 .785 r
F P
0 g
s
.31962 .16808 m .31141 .15041 L .28969 .1528 L p .577 .661 .894 r
F P
0 g
s
.31141 .15041 m .31962 .16808 L .34083 .16474 L p .666 .68 .853 r
F P
0 g
s
.49874 .3559 m .50361 .34253 L .48624 .32211 L p .313 .397 .788 r
F P
0 g
s
.50361 .34253 m .49874 .3559 L .51448 .37414 L p .256 .366 .785 r
F P
0 g
s
.62819 .49253 m .61267 .48862 L .62397 .50095 L p .182 .476 .893 r
F P
0 g
s
.62397 .50095 m .64046 .50514 L .62819 .49253 L p .182 .476 .893 r
F P
0 g
s
.36789 .18606 m .36263 .16232 L .34083 .16474 L p .639 .631 .826 r
F P
0 g
s
.36263 .16232 m .36789 .18606 L .38871 .18827 L p .62 .606 .815 r
F P
0 g
s
.78838 .57628 m .76763 .5736 L .77473 .58238 L p .328 .73 .981 r
F P
0 g
s
.77473 .58238 m .79555 .58302 L .78838 .57628 L p .328 .73 .981 r
F P
0 g
s
.46883 .30408 m .47077 .2826 L .45193 .26588 L p .444 .465 .787 r
F P
0 g
s
.47077 .2826 m .46883 .30408 L .48624 .32211 L p .381 .421 .777 r
F P
0 g
s
.28969 .1528 m .28005 .13553 L .2583 .13274 L p .419 .577 .904 r
F P
0 g
s
.66939 .52135 m .65176 .51687 L .66204 .52789 L p .214 .535 .924 r
F P
0 g
s
.66204 .52789 m .68041 .53232 L .66939 .52135 L p .214 .535 .924 r
F P
0 g
s
.41226 .21875 m .40989 .19309 L .38871 .18827 L p .588 .575 .806 r
F P
0 g
s
.40989 .19309 m .41226 .21875 L .43226 .22759 L p .586 .559 .791 r
F P
0 g
s
.28005 .13553 m .28969 .1528 L .31141 .15041 L p .425 .655 .955 r
F P
0 g
s
.51448 .37414 m .52083 .36448 L .50361 .34253 L p .256 .366 .785 r
F P
0 g
s
.52083 .36448 m .51448 .37414 L .52998 .39281 L p .204 .345 .785 r
F P
0 g
s
.61501 .47882 m .60055 .47536 L .61267 .48862 L p .159 .447 .878 r
F P
0 g
s
.61267 .48862 m .62819 .49253 L .61501 .47882 L p .159 .447 .878 r
F P
0 g
s
.45193 .26588 m .45243 .24016 L .43226 .22759 L p .527 .514 .785 r
F P
0 g
s
.45243 .24016 m .45193 .26588 L .47077 .2826 L p .482 .474 .772 r
F P
0 g
s
.34083 .16474 m .33405 .1442 L .31141 .15041 L p .666 .68 .853 r
F P
0 g
s
.33405 .1442 m .34083 .16474 L .36263 .16232 L p .689 .656 .812 r
F P
0 g
s
.759 .56458 m .73876 .56084 L .74707 .57044 L p .283 .643 .967 r
F P
0 g
s
.74707 .57044 m .76763 .5736 L .759 .56458 L p .283 .643 .967 r
F P
0 g
s
.69904 .53649 m .68041 .53232 L .69029 .54281 L p .24 .572 .94 r
F P
0 g
s
.69029 .54281 m .70955 .54693 L .69904 .53649 L p .24 .572 .94 r
F P
0 g
s
.38871 .18827 m .38488 .16309 L .36263 .16232 L p .62 .606 .815 r
F P
0 g
s
.38488 .16309 m .38871 .18827 L .40989 .19309 L p .601 .585 .807 r
F P
0 g
s
.48624 .32211 m .48966 .30349 L .47077 .2826 L p .381 .421 .777 r
F P
0 g
s
.48966 .30349 m .48624 .32211 L .50361 .34253 L p .303 .371 .767 r
F P
0 g
s
.72903 .55066 m .70955 .54693 L .71877 .55703 L p .271 .604 .953 r
F P
0 g
s
.71877 .55703 m .73876 .56084 L .72903 .55066 L p .271 .604 .953 r
F P
0 g
s
.43226 .22759 m .43132 .20044 L .40989 .19309 L p .586 .559 .791 r
F P
0 g
s
.43132 .20044 m .43226 .22759 L .45243 .24016 L p .577 .536 .772 r
F P
0 g
s
.52998 .39281 m .53782 .38683 L .52083 .36448 L p .204 .345 .785 r
F P
0 g
s
.53782 .38683 m .52998 .39281 L .54514 .41124 L p .164 .338 .792 r
F P
0 g
s
.60096 .46377 m .58766 .46104 L .60055 .47536 L p .14 .417 .861 r
F P
0 g
s
.60055 .47536 m .61501 .47882 L .60096 .46377 L p .14 .417 .861 r
F P
0 g
s
.8093 .57846 m .78838 .57628 L .79555 .58302 L p .244 .759 .824 r
F P
0 g
s
.79555 .58302 m .81618 .5793 L .8093 .57846 L p .244 .759 .824 r
F P
0 g
s
.65724 .50971 m .64046 .50514 L .65176 .51687 L p .178 .507 .911 r
F P
0 g
s
.65176 .51687 m .66939 .52135 L .65724 .50971 L p .178 .507 .911 r
F P
0 g
s
.36263 .16232 m .35735 .13738 L .33405 .1442 L p .689 .656 .812 r
F P
0 g
s
.35735 .13738 m .36263 .16232 L .38488 .16309 L p .64 .612 .806 r
F P
0 g
s
.54514 .41124 m .55444 .40849 L .53782 .38683 L p .164 .338 .792 r
F P
0 g
s
.55444 .40849 m .54514 .41124 L .55987 .42893 L p .138 .344 .805 r
F P
0 g
s
.31141 .15041 m .30292 .1374 L .28005 .13553 L p .425 .655 .955 r
F P
0 g
s
.30292 .1374 m .31141 .15041 L .33405 .1442 L p .731 .745 .863 r
F P
0 g
s
.58612 .44712 m .57407 .44557 L .58766 .46104 L p .129 .388 .842 r
F P
0 g
s
.58766 .46104 m .60096 .46377 L .58612 .44712 L p .129 .388 .842 r
F P
0 g
s
.40989 .19309 m .40748 .16718 L .38488 .16309 L p .601 .585 .807 r
F P
0 g
s
.40748 .16718 m .40989 .19309 L .43132 .20044 L p .616 .58 .79 r
F P
0 g
s
.47077 .2826 m .47271 .25785 L .45243 .24016 L p .482 .474 .772 r
F P
0 g
s
.47271 .25785 m .47077 .2826 L .48966 .30349 L p .404 .415 .758 r
F P
0 g
s
.55987 .42893 m .57058 .4287 L .55444 .40849 L p .138 .344 .805 r
F P
0 g
s
.57058 .4287 m .55987 .42893 L .57407 .44557 L p .127 .362 .823 r
F P
0 g
s
.57407 .44557 m .58612 .44712 L .57058 .4287 L p .127 .362 .823 r
F P
0 g
s
.50361 .34253 m .50853 .32808 L .48966 .30349 L p .303 .371 .767 r
F P
0 g
s
.50853 .32808 m .50361 .34253 L .52083 .36448 L p .218 .323 .758 r
F P
0 g
s
.45243 .24016 m .45292 .21127 L .43132 .20044 L p .577 .536 .772 r
F P
0 g
s
.45292 .21127 m .45243 .24016 L .47271 .25785 L p .537 .493 .755 r
F P
0 g
s
.38488 .16309 m .38103 .1366 L .35735 .13738 L p .64 .612 .806 r
F P
0 g
s
.38103 .1366 m .38488 .16309 L .40748 .16718 L p .578 .578 .816 r
F P
0 g
s
.68729 .52574 m .66939 .52135 L .68041 .53232 L p .2 .549 .931 r
F P
0 g
s
.68041 .53232 m .69904 .53649 L .68729 .52574 L p .2 .549 .931 r
F P
0 g
s
.64402 .49715 m .62819 .49253 L .64046 .50514 L p .141 .474 .895 r
F P
0 g
s
.64046 .50514 m .65724 .50971 L .64402 .49715 L p .141 .474 .895 r
F P
0 g
s
.77954 .56919 m .759 .56458 L .76763 .5736 L p .215 .651 .952 r
F P
0 g
s
.76763 .5736 m .78838 .57628 L .77954 .56919 L p .215 .651 .952 r
F P
0 g
s
.33405 .1442 m .32712 .12595 L .30292 .1374 L p .731 .745 .863 r
F P
0 g
s
.32712 .12595 m .33405 .1442 L .35735 .13738 L p .765 .683 .772 r
F P
0 g
s
.43132 .20044 m .43037 .17256 L .40748 .16718 L p .616 .58 .79 r
F P
0 g
s
.43037 .17256 m .43132 .20044 L .45292 .21127 L p .64 .571 .761 r
F P
0 g
s
.71791 .54014 m .69904 .53649 L .70955 .54693 L p .242 .587 .947 r
F P
0 g
s
.70955 .54693 m .72903 .55066 L .71791 .54014 L p .242 .587 .947 r
F P
0 g
s
.74875 .55402 m .72903 .55066 L .73876 .56084 L p .267 .608 .955 r
F P
0 g
s
.73876 .56084 m .759 .56458 L .74875 .55402 L p .267 .608 .955 r
F P
0 g
s
.35735 .13738 m .35208 .1091 L .32712 .12595 L p .765 .683 .772 r
F P
0 g
s
.35208 .1091 m .35735 .13738 L .38103 .1366 L p .663 .603 .778 r
F P
0 g
s
.48966 .30349 m .49308 .28185 L .47271 .25785 L p .404 .415 .758 r
F P
0 g
s
.49308 .28185 m .48966 .30349 L .50853 .32808 L p .295 .342 .741 r
F P
0 g
s
.52083 .36448 m .5273 .35497 L .50853 .32808 L p .218 .323 .758 r
F P
0 g
s
.5273 .35497 m .52083 .36448 L .53782 .38683 L p .141 .289 .755 r
F P
0 g
s
.40748 .16718 m .40505 .14228 L .38103 .1366 L p .578 .578 .816 r
F P
0 g
s
.40505 .14228 m .40748 .16718 L .43037 .17256 L p .624 .603 .808 r
F P
0 g
s
.47271 .25785 m .47464 .22844 L .45292 .21127 L p .537 .493 .755 r
F P
0 g
s
.47464 .22844 m .47271 .25785 L .49308 .28185 L p .444 .419 .736 r
F P
0 g
s
.62977 .48337 m .61501 .47882 L .62819 .49253 L p .106 .437 .876 r
F P
0 g
s
.62819 .49253 m .64402 .49715 L .62977 .48337 L p .106 .437 .876 r
F P
0 g
s
.45292 .21127 m .45342 .17909 L .43037 .17256 L p .64 .571 .761 r
F P
0 g
s
.45342 .17909 m .45292 .21127 L .47464 .22844 L p .614 .528 .734 r
F P
0 g
s
.38103 .1366 m .3772 .10614 L .35208 .1091 L p .663 .603 .778 r
F P
0 g
s
.3772 .10614 m .38103 .1366 L .40505 .14228 L p .437 .497 .823 r
F P
0 g
s
.67432 .5145 m .65724 .50971 L .66939 .52135 L p .152 .517 .916 r
F P
0 g
s
.66939 .52135 m .68729 .52574 L .67432 .5145 L p .152 .517 .916 r
F P
0 g
s
.43037 .17256 m .42941 .14661 L .40505 .14228 L p .624 .603 .808 r
F P
0 g
s
.42941 .14661 m .43037 .17256 L .45342 .17909 L p .718 .626 .754 r
F P
0 g
s
.53782 .38683 m .54583 .38217 L .5273 .35497 L p .141 .289 .755 r
F P
0 g
s
.54583 .38217 m .53782 .38683 L .55444 .40849 L p .083 .277 .762 r
F P
0 g
s
.47836 .14631 m .48006 .08608 L .45441 .11177 L p .828 .649 .66 r
F P
0 g
s
.48006 .08608 m .47836 .14631 L .50297 .17251 L p .693 .518 .646 r
F P
0 g
s
.50297 .17251 m .50574 .09953 L .48006 .08608 L p .693 .518 .646 r
F P
0 g
s
.61456 .468 m .60096 .46377 L .61501 .47882 L p .074 .397 .854 r
F P
0 g
s
.61501 .47882 m .62977 .48337 L .61456 .468 L p .074 .397 .854 r
F P
0 g
s
.80062 .57726 m .77954 .56919 L .78838 .57628 L p 0 .526 .721 r
F P
0 g
s
.78838 .57628 m .8093 .57846 L .80062 .57726 L p 0 .526 .721 r
F P
0 g
s
.50853 .32808 m .5135 .31194 L .49308 .28185 L p .295 .342 .741 r
F P
0 g
s
.5135 .31194 m .50853 .32808 L .5273 .35497 L p .169 .267 .722 r
F P
0 g
s
.45342 .17909 m .45391 .14465 L .42941 .14661 L p .718 .626 .754 r
F P
0 g
s
.45391 .14465 m .45342 .17909 L .47654 .19229 L p .714 .582 .705 r
F P
0 g
s
.47464 .22844 m .47654 .19229 L .45342 .17909 L p .614 .528 .734 r
F P
0 g
s
.55444 .40849 m .56397 .40778 L .54583 .38217 L p .083 .277 .762 r
F P
0 g
s
.56397 .40778 m .55444 .40849 L .57058 .4287 L p .049 .288 .779 r
F P
0 g
s
.47654 .19229 m .47464 .22844 L .49649 .2554 L p .508 .437 .712 r
F P
0 g
s
.49308 .28185 m .49649 .2554 L .47464 .22844 L p .444 .419 .736 r
F P
0 g
s
.50574 .09953 m .50297 .17251 L .52829 .23628 L p .373 .273 .611 r
F P
0 g
s
.52829 .23628 m .53279 .18627 L .50574 .09953 L p .373 .273 .611 r
F P
0 g
s
.59846 .45061 m .58612 .44712 L .60096 .46377 L p .05 .356 .829 r
F P
0 g
s
.60096 .46377 m .61456 .468 L .59846 .45061 L p .05 .356 .829 r
F P
0 g
s
.70545 .52976 m .68729 .52574 L .69904 .53649 L p .197 .57 .938 r
F P
0 g
s
.69904 .53649 m .71791 .54014 L .70545 .52976 L p .197 .57 .938 r
F P
0 g
s
.40505 .14228 m .40256 .12014 L .3772 .10614 L p .437 .497 .823 r
F P
0 g
s
.40256 .12014 m .40505 .14228 L .42941 .14661 L p .507 .601 .881 r
F P
0 g
s
.49649 .2554 m .49308 .28185 L .5135 .31194 L p .294 .313 .711 r
F P
0 g
s
.57058 .4287 m .58156 .43066 L .56397 .40778 L p .049 .288 .779 r
F P
0 g
s
.58156 .43066 m .57058 .4287 L .58612 .44712 L p .04 .317 .803 r
F P
0 g
s
.58612 .44712 m .59846 .45061 L .58156 .43066 L p .04 .317 .803 r
F P
0 g
s
.76874 .55745 m .74875 .55402 L .759 .56458 L p .245 .584 .945 r
F P
0 g
s
.759 .56458 m .77954 .56919 L .76874 .55745 L p .245 .584 .945 r
F P
0 g
s
.73698 .54283 m .71791 .54014 L .72903 .55066 L p .261 .598 .951 r
F P
0 g
s
.72903 .55066 m .74875 .55402 L .73698 .54283 L p .261 .598 .951 r
F P
0 g
s
.66016 .50236 m .64402 .49715 L .65724 .50971 L p .099 .475 .894 r
F P
0 g
s
.65724 .50971 m .67432 .5145 L .66016 .50236 L p .099 .475 .894 r
F P
0 g
s
.45441 .11177 m .45391 .14465 L .47836 .14631 L p .828 .649 .66 r
F P
0 g
s
.47654 .19229 m .47836 .14631 L .45391 .14465 L p .714 .582 .705 r
F P
0 g
s
.47836 .14631 m .47654 .19229 L .49982 .22091 L p .594 .472 .683 r
F P
0 g
s
.49982 .22091 m .50297 .17251 L .47836 .14631 L p .594 .472 .683 r
F P
0 g
s
.49649 .2554 m .49982 .22091 L .47654 .19229 L p .508 .437 .712 r
F P
0 g
s
.4284 .12878 m .42941 .14661 L .45391 .14465 L p .826 .723 .751 r
F P
0 g
s
.45391 .14465 m .45441 .11177 L .4284 .12878 L p .826 .723 .751 r
F P
0 g
s
.42941 .14661 m .4284 .12878 L .40256 .12014 L p .507 .601 .881 r
F P
0 g
s
.5273 .35497 m .53388 .34582 L .5135 .31194 L p .169 .267 .722 r
F P
0 g
s
.53388 .34582 m .5273 .35497 L .54583 .38217 L p .051 .21 .709 r
F P
0 g
s
.64487 .4889 m .62977 .48337 L .64402 .49715 L p .047 .427 .869 r
F P
0 g
s
.64402 .49715 m .66016 .50236 L .64487 .4889 L p .047 .427 .869 r
F P
0 g
s
.49982 .22091 m .49649 .2554 L .51849 .29301 L p .304 .289 .677 r
F P
0 g
s
.5135 .31194 m .51849 .29301 L .49649 .2554 L p .294 .313 .711 r
F P
0 g
s
.69169 .51935 m .67432 .5145 L .68729 .52574 L p .13 .535 .919 r
F P
0 g
s
.68729 .52574 m .70545 .52976 L .69169 .51935 L p .13 .535 .919 r
F P
0 g
s
.51849 .29301 m .5135 .31194 L .53388 .34582 L p .105 .194 .673 r
F P
0 g
s
.54583 .38217 m .55405 .37975 L .53388 .34582 L p .051 .21 .709 r
F P
0 g
s
.55405 .37975 m .54583 .38217 L .56397 .40778 L p 0 .188 .712 r
F P
0 g
s
.50297 .17251 m .49982 .22091 L .52345 .26918 L p .33 .274 .643 r
F P
0 g
s
.52345 .26918 m .52829 .23628 L .50297 .17251 L p .33 .274 .643 r
F P
0 g
s
.78911 .56236 m .76874 .55745 L .77954 .56919 L p .166 .49 .903 r
F P
0 g
s
.77954 .56919 m .80062 .57726 L .78911 .56236 L p .166 .49 .903 r
F P
0 g
s
.72384 .53288 m .70545 .52976 L .71791 .54014 L p .219 .604 .95 r
F P
0 g
s
.71791 .54014 m .73698 .54283 L .72384 .53288 L p .219 .604 .95 r
F P
0 g
s
.51849 .29301 m .52345 .26918 L .49982 .22091 L p .304 .289 .677 r
F P
0 g
s
.6285 .47377 m .61456 .468 L .62977 .48337 L p 0 .376 .84 r
F P
0 g
s
.62977 .48337 m .64487 .4889 L .6285 .47377 L p 0 .376 .84 r
F P
0 g
s
.75619 .54361 m .73698 .54283 L .74875 .55402 L p .302 .589 .943 r
F P
0 g
s
.74875 .55402 m .76874 .55745 L .75619 .54361 L p .302 .589 .943 r
F P
0 g
s
.56397 .40778 m .57379 .41025 L .55405 .37975 L p 0 .188 .712 r
F P
0 g
s
.57379 .41025 m .56397 .40778 L .58156 .43066 L p 0 .208 .734 r
F P
0 g
s
.61115 .45641 m .59846 .45061 L .61456 .468 L p 0 .32 .807 r
F P
0 g
s
.61456 .468 m .6285 .47377 L .61115 .45641 L p 0 .32 .807 r
F P
0 g
s
.67662 .50804 m .66016 .50236 L .67432 .5145 L p .054 .479 .887 r
F P
0 g
s
.67432 .5145 m .69169 .51935 L .67662 .50804 L p .054 .479 .887 r
F P
0 g
s
.58156 .43066 m .59287 .43568 L .57379 .41025 L p 0 .208 .734 r
F P
0 g
s
.59287 .43568 m .58156 .43066 L .59846 .45061 L p 0 .259 .769 r
F P
0 g
s
.59846 .45061 m .61115 .45641 L .59287 .43568 L p 0 .259 .769 r
F P
0 g
s
.53388 .34582 m .54059 .33743 L .51849 .29301 L p .105 .194 .673 r
F P
0 g
s
.54059 .33743 m .53388 .34582 L .55405 .37975 L p 0 .096 .636 r
F P
0 g
s
.52345 .26918 m .51849 .29301 L .54059 .33743 L p .023 .103 .609 r
F P
0 g
s
.70935 .52417 m .69169 .51935 L .70545 .52976 L p .114 .569 .917 r
F P
0 g
s
.70545 .52976 m .72384 .53288 L .70935 .52417 L p .114 .569 .917 r
F P
0 g
s
.66029 .49516 m .64487 .4889 L .66016 .50236 L p 0 .416 .853 r
F P
0 g
s
.66016 .50236 m .67662 .50804 L .66029 .49516 L p 0 .416 .853 r
F P
0 g
s
.74237 .5339 m .72384 .53288 L .73698 .54283 L p .297 .665 .973 r
F P
0 g
s
.73698 .54283 m .75619 .54361 L .74237 .5339 L p .297 .665 .973 r
F P
0 g
s
.77535 .54036 m .75619 .54361 L .76874 .55745 L p .352 .517 .881 r
F P
0 g
s
.76874 .55745 m .78911 .56236 L .77535 .54036 L p .352 .517 .881 r
F P
0 g
s
.55405 .37975 m .56254 .38128 L .54059 .33743 L p 0 .096 .636 r
F P
0 g
s
.56254 .38128 m .55405 .37975 L .57379 .41025 L p 0 .054 .62 r
F P
0 g
s
.52829 .23628 m .52345 .26918 L .54746 .33059 L p 0 0 .529 r
F P
0 g
s
.54059 .33743 m .54746 .33059 L .52345 .26918 L p .023 .103 .609 r
F P
0 g
s
.64278 .48077 m .6285 .47377 L .64487 .4889 L p 0 .358 .816 r
F P
0 g
s
.64487 .4889 m .66029 .49516 L .64278 .48077 L p 0 .358 .816 r
F P
0 g
s
.69342 .51435 m .67662 .50804 L .69169 .51935 L p 0 .478 .863 r
F P
0 g
s
.69169 .51935 m .70935 .52417 L .69342 .51435 L p 0 .478 .863 r
F P
0 g
s
.53279 .18627 m .52829 .23628 L .55454 .32691 L p 0 0 .442 r
F P
0 g
s
.55454 .32691 m .56195 .32964 L .53279 .18627 L p 0 0 .442 r
F P
0 g
s
.57379 .41025 m .58398 .41785 L .56254 .38128 L p 0 .054 .62 r
F P
0 g
s
.58398 .41785 m .57379 .41025 L .59287 .43568 L p 0 .09 .643 r
F P
0 g
s
.6242 .46469 m .61115 .45641 L .6285 .47377 L p 0 .286 .767 r
F P
0 g
s
.6285 .47377 m .64278 .48077 L .6242 .46469 L p 0 .286 .767 r
F P
0 g
s
.54746 .33059 m .54059 .33743 L .56254 .38128 L p 0 0 .518 r
F P
0 g
s
.54746 .33059 m .55454 .32691 L .52829 .23628 L p 0 0 .529 r
F P
0 g
s
.72732 .52908 m .70935 .52417 L .72384 .53288 L p .108 .629 .882 r
F P
0 g
s
.72384 .53288 m .74119 .53383 L p .72732 .52908 L .108 .629 .882 r
F P
0 g
s
.70935 .52417 m .72732 .52908 L .71064 .52238 L p 0 .442 .768 r
F P
0 g
s
.72854 .53579 m .71306 .5242 L p .72732 .52908 L .343 0 0 r
F P
0 g
s
.71306 .5242 m .71064 .52238 L .72732 .52908 L p .343 0 0 r
F P
0 g
s
.74119 .53383 m .74237 .5339 L .72732 .52908 L p .108 .629 .882 r
F P
0 g
s
.7608 .52977 m .74237 .5339 L .75619 .54361 L p .479 .75 .989 r
F P
0 g
s
.75619 .54361 m .77535 .54036 L .7608 .52977 L p .479 .75 .989 r
F P
0 g
s
.60459 .44491 m .59287 .43568 L .61115 .45641 L p 0 .187 .701 r
F P
0 g
s
.61115 .45641 m .6242 .46469 L .60459 .44491 L p 0 .187 .701 r
F P
0 g
s
.59287 .43568 m .60459 .44491 L .58398 .41785 L p 0 .09 .643 r
F P
0 g
s
.67603 .50178 m .66029 .49516 L .67662 .50804 L p 0 .394 .825 r
F P
0 g
s
.67662 .50804 m .69342 .51435 L .67603 .50178 L p 0 .394 .825 r
F P
0 g
s
.56254 .38128 m .57143 .39006 L .54746 .33059 L p 0 0 .518 r
F P
0 g
s
.57015 .39426 m .58398 .41785 L p .57143 .39006 L 0 0 .442 r
F P
0 g
s
.59471 .43401 m .58398 .41785 L .60161 .441 L p .561 .082 0 r
F P
0 g
s
.60161 .441 m .60459 .44491 L p .59471 .43401 L .561 .082 0 r
F P
0 g
s
.59471 .43401 m .60628 .46496 L .58801 .42722 L p .784 .381 0 r
F P
0 g
s
.58398 .41785 m .59471 .43401 L p .58324 .41622 L 0 0 .442 r
F P
0 g
s
.59471 .43401 m .57143 .39006 L p .58324 .41622 L 0 0 .442 r
F P
0 g
s
.58801 .42722 m .58099 .41272 L p .59471 .43401 L .784 .381 0 r
F P
0 g
s
.58099 .41272 m .57143 .39006 L .57998 .40619 L p .784 .381 0 r
F P
0 g
s
.57998 .40619 m .59471 .43401 L p .58099 .41272 L .784 .381 0 r
F P
0 g
s
.58099 .41272 m .59176 .46291 L .582 .41926 L p .716 .455 0 r
F P
0 g
s
.57143 .39006 m .58099 .41272 L .57271 .38587 L p 0 0 .341 r
F P
0 g
s
.56195 .32964 m .55454 .32691 L .58099 .41272 L p .716 .455 0 r
F P
0 g
s
.582 .41926 m .56195 .32964 L p .58099 .41272 L .716 .455 0 r
F P
0 g
s
.57271 .38587 m .55454 .32691 L p .57143 .39006 L 0 0 .341 r
F P
0 g
s
.57143 .39006 m .56254 .38128 L .57015 .39426 L p 0 0 .442 r
F P
0 g
s
.71064 .52238 m .69342 .51435 L .70935 .52417 L p 0 .442 .768 r
F P
0 g
s
.65737 .48794 m .64278 .48077 L .66029 .49516 L p 0 .347 .794 r
F P
0 g
s
.66029 .49516 m .67603 .50178 L .65737 .48794 L p 0 .347 .794 r
F P
0 g
s
.74237 .5339 m .7608 .52977 L .74565 .53453 L p 0 0 0 r
F P
0 g
s
.74565 .53453 m .72732 .52908 L .74237 .5339 L p 0 0 0 r
F P
0 g
s
.55454 .32691 m .54746 .33059 L .57143 .39006 L p 0 0 .341 r
F P
0 g
s
.64278 .48077 m .65737 .48794 L .63763 .47486 L p 0 .281 .715 r
F P
0 g
s
.63763 .47486 m .65134 .48442 L .65022 .48428 L p .496 0 0 r
F P
0 g
s
.62529 .46564 m .64278 .48077 L p .63763 .47486 L 0 .281 .715 r
F P
0 g
s
.65022 .48428 m .62962 .48171 L p .63763 .47486 L .496 0 0 r
F P
0 g
s
.63763 .47486 m .6242 .46469 L .62529 .46564 L p 0 .281 .715 r
F P
0 g
s
.6168 .45977 m .60459 .44491 L .6242 .46469 L p .438 0 0 r
F P
0 g
s
.6242 .46469 m .63763 .47486 L .6168 .45977 L p .438 0 0 r
F P
0 g
s
.6921 .50859 m .67603 .50178 L .69342 .51435 L p 0 .329 .775 r
F P
0 g
s
.69342 .51435 m .71064 .52238 L .6921 .50859 L p 0 .329 .775 r
F P
0 g
s
.60459 .44491 m .6168 .45977 L .59471 .43401 L p .561 .082 0 r
F P
0 g
s
.72732 .52908 m .74565 .53453 L .72854 .53579 L p .343 0 0 r
F P
0 g
s
.67214 .49275 m .65737 .48794 L .67603 .50178 L p 0 .347 .803 r
F P
0 g
s
.67603 .50178 m .6921 .50859 L .67214 .49275 L p 0 .347 .803 r
F P
0 g
s
.64201 .47777 m .65737 .48794 L p .65134 .48442 L 0 .381 .718 r
F P
0 g
s
.65737 .48794 m .67214 .49275 L .65134 .48442 L p 0 .381 .718 r
F P
0 g
s
.66498 .4863 m .65134 .48442 L .67214 .49275 L p .261 .739 .935 r
F P
0 g
s
.65134 .48442 m .66498 .4863 L .66076 .49114 L p .221 0 .037 r
F P
0 g
s
.66076 .49114 m .64316 .51132 L p .65134 .48442 L .221 0 .037 r
F P
0 g
s
.65134 .48442 m .63763 .47486 L .64201 .47777 L p 0 .381 .718 r
F P
0 g
s
.70857 .51665 m .6921 .50859 L .71064 .52238 L p 0 .156 .657 r
F P
0 g
s
.71064 .52238 m .72854 .53579 L .70857 .51665 L p 0 .156 .657 r
F P
0 g
s
.62962 .48171 m .6168 .45977 L .63763 .47486 L p .496 0 0 r
F P
0 g
s
.60628 .46496 m .59471 .43401 L .6168 .45977 L p .76 .247 0 r
F P
0 g
s
.6168 .45977 m .62962 .48171 L .60628 .46496 L p .76 .247 0 r
F P
0 g
s
.68679 .48995 m .67214 .49275 L .6921 .50859 L p 0 .301 .796 r
F P
0 g
s
.6921 .50859 m .70857 .51665 L .68679 .48995 L p 0 .301 .796 r
F P
0 g
s
.67214 .49275 m .68679 .48995 L .66498 .4863 L p .261 .739 .935 r
F P
0 g
s
.59176 .46291 m .58099 .41272 L .60628 .46496 L p .92 .525 .177 r
F P
0 g
s
.64316 .51132 m .62962 .48171 L .65134 .48442 L p .221 0 .037 r
F P
0 g
s
.61928 .52249 m .60628 .46496 L .62962 .48171 L p .658 .259 .277 r
F P
0 g
s
.62962 .48171 m .64316 .51132 L .61928 .52249 L p .658 .259 .277 r
F P
0 g
s
.60628 .46496 m .61928 .52249 L .59176 .46291 L p .92 .525 .177 r
F P
0 g
s
.25 Mabswid
.12983 0 m
.94587 .1381 L
s
.94587 .1381 m
1 .56832 L
s
1 .56832 m
.09237 .4558 L
s
.09237 .4558 m
.12983 0 L
s
.03558 .4252 m
0 .79557 L
s
0 .79557 m
.09237 .4558 L
s
.09237 .4558 m
.12983 0 L
s
.12983 0 m
.03558 .4252 L
s
.03558 .4252 m
.12983 0 L
s
.03728 .41755 m
.04416 .41843 L
s
[(-1)] .02352 .4158 1 .12703 Mshowa
.05545 .33556 m
.06232 .33649 L
s
[(-0.5)] .04171 .3337 1 .13526 Mshowa
.07606 .24256 m
.08293 .24355 L
s
[(0)] .06234 .24057 1 .14463 Mshowa
.09964 .13618 m
.10649 .13724 L
s
[(0.5)] .08594 .13405 1 .15539 Mshowa
.12688 .01331 m
.13371 .01446 L
s
[(1)] .1132 .01101 1 .16788 Mshowa
.125 Mabswid
.04074 .40194 m
.04487 .40247 L
s
.04428 .38595 m
.04841 .38648 L
s
.04792 .36956 m
.05204 .37011 L
s
.05164 .35277 m
.05576 .35332 L
s
.05936 .3179 m
.06349 .31847 L
s
.06338 .2998 m
.0675 .30037 L
s
.0675 .28122 m
.07162 .28179 L
s
.07172 .26214 m
.07584 .26273 L
s
.08052 .22244 m
.08464 .22304 L
s
.08511 .20177 m
.08922 .20238 L
s
.08982 .18051 m
.09393 .18113 L
s
.09466 .15866 m
.09877 .15929 L
s
.10477 .11304 m
.10888 .11369 L
s
.11005 .08921 m
.11416 .08987 L
s
.11549 .06467 m
.1196 .06534 L
s
.1211 .03938 m
.1252 .04006 L
s
gsave
-0.00628 .23065 -71 -10.8678 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.94587 .1381 m
1 .56832 L
s
.95032 .17352 m
.94348 .17239 L
s
[(0)] .964 .17578 -1 -0.16553 Mshowa
.96065 .25559 m
.9538 .25452 L
s
[(0.25)] .97435 .25774 -1 -0.15693 Mshowa
.97141 .3411 m
.96455 .34008 L
s
[(0.5)] .98513 .34313 -1 -0.14794 Mshowa
.98263 .43025 m
.97576 .4293 L
s
[(0.75)] .99636 .43215 -1 -0.13855 Mshowa
.99433 .52328 m
.98746 .5224 L
s
[(1)] 1.00809 .52505 -1 -0.12873 Mshowa
.125 Mabswid
.95236 .18967 m
.94825 .189 L
s
.9544 .20595 m
.9503 .20528 L
s
.95647 .22236 m
.95236 .22171 L
s
.95855 .23891 m
.95444 .23826 L
s
.96277 .27241 m
.95866 .27178 L
s
.9649 .28937 m
.96079 .28874 L
s
.96705 .30647 m
.96294 .30585 L
s
.96922 .32371 m
.96511 .3231 L
s
.97362 .35863 m
.9695 .35803 L
s
.97584 .37631 m
.97172 .37571 L
s
.97808 .39414 m
.97396 .39355 L
s
.98035 .41212 m
.97623 .41154 L
s
.98493 .44854 m
.98081 .44797 L
s
.98725 .46698 m
.98313 .46643 L
s
.98959 .48559 m
.98547 .48504 L
s
.99195 .50435 m
.98783 .50382 L
s
.94831 .1575 m
.9442 .15681 L
s
.94631 .1416 m
.94221 .14091 L
s
.99674 .54238 m
.99261 .54186 L
s
.99916 .56164 m
.99503 .56113 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 246.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001LR000`400?l00000o`00003ooooooona
ooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00oooooona
ooooo`00oooooonaooooo`00hOooool6o`000<Wooooo003Qooooo`03oiRHV?mEEEGooooo00;ooooo
00?o0000ooooooooool0aoooool00>;ooooo00?oV9RHoeEEEOooool0boooool0053ooooo1?l00000
0ol@413oooooooooo`2<ooooo`03oiRHV?mEEEGooooo0<[ooooo001Booooo`03o`000?oooooooooo
08oooooo00?oV9RHoeEEEOooool0bOooool005;ooooo00?o0000ooooooooool0S?ooool01_l0003o
ooooooooooooooooV9RHoeEEELWooooo0016ooooo`Oo00001Oooool00ol0003oooooooooo`2<oooo
o`Ko0000bOooool005;ooooo00?o0000ooooooooool0oooooomLooooo`00D_ooool00ol0003ooooo
ooooo`3ooooooecooooo001Booooo`03o`000?oooooooooo0?ooooooG?ooool0053ooooo00?o0000
odA4A?l00000oooooomNooooo`00D?ooool00oo<c<coEEEEo`00003ooooooekooooo003ooooook7o
oooo003ooooook7ooooo003ooooook7ooooo003ooooook7ooooo0015ooooo`Co0000Boooool01?nj
^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo00KoV9RHoa0@4?l0003o0000odA4
A?o^k^koooooo`Kooooo000gooooo`Co000000?o410@ooooooooool01oooool01?l0003ooooooooo
ooooool6o`0004Cooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool01_l@
413oQhN7ooooooooooooMgMgodA4A?oooooo1_ooool003Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooo000000Go0000?_ooool01_m4A4CoZJVYoooooooo
ooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED02Oooool00ol0003oooooooooo`3oooooo`Cooooo
000iooooo`03o`000?oooooooooo00Sooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo1_l0
000_ooooo`Oo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o
k^k^o`000?ooool0ooooool5ooooo`00>Oooool00ol0003oooooooooo`08ooooo`;o00001_ooool0
0ol0003oooooooooo`0<ooooo`Ko0000<_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00Ko410@oiRHV?ooooooooooogMgMomVIVKoooooo`Kooooo000iooooo`03o`000?oo
oooooooo00Sooooo0_l0000Fooooo`03o`000?oooooooooo00;ooooo1Ol0000]ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?l0003oIVIV0?oooooo
1oooool003Wooooo00?o0000ooooooooool02?ooool3o`0001Gooooo00?o0000ooooooooool01ooo
ool6o`0002Oooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooooooo0?oo
oooo2Oooool003Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`Ko0000
8Oooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00?o0000ooooooooool0ooooool9oooo
o`00=oooool00ol0003oA4A4o`000009ooooo`;o00009oooool00ol0003oooooooooo`03ooooo`Ko
00007?ooool01?nj^[[o410@oa0@4?o<c<`=ooooo`Go0000ooooool7ooooo`00=oooool00oo<c<co
EEEEo`000009ooooo`;o00009oooool00ol0003oooooooooo`09ooooo`Ko0000oooooolcooooo`00
@oooool2o`0003Kooooo00?o0000ooooooooool01_l0003oooooobgooooo0013ooooo`;o0000=_oo
ool00ol0003oooooooooo`06ooooo`Ko0000oooooolWooooo`00@_ooool00ol0003oooooo`000015
ooooo`Ko0000D_ooool01?nj^[[o410@o`000?mgMgO:ooooo`00@_ooool00ol0003oooooo`000016
ooooo`03o`000?oooooooooo00;ooooo1_l0001;ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY
bOooool004;ooooo00?o0000ooooool00000A_ooool00ol0003oooooooooo`08ooooo`Ko0000AOoo
ool01_m4A4CoZJVYooooooooooooZJVYoc8b</Wooooo0011ooooo`Co0000EOooool00ol0003ooooo
o`000005o`0003oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`37ooooo`00@_oo
ool00ol0003oooooo`00001Eooooo`03o`000?oooooooooo00Gooooo1Ol0000jooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0aoooool0047ooooo00Co0000oooooooooooo0000EOoo
ool00ol0003oooooooooo`0:ooooo`Ko0000=?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0<Oooooo0011ooooo`04o`000?ooooooooooo`0006Cooooo00Co0000oooooooooooooooo
1_l0000^ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A4bOooool0047ooooo00?o0000ooooool0
0000IOooool00ol0003oooooooooo`07ooooo`Ko0000:?ooool01_o<c<co<S8bonk^k_o^k^ko<S8b
olc<c<Wooooo0011ooooo`03o`000?oooooo000007Cooooo1ol0000Sooooo`04okZj^_l@413o410@
olc<c<[ooooo0010ooooo`04o`000?ooooooooooo`0007Cooooo00?o0000ooooooooool01?ooool6
o`000>_ooooo0010ooooo`04o`000?ooooooooooo`0007Cooooo00?o0000ooooooooool02_ooool6
o`000>Gooooo0010ooooo`04o`000?ooooooooooo`0008?ooooo00Co0000oooooooooooooooo1_l0
003Oooooo`00@?ooool01?l0003oooooooooool00023ooooo`03o`000?oooooooooo00Oooooo1_l0
0018ooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool01_nHV9So410@
o`000?l0003oA4A4onk^kW[ooooo000oooooo`?o000000?oooooo`000?ooool0TOooool7o`00047o
oooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool01_l@413oQhN7oooooooo
ooooMgMgodA4A7[ooooo000oooooo`05o`000?ooooooooooooooool00000T_ooool00ol0003ooooo
ooooo`04ooooo`Go0000??ooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`00
0?mEEED02Oooool00ol0003oooooooooo`1hooooo`00?oooool01Ol0003ooooooooooooooooo0000
09;ooooo00?o0000ooooooooool02Oooool6o`0003Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0>ooooo`03onk^k_l0003ooooo07Wooooo000oooooo`05o`000?oooooooooooooo
ool00000XOooool00ol0003oooooooooo`06o`00033ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIVN_ooool003oooooo00Go0000
ooooooooooooooooo`00002Qooooo`03o`000?oooooooooo00Kooooo1_l0000Zooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?l0003oIVIV07_ooooo
000nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Woooool00ol0003ooooooooo
o`0;ooooo`Oo00009?ooool01_m4A4CoZJVYooooooooooooZJVYodA4A0cooooo00?o0000oooooooo
ool0OOooool003kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2]ooooo`03o`00
0?oooooooooo00Cooooo1_l0000Nooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool00ol0
003oooooooooo`1mooooo`00?_ooool01Ol0003ooooooooooooooooo00000;gooooo1_l0000Ioooo
o`04okZj^_l@413o410@olc<c0gooooo1Ol0001kooooo`00?_ooool01Ol0003ooooooooooooooooo
000008Gooooo0_l0000gooooo`03o`000?oooooooooo00;ooooo1_l0002Tooooo`00?Oooool3o`00
00;ooooo00?o0000ooooooooool0P_ooool00ol0003o/HBUok64Y@02o`0003Kooooo00?o0000oooo
ooooool01oooool6o`0009kooooo000mooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0POooool00ol0003odjJXok64Y@03ok64Y@;o0000@_ooool00ol0003oooooo`000005o`0009So
oooo000mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0P?ooool01?l0003odjJX
om>VZ?l00005ok64Y@;o0000@?ooool00ol0003oooooooooo`05ooooo`Go0000D?ooool4o`000003
oa0@4?oooooooooo03cooooo000mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
Ooooool01Ol0003odjJXom>VZ?oCYZSo000000Oo/HBU0_l0001;ooooo`Ko0000C?ooool00ol0003o
ooooooooo`0nooooo`00?Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07kooooo
00?o0000om>VZ?oCYZP00_oCYZP00ol0003o/HBUok64Y@07ok64Y@03o`000?oooooooooo04Wooooo
00?o0000ooooooooool00_ooool6o`0004Kooooo00?o0000ooooooooool0?_ooool003cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`03o`000?oCYZSodjJX00?odjJX00?o
0000ok64YOnaQ:D01onaQ:D00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Sooooo1_l0
0010ooooo`03o`000?oooooooooo03kooooo000looooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0F?ooool7o`0001gooooo00?o0000om>VZ?oCYZP01?oCYZP00ol0003o/HBUok64Y@07
ok64Y@03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_l0000jooooo`03o`000?oooooo
oooo03kooooo000looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0D_ooool6o`00
00GoZI[70_m_Om800ol0003oooooooooo`0Iooooo`03o`000?oCYZSodjJX00GodjJX00?o0000ok64
YOnaQ:D01onaQ:D00omOAIco0000ooooo`1Gooooo`03o`000?oooooooooo00Kooooo1_l0000doooo
o`03o`000?oooooooooo03kooooo000looooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0DOooool00ol0003o`jk5o`000009ojVJa`03o`000?m_Om;oKgoB00;o00005oooool2o`0000So
djJX00?o0000ok64YOnaQ:D01onaQ:D2o`0005Sooooo00?o0000ooooooooool02oooool7o`0002ko
oooo00?o0000ooooooooool0?_ooool003_ooooo0ol00004ooooo`03o`000?oooooooooo053ooooo
00Co0000ol>^aOo3[/Go00002OnYV/L00ol0003oKgoBofmodP02ofmodP03o`000?oooooooooo01?o
oooo00?o0000om>i`?l000002?oCYZP00ol0003o/HBUok64Y@07ok64Y@;o0000I_ooool00ol0003o
ooooooooo`04ooooo`Ko00009_ooool00ol0003oA4A4o`000010ooooo`00>oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04oooooo0_l00003ol>^a@03o`000?nYV/OoZI[700OoZI[7
00?o0000ofmod_m_Om800om_Om82o`00017ooooo0_l00002om>i`003o`000?oCYZSodjJX00KodjJX
00?o0000ok64YOnaQ:D01onaQ:D00ol0003oGdFLo`00001Uooooo`03o`000?oooooooooo00[ooooo
1_l0000Pooooo`03olc<c?mEEEGo0000043ooooo000kooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0C_ooool00ol0003o`jk5ol>^a@04ol>^a@03o`000?nYV/OoZI[700KoZI[700?o
0000ofmod_m_Om801Om_Om800ol0003oooooooooo`0=ooooo`03o`000?oC^L3odkW000;odkW000?o
0000om>VZ?oCYZP01_oCYZP00ol0003o/HBUok64Y@07ok64Y@03o`000?mOAIco000007?ooooo00?o
0000ooooooooool00_ooool6o`0005gooooo000kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0COooool00ol0003o`jk5ol>^a@05ol>^a@03o`000?nYV/OoZI[700KoZI[700?o0000
ofmod_m_Om801_m_Om83o`0000_ooooo00?o0000om>i`?oC^L000ooC^L000ol0003odjJXom>VZ006
om>VZ003o`000?naQ:Go/HBU00Oo/HBU00?o0000oem5W?l00000Loooool00ol0003oooooooooo`08
ooooo`Ko0000Eoooool001_ooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04
ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^2Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo04cooooo00?o0000ol>^aOo3[/D01_o3[/D00ol0003oZI[7ojVJa`07ojVJa`03o`00
0?m_Om;oKgoB00GoKgoB00?o0000oh6IhOn1VN400ol00006ooooo`;o00001_oC^L000ol0003odjJX
om>VZ006om>VZ003o`000?naQ:Go/HBU00Oo/HBU00Co0000oem5W?mOAIco0000P?ooool00ol0003o
ooooooooo`05o`0005;ooooo000Jooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`00
00Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@8ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0B_ooool2o`0000Wo`jk500?o0000ojVJaonYV/L01onYV/L00ol0003oKgoBofmo
dP05ofmodP03o`000?n1VN7oPIWQ00?oPIWQ0ol00002ooooo`03o`000?oC^L3odkW000KodkW000?o
0000om>VZ?oCYZP01_oCYZP00ol0003o/HBUok64Y@07ok64Y@04o`000?mOAIcoGdFLo`00083ooooo
00?o0000ooooooooool01Oooool6o`0004cooooo000Jooooo`06odA4A?nYZJWooooooooooonYZJWo
<S8b1Oooool00omEEEGo0000oeEEE@09ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`18ooooo`;o000000?o^kkLo`000?o3[/D02?o3[/D00ol0003o
ZI[7ojVJa`07ojVJa`03o`000?m_Om;oKgoB00GoKgoB00?o0000oh6IhOn1VN401_n1VN42o`0000Wo
dkW000?o0000om>VZ?oCYZP01_oCYZP00ol0003o/HBUok64Y@07ok64Y@04o`000?mOAIcoGdFLo`00
08gooooo1ol00016ooooo`006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00ko
oooo00?ok^k^o`000?ooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033o
oooo1_l0000?ooooo`?o00000onk_]`00ol0003o`jk5ol>^a@08ol>^a@03o`000?nYV/OoZI[700Ko
ZI[700?o0000ofmod_m_Om801Om_Om800ol0003oPIWQoh6Ih@07oh6Ih@03o`000?oC^L3odkW000Oo
dkW000?o0000om>VZ?oCYZP01_oCYZP00ol0003o/HBUok64Y@07ok64Y@05o`000?mOAIcoGdFLoem5
W?l00000S?ooool00ol0003oooooooooo`04ooooo`Ko0000@?ooool001[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0:ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV2?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02kooooo0_l000000onSXM?o0000of^Ci`03
of^Ci`Wo00001?ooool2o`0000Oo^kkL00?o0000ol>^aOo3[/D01oo3[/D00ol0003oZI[7ojVJa`06
ojVJa`03o`000?m_Om;oKgoB00KoKgoB00?o0000oh6IhOn1VN401_n1VN400ol0003odkW0om>i`007
om>i`003o`000?oCYZSodjJX00KodjJX00?o0000ok64YOnaQ:D01onaQ:D01Ol0003oGdFLoem5W?mO
AIco000009Wooooo1_l0000jooooo`006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00Go0000ob4Q8Ol0003o0000ofIVIP08ooooo`Co00001?ooool00ol0003ooooooooo
o`0/ooooo`;o00001?nSXM<00ol0003oJi?Wof^Ci`04of^Ci`03o`000?m/YoCoK:Od00?oK:Od1?l0
0009ok^ng003o`000?o3[/Go`jk500Ko`jk53Ol00006ofmodP03o`000?n1VN7oPIWQ00KoPIWQ00?o
0000om>i`?oC^L001ooC^L000ol0003odjJXom>VZ006om>VZ003o`000?naQ:Go/HBU00Ko/HBU00?o
0000oem5W?mOAI`00_mOAI`00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00;ooooo0ol0
000gooooo`006_ooool01_m4A4CoZJVYooooooooooooZJVYodA4A0cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02[ooooo0_l00006oj>Qd`03o`00
0?m[TnOoJi?W00GoJi?W00?o0000ofbWm?m/Yo@01Om/Yo@00ol0003o^kkLok^ng007ok^ng003o`00
0?o3[/Go`jk500?o`jk50ol000000on`Yloo0000oj>LcP07oj>LcP?oTi?@1Ol000000om_Om;o0000
oh6Ih@07oh6Ih@03o`000?oC^L3odkW000OodkW000?o0000om>VZ?oCYZP01_oCYZP00ol0003o/HBU
ok64Y@06ok64Y@03o`000?mOAIcoGdFL00?oGdFL00?o0000ooooooooool0Uoooool00ol0003ooooo
ooooo`02ooooo`?o0000=oooool001[ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`;o
00002OnSXM<00ol0003oJi?Wof^Ci`04of^Ci`03o`000?m/YoCoK:Od00KoK:Od00?o0000ok^ng?nk
_]`01onk_]`00ol0003o`jk5o`000002o`0000Co/:O?00?o0000oj>Lc_nSW<h01_nSW<h00ol0003o
Ti?@oi>Cd005oi>Cd0Co00001_n1VN400ol0003odkW0om>i`007om>i`003o`000?oCYZSodjJX00Ko
djJX00?o0000ok64YOnaQ:D01_naQ:D00ol0003oGdFLoem5W003oem5W003o`000?oooooooooo09Oo
oooo00?o0000ooooooooool00oooool2o`0003Oooooo000Kooooo`04okZj^_l@413o410@olc<c0go
oooo1Ol00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003o
^:o@o`000009oj>Qd`03o`000?m[TnOoJi?W00GoJi?W00?o0000ofbWm?m/Yo@01_m/Yo@00ol0003o
^kkLok^ng004ok^ng004o`000?nk_]co0000o`0000So/:O?00?o0000oj>Lc_nSW<h01_nSW<h00ol0
003oTi?@oi>Cd005oi>Cd0?oWi[>1Ol000000on1VN7o0000om>i`003om>i`0oo00002?naQ:D00ol0
003oGdFLoem5W003oem5W003o`000?oooooooooo09cooooo00?o0000ooooool00000=oooool003Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`05o`000?nh[m3o^:o@okR_
d?l000002?nSXM<00ol0003oJi?Wof^Ci`06of^Ci`03o`000?m/YoCoK:Od00GoK:Od00?o0000ok^n
g?nk_]`01?l00002ojZ^fP03o`000?n`Yloo/:O?00Oo/:O?00?o0000oj>Lc_nSW<h01_nSW<h00ol0
003oTi?@oi>Cd005oi>Cd003o`000?nOV/koWi[>00GoWi[>1_l00005okNP`@Wo]YBd00?o0000ok64
YOnaQ:D01_naQ:D00ol0003oGdFLoem5W003oem5W003o`000?oooooooooo09_ooooo00Co0000oooo
oooooooo0000=oooool003Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Voooo
o`03o`000?nh[m3o^:o@00;o^:o@00?o0000oj>QdonSXM<01onSXM<00ol0003oJi?Wof^Ci`05of^C
i`03o`000?m/YoCoK:Od00;oK:Od1_l00007ojZ^fP03o`000?n`Yloo/:O?00Ko/:O?00?o0000oj>L
c_nSW<h01_nSW<h00ol0003oTi?@oi>Cd005oi>Cd003o`000?nOV/koWi[>00KoWi[>2_ngX<400ol0
003o]YBdokJD]006okJD]003oiQh[_l0003o/HBU00Ko/HBU00?o0000oem5W?mOAI`01?mOAI`00ol0
003oooooooooo`2Jooooo`05o`000?ooooooooooooooool00000=_ooool003Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?nh[m3o^:o@00Co^:o@00?o0000oj>Q
donSXM<01_nSXM<00ol0003oJi?Wof^Ci`02of^Ci`So00001?nCZN@00ol0003oZZkJojZ^fP06ojZ^
fP03o`000?n`Yloo/:O?00Ko/:O?00?o0000oj>Lc_nSW<h01_nSW<h00ol0003oTi?@oi>Cd005oi>C
d003o`000?nOV/koWi[>00KoWi[>00?o0000okNP`OngX<401ongX<400ol0003o]YBdokJD]006okJD
]003o`000?nHN:ko000000Ko/HBU00?o0000oem5W?mOAI`01?mOAI`00ol0003oooooooooo`2Ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=?ooool003Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?nh[m3o^:o@00Ko^:o@00?o0000oj>QdonS
XM<01?nSXM<6o`0000CoSJ?S00?o0000oi>Yi?nCZN@01_nCZN@00ol0003oZZkJojZ^fP06ojZ^fP03
o`000?n`Yloo/:O?00Go/:O?00?o0000oj>Lc_nSW<h01_nSW<h00ol0003oTi?@oi>Cd006oi>Cd003
o`000?nOV/koWi[>00GoWi[>00?o0000okNP`OngX<401ongX<400ol0003o]YBdokJD]006okJD]004
o`000?nHN:koV7R^o`0000Go/HBU00?o0000oem5W?mOAI`01?mOAI`00ol0003oooooooooo`2Hoooo
o`07o`000?ooooooooooooooool0003oooooo`00000fooooo`00=oooool3o`0000Kooooo00?o0000
ooooooooool08oooool00ol0003o^:o@okR_d007okR_d003o`000?nSXM?oXj7C00Co00000_nMY]`0
0ol0003oSJ?SohfSh`06ohfSh`03o`000?nCZNCoTjWT00GoTjWT00?o0000ojZ^f_nZ[]X01_nZ[]X0
0ol0003o/:O?ok2Wc`06ok2Wc`03o`000?nSW<koXic>00KoXic>00?o0000oi>Cd?nCTm001OnCTm00
0ol0003oWi[>oinJcP05oinJcP03o`000?ngX<7o]j3100Oo]j3100?o0000okJD]?nfU;@01_nfU;@0
1Ol0003oV7R^oiQh[_nHN:ko000000Co/HBU00?o0000oem5W?mOAI`01OmOAI`00ol0003ooooooooo
o`2Fooooo`03o`000?oooooooooo00?ooooo0_l0000fooooo`00=oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo027ooooo0_l0000;okR_d0;o00001onMY]`00ol0003oSJ?SohfSh`05
ohfSh`03o`000?nCZNCoTjWT00KoTjWT00?o0000ojZ^f_nZ[]X01OnZ[]X00ol0003o/:O?ok2Wc`02
ok2Wc`[o00000onSW<h00ol0003oTi?@oi>Cd005oi>Cd003o`000?nOV/koWi[>00KoWi[>00?o0000
okNP`OngX<401_ngX<400ol0003o]YBdokJD]006okJD]003o`000?nHN:koV7R^00;oV7R^00Go0000
ok64YOnaQ:Go/HBUo`000007oem5W003o`000?oooooooooo09Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0dooooo`00=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01oooooo0_l00002ojg2j@03o`000?nh[m3o^:o@00Ko^:o@00?o0000ojN]fol000002?nMY]`0
0ol0003oSJ?SohfSh`06ohfSh`03o`000?nCZNCoTjWT00GoTjWT00?o0000ojZ^f_nZ[]X01?nZ[]X6
o`0000CoXj7C00?o0000oijKd?nNVm000onNVm08o`0000?oTi?@00?o0000oinJc_nOV/h01_nOV/h0
0ol0003o]j31okNP`@05okNP`@03o`000?nfU;Co]YBd00Oo]YBd00?o0000oiQh[_nHN:h00onHN:h0
1?l0003o/HBUok64YOl00007oem5W003o`000?oooooooooo09Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0dooooo`00=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01kooooo00?o0000ojg2jOn]`^T00on]`^T00ol0003o^:o@okR_d003okR_d0;o00000onW[M/0
0ol0003oWJKLoifVg006oifVg003o`000?n=Xn?oSJ?S00GoSJ?S00?o0000oi>Yi?nCZN@01OnCZN@0
0ol0003oZZkJojZ^fP04o`0000;oXJGI00?o0000oj>QdonSXM<01OnSXM<00ol0003oWY_@oijKd006
oijKd0GoVIG>1_l00006oinJcP03o`000?ngX<7o]j3100Go]j3100?o0000okJD]?nfU;@01onfU;@0
0ol0003oV7R^oiQh[P04oiQh[P03o`000?naQ:Go000000SoGdFL00?o0000ooooooooool0Toooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Cooooo000gooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool07?ooool2o`0000Oo[L;Y00Go0000okR_d?nh[m3o^:o@o`000006
ojN]f`03o`000?nMY]coWJKL00KoWJKL00?o0000ohfShon=Xn<01?n=Xn<00ol0003oTjWToi>Yi002
oi>Yi0Ko00001_nQYMT00ol0003oXj7Coj>Qd`06oj>Qd`03o`000?nNVm3oWY_@00GoWY_@00?o0000
oiVEc_nIULh01OnIULh3oifDbPGo000000?oWi[>o`000?ngX<401_ngX<400ol0003o]YBdokJD]007
okJD]003o`000?nHN:koV7R^00GoV7R^0_l00008oem5W003o`000?oooooooooo09;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0dooooo`00=_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01Sooooo1?l0000:ojg2j@03o`000?nh[m3o000000SoYjgK00?o0000oifV
g?nMY]`01OnMY]`00ol0003oSJ?SohfSh`02ohfSh`Oo00001?nIYMh00ol0003oXJGIoj6Uf@06oj6U
f@03o`000?nSXM?oXj7C00GoXj7C00?o0000oijKd?nNVm001OnNVm000ol0003oVIG>oiVEcP05oiVE
cP03o`000?nMU<[oWIC:00GoWIC:0ol00006okNP`@03o`000?nfU;Co]YBd00Ko]YBd00?o0000oiQh
[_nHN:h01onHN:h00ol0003oGdFLoem5W006oem5W003o`000?oooooooooo097ooooo00?o0000oooo
ooooool01_ooool2o`000003ooooool0003ooooo00Cooooo00Co^[Zjoa0@4?l0003oMgMg;?ooool0
03Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`Ko00001OmE[OX00ol0
003o[L;Yojg2j@07ojg2j@03o`000?nW[M_oYjgK00OoYjgK00?o0000oifVg?nMY]`01?nMY]`6o`00
00?oUJCO00?o0000oiVUg_nIYMh01_nIYMh00ol0003oXJGIoj6Uf@05oj6Uf@03o`000?nSXM?oXj7C
00GoXj7C00?o0000oijKd?nNVm001OnNVm000ol0003oVIG>oiVEcP05oiVEcP03o`000?nMU<[oWIC:
00KoWIC:0_nST/83o`0000?o]j3100?o0000okJD]?nfU;@01_nfU;@00ol0003oV7R^oiQh[P07oiQh
[P03o`000?mOAIcoGdFL00OoGdFL00?o0000ooooooooool0T?ooool00ol0003oooooooooo`08oooo
o`;o00001?ooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZB_ooooo000fooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03oooool3o`0000CoH9_`00?o0000oeF]n_mE[OX01OmE[OX2
o`0000Co[L;Y0_l00002oj2ciP03o`000?nW[M_oYjgK00OoYjgK00?o0000oifVg?nMY]`00ol00002
oiVVgP03o`000?nEY=ooUJCO00GoUJCO00?o0000oiVUg_nIYMh01OnIYMh00ol0003oXJGIoj6Uf@05
oj6Uf@03o`000?nSXM?oXj7C00GoXj7C00?o0000oijKd?nNVm001_nNVm000ol0003oVIG>oiVEcP04
oiVEcP03o`000?nMU<[oWIC:00KoWIC:00?o0000oj>B`_nST/800_nST/82o`000003okNP`Ol0003o
]YBd00Oo]YBd00?o0000oiQh[_nHN:h01onHN:h00omDAZCo0000oem5W007oem5W003o`000?oooooo
oooo08oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`06odA4A?nYZJWo
oooooooooonYZJWo<S8b:oooool003Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0>ooooo`;o00001omPVo000ol0003oEJgjoeF]nP06oeF]nP04o`000?n]`^Wo0000o`0000GoX;?V
00?o0000ojN]fonW[M/01onW[M/2o`0000KoVJKN00?o0000oiFTgonEY=l01?nEY=l00ol0003oVJGN
oiVUgP06oiVUgP03o`000?nQYMWoXJGI00CoXJGI00?o0000oj>QdonSXM<01OnSXM<00ol0003oWY_@
oijKd006oijKd003o`000?nIULkoVIG>00CoVIG>00?o0000oifDb_nMU<X01_nMU<X00ol0003oXi;2
oj>B`P05oj>B`P;o00001onfU;@00ol0003oV7R^oiQh[P07oiQh[P;o00002?mOAI`00ol0003ooooo
ooooo`2>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02Wooooo000fooooo`;o00001oooool00ol0003ooooooooo
o`0>ooooo`04o`000?nMXMOoWJ7Go`0000OoH9_`00?o0000oeF]n_mE[OX01?mE[OX00ol0003oEJgj
o`000008oj2ciP03o`000?nW[M_oYjgK00;oYjgK0ol000000onMZ]oo0000oiVVgP06oiVVgP03o`00
0?nEY=ooUJCO00GoUJCO00?o0000oiVUg_nIYMh01OnIYMh00ol0003oXJGIoj6Uf@05oj6Uf@03o`00
0?nSXM?oXj7C00GoXj7C00?o0000oijKd?nNVm001OnNVm000ol0003oVIG>oiVEcP05oiVEcP03o`00
0?nMU<[oWIC:00GoWIC:00?o0000oj>B`_nST/801OnST/82oif7^`;o00001OnfU;@00ol0003oV7R^
oiQh[P07oiQh[P;o00002OmOAI`00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo
000eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oWJ7GoifQ
e`02oifQe`03o`000?mPVo3oH9_`00GoH9_`00?o0000oeF]n_mE[OX00ol00003ohV`l003o`000?nP
/nKoX;?V00KoX;?V00Co0000ojN]fol0003o00001OnMZ]l00ol0003oVJKNoiVVgP05oiVVgP03o`00
0?nEY=ooUJCO00GoUJCO00?o0000oiVUg_nIYMh01?nIYMh00ol0003oXJGIoj6Uf@02oj6UfA3o0000
0onNVm000ol0003oVIG>oiVEcP05oiVEcP03o`000?nMU<[oWIC:00GoWIC:00?o0000oj>B`_nST/80
1OnST/801?l0003oWHNkoif7^onMQk/2o`0000?o]YBd00?o0000oiQh[_nHN:h01onHN:h00ol0003o
E4JTo`000008oem5W003o`000?oooooooooo08cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool003Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?nMXMOoWJ7G00CoWJ7G
00?o0000of2Kl?mPVo001?mPVo03o`0000OoRK3`00?o0000oj2ci_nP/nH01_nP/nH00ol0003oWJ[O
oifZg`05oifZg`03o`000?nIY]koVJKN00KoVJKN00?o0000oiFTgonEY=l01?nEY=l00ol0003oVJGN
oiVUgP02oiVUgPOo00000onJWmP00ol0003oVicDoi^Le005oi^Le0GoVIOA1_l00005oiVEcP03o`00
0?nMU<[oWIC:00GoWIC:00?o0000oj>B`_nST/801OnST/800ol0003oWHNkoif7^`03oif7^`04o`00
0?nfU;Co]YBdo`0000WoV7R^00?o0000oeA6Y?l000002?mOAI`00ol0003oooooooooo`2;ooooo`03
o`000?oooooooooo00_ooooo0ol00004ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A4:oooool0
03Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?nMXMOoWJ7G
00KoWJ7G00Co0000of2Kl?mPVo3oH9_`0_l00002ohJYk003o`000?n9/?3oRK3`00KoRK3`00?o0000
oj2ci_nP/nH00_nP/nH2o`000003oiV/i?l0003oWJ[O00OoWJ[O00?o0000oiVVg_nIY]h01OnIY]h0
0ol0003oUJCOoiFTg`02oiFTg`Oo00000onGXM/00ol0003oVYoHoiZOf005oiZOf003o`000?nKW=Co
VicD00CoVicD00?o0000oiVGdOnIUm401OnIUm43oiJCcPCo000000?oVIG>o`000?nMU<X01_nMU<X0
0ol0003oXi;2oj>B`P05oj>B`P03o`000?nMQk_oWHNk00CoWHNk00?o0000okJD]?l000002OnHN:h0
0ol0003oE4JTo`000008oem5W003o`000?oooooooooo08[ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`02ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<:oooool003Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?nMXMOoWJ7G00SoWJ7G00?o
0000of2Kl?l000001On6ZN`00ol0003oRK3`ohV`l006ohV`l004o`000?nP/nKo0000o`0000CoVJcT
00?o0000oifZgonMZ]l01_nMZ]l00ol0003oVJKNoiVVgP03oiVVgPKo00000onEX]d00ol0003oUj7K
oiNQf`05oiNQf`03o`000?nJWmSoVYoH00CoVYoH00?o0000oi^Le?nKW=@01OnKW=@00ol0003oVIOA
oiVGd@04oiVGd@03o`000?nFTlkoUY?>00CoUY?>0ol00006oifDbP03o`000?nST/;oXi;200GoXi;2
00?o0000oif7^onMQk/01_nMQk/00ol0003oV7R^oiQh[P07oiQh[P04o`000?mDAZCoE4JTo`0000Oo
GdFL00?o001ao`000?ooool0ROooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;o
oooo00Co^[Zjoa0@4?l@413oc<c<;?ooool003Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?nb[M;o000000WoWJ7G00?o0000ohJYk?n6ZN`01On6ZN`00ol0003o
RK3`ohV`l006ohV`l003o`000?nI[>CoVJcT00GoVJcT00?o0000oifZgonMZ]l01OnMZ]l00ol0003o
VJKNoiVVgP03o`0000;oUZCO00?o0000oiFRgOnEX]d01OnEX]d00ol0003oUj7KoiNQf`04oiNQf`03
o`000?nJWmSoVYoH00CoVYoH00?o0000oi^Le?nKW=@01OnKW=@00ol0003oVIOAoiVGd@04oiVGd@03
o`000?nFTlkoUY?>00GoUY?>0_nFSlX3o`0000?oWIC:00?o0000oj>B`_nST/801OnST/800ol0003o
WHNkoif7^`06oif7^`03o`000?nHN:koV7R^00OoV7R^00Co0000oeA6Y?mDAZCo00001omOAI`2o`00
08[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`00=?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00Co0000ok:]d_nb[M;o/ZgB0_l00005oifQ
e`05o`000?nHZN;oV:WRoiRYh_l000001_n6ZN`00ol0003oRK3`ohV`l002ohV`l0;o00000_nA[>P0
0ol0003oVJcToiV/i005oiV/i003o`000?nMZ]ooWJ[O00CoWJ[O0ol00006oiJTg`03o`000?nEX]go
UJ;M00CoUJ;M00?o0000oiNQfonGXM/01?nGXM/00ol0003oVYoHoiZOf005oiZOf003o`000?nKW=Co
VicD00CoVicD00?o0000oiVGdOnIUm401?nIUm400ol0003oUY?>oiJCcP05oiJCcP03o`000?nFSl[o
UXo:00;oUXo:0_l000000onMU<[o0000oj>B`P06oj>B`P03o`000?nMQk_oWHNk00KoWHNk0_l00007
oiQh[P03o`000?mDAZCoE4JT00;oE4JT00?o0000oem5W?mOAI`01?mOAI`2o`0008Wooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0booooo`00=?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ok:]d_nb[M801?nb[M801Ol0003oWJ7GoifQeonMXMOo
000000GoV:WR00?o0000ohJYk?n6ZN`01?n6ZN`01?l0003oRK3`o`000?l00005oi6/j003o`000?nI
[>CoVJcT00GoVJcT00?o0000oifZgonMZ]l00ol000000onGY^7o0000oiJTg`06oiJTg`03o`000?nE
X]goUJ;M00GoUJ;M00?o0000oiNQfonGXM/01?nGXM/00ol0003oVYoHoiZOf004oiZOf003o`000?nK
W=CoVicD00CoVicD00?o0000oiVGdOnIUm401OnIUm400ol0003oUY?>oiJCcP04oiJCcP03o`000?nF
Sl[oUXo:00GoUXo:0_l00006oj>B`P03o`000?nMQk_oWHNk00KoWHNk00?o0000oh9_]_l000001_nH
N:h00ol0003oE4JToeA6Y002oeA6Y003o`000?mOAIcoGdFL00?oGdFL00?o0000o`00LOl00000R?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03;ooooo000dooooo`;o00002Oooool0
0ol0003oooooooooo`08ooooo`03o`000?nb[M;o/ZgB00Go/ZgB00?o0000oifQeol000001onHZN80
0ol0003oQZW/ohJYk004ohJYk003o`000?nA[>SoTJcX00KoTJcX00?o0000oiV/i?nI[>@01OnI[>@2
o`0000GoUjKQ00?o0000oiJTgonFY=l01OnFY=l00ol0003oUJ;MoiFRg@04oiFRg@03o`000?nGXM_o
Uj7K00CoUj7K00?o0000oiZOf?nJWmP01?nJWmP00ol0003oVicDoi^Le004oi^Le003o`000?nIUm7o
VIOA00GoVIOA00?o0000oiJCc_nFTlh01?nFTlh00ol0003oUXo:oiJ?bP05oiJ?bP;oThW50_l00004
oj>B`P03o`000?nMQk_oWHNk00KoWHNk00Co0000oh9_]_n2KkKo00001OnHN:h00ol0003oE4JToeA6
Y002oeA6Y003o`000?mOAIcoGdFL00?oGdFL00?o0000o`00LOl00000Qoooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo03;ooooo000dooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003o/ZgBok:]dP07ok:]dP03o`000?nHZN;oV:WR00OoV:WR00?o0000
ohJYk?l000000_l00003ohn[j003o`000?nA[>SoTJcX00GoTJcX00?o0000oiV/i?nI[>@00ol00000
0onDZ>?o0000oiNVh@06oiNVh@03o`000?nFY=ooUZCO00GoUZCO00?o0000oiFRgOnEX]d00onEX]d0
0ol0003oUj7KoiNQf`04oiNQf`03o`000?nJWmSoVYoH00GoVYoH00?o0000oi^Le?nKW=@01?nKW=@0
0ol0003oVIOAoiVGd@04oiVGd@03o`000?nFTlkoUY?>00CoUY?>00?o0000oiJ?b_nFSlX01OnFSlX0
1?l0003oThW5oi>9aOnCRLD2o`0000;oXi;200?o0000oif7^onMQk/01_nMQk/01Ol0003oPVnfoh9_
]_n2KkKo000000CoV7R^00?o0000oeA6Y?mDAZ@00omDAZ@00ol0003oGdFLoem5W002oem5W004o`00
0?l0077o001ao`0008Kooooo00?o0000ooooooooool04Oooool3o`0003Cooooo000cooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003o/ZgBok:]dP06ok:]dP04o`00
0?nR[n7oXZoQo`0000SoV:WR00?o0000ohn[j?n?ZnP01On?ZnP00ol0003oTJcXoi6/j005oi6/j0;o
00001OnDZ><00ol0003oUjKQoiNVh@05oiNVh@03o`000?nFY=ooUZCO00CoUZCO00Co0000oiFRgOnE
X]goUJ;M7Ol00002oiVGd@03o`000?nFTlkoUY?>00GoUY?>00?o0000oiJ?b_nFSlX01?nFSlX00ol0
003oThW5oi>9a@03oi>9a@03o`000?nST/;o000000SoWHNk00?o0000oh9_]_n2KkH00_n2KkH01Ol0
003oV7R^oiQh[_nHN:ko000000GoE4JT00?o0000oem5W?mOAI`00_mOAI`01?l0003o001ao`00LOl0
0025ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<_ooool003?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?nb[M;o/ZgB00Ko/ZgB00?o0000
oj:_hOnR[n400_nR[n400ol0003oV:WRoiRYhP03oiRYhP04o`000?nDZnKoU:_Vo`0000OoSj_X00Co
0000oi6/j?nA[>SoTJcX0_l000000onAZ>Go0000oiBXh`06oiBXh`03o`000?nGY^7oUjKQ00GoUjKQ
00Co0000oiJTgonFY=ooUZCO1_l00003oi:Og003o`000?nCWM[oTigJ00CoTigJ00?o0000oiBKf?nD
VmP01?nDVmP00ol0003oU9SDoiBHe004oiBHe0GoTYCB1?l00006oiJCcP03o`000?nFSl[oUXo:00Co
UXo:00?o0000oi>9aOnCRLD01OnCRLD2o`0000KoWHNk00?o0000oh9_]_n2KkH01?n2KkH01?l0003o
V7R^oiQh[_l00005oeA6Y003o`000?mOAIcoGdFL00;oGdFL00Co0000o`00LOl0077o0000Q?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03;ooooo000cooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01_ooool00ol0003o/ZgBo`000006ok:]dP03o`000?nR[n7oXZoQ
00CoXZoQ00Go0000oiRYh_nHZN;oV:WRo`000004oiB[iP03o`000?n?ZnSoSj_X00GoSj_X00?o0000
oi6/j?l000001?nAZ>D00ol0003oU:SSoiBXh`05oiBXh`03o`000?nGY^7oUjKQ00CoUjKQ1?l00003
oi:QgP03o`000?nBWmcoTYoL00CoTYoL00?o0000oi>Mf_nCWMX01?nCWMX00ol0003oU9_HoiBKf003
oiBKf003o`000?nDV=CoU9SD00CoU9SD00?o0000oi:Dd_nBU=801?nBU=82oi2?c`?o00000onFTlh0
0ol0003oUXo:oiJ?bP04oiJ?bP03o`000?nCRLGoThW500GoThW50_n9O/400ol0003oWHNkoif7^`03
oif7^`03o`000?n2KkKoPVnf00GoPVnf00?o0000oiQh[_l000001_mDAZ@01Ol0003oGdFLoem5W?mO
AIco000000;o001a00?o0000ooooooooool0POooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo037ooooo0007ooooo`07oa0@4?l0003o410@ooooool@413o0000oa0@400Uooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01Oooool01?l0003oYlWaojO9lOnWbO43o`0000;o
/ZgB00?o0000oj:_hOnR[n401_nR[n400ol0003oV:WRo`000006oiB[iP03o`000?n?ZnSoSj_X00Go
Sj_X00?o0000oi6XiOnAZ>D01?nAZ>D00ol0003oU:SSoiBXh`05oiBXh`03o`000?nGY^7oUjKQ00?o
000000?oTZ?Po`000?nBXMh01OnBXMh00ol0003oTYoLoi:Og003oi:Og003o`000?nCWM[oTigJ00Co
TigJ00?o0000oiBKf?nDVmP01?nDVmP00ol0003oU9SDoiBHe004oiBHe003o`000?nBU=;oTYCB00?o
TYCB00?o0000oi2?con@Sll00_n@Sll2o`000003oiJCc_l0003oUXo:00GoUXo:00?o0000oi>9aOnC
RLD01OnCRLD01?l0003oRGk1ohUn`Ol00004oif7^`03o`000?n2KkKoPVnf00KoPVnf0_l00006oeA6
Y005o`000?mOAIcoGdFLoem5W?l000000_l007400ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0<Oooool000Sooooo00Ko<S8bohN7Qooooooo^[Zjo`000?o^
k^hTooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oYlWaojO9
l@05ojO9l@;o00002_nR[n400ol0003oU:_VoiB[iP06oiB[iP04o`000?n?ZnSoSj_Xohn[j0;o0000
0_n@ZNL00ol0003oTJSUoi6Xi@04oi6Xi@03o`000?nDZ>?oU:SS00CoU:SS0ol00005oi:Sh003o`00
0?nBXMkoTZ7N00?oTZ7N00?o0000oi:Og?nBWm`01?nBWm`00ol0003oTigJoi>MfP04oi>MfP03o`00
0?nDVmSoU9_H00?oU9_H00?o0000oiBHe?nDV=@01?nDV=@00ol0003oTYCBoi:DdP04oi:DdP03o`00
0?n@SlooT8o?00CoT8o?0_l00005oiJ?bP03o`000?nCRLGoThW500GoThW500Co0000ohUn`On9O/7o
RGk10_l00002oif7^`03o`000?n2KkKoPVnf00OoPVnf00?o0000oeA6Y?mDAZ@01OmDAZ@01?l0003o
GdFLoem5W?l00003o`00L@03o`000?oooooooooo07oooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0aooooo`002?ooool01Oo^k^ko8B4Qolc<c?lQ8B7oc<c<02Gooooo0ol00009oooo
o`03o`000?oooooooooo00?ooooo00?o0000ojO9lOnWbO401_nWbO401?l0003oVKS^oiVhk_l00006
oj:_h@05o`000?nG[NKoUjgVoiN]i_l000001onDZnH00ol0003oSj_Xo`000005oi2Yi`03o`000?nA
Z>GoTJSU00CoTJSU00?o0000oiBXhonDZ><00ol000000onAY>;o0000oi:Sh005oi:Sh003o`000?nB
XMkoTZ7N00CoTZ7N00?o0000oi:Og?nBWm`00onBWm`00ol0003oTigJoi>MfP04oi>MfP03o`000?nD
VmSoU9_H00?oU9_H00?o0000oiBHe?nDV=@01?nDV=@00ol0003oTYCBoi:DdP04oi:DdP03o`000?n@
SlooT8o?00CoT8o?0_n<R/`3o`0000;oUXo:00?o0000oi>9aOnCRLD01OnCRLD00ol0003oRGk1ohUn
`@03ohUn`@03o`000?nMQk_o000000WoPVnf00?o0000oeA6Y?mDAZ@01OmDAZ@01?l0003oGdFLoem5
W?l00003o`00L@03o`000?oooooooooo07kooooo00?o0000ooooooooool05oooool3o`0003?ooooo
0009ooooo`03okZj^_l0003oQhN702Kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`03o`0000SoYlWa00?o0000oiVhk_nI^>h00_nI^>h2o`0000?oXZoQ00?o0000oiN]i_nG[NH00onG
[NH00ol0003oU:_VoiB[iP05oiB[iP03o`000?n@ZNOoT:WW00GoT:WW00?o0000oi6XiOnAZ>D01?nA
Z>D2o`0000GoTJCR00?o0000oi:Sh?nBXn001?nBXn000ol0003oTZ7Noi:QgP04oi:QgP03o`000?nB
WmcoTYoL00?oTYoL00?o0000oi>Mf_nCWMX00onCWMX00ol0003oU9_HoiBKf003oiBKf003o`000?nD
V=CoU9SD00CoU9SD00?o0000oi:Dd_nBU=801?nBU=800ol0003oT8o?oi2?c`04oi2?c`03o`000?n<
R/coS8[<00;oS8[<00?o0000oiJ?b_l000001onCRLD00ol0003oRGk1ohUn`@04ohUn`@03oif7^ol0
003oPVnf00SoPVnf00?oCDV]o`000?mDAZ@01OmDAZ@00ol0003oGdFLo`000004o`00L@03o`000?oo
oooooooo07gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0aooooo`002?ooool0
1Oo^k^ko<S8bolc<c?lb<S;ok^k^02Gooooo00?o0000ooooooooool02Oooool3o`0000Go5Y_Q0ol0
0002ojO9l@03o`000?nI^>koVKS^00GoVKS^00?o0000oj:_hOl000001onG[NH01?l0003oU:_VoiB[
i_nDZnH2o`0000;oTJWW00?o0000oi2Yion@ZNL01On@ZNL00ol0003oTJSUo`000002o`000003ohnU
i?l0003oTJCR00KoTJCR00?o0000oi:Sh?nBXn001?nBXn000ol0003oTZ7Noi:QgP03oi:QgP03o`00
0?nBWmcoTYoL00?oTYoL00Co0000oi>Mf_nCWM[oTigJ1ol00002oiBKf003o`000?nDV=CoU9SD00?o
U9SD00?o0000oi:Dd_nBU=801?nBU=800ol0003oT8o?oi2?c`04oi2?c`03o`000?n<R/coS8[<00Co
S8[<0_l00006oi>9a@03o`000?n9O/7oRGk100GoRGk100?o0000oh9_]_n2KkH01on2KkH2o`0000Oo
E4JT0_l00004o`00L@03o`000?oooooooooo07gooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0aooooo`002?ooool01OmEEEGoMgMgoooooon7QhOoEEEE01Oooooo00Co^[Zjoa0@4?l0
003oMgMg2_ooool00ol0003oooooooooo`07ooooo`?o00000_lfSnl2o`0000Ko5Y_Q0_l00009oiVh
kP03o`000?nG[NKoUjgV00OoUjgV00?o0000oiB[i_l000001OnAZNL00ol0003oT:WWoi2Yi`05oi2Y
i`03o`000?n?YNCoSjGT00?oSjGT00?o0000oi6Th_nAY>801OnAY>800ol0003oTZ?Poi:Sh003oi:S
h004o`000?nBXMkoTZ7Noi:QgPco00000on?V]X01?l0003oSiOHohnGf?n?UmP7o`0000;oU9SD00?o
0000oi:Dd_nBU=800onBU=800ol0003oT8o?oi2?c`04oi2?c`03o`000?n<R/coS8[<00CoS8[<0_n6
PlP00ol0003oThW5oi>9a@03oi>9a@03o`000?n9O/7oRGk100GoRGk100?o0000oh9_]_n2KkH01on2
KkH00ol0003oCDV]o`000006oeA6Y0;o00001?l007400ol0003oooooooooo`1looooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0<Oooool000Oooooo00Oo410@o`000?l@413ooooooa0@
4?l0003o410@01Gooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT8ooooo`03o`000?oooooooooo
00Sooooo00?o0000oiNFd?l000001?lfSnl00ol0003o5Y_QoaJKh@02oaJKh@05o`000?mj]_WoN[Ki
ogZfnOl000001_nI^>h00ol0003oT[7[oi:aj`02o`0000OoUjgV00?o0000oi6YionAZNL01OnAZNL0
1?l0003oT:WWoi2Yion@ZNL2o`0000;oSZKU00?o0000ohnUi?n?YN@00on?YN@00ol0003oTJCRoi6T
hP05oi6ThP04o`000?nBXn3oTZ?Poi:Sh0Go00000on?W]h00ol0003oSicLohnLg003ohnLg003o`00
0?n?V][oSi[J00CoSi[J00?o0000ohnGf?n?UmP00_n?UmP00ol0003oSYCEohjDe@02ohjDe@Oo0000
0_nBU=800ol0003oT8o?oi2?c`04oi2?c`03o`000?n<R/coS8[<00?oS8[<00?o0000ohJ3b?n6PlP0
0_l00003oi>9a@03o`000?n9O/7oRGk100GoRGk10_l00008oh9_]P03o`000?m=BJgo000000KoE4JT
0_l00005o`00L@03o`000?oooooooooo07[ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0aooooo`008oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PSooooo00?o0000oooooooo
ool02?ooool01?l0003oUiK@o`000?l00004ocJ?k`;o000000?o5Y_Qo`000?mj]_T01?mj]_T2o`00
00?oVKS^00?o0000oi:ajonB/N/00onB/N/00ol0003oUjgVoiN]iP02oiN]iP05o`000?nAZnSoTJ_X
oi6[j?l000001_nAZNL00ol0003oT:WWo`000005ohjVi@03o`000?n?YNCoSjGT00?oSjGT00?o0000
oi6Th_nAY>801?nAY>84o`0000;oSYoO00?o0000ohnNg_n?W]h01?n?W]h00ol0003oSicLohnLg003
ohnLg003o`000?n?V][oSi[J00?oSi[J00?o0000ohnGf?n?UmP00on?UmP00ol0003oSYCEohjDe@03
ohjDe@GoS93C1?l00005oi2?c`03o`000?n<R/coS8[<00?oS8[<00?o0000ohJ3b?n6PlP00_n6PlP2
o`000003oi>9aOl0003oRGk100KoRGk100?o0000og5[_?l000001on2KkH01?l0003oCDV]ode9[Ol0
0006oeA6Y003o`000?l0077o001a00?o001a00?o0000ooooooooool0NOooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo033ooooo000Sooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`06o`000?nGU]3oUiK@o`000?nGU]3o0000
1OlfSnl00ol0003oN[KiogZfn@06ogZfn@03o`000?nI^>ko000000OoT[7[0_l000000onG[NKo0000
oi6[j004oi6[j003o`000?nAZNOoTJWW00CoTJWW00?o0000ohjViOn>Y^D01On>Y^D00ol0003oSjGT
ohnUi003ohnUi003o`000?nAY>;oTJCR00?o000000?oSJ7Qo`000?n>Wml01?n>Wml00ol0003oSikN
ohnNgP03ohnNgP03o`000?n?W=coSicL00?oSicL00?o0000ohnJf_n?V]X00on?V]X00ol0003oSiOH
ohnGf003ohnGf003o`000?n>U=GoSYCE00?oSYCE00?o0000ohb@don<T=<01?n<T=<2ohR<d0?o0000
0_n@Sll00ol0003oS8[<ohb:c003ohb:c003o`000?n6PlSoQX?800CoQX?800?oThW5o`000?n9O/40
1_n9O/401?l0003oLF^log5[_?l00005oh9_]P05o`000?m=BJgoCDV]ode9[Ol000001_mDAZ@00ol0
003o001ao`00L@03o`00L@03o`000?oooooooooo07Sooooo00?o0000ooooooooool07Oooool3o`00
03;ooooo000Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`04o`000?nGU]3oUiK@o`0000;oUiK@00Go0000ocJ?kolfSnoo=Xo_o`000002
ogNZlP;o00001_mj]_T00ol0003oT[7[oi:aj`08oi:aj`03o`000?nAZnSoTJ_X00GoTJ_X00Go0000
oi6YionAZNOoTJWWo`000003ohjWiP03o`000?n>Y^GoSZKU00CoSZKU00?o0000ohnUi?n?YN@00_n?
YN@3o`0000GoSJ7Q00?o0000ohjOgon>Wml00_n>Wml00ol0003oSikNohnNgP04ohnNgP03o`000?n?
W=coSicL00?oSicL00?o0000ohnJf_n?V]X00on?V]X00ol0003oSiOHohnGf002ohnGf003o`000?n>
U=GoSYCE00CoSYCE00?o0000ohb@don<T=<00on<T=<00ol0003oR8c@ohR<d002ohR<d003o`000?n@
Sloo000000GoS8[<00?o0000ohJ3b?n6PlP01On6PlP2o`0000KoRGk100Go0000og5[_?maJkcoLF^l
o`000004oh9_]P03o`000?m=BJgoCDV]00;oCDV]00?o0000oeA6Y?mDAZ@00omDAZ@00ol0003o001a
o`00L@03o`00L@03o`000?oooooooooo07Sooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0`ooooo`008oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo1?l0
0007ooooo`04o`000?nGU]3oUiK@o`0000?oUiK@00?o0000ocJ?kol000001OmgZ_800ol0003oN[Ki
ogZfn@02ogZfn@03o`000?n8/?3oR;3`00?o00001?nB/N/01Ol0003oSZcZohj/j_n>[>[o000000Ko
TJ_X00?o0000oi6Yiol000001On>YnH00ol0003oSZKUohjVi@04ohjVi@06o`000?n?YNCo0000o`00
0?n=X^?o00001_n=XN400ol0003oSYoOohjOg`03ohjOg`03o`000?n?W]koSikN00CoSikN00?o0000
ohnLg?n?W=`00_n?W=`00ol0003oSi[JohnJfP03ohnJfP03o`000?n?UmSoSiOH00?oSiOH00?o0000
ohjDeOn>U=D00on>U=D00ol0003oS93Cohb@d`03ohb@d`03o`000?n8S=3oR8c@00CoR8c@0_l00005
ohb:c003o`000?n6PlSoQX?800CoQX?80_mkNLD00ol0003oRGk1ohUn`@03ohUn`@03o`000?maJkco
LF^l00;oLF^l00Go0000oh9_]_n2KkKoPVnfo`000004ode9[@03o`000?mDAZCoE4JT00?oE4JT0_l0
0004o`00L@03o`000?oooooooooo07Oooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0`ooooo`008oooool01_m4A4CoZJVYooooooooooooZJVYodA4A0Oooooo00?o0000ooooooooool0
2?ooool00ol0003oUiK@o`000005oiNFd003o`000?mgZ_;oMj[b00GoMj[b0_l000000omj]_Wo0000
ohR`l005ohR`l0;o000000?oT[7[o`000?n>[>X01?n>[>X00ol0003oTJ_Xoi6[j004oi6[j003o`00
0?n>YnKoSZOV00GoSZOV00?o0000ohjViOn>Y^D01?n>Y^D00ol0003oSJ;SohfRh`02ohfRh`03o`00
0?n=XN7oSJ7Q00CoSJ7Q00?o0000ohjOgon>Wml00on>Wml00ol0003oSikNohnNgP03ohnNgP03o`00
0?n?W=coSicL00;oSicL00?o0000ohnJf_n?V]X00on?V]X00ol0003oSiOHohnGf003ohnGf003o`00
0?n>U=GoSYCE00?oSYCE00?o0000ohb@don<T=<00on<T=<00ol0003oR8c@ohR<d004ohR<d0;oQ8O>
0_l00003ohb:c003o`000?n6PlSoQX?800CoQX?800Co0000og]iaOmkNLGo00001?n9O/400ol0003o
LF^log5[_003og5[_004o`000?n2KkKoPVnfo`0000GoCDV]00?o0000oeA6Y?mDAZ@00_mDAZ@2o`00
00Go001a00?o0000ooooooooool0MOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
033ooooo000Sooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<1oooool00ol0003oooooooooo`07
ooooo`04o`000?nGU]3oUiK@o`0000GoUiK@00?o0000oi>Vh_l000001omgZ_800ol0003oR;3`ohR`
l007ohR`l003o`000?n>[>[oSZcZ00GoSZcZ00Go0000oi6[j?nAZnSoTJ_Xo`000003ohfXi`03o`00
0?n>YnKoSZOV00CoSZOV00?o0000ohjViOl000000_l000000on<XnCo0000ohfRh`04ohfRh`03o`00
0?n=XN7oSJ7Q00CoSJ7Q00?o0000ohjOgon>Wml00_n>Wml01?l0003oSikNohnNg_n?W]hBo`000003
ohnGf?l0003oSYCE00CoSYCE00?o0000ohb@don<T=<01?n<T=<00ol0003oR8c@ohR<d003ohR<d005
o`000?n4QlkoQ8O>ohB7c_l000000_n<R/`00ol0003oQX?8ohJ3b004ohJ3b004o`000?mkNLGoNgW5
og]ia@;o00000_n9O/400ol0003oLF^log5[_004og5[_003o`000?n2KkKo000000GoCDV]00?o0000
oeA6Y?mDAZ@00_mDAZ@2o`0000Go001a00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo033ooooo000Tooooo`04okZj^_l@413o410@olc<c0Sooooo00?o0000
ooooooooool01oooool01?l0003oUiK@oiNFd?l00004oiNFd004o`000?nCY^;oTjKRoi>VhP;o0000
1OmgZ_801?l0003oQZg_o`000?l00006ohR`l003o`000?n;[Nco000000KoSZcZ00?o0000oi6[j?l0
00001On=Z>L00ol0003oSZOVohjWiP04ohjWiP03o`000?n<XnCoS:?T00?oS:?T00?o0000ohfRhon=
X^<00on=X^<00ol0003oSJ7QohfQh@03ohfQh@04o`000?n>WmooSYoOohjOg`Go00000on;Vmd00ol0
003oRYWLohZIg002ohZIg003o`000?n:Um[oRYOJ00?oRYOJ1?n9U=P6o`0000;oSYCE00?o0000ohb@
don<T=<00on<T=<00ol0003oR8c@ohR<d003ohR<d003o`000?n4QlkoQ8O>00;oQ8O>00?o0000ohb:
c?l000001_n6PlP00ol0003oNgW5og]ia@03og]ia@03o`000?n9O/7o000000OoLF^l00?oPVnfo`00
0?m=BJd01?m=BJd00ol0003oE4JToeA6Y002oeA6Y003o`000?l008Oo000000Co001a00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo033ooooo000`ooooo`03
o`000?oooooooooo00Oooooo00Co0000okNSa?l0003o00001?nGU]000ol0003oTjKRoi>VhP03oi>V
hP05o`000?mgZ_;oMj[bogNZl_l000001?n6[Nl00ol0003oR;3`ohR`l002ohR`l005o`000?n;[Nco
Rjg/oh^]k?l000001_n>[>X00ol0003oSJSWohfXi`05ohfXi`05o`000?n>YnKoSZOVohjWi_l00000
0_n;Y>H00ol0003oS:?TohbSi003ohbSi003o`000?n=X^?oSJ;S00?oSJ;S00Co0000ohfQhOn=XN7o
SJ7Q1Ol00002ohZLg`03o`000?n;VmgoRi_M00CoRi_M00?o0000ohZIg?n:VM`00_n:VM`00ol0003o
RYOJohZGfP03ohZGfPGoRICH1?n7TMH5o`0000?oS93C00?o0000ohR<d?n8S=000on8S=000ol0003o
Q8O>ohB7cP04ohB7cP;o00001On6PlP00ol0003oNgW5og]ia@04og]ia@03ohUn`Ol0003oLF^l00Oo
LF^l00?o0000ode9[Om=BJd01?m=BJd01?l0003oE4JToeA6Y?l00002o`00Q`03o`000?l0077o001a
00;o001a00?o0000ooooooooool0Loooool00ol0003oooooooooo`0Pooooo`Co00001_ooool01?nj
^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo1_l00003ooooo`06oiRHV?l@413o
0000o`000?m4A4Cok^k^3?ooool002oooooo00?o0000ooooooooool02?ooool00ol0003o]j?4okNS
a002o`0000?oUiK@00?o0000oi>Vh_nCY^801?nCY^800ol0003oMj[bo`000006ohJ]k`;o000000?o
R;3`o`000?n;[N`01?n;[N`01Ol0003oSZcZohj/j_n>[>[o000000?oRjWY00?o0000ohfXion=Z>L0
1?n=Z>L00ol0003oSZOVo`000004oh^TiP03o`000?n<XnCoS:?T00?oS:?T00?o0000ohfRhon=X^<0
0_n=X^<4o`0000;oRYkQ00?o0000ohZLgon:W=l00on:W=l00ol0003oRi_Moh^Kg@03oh^Kg@03o`00
0?n:VMcoRYWL00;oRYWL00?o0000ohZGf_n:UmX00on:UmX00ol0003oRICHohVDf002ohVDf003o`00
0?n7TMKoQi7F00?oQi7F0on5S]@2o`000003ohb@dol0003oR8c@00GoR8c@00?o0000ohB7c_n4Qlh0
0on4Qlh2ogb0c0;o00000on6PlP00ol0003oNgW5og]ia@05og]ia@03o`000?maJkcoLF^l00KoLF^l
00?o0000ode9[Om=BJd01?m=BJd01?l0003oE4JToeA6Y?l00002o`00Q`03o`000?l0077o001a00;o
001a00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?o
oooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool00onHV9So0000olc<c002
ooooo`06oa0@4?ooooooooooooooool@413oQhN70_ooool00omgMgOoA4A4ooooo`0;ooooo`00;ooo
ool00ol0003oooooooooo`07ooooo`06o`000?ngXlCo]j?4okNSa?l0003o]j?40ol00008oi>VhP03
o`000?n6[NooQZg_00OoQZg_00?o0000oh^]k?n;[N`01On;[N`00ol0003oSZcZo`000005oh^Yj@;o
00001On=Z>L00ol0003oRjCVoh^TiP04oh^TiP03o`000?n<XnCoS:?T00?oS:?T00Ko0000ohfRhol0
003o0000ohVOh_l00005ohZNh@03o`000?n:W=ooRYcO00;oRYcO00?o0000oh^KgOn;Vmd01?n;Vmd0
0ol0003oRYWLohZIg002ohZIg003o`000?n:Um[oRYOJ00;oRYOJ00?o0000ohVDf?n9U=P00on9U=P0
0ol0003oQi7FohNAeP02ohNAeP03o`000?n5S]CoQHkD00?oQHkD0_l00005ohR<d003o`000?n4Qlko
Q8O>00?oQ8O>00Go0000ogb0c?mlP<coO83<o`000002ohJ3b003o`000?mkNLGoNgW500GoNgW500?o
0000og5[_?maJk`01_maJk`00om;D;Ko0000ode9[@05ode9[@03o`000?mDAZCo000000?o002700?o
0000o`00LOl007400_l007400ol0003oooooooooo`1`ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool00_ooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mE
EED01Oooool00onHV9So0000olc<c00:ooooo`03o`000?oooooooooo00[ooooo000_ooooo`;o0000
2?ooool01Ol0003o]j?4okNSa?ngXlCo000000?o]j?400?o0000oi>Vh_nCY^801_nCY^800ol0003o
SZ_Yo`000002o`0000CoQZg_00Co0000ohV/kOn9[>go00001_n;[N`00ol0003oRjWYoh^Yj@06oh^Y
j@04o`000?n=Z>Oo0000o`0000?oRZGW00?o0000oh^Ti_n;Y>H00on;Y>H00ol0003oS:?TohbSi002
ohbSi0;o00001?n9Wn800ol0003oRYkQohZNh@03ohZNh@03o`000?n:W=ooRYcO00;oRYcO00?o0000
oh^KgOn;Vmd00on;Vmd00ol0003oRYWLohZIg002ohZIg003o`000?n:Um[oRYOJ00?oRYOJ00?o0000
ohVDf?n9U=P00_n9U=P00ol0003oQi7FohNAeP03ohNAeP03o`000?n5S]CoQHkD00;oQHkD0_n1RM83
o`0000;oR8c@00?o0000ohB7c_n4Qlh00on4Qlh00ol0003oO83<ogb0c002ogb0c003o`000?n6PlSo
000000OoNgW50_l00006og5[_003o`000?m;D;Ko000000KoCDV]00?o0000oeA6Y?l000000ol008L0
0ol0003o001ao`00L@02o`00L@03o`000?oooooooooo073ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool0
0onYZJWo410@olc<c008ooooo`03onk^k_l0003ooooo00_ooooo000_ooooo`03o`000?oooooooooo
00Oooooo00Go0000okNSa?ngXlCo]j?4o`000003okNSa003o`000?nV[=_o000000;o00000onCY^80
0ol0003oSZ_Yohj[j@03ohj[j@;o000000?oQZg_o`000?n9[>d00on9[>d2o`0000?oRjg/00?o0000
ohVYjon9ZN/00_l00006oh^Yj@03o`000?n:YNOoRZGW00CoRZGW00?o0000oh^Ti_n;Y>H00on;Y>H0
1_l0003oS:?To`000?l0003oR:3To`0000GoRIoR00?o0000ohZNhOn:W^400on:W^400ol0003oRYcO
ohZLg`02ohZLg`03o`000?n;VmgoRi_M00;oRi_M00?o0000ohZIg?n:VM`00_n:VM`00ol0003oRYOJ
ohZGfP03ohZGfP03o`000?n9U=SoRICH00;oRICH00?o0000ohNAe_n7TMH00on7TMH00ol0003oQHkD
ohF>e002ohF>e003o`000?n1RM;oPHWB00;oPHWB00?o0000ohR<d?l000001On4Qlh00ol0003oO83<
ogb0c004ogb0c003o`000?mkNLGoNgW500GoNgW500?o0000ofMZ`_l000001OmaJk`01?l0003oBe2f
od]@]_l00006ode9[@;o00000ol008L00ol0003o001ao`00L@02o`00L@03o`000?oooooooooo06oo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03Oooool00oo<c<co410@olc<c003ooooo`06oa0@4?nHV9Sooooooooo
oomgMgOoIVIV3?ooool002kooooo00?o0000ooooooooool02?ooool01Ol0003o]j?4okNSa?ngXlCo
000000;o]j?400?o0000ojJ/fonV[=/00onV[=/2o`000003oi>Vh_l0003oSZ_Y00KoSZ_Y00?o0000
ohV/kOn9[>d01On9[>d00ol0003oRjg/o`000005ohVYj`03o`000?n;ZNWoRjWY00;oRjWY00Co0000
ohRVj?n8Y^So00001On:YNL00ol0003oRjCVoh^TiP03oh^TiP03o`000?n8X>CoR:3T00;oR:3T00?o
0000ohVOh_n9Wn800on9Wn800ol0003oRYkQohZNh@02ohZNh@03o`000?n:W=ooRYcO00;oRYcO00Co
0000oh^KgOn;VmgoRi_M2ol000000on:Um[o0000ohVDf003ohVDf003o`000?n7TMKoQi7F00?oQi7F
00?o0000ohF>e?n5S]@00on5S]@00ol0003oPHWBoh69dP03oh69dP;o00001?n4Qlh00ol0003oO83<
ogb0c004ogb0c003og5gbOl0003oNgW500GoNgW500Co0000ofMZ`_mWJ/;o00001?maJk`01?l0003o
Be2fod]@]_l00006ode9[@;o00000ol008L00ol0003o001ao`00L@02o`00L@03o`000?oooooooooo
06kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03_ooool00onYZJWo<S8booooo`02ooooo`05o`000?lQ8B7o0000
o`000?mVIVH03Oooool002kooooo00?o0000ooooooooool01oooool00ol0003o]j?4okNSa002okNS
a004o`000?ngXlCo]j?4o`0000OoYZcK00?o0000ohj[jOn>ZnT01_n>ZnT01?l0003oRZc/o`000?l0
0005ohV/k@03o`000?n9ZN_oRJW[00GoRJW[0_l000000on;ZNWo0000ohRVj003ohRVj0;o00001?n:
YNL01?l0003oRjCVo`000?l00002ohNQi@03o`000?n8X>CoR:3T00;oR:3T00?o0000ohVOh_n9Wn80
0_n9Wn800ol0003oRYkQohZNh@03ohZNh@03o`000?n:W=ooRYcO00Go00000_n6V=d00ol0003oQYKL
ohJFg002ohJFg004o`000?n5U=[oQICJohFDfPKo000000?oRICHo`000?n7TMH00on7TMH00ol0003o
QHkDohF>e003ohF>e003o`000?n1RM;oPHWB00?oPHWB0_mlQ=02o`0000;oQ8O>00?o0000ogb0c?ml
P<`01?mlP<`00ol0003oLGO9o`000005og]ia@05o`000?mWJ/;oIf[2ofMZ`_l000000omaJk`01Ol0
003oBe2fod]@]_m;D;Ko000000KoCDV]00?o0000o`00Qol008L00_l008L01Ol0003o001ao`00LOl0
077o000006oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`06odA4A?nY
ZJWooooooooooonYZJWoA4A44Oooool01Ol0003ooooooooooooooooo0000017ooooo000^ooooo`03
o`000?oooooooooo00Oooooo00?o0000okNSa?ngXl@00_ngXl@01?l0003o]j?4okNSa?l00007ojJ/
f`03o`000?nF[^So000000;o00000on>ZnT00ol0003oRZc/ohZ/k002ohZ/k003o`000?n9[>goRJc]
00;oRJc]00Co0000ohRYjol0003o00001_n9ZN/00ol0003oR:KXohRVj005ohRVj003o`000?n:YNOo
RZGW00;oRZGW00?o0000ohNQiOn7XND00on7XND00ol0003oR:3TohRPi002ohRPi003o`000?n9Wn;o
RIoR00;oRIoR00Co0000ohZNhOn:W^7oRYkQ1?l00002ohJIg`03o`000?n6V=goQYSM00?oQYSM00?o
0000ohJFg?n6U]`00_n6U]`00ol0003oQICJohFDfP02ohFDfPCoQ97I1Ol00002ohNAeP03o`000?n5
S]CoQHkD00;oQHkD00?o0000oh69d_n1RM800on1RM801ol0003oO8C@ogb4d?mlQ=3o0000ohB7c_l0
00001_mlP<`01?l0003oLGO9og5gbOl00003og]ia@03o`000?mWJ/;oIf[200;oIf[200Go0000og5[
_?maJkcoLF^lo`000003od]@]P03o`000?m=BJgoCDV]00CoCDV]00?o0000o`00Qol008L00_l008L0
0ol0003o001ao`00L@02o`00L@03o`000?oooooooooo06cooooo00?o0000ooooooooool09oooool3
o`0000Cooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`06o`000?n7QhOok^k^oooooomg
MgOo<S8b0oooool00ol0003oooooooooo`0?ooooo`00;_ooool00ol0003oooooooooo`07ooooo`03
o`000?ngXlCo]j?400;o]j?400?o0000okNSa?l000001onV[=/00ol0003oUZkXoiJ^j003oiJ^j0;o
000000?oSZ_Yo`000?n:[>`01?n:[>`2o`000003ohV/kOl0003oR:W[00?oR:W[00?o0000ohVYjon9
ZN/00_n9ZN/01?l0003oQjKYohNVjOl00006ohRVj003o`000?n:YNOo000000?oQZ;V00?o0000ohNQ
iOn7XND00_n7XND00ol0003oR:3TohRPi002ohRPi003o`000?n9Wn;oRIoR00Go00000_n6Vn000ol0
003oQYWOohJIg`02ohJIg`03o`000?n6V=goQYSM00;oQYSM00?o0000ohJFg?n6U]`00_n6U]`00ol0
003oQICJohFDfP03ohFDfPCoQ97I1?n2S]L5o`0000;oQHkD00?o0000oh69d_n1RM800on1RM800ol0
003oO8C@ogb4d003ogb4d0;o00001OmlP<`01Ol0003oLGO9og5gbOmaMlWo000000;oNgW500?o0000
ofMZ`_mWJ/800omWJ/800ol0003oLF^lo`000005od]@]P03o`000?m=BJgoCDV]00?oCDV]00?o1AZK
o`000?l008L00_l008L00ol0003o001ao`00L@02o`00L@03o`000?oooooooooo06_ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`04okZj^_l@413o410@olc<c0gooooo00Ko
ZJVYoc8b<_l0003o0000oeEEEOo^k^h3ooooo`Go00003Oooool002gooooo00?o0000ooooooooool0
2?ooool01?l0003o]j?4okNSa?ngXl@4o`000003ojJ/fol0003oYZcK00CoYZcK00?o0000oiJ^j?nF
[^P01OnF[^P00ol0003oRZc/ohZ/k006ohZ/k003o`000?n8ZN_oR:W[00CoR:W[0_l000000on9ZN_o
0000ohNVj@03ohNVj@03o`000?n8Y^SoR:KX00CoR:KX00?o0000ohJRi_n6X^H00on6X^H00ol0003o
Qj7UohNQi@02ohNQi@03o`000?n8X>CoR:3T00Co00000_n5W>800ol0003oQY_PohJKh003ohJKh003
o`000?n6VMooQYWO00;oQYWO00?o0000ohJHgOn6V=d00_n6V=d00ol0003oQYKLohJFg002ohJFg003
o`000?n5U=[oQICJ00;oQICJ00?o0000ohBAfOn4TMT00_n4TMT5oh:>e`?oOh_F0_l000000on5S]Co
0000oh69dP03oh69dP03o`000?mlQ=3oO8C@00?oO8C@0_meO/h00ol0003oO83<ogb0c002ogb0c003
o`000?maMlWoLGO900;oLGO900?o0000og]iaOl000001_mWJ/800omaJkco0000od]@]P05od]@]P07
o`000?m=BJgoCDV]ode9[Ol0003o1AZKo`000004o`00Q`05o`000?l0077o001ao`00LOl00000K?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02oooooo000]ooooo`?o00001oooool0
0ol0003o]j?4o`000003o`0000;odLkG00?o0000ojg2jOn]`^T00ol00002ojJ/f`03o`000?nF[^So
UZkX00GoUZkX00Co0000ohb]k?l0003o00001On:[>`01?l0003oQj[/o`000?l00005ohRYj`03o`00
0?n7Y^WoQjKY00CoQjKY00Go0000ohRVj?n8Y^SoR:KXo`000003ohFSi`03o`000?n6X^KoQZ;V00;o
QZ;V00Co0000ohNQiOn7XNGoQj7U0ol00003ohFMh`05o`000?n5W>;oQIcRohFLh_l000001On6Vn00
0ol0003oQYWOohJIg`02ohJIg`05o`000?n6V=goQYSMohJHgOl000001?n6U]`00ol0003oQICJohFD
fP03ohFDfP05o`000?n4TMWoQ97IohBAfOl000001?n2S]L00ol0003oOh_Fogn;eP03ogn;eP;o0000
0on1RM800ol0003oO8C@ogb4d003ogb4d003o`000?meO/koMGk>00;o00000_mlP<`00ol0003oLGO9
og5gb@03og5gb@03og]iaOl0003oIf[200KoIf[200?o0000od]@]_m;D;H01?m;D;H01ol0003oCDV]
ode9[Om=BJgo0000o`DJVol000001?l008L01Ol0003o001ao`00LOl0077o000006_ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`00;Oooool00ol0003oooooooooo`07oooo
o`;o00000ooAc]L00ol0003odLkGom7>e`06ojg2j@;o000000?oUZkXo`000?nF[^P01?nF[^P00ol0
003oS:g/ohb]k002ohb]k005o`000?n:[>coRZc/ohZ/k?l000001?n7Z^`00ol0003oR:W[ohRYj`02
ohRYj`03o`000?n5Yn[o000000GoQjKY00?o0000ohRVj?l000001On5XnL00ol0003oQZ;VohJRiP02
ohJRiP03o`000?n7XNGo000000;oQ9kT00?o0000ohFMhon5WN<00_n5WN<01Ol0003oQIcRohFLh_n5
W>;o000000CoQY_P00?o0000ohJIgon6VMl00_n6VMl00ol0003oQYSMohJHg@02ohJHg@03o`000?n6
U]coQYKL00;oQYKL00?o0000ohFDf_n5U=X00_n5U=X01Ol0003oQ97IohBAfOn4TMWo000000GoPXkG
00?o0000ogn;e_moRmH00_moRmH2og^7e004o`000?n1RM;oPHWBo`0000GoO8C@00?o0000ogEnc_me
O/h00_meO/h00ol0003oO83<o`000006og5gb@03o`000?mWJ/;oIf[200GoIf[200?o0000od]@]_m;
D;H01Om;D;H01?l0003oCDV]ode9[Ol00002o`DJV`05o`000?l008Oo0027o`00Qol000000ol00740
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool0
02gooooo00?o0000ooooooooool01oooool00ol0003odLkGom7>e`02om7>e`03o`000?oAc]Oo0000
00Oo[L;Y00?o0000oiJfk_nF]^h00ol00002oiJ^j003o`000?n<[NcoS:g/00?oS:g/0_l000000on:
[>co0000ohNZk004ohNZk0;o000000?oR:W[o`000?n5YnX00on5YnX00ol0003oQjKYohNVj@02ohNV
j@03o`000?n5XnOoQJ?W00GoQJ?W00Co0000ohJRi_n6X^KoQZ;V0_l00004ohBNi003o`000?n5WN?o
QIgS00;oQIgS00Go0000ohFLh_n5W>;oQIcRo`000004ohJKh003o`000?n6VMooQYWO00;oQYWO00Go
0000ohJHgOn6V=goQYSMo`000004ohJFg003o`000?n5U=[oQICJ00;oQICJ00?o0000ohBAfOn4TMT0
0_n4TMT00ol0003oPXkGoh:>e`02oh:>e`03o`000?moRmKoOh_F00;oOh_F00Ko0000og^7e?mkQmCo
NhODoh69d_l00005ogb4d003o`000?meO/koMGk>00?oMGk>00?oO83<o`000?maMlT01OmaMlT00ol0
003oIf[2ofMZ`P05ofMZ`P;o00001_m;D;H01?l0003oCDV]ode9[Ol00002o`DJV`05o`000?l008Oo
0027o`00Qol000001?l007400ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0;_ooool002gooooo00?o0000ooooooooool01oooool00ol0003odLkGom7>e`02
om7>e`03o`000?oAc]Oo000000Ko[L;Y00?o0000oiJfk_nF]^h01?nF]^h2o`0000SoS:g/00?o0000
ohNZk?n7Z^`01_n7Z^`00ol0003oQJOZohFWjP04ohFWjP;o000000CoQjKYo`000?n4XnSoQ:?X0_l0
0005ohFSi`03o`000?n6X^Ko000000;oPioU00?o0000ohBNi?n4W^@00_n4W^@00ol0003oQIgSohFM
h`02ohFMh`05o`000?n5W>;oQIcRohFLh_l000000_n6Vn0Go`0000;oQ97I00?o0000oh:>eon2S]L0
0_n2S]L00ol0003oOh_Fogn;eP02ogn;eP03o`000?mkQmCoNhOD00;oNhOD0_l00004ogb4d003o`00
0?meO/koMGk>00CoMGk>00?o0000og5gbOmaMlT01?maMlT2o`0000KoIf[200?o0000od]G_Ol00000
1_m;D;H2ode9[@05o`000?l56Y_o1AZKo`DJVol000000ol008L01Ol0003o001ao`00LOl0077o0000
06Sooooo00?o0000ooooooooool0;Oooool3o`00033ooooo000/ooooo`03o`000?oooooooooo00Oo
oooo00?o0000om7>eooAc]L00ooAc]L2o`0000Oo[L;Y00?o0000oiJfk_nF]^h01OnF]^h00ol0003o
Rjo^o`000002o`0000CoS:g/00?o0000ohNZkOl000000_l00004ohNZk003o`000?n4Yn_o000000Ko
QJOZ00?o0000ohBSj?n4XnP00on4XnP00ol0003oQJ?WohFSi`03ohFSi`03o`000?n3WnGoPioU00;o
PioU00?o0000ohBNi?n4W^@00_n4W^@00ol0003oQIgSohFMh`02ohFMh`03o`000?n5W>;oQIcR00?o
00000_n2V>000ol0003oPYONoh:GgP02oh:GgP05o`000?n2UMgoPYGMoh:EgOl000001?n1Tm`5oh2A
f`;oOXoI0ol00004oh:>e`03o`000?moRmKoOh_F00;oOh_F00?o0000og^7e?mkQm@00_mkQm@2ogJ3
dP05o`000?mlQ=3oO8C@ogb4d?l000001_meO/h00om[Mlgo0000og5gb@04og5gb@03o`000?mQJlKo
000000GoIf[200?o0000od]G_Ol000001_m;D;H2o`0000Co1AZK00Go0000o`00Qol008Oo0027o`00
0003o`00L@03o`000?oooooooooo06Gooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0^ooooo`00;?ooool00ol0003oooooooooo`07ooooo`03o`000?oAc]OodLkG00?odLkG2Ol00000
0onF]^ko0000oiJfkP04oiJfkP03o`000?n;[nkoRjo^00?oRjo^0_l000000on<[Nco0000ohNZk@04
ohNZk@;o000000?oQj[/o`000?n4Yn/00_n4Yn/2o`0000?oQJOZ00Co0000oh>TjOn3Y>Wo00001?n4
XnP2o`000003ohFSiol0003oPYoV00;oPYoV1?n3WnD00ol0003oQ9kTohBNi002ohBNi003o`000?n5
WN?oQIgS00Co000000?oPYWQo`000?n2V>000on2V>000ol0003oPYONoh:GgP02oh:GgP05o`000?n2
UMgoPYGMoh:EgOl000001?n1Tm`4oh2Af`03o`000?mnSmWoOXoI00;oOXoI1?l000000on2S]Oo0000
ogn;eP03ogn;eP05o`000?mkQmCoNhODog^7e?l000000_mfPm82o`000003ogb4d?l0003oMGk>00Go
MGk>00?o0000of]gcOl000001?maMlT01?l0003oHF_6of5[a_l00003ofMZ`P05o`000?m;EkgoBeNm
od]G_Ol000001_m;D;H00ol0003o1AZKo`DJV`02o`DJV`05o`000?l008Oo0027o`00Qol000000ol0
07400ol0003oooooooooo`1Tooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;_oo
ool002cooooo00?o0000ooooooooool01oooool00ol0003odLkGom7>e`02om7>e`?o00001_nCfOh0
0ol0003oRkcgoh^lm`03o`0000;oU[K^00?o0000oh^_k_n;[nh01On;[nh00ol0003oQj[]ohNZk@06
ohNZk@03o`000?n4Yn_oQ:O[00CoQ:O[00?o0000ohFWj_l000001?n3Y>T00ol0003oQ:?XohBSj003
ohBSj003o`000?n2WnKoPYoV00?oPYoV00Go0000oh>OiOn3WnGoPioUo`000003ohBNi0?o00000_n1
V^801Ol0003oPYWQoh:IhOn2VN7o000000CoPYSP00Go0000oh:Gg_n2UmkoPYONo`000003oh:Eg@03
o`000?n1TmcoPI?L00;oPI?L00?o0000oh2Afon0TM/00_n0TM/01?l0003oOXoIogj?fOmnSmT4ogb<
f0?o00000omoRmH01Ol0003oNhODog^7e?mkQmCo000000CoMX?B00?oO8C@o`000?meO/h01OmeO/h0
1?l0003oJgO=of]gcOl00002og5gb@03o`000?mQJlKoHF_600;oHF_600Co0000ofMZ`_mWJ/;o0000
1?m;Ekd00ol0003oBe2fod]@]P03od]@]P03o`000?l56Y_o1AZK00?o1AZK00Go0000o`00Qol008Oo
0027o`000002o`00L@03o`000?oooooooooo06Cooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0^ooooo`00;?ooool2o`0000Sooooo00?o0000om7>eooAc]L00_l000000om_fJgo0000
oi?IoP06oi?IoP03o`000?n;_?OoRkcg00?oRkcg0_l00008oh^_kP03o`000?n5Znko000000;o0000
1?n7Z^d00ol0003oPjO/o`000005ohBWj`03o`000?n3Y>WoPjCY00CoPjCY00Go0000ohBSj?n4XnSo
Q:?Xo`000002oh6Pi`03o`000?n2WnKoPYoV00;oPYoV00Oo0000oh>OiOn3WnGoPioUo`000?n4W^Co
000000;oPI_S00Go0000oh6Jh_n1V^;oPI[Ro`000003oh:Ih@03o`000?n2V>3oPYSP00;oPYSP00Go
0000oh:Gg_n2UmkoPYONo`000003oh:Eg@03o`000?n1TmcoPI?L00;oPI?L00Go0000oh2Afon0TM_o
P97Ko`000003ogj?f@03o`000?mlS=SoO8cH00;oO8cH0_miRML2o`000003ogn;e_l0003oNhOD00;o
NhOD00?o0000ogJ3d_mfPm800omfPm82o`0000GoMGk>00Oo0000of]gcOm[MlgoJgO=o`000?maMlWo
000000GoHF_600?o0000ofMZ`_l000001?m;Ekd00ol0003oBe2fod]@]P03od]@]P03oaXa[?l0003o
1AZK00?o1AZK00Go0000o`00Qol008Oo0027o`000003o`00L@03o`000?oooooooooo06;ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0^ooooo`00:oooool00ol0003oooooooooo`07
ooooo`;o000000?odLkGo`000?m_fJd01ol00003oi?IoP03o`000?n;_?OoRkcg00CoRkcg00?o0000
ohFal_l000000_l00004oh^_kP03o`000?n5ZnkoQJ_^00;oQJ_^0_l000000on7Z^go0000oh>Wk002
oh>Wk0;o00000on4Yn/00ol0003oPJCZo`000005oh>Tj@03o`000?n4XnSo000000CoPJ3W00?o0000
oh:Oi_n2WnH00_n2WnH00ol0003oPioUoh>Oi@02o`0000CoPI_S00Go0000oh6Jh_n1V^;oPI[Ro`00
0003oh:Ih@05o`000?n2V>3oPYSPoh:Hh?l000001?n2Umh01Ol0003oPYGMoh:EgOn2UMgo000000?o
PI?L00Go0000oh2Afon0TM_oP97Ko`000004ogj?f@05o`000?mlS=SoO8cHogb<f?l000001?miRML2
o`0000?oNhOD00?o0000ogJ3d_mfPm800_mfPm82ofmmd@05o`000?meO/koMGk>ogEnc_l000001Om[
Mld00omaMlWo0000of5[aP05of5[aP;o00001Om;Ekd01ol0003oBe2fod]@]_m;D;Ko0000oaXa[?l0
00001Ol56Y/01?l0003o0027o`00Qol00003o`00L@03o`000?oooooooooo067ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0]ooooo`00:oooool00ol0003oooooooooo`07ooooo`03
o`000?oAc]Oo000000?o000000?oB000o`000?mKa?/00omKa?/4o`000003oh^lmol0003oRkcg00?o
Rkcg00?o0000ohFal_n5/O800_n5/O84o`0000OoQJ_^00?o0000oh>Wk?n3Yn`01?n3Yn`00ol0003o
Q:O[o`000004oh6TjP03o`000?n3Y>WoPjCY00;oPjCY00?o0000oh6Pion1X>L01?n1X>L01?l0003o
PYoVoh:Oi_n2WnH3o`0000?oP9cT1?n1Vn<01Ol0003oPI[Roh6Jh_n1V^;o000000?oPYWQ00Go0000
oh:Hh?n2V>3oPYSPo`000003oh:GgP05o`000?n2UMgoPYGMoh:EgOl000000on1Tm`01Ol0003oP97K
oh2Afon0TM_o000000CoOXoI00?o0000ogb<f?mlS=P00_mlS=P01?l0003oNHWGogV9eomiRML2ogJ6
eP;o000000?oNhODo`000?mfPm800omfPm800ol0003oKggAofmmd@02o`000003ogEnc_l0003oJgO=
00GoJgO=00?o0000of5[a_mQJlH01OmQJlH00ol0003oBeNmod]G_@04od]G_@04o`000?m;D;KoBe2f
o`0000;o6S6/00?o0000o`DJVol56Y/00_l56Y/01Ol0003o0027o`00Qol008Oo000000;o001a00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo000002oooooo000[
ooooo`03o`000?oooooooooo00Oooooo0_l000001?mmS=Oo0000o`000?l;RN82o`0000OoFlCk00?o
0000ogbhnOml^?T00ol000000on;_?Oo0000ohFalP06ohFalP03o`000?n5ZnkoQJ_^00GoQJ_^00Co
0000oh6XkOl0003o00001?n3Yn`00ol0003oPJCZoh6TjP04oh6TjP;o000000GoPjCYo`000?n0XNSo
P:7Xo`000005oh6Pi`03o`000?n2WnKo000000;oOicU00?o0000oh2Li?n0W>@00_n0W>@01Ol0003o
PI_Soh6Khon1Vn?o000000?oPI[R00?o0000oh:IhOn2VN405?l000000on0TM_o0000ogj?f@02ogj?
f@03o`000?mlS=SoO8cH00;oO8cH00Go0000ogV9eomiRMOoNHWGo`000003ogJ6eP03og^7e?l0003o
MX?B00?oMX?B00?o0000ofmmdOm_OM400_m_OM400omeO/ko0000of]gc@05of]gc@03oei^bol0003o
HF_600GoHF_600?o0000od]G_Om;Ekd01?m;Ekd01?l0003oBe2fod]@]_l00002oaXa[003o`000?l5
6Y_o1AZK00;o1AZK00Go0000o`00Qol008Oo0027o`000002o`00L@03o`000?oooooooooo063ooooo
00?o0000ooooooooool0=?ooool2o`0002oooooo000[ooooo`03o`000?oooooooooo00Sooooo00Oo
0000ogf<eommS=OoOHcGo`000?l;RN;o000000;oJ:ki0ol000000omKa?_o0000ogbhn@05ogbhn@;o
00001on5/O800ol0003oPZc_o`000002o`0000?oQJ_^00Go0000oh6XkOn1Z>goPJS]o`000003oh>W
k004o`000?n0Y>_o0000o`0000GoPJCZ00?o0000oh2Qj?n0XNP00on0XNP00ol0003oPJ3Woh6Pi`02
oh6Pi`03o`000?moW>GoOicU00;oOicU00?o0000oh2Li?n0W>@00_n0W>@01Ol0003oPI_Soh6Khon1
Vn?o000000;oPI[R0ol000000omnU^7o0000ogjEg`02ogjEg`05o`000?mnU=koOYCNogjDg_l00000
0ommT]d01?l0003oO97LogbAg?mlTM`3og^?f`Go000000?oOXoIo`000?mlS=P00_mlS=P01Ol0003o
NHWGogV9eomiRMOo000000CoMXKF0_l00004ogJ3dP03o`000?m_OM7oKggA00;oKggA0_l00005of]g
c@03o`000?mNK/_o000000GoHF_60_l00006od]G_@;o00001?lJ<J`00ol0003o1AZKo`DJV`02o`DJ
V`04o`000?l008Oo0027o`0000;o001a00?o0000ooooooooool0Goooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo02gooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000ogf<
eommS=L00_mmS=L3o`0000CoJ:ki0_l00007ogbhn@03o`000?n0/??oP;3c00?o000000?oQK7bo`00
0?n2[>l01?n2[>l3o`0000GoPJS]0ol00004oh2Tj`03o`000?n1Y>[oPJCZ00;oPJCZ00?o0000ogjQ
jOl000001?n0XNP2o`000004oh6Piol0003oOYgVogjMiPCoOicU00?o0000oh2Li?n0W>@00_n0W>@0
0ol0003oPI_Soh6Kh`03o`000003ogfGhOl0003oOYKQ00;oOYKQ00Go0000ogjEgomnUMooOYGOo`00
0003ogjDgP05o`000?mmT]goOI;MogfBgOl000000omlTM`3og^?f`CoNHgJ0ol00002ogb<f005o`00
0?miRMOoNHWGogV9eol000001?mfQ]H2og62e0;o00000_mfPm800ol0003oKggAofmmd@02ofmmd@;o
IgS@00?o0000of]gcOm[Mld00_m[Mld01?l0003oGVk;oei^bol00004of5[aP03o`000?m=G/Co0000
00KoBeNm00?o0000oaXa[?lJ<J`00_lJ<J`00ol0003o1AZKo`DJV`02o`DJV`04o`000?l008Oo0027
o`0000?o001a00?o0000ooooooooool0GOooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo02gooooo000Zooooo`03o`000?oooooooooo00Wooooo00?o0000ogf<eommS=L00_mmS=L00ol0
003oOHcGo`000005ofR^n@03o`000?mk[oCo000000;o00000oml^?T00ol0003oP;3coh2`l`03oh2`
l`;o00001on2[>l00ol0003oPJS]oh6Xk@05oh6Xk@03o`000?n0Y>_oP:C[00?oP:C[0_l000000on1
Y>[o0000ogjQj@02ogjQj@;o00001?n0XNP00ol0003oOYgVogjMiP02ogjMiP05o`000?moW>GoOicU
ognLiOl000000on0W>@3o`000003ogfHh_l0003oOIOQ00;oOIOQ00Go0000ogjFhOmnU^7oOYKQo`00
0002ogjEg`05o`000?mnU=koOYCNogjDg_l000000ommT]d01Ol0003oO97LogbAg?mlTMco000000?o
NhoK1?miSMX2ogN;f@;o000000?oO8cHo`000?miRML00_miRML01Ol0003oMXKFogJ6e_mfQ]Ko0000
00?oLH;D00?o0000ogJ3d_l000001?m_OM401?l0003oIgS@ofMhd?l00002of]gc@03o`000?mNK/_o
GVk;00;oGVk;00Co0000of5[a_mQJlKo00000om=G/@00ol0003oBeNmod]G_@03od]G_@03o`000?lJ
<Jco6S6/00?o6S6/00Go0000o`DJVol56Y_o1AZKo`000003o`00Q`04o`000?l0077o001ao`0005ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0]ooooo`00:_ooool3o`0000Wooooo
00?o0000ogf<eommS=L00_mmS=L01?l0003oOHcGo`000?n2X^P2o`0000;oJ:ki00?o0000og^_m?mk
[o@00_mk[o@3o`0000OoP;3c00?o0000ogn[l?l000000_l00003oh:/k`03o`000?moZ>ko000000;o
00000on1Z>d00ol0003oOZC/o`000002o`0000?oP:C[00?o0000ogjQjOmnXNT01?mnXNT01_l0003o
P:7Xoh2Qj?n0XNSo0000ogbMi`CoOYgV00Wo0000ognLiOmoW>GoOicUo`000?n0W>Co0000ogbIhol0
00000ommV>801Ol0003oOIOQogfGhOmmUn7o000000?oOYKQ00Co0000ogjEgomnUMoo00000omnU=h0
1Ol0003oOI;MogfBgOmmT]go000000?oO97L00Co0000og^?fomkSm_o00000omiSMX00ol0003oMh_I
ogN;f@02ogN;f@;o00000_miRML01Ol0003oMXKFogJ6e_mfQ]Ko000000GoLH;D0_l00003ofmmd@07
o`000?mWN=3oIgS@ofMhd?l0003oJgO=o`000005oei^b`03o`000?mQJlKo000000CoCEk400Oo0000
od]G_Om;EkgoBeNmo`000?l[A;So000000Co6S6/00?o0000o`DJVol56Y/00_l56Y/01?l0003o0027
o`00Qol00002o`00L@03o`000?oooooooooo05cooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0]ooooo`00:_ooool00ol0003oooooooooo`09ooooo`03o`000?mmS=OoOHcG00;oOHcG
00?o0000ogf<eol000000on2X^P3o`0000KoNjod00?o0000oh2`lol000001On0/?<00ol0003oOj_`
ogn[l002ogn[l0?o00001OmoZ>h3o`0000GoOZC/0_l000001?n0Y>_o0000ogfQj_l00005ogjQj@03
o`000?n0XNSo000000?oO9gW00Go0000ogjMi_mnWNKoOYgVo`000003ognLi@05o`000?mlVN?oO9WS
ogbIhol000000ommV>801Ol0003oOIOQogfGhOmmUn7o000000;oOYKQ00Go0000ogjEgomnUMooOYGO
o`000003ogjDgP05o`000?mmT]goOI;MogfBgOl000000_mlTM`01Ol0003oNhoKog^?fomkSm_o0000
00?oNHgJ00Co0000ogN;fOmgRmWoMh_I0_mdR=P00ol0003oNHWGo`000004ogJ6eP03o`000?maP]Co
LH;D00;oLH;D0_m[OM<01?l0003oKggAofmmdOl00004ofMhd003of]gcOl0003oGVk;00GoGVk;00?o
HF_6o`000?m=G/@00om=G/@01Ol0003oBeNmod]G_Om;Ekgo000000;o:dBh00?o0000oaXa[?lJ<J`0
0_lJ<J`01Ol0003o1AZKo`DJVol56Y_o000000;o002700Co0000o`00LOl0077o0000GOooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000;ooooo`04okZj^_l@413o0000ogMg
M`Kooooo00?oEEEEo`000?mEEED01?ooool01_nHV9So410@o`000?l0003oA4A4onk^kPSooooo00?o
0000ooooooooool02Oooool00ol0003oOHcGogf<e`02ogf<e`03o`000?mmS=Oo000000GoPZ;X00?o
0000og^_m?mk[o@01?mk[o@00ol0003oOZgbogj]lP03o`000003oh2`lol0003oOj_`00KoOj_`00?o
0000ognXk_moZ>h01OmoZ>h00ol0003oOZC/ogjTk005ogjTk003o`000?mmXN[oOJ7Z00;oOJ7Z00?o
0000ogjQjOmnXNT00_mnXNT00ol0003oO9gWogbMi`03ogbMi`09o`000?mnWNKoOYgVogjMi_l0003o
OicUo`000?mkVNCo000000?oO9WS00Go0000ogfHh_mmV>;oOISRo`000002ogfGh@05o`000?mnU^7o
OYKQogjFhOl000000_mnUMl01Ol0003oOYCNogjDg_mnU=ko000000?oOI;M00Co0000ogbAg?mlTMco
00000omkSm/01Ol0003oNHgJogV=f_miSM[o000000?oMh_I00Co0000ogB8f?mdR=SoM8SH0_l00003
ogJ6eP03o`000?maP]CoLH;D00;oLH;D00Ko0000of]mdom[OM?o0000ofmmdOl00005ofMhd003o`00
0?mNK/_oGVk;00GoGVk;00?o0000odeNa?m=G/@00om=G/@01?l0003oBeNmod]G_Ol00002ob]4^003
o`000?lJ<Jco6S6/00;o6S6/00?o0000o`DJVol56Y/00_l56Y/3o`00Q`03o`000?l0077o000005co
oooo00?o0000ooooooooool0>Oooool3o`0002kooooo000:ooooo`06olc<c?lb<S;ok^k^onk^k_lQ
8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@7ooooo`03o`000?oo
oooooooo00[ooooo0ol00002ogf<e`03o`000?mmS=Oo000000GoPZ;X00?o0000oh6Zkon1Z^l00ol0
00000omk[oCo0000ogj]lP04ogj]lP;o00001omoZo000ol0003oOJS_o`000002o`0000?oOjS^00?o
0000ogbTkOl000000_l00003ogjTk003o`000?mkXN_o000000?oOJ7Z0_l000001OmnXNWo0000og^M
j?mkWNSo000000CoO9gW00?o0000ogjMi_mnWNH00_l00003og^Ii005o`000?mlVN?oO9WSogbIhol0
00000ommV>801?l0003oOIOQogfGhOl00002ogjFhA?o00000omiSMX00ol0003oMh_IogN;f@02ogN;
f@03o`000?mdR=SoM8SH00;oLHGG0_l000000omfQ]Ko0000og62e003og62e006o`000?m[OM?oJggC
of]mdom_OM7o00001OmWN=000omMLLoo0000oei^b`05oei^b`03o`000?m=G/CoCEk400CoCEk40_l0
0004ob]4^003o`000?lJ<Jco6S6/00;o6S6/00Co0000o`DJVol56Y_o1AZK0ol008L4o`0005[ooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0/ooooo`002_ooool01_m4A4CoZJVYoooo
ooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED02Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00[ooooo00?o0000oiZMe_nJWMH00ol000000ommS=Oo0000oh:Rj004oh:Rj003
o`000?n1Z^ooPJ[_00?oPJ[_0_l00006ogj]lP03o`000?mmZ_7oOJ[a00?o000000?oOj_`o`000?mm
Z>l01?mmZ>l3o`0000GoO:C]0ol00004og^Qj`05o`000?mmXN[oOJ7ZogfQj_l000001OmkWNP01?l0
003oO9gWogbMiomlWNL2o`0000?oNY[U0omkVN@01Ol0003oO9WSogbIhomlVN?o000000;oOISR1_l0
00001OmjTn3o0000ogZBgomjT]oo000000?oNI7N00Go0000ogV@gOmiT=goNI3Mo`000002ogR?g@?o
MhgL1?l000000omiSM[o0000ogN;f@02ogN;f@04o`000?mdR=SoM8SHo`0000CoLHGG0_l00003og62
e003o`000?m[OM?oJggC00;oJggC0_l00004ofMhd003o`000?mMLLoo000000CoGVk;00?o0000oe1U
bOl000001_m=G/@00ol0003o:dBhob]4^003ob]4^005o`000?lJ<Jco6S6/oaXa[?l000000ol56Y/0
1?l0003o0027o`000?l00002okMd0003o`000?oooooooooo05Sooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0/ooooo`0000?oooooo`000?l000001Ol00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03_ooool00oo^k^ko0000ooooo`06ooooo`03o`000?oooooo
oooo00[ooooo00?o0000oiZMe_nJWMH00_nJWMH5o`0000CoPZ;X00?o0000oh6Zkon1Z^l00on1Z^l0
0ol0003oOZcao`000002o`0000;oOZgb00?o0000ogfZlOmmZ_400ommZ_42o`0000OoOJS_00?o0000
ogbTkOmlY>d01OmlY>d00ol0003oNj7[og^Qj`03og^Qj`;o000000CoOJ7Zo`000?mjW^Wo00001?mk
WNP2o`000003ogbMiol0003oNI[V00CoNY[U00Co0000og^Ii?mkVNCo00000omlVN<2o`000005ogVE
h_l0003oNICQogVDhOl000000omjTn001?l0003oNY;OogZBgol00003ogVAgP05o`000?miT=goNI3M
ogV@gOl000000_mhSmd3ogN=g0?oMH_K0ol00002ogN;f@05o`000?mdR=SoM8SHogB8f?l000000oma
QML2off2e`;o000000?oLH;Do`000?m[OM<00om[OM<2ofAid`05o`000?mWN=3oIgS@ofMhd?l00000
0_mMLLl01Ol0003oGVk;oei^bomNK/_o000000;oD6G900?o0000odeNa?m=G/@00om=G/@00ol0003o
:dBhob]4^003ob]4^003o`000?lJ<Jco6S6/00;o6S6/0ol56Y/2o`000005o`00Eol0003o]g@0okMd
0?l00000FOooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02cooooo000:ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_l@413oV9RHooooooooooooMgMg
ofIVIPOooooo00?o0000ooooooooool02_ooool00ol0003oVYgFoiZMeP02oiZMeP03o`000?nJWMKo
000000;oSZ[X0ol000000on2X^So0000oh6Zk`04oh6Zk`03o`000?mn[?7oOZca00;oOZca0ol00006
ogfZl@03o`000?mjYnoo000000;o00000ommZ>l00ol0003oNZC^o`000002o`0000?oO:C]00Co0000
ogVQk?l0003o00001?mkXN/00ol0003oNYkYogZNj@02ogZNj@03o`000?mkWNSoNigX00;oNigX00Go
0000ogVJi_miV^KoNI[Vo`000003ogZJi@08o`000?mkVNCoNiWTo`000?mlVN?o0000ogRFhol00002
ogVEhP04o`000?miU>7oNICQo`0000?oNY?P00Co0000ogZBgomjT]oo00000_miTMh01Ol0003oNI3M
ogV@gOmiT=go000000;oN8oM00Co0000ogN=g?mgSMcoMhgL0omeRm/2og>9fP;o000000GoMh_Io`00
0?mdR=SoM8SHo`000003og65e`06o`000?m]P]OoKH;Goff2eomaP]Co00001?m[OM<01?l0003oI7WC
ofAidol00002ofMhd005o`000?mMLLooGG7?oeeacol000000_mNK//01Ol0003oD6G9oe1UbOm@ILWo
000000?oCEk400?o0000ocMB`_l000001Ol[A;P02Ol0003o6S6/oaXa[?lJ<Jco0000o`DJVol0003o
0024o`000002o`00E`03o`000?ngM03o000005Sooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0/ooooo`002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo
00Go0000ob4Q8Ol0003o0000ofIVIP08ooooo`?o00002_ooool00ol0003oVYgFoiZMeP02oiZMeP03
o`000?nJWMKo000000GoSZ[X1_l00002oh6Zk`03o`000?mn[?7oOZca00?oOZca00?o0000ogfZlOl0
00001?mmZ_400ol0003oNZO_ogZWk`02ogZWk`?o00001OmjY>h3o`0000CoNJ7/00Oo0000og^Qjomk
XN_oNj7[o`000?mhW^Wo000000?oNYkY0_l000001?mkWNSo0000ogRJiomhV^L4ogVJiP05o`000?mj
V^GoNY[Uo`000?mkVN@00_l00003ogRFh`04o`000?miUN;oNIGRo`0000;oNICQ00Go0000ogZCh?mj
Tn3oNY?Po`000002ogZBg`04o`000?miTMkoNI7No`0000?oNI3M00Co0000ogR?gOmhSmgo00000_mg
SM`01?l0003oMH_KogF;fomeRm/4og>9fP;o000000?oM8SHo`000?maQML00_maQML00ol0003oKH;G
off2e`02off2e`;o00000om[OM<01ol0003oI7WCofAidomTNM?o0000ofMhd?l000001?mMLLl00omN
K/_o0000oe1Ub@04oe1Ub@04o`000?m=G/CoCEk4o`0000;o=e;200?o0000ob]4^?l[A;P00ol[A;P0
1Ol0003o6S6/oaXa[?lJ<Jco000000?o002400?o0000o`00Eol000000_ngM0000ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0;?ooool000[ooooo00KoA4A4
ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3?ooool01Ol0003oVYgFoiZMe_nJWMKo000000;oVYgF00?o0000ohjZj?n>Z^P00on>Z^P00ol0003o
Q:g`ohB]l002ohB]l0?o00001Omn[?400ol0003oNj[aog^Zl@03o`000003ogfZlOl0003oNZO_00Go
NZO_00?o0000ogZTk_mjY>h01OmjY>h00ol0003oNJ7/ogVQk003ogVQk0?o00001?mhW^T01Ol0003o
NYkYogZNjOmjW^Wo000000CoN9[W00Ko0000ogVJi_miV^KoNI[Vo`000?mjV^D2o`0000KoN9KS00Co
0000ogVEh_miUN;o00000_miU>401?l0003oNY?PogZCh?l00003ogZBg`04o`000?miTMkoNI7No`00
00;oNI3M00Go0000ogR?gOmhSmgoN8oMo`000002ogN=g004o`000?meRm_oMH_Ko`0000?oLhWJ0_m`
QmT00ol0003oM8SHo`000003og65e`04o`000?m]P]OoKH;Goff2e`;oJ7kF00Co0000of]mdom[OM?o
00001?mTNM<00omWN=3o0000oeeac`04oeeac`03o`000?m@ILWoD6G900CoD6G90_m=G/@01?l0003o
=e;2ocMB`_l00005ob]4^005o`000?lJ<Jco6S6/oaXa[?l000000ol008@00ol0003o001Go`000002
okMd0003o`000?oooooooooo05Cooooo00?o0000ooooooooool0?Oooool3o`0000Kooooo00Co^[Zj
oa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06oiRHV?l@413o0000o`000?m4A4Co
k^k^4Oooool000[ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03?ooool01Ol0003oVYgFoiZMe_nJWMKo000000;oVYgF00?o0000
ohjZj?n>Z^P00on>Z^P00ol0003oQ:g`ohB]l004ohB]l003o`000?mm[?;oOJcb00?o000000?oOZca
o`000?mkZ_400omkZ_42o`0000KoNZO_00?o0000ogRTk_l000000_l00003ogZTkP03o`000?mgXNco
000000;o00000omiXN`00ol0003oN9kYogRNj@03ogRNj@;o000000?oNYkYo`000?mfV^L01?mhV^L0
1Ol0003oNI[VogVJi_miV^Ko000000?oMiKT0omhU^<01?l0003oN9KSogRFhol00002ogVEhP04o`00
0?miU>7oNICQo`0000;oNY?P00?o0000ogZBgomjT]l01?l00002ogV@g@05o`000?mhSmgoN8oMogR?
gOl000000_mgSM`01?l0003oMH_KogF;fol00003og>9fP04o`000?m`QmWoL8OIog27f@;o00000_ma
QML01Ol0003oKH;Goff2eom]P]Oo000000;oJ7kF00?o0000of]mdol000001OmTNM<00ol0003oGG7?
oeeac`03oeeac`03oe9[c_l0003oD6G900GoD6G900?o0000ocMB`_lgD/800_lgD/800ol0003o:dBh
ob]4^003ob]4^005o`000?lJ<Jco0000o`0HX_l000000_l008@01_l0003o001Go`00Eol0003o]g@0
o`0005Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`03ooooo`06olc<c?lb<S;o
k^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@Aoooo
o`002oooool01?nj^[[o410@oa0@4?o<c<`=ooooo`Go00001oooool00ol0003oooooooooo`0<oooo
o`03o`000?nJWMKoVYgF00Wo00000_n>Z^P00ol0003oQ:g`ohB]l003ohB]l003o`000?mm[?;oOJcb
00?oOJcb0_l00005og^Zl@03o`000?mhYo3oN:O`00?o000000?oNZO_o`000?mhY>h00omhY>h3o`00
00GoMj7/0_l000000omiXNco0000ogJNjP02o`0000CoN9kY00Co0000ogJJiomfV^OoMY[W0_l00002
ogRJi`05o`000?miV^Ko0000ogJGiOl000000omgU^@01?l0003oN9KSogRFhol00002ogRFh`05o`00
0?miUN;oNIGRo`000?miU>401_l000001?mfT=oo0000ogF?g_meSmh:o`0000?oMH_K00Co0000og>9
f_mcRM[o00000om`QmT2off4f@03o`000?maQMOo000000?oKH;G00Ko0000ofQne_mXO]KoJ7kFof]m
dol00005ofAid`03oeedd_l0003oGG7?00?oGG7?00?o0000oe9[c_l000001Om@ILT00ol0003o=e;2
ocMB`P03ocMB`P03o`000?l[A;So:dBh00?o:dBh00Co0000o`0HX_l06:;o00000ol008@01Ol0003o
001Go`000?ngM03o000005Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`02oooo
o`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@09ooooo`03o`000?oo
oooooooo00oooooo000Xooooo`03o`000?oooooooooo00cooooo1?l00003oj;An003o`000?n:_OOo
R[gg00;oR[gg1ol00002ohB]l003o`000?mm[?;oOJcb00?oOJcb00?o0000ogVYlOmiZO400ol00000
0omkZ_7o0000ogRWl003ogRWl0;o00001_mhY>h00ol0003oMj7/ogNQk005ogNQk003o`000?mfW^[o
MYkZ00;oMYkZ00Ko0000ogRNjOmhW^WoN9kYo`000?meV^P4ogJJi`04o`000?mhV^OoN9[Wo`0000?o
MYOU00Go0000ogNFi?mgU^CoMiKTo`000002ogRFh`03o`000?mhU^?o000000Co000000GoMY7Po`00
0?mfTN3oMY7Po`000003ogJ@g`03o`000?meSmko000000;oM8kN00Co0000og>=gOmcSMgoLhgM0omb
Rm`2o`000003ogF;fol0003oLhWJ00;oLhWJ00Co0000og27fOm`QmWo00000om]Q=T2o`0000;oKH;G
00?o0000ofQne_mXO]H00_mXO]H2o`0000CoI7WC00?o0000oeedd_l000000omMLLl01?l0003oDV_>
oe9[c_l00003oe1Ub@03o`000?m1GLSo000000Go=e;200?o0000ob]4^?l[A;P00_l[A;P01Ol0003o
01RRo`0HX_l06:;o000000;o002400?o0000o`00Eol000000_ngM0000ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00kooooo00?ok^k^o`000?ooool04?ooool002Oooooo00?o0000oooooooo
ool03Oooool01?l0003oX]7hoj;An?l00004oj;An003o`000?n:_OOoR[gg00?oR[gg00?o0000ognc
m_mo/oH00_mo/oH3o`000003ogf/l_l0003oOJcb00;oOJcb00?o0000ogVYlOmiZO400omiZO42o`00
00GoN:O`00?o0000ogFSkol000000_l00002ogRTkP03o`000?meXNgo000000;o00000omgXN`00ol0
003oM9g[o`000003ogJNjP?o00000omeV^P2o`0000;oMY[W00Co0000ogRJiol0003oM9OU0omfUnD0
1_l0003oMiKTogNFi?mgU^Co0000ogRFh`;o000000GoMI;Ro`000?meT^7oMI;Qo`000002ogJAh004
o`000?mfTN3oMY7Po`0000;oMY3O00Co0000ogF?g_meSmko00000_mdS]h01?l0003oLhgMog>=gOmc
SMd2og:;g0;oLHWL0_l00003og>9fP04o`000?m`QmWoL8OIo`0000?oKHCI0_mZP]P00ol0003oKH;G
o`000004ofQneP;oHg_E00Go0000ofAidomTNM?oI7WCo`000002oeeddP03o`000?mMLLoo000000Co
DV_>00Co0000oe1UbOm@ILWo00000_m1GLP00ol0003o=e;2ocMB`P02ocMB`P07o`000?l[A;So:dBh
ob]4^?l0003o3CFeo`000002o`0HXP09o`000?l008Co0024o`00Q?l0003o001Go`000?ngM03o0000
05;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02_ooool01_l@413oV9RHooooooooooooMgMgofIVIQ7ooooo000W
ooooo`?o00003_ooool00ol0003oX]7ho`000004oj;An003o`000?n:_OOoR[gg00CoR[gg00?o0000
ogncm_mo/oH00omo/oH00ol0003oNZkdogZ^m003o`000003ogf/l_l0003oNJWa00CoNJWa00?o0000
ogJVlOl000000_l000000omhYo3o0000ogFSk`03ogFSk`?o00001?meXNd3o`0000CoM9g[00Go0000
ogJNj_mfW^[oMYkZo`000005ogFJj004o`000?mfV^OoMY[Wo`0000?oM9OU00Co0000ogJGiOmfUnGo
00000omgU^@01_l0003oM9?RogBCh_l0003oMI;Ro`0000;oMI;Q00Co0000ogJAh?mfTN3o00000_mf
TN001?l0003oMY3OogJ@gol00002ogF?gP03o`000?mdS]ko000000?oLhgM00?o0000og:;g?mbRm`0
0omaRM`2o`000003og>9f_l0003oL8OI00;oL8OI00Co0000off4fOm]Q=Wo00000_mZP]P00om]P]Oo
0000ofQneP03ofQneP06o`000?mSNmGoHg_Eo`000?mTNM?o00001?mMM=800omMLLoo0000oe9[cP04
oe9[cP03o`000?m@ILWo000000?o@Eg800?o0000ocMB`_lgD/800_lgD/800ol0003o:dBho`000002
o`de]@05o`000?l06:;o01RRo`0HX_l000000_l008@01Ol0003o001Go`000?ngM03o0000057ooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?l0003oIVIV01;ooooo000Wooooo`03o`00
0?oooooooooo00kooooo00?o0000oj;An?l000000_nRdOP8o`000003ohZmmol0003oOk?f00CoOk?f
00?o0000ogZ^m?mj[_@00omj[_@2o`000003ogVYlOl0003oNJWa00;oNJWa00?o0000ogJVlOmfY_40
0_mfY_43o`0000GoMJ?_00?o0000ogFQkOmeXNd01?meXNd00ol0003oM9g[ogBMj`03ogBMj`;o0000
00CoMYkZo`000?mcV^Wo00001?meV^P01?l0003oMY[Wo`000?mcUnH4ogBGi@07o`000?mfUnGo0000
ogNFi?l0003oLi?So`000002ogBChP03o`000?meT^;o000000;oMI;Q00Co0000ogJAh?mfTN3o0000
0_mfTN001_l0003oMY3OogJ@gol0003oMHoNo`0000;oM8kN00Oo0000og>=gOmcSMgoLhgMo`000?mb
Rmco000000;oLHWL0om_R=/2o`0000;oL8OI00Co0000off4fOm]Q=Wo00000omZP]P2o`0000?oJ7kF
00Ko0000of=keOmSNmGoHg_EofAidol00005oeeddP;o00001OmBJlh00ol0003o@Eg8od5Mb003od5M
b003o`000?lgD/;o=e;200;o=e;200?o0000o`de]Ol==KD00_l==KD01?l0003o01RRo`0HX_l00002
o`00Q005o`000?l005Oo0000okMd0?l00000D?ooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo00;ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooooooo01Co
oooo000Wooooo`03o`000?oooooooooo00oooooo1?l000001?ln`=oo0000ock0gol00004ofnooPKo
00000_mo/oH00ol0003oNZkdogZ^m003ogZ^m003o`000?mfZO?oMZWc00?o000000?oNJWao`000?mf
Y_401?mfY_400ol0003oMJ?_ogFSk`03ogFSk`03o`000?mbX>go000000;o00000_meXNd01?l0003o
LYg[o`000?l00004ogBMj`03o`000?mcV^WoLi[Y00;oLi[Y00Go0000ogFJj?meV^SoMI[Xo`000003
og>GiP07o`000?mdUnGoM9OUogBGiOl0003oMYOUo`000003og>Ch`06o`000?mdTn;oM9?Ro`000?me
T^;o00000_meT^400ol0003oMY7Po`000003ogJAh003o`000?mfT=oo000000;oMHoN00Co0000ogB>
g_mdS]ko00000_mcSMd01?l0003oLX_Log:;g?l00002og69g0;oKhSK0_m]Q]/00ol0003oL8OIo`00
0003off4f@03o`000?mZP]SoJX;H00;oIWoH0_l000000omXO]Ko0000of=ke@03of=ke@;o00001?mM
M=82oeE`d@03o`000?mBJlkoDV_>00;oDV_>00?o0000od5Mb?m1GLP01?m1GLP01Ol0003o=e;2ocMB
`_lgD/;o000000Co3CFe00Go0000o`0HX_l06:;o01RRo`000002o`00Q004o`000?l005Oo0000o`00
04oooooo00?o0000ooooooooool0A?ooool3o`0000Cooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<
c<`<ooooo`03o`000?oooooooooo01Cooooo000Wooooo`03o`000?oooooooooo013ooooo00Go0000
oooooooooooo0000oc>NlP03o`0000GoKkon00Co0000ogBcnOmd/oWoM;?i0ol000001?mj[_Co0000
o`000?l00002ogZ^m003o`000?mfZO?oMZWc00;oMZWc0_l00005ogJVl@03o`000?mbXnooLZ?_00?o
000000?oMJ?_o`000?mbX>d00_mbX>d3o`0000?oLYg[00Oo0000ogBMjomdWN_oM9g[o`000?maV^Wo
000000?oLi[Y0_l000000omeV^So0000og:Gi`03og>GiP05o`000?mdUnGoM9OUogBGiOl000000_mb
Tn@3og>Ch`06o`000?mdTn;oM9?Ro`000?meT^;o00000_meT^400ol0003oMY7Po`000002ogJAh0Wo
00000_mcSMd01?l0003oLX_Log:;g?l00002og69g003o`000?m_R=_o000000?oKHKK0_l00002off4
f@04o`000?mZP]SoJX;Ho`0000?oIWoH00?oJ7kFo`000?mSNmD00omSNmD2oeege005o`000?mMM=;o
GGCBoeedd_l000000_mEL=401?l0003oDV_>oe9[c_mBJlh2o`0000Ko@Eg80_lgD/800ol0003o94W1
o`000004o`de]@04o`000?l06:;o01RRo`0000;o002400Go0000o`00Eol0003o]g@0o`00001=oooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool00oooool01?nj^[[o410@oa0@4?o<c<`=
ooooo`Go00004_ooool002Kooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo
000000?o<ikb1Ol000000om__oko0000ogBcn@03ogBcn@03o`000?md[OGoM:ge00;oM:ge0ol00005
ogJYl`03o`000?mbY_7oLZKa00Co00001OmbXnl2o`0000GoLZ3]00?o0000og:MjombWN/00_mbWN/3
o`0000CoLI[Y00Go0000og>JjOmcV^WoLi[Yo`000003og:Gi`;o000000CoLiOVo`000?mdUnGo0000
0_maTn@2og:Ci004o`000?mcTn?oLi?So`0000;oM9?R00Co0000ogFBh_l0003oMI;Q1Ol000001?mb
S]oo0000og6>gol00002og6=gP?oL8cN1_l00002og69g004o`000?m_R=_oKhSKo`0000;oKHKK0_mZ
Q=X00ol0003oKHCIo`000002ofZ2f003o`000?mVOmSoIWoH00;oIWoH0_l00003of=ke@06o`000?mM
MmCoGGODo`000?mMM=;o00001?mEL=400ol0003oDV_>o`000002odQVcP03o`000?m1GLSo@Eg800Co
@Eg800Go0000obA9`OlTBL7o94W1o`000004o`de]@03o`000?l06:;o000000?o00240_l000000ong
M03o0000ooooo`1<ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0:oooool002Ko
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`04o`000?lcW_;o<ikbo`00
00CoI:gi1Ol00002ogBcn@03o`000?md[OGoM:ge00?oM:ge00?o0000og:YlombZO<00ol000000omf
ZO?o0000og:Vl@03og:Vl@03o`000?mbXnooLZ?_00CoLZ?_00?o0000og2Ok_l000000_l000000omb
X>go0000og2Lk003o`0000;oLYg[00?o0000og6JjOmaV^T00omaV^T2o`000004og>JjOl0003oL9OW
o`0000?oLYOW00?o0000og>Gi_l000001?maTn@01ol0003oLY?Tog:Ci?l0003oLi?So`000?mdTn80
1?l000001?maSn7o0000og:?h?l00003og:>g`03o`000?maS]oo000000;oLHgN0_m`S=h3og2;g@?o
KXWM0_l000001?maRMco0000ofn8fol00002off6f`04o`000?mZQ=[oJXCJofZ4fP;o00000_mZP]P0
1?l0003oIWoHofIof?mVOmP2of9me`03o`000?mSNmGo000000CoGGOD00?oGGCBo`000?mEL=401?mE
L=400omBJlko0000odQVcP02odQVcP03o`000?m1GLSo@Eg800?o@Eg800Go0000obA9`OlTBL7o94W1
o`000004o`de]@04o`000?l06:;o01RRo`0000;o00240_l000000ongM03o0000ooooo`1;ooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool0:_ooool002Kooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`02ooooo`03o`000?mZS>7o000000;o00001OmT[OT00ol0003oKjgg
ofn]m`03o`0000KoM:ge00?o0000og:YlombZO<00_mbZO<2o`0000CoLZKa00?o0000ofnRl?m_X_00
0ol000000ombXnoo0000og2OkP03og2OkP?o00000om`W>`3o`000004ofnIj_l0003o0000o`0000?o
LI[Y00?o0000og2Giom`UnL00_m`UnL01?l0003oLYOWog:Giol00002og2Ci@CoLI?T00Ko0000og:C
i?mbTnCo0000og>Chol00002og2@hP07o`000?maT>7o0000og6?hOl0003oLXoPo`000002og:>g`06
o`000?maS]ooLHkOo`000?maSMko00000_m`S=h3og2;g@;oKXWM0om]R=`00ol0003oKhSKo`000002
off6f`04o`000?mZQ=[oJXCJofZ4fP;oIh;J00?o0000ofZ2f?l000000omVOmP01Ol0003oHWgGof9m
eomSNmGo000000GoGGOD00?o0000oeE`dOmEL=401?mEL=400ol0003oB6K>odQVcP02odQVcP07o`00
0?m1GLSo@Eg8od5Mb?l0003o=5S8o`000003obA9`@03o`000?l==KGo3CFe00;o3CFe00?o0000o`0H
X_l000000ol008@3o`0004_ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Zoooo
o`009_ooool2o`0001;ooooo00?o0000ooooooooool00oooool00ol0003oJXcQofZ<h@02o`0000Go
I:gi00?o0000ofn]mom_[OL00_m_[OL5o`000003ogB]mOl0003oLZWc00CoLZWc00?o0000ofnUl_m_
YO801?l00004ofnRl0;o00001_m`Wnh00ol0003oL9c/og2Lk003og2Lk003o`000?m_VN[oKiWZ00;o
KiWZ0_l000001?maV^Wo0000ofjFj?l00003og2Gi`?o000000?oKi?Uog2CiOm`TnD00_l00002og6C
i004o`000?mbTnCo0000o`0000CoL93R00Oo0000og6@hOl0003oLHoQo`000?mbSn3o000000;oLXkO
00So0000og6>gomaS]oo0000og6=g_l0003oL8cNo`0000;oL8_M00?o0000ofj9gOm^RMd00_m]R=`2
ofb7g005ofn8fol0003oKHKKoff6fol000000_mZQ=X01?l0003oIh;JofN2f_mWP]X2o`0000;oIWoH
00Co0000of9meomROMOoHWgG0_l00004oeege003oeQde?l0003oEG3A00CoEG3A00?o0000odQVc_m8
I/h00om8I/h00ol0003o@Eg8o`000003ocAHb005o`000?lTBL7o94W1obA9`Ol000000ol==KD01?l0
003o01RRo`0HX_l00002o`00Q0;o000000?o]g@0o`000?ooool0B?ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo02[ooooo000Uooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool00oooool00ol0003oJXcQofZ<h@02ofZ<h@Co000000?oI:gio`000?m_[OL00om_[OL00ol0
003oKj_eofn[m@02ofn[m@Go00000_mbZO<00ol0003oKjGbofnUlP03ofnUlP03o`000?m_X_3oKj;`
00?oKj;`00?o0000offNk_l000000_l00002og2OkP04o`000?m]W>co0000o`0000;oL9c/00?o0000
offIj_l000000_l00002ofnIjP03o`000?m^U^SoKYKX00;oKYKX00Go0000og2Giom`UnOoL9OWo`00
0002ofnCi@04o`000?m`TnGoL9?Uo`0000;oLI?T00Co0000ofn@hom_T>?o00001?m`T>801ol0003o
LI3Qo`000?maSn7o0000og:?h?l000000_mbS]l00ol0003oLHkOo`000002og6=gP;oL8cN00So0000
og2;gOm`Rmgo0000ofj9gOl0003oKHSLo`0000;oK8OL0_l000001Om]Q]_o0000ofZ4f_mZQ=[o0000
00?oIh;J0_mTP=T00ol0003oIWoHo`000003of9me`;oGW[G00Oo0000oeege?mMMmCoGGODo`000?mH
M=Co000000?oEG3A00?o0000odi]dOl000001Om8I/h00ol0003o=5S8ocAHb002ocAHb003o`000?lT
BL7o94W100;o94W100Co0000o`de]Ol==KGo3CFe0_l06:800ol0003o0024o`00Q002o`000003okMd
0?l0003ooooo04Sooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Zooooo`009Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00Go0000ofZ<hOmZS>7oJXcQ
o`000003og6Rk`Ko000000?oKjggo`000?m_ZoD01?m_ZoD00ol0003oKZOdofjWm004o`0000CoKjGb
00?o0000ofbQl?m/XO000ol000000om_X_3o0000offNkP02offNkP?o00000om]W>`3o`0000CoKIWZ
0ol000000om]U^So0000ofjFj002ofjFj0;o000000?oL9OWo`000?m]TnH00om_TnD01_l0003oL9?U
o`000?maTnCo0000ofj@h`;oKi3S00ko0000og2@h_m`T>;o0000og2@h_l0003oLI3Qo`000?maSn7o
0000og:?h?l0003oLXkOo`0000;oLHkO00Go0000og6=g_l0003oL8cNo`000002og2;g@03o`000?m^
RMgoKXWM00;oKHSL00?o0000ofb7g?mZQ]`00_mZQ]`2o`0000;oJXCJ00Co0000ofN2f_mWP][o0000
0_mTP=T00omVOmSo0000of9me`02of9me`06o`000?mNN]OoGW[Go`000?mMMmCo00000omHM=@01?l0
003oEG3AoeE`dOl00002odi]d@03o`000?m8I/koB6K>00;oB6K>00?o0000ocAHb?ldF<P00oldF<P0
1Ol0003o94W1obA9`OlTBL7o000000?o3CFe00?o0000o`0HX_l06:800ol008@3o`0004Sooooo00?o
0000ooooooooool0B_ooool3o`0002cooooo000Uooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01Oooool00ol0003oJXcQofZ<h@02ofZ<h@03o`000?maX^ooLJ;_00;oLJ;_00Co0000
og2Xm?m`Z?CoL:Sd1Ol00003ofn[m@03o`000?m^YoCoKZOd00;oKZOd1Ol000000om_YO;o0000ofbQ
l003ofbQl0;o00001Om]W^h00ol0003oKIc/offLk003offLk003o`000?m]VN[oKIWZ00CoKIWZ00Co
0000offFj?m]U^SoKIKX0_l00002ofjFj005o`000?m]TnKoKI?VoffCi_l000000_m_TnD00ol0003o
L9?Uo`000003ofj@h`;oKi3S00Wo0000og2@h_m`T>;o0000og2@h_l0003oLI3Qo`000?maSn402ol0
0002og2;g@06o`000?m^RMgoKXWMo`000?m]R=co00000_m/Qm`2ofZ6g0;oJ8CK00?o0000ofZ4f_l0
00000_mWP]X01?l0003oI83IofB0fOmTP=T2o`0000;oHWgG00Ko0000oeijeomNN]OoGW[Goeege?l0
0004oeQde0;oEG3A00Go0000odi]dOm>KM7oCVgAo`000002odQVcP03o`000?loHlko000000Go=5S8
00Go0000obA9`OlTBL7o94W1o`000002o`de]@Co00000_l008@3o`0004Oooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`0Zooooo`009Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Gooooo00?o0000ofZ<hOmZS>400omZS>400ol0003oLJ;_og6Rk`02og6Rk`03o`00
0?m`Z?CoL:Sd00;oL:Sd00?o0000offXm?m]Z?@01?l00004ofjWm003o`000?m[Xo;oJj?b00;oJj?b
0ol00004ofbQl003o`000?mYWNooJIg_00Co00000_mZVnd4o`000004of^Hjol0003o0000o`0000;o
KIWZ00?o0000of^Ej?l000000om]U^P3o`000005ofbCi_m]TnKoKI?VoffCi_l000000_m_TnD00ol0
003oKI3Soff@h`03ofj@h`03o`000?m_T>?o000000;oL93R00?o0000og2@h_l000000ol000001?m^
S=oo0000ofj<gol00002ofj;g`;oKH_N0_m]R]h6o`000007off8g?l0003oK8OLofb7g?l0003oJXKL
o`000003ofR4f`;o000000?oIh;Jo`000?mTP=T00_mTP=T2of9nf@03o`000?mROMOo000000CoGW[G
00?o0000oeQde?mHM=@00omHM=@2o`0000CoCVgA0_m8I/h01?l0003o?f?>ocmSc_l00004ocAHb004
o`000?lTBL7o94W1obA9`@?o000000Co032fo`000?l03Iko00fN0_l000001?l008Co0000okMd0?l0
0015ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0:_ooool002Cooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`06ooooo`[o000000?oLJ;_o`000?m`Z?@00om`Z?@0
0ol0003oKJSdoffXm002offXm0Go000000?oKZOdo`000?m[Xo801?m[Xo800ol0003oJ9oaofROl@04
o`0000CoJIg_0_l00004ofZKk@;o00000om[V>/3o`0000?oJiGX00Go0000offFj?m]U^SoKIKXo`00
0003ofbCiP06o`000?m]TnKo0000ofnCiOl0003oK93T0_m]T><01ol0003oKY3Sofj@hol0003oKi3S
o`000?m`T>800ol000002?m^SN3o0000ofj=h?l0003oKXcOo`000?m^S=oo00000_m^Rml2off;gP04
off:g_m/RMkoK8WNofb9gP?oJhSM00Go0000off8g?l0003oK8OLo`000002ofZ6g003o`000?mXQ=_o
J8CK00;oIX?K00?oIh;Jo`000?mTP=T00_mTP=T01Ol0003oHWkIof9nfOmROMOo000000CoGW[G00?o
FWSGo`000?mHM=@00omHM=@2oe9be003o`000?m>KM7oCVgA00;oCVgA00?o0000ocmSc_loHlh00_lo
Hlh00ol0003o=5S8ocAHb002ocAHb005o`000?lTBL7o0000oaE6`ol000000ol0<;H01?l0003o00fN
o`000?l00744o`0004Gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Zooooo`00
9?ooool3o`0001;ooooo00?o0000ooooooooool01_ooool00ol0003oRioRoh^OhP03oh^OhP04o`00
0?mlZ_3oO:[`ogbZl0Ko000000?oL:Sdo`000?m]Z?@00om]Z?@01?l0003oJJGdofVUm?mYYO@5o`00
00;oJj?b00?o0000ofROlOmXWo400omXWo400ol0003oJIg_ofVMk`03ofVMk`03o`000?mWV^go0000
00;o000000?oJY_]o`000?mXUn/00_l00002of^Hj`03o`000?m[UNSoJiGX00;oJiGX0_l000001?m]
U^So0000ofZBi_l00002ofbCiP?o00000om/T>@02?l0003oKI3Soff@hol0003oKY3So`000?m_T>?o
00000_m]SN42o`00000=ofj=h?l0003oKXgPo`000?m^S=oo0000ofj<gol0003oKX_Oo`000?m]Rmko
0000off:gP03ofb9gP;oJhSM0_mZQmd2o`000004ofb7g?l0003oJXKLo`0000;oJ8CK00?o0000ofJ3
fomVPm/00_l000000omTP=Wo0000of9nf@03of9nf@05o`000?mNN]OoGW[Goeijeol000000_mJN=L0
1?l0003oF7CDoeQde?l00003oe9be005o`000?m>KM7oCVgAodi]dOl000001OloHlh01?l0003o=5S8
ocAHb?ldF<P2o`0000?o5DK300So0000o`0`]_l0<;Ko032fo`000?l03Iko0000o`00L@?o0000A?oo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Wooooo000Tooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01oooool00ol0003oRioRoh^OhP03oh^OhP03o`000?mlZ_3o
O:[`00;oO:[`00Co0000og6[mOmaZoGoLJ_e1_l000000om]Z?Co0000ofVUm003ofVUm003o`000?mV
X_;oIZ;b00Co00001?mXWo400ol0003oIYc_ofJLk`03o`000003ofVMkol0003oIi[]00;oIi[]0ol0
0003ofRGj`;o000000CoJ9CYo`000?l0003o00000_m[UNP00ol0003oJY;VofZBiP02ofZBiP05o`00
0?m/TnKoK9?Vo`000?m[T>@01?m/T>@01Ol0003oKI3So`000?m^T>?o000000;oK8kR0_m]SN42o`00
000=ofj=h?l0003oKXgPo`000?m^S=oo0000ofj<gol0003oKX_Oo`000?m]Rmko0000off:gP02ofb9
gP04o`000?m[R=go0000ofZ7g@?oJHKM00?o0000ofZ6g?l000000_mXQ=/00ol0003oIX?KofJ3f`02
ofB1f`03ofB0fOl0003oHWkI00?oHWkI00GoGWgIo`000?mNN]OoGW[Go`000003oeYhe`03o`000?mH
M=Co000000CoDW;D00Go0000odi]dOl0003oB6_Bo`000005ocmScP05o`000?ldF<So0000obUFb_l0
00001?lEA/<01Ol0003o032fo`0`]_l0003o00fN00;o000000?o001ao`000?l00000@oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo02Wooooo000Tooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01oooool00ol0003oRioRoh^OhP04oh^OhP03o`000?mlZ_3oO:[`00;o
O:[`00?o0000og6[mOmaZoD00_maZoD01?l0003oJJSeofVXmOmYZ?D6o`000003ofVUm?l0003oIZ;b
00?oIZ;b1Ol000000omXWo7o0000ofJLk`03ofJLk`;o00001OmWV^d00ol0003oJ9O[ofRGj`03ofRG
j`04o`000?mXU>WoJ9CYofRDj@?o000000?oJ9;Wo`000?mZT^H00_mZT^H3o`000004ofV@iOm[T>Co
Ji3To`0000;oK93T00?o0000off@hol000000_m[S^82ofb>hP;oKHgQ0_l000000om^SN3o0000ofj=
h002o`000006ofj<gol0003oKX_Oofj;gol0003oKH_N0_l00002ofb9gP;oJhSM00CoJXOMo`000?mY
Q]goJHKM0_mWQM`01?mZQ]co0000ofR4fomXQ=/2ofJ3f`03o`000?mTPM_oI87K00;o00000omRO]T2
oeimf@03o`000?mNN]Oo000000CoFWSG00?o0000oe9be?mBL]@01?mBL]@01Ol0003oB6_BodQ[d_m8
Jm;o000000Go?f?>00Go0000obUFb_lYE/[o:EK:o`000003oaE6``0;o`000?l0<;Ko032fo`0`]_l0
003o00fNo`000?l0077o0000okMd0?l00000@Oooool00ol0003oooooooooo`1@ooooo`?o0000:ooo
ool002Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`03o`000?n;Wn;o
RioR00?oRioR00?o0000ogbZl?mlZ_000omlZ_000ol0003oLJ_eog6[m@02og6[m@03o`000?mYZ?Go
JJSe00;oJJSe00Co0000ofFTm?mUY?CoIJCd0ol000001?mVX_;o0000ofJRl_l00004ofBNl@?o0000
1?mVW>l00ol0003oI9S]o`000002o`000003ofNJkOl0003oIIK[00;o00000_mXUn/01?l0003oIYCY
o`000?l00002ofRDj@05o`000?mXT^OoJ9;WofRBiol000000omZT^H00ol0003oJI3UofV@i@04o`00
0004ofb@i?l0003oJXkRofZ>hP;oJhkR0_m/S^801ol0003oKHgQo`000?l0003oKXgPo`000?m^SN00
0_l000004?m^S=oo0000ofj;gol0003oKH_No`000?m]R]ko0000ofb9g_l0003oJhSMo`000?mZQmgo
0000ofV6gOl00002ofN5g0;o000000CoJ8CKo`000?mVPm_o00000_mTPM/2of60fP03o`000?mRO]Wo
000000?oGWgI0_l00004oeYhe`03oeIgeol0003oDW;D00CoDW;D00?o0000odQ[d_m8Jm800_m8Jm80
1?l0003o?f?>ocmSc_loHlh2o`0000Co:EK:00Go0000oaE6`olEA/?o5DK3o`000003o`0`]P06o`00
0?l03Iko0000o`00LOngM03o0000@Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
02Wooooo000Sooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool01?l0003o
RioRoh^Oh_n;Wn8=o`000003og6[mOl0003oJJSe00?oJJSe00?o0000ofFTm?mUY?@00_mUY?@00ol0
003oHZ3bof:PlP03o`0000GoI9ka00?o0000of:JkomRV^l01?l00003ofBHk@?o00000_mUU^/3o`00
00CoIYCY0_l000001?mWTNOo0000ofRBiomXT^L2o`000003ofZBi_l0003oJ8oU00?oJI3U00?o0000
of^@i?l000000_mYSN<2ofZ>hP;oJhkR00Co0000ofb>h_l0003oKHgQ0_l000000om^SN3o0000o`00
000;o`000004of^8gOl0003oJXOMo`0000;oJHKM0_mWQM`3ofJ4g003o`000?mVPm_o000000;oI87K
00Go0000of60f_mQP=[oHWkIo`000003oeimf@;oG7_I00Co0000oeYheomJN=Oo00000_mFMmL01ol0
003oDW;Doe9be?mBL]Co0000odiaeOl000001?m8Jm800ol0003o?f?>o`000002ocQQd003o`000?lY
E/[o:EK:00;o:EK:00Go0000oaE6`olEA/?o5DK3o`000002o`0`]P04o`000?l03Iko0000o`00L@;o
0000@?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02Wooooo000Sooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02Oooool3o`0000GoV=Cm00?o0000ogVlo?mi_?`0
0_mi_?`00ol0003oJZoiofZ_n@06o`000003ofVXmOl0003oIJCd00?oIJCd00?o0000of:Pl_mRX?80
0_mRX?85o`000003ofBNlOl0003oHY[_00?oHY[_00?o0000ofBHkOmTV>d00omTV>d00ol0003oIIK[
ofFFj`02ofFFj`03o`000?mVU>WoIYCY00CoIYCY00Co0000ofNAiomWTNOo00000_mXT^L00ol0003o
J8oUofR?i@02ofR?i@05o`000?mYT>Go0000o`000?mXSN<00_mYSN<02?l0003oJXkRofZ>h_m[S^;o
0000ofb>h_l0003oKHgQ0ol000000om[Rmoo0000of^:g`02o`000003of^9gomZRMkoJXWN00;oJXSN
0_mYR=h01?l0003oJhSMo`000?l00002ofV6g@03o`000?mWQMco000000;oIXCL00?oI8?LofJ3fol0
00000_mTPM/01?l0003oHH3Jof60f_mQP=X2o`0000;oGWgI00Ko0000oeakfOmLNmWo0000oeYheol0
0003oeIge`03o`000?mBL]Co000000?oCW7E00Co0000odQ[d_m8Jm;oB6_B0_l00004ocQQd005o`00
0?lYE/[o:EK:obUFb_l000001?lEA/<01Ol0003o032fo`0`]_l0003o00fN00?o0000?oooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo02Wooooo000Sooooo`?o00004oooool00ol0003o
ooooooooo`0;ooooo`03o`000?nHe?goV=Cm00CoV=Cm00?o0000ogVlo?mi_?`00_mi_?`00ol0003o
JZoiofZ_n@02ofZ_n@03o`000?mSZ?OoHjSg00Ko000000?oIJCdo`000?mRX?800omRX?801?l0003o
GicaoenLlOmOW?43o`000004of:Jkol0003oHY[_o`0000;oH9O]1?l00002of:Ej`?o000000CoI9?Y
o`000?l0003o00000_mVU>T01?l0003oII7Wo`000?mWTNL3o`000003ofJ?iOl0003oJ8oU00;oJ8oU
0ol00002ofR=h`05o`000?mYSN?oJHgSo`000?mZS^800_l000000om/S^;o0000ofZ;h003o`000003
of^;gol0003oJh[O00;o000000?oJhWOofZ9g_mZRMh00_mZR=h02_mYR=koJ8ONofR7g_l0003oJXOM
o`000?mYQ]go0000ofN5g?l00002ofJ4g006o`000?mTPmco0000o`000?mTPM_o00000omQP=X2oemo
fP;o00001?mLNmT00ol0003oEWOGoeIge`03oeIge`;o00001?m>LMD01Ol0003oB6_Bo`000?m3J]?o
000000Go>67@00Go0000obUFb_lYE/[o:EK:o`000003oaE6``08o`000?l0<;Ko032fo`0`]_l03Iko
0000o`00LOl0000nooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:Oooool001Ko
oooo1?l000000ol@413oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool03?ooool01?l0003oV=CmoiSDoOnHe?d7o`000003ogVlo?l0003oJZoi00?oJZoi00?o0000of>X
momSZ?L00_mSZ?L00ol0003oGZ;doejRm006o`000003of:Pl_l0003oGica00?oGica00?o0000oefH
komMV>l00ol00004of2Gk@;o00001?mRUN/01?l0003oI9?YofBCjOmTTnT3o`0000?oII7W00?o0000
ofNAiol000000omVSnD01_l0003oJ8oUofR?iOmXSnGo0000ofN=h`?oJ8gS00Co0000ofV=hol0003o
JXkR0_l000000omYRn7o0000ofZ;h003o`000003of^;gol0003oJh[O00;o000000OoJhWOofZ9g_l0
003oJXSNo`000?mYR=koJ8ON00;oIhOM0_l000001omYQ]go0000ofN5g?l0003oIXCLo`000?mTPm`0
0_mSP]`00omTPM_o0000of60fP02of60fP?oGgoJ0_l00003oeakf@03oeUjfOl0003oEWOG00?oEWOG
0_mCM]L00ol0003oCW7Eodiae@02odiae@05o`000?m3J]?o@f[Cod=Zdol000001OlhHM001Ol0003o
:EK:obUFb_lYE/[o000000?o5DK30ol0<;H01Ol0003o00fNo`000?ngM03o000003gooooo00?o0000
ooooooooool0EOooool00ol0003oooooooooo`0Yooooo`006?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool7o`000003ocVmfOl0003oEkWl
00_o000000?oHjSgo`000?mNX_@00omNX_@00ol0003oG9gboebMlP05o`0000;oGica00?o0000oefH
komMV>l00_mMV>l00ol0003oH9O]of2Gk@02of2Gk@07o`000?mOTn_o0000o`000?mRUN_o0000of6A
j@02o`0000;oI9?Y00?o0000ofFAiomUTNL00_mUTNL2o`000004ofF>iOl0003oIXoUofJ?i@;o0000
00CoJ8oUo`000?mVSN?oIhgS0_l000002_mXSN?o0000ofV=hol0003oJ8_Qo`000?mXRn7oJH_Qo`00
0?mZRn03o`000003of^;gol0003oJh[O00?o000000OoJXWNo`000?mZR=koJHSNo`000?mXQmkoIhOM
00?oIXKM00Oo0000ofN5g?l0003oIXCLo`000?mTPmco000000;oHh;L0_l000000omQP=[o0000oemo
fP02oemofP;oGGkJ00?o0000oeakfOmLNmT00_mIN]T01?l0003oEWOGoeIgeol00003oe=fe`06o`00
0?m>LMGoCW7EodiaeOm;L=Ko00000om3J]<00ol0003o>67@ocQQd003ocQQd003o`000?lYE/[o:EK:
00So000000Co00fNo`000?ngM03o0000??ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo02Sooooo000Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Eooooo`?o00000omG^O`00ol0003oFZcjoeZ/nP03oeZ/nP03o`000?mIYOOo0000
00Go000000?oGZ;do`000?mLWO800_mLWO800ol0003oFYW`oeZIl003o`0000CoGIS_00?o0000oebD
kOmLU>d01?l00002oenCj`?o00000omQTNT2o`000004of>@iol0003o0000o`0000;oII7W00Co0000
ofF>iOmUS^Go00000_mVSnD02Ol0003oIXgSofJ=homVSN?o0000ofN=hol0003oJ8gSo`000002ofN;
h@06ofR;hOl0003oJ8_QofV;hOl0003oJX_P0ol000000om[Rmoo0000of^:g`03o`000004ofZ9g_l0
003oJXSNofV8gP;o000000?oIhOMofJ6gOmVQ]d00_mVQMd00ol0003oIXCLo`000002ofB3g0;oHh;L
0_mQPM`00omQP=[o0000oemofP02oemofP?oGGkJ00?oG7_Io`000?mIN]T00_mIN]T00ol0003oEWOG
o`000004oe=fe`03o`000?m>LMGo000000;oBg3F00Go0000od=Zdom3J]?o@f[Co`000004ocQQd0?o
000000?o8eS>o`000?l<BLL00_l<BLL00ol0003o03Fko`0e^`05o`0003[ooooo00?o0000oooooooo
ool0E_ooool3o`0002[ooooo000<ooooo`Oo00001Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05oooool6o`0000GoFZcj00Go0000oeVUmomIYOOo
FJGgo`000002oeNOm0Oo00001?mJVO04o`000003oefHkol0003oG9C]00?oG9C]00?o0000oenCjomO
Tn/00_mOTn/00ol0003oHI7Yof6Aj@03of6Aj@04o`000?mST>OoHi3Wof>@i`?o000000?oI8kUo`00
0?mUS^D00ol000000omUS>?oIXgSofJ=h`02ofJ=h`04ofN=hol0003o0000ofJ;hP;oIh_Q00?oJ8_Q
o`000?mXRn400_l000001OmZRn3o0000o`000?l0003oJh_O00Ko000000GoJXSNofV8g_l0003oJ8ON
o`000002ofJ6g@04o`000?mVQMgoIHCMofF4g@;o000000CoI8?Lo`000?mSP]co00000_mQPM`2o`00
0003oemof_l0003oGGkJ00?oGGkJ00?o0000oeUjfOmIN]T00_mIN]T2o`0000GoDgKG00?o0000od]`
e_m;L=H00_m;L=H01_l0003o@f[Cod=Zdom3J]?o0000ocQQd0;o000000?o<f;Bo`000?lSF<h00_lS
F<h01Ol0003o34W7o`a9aol<BLOo000000;o03Fk1?l0000iooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool0:?ooool001Sooooo00?o0000ooooooooool01oooool2o`0001Cooooo00?o
0000ooooooooool06?ooool@o`0000CoEiod00?o0000oeBJl_mDV_800_l000001?mJVO3o0000oeZI
l?l00003oeVFkP?o000000CoG9C]o`000?mLU>go00000_mLTN/4o`000003oen@jOl0003o000000;o
000000?oHHoWo`000?l000000_mST>L00ol0003oI8kUofB>i@02ofB>i@;o00000omUS><00ol0003o
IXgSofJ=h`02o`0000;oIX_R0_mWRn42o`000004ofR;hOl0003o0000ofZ;h0Co00000_mXR=l00omW
R=ooIhSNofN8gP03o`000008ofR7g_l0003oIhOMofJ6gOl0003oIXGMo`000?mUQ=d3of>4g@03o`00
0?mSP]co000000;oHH7L0_mPPM/2o`0000CoGGkJ00?oFggJo`000?mIN]T00_mIN]T2oeMif@04o`00
0?mCM]OoDgKGoe=fe`;o00001Om;L=H00ol0003o@f[Cod=Zd`02o`0000Co<f;B00Go0000ob=Hc_lS
F<ko8eS>o`000003o`a9a`03o`000?l0=K_o03Fk00Co0000=oooool00ol0003oooooooooo`1Joooo
o`03o`000?oooooooooo02Sooooo000Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool0
00004oooool00ol0003oooooooooo`0Hooooo`03o`000?llMn3o000000;o00000_loWoD2o`0000?o
CJ;f00?o0000odnOmOm?WoD01Ol000001OmGWoCo0000oeBJl_mDV_;o000000;oDiK`0ol00004oeVF
kP03o`000?mHT^coF9;/00?o00001?mLTN/2o`0000?oGi3Y0_l00003of6?i`;o000000CoHXgUo`00
0?l0003o00000_mTS^D2o`0000?oIHcS0ol000001OmURn;oIX_RofJ;h_l0003oIh_Q00;o000000Go
J8_Qo`000?l0003o0000ofN9g`03o`0000;oJ8SO00GoIhSOofN8g_mWQmkoIhONofJ7gP04o`000005
ofJ6gOl0003o0000ofF4gOl000000_mSQ=d00omRPmgoHh;Lo`000002of61g003o`000?mPPM_oH87K
00;o00000_mMO]X01_l0003oFggJoe]mf_l0003oFG[Io`0000?oEgWI00?o0000oe=feol000000_m@
MMP00ol0003oBg3Fod]`eP03od]`eP;o00000_loJ]D00ol0003o<f;Boc=RdP02oc=RdP05o`000?lS
F<ko8eS>ob=Hc_l000000ol<BLL00ol0003o03Fko`0e^`03o`0003Oooooo00?o0000ooooooooool0
F_ooool00ol0003oooooooooo`0Xooooo`006?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool06Oooool01?l0003o?7OPocagh?llMn05o`0000?oCJ;f
00Go0000odnOmOm?WoGoCioeo`000002odjJl`Co000000?oE9[bo`000?mCU_000omCU_04o`000003
oeVFk_l0003oF9;/00?oF9;/00?o0000oebAjomLTN/00_mLTN/01ol0003oG8oXo`000?l0003oGi3Y
o`000?mOS^L00_l00002of6?i`04o`000?mRSNGoHXgUof:=i@?o000000CoHh_TofB<i?l0003o0000
0_mUS><01ol0003oIH[RofF;h_l0003oIX_Ro`000?mWRn400_l00002ofJ9h0;o000000CoIhWOo`00
0?l0003o00000_mXR=l01?mWR=ooIhSNofN7g_mWQmh2ofJ6gP;oIHKN00?oIXKMo`000?mVQMd00_l0
0002of>4g@;oHX?M0_l000001?mQPMco0000of21fomPPM/2oej0f`03o`000?mMO][o000000?oFggJ
00?o0000oeMifOmGNMT00omGNMT00ol0003oD7GHoe1ef002oe1ef004o`000?m;L=KoBg3Fod]`eP;o
00001?loJ]D00ol0003o<f;Boc=RdP02oc=RdP04o`000?lSF<ko8eS>o`0000Co34W700Ko0000o`0e
^ol0=K_o0000olQQ0?l0000eooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0:?oo
ool001Kooooo00?o0000odA4A?l000002?ooool5o`0001;ooooo00?o0000ooooooooool06_ooool0
1Ol0003o?7OPocagh?llMn3o000000;oB9?`1_l00003odnOm@06o`000?m>V_?oCY[codjJlol0003o
CIKa0ol00004oe>Fl003o`000?mCT^koDi;^00?o000000CoF9;/o`000?mHT^co00000_mISnX4o`00
00;oG8oX0ol00002oen>i`?o000000?oHHcUo`000?l000000_mRSND01?l0003oHh_Tof>;i?mSRn@4
o`000008ofB:h_mUR^;o0000ofF;h_mVRn;o0000ofN;hOl00003ofJ9h0;o000000CoIhWOo`000?l0
003o00000_mXR=l01?mWR=ooIhSNofN7g_mVQmh2ofJ6gP;oIHKN00So0000ofJ5gOl0003oIHCMo`00
0?mSQ=go0000of:3g@;oHX;M00CoHH7Lo`000?mPPM_oH87K0omNP=/00ol0003oFggJoe]mfP02oe]m
fP03oeYmfol0003oEgWI00;oEgWI00?o0000oeEif_l000001?m@MMP00ol0003oBg3Fo`000002odQa
e`03o`000?loJ]Go?f[E00;o?f[E00Go0000oc=Rd_lcH];o<f;Bo`000003ob=HcP03o`000?l<BLOo
34W700;o34W700?o0000o`0e^ol000000_l0000dooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool0:?ooool001Kooooo00?oc<c<oeEEEOl000002?ooool00ol0003oooooooooo`02oooo
o`So00002_ooool00ol0003oooooooooo`0Kooooo`05o`000?llMn3o?7OPocagh?l000000om8To00
0ol0003oB9[codRJl`06o`0000?oCY[c00Co0000odfFlOm=U_7oCIKa1?l000000omCU_3o0000oe>B
kP02oe>BkP03o`000?mDSncoE8o/00?o00001?mISnX00ol0003oG8oXoeb?j002oeb?j003o`000?mO
S^OoGhkW00;oGhkW00Co0000of6<iOmQS>GoHHcU0ol000001?mRRnCo0000of>;i?mSRn@3o`0000;o
I8[R00?o0000ofF:h_mURn800_l00002ofF9h0?oIXWP0_l000000omWRMoo0000o`000005o`000003
ofN7g_l0003oIXKN00;oIHKN0_mTQMh01ol0003oIHCMo`000?mSQ=go0000of:3gOl000000_mRP]d3
o`0000?oGX3K00GoGGoLo`000?mKOM[oFggJo`000002oeYmf`03o`000?mGNMWo000000?oEGWJ00Co
0000oe1ef?m@MMSoD7GH0_l00004odQae`03o`000?loJ]Go?f[E00;o?f[E00Go0000oc=Rd_lcH];o
<f;Bo`000003ob=HcP03o`000?l<BLOo34W700;o34W700Co03Fko`000?l0003o0000<oooool00ol0
003oooooooooo`1Mooooo`03o`000?oooooooooo00Gooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool0
0omEEEGo0000oeEEE@06ooooo`03ob4Q8OnHV9Sooooo00Cooooo00KoV9RHoa0@4?l0003o0000odA4
A?o^k^h3ooooo`008Oooool00ol0003oooooooooo`0:ooooo`So00000_ooool00ol0003ooooooooo
o`0Looooo`05o`000?llMn3o?7OPocagh?l000000om8To000ol0003oB9[codRJl`02odRJl`03o`00
0?m6VO?o000000Go00000om=U_400ol0003oCI;_odfBk`04o`0000;oDi;^00?o0000oeB?k?mDSn`0
0_mDSn`01Ol0003oFHoZo`000?mISn[o000000;oFXgX0ol00002oef<iP?o000000?oGh_Uo`000?l0
00000_mQS>D01Ol0003oHX_Tof:;i?mRRnCo000000;oHh_T00?o0000of>9h_mTR^800_mTR^801?mU
R^;o0000o`000?mUR>42ofF9h003ofJ9h?l0003oIXWP00;o000000?oIhWOo`000?l000001?l00000
1?mWQmko0000o`000?mVQ]h2ofF6gP08ofB5g_mSQMkoHhGNo`000?mSQ=go0000of:3gOl00002of:2
g@;oHH;L00Co0000oej0fomNP=_o00000_mMOm`00ol0003oFggJo`000003oeYmf`03o`000?mENM[o
EGWJ00?oEGWJ00?o0000oe1ef?l000000_m?M]T00ol0003oB77GodQae`02odQae`04o`000?loJ]Go
?f[EocmZe@oo000000?ojhH]o`000?l00000<_ooool00ol0003oooooooooo`1Kooooo`Co00001Ooo
ool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00006ooooo`03oiRHV?m4A4Cooooo00Co
oooo00Ko410@ohN7QoooooooooooogMgMom4A4@3ooooo`008Oooool00ol0003oooooooooo`0Boooo
o`So00006_ooool9o`0000CoB9[c00Ko0000odJIlom6VO?oAYWco`000?m4UO46o`0000CoCI;_1?l0
0004oeB?k003o`000?mESNWoEHgY00?o00001?mJSNP00ol0003oGHcVoef<iP02oef<iP04o`000?mO
RnGoGh_Uoen;i@;o000000CoHH[To`000?mRRnCoHX_T0ol000001OmRRN;oHhWRof>9h_l0003oI8[R
00;o000000?oI8SQofF8hOl000000_mURN001Ol0003oIXWPo`000?l0003oIhWO00So000000KoIXKN
o`000?l0003o0000ofB5g_mSQMh2of>4g@?o00000_mRP]d2of62g004of22g?l0003oGX3Ko`0000?o
GGoL00Oo0000oeYmfomJOM_oFWgKo`000?mIO=_o000000CoEGWJ0_l00004odmff@03o`000?m8LMOo
B77G00;oB77G00Go0000ocmZeOl0003o?FcHo`000004oc1Ue@04o`000?lPG=;o85cBo`0000Co2U7=
00?o0000on^6;Ol000000_l0000`ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0
0oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED01_ooool00oo^
k^ko0000onk^kP09ooooo`03o`000?oooooooooo007ooooo000Qooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00oooool8o`0001;ooooo00?o0000og>KjOmcVnT00omcVnT00ol0003o
F:7eo`00000:o`0000?oA9Ga00?o0000odBAkol000001?l000001?m=T^oo0000odj?kOm>Snd4o`00
0003oeB?k?l0003oEHgY00?oEHgY00Go0000oeZ=j?l0003oFXgXo`000002oe^;iPKo00000_mORnD0
1ol0003oHH[Tof6:i?mQR^Co0000of:;i?l000000omRRN84o`0000;oI8SQ00Ko0000ofF8hOl0003o
IHWPo`000?mVRN02o`0000GoIHOO0_mUQ]h3o`000006ofF6g_l0003oI8GNof>5g_l0003oHhCM0_mR
Q=d3o`0000;oHH;L0_mPP]`2o`0000?oGGoL00CoG7oLo`000?mJOM_o00000omIO=/01_l0003oEGWJ
o`000?l0003oE7WKo`0000GoCgKI00?o0000odQaeom8LML00ol00003oce/f003o`000?l`IMGo<6GE
00;o<6GE00Co0000ob1Ld_lPG=;o00001?l:DLd00ol0003ojhH]o`000002o`0002kooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03Oooool00omEEEGoV9RHooooo`07ooooo`03onk^k_l0003ooooo00;ooooo000Qoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool8o`0000_ooooo00?o0000og>K
jOmcVnT00omcVnT01?l0003oF:7eoeRQmOmHXOD2o`0000?oA9_d00?o0000oc^ElOl000001Ol00003
odBAk`03o`000?m5S^go000000?o000000CoCXo]o`000?m@S>_oD8c[0ol000001?mESNWo0000oeF=
jOl00002oeN;i`?o00001?mKRnH2o`0000;oGH[U0_l000000omORN?o0000o`000002of6:i003o`00
0?mQRN;o000000;oHXWR0ol000002OmSR>7oI8SQofB8hOmTR>7oIHSQo`000?mURN3o0000ofB7g`02
o`0000GoIHOO0_mUQ]h3ofB6gP07ofF6g_l0003o0000of>5g_mSQ=go0000of:4g@02of:3g@03o`00
0?mQP]co000000;oH8;L0_mOPMd00ol0003oGGoLo`000002oeaog003o`000?mIO=_oFGcK00?oFGcK
00?o0000oeAifomDNM/00_mDNM/00ol0003oCgKIodmff@02odmff@?o00000om6L]T01Ol0003o?FcH
oce/f?lmK=So000000Co<6GE00Co0000ob1Ld_lPG=;o00000ol:DLd00ol0003ojhH]o`000003o`00
02cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03Oooool00onYZJWoA4A4ooooo`03ooooo`06oa0@4?nHV9Sooooo
oooooomgMgOoIVIV0oooool0023ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0C
ooooo`So00001?ooool00ol0003oLi_Yog>Kj@03og>Kj@03o`000?mHXOGoF:7e00;oF:7e00Go0000
odBKm?m4VoCoA9_do`000002oc^El@03o`000?lhSnoo>8o_00Ko00000_m5S^d00ol0003oB8_[o`00
0002o`0000?oD8c[00?o0000oe::j?mBR^P00ol00004oeN;i`03o`000?mKRnKoFh_V00;oFh_V00Ko
0000oeb9i?l0003o0000oef:iOl00003oen9h`;o000000SoHHSRo`000?mQRN;oHHWRo`000?mRRN;o
0000of:8h@;oHhSQ00Co0000ofB8hOl0003o00000omTQml2o`0000;oIHOO0ol00002ofF6gP03ofB6
g_l0003oI8GN00;o000000CoHhGNof>4gOl0003oHXCM0_mRPmd00omQPmgo0000o`000002of22g0?o
Gh7M00?o0000oeaog?mLOm`00_mLOm`01ol0003oFGcKoeUlfomIO=_o0000oeQmg?l000001?mDNM/0
1?l0003oCgKIo`000?l00002odegfP03o`000?m6L]WoAW;I00;oAW;I00Go0000oce/f?lmK=So?FcH
o`000004oc1Ue@04o`000?lPG=;o85cBo`0000;o2U7=00?o0000on^6;Oo[QRd01?l0000[ooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00kooooo00?o0000onk^k_ooool00_ooool01Ol0003o8B4Qo`000?l0003oIVIV
00Cooooo000Pooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07?ooool6o`0000Co
Li_Y2ol00002oc^El@05o`000?lhSnoo>8o_ocR?kol000000_ljRnd3o`000003odF>kOl0003oB8_[
00;oB8_[1Ol00004oe::j005o`000?mGRnOo0000oeN;iol000000_mIRND4o`0000;oG8WT0_l00002
oej9h`04o`000?mORN?oGhWSo`0000?oHHSR00Co0000of69h_l0003oHXOQ0_mRR>44o`000004of>7
gomTQmooI8OOofB7g`;o00000_mUQml4o`0000?oI8KN0omSQMh2o`000003of:4gOmRPmgoHX?M00;o
HH?M0ol00003oen1g@04oej1gOl0003oG7oLo`0000;oG7oL00?o0000oeUlfol000000omHOM`00ol0
003oE7WKoeAif`03o`0000GoCGOJ00?o0000odIbfOm6L]T00_m6L]T01Ol0003o?FcHoce/f?lmK=So
000000Co<6GE00Ko0000ob1Ld_lPG=;o0000o`YAcOl00003on^6;@03o`000?o2?`3o000002[ooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`03ooooo`06odA4A?nYZJWooooooooooonY
ZJWoA4A44?ooool00omEEEGoV9RHooooo`02ooooo`03o`000?oooooooooo00Kooooo000Pooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool08_ooool01?l0003oLi_Yo`000?l00004oh[O
o@?o000000?oB[?io`000?l000001Ol00003ocR?k`05o`000?ljRngo>X_]o`000?lmR>/00ol00003
odR;j`03o`000?m;RNWoBhWY00;o000000CoDX[Xo`000?mBR^So00000_mDRNH3o`0000CoFHWU00?o
0000oeb9i?mLRN@00_mLRN@00ol0003oGXWSoej9h`02oej9h`Co00000_mQR>801?l0003oHHOQof:7
hOmRQn44o`000004of>7h?mSQmooI8OOofB7g`Co00000omUQml2ofF6gP06ofB6g_l0003oI8GNof>5
g_l0003oHXGN1?l00004of63g@04o`000?mOPMgoGh7Mo`0000;oGX7M00Co0000oeaog?mLOmcoG7oL
0ol00003oeQmg0?o00000omCN]/00ol0003oCGOJodegfP03odegfP03o`000?m6L]WoAW;I00oo0000
00Co2U7=o`000?o[QRgojhH]0_l000000oo2?`3o0000o`00000Wooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool00oooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00Ko410@
ooooooooooooooooojVYZOm4A4@3ooooo`03o`000?oooooooooo00Kooooo000Pooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool08oooool4o`0000CoR]om1_l00002oc2Jl@Oo00000_lj
Rnd01?l0003o?HS[ocf8jolmR>/5o`0000?oBhWY00?o0000odj7iol000000_l00004oeB9iP03o`00
0?mIRNGo000000;o00000_mKR>@3o`0000;oGHSS1?l000000omOQn;o0000of28hP02o`0000?oHHOQ
1?l000001OmRQn3oHhOPof>7gol0003oI8OO00_o000000?oHhGNo`000?l000000_mRQ=h2o`0000Co
HH?M00?o0000oen1gOl000000_mNPMd01Ol0003oGX7Mo`000?mLOmco000000?oFgoL00Go0000oeQm
g?l0003oEggLo`000005oe=jf`04o`000?m=Mm[oCGOJodegfPCo00000_m5M=/00ol0003o?6oJoca_
fP02oca_fP05o`000?l`J]Wo<6[Ioc1ZfOl000000_lQHmL3o`0000?ojhH]00?o0000ol8o0?o2?`00
0_l0000Uooooo`03o`000?oooooooooo06?ooooo0_l00006ooooo`04okZj^_l@413o410@olc<c0go
oooo1_l00003ooooo`Go00001?ooool0023ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Wooooo`Co00001Oooool5o`0000;o:8g]1ol00003ocf8j`03o`000?m1Q^Wo@HKY00Ko0000
0om>QnL01_l0003oE8WVo`000?l0003oE8WVo`0000;oEhOU0_l00004oe^8i003o`000?mMR>?oGHSS
00;oGHSS00Co0000oen7h_mOQn;oGhOR0ol00002of67h@Co000000KoHXKPof:7h?l0003oHhOPo`00
0?mTQml8o`0000;oI8KN00Co0000of>5g_mSQMko00000_mRQ=h3o`000003of63gOl0003oH8?M00;o
000000?oGX7Mo`000?mNPMd00_mNPMd00ol0003oFgoLoe]og002oe]og0;o00000omGOM`00ol0003o
Dg[Koe=jf`02oe=jf`Co00000_m<N=`00ol0003oAGCKodEdf`02odEdf`03o`000?llKm[o?6oJ00;o
?6oJ00Go0000oc1ZfOl`J]Wo<6[Io`000003ob5Se`04o`000?o[QRgojhH]on^6;@;o00000_o2?`02
o`0002Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Vooooo`008?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo03?ooooo1ol00002obV7j`Oo00000om1Q^T00ol0
003oAXGXodJ5j002o`0000;oCXOW00Co0000oe:6i_mBQ^KoDXKV0ol00002oeN7i@03o`000?mJQn?o
FXOS00?o00000_mLQn83o`000003oen7h_l0003o000000;oGhOR00Co0000of67hOl0003oHHOQ0ol0
0002of:6h005o`000?mRQn3oHhOPo`000?mTQml01?l000001?mTQ]ooHhKOof>6g_mSQMh2o`000003
of>5g_l0003oHXGN00CoHXCN00?o0000of63gOl000000omPPmd02?l0003oGX7Moej1gOmNPMgo0000
oef1gOl0003oFgoL0_l000000omKOmgo0000oeMmg003oeMmg004o`000?mCN]_o0000o`0000;oDW_M
00?o0000odahg?m<N=`00_m<N=`00ol0003oAGCKodEdf`02odEdf`03o`000?llKm[o?6oJ00;o?6oJ
00Go0000oc1ZfOl`J]Wo<6[Io`000002ob5Se`03o`000?o[QRgojhH]00;ojhH]00Co0000ol8o0?o2
?`3o`Sl00_l0000Rooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool09_ooool0023o
oooo00?o0000ooooooooool05?ooool5o`0003?ooooo00?o0000o`J3h?l000001_l000001?l^Pn[o
0000ocB2j?ldP^P6o`0000;oAXGX00?o0000od^4i_l000000_l00004oe:6iP03o`000?mEQ^Co0000
00;o00001?mJQn<00ol0003oG8ORoeb7hP02oeb7hP04o`000?mOQn;oGhORoen7hP;o000000?oH8KQ
o`000?mQQn400ol00004of:6h004of:7h?l0003o0000of>6g`Co000000?oI8KOof>6gomSQ]h00omS
QMh2o`000008of:4g_l0003oHXCNof:4g_mQQ=ko0000of23gOl00002of23g@04oen3gOl0003oGX7M
o`0000;oGH7M0_l00004oe]og@03o`000?mGOMcoEggL00?o00001OmBNmd00ol0003oC7SLodahg002
odahg003o`000?m5M=_oAGCK00;oAGCK00?o0000oca_f_llKmX00_llKmX01ol0003o<6[Ioc1ZfOl`
J]Wo0000ob5Seol000001?o[QRd00ol0003o`Sl0ol8o0002ol8o00;o00008?ooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oooooooooo02Kooooo000Pooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool00_ooool8o`0002cooooo1?l000000ol>ONCo0000oaMki@04o`0000?o=8;X00?o
0000oc^1iolkPNL00ol000000om6QNSo0000od^4iP02od^4iPCo000000?oDXKVo`000?mEQ^@00_mE
Q^@01ol0003oFXOSo`000?l0003oFXOSo`000?mLQ^800ol00002oej6h@04o`000?mOQn;oGhORo`00
00?oH8KQ0_l000001OmQQ^3oHXKPof:6h?l0003oHXKP00;o000000?oHXKOof>6gol000000ol00000
0omTQ]ooHhKNof>5gP02of>5gP;oHXGN0ol000000omRQ=koHHCNof64gP02o`000003of23gOl0003o
Gh?M00?o000000GoGH7Mo`000?mMPMgoGH7Mo`000002oe]og@Co00000omGO]d00ol0003oDW_Moe9k
g@03oe9kg@03o`000?m<N=coC7SL017o000000?o8F?Go`000?o[QRd00oo[QRd00ol0003o`Sl0ol8o
0002ol8o00;o00007_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo02Kooooo000P
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool8o`0002Gooooo1_l00002
oaMki@?o00000oldP^P01Ol0003o>h7Woc^1iol0003o@X7V00?o00000om;Q>H00ol0003oD8CToe24
i003o`000004oeF6i?l0003o0000o`0000;oF8GS0ol00003oeb6hP03o`000?mNQ^7oGXKQ00;oGXKQ
0_l000001?mPQ^7o0000of26hOmPQ^42o`0000;oHHKP0ol00002of:6g`03of>6gol0003o000000?o
000000CoHhKNof>5g_mSQMko00000_mRQMh4o`0000?oHHCN00?o0000oen3gOl000000_mOPmh2o`00
00?oGH7M0ol00003oeZ0g@03o`000?mGO]goEgkM00;oEgkM00Co0000oe9kgOmBNmgoDW_M1?l00003
odajg@05o`000?m5MmgoAGOModEggOl000001?llLmd01?l0003o<FoMoc5_gOlaKmd3o`0000CojhH]
00?o0000ol8o0?o2?`000_o2?`000ol0003oOP00o`00000Mooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool09_ooool0023ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Cooooo`So00007_ooool00ol0003o00jHo`000003o`0000;o5g_U00?o0000ob1jiOl000001?l0
0002oc^1i`04o`000?m2PNKo@X7Vod:1iPGo00000om@Q>@01?l0003oE8CSoeB4homDQ><2o`000004
oeR5hol0003o0000o`0000;oFhGR0ol000000omNQ^7o0000o`000002o`0000;oGhKP00[o0000of26
hOl0003oHHKPo`000?mQQ^3o0000of66h?l0003oHXGO0_mRQ]l8o`000003of>5g_mRQMkoHXGN00;o
HXGN00OoHHCNo`000?l0003oHHCNo`000?mQQ=ko000000;oGh?N00Co0000oen3g_l0003oGH7M0_l0
00000omMP]ko0000oeZ0g@04oeZ0g@03o`000?mGO]goEgkM00Go00000_mBO=h00ol0003oC7[Modaj
g@03odajg@05o`000?m5MmgoAGOModEggOl000001?llLmd00ol0003o<FoMoc5_g@02oc5_g@03o`00
0?o[QRgojhH]00?ojhH]0_l00003ol8o0004o`000?mn003o0000o`0001[ooooo00?o0000oooooooo
ool0JOooool00ol0003oooooooooo`0Vooooo`008?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01_ooooo2Ol0000Fooooo`03o`000?l03YSo000000Ko00000_lPN^D00ol0003o:g[U
o`000004o`0000?o@X7V00?o0000odR1i?m8PN@01_l00003oeB4h`04o`000?mHQ>;oF8CRoeR4hP;o
00001?mKQN801Ol0003oGXKQoej6hOmNQ^7o000000GoGhKP0_l00002of66h0;o00000omRQMl00omR
Q]oo0000o`000004o`0000;oHhGN1?mRQMh2o`000003of64g_l0003oHHCN00;o000000CoGh?No`00
0?mOPmkoGh?N0_l00004oef2gP04o`000?mJP=goFX3MoeZ0g@Co00000omGOmh00ol0003oDWcNoe9l
gP02oe9lgP03o`000?m<N]goC7[M00?oC7[M00Go0000odEggOm5MmgoAGOMo`000004ocacg@03o`00
0?laKmgo<FoM00;o<FoM00?o0000on^6;Oo[QRd00_o[QRd00ol0003oZ496o`000002ol8o0003o`00
0?mn003oOP0000;o00006?ooool00ol0003oooooooooo`1Yooooo`;o0000:?ooool001oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Tooooo`So00003oooool01_l0003o00jHo`0i
/?l0>K3o0000o`1XePKo000000Co:g[Uo`000?ldNnCo=7_T1_l00002odR1i004o`000?m>PN?oCX7S
odj1h`Ko00000omHQ>800ol0003oFhCQoe^4h@03o`0000?oGHGQ0_l00003oen5h0?o000000GoHHGO
of66h?l0003oHHKPo`000002of:5g`03o`000?mRQ]oo000000[o00000_mRQ=h01?l0003oHHCNo`00
0?mQQ=h3o`000005oen3g_l0003oGh?Noen3g_l000000_mMP]h5o`0000?oFX7N00?o0000oeMog_mG
Omh00_mGOmh00ol0003oDWcNoe9lgP02oe9lgP04o`000?m<N]goC7[Modajg@Oo00001?llLmd01Ol0
003o<FoMoc5_gOlaKmgo000000CojhH]00Co0000ojQ2A_nX@TKo00000_o2?`001Ol0003oOP00ogh0
0?mn003o000001Kooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0Vooooo`007ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02gooooo2?l00008ooooo`;o00000_l0
>K03o`0000;o0V_L1Ol00003ocAki003o`000?lmO>?o?GcS00Go00000om>PN<01?l0003oDX;Roe:2
h_mBP^86o`0000CoFhCQ00?o0000oef5hOl000000_l00002oen5h0Co00000_mQQMl01_l0003oHHGO
o`000?mRQMoo0000of:5g`[o000000CoHXGNo`000?l0003oHXCN0_l000000omQQ=ko0000of64gP03
o`0000;oGh?N1?l00003oef2gP04o`000?mJPMkoFX7NoeZ1gPoo00000_m=O=l01?l0003oAW[OodIj
gom6N]l;o`0000CojhH]00?o0000ojQ2A_nX@TH00_l000000oo2?`3o0000ogh00002ogh00003o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0Vooooo`007ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Gooooo2?l00002ooooo`Ko00000_l2
Jm`00ol0003o4VkOo`000002o`0000?o=7_T00Co0000ocelholmO>?o00000_m5ON<6o`0000?oDX;R
00Co0000oeN3hOmGPn7oEh?Q0_l000001?mKQ>7o0000o`000?l00003oef4h0;o00001?mOQN000ol0
003oHHGOof65g`03of65g`;o000000?oHXGOo`000?l000003?l000000omRQMko0000o`000002o`00
0003of64g_l0003o000000;o00000omOPmh00ol0003oGH;Noef2gP05o`0000;oFX7O00?o0000oeN0
gomGP=l00omGP=l00ol0003oDWkOoe9ng`02oe9ng`03o`000?m=O=ooCGcO00;oCGcO00?o0000odIj
gom6N]l00_m6N]l01Ol0003o?WOPocigh?lnMn3o000000?o=7CP00?o0000on^6;Oo[QRd00_o[QRd0
0ol0003oZ496ojQ2AP02ojQ2AP;o00001?mn0002o`0001;ooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`007oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
03gooooo3?l000000olBK]oo0000ob5ah@05o`0000;o?GcS00Go0000odEmhom5ON?oAGgSo`000002
odaohPKo00001?mGPn400ol0003oFX?PoeZ3h002o`000003oef4h?l0003o000000?o000000CoGhGO
o`000?l0003o00000_mQQMl3o`0000?oHXGO3?l000001?mRQMko0000o`000?mRQMh3o`000003of64
g_l0003o000000Oo00000omMPml00ol0003oFX7OoeZ1g`02oeZ1g`03o`000?mGP=ooEh3O00?oEh3O
00?o0000oe9ngomBO]l00_mBO]l00ol0003oCGcOodelg`02odelg`03o`000?m6N]ooAW[O00;oAW[O
00Go0000ocigh?lnMn3o?WOPo`000003ocAdh005o`000?o[QRgojhH]on^6;Ol000001OnX@TH2o`00
00CoOP000_l0000@ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool001oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`12ooooo`03o`000?lQNNGo8GWU00Wo
00000_l_M>45o`0000?oAGgS00Go0000odaoh_m<On;oC7oRo`000002oe60h@Oo000000CoFX?Po`00
0?l0003o00001?mMQ>001?l0003oGhCOoen4gomOQ=l2o`0000;oHHGO0ol00004of:5ga;o00000_mQ
Q=h01?l0003oGhCNoen4g_mOQ=hPo`000003odIjgol0003o?WOP00;o?WOP00Co0000ocAdh?ldM>3o
00000oo[QRd00ol0003oZ496ojQ2AP04ojQ2AP03o`000?mn003oOP0000?oOP000ol0000=ooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool09Oooool001oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`14ooooo`03o`000?lQNNGo8GWU00?o000000?o05[Ao`000?l00000
4_l00003oe60h@03o`000?mFPN3oEX7P00;oEX7P00?o0000oeZ2h?mJP^001ol000000omOQ=oo0000
o`000002o`0000;oHHGO0_l00003of:5gaWo00000_mOQ=l00ol0003oGH?Ooef3g`03oef3g`03o`00
0?mJP]ooFX;O00;oFX;O00?o0000oeN1h?mGPN000_mGPN000ol0003oDX3Poe:0h003oe:0h005o`00
0?m=O^7oCGkQodenhOl000000om7ON87o`0000;o=7CP00Co0000on^6;Oo[QRgo00001onX@TH5o`00
00;oOP000_l0000;ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool09Oooool001oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`15ooooo`;o00000_ooool01Ol0=jKo
0000o`1JdOl0003o1F;H00?o00000_l_M>400ol0003o>WOQocYgh@0Co`000003oeZ2h?l0003o0000
00CoGH?O00Co0000oen4gomOQ=ooGhCO0ol000000omQQMoo0000o`000002o`0000;oHXGO:_l00000
0omGPN3o0000oe:0h004oe:0h005o`000?m=O^7oCGkQodenhOl000001?m7ON801?l0003o@7_Rod1k
h_m0Nn84o`0000?ojhH]00?o0000ojQ2A_nX@TH01?nX@TH00ol0003o>009ocP02@02ocP02@_o0000
1?ooool00ol0003oooooooooo`1^ooooo`?o00009oooool001oooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1:ooooo`Co000000?o1F;Ho`000?lIJ=`01?l00003ocYgh@04o`000?m3
N^7o@g[Qo`0000;oBgcP2?l00002oeJ0g`03o`000?mJP]ooFX;O00Wo00000_mOQ=l01?l0003oHHCO
of64gomQQ=l2o`000003of:5gol0003oHXGN01[o000000?oGhCOo`000?mMQ=l00omMQ=l00ol0003o
FX?PoeZ3h002oeZ3h004o`000?mGP^7oEh;QoeN2h@go00001?m7ON800ol0003o@7_Rod1khP02od1k
hP03o`000?lhN^?o000000;ojhH]00?o0000ojQ2A_nX@TH01OnX@TH00ol0003o>009ocP02@08ocP0
2@04o`000?m2_Noo@[g_od:mk`Co0000Loooool00ol0003oooooooooo`0Uooooo`007oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo04cooooo0ol000001?l5H]So0000oaUXg?lIJ=`:
o`0000?oBgcP00?o0000oe5nh?mAO^000_mAO^0:o`000003oef3gol0003o000000Oo000000?oHHCN
o`000?l000000_l000000omRQMko0000o`00000Bo`000003of65gol0003o000000ko000000?oFX?P
o`000?mGP^400omGP^400ol0003oDh7Qoe>1h@03oe>1h@04o`000?m>PN;oCX7Rodj1hPGo000000?o
AggRo`000?m0Nn800om0Nn82o`0000;ojhH]00?o0000ojQ2A_nX@TH01OnX@TH00ol0003o>009ocP0
2@07ocP02@Co00001?m2_Nl3o`00077ooooo00?o0000ooooooooool09Oooool001oooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1>ooooo`03o`000?l0B<Go000000;o00000_lIJ=`0
0ol0003o:VkMo`000003ocMcgP03o`000?m2Mmko000001go000000?oHHCNo`000?l000000_l00000
0omRQMkoHXCNo`00000Eo`0000?oGhGP1_l000001?mMQ>3o0000oe^4hOmKQ>46o`000003oeN2hOl0
003oDh7Q00CoDh7Q00Go0000odj1h_m>PN;oCX7Ro`000003odV0h`Ko000000Go@7_Ro`000?l0003o
jhH]o`000008ojQ2AP03o`000?lh00Wo>00900Ko>00900Go0000o`1Hbol0003o0000o`1Hc@03o`00
00;o04g;00?o0000ooooooooool0Koooool00ol0003oooooooooo`0Uooooo`007oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04oooooo0_l00002o`1Ed0Co000000?o:VkMo`000?lg
Lmh00_lgLmh01?l0003o@WONod9gg_l00003odYjgP05o`000?m@OMkoD7gNoe1mg_l000001?mFOmh0
1Ol0003oFX7NoeZ1g_mJPMko000000;oGH;N1?l000000omOPmko0000o`000006o`000004of:4g_l0
003oHXCNof:4gQSo000000?oGhGPo`000?mMQN000_mMQN06o`000004oe^4hOl0003oF8CRoeR4hPKo
000000?oDh7Qo`000?m>PN800om>PN800ol0003oBH3SodV0h`03odV0h`03o`000?m3OnGo@goU00?o
00000_o[QRd00ol0003oZ496ojQ2AP05ojQ2AP03o`000?lh00Wo>00900Go>0091?l000001Ol0F<_o
0000o`1HcOl0F<go000000?o04g;00?o0000ooooooooool0Koooool00ol0003oooooooooo`0Toooo
o`007_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo0_l00002o`1Ed003
o`000?lDGmOo000000?o00000olgLmh01?l0003o@WONod9gg_l00003odYjgP05o`000?m@OMkoD7gN
oe1mg_l000000_mFOmh8o`0000;oGH;N0ol00002oen3gP;o00001?mQQ=hKo`000003oen5h?l0003o
000000Co000000?oGHGPo`000?mKQN400_mKQN45o`000003oeR4h_l0003oE8?S00;oE8?S1_l00000
0om>PN;o0000odV0h`04odV0h`05o`000?m3OnGo@goUod=oiOl000000_o[QRd00ol0003oZ496ojQ2
AP06ojQ2AP03o`000?lh00Wo>00900?o>0090_l00002o`1ZfPCo00000_l0F<d01Ol0003o04g;o`1=
bol0CL_o0000073ooooo00?o0000ooooooooool09?ooool001kooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Booooo`;o00000_l0EM000ol0003o55oGo`000002obMXfQ7o00000_mF
O]d00ol0003oFX3NoeZ0gP02oeZ0gP03o`000?mMP]koGH;N00;oGH7N00?o0000oen3g_mOPmh00_mO
Pmh00ol0003oHHCNof64gP02of64gP03o`000?mRQ=ko000000?oHXGN00?oHhGNo`000?l000005Ol0
0003oej5h@Go00000_mKQN400ol0003oF8GRoeR5hP03o`0000GoE8?S00?o0000oe23i?m@Pn@01ol0
00000om9P>?o0000od=oi@02od=oi@03o`000?o[QRgo000000SoZ49600?o0000ocP02Olh00T00_lh
00T00ol0003o6GWToaUii005o`000005o`1Tdol0003o0000o`1HcOl000000ol0CL/00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0E?ooool01_l0003o05G@o`1Ed?l0003o55oGo`0000;o9fSJ00Co0000ocI_folf
Km_o00000om1M=`01Ol0003oBWSModYhgOm:N=go000000?oDG_M00Go0000oeIngOmFO]goEWkMo`00
0002oeZ0gP?o00000omMPMh2o`0000;oGh?N00Go0000oen3g_l0003oHHCNo`000002of64gP?o0000
00KoHXGNo`000?l0003oHhKNof>6gomTQ]lIo`000003oej5hOl0003oG8KR00Co00001?mHQN85o`00
0003oeB3hol0003oD8?T00?oD8?T00Co0000od^3iOm;PnGoBh?U1_l000000oo[QRgo0000ojQ2AP07
ojQ2AP03o`000?lh00Wo>00900;o>00900Ko0000oaUii?lINNCo6GWTo`000?l=N^<3o`0000;o06CC
0ol00003o`1=b`03o`000?oooooooooo06[ooooo0ol0000Vooooo`007_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo05Gooooo1?l000001OlDGmOo0000obMXf_lWJ=[o000000;o=VoK
00Go0000od5dg?m1M=co@GCLo`000003odYhg@05o`000?mANmgoDG_Moe5kgOl000000_mFO]d3o`00
00?oFWoM00Oo0000oef1g_l0003oGH7Mo`000?mOPmko000000;oGh?N0_l000000omQQ=ko0000of64
gP02of64gPCo000000CoHhGNof>6g_mSQ]ooI8KO5ol000000omNQ^7o0000o`000003o`000003oeb6
h_l0003o000000?o000000?oF8GRo`000?mEQN@00_mEQN@6o`000003oe23i?l0003oBh?U00?oBh?U
00?o0000odJ4iom6Q>L00_l000000oo[QRgo0000ojQ2AP07ojQ2AP03o`000?lh00Wo>00900?o0000
0olINN@01?l0003o3G[So`ejhol=N^<2o`000004o`1Tdol0003o0000o`0000;o04g;00?o0000oooo
ooooool0K?ooool00ol0003oooooooooo`0Tooooo`007_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo05Gooooo0_l000000ol0BLWo0000o`000002o`0000;o9fSJ00Co0000ocI_folf
Km_o00000om1M=`00ol0003oBWSModYhg@07o`0000;oEWgM00?o0000oeYogOmJOmd00ol00003oef1
g@;o000000KoGh?No`000?mOPmgoGh?Mo`000?mQQ=h2o`000005of64g_mRQ=ko0000o`000?mRQMh0
1?l000000omTQ]oo0000o`00000Io`000004oeb7h_l0003o0000o`0000?oFHKS1Ol00002oeF5i004
o`000?mAQNGoDHGUoe65i@Go00000_m;PnD01_l0003oAXCWodJ4iol0003ojhH]o`0000SoZ49600?o
0000ocP02Ol000000ol]PNT3o`000003oaUii?l0003o3G[S00?o3G[S1_l000000ol0CL_o0000oooo
o`1/ooooo`03o`000?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Eoooool2o`000004o`19bOl0003o4ESAoa5Hd@co000000?oBgKKo`000?mAN]`00omA
N]`00ol0003oEWgMoeImg@03o`0000?oFWoM00?o0000oef1gOl000000_mMPMd02Ol0003oGh?Moen3
gOmOPmgoH8?Mo`000?mQQ=ko0000of64gP02of:4gPCo000000CoHhKNo`000?l0003oI8KO5_l00002
oej7h@co00000_mFQn@4o`0000CoDHGU00?o0000odj6iom>Q^L01?l00002odJ4i`;o00002?nX@TH3
o`0000Go;H7Y1?l00004o`ejh`03o`000?l0N]co000000;o05C60ol0001/ooooo`03o`000?oooooo
oooo02Cooooo000Nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0F?ooool2o`00
0004o`19bOl0003o4ESAo`0000;o9f?F00Go0000ocM[f?lgJmSo=f_Ho`000002od9afP05o`000?m;
M]_oBgKKod]ffol000000omAN]`3o`0000?oEggL00?o0000oeYogOmJOmd00ol000001_mMPMgo0000
oej1gOl0003oGh?Mo`0000;oH8?M0ol000001_mRQ=ko0000of>5g_mSQMko0000of>5gP;o000000?o
HhKOo`000?l000004Ol000001?mPQn7o0000o`000?mOQn84o`0000;oGHOS1?l000000omJQnCo0000
o`00000:o`0000;oDHGU00?o0000odj6iom>Q^L00_m>Q^L5o`0000KoZ4961_l00005obf1j@03o`00
0?lVQ>[o9XCZ00?o00000_l=N^<00ol0003o07[Lo`1jg005o`0006_ooooo00?o0000ooooooooool0
9?ooool001kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Iooooo`;o000000Co
04W9o`000?lAF=7o00000_lWHmH01Ol0003o=f_HocM[f?lgJmSo000000;o@W7J00Oo0000od]ffom;
M]_oBgKKo`000?mAN]co000000;oDWWK00Co0000oeMmg?mGOMcoEggL0ol00003oe]og004o`000?mN
PMgoGX7Moej1g@?o000000?oH8?Mof63gOmQPmd00_l000001OmRQ=ko0000o`000?mSQMkoI8GN01So
000000GoGhSRo`000?l0003o0000oen7hP03o`0000?oGHOS0ol00002oeZ7i0Co00000_mFQn@9o`00
00;oCXKW00Co0000odV7j?m9QnSo00000onX@TH3o`000003od64j?l0003o>hKZ00;o>hKZ1_l00000
0ol]PNWo0000obJ4jP02obJ4jPGo00000ol0N]`5o`0006[ooooo00?o0000ooooooooool08oooool0
01kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Jooooo`Co000000Go4ESAo`00
0?lWHmKo9f?Fo`000003ocM[f004o`000?m2LM[o@W7Jo`0000;oBgKK0_l00004oe9if`05o`000?mG
OMco0000oeQlfol000000omKOm`01Ol0003oG7oLo`000?mNPMgo000000;oGX7M0_l00003of63g@;o
000000CoHXCNof>5g_mSQMkoHhGN0_mTQ]h00omUQ]ko0000o`000004o`000003ofF7gol0003o0000
00So000000?oHXOQo`000?l000000ol00002oen8hP?o000000OoGXSSo`000?l0003o0000oef7hol0
003oFhST00;o000000CoFXOTo`000?mHR>GoF8SU1?l00004oe>8iQ3o000000?o@HCXo`000?lkQ^X0
0olkQ^X01?l0003o=XS/ocJ8k?lfR>`5o`000004obJ4j_l0003o8HS[ob68j`Co000000?o07[Lo`00
0?l000000_l09jP00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00Cooooo1?l000000ol@
413oooooooooo`0Hooooo`007_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05co
oooo00?o0000o`0o`ol0?l<00ol00002obMSeP03o`000?lgJmSo=f_H00Ko00000_m<MMX01?l0003o
DWWKoe9ifomBNM/2o`0000?oF7cK00?o0000oe]og?l000000omLOm`01_l0003oGX7Moej1gOmNPMgo
Gh7Lo`0000?oHH?M0_mRQ=d01Ol0003oHhGNo`000?mSQMkoI8GN00;oI8KN0_mUQml5o`000005ofF7
gol0003o0000o`000?mTQml03_l000000omOR>;o0000o`000003oej8h`?o00000_mKR>@3o`0000Co
F8SU1?l00002oe>8iP03o`000?m@RNSoD8WX00?o00000_m9QnP00ol0003oBHOXo`000009o`0000;o
>hKZ00?o0000ocJ8k?lfR>`00_lfR>`00ol0003o<hc^oc><kP03o`0000Co8HS[2?l0001Uooooo`Co
00002?ooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo05gooooo00?o0000o`0o`ol000000_lDD/d5o`000003ocUYe_l0003oA73H00?oA73H
00Ko0000odaef_m<MM[o0000oe9ifol00002oe=ifP04o`000?mHO=_oF7cKoeQlf`;o00000omLOm`0
1_mMOmco0000oej1gOl0003oGh7Lof22g0;o000000CoHH?Mo`000?mRQ=goHhCM1?l000000omTQ]ko
0000o`000002ofF7g`Go000000GoIHOOo`000?l0003o0000ofB7g`0?o`000004oej9hol0003o0000
o`0000;oGXSS0ol00002oe^8i0?o00000omHR>D00ol0003oEX[WoeJ:i`04o`0000CoD8WX1Ol00000
0om9QnSo0000odF9j`03odF9j`Wo00000_lfR>`00ol0003o<hc^oc><kP02oc><kP?o00000_lQR>/0
0ol0003o7I7ZoafAjP07o`0006Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0J
ooooo`007Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05gooooo0_l000001ol0
?l?o0000oaABcOlDD/go0000obUOd_l000000oliJMH00ol0003oA73HodA`f002odA`f004o`000?m<
MM[o0000o`0000CoDgWJ00?o0000oeQlfol000000_mIO=/00ol0003oG7oLo`000002oeeog003o`00
0?mOPMcoGh7L00;oH8;L0ol000000omRQ=goHhCMof>4g@02ofB5gP05of>5g_l0003o0000ofB6g_l0
00000_mUQml5o`000005ofF7gol0003o0000o`000?mTQml02?l000001?mRRN;o0000o`000?mQR>84
o`0000;oGXWS0ol00002oeb9i@Co000000?oFH[Vo`000?l000000ol00004oeJ:i`Co00000_m@RNP0
1?l0003oCH_Zodf;j_m=RnX5o`0000;oAHW[00?o0000od:;kOm2Rnd00_m2Rnd;o`000003oc><k_l0
003o000000?o00001?lMTNX3o`000004oeL00?l0003o0000o`0006;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Jooooo`007Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05oooooo00Co02>^o`000?l0?l?o00000_lDD/d00ol0003o:EoBo`000003ocUYeP04o`00
0?m4L=SoA73HodA`f0;o00000_m>MMT01?l0003oDgWJoe=if_mCNMX2o`0000CoFGcK00Go0000oeeo
g?mMOmcoGGoLoeiog002o`0000;oH8;L0_mQP]`00ol0003oHXCMo`000002o`000004ofB5g_mUQMko
0000ofB6gP[o000000?oIHOOo`000?l000000_l000000omUR>7o0000o`000006o`000003of:9h_l0
003o000000;oHHSR1?l00002oej9h`;o00000omLRND3o`0000?oFH[V1?l00002oeJ:i`03o`000?mC
S>WoDhcY00Co00001?m=RnX00ol0003oBXg/odZ=k004o`0000Co@X_]00?o0000ocn>k_loS^h01?l0
0003oc><kP_o000000?o7I7Zo`000?l000000omG0003o`0000Cooooo1Ol0001Fooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool06_ooool001gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Pooooo`;o000000Oo03o3o`000?lDD/go55;=o`000?lYGm;o000000?o>FWF
00Go0000odA`f?l0003oAfoGo`000003odief@03o`000?mCNM[o000000;oEWWI00So0000oeUlfomI
O=_oFGcKoe]mfol0003oGGoLo`0000;oGWoL00?o0000of22g?mPP]`00_mQP]`2of:3g@?o000000Co
I8GNo`000?mUQ]koIXKN2ol000000omUQmoo0000o`000002o`000005ofF8hOl0003o0000o`000?mS
R>401Ol000001OmRRN;o0000o`000?l0003oHH[T00Go000000OoGX_Uo`000?l0003o0000oeb9iOl0
003oFh_V00?o000000CoFH[Vo`000?mHS>SoF8cX1?l00004oe><j@Co00000_m=RnX00ol0003oBXg/
odZ=k002odZ=k0Co00000_m2Rnd00ol0003o?hk^ocn>kP02ocn>kPKo000000?o<hc^o`000?lbTO00
0olbTO09o`000003oeL00?l0003o000000Co00001Omj_od00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06_ooool001gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Pooooo`04o`000?l07:[o03o3o`0o``?o55;=0_lYGm800ol0003o>FWF
ocUYeP02o`0000?oAfoG00Co0000odiefOm>MMWoCWGI0_l00003oeIif@03o`000?mIO=_o000000;o
FggK00Go0000oeiog?mNOmcoGWoLoen0f`02o`0000;oHH;L00Wo0000of:3gOmSPmgo0000of>4gOl0
003oI8GNofF5g_mUQ]h00_mVQmh00omWQmko0000o`000007o`000003ofN9h?l0003oIXWP00;o0000
00GoIHSQo`000?l0003o0000of>8h@05o`0000;oHXWR0_l00002of6:i004o`000?mOR^?o0000o`00
00?oGX_U0ol00003oe^;iP?o00001?mHS>P4o`0000;oDhcY00?o0000oe6>jomAS^/01?l00004odZ=
k003o`000?m8T>koB93^00Co00001?loS^h00ol0003o?I;`ocfBl002ocfBl0Go00000_lbTO000ol0
003o>9[cocRJl`03ocRJl`[o00001Omj_od00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool06_ooool001gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1Qooooo`03o`000?l07:[o000000So00000_lmJ=@01ol0003oAfoGodM_eom7KmOo0000
odiefOl000000_mAMMP01Ol0003oEWWIoeIifOmFNMWo000000?oFggK00CoG7gJo`000?mNOmcoGWoL
0_mOP=/3o`0000;oHX?M00So0000ofB4gOl0003o0000ofB5g_l0003oIHKNofJ6gP;oIXON00CoIhON
o`000?mXR=ooJ8SO0_l000001omWRMoo0000o`000?l0003oIhWPo`000?mVRN000_l000000omUR>7o
0000o`000002o`000003ofB:h_l0003o000000Co000000CoHX_To`000?l0003oHH[T0_l000001?mO
S>Go0000o`000?l00002oej;i@?o00000omKRnH3o`0000?oF8cX00?o0000oeJ>j_mFS^X01?l00004
oe6>j`Co00000_m:SN`00ol0003oB93^odR@kP02odR@kPCo00000_loS^h00ol0003o?I;`ocfBl004
ocfBl003o`000?lmU_;o000000?o00001OlhV_<00ol0003oC:[iodbZn@04odbZn@03o`000?mj_ogo
000000Oo0000Doooool00ol0003oooooooooo`03ooooo`03o`000?m4A4Co000001cooooo000Moooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0H_ooool3o`000005o`0l_ol0003o6e7:
oa]Ab_l000000_l_G]001Ol0003o?FSDoceXe?lmJ=Co000000?oAfoG00?o0000oe5ef?mAMMP00_mA
MMP01Ol0003oEWWIo`000?mHN]Wo000000;oFggK00Co0000oeamf_l0003o00000_mOP=/2of61f`;o
000000CoHX?Mo`000?l0003oI8CM1_l000001?mVQmkoIhONofN7g_l00002ofR8g`;o000000GoIhWO
o`000?l0003o0000ofN9h002o`000003ofJ9h?l0003oIHSQ00Co00000_mTR^85o`0000;oHX_T00?o
0000of6:i?mQR^@00_l00002oen<i@?o00000_mMSNL4o`0000;oFXgX0ol000000omHS>So0000oeJ>
jP03oeJ>jPCo00000_mAS^/00ol0003oCi3]odn@k@04o`0000CoB93^00?o0000odJCl?m6To001?l0
0006ocfBl004o`000?lmU_;o?IKbocfFlPKo000000?o>9[co`000?m<Z_T01Om<Z_T00ol0003oN[om
ogZoo@02ogZoo@co0000BOooool3o`0000Gooooo00?oc<c<oeEEEOl000007?ooool001gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`1Sooooo`05o`000?l07:[o0000o`0l_ol00000
0_lKDLX01?l0003o;ek@obmNd?l00003oceXe005o`000?m7KmOo0000od]`e_l000001?mAMMP01?l0
003oF7[IoeQjfOmHN]T2o`0000?oG7gJ00Go0000oen0fomOP=_o0000of61f`02of:2g0;o000000Co
Hh?MofB4gOmUQMgoIHGM0_mVQ]d01omUQ]ko0000o`000?mVQmko0000ofN7g_l000000_mXR=l2o`00
0005ofN9gol0003o0000o`000?mWRN000_l000000omVRN3o0000ofF8h@05o`000003ofB:h_l0003o
000000So000000CoH8cUo`000?l0003o00000_mOS>D2o`0000?oGHgW0ol00003oeZ=j0Co00000omF
S^X00ol0003oE93/oeB@k004o`0000CoCi3]1?l00002odR@kP03o`000?m6To3oAY?`00;oAY?`1_l0
0002ocfBl003o`000?lmU_;o?IKb00?o?IKb00?o0000od:Ilom2VO<03Ol00003oeZ4h@03o`000?oo
oooooooo00Kooooo2?l00013ooooo`03o`000?oooooooooo02;ooooo000Mooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0I?ooool01Ol0003o01bZo`000?l0?;oo000000;o6e7:00Co
0000obmNd?l_G]3o00000olmJ=@01Ol0003oBg3Fod]`e_m;L=Ko000000?oDGGH00?o0000oeQjfOmH
N]T00_mHN]T2o`0000;oG7gJ00?oGWkJo`000?l000000_mQPM/00ol0003oHX;Lof:2g004o`000004
ofF5gOl0003oIXKMofN6g@;o000000GoIXONo`000?l0003o0000ofN8g`02ofR8g`;o000000GoIhWO
o`000?l0003o0000ofN9h002o`000004ofJ9h?l0003o0000ofJ;hPGo000000?oI8[Ro`000?l00000
0_l000000omSRnCo0000o`000002o`0000?oH8cU0ol000001omNS^Oo0000o`000?l0003oGHgWo`00
0?mLSnT00ol000001?mJSNSo0000oeV@jomIT>/5o`0000CoE93/1?l00003odn@k@03o`000?m>Tnoo
000000?o00001_m6To000ol0003oAIObodFGlP08o`000003ocfFl_l0003o@YWc00?o@YWc00?o0000
odfFlOm=U_401?m=U_400ol0003oFXCQoeZ4h@04oeZ4h@03o`000?oooooooooo00gooooo2?l0000k
ooooo`03o`000?oooooooooo02;ooooo000Mooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0I?ooool2o`000006o`0LZ_l0003o03boo`000?lKDL[o00000ol_G]001Ol0003o?FSDo`00
0?m3JM;o000000?oBg3F00Go0000oe5ef?l0003oE7KGo`000003oeQjf@;oFW_I0_l00002oeinfP;o
000000CoHH7Ko`000?mRP]coHX;L0_mTPm`01?l0003oI8CMofF5gOl00002ofJ6g@;oJ8ON0ol00000
0omWQmko0000ofN8g`02o`000003ofR8gol0003oIhWO00?o000000CoIhWPo`000?l0003oJ8_Q0_l0
00001OmVRn;o0000o`000?l0003oIH[R00;o000000?oIHcTo`000?mTS>@00_l00002of>;i0Co0000
0_mPS>D2o`0000?oGXkW0ol00003oeb?j@?o00001OmIT>/3o`0000?oE93/00?o0000oe>Ck_mCTnh0
1Ol00003odjCk`Ko00000_m6To000ol0003oAIObodFGlP02odFGlP03o`000?m5V_?oAI[c00;oAI[c
1Ol00002od:Il`03o`000?m=U_7oCIKa00CoCIKa00?o0000oeZ4hOmJQ>401?mJQ>400ol0003ooooo
ooooo`0Dooooo`So0000<oooool00ol0003oooooooooo`0Rooooo`007Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo06Kooooo00Go0000o`0LZ_l0003o03boo`000002oa]AbP03o`00
0?l_G]3o;ek@00;o00000om3JM801Ol0003oBg3Fod]`e_m;L=Ko000000?oE7KG00?o0000oeQjfOl0
00000omJNmT00ol0003oGWkJoeinfP02of5ofP;o00000_mRP]`02_l0003oI8?LofF4g?mTQ=go0000
ofF5gOl0003oIXKMofN6gOmXQmh3ofV8gPKo000000?oJ8SOo`000?mWRMl00ol000001?mYRn7o0000
o`000?mXRn43o`000004ofJ;h_l0003o0000ofF:hP;o000000CoIHcTo`000?l0003oI8cT0ol00000
0omSS^Go0000o`000003o`000004of6?iol0003o0000o`0000;oGXkW0_l00005oeb?j@?o00000omI
T>/00ol0003oF9?]o`000002o`000003oeB@k?l0003oDi?^00CoDi?^1?l00002odjCk`04o`000?m=
Uo;oCIObodfGlPKo00000_m5Uo800ol0003oAI[codFJl`04odFJl`03o`000?m4VoCo000000?o0000
1_m=U_400ol0003oFXCQoeZ4h@04oeZ4h@03o`000?oooooooooo01_ooooo2?l0000[ooooo`03o`00
0?oooooooooo02;ooooo000Looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0I_oo
ool00ol0003o01bZo`0LZP02o`0l_`03o`000?lKDL[o000000;o000000?o=eo>o`000?m3JM800om3
JM801?l0003oBg3Fo`000?l00004oeAfe`03o`000?mJNmWoFW_I00;oFW_I00CoGGcIo`000?mNO][o
00000_mQOmX2o`000009of:2g?l0003oI8?Lo`000?mUQ=co0000ofF5gOl0003oIXKM00;o000000Go
J8ONofV8g_mYR=ko0000ofZ9gP02ofZ9g`03of^:gol0003o000000?o000000CoJX_Po`000?l0003o
JH_Q0_l000001OmXRn7o0000ofN;hOl0003oIX_R00?o000000CoIXgSo`000?l0003oIHcT0_l00000
0omTS>Co0000o`000002of>>i@03o`000?mRSNGoHXgU00;o00000_mQSnL3o`000004oej@jOl0003o
0000o`0000;oG8oY00?o0000oebBjomLT^/00ol000000omIT>_o0000oeRCk@02oeRCk@;o00001_mC
Tnh00ol0003oDiO`oe>Gl004o`0000GoCIOb00?o0000odfKm?m=Vo@01?l00006odFJl`04o`000?m4
VoCoA9_dodBKm0Ko00000_m=U_400ol0003oFXCQoeZ4h@03oeZ4h@03o`000?oooooooooo02?ooooo
2?l0000Sooooo`03o`000?oooooooooo02;ooooo000Looooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0Ioooool6o`000003obMCb?l0003o=eo>00;o=eo>00?o0000od=Yd_m3JM800_m3
JM801?l0003oD77Eoe1aeOl00003oeAfe`05oeQgeol0003oFW_IoeYkfOl000000_mMO=T2o`0000;o
HGoJ0_mSPMX01OmRP]co0000ofB3g?l0003oIHCL00;oIhGL0_l000001OmVQ]go0000o`000?l0003o
JHSN00;o000000?oJXWNofZ9gomZRMl00_l000001Om[R]oo0000ofZ;h?l0003oJX_P00;o000000So
JH_Qo`000?l0003oJ8_Qo`000?mWRn7o0000ofJ;hP?o00000_mVSN<00ol0003oIHcTofF<i002o`00
0004ofF>iOl0003o0000of>>i@?o000000?oHY3Wo`000?l000000omQSnL2o`0000;oGY3Y1?l00004
oebBj`?o00001?mHTnd3o`0000CoDi?^00?o0000oe>Gl?mCUo000_mCUo04o`0000?oCIOb00?o0000
odfKm?m=Vo@00_m=Vo@6o`0000;oAI[c00?o0000odBKm?m4Vo@00_m4Vo@01?l0003o?YGaocjElOln
UO46o`0000?oFXCQ00?o0000ooooooooool0:_ooool9o`0001[ooooo00?o0000ooooooooool08_oo
ool001cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`;o000000Co02>]
o`000?l@@;ko00000_lWDlP01Ol0003o=eo>ocMOc_lgGlko000000?o@fWB00Oo0000oe1aeOm@LMGo
D77Eo`000?mDM]Oo000000;oF7OG00?o0000oeYkfOl000000omMO=T2o`000004of5of_l0003oHh7J
of>1fP?o000000?oIHCLo`000?mWQM`00omXQ]`2o`000003ofR7g_l0003oJHSN00;o000000?oJXWN
ofZ9gol000000_l000001Om[R]oo0000ofZ;h?l0003oJX_P00;o000000KoJH_Qo`000?l0003oJ8_Q
o`000?mWRn42o`000005ofR=hol0003o0000o`000?mVSN<00_l000000omUS>Co0000o`000002ofF>
i@03o`000?mSS^GoHhkU00;o00000_mRT>L01Ol0003oHHoWof6?iol0003oHI;Y00?o00000_mNT>T3
o`0000?oG9;[00?o0000oebEkOl000000_l000001?mHTngo0000oeRFkomHU^l5o`0000GoDiO`00?o
0000oe>Kl_mCVo801?l00005odfKm003o`000?m<X?KoC:3f00;oC:3f1_l00002odBKm003o`000?ln
UO7o?YGa00Co?YGa00?o0000obYmiol000001?l0000dooooo`So00004Oooool3o`0002?ooooo000L
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool01ol004_o0000o`000?l0
8jgo0000oa10__l000000_lWDlP02Ol0003o=eo>ocMOc_lgGlko0000od=Yd_l0003oBV_Bo`000003
oe1ae@;o00000omHMmL2o`0000?oGGcI0_mQO]T01?mQOm[o0000of>1f_mSPMX2ofF2f`;o000000?o
IHCLo`000?mWQM`00_mXQ]`2ofZ7g@;o000000KoJHSNo`000?l0003oJXWNo`000?mZRMl3o`000005
of^:gol0003oJX_Po`000?mZRn000_l000001OmYRn7o0000o`000?mXRn7o000000;oJHgS00?o0000
ofR=hol000000ol000001?mVSN?o0000o`000?mVSnD2o`000005ofF>iOl0003o0000o`000?mTTNL0
0_l000001?mRT>Oo0000o`000?l00004of6Bj@?o00000_mNTn/3o`000003oebBjol0003oG9G]00;o
G9G]0ol00005oeRFk`Co00000omCUo000ol0003oDi_boe>KlP02oe>KlPCo00000om=Vo@00ol0003o
C:3fodbPmP04odbPmP03o`000?m8Y?OoB:Cg00Co00001_lnUO400ol0003o:WgWobYmi`02obYmi`;o
0000>oooool8o`0000_ooooo00?o0000ooooooooool08Oooool001cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1Yooooo`07o`000?l008_o0000o`0S[Ol0003o442no`000002obMC
b005o`000?lgGlko=eo>ocMOc_l000000om:Jm800ol0003oD77Eoe1ae@02oeEce003o`000?mHMmOo
F7OG00;oG7WG00?o0000oeelfOmMO=T00omQO]T2o`000003of>1f_l0003oIH;K00;oIhCK00?oIHCL
o`000?mWQM`00_mXQ]`01?l0003oJXOMof^8gOm[R=d4o`000003ofZ9g_l0003oJXWO00?o000000?o
Jh[Oo`000?l000000_mZRn02o`000003ofV;hOl0003o000000;oJXgR0_mYSN<2o`000003ofR=hol0
003oIhgS00;o000000GoIhoUo`000?mVSnGoIXoUo`000002ofF>i@;o00000_mTTNL2o`000003of:@
iol0003o000000KoHI;Y0_l00003oejCj`?o00001OmLUNd3o`0000?oF9K_00?o0000oeRJlOmHV_40
1?l00005oe>KlP03o`000?mDWoGoE9oe00Go00001_m<X?H00ol0003oB:CgodRTm`02odRTm`Ko0000
0_lnUO400ol0003o:WgWobYmi`02obYmi`03o`000?oooooooooo047ooooo2?l00003ooooo`03o`00
0?oooooooooo027ooooo000Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0JOoo
ool01Ol004_o002;o`000?l08jgo000000;o442n00Go0000obMCb?lWDlSo0000ocMOcP02o`0000Co
BV_B0_l00003oeEce0;o00000omLNML2o`0000?oHGkI0_mTOmT01?mSPM[o0000ofF2fol00002ofN4
f`?o000000GoJ8KLo`000?mZQmgoJXOMof^8g@02ofb9g@;oKH[N1?l000001?m[R]oo0000o`000?m[
R]l2o`000004ofZ;h?l0003o0000o`0000;oK8gR00CoJhgRofZ=h_mZSN;o00000_mYSN<01?l0003o
J8gSo`000?mWSN<2o`000004ofN?iOl0003o0000ofJ?i@?o000000?oIY7Wo`000?l000000_mTTNL2
o`000004of>CjOl0003o0000o`0000?oHI;Y00?o0000of6Ejol000000_l000000omNTn_o0000oenG
k@03o`0000;oG9G]00?o0000oebHkomLV>l00ol000000omHU^oo0000oeRJl@03oeRJl@Co00000omC
Vo800ol0003oE9oeoeBOm@03oeBOm@Ko00000_m<X?H00ol0003oB:CgodRTm`03odRTm`04o`000?lg
Y_?o=jKcocNVl`Go00000olZONL00ol0003oooooooooo`18ooooo`Co00008oooool001cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`1Zooooo`08o`00Bol0003o002;o`000?l08jgo
0000oa10__l00003obMCb004o`000?m2Hlko@V?>o`0000CoBV_B00?o0000oeEce?mELm@00_mELm@0
0ol0003oG7WGoeaie`02oeaie`05o`000?mQO]WoHGkIof5nfOl000000_mTOmT2o`000003ofF2fomW
Q=_oIhCK00?oJHGK00Co0000ofR6g?l0003oJXOM0_m[R=d2ofb9g@03off:g_m]RmkoKH_N00;oKX_O
1ol00002off=h@;o00000_m/SN802?m[SN;o0000ofZ=h_mZSN;o0000ofV=hol0003oJ8gS0_l00000
1?mYT>Go0000o`000?mWSnD2o`000003ofJ?iOl0003o000000;oIY7W0_l00002ofBAi`;o00000_mS
TnT4o`0000CoHIG[0ol00003oenGk@Co00001?mLV>l4o`0000?oF9[a00?o0000oeVMlomIWO<01Ol0
0006oeBOm@04o`000?mDYOOoE:GgoeBUm`So000000?oB:Cgo`000?lgY_<01OlgY_<4o`000003obYm
iol0003ooooo04Wooooo00?o0000ooooooooool08oooool001cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1[ooooo`05o`00Bol008_o0000o`0S[Ol000000_l@@;h2obMCb0;o0000
0om2Hlh01_l0003oBV_BodY[d_m:Jm;oDVkAo`0000?oEG?D00?oFgKDo`000?mLNML00_mLNML01?mQ
O=Oo0000of5nfOl00003ofAof@;oIh;I00CoIH;Ko`000?mWQ=_o00000_mYQM/02_m[Q]coJ8KLo`00
0?mZQmgo0000of^8gOl0003oK8WMo`000?m]R]h2off;gP03ofj;gol0003oKXcO00;o000000CoKXgP
o`000?m]SN3o00000_m]SN42o`0000;oK8gR00Ko0000of^=h_l0003oJXgRo`000?mYSN<2o`000005
ofZ@i?l0003oJI3UofV@iOl000000_mWSnD2o`000003ofNBiol0003o000000;oIY7W0ol000001?mU
U>Wo0000o`000?l00002of>Cj@;o00001OmQUN/2o`0000GoGiO]0ol00003oebHk`03o`000?mLW?7o
G9ca00Go00001OmIWO<6o`0000;oE9oe00?o0000oeBUmomDYOL00omDYOL00ol0003oEJgjoeF]nP02
oeF]nPOo00000_lgY_<00ol0003o08Jho`26^003o`0004Sooooo00?o0000ooooooooool09?ooool0
01cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1[ooooo`05o`00Bol0003o002;
o`000?l08jd00_l@@;h2o`0000;o=eW800Oo0000od9Sc_m2Hlko@V?>o`000?m:Jm;o000000;oDVkA
00Ko0000oeEce?mELmCo0000oe]fe?l00002oeaie`04o`000?mQO=Oo0000o`0000?oI7oI00?o0000
ofN2fOmWP]T00_l000001OmWQ=_oJHGKofV5fol0003oJhKL00;o000000?oJXOMo`000?l000000_m/
RMd2o`000005off;g_l0003oKX_Oo`000?m^S=l00_l000001?m^SN3o0000off=h?l00002off=h@;o
00000_m/SN801Ol0003oJhgRo`000?mZSN;o000000;oJi3T00Go0000ofZ@i?l0003o0000ofV@i@02
o`000003ofN?iOl0003o000000;oIi;W00Co0000ofJAiomVTNOoIY7W0_l00003ofFDj@?o000000Co
I9K[o`000?l0003o00000_mQUN/00ol0003oHYS]o`000002o`0000;oGiO]00?o0000oenJkomOV^l0
1Ol00005oebLl@Co00000omIWO<00ol0003oFZ;eoeZRm@02oeZRm@So000000?oE:Ggo`000?mE[OX0
1OmE[OX01?l0003oDk[koe>jnomC^_/;o`0004Cooooo00?o0000ooooooooool09Oooool001cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`1[ooooo`;o001;0_l008/2o`0S[@03o`00
0?lYBl3o000000?o=eW800Go0000od9Sc_m2Hlko@V?>o`000004oe9^d@03oeEce?l0003oFgKD00;o
FgKD00?oG7WGo`000?mQO=L00_mQO=L2o`0000;oI7oI00?o0000ofN2fOmWP]T00_mZPmX01OmWQ=_o
0000ofV5fol0003oJhKL00?oKHSL00co0000of^8gOl0003oK8WMo`000?m]R]ko0000off;g_l0003o
KX_Oo`000?m^S=l2o`000004ofj=h?l0003oKHgPo`0000;oKHgQ0_l00002ofb=hP03o`000?m[SN;o
000000;oKI3T0_m[T>@2o`000004ofZ@i?l0003oJI3UofV@i@;o000000CoJI;Wo`000?l0003oIi;W
0_l000000omVTNOo0000ofNDj@02o`0000?oIICY0_l00003ofBFj`Co00000omRV>d4o`0000GoGi[_
1?l00003oebLl@03o`000?mNWo?oGYoc00Go00001_mJX_D00ol0003oGJKgoefVm`02oefVm`Oo0000
0_mE[OX00ol0003oDk[koe>jn`04oe>jn`04o`000?ln`];o?/;Bock2dPOo0000?oooool00ol0003o
ooooooooo`0Vooooo`007?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06gooooo
00?o0000o`00Rol008/00_l08jd01?l0003o:D_0obU;`?l00003ocMIb005o`000?m2Hlko@V?>odiX
c_l000001?mBK]400ol0003oFgKDoe]fe002oe]fe0;o00000_mQO=L2ofEne`03o`000?mTOmWo0000
00;oIh;I00?o0000ofZ3f_mZPmX00_l000000omYQM_o0000of^6g002off8g0;oKXWM0ol000001?m]
R]ko0000off;g_m]Rmh2o`000008ofj<gol0003oKXcOo`000?m^SN3o0000off=h?l00002off=h@;o
000000?oK8gRo`000?l000000_m^T><2off@i00:o`000?m[T>CoJi3To`000?mZT>Co0000ofV@iOl0
003oJi?Vo`0000;oJI;W00?o0000ofNBiomWT^L00_l00003ofNDj@05o`000?mUU>WoIICYo`000?mV
Un/00ol00003ofBFj`;o00001OmRV>d3o`0000CoGi[_00?o0000of6NlOmQW_400ol000000omLW?7o
0000oejOl`04oejOl`Co00001?mJX_D00ol0003oGJKgoefVm`03oefVm`03o`000?mT[?WoI:ci00;o
I:ci2?l00002oe>jn`03o`000?ln`];o?/;B00Co00000_n>^oD00ol0003oooooooooo`0looooo`03
o`000?oooooooooo02Oooooo000Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
KOooool00ol0003o0023o`000002o`000005oa<g]?l0003o:D_0obU;`?l000000olgFLP01Om2Hlko
0000odiXc_m>J<ko000000?oDVkA00?oFW?Bo`000?mKM]@00_mKM]@2of5je@03o`000?mQO=Oo0000
00?oIGkG00Co0000ofN2fOmWP]Wo00000_mZPmX2ofb5fP04ofV5fol0003oJhKLo`0000;oKHSL00Co
KXWMofn:gOm_R]goKh[M1Ol000002om^Rmoo0000ofj<gol0003oKXcOo`000?m^SN3o0000off=h?l0
003oKHgQ00?o00000om_T><2ofj@h`07o`000?m]T>CoKI3To`000?m[T>Co0000ofZ@i002o`0000;o
Ji?V0_l000001OmYT^Oo0000o`000?l0003oJIGY00;o00000_mWU>T3o`0000CoIYO[1?l000001?mU
VNgo0000o`000?l00002of:Hk@03o`000?mSW>ooHic_00Co000000?oGi[_o`000?mQW_400omQW_44
o`0000CoGYoc00?o0000oenSmOmOXoD01Ol00006oefVm`03o`000?mT[?WoI:ci00CoI:ci00?o0000
og:cnOmb/oT00_mb/oT5o`0000OoS[_e00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0X
ooooo`006oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06gooooo00Go001Fo`00
0?l0003o01ZQo`000002oa<g]004o`000?lYBl3o:D_0o`0000?o=eW800Go0000odiXc_m>J<koCVS>
o`000002oe9^d@03o`000?mJLm;o000000;oFgKD00Go0000of5jeOmQN]GoHGcGo`000003ofEne`04
ofV1f?l0003oIh;Io`0000;oJX?J00?o0000ofb5f_m/QMX00ol00002off8g006o`000?m^RMgoKh[M
ofn:gOl0003oL8_M0omaS=h;o`0000;oL93R00?o0000ofn@h_m_T><00_m_T><01ol0003oKY3Sofj@
hol0003oKI3To`000?m[T>@00_l000000om/TnKo0000o`000002of^CiP03o`000?mYT^OoJI;W00;o
00000_mYUNT2o`0000;oIiCY0_l00006ofJGj`;o00000omUVNd3o`0000KoHic_0ol00004of6Nl@03
o`000?mRX_?oHZ;c00Co000000?oGYoco`000?mOXoD01?mOXoD6o`000003oefVmol0003oI:ci00Ko
I:ci00?o0000og:cnOmb/oT01?mb/oT00ol0003oS[_eohjkm@06ohjkm@03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0:Oooool001_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1^ooooo`;o000000Ko0023o`000?l06Z7o0000oa<g]?l00002obU;`005o`000?lgFLSo=eW8
ocMIb?l000001?m>J<h00omBK]7o0000oeYcdP02oeYcdP03oe]fe?l0003oHG[E00?oHG[E0_l00002
ofEne`04o`000?mYPMSoIh;Io`0000;oJX?J00?o0000ofb5f_m/QMX00om_Qm/01Ol0003oKHSLo`00
0?m^RMgo000000;oKh[M00go0000og2;gOmaS=koLHcNo`000?maSMoo0000og6>gol0003oLHkPo`00
0?maSn3o000000?oLHoQ0_m`T>800ol0003oKi3Ro`000002ofn@h`06o`000?m^T>?oKY3So`000?m]
T>Co00000_m^TnD01?l0003oK9?VofbCi_l00002of^CiP04o`000?mYT^Oo0000of^Fj0;o00000_mY
UNT3o`000004ofVHjol0003o0000o`0000?oIYO[00?o0000ofRJkOl000000_l00002ofFIk@?o0000
1OmSW>l00ol0003oI9oao`000002o`000003of6NlOl0003oHZ;c00GoHZ;c1?l00004oenSm@03o`00
0?mSYoKoHjOf00;oHjOf1ol00002ofB/n@03o`000?mb/oWoL[?i00GoL[?i00?o0000ohjkmOn>^oD0
1On>^oD00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02[ooooo000Kooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0K_ooool01?l0023o0000o`00Pol00002o`0JX@03o`00
0?lC=kCo000000;o:D_000Go0000ocMIb?l0003oBF79o`000004odiXcP03o`000?mJLm;oFW?B00;o
FW?B0_l00003of5je@;oIggE00?o0000ofEneol000000_mYPMP2o`0000;oJX?J00?o0000ofb5f_l0
00000_m_Qm/2og69f`06off8g?l0003oKXWMo`000?m_R]go00000_m`Rmd2og6<gP09o`000?maSMoo
0000og6>gol0003oLHkPo`000?maSn3o000000?oLHoQ0_m`T>800ol0003oKi3Ro`000002ofn@h`04
o`000?m^T>?o0000o`0000;oKi?U0_m^TnD2o`000004ofbCi_l0003o0000of^CiP;o00000om[U^P0
1?l0003oJIGYofVEjOmYUNT2o`0000?oJIS[1?l00004ofRJk@?o00000_mVWNl4o`000003of>Lkol0
003oI9oa00?oI9oa0ol00006of:Rl`03o`000?mSYOGoHjGe00Co000000?oGj?eo`000?mSYoH01?mS
YoH00ol0003oJ:SfofRXmP02ofRXmPSo00000_mb/oT00ol0003oS[_eohjkm@02ohjkm@Go0000>?oo
ool00ol0003oooooooooo`0[ooooo`006oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo06kooooo00Oo000Po`00E_l0003o0023o`000?l06Z7o000000;o4cNd00Co0000obU;`?lYBl3o
00000om9HLT01_l0003oCVS>odiXc_m>J<koFVo>o`0000?oFW?B0_mSN=801?l0003oHG[Eof5jeOl0
0002ofMme@04ofEneol0003oJH7HofV1f0;oKHCH00Go0000ofZ3f_l0003oK8GJo`000003ofn7f`;o
LHWK0ol00002ofn:g@05o`000?m`Rmgo0000og6<g_l000000_maSMl01ol0003oLHkOo`000?maS^3o
0000og6?h?l000000omaSn401_l0003oL93Ro`000?m_T>;o0000ofn@h`;o00000om`Tn@2ofnCi@04
o`000?m^TnGoKY?Uo`0000;oK9?V0_l000000om]U^So0000o`000002of^Fj0;o000000?oJIGYo`00
0?m[VN/00ol00003ofVHj`;o00001_mXV^d2o`0000CoIYg_0ol00005ofBOl@?o00001?mRX_<00ol0
003oHjGeof>Um@04of>Um@Co00001?mSYoH00ol0003oJ:SfofRXmP04ofRXmP03o`000?maXo3oLJ?`
00;oLJ?`1ol00004og^Ag@03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;?ooool001_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1^ooooo`05o`008?l005Ko0000o`00
Pol000000_l06Z400ol0003o4cNdo`000002obU;`003o`000?m9HLWoBF7900;oBF7900Ko0000odiX
c_m>J<ko0000oeY_c_l00002oeYcdP06o`000?mSN=;oHgSBo`000?mQN]Go00000omWOMD2o`000003
ofV1f?l0003oKHCH00;oKHCH0_l000001_m/QM[o0000ofn7fom_Qm_o0000og69f`?oLX_L0ol00002
og2;g@05o`000?maS=ko0000og6=gol000000_maS]l01Ol0003oLHkPo`000?maSn3o000000?oLHoQ
00Go0000og2@h_l0003oKi3Ro`000002og:Ci005o`000?m`TnCoL9?Tog2Ci?l000000_m_TnD01ol0
003oKY?Uo`000?m/TnKo0000ofnFj?l000000_m]U^P2o`0000;oJiKX0_l00004of^Ij`Co000000Co
JY_]o`000?l0003o00000omXV^d00ol0003oJIk_o`000002o`0000;oIYg_00?o0000ofRQlOl00000
0_l00002ofBOl@03o`000?mVXo?oIZ?c00Co000000?oHZ;co`000?mSYOD01OmSYOD00ol0003oIJSf
ofFXmP05o`0000OoJ:Sf00?o0000og6Sl?maXo001?maXo000ol0003oNi7Mog^Ag@05og^Ag@03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0;Oooool001_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1`ooooo`04o`00E_l0003o0023o`0000;o01ZQ00Oo0000oa<g]?lC=kCo
:D_0o`000?m3FL?o000000CoBF7900?oCVS>o`000?mJKlh00_mJKlh00ol0003oFW?Bo`000003of=h
dP03of5jeOl0003oIggE00;oIggE0_m/PMH00ol0003oJH7Ho`000002off4f0;oL8KI00GoK8GJo`00
0?m_Qm_oKhOKo`000002og69f`;oLX_L0omcS=`5o`0000;oLHgO00So0000og6>gomaS]oo0000og6>
h?l0003oLHoPo`0000;oLHoQ1?l00002og>Ch`;oLY?T00Go0000og2Ci?m`TnCoL9?To`000002ofnC
i@04o`000?m^TnGo0000o`0000;oKiKX0_l00002offFj0?o000000CoKIWZo`000?l0003o00001?m[
VN/2o`0000?oJY_]1?l00004ofVNk`?o00001?mXXO44o`0000GoIZ?c1?l00004of>Um@03o`000?mU
Z?KoIJSf00CoIJSf1_l00002ofRXmP03o`000?maXo3oLJ?`00GoLJ?`00?o0000og^AgOmkTMd01Omk
TMd00ol0003oooooooooo`0aooooo`;o0000<?ooool001_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1`ooooo`05o`000?l005Ko0000o`00Pol000000_l06Z401?l0003o4cNdoa<g
]?l00002od=I``03o`000?m9HLWoBF7900;oBF7900?o0000oeY_c_mJKlh00_mJKlh00omJLm;o0000
of=hdP03of=hdP;o00000_mWOMD01Ol0003oK87Fofb1e_mYPMSo000000;oKHCH00?o0000og26fOm`
Q]T00ol000001?m_Qm_o0000og69fol00002og:;g0;oLhcL00?o0000ogB=gOmdSMd00_meS]h<o`00
0005ogBBh_l0003oLi;Rog>Bh_l000000_mcTn<2og:Ci006o`000?m`TnCoL9?Tog2Ci?l0003oKi?U
0_l00002og2Gi`;o00000_m_U^P2o`0000;oKIKX0_l00003offIjP?o000000?oJiW[o`000?m]W>d0
0_l00004ofZKk@;o00001OmYW^l2o`0000KoJ:7a0ol00004ofJSl`03o`000?mWYoGoIjOe00Co0000
00?oHjGeo`000?mUZ?H01OmUZ?H00ol0003oIJWgofFYm`02ofFYm`Ko00001?maXo000ol0003oNi7M
og^Ag@05og^Ag@03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool001_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1`ooooo`05o`008?l005Ko0000o`00Pol00000
0ol06Z42oa<g]005o`000?m3FL?o@eW3od=I`ol000000om9HLT00omJJl[o0000oeY_cP03oeY_cP03
o`000?mSN=;oHgSB00;oHgSB0_mZO=<00ol0003oIggEo`000003ofb1eP;o00000_m]Q=P00ol0003o
L8KIog>8fP02og>8fP;o000000GoLHWKo`000?mbRmcoLX_Lo`000002og><g005o`000?mdSMgoM8gM
ogF>g_l000000_meSml01_l0003oMI3OogF@gol0003oMI7Po`0000;oMI;Q00Co0000ogBBh_mdT^;o
00000_mcT^801_l0003oLi?Sog>Chol0003oLY?To`0000?oL9?T00Co0000og:Gi_mbUnKoLYOV0om`
UnL02?l0003oKiKXofnFj?m_U^So0000offFj?l0003oKi[Z0_l00004offIjP;o00000om]W>d01_l0
003oJY_]ofZKkOmZVngo0000ofbOk`?o00000_mYW^l00ol0003oJj;ao`000002o`0000?oJ:7a00?o
0000ofVTlomYY?<01?l000000omVXo?o0000ofNWm@04ofNWm@Ko00000omUZ?H00ol0003oIJWgofFY
m`04ofFYm`03o`000?mRY?GoHZCe00Go00001omkTMd00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo037ooooo000Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0L?ooool0
0ol0023o001Fo`00EP02o`00P`?o01ZQ00Co4cNdo`000?lmC[_o00000om3FL<01_l0003oBF79odUQ
bOl0003oFV_:o`0000?oFVo>00?oIGK?o`000?mSN=800_mSN=801Ol0003oJWcCofYldomWOMGo0000
00?oK87F0_maQ=L00ol0003oKHCHo`000002og26f@?oLhSJ0_meR]X01omaRM_o0000og:;g?mbRmco
0000og><g?l000000_mdSMd00ol0003oMHkNo`000002ogF?g`06o`000?meT=ooMI3Oo`000?meTN3o
00000_meT^401?l0003oM9;RogBBh_l00002og>BhP08o`000?mcTn?oLi?So`000?mbTnCo0000og2C
i?l00002og>GiP?oLYOV0_l000001?m`UnOo0000o`000?m_U^P3o`0000?oKi[Z00Ko0000offIj_m]
VN[oKIWZo`000?m_WN`2o`0000;oKIc]0ol00005ofbOk`?o00001?m[X_44o`0000KoJJCc1?l00004
ofNWm@03o`000?mWZoOoIj_g00;oIj_g1_l00004ofFYm`03o`000?mRY?GoHZCe00CoHZCe1?l00004
og^Ag@03o`000?oooooooooo02kooooo00?o0000ooooooooool0<_ooool001_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1aooooo`06o`008?l005Ko001Fo`000?l008?o00000ol0
6Z401?l0003o?Djkoce>^ol00003od=I``03odUQbOl0003oFV_:00;oFV_:00So0000oeY_c_mJKlko
0000ofEfcol0003oHgSBo`0000CoJWcC0_l00002ofb1eP04o`000?maQ=OoLHCGog64e`;o000000?o
L8KIo`000?mcR=X00_mcR=X2ogF:fPCo00000_mcS=`01_l0003oM8gMogB=gOl0003oMHkNo`0000;o
MHoO00Ko0000ogF@gomeT=oo0000ogFAh?l00002ogFBh@04o`000?mdT^;oM9;Ro`0000;oLi;R00Ko
0000og>ChomcTn?o0000og:Ci?l00004og>GiP05o`000?mbUnKoLYOVog:Gi_l000000_m`UnL01?l0
003oLI[Yog6JjOmaV^T2o`0000;oKi[Z0ol00004ofnMk004o`000?m]W>goKIc]offLk@;o00001_m/
Wnl2o`0000KoJj;a0ol00005ofVTl`03o`000?m[Z?GoJjSe00Co000000?oIjOeo`000?mWZoL01OmW
ZoL00ol0003oI:ojofB_nP04o`000003ofFYmol0003oHZCe00GoHZCe00?o0000oeBBkOmDT^d01?l0
00000omkTMgo0000ooooo`0]ooooo`03o`000?oooooooooo03?ooooo000Jooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0LOooool01?l0023o001Fo`00E_l00002o`00P`?o01ZQ00Co
0000oce>^olmC[_o00001?m3FL<00ol0003oFV_:oeY[bP02oeY[bP03oeY_c_l0003oIGK?00;oIGK?
00?oHgSBo`000?mZO=<00omZO=<2og21e003o`000?m/PMKo000000?oLHCG0_mdQmL2o`0000?oLhSJ
00?o0000ogF:f_mgS=/00_mgS=/4o`0000;oM8gM00?o0000ogF>g_l000000_meSml01?l0003oMI3O
ogF@gol00002ogFAh004o`000?meT^7oMI;Qo`0000;oM9;R00?o0000og>Bh_l000001?l00002ogBF
i@03o`000?mcUnKoLiOV00;oLiOV00So0000og:Gi_mbUnKo0000og2Giol0003oLi[Yo`0000?oLI[Y
00Co0000ofnJj_m_V^[oKi[Z0_l00004ofnMk0;o000000?oKIc]o`000?m_X>h00ol00003ofbOk`03
o`000?m^Xo7o000000;o00000om[X_400ol0003oKJGcoffUl`04o`000003ofVTlol0003oJjSe00Go
JjSe1?l00004ofN[m`03o`000?mT[o[oI:oj00CoI:oj1?l00004of:Tm@03o`000?mDT^goE9;]00Co
E9;]0_l0000]ooooo`03o`000?oooooooooo03Cooooo000Jooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0LOooool2o`0080;o001F0_l008<2o`0JX@03o`000?lf@k;o000000;o?Djk
00Go0000od=I`om3FL?o@eW3o`000005oeY[bP03o`000?mUM/ooIGK?00;oIGK?0_l00003ofYld`05
o`000?m`PMCoL87Dofb1e_l000000omaQ=L01?l0003oM8OGogB7eomdQmL2o`000004og>8f_l0003o
MH[JogF:fP?oMhcK0omhS]`6o`0000;oMHoO00Co0000ogF@gomeT=oo00000_meTN001Ol0003oMI;Q
ogFBhOl0003oM9;R00;o00000_mgU^<01?l0003oMYKTogJFi?mfU^@2ogBFi@;o00000omcUnH01?l0
003oLYOVo`000?l00003og>Jj@;o00000_maV^T2o`000003ofnJj_l0003oLIg/00?o00000om_WN`2
o`0000CoKj3^1?l00004ofjSl@Co00001_m]YO<4o`0000GoJjSe00?o0000off]mom][OL00ol00000
0omWZoOo0000ofB_nP06ofB_nP03o`000?m@/_[oD;;j00Co000000?oHZCeo`000?mDT^d01OmDT^d0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Gooooo000Jooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0Loooool00ol0023o001Fo`00EP02o`00P`05o`000?l06Z7o0000
ocI3/_l000000olmC[/00ol0003o@eW3od=I``02o`0000CoFV_:00?oJ7C<o`000?mUM/l00_mUM/l2
ofild004o`000?mZO=?oJWcCo`0000?oL87D0_l00002og64e`04o`000?mdQmOoM8OGogB7e`;oMhWH
00Go0000og>8f_l0003oMH[Jo`000003ogN<f`;oN8kL00Co0000ogV?gOmiSmgo00000_miTMh=o`00
00;oN9GS00Co0000ogNFhomgU^?o00000omfU^@01?l0003oM9KUogBFiOl00003og>GiP04o`000?md
V^SoM9[XogBJj0CoLi[Y00Co0000og6JjOmaV^WoLI[Y0_l00004og6Mk0;o000000?oKig/o`000?ma
X>h00ol00004ofnPkP?o00001Om^Xo43o`0000GoKJGc00?o0000ofnYm?m_ZO@01?l000000om[Z?Go
0000off]m`04off]m`Ko00000omT[oX00ol0003oD;;joe2bnP04oe2bnP?o00001OmDT^d00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo03Kooooo000Jooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0Loooool01?l0023o001Fo`00E_l00002o`00P`05o`000?lf@k;o=T>bocI3
/_l000000_lmC[/00ol0003o@eW3o`000002oeaWa@07o`000?mJJl[oFV_:oeY[b_l0003oJ7C<o`00
0002ofEfc`06o`000?m^O=3oKWc@o`000?mZO=?o00000om`PM@2ogJ5e@04o`000?maQ=OoLHCGo`00
00;oM8OG00Oo0000ogN9f?mgRMSoMhWHo`000?meR][o000000?oMhcK00Co0000ogR>g?mhS]co0000
0_miSmd00ol0003oNI7No`000002ogVBg`04o`000?miTn3oNI?Po`0000;oNICQ00Go0000ogRDh_mh
U>;oN9CRo`000002ogREh`04o`000?mgU^?oMiKSo`0000?oMYKT00Ko0000ogBFiOmdU^Go0000og>G
i_l00002ogJJi`?oM9[X0_l00002og>Jj@03o`000?maV^Wo000000;oLig[0ol00003og6Mk0;o0000
1?maX>h3o`000004ofnPk_l0003oLJ?`og6Sl0?o00000_m^Xo400ol0003oL:Kbog2VlP04o`000003
offUlol0003oKjWd00GoKjWd1?l00004off]m`03o`000?m]]?[oKKCj00;oKKCj1_l00005oe2bnP03
o`000?l0QkSo000000;o00000omDT^d00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oo
oooo000Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Loooool01?l0023o001F
o`00E_l005H2o`00P`05o`000?lf@k;o=T>bocI3/_l000000olmC[/00om3FL?o0000oeaWa@02oeaW
a@03o`000?mJJl[o000000?oJ7C<00?o0000ofEfcol000000om^O=000omZO=?o0000og21e002og21
e006o`000?mfQMGoMXGEogJ5eOmaQ=Oo00000_mdQmL01?l0003oMhWHogN9f?mgRMP2ogZ<f@05ogF:
f_l0003oMhcKogN<fol000000_mhS]`01?l0003oNHoMogV?gOl00002ogVAgP04o`000?miT]ooNI;O
o`0000;oNI?P00Co0000ogVDhOmiU>7o00000omhU>801?l0003oN9GSogREhol00002ogNFh`06o`00
0?mfU^CoMYKTogJFi?l0003oM9KU0_l00004ogJJi`06o`000?mdV^SoM9[XogBJj?l0003oLi[Y0_l0
0006og>Mj`;o000000?oLIg/o`000?mcXNd00_l00005og6PkP;o00001OmaXo03o`0000KoL:Kb1?l0
0005ofnYm003o`000?mc[OKoLjgf00?o000000?oKJggo`000?m]]?X01_m]]?X00ol0003oIl7nofO1
oP04o`000003oe2bn_l0003o08Nh00?o08Nh1?l0000Xooooo`03o`000?oooooooooo03Sooooo000J
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Loooool01?l0023o001Fo`00E_l0
05H2o`00P`03oc0fYol0003o=T>b00;o=T>b00Go0000oce>^olmC[_o?Djko`000004oeaWa@03oeY[
b_l0003oJ7C<00?oJ7C<00?oIGK?o`000?m^O=000om^O=02o`0000;oL87D00?o0000ogJ5eOmfQMD0
0_mfQMD2o`0000;oM8OG00Co0000ogN9f?mgRMSo00000_mjS=T3o`000005ogN<fol0003oN8kLogR>
g?l000000_miSmd01?l0003oNI7NogVAg_l00002ogVBg`04o`000?miTn3oNI?Po`0000;oNICQ00Go
0000ogRDh_mhU>;oN9CRo`000002ogREh`04o`000?mgU^?oMiKSo`0000;oMYKT0_l00003ogRJiPCo
MY[W00Go0000ogBJj?mdV^SoM9[Xo`000003ogFMjP?o00001?mcWN/2o`0000?oLj7]0_l00003og6P
kP03o`000?mcY?3o000000;o00000omaXo000ol0003oLjObo`000002o`0000CoL:Kb00?o0000og>Y
lomcZO<00ol000000om_ZOCo0000og>]mP05og>]mPKo00000om]]?X00ol0003oIl7nofO1oP04ofO1
oP[o00009oooool00ol0003oooooooooo`0iooooo`006_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo07Cooooo0_l00202o`00EP;o000000?o<3JWo`000?lf@k800olf@k83oce>^`03
o`000?mLIlGoG6O500?oG6O500?o0000ofQdc?mXM<`00omXM<`2o`0000?oKWc@0_mfPM42o`000003
og21e?l0003oMXGE00;oMXGE0_mjR=H00ol0003oM8OGo`000002ogN9f004o`000?mjS=WoNXcIo`00
00;oNhkJ1Ol00002ogV?g@04o`000?miTMkoNI7No`0000;oNI;O00Go0000ogVCh?miTn3oNI?Po`00
0002ogVDh@05o`000?mhU>;oN9CRogRDh_l000000_mhUN<00ol0003oMiKSo`000002o`0000?oNIWU
0omhV^H2o`0000;oMY[W00?o0000ogBJj?l000000_mgWNT00ol0003oMIgZogFMjP02ogFMjP;o0000
00CoLig[o`000?mfXNgoMZ7]0_l00003og>Qk@?o00001OmcY?03o`0000GoLjOb1?l00006og>Yl`Co
00001Omc[OH00ol0003oNK7fogVamP02ogVamPSo00000omW`Oh01?l0003o>[oAocZodOlj_m45o`00
02Kooooo00?o0000ooooooooool0>_ooool001[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1dooooo`;o000P0ol005H01?l0003o<3JWoc0fYol00003ocI3/P03o`000?lmC[_o?Djk
00;o00001?mLIlD00om_M<Oo0000ofQdc003ofQdc0;oM7c=00Co0000ofild?m^O=3o00000omfPM40
0om`PMCo0000ogJ5e@02ogJ5e@04o`000?mjR=KoNXSFogZ8eP;o00000_mgRMP01?l0003oNXcIogZ<
fOl00002og^>fP03o`000?mlT=_oO93K00So00000_miT]l01Ol0003oNI?PogVCh?miTn3o000000;o
NICQ00?o0000ogRDh_mhU>801Ol00003ogZIi0CoNIWU00Ko0000ogRJi_mhV^KoN9[Vo`000?mfV^L2
o`0000GoMigY00?o0000ogFMj_meWNX00_meWNX00ol0003oMZ7]ogJQk@03ogJQk@03o`000?mcXNgo
Lj7]00;oLj7]0_l00006og>Tl0;o00001omcYo82o`0000KoLjWc00?o0000ogJ/m?mf[?@01?l00000
0omc[OKo0000ogVamP06ogVamP03o`000?n7]OCoQkGd00;oQkGd1ol00004oingj@03o`000?oooooo
oooo02;ooooo0_l0000mooooo`006_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
07Cooooo0_l00203o`00EP04o`000?l`=ZOo<3JWo`0000Co=T>b00Go?Djko`000?mPI<3oH6C0o`00
0003oeaWa@03o`000?m_M<Oo000000?oJ7C<00Ko0000ogAlcOmdO<go0000ofild?l00004ogJ1d@;o
00000_mfQMD01?l0003oNXSFogZ8e_mjR=H2ogf;e`03o`000?mgRMSo000000;oNXcI00Go0000og^>
f_mkS][oNhkJo`000002ogb@f`04o`000?mmT]goOI;Mo`0000;oOI?N3Ol000000omlUn;o0000og^H
h`02og^Hh`05o`000?mjVNCoNYWTogZIi?l000000omiVND01Ol0003oN9[VogRJi_mhV^Ko000000?o
NIgY00?o0000ogNMjOmgWNT00_mgWNT2o`000005ogFMj_l0003oN:7/ogRQk?l000001?mfXNd2o`00
0004og>QkOl0003oMZC_ogJTk`?o00000omcY?000ol0003oMJOao`000002o`0000CoLjOb00?o0000
ogBZlol000000_l00003og>Yl`03o`000?mf[?CoMZcd00CoMZcd1?l00005ogVamP03o`000?n7]OCo
QkGd00GoQkGd00?o0000oingjOnO]nT01OnO]nT00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo03gooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0MOooool01_l0
023o001Fo`00E_l0003o:bVKo`0000;o<3JW00Ko0000ocI3/_lf@k;o=T>boce>^ol00003of1T`004
o`000?mLIlGoG6O5o`0000;oKgC700Co0000ofQdc?mXM<co00000omdO<d00om^O=3o0000ogJ1d@03
ogJ1d@;oNhKB00Co0000ogJ5eOmfQMGo00000_mjR=H01?l0003oOH_Gogf;eommRmL2o`0000;oNXcI
00Co0000og^>f_mkS][o00000omlT=/01?l0003oOI;MogfBgOl00002ogfCgP04o`000?mmU=ooOICO
o`0000?oOIKP00Go0000ogfGhOmmUn7oOIOQo`000002ogbGhP05o`000?mkV>?oNiSSog^Hhol00000
0omjVN@01ol0003oNIWUogVIiOmiVNGo0000ogRJi_l000000_mjWNP01Ol0003oNIgYogVMjOmiWNWo
000000CoMigY00?o0000ogRQk?mhXN`00omhXN`00ol0003oMZ7]ogJQk@02ogJQk@03o`000?mfY>oo
MZC_00CoMZC_0ol00005ogFWl@Co00001OmdZ_<3o`0000SoMZcd00?o0000ogb[lOmlZo401?l00000
0omi/OKo0000ohNem006ohNem003o`000?nO]nWoWkOY00GoWkOY00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0nooooo`006_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07Kooooo00Ko000Po`00E_l005Ko0000ob/YVol00002oc0fY`03o`000?lf@k;o=T>b00;o=T>b00Oo
0000of1T`?mPI<3oH6C0o`000?mLIlGo000000CoKgC700?o0000ofQdc?l000001?mdO<d2o`0000?o
MX7A00Ko0000og^6d_mkQ];oNhKBogJ5eOl00002ogZ8eP04o`000?mmRmOoOH_Gogf;e`;oOhkH0ol0
0003og^>fP04o`000?mlT=_oO93Ko`0000?oOI;M00Co0000ogfCg_mmTmko00000_mmU=l01Ol0003o
OIKPogfFh?mmU^3o000000?oOIOQ00Co0000ogbGh_mlUn;o00000omkV><01Ol0003oNYWTogZIi?mj
VNCo000000;oNIWU0_l00004ogZMj004o`000?miWNWoNIgYogVMj@;o000000GoMigYo`000?mjXN_o
NZ7[o`000004ogRQk0;o000000CoMZ7]o`000?mhY>koN:C^0ol00004ogJTk`;o00001omeYo42o`00
00KoM:[c0ol00006ogJ/m003o`000?mlZo7oO:_a00CoO:_a1?l00004ohNem003o`000?nO]nWoWkOY
00GoWkOY00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`006Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo07Kooooo0_l002001?l005Ko0000ob/YVol00002oc0f
Y`03o`000?lf@k;o=T>b00;o=T>b00?o0000of1T`?mPI<000_mPI<02o`0000GoKgC700?oJ7C<o`00
0?mdO<d00omdO<d2ogb3c`04o`000?mfPM7oMX7Ao`0000CoNhKB0_l00002ogZ8eP04o`000?mmRmOo
OH_Gogf;e`CoOhkH1?l00003ogb@f`04o`000?mmT]goOI;Mo`0000?oOI?N00Co0000ogfDgommU=oo
00000ommU^001Ol0003oOIOQogfGhOmmUn7o000000;oO9OR00Go0000og^HhomkV>?oNiSSo`000002
ogZIi0?o00000omlW>L4ogZMj004o`000?miWNWoNIgYogVMj@;o00001OmjXN/00ol0003oN:7/ogRQ
k002ogRQk003o`000?mhY>koN:C^00CoN:C^0_l000001?mfY>oo0000ogRXlOmhZ?43o`0000CoMJOa
00?o0000ogJ[lol000000_l00003ogBZl`03o`000?mf[?CoMZcd00Co000000?oMZcdo`000?mlZo40
1omlZo400ol0003oQZCWohJTi`03o`000003ohNem?l0003oWkOY00KoWkOY00?o0000ooooooooool0
7oooool00ol0003oooooooooo`10ooooo`006Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo07Kooooo0_l002001Ol0003o:bVKob/YVol[:I_o000000;o<3JW00Ko0000ocI3/_lf@k;o
0000ofQS^_l00004of1T`003o`000?m_M<OoKgC700CoKgC700?o0000ogAlcOmdO<d00_mdO<d01_l0
003oO8??ogb3col0003oMX7Ao`0000CoNhKB0_moR]@00ol0003oNXSFo`000003ogf;e`04o`000?mo
S]SoOhkHogn>f0?oP93J1Ol00003ogfBg@04o`000?mmTmkoOI?No`0000;oOICO00Go0000ogfFh?mm
U^3oOIKPo`000004ogfGh@04o`000?mlUn;oO9ORo`0000;oNiSS0ol00003ogfLiP04o`000?mlW>Oo
O9cWogbLi`;o00000_mjWNP00ol0003oNIgYo`000003og^QjP03o`000?mjXN_oNZ7[00;oNZ7[0_l0
00001?mhXNco0000ogZTkOmjY>d2o`0000GoN:C^00?o0000ogRXlOmhZ?401?mhZ?42o`000003ogFW
lOl0003oMZ_c00CoMZ_c0ol00007ogJ/m0Co00001_mlZo400ol0003oQZCWohJTi`03ohJTi`[o0000
8?ooool00ol0003oooooooooo`11ooooo`006Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07Oooooo0_l002001Ol0003o:bVKob/YVol[:I_o000000;o<3JW00Co0000ocI3/_lf@k;o
00000_mXHkX01_l0003oH6C0of1T`?mPI<3oN7G3o`0000GoKgC700?oO7g9o`000?mdO<d00_mdO<d0
1_l0003oO8??ogb3comlPlooMX7Ao`0000CoNhKB00Co0000ogn:e?moR]CoOh[D0_l00002ogf;e`03
o`000?moS]SoOhkH00;oOhkH0on0T=X00ol0003oPI;Koh6Bf`09o`0000;oOICO00Go0000ogfFh?mm
U^3oOIKPo`000002ogfGh@Oo00000_mnVn@00ol0003oOIcVogfLiP02ogfLiP03o`000?mlW>OoO9cW
00;oO9cW00Co0000ogZMj?l0003o00001OmkXNX2o`0000CoNZ7[00?o0000ogZTkOmjY>d00omjY>d0
0ol0003oN:C^ogRTkP02ogRTkP03o`000?mjZ?3o000000;o00001?mhZ?43o`0000KoMZ_c0ol00006
ogJ/m003o`000?mf[?CoMZcd00Co000000?oO:_ao`000?n6Y>L01_n6Y>L00ol0003oSi3Aohn@d@05
ohn@d@03o`000?oooooooooo01gooooo00?o0000ooooooooool0@_ooool001Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1gooooo`;o000P00Go0000ob/YVol[:I_o:bVKo`000003
oc0fY`;o=T>b00Co0000ofQS^_mXHk[o00000omPI<000ol0003oN7G3o`000004ofmda`03o`000?ml
OLWo000000;oM7c=00?o0000ogb3comlPll00_mlPll2o`0000?oNhKB00Co0000ogn:e?moR]CoOh[D
0_n2SMH2o`000003ogf;eol0003oOhkH00;oOhkH00Go0000oh2@f_n0T=[oP93Jo`000002oh6Bf`05
o`000?n2U=coPYCLoh:Dg?l000000_n2U]h:o`0000;oP9[R00Go0000ognJhomoV^?oOi[So`000003
ogjKi003o`000?mmW>KoOIcV00;oOIcV00Co0000ogbLiomlW>OoO9cW0_l00003ogfPj@03o`000?mk
XN[oNj7Z00?oNj7Z00?o0000ogZQjol000000omlY>d00ol0003oNZC]ogZTk@02ogZTk@;o000000?o
N:C^o`000?mjZ?001?mjZ?02o`000003ogRXlOl0003oNJcc00;oNJcc0ol00002ogJ[l`04o`000?me
[_KoMJkfogF^mPCo000000?oMZcdo`000?mf[?@01_mf[?@3o`0000KoQZCW00?o0000ohn@dOn?T=40
1On?T=400ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo000Iooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Moooool2o`008003obTPTOl0003o:bVK00;o:bVK00?o
0000oc0fYol`=ZL00_l00004ofQS^P04o`000?mPI<3oH6C0o`0000;oN7G300Go0000ofmdaom_M<Oo
KgC7o`000002ogamb@03o`000?mdO<go000000CoO8??0_n2R=02o`000003og^6d_l0003oOh[D00;o
Oh[D00?o0000oh:=e_n2SMH00_n2SMH2o`0000;oOhkH00Go0000oh2@f_n0T=[oP93Jo`000003oh6B
f`05o`000?n2U=coPYCLoh:Dg?l000000_n2U]h01?l0003oPYOOoh:Ggol00003oh6Ih@03o`000?n0
V^;oP9[R00;oP9[R00Go0000ognJhomoV^?oOi[So`000003ogjKi003o`000?mmW>KoOIcV00;oOIcV
00?o0000ogbLiol000000omoX>P01Ol0003oOJ3YogfPjOmmX>Wo000000CoNj7Z00?o0000ogbTkOml
Y>d01?mlY>d00ol0003oNZC]ogZTk@02ogZTk@03o`000?mjZ?3oNZS`00KoNZS`00?o0000ogV/lomi
[?<01Omi[?<2o`0000SoMJkf1?l00006ogJ/m003o`000?maYO7o000000;o00000_n6Y>L00ol0003o
Si3Aohn@d@06ohn@d@03o`000?oooooooooo01_ooooo00?o0000ooooooooool0A?ooool001Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1hooooo`03o`000?lY897o000000?o:bVK
00Go0000oc0fYol`=ZOo<3JWo`000005ofQS^P03o`000?mPI<3o000000?oN7G300?o0000ofmdaol0
00001?mlOLT00omdO<go0000ogb3c`03ogb3c`06o`000?n2R=3oPXS@oh:8d?mkQ];o00001?moR]@0
1?l0003oPXgFoh:=e_n2SMH2ohB@e`;o000000GoOhkHo`000?n0T=[oP93Jo`000003oh6Bf`05o`00
0?n2U=coPYCLoh:Dg?l000000on2U]h01?l0003oPYOOoh:Ggol00003oh6Ih@03o`000?n0V^;oP9[R
00;oP9[R00Go0000ognJhomoV^?oOi[So`000003ogjKi003o`000?mmW>KoOIcV00?o00001OmoX>P0
1?l0003oOJ3YogfPjOmmX>T2o`000004og^Qj_l0003oOZC/ogjTk0;o00001?mlY>d2o`000004ogZT
kOl0003oOJS_ogfXk`?o00001?mjZ?000ol0003oOJcbo`000002o`0000CoNJcc00?o0000ogVam_l0
00000_l00005ogF^mP03o`000?m//o[oK;?j00?o00000_mf[?@00ol0003oLJGaog6Ul@03og6Ul@?o
00002?n?T=400ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Gooooo000Iooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0NOooool00ol0003o:B2Ao`000003ob/YV`05o`00
0?l`=ZOo<3JWoc0fYol000001OmXHkX00ol0003oH6C0o`000004ogQe``03ofmdaol0003oO7g900Co
O7g90_l00003ogb3c`03o`000?n2R=3oPXS@00;oPXS@0_l00003ogn:e005o`000?n2SMKoPXgFoh:=
e_l000001?n4T=L3o`000003oh2@f_l0003oPI;K00;oPI;K00Go0000oh:Dg?n2U=coPYCLo`000002
oh:FgP05o`000?n2UmooPYOOoh:Ggol000000on1VN401Ol0003oP9[Roh2Jh_n0V^;o000000CoOi[S
00?o0000ogjKi?mnVn@00ol00004oh2Oi`03o`000?moX>SoOj3X00;oOj3X00Co0000ogfPjOmmX>Wo
OJ3Y0_l00005ogjTk003o`000?mlY>goO:C]00?oO:C]00?o0000ogfXkommZ>l01?mmZ>l2o`000003
ogZXl?l0003oOJcb00CoOJcb0_l000000omi[??o0000ogVamP04ogVamP?o000000?oMJkfo`000?m/
/oX01Om//oX3o`0000OoLJGa0_l00006ohn@d@03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0A_ooool001Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1iooooo`03o`00
0?lY897o000000Co:bVK0ol`=ZL00omdIKCo0000ofQS^P04ofQS^P03of1T`?l0003oN7G300CoN7G3
00?o0000ogambOmlOLT00omlOLT2ohB5c005o`000?mlPlooO8??ogb3col000000on2R=02ohJ<dP;o
000000?oOh[Do`000?n2SMH00on2SMH01Ol0003oQ93GohB@eon4T=Oo000000;oQI?I1_l00003oh:D
g005o`000?n2U]koPYKNoh:Fg_l000000on2Uml01Ol0003oPIWQoh6IhOn1VN7o000000?oP9[R00?o
0000ognJhomoV^<01?l00003oh:NiP03o`000?n0WnOoP9oW00;oP9oW00?o0000ognPj?moX>P00_mo
X>P00ol0003oOJ3Yo`000003ognTj`03o`000?mnY>coOZC/00;oOZC/0_l000000omlY>go0000ogjW
kP02ogjWkP;o00001OmmZ>l00ol0003oOJcbogf/lP06ogf/lP03o`000?mi/OKoNK7f00OoNK7f00?o
0000ofbcn_m//oX01_m//oX00ol0003o=jgao`000002o`0000CoLJGa00Co0000of:@iol0003o0000
1?n?T=400ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Oooooo000Iooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0NOooool01?l0003o:B2AobTPTOl00003ob/YV`06o`00
0?l`=ZOo<3JWo`000?mdIKCo00001OmXHkX00ol0003oN7G3ogQe``03ogQe``03ohJ1a_l0003oO7g9
00?oO7g900?o0000ohB5c?n4QL`00_l000000omlPloo0000oh:8d002oh:8d007o`000?n6S=;oQXcB
ohJ<d_l0003oOh[Do`000003oh:=eP03o`000?n4T=OoQ93G00;oQ93G00Co0000ohFCfOn5TmWo0000
0on6UM/9o`0000;oPYOO3?l00003oh>Ni003o`000?n2W^KoPYkV00;oPYkV00?o0000oh2Oion0WnL0
0_n0WnL00ol0003oOj3XognPj003o`0000GoOjC[0_l00004ogjTk003o`000?mnYnkoOZO^00CoOZO^
0_l000000ommZ>oo0000oh2[l002oh2[l0?o00001?mm[?800ol0003oP;7do`000002o`0000CoNK7f
00Co0000og6loOma_?goLKcm0ol00002ofbcnP03o`000?lg[O7o=jga00?o=jga1?l00004of:@i`;o
00000_n?T=400ol0003oooooooooo`0Gooooo`;o0000B_ooool001Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1iooooo`04o`000?lY897o:B2Ao`0000?o:bVK00Ko0000oc0fYol`
=ZOo0000ogAU]?l00005ofQS^P03o`000?mhML?oN7G300?oN7G300?o0000ohJ1a_l000000omlOLT0
0ol0003oQ8G<ohB5c002ohB5c003ogb3col0003oPXS@00;oPXS@00?o0000ohJ<d_n6S=800on6S=82
o`0000;oPXgF00?o0000ohB@eon4T=L00_n4T=L01Ol0003oQI?IohFCfOn5TmWo000000?oQYGK00Go
0000ohJGg?n6UmcoQYOLo`000002ohJIgP?o00000_n6V^000ol0003oQI_QohFKh@02ohFKh@05o`00
0?n4WN?oQ9gSohBMhol000001?n3W^@00ol0003oPYkVoh:NiP02oh:NiP04o`000?n0WnOoP9oWoh2O
i`?o00001?n1XnT00ol0003oOjC[ognTj`03ognTj`03o`000?mnY>co000000?oP:O]00?o0000ogjW
k_mnYnh01?mnYnh00ol0003oP:_`oh2[l005oh2[l0;o000000?oOJcbo`000?n0/O@01?n0/O@2o`00
0003ogVam_l0003oLKcm00KoLKcm0_l00009ocN]l@;o00001OmRT>L3o`0001Sooooo00?o0000oooo
ooooool0B_ooool001Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1jooooo`04
o`000?lY897o:B2Ao`0000Co:bVK00?o<3JWo`000?mdIK@00_mdIK@00ol0003oJ6>jofQS^P02ofQS
^P;o00001?mhML<01?l0003oQX76ohJ1a_l00002ogamb@03o`000?n4QLcoQ8G<00?oQ8G<0_l00003
oh:8d003o`000?n6S=;oQXcB00;oQXcB0_n8T=@2o`000003oh:=e_l0003oQ93G00;oQ93G00Go0000
ohFCfOn5TmWoQI?Io`000004ohJEf`05o`000?n6UmcoQYOLohJGg?l000000_n6VMh00ol0003oQY[P
ohJJh002ohJJh003o`000?n5Vn7oQI_Q00;oQI_Q00Go0000ohBMhon4WN?oQ9gSo`000004oh>Ni003
o`000?n2W^KoPYkV00;oPYkV00?o0000oh2Oiol000000on3XnP00ol0003oPJ?Yoh6Sj@02oh6Sj@03
o`000?moY>_oOjC[00?oOjC[00?o0000oh2WkOn0Ynd00on0Ynd2o`0000?oOZO^00?o0000oh:[kon2
Znl00_l00006oh2[l003o`000?n0/OCoP;7d00KoP;7d00?o0000og6loOma_?d01Oma_?d00ol0003o
<[SLoc:hg004oc:hg0Co000000CoN000o`000?l0003o00001_mRT>L00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo04_ooooo000Hooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0N_ooool01Ol0003o:B2AobTPTOlY897o000000?o:bVK00?o<3JWo`000?mdIK@00omdIK@01ol0
003oJ6>jofQS^_mXHk[o0000ohIi__l000000omhML<01ol0003oQX76ohJ1a_n6PLKo0000ogambOl0
00001On4QL`2ohV:cP;o000000?oPXS@o`000?n6S=800on6S=800ol0003oR93DohR@e002ohR@e0Co
000000?oQ93Go`000?n5TmT00_n5TmT01Ol0003oQYGKohJEfon6UM_o000000?oQYOL00Go0000ohJI
g_n6VMkoQYWNo`000004ohJJh003o`000?n5Vn7oQI_Q00;oQI_Q00Go0000ohBMhon4WN?oQ9gSo`00
0004oh>Ni003o`000?n2W^KoPYkV00?o00001On3XnP00ol0003oPJ?Yoh6Sj@02oh6Sj@04o`000?mo
Y>_o0000o`0000?oPZO/00?o0000oh2WkOn0Ynd00on0Ynd00ol0003oOZO^o`000005oh:[k`03o`00
0?n0Zo3oP:_`00;oP:_`00Co0000ohJ_l?n6[o3oQZo`0ol00002oh2am003o`000?n7_OSoQkgh00?o
Qkgh0ol00004oc:hg0Co00000omS02H3ogP000?o00001?mRT>L00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo04cooooo000Hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Noooool01?l0003o:B2AobTPTOl00003ob/YV`03oc0fYol0003oM6Fd00?oM6Fd00Go0000ofQS^_mX
Hk[oJ6>jo`000002ohIi_P04o`000?mhML?oN7G3o`0000CoQX7600?oO7g9o`000?n4QL`01?n4QL`0
1_l0003oRH[>ohV:c_n9R/koPXS@o`0000CoQXcB00?o0000ohR@e?n8T=@00_n8T=@01?l0003oRY?F
ohZCe_n:TmH6o`0000CoQYGK00Go0000ohJGg?n6UmcoQYOLo`000003ohJIgP05o`000?n6V^3oQY[P
ohJJh?l000001On5Vn401Ol0003oQ9gSohBMhon4WN?o000000;oPikT1?l00004ohBRi`03o`000?n3
XnSoPj?X00;oPj?X00Co0000oh6SjOn1XnWoPJ?Y0_l00006oh:Wk0;o00001?n0Ynd00ol0003oPZ__
oh:[k`05oh:[k`;o000000?oP:_`o`000?n6[o001_n6[o02o`0000OoQkgh00?o0000oiOJo_nGf_h0
1?nGf_h01Ol0003oV>fholFfc?o5]/co000000Cooooo0_mh0002o`0000;oHY3W00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1=ooooo`006?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo07cooooo00Co0000obTPTOlY897o00001?l[:I/00ol0003oM6FdogAU]003ogAU]003
o`000?mXHk[o000000CoQWVn00?o0000ogQe`ol000001On6PLH2o`0000CoQ8G<00?o0000ohV:c_n9
R/h00_n9R/h3o`0000?oQXcB00Go0000ohR@e?n8T=CoR93Do`000004ohZCeP04o`000?n;U]SoRiKH
oh^Ff0Ko00000on6Um`00ol0003oQYWNohJIgP02ohJIgP05o`000?n6V^3oQY[PohJJh?l000000on5
Vn48o`0000CoQZ7U00?o0000ohBRion4X^L00_n4X^L00ol0003oPj?Xoh>Sj002oh>Sj003o`000?n1
XnWo000000?oQ:K[00?o0000oh:Wk?n2Yn`01?n2Yn`00ol0003oP:O]o`000003oh:ZkP?o00001On2
Znl00ol0003oQZo`ohJ_l006ohJ_l004o`000?nB]>koT[C^oi:dkP?o000000?oQkgho`000?nGf_h0
1OnGf_h01Ol0003oaKK<olFfc?o5]/co000000Oooooo00GoN000o`000?l0003oHY3Wo`00000Eoooo
o`03o`000?oooooooooo04kooooo000Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0O?ooool01?l0003o:B2AobTPTOl00004ob/YV`03o`000?mdIKCoM6Fd00?oM6Fd00?o0000ofQS
^_l000001On6NKh00omhML?o0000ohJ1aP04ohJ1aP;oSXS90_l00002ohB5c003o`000?n9R/koRH[>
00;oRH[>0on=Sm02o`000003ohJ<d_l0003oR93D00;oR93D00?o0000ohZCe_n:TmH00on:TmH01Ol0
003oRiKHoh^Ff?n;U]So000000?oRiSJ4Ol00002ohROhP03o`000?n7X>CoQj3T00;oQj3T00?o0000
ohJQiOn6XND00on6XND00ol0003oQ:;WohBRi`02ohBRi`03o`000?n3XnSoPj?X00?o00001On4Y^/2
o`0000GoPZO/00?o0000oh:Zk_n2Z^h01On2Z^h2o`000003oh:[kol0003oQZg_00?oQZg_0ol00002
ohJ_l003o`000?nB]>koT[C^00GoT[C^00?o0000oiOJo_l000001Ol00004olFfc003o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1?ooooo`006?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo07cooooo00Go0000obTPTOlY897o:B2Ao`000003
ob/YV`03o`000?mdIKCoM6Fd00CoM6Fd0_l00006ohIi_P;o00001?n6PLH01ol0003oSXS9ohj8bOn>
R<Wo0000ohB5c?l000001?n9R/h00ol0003oSHo@ohf?d003ohf?d0;o00000on8T=@00ol0003oRY?F
ohZCeP02ohZCeP03o`000?n;U]SoRiKH00;oRiKH00Go0000oh^Hf_n;V=[oRiSJo`000003oh^Jg003
o`000?n:W=koRYcN00;oRYcN00Go0000ohVMh?n9WN3oRIgPo`000005ohROhP03o`000?n7X>CoQj3T
00;oQj3T00?o0000ohJQiOn6XND00on6XND00ol0003oQ:;WohBRi`04o`0000CoQZKY00?o0000ohBV
jon4Y^/00on4Y^/01?l0003oPZO/o`000?l00003oh>ZkP;o00001_n2Z^h00ol0003oQZg_ohJ]k`06
ohJ]k`;o00002?nB]>h00ol0003oZKSTojVhi004ojVhi003o`000?o5]/coaKK<00;oaKK<00?o0000
ooooooooool07Oooool00ol0003oooooooooo`1@ooooo`006?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo07cooooo00Go0000obTPTOlY897o:B2Ao`000003ob/YV`03ohE[[Ol0003o
M6Fd00GoM6Fd00?o0000ohIi__n6NKh01?n6NKh2oiB6`P05o`000?n6PLKoQX76ohJ1a_l000001On>
R<T2o`0000?oRH[>00?o0000ohf?d?n=Sm000on=Sm02ohnCd`;o000000?oR93Do`000?n:TmH00on:
TmH00ol0003oRiKHoh^Ff002oh^Ff003o`000?n;V=[oRiSJ00;oRiSJ00Go0000oh^Jg?n;V]coRi[L
o`000004ohZLgP05o`000?n9WN3oRIgPohVMh?l000001On8Wn800ol0003oQj3TohNPi002ohNPi003
o`000?n6XNGoQZ7U00;oQZ7U0ol00004ohNUj003o`000?n6Y^WoQZKY00;oQZKY00?o0000ohBVjon4
Y^/00on4Y^/00ol0003oPj[^oh>ZkP05oh>ZkP;o000000?oPZ[^o`000?l000000on3[>l2o`0000Co
QZg_00Co0000ohj]jon>[N_oSZg[0_l00004oi:dkP03o`000?nY^>CoZKST00CoZKST00?o0000olFf
c?o5]/`00_o5]/`00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo057ooooo000Hooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0OOooool01Ol0003o:B2AobTPTOlY897o0000
00?o:bVK0_l00006ogAU]003oiR1^?l0003oQWVn00CoQWVn00Co0000oiB6`_nDQ/;o00000_n6PLH0
0ol0003oSXS9ohj8b@03ohj8b@;oTHk<00Go0000ohV:c_n9R/koRH[>o`000004ohf?d003o`000?n?
Tm?oSi?C00;oSi?C1?l00002ohZCeP05o`000?n;U]SoRiKHoh^Ff?l000001?n;V=X00ol0003oRi[L
oh^Jg002oh^Jg003o`000?n:W=koRYcN00;oRYcN00Go0000ohVMh?n9WN3oRIgPo`000005ohROhP03
o`000?n7X>CoQj3T00;oQj3T00Co0000ohJQiOl0003o00000_n9Y>H00ol0003oQjGXohNUj003ohNU
j003o`000?n6Y^WoQZKY00;oQZKY00Co0000ohBVjol0003o00000on6Z^`2o`0000KoPj[^00?o0000
oh>/kon3[>l01On3[>l2o`000003ohJ]kol0003oSZg[00GoSZg[0_l000000onB]>ko0000ojVhi006
ojVhi003o`000?o5]/coaKK<00;oaKK<00?o0000ooooooooool07?ooool00ol0003oooooooooo`1B
ooooo`006?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07kooooo00Co0000obTP
TOlY897o00000ol[:I/00ol0003oQF^]o`000005ogAU]003o`000?nHPKSo000000CoQWVn00Oo0000
oiB6`_nDQ/;oU8K2o`000?n6PLKo000000GoSXS900?o0000oi6>c?nAS/`00_l000000on9R/ko0000
ohf?d003ohf?d003o`000?n?Tm?oSi?C00;oSi?C00Co0000oi2Fe_n@U]KoT9KF1_l000000on;U]So
0000oh^HfP02oh^HfP03o`000?n;V]coRi[L00;oRi[L00?o0000ohZLg_n:W=h00_n:W=h00ol0003o
RIgPohVMh002ohVMh004o`000?n8Wn;oR9oRohROhPSo00001On9Y>H00ol0003oQjGXohNUj003ohNU
j003o`000?n6Y^WoQZKY00?o00001on6Z^`2o`000003oh>Zk_l0003o000000?oPjg`00?o0000oh>/
kon3[>l01On3[>l00ol0003oSZg[ohj]j`07ohj]j`?o00001OnY^>@00ol0003oaKK<olFfc003olFf
c003o`000?oooooooooo01_ooooo00?o0000ooooooooool0Doooool001Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1nooooo`05o`000?lY897o:B2AobTPTOl000000_l[:I/00ol0
003oQF^]o`000005ogAU]004o`000?nHPKSoV86ho`0000?oQWVn00?o0000oiB6`_nDQ/800_nDQ/80
0on6PLKo0000ohj8b@04ohj8b@03o`000?nAS/coTHk<00;oTHk<00?oRH[>o`000?n=Sm001?n=Sm00
0ol0003oSi?CohnCd`02ohnCd`03o`000?n@U]KoT9KF00;oT9KF00Co0000oi2If?n@VMSoT9WH1Ol0
00000on;V=[o0000oh^Jg003oh^Jg003o`000?n:W=koRYcN00;oRYcN00?o0000ohVMh?n9WN001Ol0
0002ohbRh`03o`000?n:XnGoRZ?U00?oRZ?U00?o0000ohVTi_n9Y>H00on9Y>H00ol0003oQjGXohNU
j002ohNUj0?o00001?n8ZN/2o`0000KoQZ[/00?o0000oh>]l?n3[O001?n3[O02o`0000?oPjc_00Co
0000ohB/kon4[>ooQ:c_0_l00004ohj]j`03o`000?nLZ=koW:SN00;oW:SN0ol00002ojVhi003o`00
0?o5]/coaKK<00?oaKK<00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Dooooo`006?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07kooooo00Go0000obTPTOlY897o:B2A
o`000002ob/YV`04o`000?n5JjgoQF^]o`0000CoM6Fd00Go0000oiR1^?nHPKSoV86ho`000002ohIi
_P03o`000?nDQ/;oU8K200?oU8K20_l00004ohj8b@03o`000?nAS/coTHk<00?oTHk<0ol00003ohf?
d003o`000?n?Tm?oSi?C00;oSi?C00?o0000oi2Fe_n@U]H00on@U]H01Ol0003oT9WHoi2If?n@VMSo
000000?oSi_K3_l00002ohfQh@03o`000?n<X^?oS:;S00?oS:;S00?o0000ohZSiOn:XnD00on:XnD0
0ol0003oRJCVohVTiP03ohVTiP04o`000?n7YNSo0000o`0000?oRZSY00?o0000ohRYjon8ZN/00on8
ZN/2o`000003ohJZk?l0003o000000?oQjg^00?o0000oh>]l?n3[O001?n3[O000ol0003oPjc_o`00
0006ohB/k`;o000000?oSZg[o`000?nLZ=h01onLZ=h5o`0000;oaKK<00?o0000ooooooooool06Ooo
ool2o`0005Oooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ooooool0
1ol0003o:B2AobTPTOlY897o0000ob/YVol000001?n5Jjd01Ol0003oM6FdogAU]?mdIKCo000000Co
V86h00?o0000ohIi__l000001OnDQ/82oiR=aP;o00000on>R<T00ol0003oTHk<oi6>c002oi6>c0?o
Ti;?0_l000000on=Sm3o0000ohnCd`03ohnCd`03o`000?n@U]KoT9KF00?oT9KF00?o0000oi2If?n@
VMP00_n@VMP01Ol0003oSi_KohnKfon?Vm_o000000GoSigM00?o0000ohjOgon>Wml00_n>Wml00ol0
003oSJ7QohfQh@02ohfQh@03o`000?n<X^?oS:;S00?oS:;S00?o0000ohZSiOn:XnD00on:XnD01?l0
003oRJCVohVTi_n9Y>H3o`0000KoRZSY0_l00005ohRYj`03o`000?n7[NkoQjg^00CoQjg^0_l00005
oh>]l003o`000?n4[>ooQ:c_00OoQ:c_00?o0000oibXg_nLZ=h02?nLZ=h01?l0003oZI[6ojVJa_nY
V/H3o`0001[ooooo00?o0000ooooooooool0Eoooool001Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1oooooo`03o`000?lY897o:B2A00;o:B2A00?o:bVKo`000?n5Jjd00on5Jjd0
1?l0003oM6FdogAU]?l00006oiR1^003ohIi__l0003oU8K200CoU8K200Go0000oiR=a_nHSLKoV8g6
o`000002ohj8b@03o`000?nAS/coTHk<00;oTHk<00?o0000oi>BconCT/l00onCT/l4o`0000;oSi?C
00?o0000oi2Fe_n@U]H00_n@U]H00ol0003oT9WHoi2If002oi2If003o`000?n?Vm_oSi_K00;oSi_K
00?o0000ohnMgOn?WMd00on?WMd00ol0003oSYoOohjOg`02ohjOg`03o`000?n=XN7oSJ7Q00;oSJ7Q
00?o0000ohbRhon<X^<00on<X^<01?l0003oRZ?UohZSiOn:XnD5o`0000CoRjOX00?o0000ohZXjOn:
Z>T01?n:Z>T01?l0003oR:W[o`000?l00003ohb]k003o`000?n7[NkoQjg^00CoQjg^00Co0000oh>]
l?l0003o00000omm[o@2o`0000CoQ:c_00Co0000oh6WkOn1YngoPJO]0_l00006oibXgP03o`000?nY
V/KoZI[600CoZI[600?o0000ooooooooool05oooool00ol0003oooooooooo`1Hooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo083ooooo00Ko0000obTPTOlY897o:B2Aob/Y
Vol00005ohE[[@03o`000?mdIKCo000000OoV86h0_l00004oiB6`P03o`000?nHSLKoV8g600;oV8g6
00?o0000ohj8bOl000001?nAS/`00ol0003oTi;?oi>Bc`03oi>Bc`04o`000?nEU];oUIKBoiFFdPKo
00000_n@U]H00ol0003oT9WHoi2If002oi2If003o`000?n?Vm_oSi_K00;oSi_K00?o0000ohnMgOn?
WMd00on?WMd00ol0003oSYoOohjOg`02ohjOg`03o`000?n=XN7oSJ7Q00;oSJ7Q00Co0000ohbRhon<
X^?oS:;S1Ol00003ohbViP03o`000?n;YnSoRjOX00CoRjOX00?o0000ohZXjOn:Z>T01?n:Z>T00ol0
003oS:g/ohb]k004ohb]k0;o00001On7[Nh00ol0003oOJodogf_m005ogf_m0;o000000?oQ:c_o`00
0?n1Ynd01On1Ynd00ol0003oW:SNoibXgP02oibXgP03o`000?nYV/KoZI[600CoZI[600?o0000oooo
ooooool05oooool00ol0003oooooooooo`1Iooooo`005oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo087ooooo00Ko0000obTPTOlY897o:B2Aob/YVol00005ohE[[@03o`000?mdIKCo
000000OoV86h0_nUS[d01Ol0003oU8K2oiB6`_nDQ/;o000000KoV8g60_l00004oi6>c003o`000?nC
T/ooTi;?00;oTi;?00?o0000oiFFd_nEU]800onEU]801?l0003oUIWEoiFIeOnEVMD6o`000003oi2I
f?l0003oSi_K00?oSi_K00?o0000ohnMgOn?WMd00on?WMd00ol0003oSYoOohjOg`02ohjOg`04o`00
0?n=XN7oSJ7QohfQh@Go00000on>YN@00ol0003oS:KVohbViP03ohbViP03o`000?n;YnSoRjOX00Co
RjOX00?o0000ohZXjOl000000_l00003ohj[j@03o`000?n<[NcoS:g/00CoS:g/00Co0000ohN]k_l0
003o00000on6/_82o`0000KoOJod00?o0000oh6WkOn1Ynd01_n1Ynd2o`000003oibXg_l0003oZI[6
00KoZI[600?o0000ooooooooool05_ooool00ol0003oooooooooo`1Jooooo`005oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo087ooooo00Co0000obTPTOlY897o:B2A0_l00006ohE[
[@03ogAU]?l0003oV86h00KoV86h00Co0000ojF>_OnUS[go00000_nDQ/800ol0003oV8g6oiR=aP04
oiR=aP;oV97;0_l00002oi6>c003o`000?nCT/ooTi;?00;oTi;?00?o0000oiFFd_nEU]800onEU]80
0ol0003oUIWEoiFIe@03oiFIe@04o`000?nDW=SoU9cHoiBLf1Go00000_n@Y>800ol0003oSZGTohjU
i004ohjUi003o`000?n<Y^KoS:KV00?oS:KV00?o0000oh^Wj?n;YnP01?n;YnP00ol0003oSZ_Yohj[
j@05ohj[j@03o`000?n<[NcoS:g/00CoS:g/00?o0000ohJbl_n6/_801On6/_82o`000003ogf_m?l0
003o000000?oGjgi00?o0000oh6WkOn1Ynd01_n1Ynd2o`0000KoZI[600?o0000ooooooooool05_oo
ool00ol0003oooooooooo`1Kooooo`005oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo087ooooo00?o0000obTPTOlY89400_lY89400ol0003oQF^]ohE[[@04ohE[[@;o00001onHPKP0
1ol0003oYHjmojF>_OnUS[go0000oiB6`_l000001_nHSLH01ol0003oV97;oiRAbonHTL_o0000oi6>
c?l000001OnCT/l00ol0003oUIKBoiFFdP03oiFFdP03o`000?nEVMGoUIWE00?oUIWE00?o0000oiBL
f?nDW=P00_nDW=P00ol0003oTikKoi>Nf`02oi>Nf`03o`000?nBX=koTZ3N00?oTZ3N00?o0000oi:R
h?nBX^000_nBX^000ol0003oT:CRoi2ThP03oi2ThP03o`000?n>YNCoSZGT00CoSZGT00?o0000ohbV
i_n<Y^H00on<Y^H00ol0003oRjOXo`000002o`0000?oSJ[Y00?o0000ohj[jOn>ZnT01?n>ZnT00ol0
003oS:g/o`000002o`0000?oT[7/0_l00006ohJblP03o`000?mO[OWoGjgi00CoGjgi0_l00003oh6W
k@;o00000omhU^<00ol0003oZI[6ojVJaP03ojVJaP03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0G?ooool001Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`21ooooo`03
o`000?lY897o:B2A00;o:B2A00?o0000ohE[[On5Jjd01On5Jjd00ol0003oV86hoiR1^005oiR1^003
o`000?nUS[goYHjm00;oYHjm00?oU8K2o`000?nHSLH01OnHSLH00ol0003oV97;oiRAb`03oiRAb`Co
00000_nCT/l00ol0003oUIKBoiFFdP03oiFFdP03o`000?nEVMGoUIWE00?oUIWE00?o0000oiBLf?nD
W=P00onDW=P00ol0003oTikKoi>Nf`02oi>Nf`03o`000?nBX=koTZ3N00?oTZ3N00?o0000oi:Rh?nB
X^000_nBX^000ol0003oT:CRoi2ThP03oi2ThP03o`000?n>YNCoSZGT00CoSZGT00Co0000ohbVi_n<
Y^KoS:KV0ol00007ohfZj@03o`000?n>ZnWoSZ_Y00CoSZ_Y00?o0000oi:ak?nB/N`01_nB/N`00ol0
003oQ[;bo`000002o`0000?oOKcj0_l00005oen]n@03o`000?n1Yngo000000KoN9KS00?o0000ojVJ
a_nYV/H00_nYV/H00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05gooooo000Gooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0P_ooool00ol0003o:B2AobTPT@02obTPT@03
o`000?n5JjgoQF^]00GoQF^]0_l00006oiR1^003o`000?nUS[goYHjm00?oYHjm0_l00005oiR=aP03
o`000?nHTL_oV97;00?oV97;00Co0000oiVEc_nIULkoVIG>1Ol00003oiFFdP03o`000?nEVMGoUIWE
00?oUIWE00?o0000oiBLf?nDW=P00onDW=P00ol0003oTikKoi>Nf`02oi>Nf`03o`000?nBX=koTZ3N
00CoTZ3N00?o0000oi:Rh?nBX^000_nBX^000ol0003oT:CRoi2ThP03oi2ThP04o`000?n>YNCoSZGT
ohjUi0Ko00000on=ZNP00ol0003oSJ[YohfZj@05ohfZj@03o`000?n>ZnWo000000;o00000onC[NP0
0ol0003oT[7/oi:ak005oi:ak003o`000?mm_?[oOKcj00KoOKcj0_l00002oen]n@03o`000?mO[OWo
000000SoN9KS00Co0000ojVJa_nYV/Ko00005_ooool00ol0003oooooooooo`1Nooooo`005oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo08?ooooo00Co0000obTPTOlY897o:B2A0_l0
0006ohE[[@03o`000?n]Rk7o000000CoV86h00?o0000ojF>_OnUS[d01?nUS[d2oj>Da@?o00000_nH
SLH00ol0003oV97;oiRAb`03oiRAb`03o`000?nIULkoVIG>00?oVIG>00?o0000oi^JdOnKV]400ol0
00000onEU];o0000oiFIe@04oiFIe@03o`000?nDW=SoU9cH00;oU9cH00?o0000oi>NfonCW]/00onC
W]/00ol0003oTZ3Noi:PgP03oi:PgP03o`000?nBX^3oTZ;P00?oTZ;P00Co0000oi2Th_n@Y>;oT:CR
1Ol00004oi6YiP03o`000?n=ZNSoSJWX00?oSJWX00?o0000ohfZjOn=Z^T01On=Z^T00ol0003oTjgX
oi>]j005oi>]j004o`000?nB/NcoT[7/oi:ak0;o00000onM]^T2o`0000OoOKcj0_l00004o`1HZP03
o`000?mhU^?oN9KS00GoN9KS00?o0000ojVJa_l000005Oooool00ol0003oooooooooo`1Oooooo`00
5oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08?ooooo00Co0000obTPTOlY897o
:B2A0_l00006ohE[[@04o`000?n]Rk7o[H^ao`0000?oV86h00?o0000ojF>_OnUS[d01?nUS[d00ol0
003oXiC5oj>Da@02oj>Da@03o`000?nHSLKo000000GoV97;00?o0000oiVEc_nIULh00onIULh00ol0
003oVi[Aoi^Jd@03oi^Jd@_o00000_nDW=P00ol0003oTikKoi>Nf`02oi>Nf`04o`000?nBX=koTZ3N
oi:PgPco00000onDYn<00ol0003oTJWVoi6YiP04oi6YiP03o`000?n=ZNSoSJWX00?oSJWX00?o0000
ohfZjOn=Z^T00ol00003ohf[jP03o`000?nC[NSoTjgX00CoTjgX00?o0000oi:ak?l000001onM]^T0
0ol0003oOKcjogflnP03o`0000?o<[CV1Ol0F:X2o`0000KoN9KS00?o0000ooooooooool04oooool0
0ol0003oooooooooo`1Pooooo`005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
08?ooooo00Oo0000obTPTOlY897o:B2Ao`000?nHLjOo000000GoQF^]00Go0000ojf;/On]Rk7o[H^a
o`000002oiR1^003o`000?nUS[goYHjm00CoYHjm00?o0000oj>DaOnSU<D01?nSU<D2o`0000GoV97;
00?o0000oiVEc_nIULh00onIULh00ol0003oVi[Aoi^Jd@03oi^Jd@03o`000?nLWMGoW9gE00?oW9gE
00Co0000oiVPfOnIX=WoVJ3I2ol00003oiFSgP03o`000?nFYN3oUZGP00?oUZGP00?o0000oiBWhonD
Yn<01?nDYn<00ol0003oTJWVoi6YiP04oi6YiP04o`000?n=ZNSoSJWXohfYj0Co00001on=ZnX00ol0
003oTjgXoi>]j004oi>]j003o`000?nM]^WoWKKY00OoWKKY0_l00009oc:diPCo05RZ00Go0000ogRF
homhU^?oN9KSo`00000Fooooo`03o`000?oooooooooo067ooooo000Fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Q?ooool01ol0003o:B2AobTPTOlY897o0000oiQcYol000001On5
Jjd00ol0003o[H^aojf;/@02ojf;/@03o`000?nHPKSo000000KoYHjm00?o0000oj>DaOnSU<D01?nS
U<D2oifDb`?o00000_nHTL/00ol0003oVIG>oiVEcP03oiVEcP03o`000?nKV]7oVi[A00?oVi[A00?o
0000oibMeOnLWMD01?nLWMD00ol0003oVJ3IoiVPf@02oiVPf@03o`000?nFXMgoUZ7M00?oUZ7M00?o
0000oiFSg_nEXmh01?nEXmh00ol0003oUZGPoiJUh003oiJUh003o`000?nDYn?oU:OS00CoU:OS00Co
0000oi6Yi_nAZNKoTJWV0_l000001?nAZNKo0000o`000?l00004ohZ/k003o`000?n=Zn[oSJ_Z00Go
SJ_Z00?o0000oi>]j?l000000_l00003oif/h@;o00000onM]^T2o`0000Ko/kcQ00?o0000oooooooo
ool01_ooool2o`1HZP03o`000?mhU^?o000001Kooooo00?o0000ooooooooool0H_ooool001Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`24ooooo`05o`000?lY897o:B2AobTPTOl0
00000_nHLjL00ol0003oQF^]ohE[[@02ohE[[@03o`000?n]Rk7o[H^a00?o[H^a0_l00006ojF>_@03
o`000?nSU<GoXiC500CoXiC500?o0000oifDbonMU</00_nMU</00ol0003oV97;o`000005oiVEcP03
o`000?nKV]7oVi[A00?oVi[A00?o0000oibMeOnLWMD01?nLWMD00ol0003oVJ3IoiVPf@03oiVPf@03
o`000?nFXMgoUZ7M00?oUZ7M00?o0000oiFSg_nEXmh00onEXmh00ol0003oUZGPoiJUh004oiJUh003
o`000?nDYn?oU:OS00?oU:OS1?l00004oi:^j@03o`000?n:[>coRZc/00CoRZc/00?o0000ohf[j_n=
ZnX01On=ZnX00ol0003oWJcQoif/h@06oif/h@03o`000?nM]^Wo000000Oo/kcQ00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Cooooo`;o0000IOooool001Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`24ooooo`05o`000?lY897o:B2AobTPTOl000000_nHLjL00ol0003o
QF^]ohE[[@02ohE[[@03o`000?n]Rk7o[H^a00Co[H^a0_l00005ojF>_@03o`000?nSU<GoXiC500Co
XiC500?o0000oifDbonMU</01?nMU</5o`0000;oVIG>00?o0000oi^JdOnKV]400onKV]400ol0003o
W9gEoibMe@03oibMe@03o`000?nIX=WoVJ3I00?oVJ3I00?o0000oiJQgOnFXMd01?nFXMd00ol0003o
UJ?NoiFSgP03oiFSgP03o`000?nFYN3oUZGP00?oUZGP00?o0000oiBWhonDYn<00ol000000onJ[>?o
0000oi:^j@06oi:^j@03o`000?n:[>coRZc/00CoRZc/00?o0000ohf[j_n=ZnX00ol00002oh^Yj@03
o`000?nM[>7oWJcQ00KoWJcQ00?o0000ok>lhOnc_>401Onc_>400ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo06Gooooo000Fooooo`05o`000?ooooooooooooooool00000R?ooool3obTPT@05
o`000?nHLjOoV7>WoiQcYol000000_n5Jjd00ol0003o[H^aojf;/@05ojf;/@03o`000?njVkSo0000
00;o00000_nUS[d00ol0003oXiC5oj>Da@04oj>Da@03o`000?nMU<_oWIC;00CoWIC;00?o0000oifG
c_nMUlh00_nMUlh6o`0000;oVi[A00?o0000oibMeOnLWMD01?nLWMD00ol0003oVJ3IoiVPf@02oiVP
f@03o`000?nFXMgoUZ7M00CoUZ7M00?o0000oiFSg_nEXmh00onEXmh01?l0003oUZGPoiJUh?nFYN05
o`0000GoVZcS00?o0000oi:^jOnB[^T01OnB[^T01?l0003oRZc/ohZ/k?n:[>`2o`000003ohZ/k?l0
003o000000KoRjWY00?o0000oif/hOnM[>400_nM[>42o`0000?oZjGA0_l00003ok>lh@03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0I_ooool001Kooooo00Go0000ooooooooooooooooo`00
0028ooooo`?o:B2A00Go0000oiQcYonHLjOoV7>Wo`000002ohE[[@03o`000?n]Rk7o[H^a00Go[H^a
00?o0000okZK^?njVkP00_njVkP00ol0003oYHjmo`000007oj>Da@03o`000?nMU<_oWIC;00?oWIC;
00?o0000oifGc_nMUlh01?nMUlh01?l0003oXig@oj>Md?nSWM0Oo`0000CoVjSO00?o0000oiZ/honJ
[><01?nJ[><00ol0003oTZkYoi:^j@05oi:^j@?o00001?mi[?<00ol0003oRjWYoh^Yj@05oh^Yj@04
o`000?nM[>7o0000o`0000OoZjGA00?o0000ok>lhOl000008_ooool00ol0003oooooooooo`1Woooo
o`005_ooool01Ol0003ooooooooooooooooo000008Sooooo00Co0000obTPTOlY897o00000onHLjL0
1?l0003oQF^]ohE[[Ol00007ojf;/@03o`000?njVkSo^Y^h00Co^Y^h0ol00005oj>Da@03o`000?nM
U<_oWIC;00?oWIC;00?o0000oifGc_nMUlh01?nMUlh00ol0003oXig@oj>Md003oj>Md003o`000?nS
XmCoXj?D00CoXj?D00?o0000oibUfonLYM/00onLYM/00ol0003oUJCPoiFTh004oiFTh003o`000?nF
YMooUZGO00?oUZGO00?o0000oi^XgonKZ=l01OnKZ=l00ol0003oVZcSoiZ/h`04oiZ/h`03o`000?nB
[^WoTZkY00?o00000_n?]O400ol0003oNJccogV/l`04ogV/l`03o`000?n;ZNWoRjWY00GoRjWY00?o
0000oj^UdOn[YM402?n[YM400ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Sooooo000F
ooooo`05o`000?ooooooooooooooool00000R?ooool00ol0003o:B2Ao`000005oiQcY`03o`000?n5
Jjgo000000Oo[H^a00?o0000okZK^?njVkP01?njVkP3ojjNaPCo000000?oXiC5o`000?nMU</01OnM
U</00ol0003oWIO>oifGcP03oifGcP03o`000?nSWM3oXig@00CoXig@00?o0000oj>Se?nSXm@01?nS
Xm@00ol0003oW:GKoibUf`03oibUf`03o`000?nEY>3oUJCP00CoUJCP00?o0000oiJUgonFYMl00onF
YMl00ol0003oVjSOoi^Xg`05oi^Xg`04o`000?nJ[>?oVZcSoiZ/h`;o000000?oVZcSo`000?l00000
1_n?]O400ol0003oNJccogV/l`04ogV/l`03o`000?n;ZNWoRjWY00?o000000?oQ9kTo`000?n[YM40
2?n[YM400ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Wooooo000Fooooo`04o`000?oo
ooooooooo`0008Wooooo00?o0000obTPTOl000001OnHLjL00ol0003oQF^]o`000007ojf;/@03o`00
0?njVkSo^Y^h00Co^Y^h00?o0000ojjNa_n^W/H01?n^W/H4o`0000CoWIC;00?o0000oifGc_nMUlh0
1?nMUlh00ol0003oXig@oj>Md003oj>Md003o`000?nSXmCoXj?D00CoXj?D00?o0000oibUfonLYM/0
1?nLYM/00ol0003oUJCPoiFTh004oiFTh003o`000?nFYMooUZGO00?oUZGO00?o0000oi^XgonKZ=l0
0onKZ=l00ol0003oVjSOo`000002o`0000GoYK;R00?o0000ohnelOn?]O401?n?]O401?l0003oNJcc
ogV/lomi[?<2o`000003ogV/lol0003o000000GoQ9kT00?o0000oj^UdOn[YM401On[YM400ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo06[ooooo000Fooooo`04o`000?ooooooooooo`0008[o
oooo00?o:B2Ao`000?nHLjL01OnHLjL00on5Jjgo0000ojf;/@06ojf;/@03o`000?njVkSo^Y^h00Co
^Y^h00?o0000ojjNa_n^W/H01On^W/H3oiNEc`?o000000?oWIC;o`000?nMUlh01OnMUlh00ol0003o
Xig@oj>Md003oj>Md003o`000?nSXmCoXj?D00CoXj?D00?o0000oibUfonLYM/01?nLYM/00ol0003o
UJCPoiFTh004oiFTh003o`000?nFYMooUZGO00?oUZGO00?o0000oi^XgonKZ=l00ol00002ojBYf`03
o`000?nU/^;oYK;R00KoYK;R00Co0000ohnelOn?]O7oSkGa0_l000001?n?]O7o0000o`000?l00004
oaZ;j@03o`000?n4W^CoQ9kT00CoQ9kT00?o0000oj^UdOn[YM400on[YM400ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo06_ooooo000Fooooo`04o`000?ooooooooooo`0008[ooooo00?o:B2A
o`000?nHLjL01OnHLjL2o`0000Oo[H^a00?o0000okZK^?njVkP01?njVkP00ol0003o[Yk6ojjNaP05
ojjNaP03o`000?nGULooUiG?00?oUiG?1_l00002oifGcP03o`000?nSWM3oXig@00CoXig@00?o0000
oj>Se?nSXm@01?nSXm@01?l0003oW:GKoibUfonLYM/Bo`0000KoY:WK00?o0000ojFbh_nU/^801_nU
/^83o`0000GoL<?n1_lJRnT00ol0003oQ9kTohBNi004ohBNi005o`000?n[YM7oZjGAoj^UdOl00000
8_ooool00ol0003oooooooooo`1/ooooo`005_ooool01?l0003oooooooooool0002:ooooo`03obTP
TOl0003oV7>W00KoV7>W0_l00006ojf;/@03o`000?njVkSo^Y^h00Co^Y^h00?o0000ojjNa_n^W/H0
1On^W/H00ol0003oUiG?oiNEc`04oiNEc`GoW9O>5?l00003oij]hP03o`000?n9YNOoRJGW00CoRJGW
00?o0000oiBTh?nDY>000onDY>000ol0003oY:WKojBYf`06ojBYf`04o`000?nU/^;oYK;RojFbhP?o
00000oni^]X00ol0003oL<?nog33oP05og33oP03o`000?lJRnWo6X_Y00;o6X_Y00?o0000ohBNi?n4
W^@01?n4W^@00ol0003oZjGAo`00000Rooooo`03o`000?oooooooooo06gooooo000Eooooo`04o`00
0?ooooooooooo`0008_ooooo00?o:B2Ao`000?nHLjL01_nHLjL01?l0003o`iNYo`000?l00004ojf;
/@03o`000?njVkSo^Y^h00Co^Y^h00?o0000ojjNa_n^W/H01On^W/H00ol0003oUiG?oiNEc`04oiNE
c`03o`000?nLUlkoW9O>00CoW9O>00?o0000ojbQc?n/XL`01?n/XL`00ol0003o/:_Cok2[d`04ok2[
d`03o`000?nN[N;oWZgR00GoWZgR00?o0000ohVUion9YNL01?n9YNL00ol0003oU:CPoiBTh003oiBT
h003o`000?nTZM_oY:WK00GoY:WK00Co0000ojFbh_l0003o00001oni^]X4o`0000Kooooo00Co0000
oaZ;jOlJRnWo00000on4W^@4o`0002;ooooo00?o0000ooooooooool0K_ooool001Gooooo00Co0000
oooooooooooo0000Roooool00olY897o0000oiQcY`06oiQcY`04o`000?o3UjWo`iNYol>GZ@;o0000
0_n]Rk400ol0003o^Y^hokZK^004okZK^003o`000?n^W/Ko[Yk600Go[Yk600?o0000oiNEconGULl0
1?nGULl00ol0003oW9O>oibGcP04oibGcP03o`000?n/XLco[:7<00Go[:7<00?o0000ok2[don`Zm<0
1?n`Zm<00ol0003oWZgRoij]hP04oij]hP03o`000?n9YNOoRJGW00CoRJGW00?o0000oiBTh?nDY>00
1?nDY>000ol0003oY:WKojBYf`03ojBYf`03o`000?nTZM_o000000Oo^K[J00?o0000ooooooooool0
2oooool5o`0002Gooooo00?o0000ooooooooool0Koooool001Gooooo00Co0000oooooooooooo0000
Roooool2o`0000OoV7>W00?o0000ol>GZOo3UjT00oo3UjT3o`0000?o^Y^h2?l00003ojjNaP03o`00
0?nGULooUiG?00GoUiG?00?o0000oibGc_nLUlh00onLUlh00ol0003o[:7<ojbQc005ojbQc003o`00
0?n`Zm?o/:_C00Co/:_C00?o0000oij]h_nN[N801?nN[N800ol0003oRJGWohVUi`04ohVUi`03o`00
0?nDY>3oU:CP00CoU:CP00?o0000ojBYfonTZM/00ol00002ok6WcP03o`000?ni^][o^K[J00?o^K[J
0_l0000>ooooo`03o`000?oooooooooo02Gooooo0_l0001booooo`005Oooool00ol0003oooooo`00
002=ooooo`03o`000?nHLjOoV7>W00GoV7>W00?o0000ol>GZOo3UjT01Oo3UjT4o`0000?odjba00?o
0000okNde_ng]=H00_ng]=H6o`0000GoUiG?00?o0000oibGc_nLUlh00onLUlh00ol0003o[:7<ojbQ
c005ojbQc003o`000?n`Zm?o/:_C00Co/:_C00?o0000oij]h_nN[N800_nN[N8Co`0000Ko/JO>00Go
0000okVjf_ni^][o^K[Jo`00000@ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
L_ooool001Gooooo00?o0000ooooool00000SOooool00ol0003oV7>WoiQcY`05oiQcY`03o`000?o3
UjWo`iNY00Go`iNY00?o0000om>//OoC[;401?oC[;400ol0003o]kCFokNdeP05okNdeP?oFgcJ1?l0
00000onGULoo0000oibGcP05oibGcP03o`000?n/XLco[:7<00Go[:7<00Co0000ok2[don`Zm?o/:_C
1ol00003oiBom@03o`000?lnS>ko?Xc^00Co?Xc^00?o0000oh^JgOn;V]d01?n;V]d00ol0003o/JO>
ok6WcP06ok6WcP03o`000?ni^][o0000017ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1cooooo`005Oooool00ol0003oooooo`00002=ooooo`03o`000?nHLjOoV7>W00GoV7>W00?o
0000ol>GZOo3UjT01Oo3UjT00ol0003odjbaom>//@04om>//@03o`000?ng]=Ko]kCF00Go]kCF00?o
0000oe]lf_mKO=X01?mKO=X4o`0000CoW9O>00?o0000ojbQc?n/XL`00on/XL`6o`0000?oa;K=00?o
0000oiBomOnD_oD01OnD_oD00ol0003o?Xc^ocj<kP04ocj<kP03o`000?n;V]goRi[M00CoRi[M00?o
0000ok6Wc_naYlh01_naYlh00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0M?ooool001Gooooo00?o0000ooooool00000SOooool00ol0003oV7>WoiQcY`05
oiQcY`03o`000?o3UjWo`iNY00Go`iNY00?o0000om>//OoC[;401OoC[;400ol0003o]kCFokNdeP04
okNdeP03o`000?mKO=[oFgcJ00GoFgcJ0onBSL/3o`000003oibGc_l0003o[:7<00Co00000_njXl80
0ol0003oa;K=olBfc@05olBfc@03o`000?nD_oGoU;oe00;oU;oe0_l000000onD_oGo0000o`000004
ocj<kP03o`000?n;V]goRi[M00CoRi[M00?o0000ok6Wc_naYlh00onaYlh2o`0001Cooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`1eooooo`005Oooool2o`0008oooooo00?o0000oiQc
YonHLjL01?nHLjL00ol0003o`iNYol>GZ@05ol>GZ@03o`000?oC[;7odjba00Godjba00Co0000okNd
e_ng]=Ko]kCF1Ol00006oe]lfP03o`000?nBSL_oTXg;00?oTXg;0ol00006okZS`P03o`000?o4]/go
a;K=00Goa;K=1Ol00005ooooo`?o00000_lnS>h00ol0003oRi[Moh^Jg@04oh^Jg@05o`000?naYlko
/JO>ok6Wc_l000005_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07Kooooo000E
ooooo`;o0000Soooool00ol0003oV7>WoiQcY`04oiQcY`03o`000?o3UjWo`iNY00Go`iNY00?o0000
om>//OoC[;401OoC[;44o`0000Gooooo00?o0000oe]lf_mKO=X00omKO=X00ol0003oTXg;oi:=b`04
oi:=b`03o`000?njXl;o^Z?200Go^Z?200?o0000olBfcOo4]/d01?o4]/d00ol0003oooooooooo`0;
ooooo`?o00001_n;V]d01?l0003o/JO>o`000?l0000Gooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0Moooool001Gooooo0_l0002@ooooo`03o`000?nHLjOoV7>W00?oV7>W00?o0000
ol>GZOo3UjT01Oo3UjT00ol0003odjbaom>//@05om>//@03o`000?oooooooooo00Oooooo0_l00003
oe]lfP03o`000?nBSL_oTXg;00CoTXg;00?o0000okZS`_njXl801_njXl801?l0003oa;K=olBfcOo4
]/d2o`00017ooooo2?l0000Iooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0N?oo
ool001Gooooo0_l0002@ooooo`03o`000?nHLjOoV7>W00?oV7>W00?o0000ol>GZOo3UjT01Oo3UjT0
0ol0003odjbaom>//@04om>//@03o`000?oooooooooo00[ooooo00Co0000oe]lf_mKO=[o00001_nB
SL/00ol0003o^Z?2okZS`P06okZS`P04o`000?o4]/go0000o`0003Gooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1iooooo`005?ooool2o`0009;ooooo00?o0000oiQcYonHLjL00_nH
LjL00ol0003o`iNYol>GZ@05ol>GZ@03o`000?oC[;7odjba00?odjba00?o0000ooooooooool03Ooo
ool00omKO=[o0000oi:=b`05oi:=b`03o`000?njXl;o^Z?200Ko^Z?20_l0000gooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0N_ooool001Cooooo0_l0002Booooo`03o`000?nHLjOo
V7>W00;oV7>W00?o0000ol>GZOo3UjT01Oo3UjT00ol0003odjbaom>//@02om>//@03o`000?oooooo
oooo00oooooo0_l00006oi:=b`03o`000?njXl;o^Z?200Co^Z?20_l0000hooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Noooool001Cooooo0_l0002Cooooo`05o`000?nHLjOoV7>W
oiQcYol000001oo3UjT01Ol0003odjbaom>//OoC[;7o000001Cooooo0ol00003oi:=b`04o`000?nj
Xl;o^Z?2okZS`P?o0000>_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo07cooooo
000Dooooo`03o`000?oooooooooo09;ooooo00Go0000oiQcYonHLjOoV7>Wo`000007ol>GZ@04o`00
0?oC[;7odjbao`0001Sooooo0_l000000onBSL_o0000o`000002o`0003gooooo00?o0000oooooooo
ool05oooool2o`0007oooooo000Dooooo`Oo0000S_ooool01Ol0003oV7>WoiQcYonHLjOo000000Oo
`iNY00?o0000om>//Ol000007?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0Ooooool001_ooooo2ol00024ooooo`04o`000?nHLjOoV7>Wo`0000Oo
`iNY0_l0001Nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0P?ooool002Kooooo
2ol0001iooooo`04o`000?nHLjOoV7>Wo`0000Ko`iNY0_l0001Oooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0POooool0037ooooo2ol0001_ooooo`03o`000?nHLjOo000000Go`iNY
00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08;ooooo
000looooo`_o0000I?ooool00ol0003oV7>Wo`000003ol>GZ@;o0000H_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo08?ooooo0017ooooo`co0000FOooool2o`000003ol>GZOl0003o
000006Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`24ooooo`00Doooool;o`00
04kooooo0ol0001Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0QOooool005ko
oooo2ol00014ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`26ooooo`00JOooool;o`000:7ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`27ooooo`00M?ooool<o`0009Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`28ooooo`00P?ooool;o`0008[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`29
ooooo`00Roooool;o`0007oooooo00?o0000ooooooooool02_ooool2o`0008cooooo002Fooooo`_o
0000M?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08cooooo002Qooooo`_o0000
JOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08gooooo002/ooooo`co0000G_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08kooooo002hooooo`_o0000Doooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo08oooooo0033ooooo`_o0000B?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo093ooooo003>ooooo`_o0000?Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo097ooooo003Iooooo`co0000<Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo09;ooooo003Uooooo`_o00009_ooool01Ol0003ooooooooo
oooooooo000009Gooooo003`ooooo`_o00006oooool01?l0003oooooooooool0002Fooooo`00nooo
ool;o`00013ooooo00?o0000ooooool00000Uoooool00?oooooo1oooool;o`0000Gooooo0_l0002H
ooooo`00oooooolBooooo`Ko0000VOooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Ooo
ool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo5Oooool01?l@413o0000
o`000?l0002Hooooo`00oooooolFooooo`03o`000?oooooooooo09Sooooo003ooooooaKooooo00?o
0000ooooooooool0V?ooool0063ooooo0ol000000ol@413oooooooooo`04ooooo`05ohN7Qol@413o
0000oa0@4?n7QhL01?ooool01_o<c<co8B4Qo`000?l0003oEEEEokZj^P?ooooo00KoMgMgoa0@4?l0
003o410@oeEEEOoMgMd2ooooo`03oa0@4?l0003o000000;ooooo0_l000001Ol@413oooooooooooo<
c<co8B4Q00;o000000GoEEEEokZj^_oooooooooooa0@4005o`00000:oa0@4?ooooooooooojVYZOl@
413o0000ob4Q8OnHV9So410@o`0000;ooooo00?o410@o`000?l000001?l0000;ooooo`03oa0@4?l0
003o000000?o000000Co410@oooooooooooo410@0_l00002ooooo`;o000000Co410@ooooool@413o
<S8b0_l000000olQ8B7oc<c<ooooo`02ooooo`03oa0@4?l0003o000000?o000000_o410@oooooooo
ooooooooohN7Qol@413o0000ob4Q8OnYZJWo0000oa0@4002ooooo`06ogMgMol@413o0000oa0@4?mE
EEGogMgM2oooool01onYZJWo410@o`000?lQ8B7oV9RHoa0@4?l000002oooool01_l@413o<S8bo`00
0?l0003o8B4Qolc<c0Cooooo00Ko0000ohN7Qol@413o0000oa0@4?mgMgL2ooooo`03oa0@4?l0003o
000000;ooooo0_l000002Ol@413ooooooooooomgMgOo410@o`000?l@413oEEEEomgMg@02ooooo`Ko
00001?ooool01_mgMgOo410@o`000?l@413oEEEEomgMgG7ooooo001Qooooo`03o`000?oooooooooo
00Gooooo00OoQhN7ob4Q8Oo<c<coooooolc<c?lQ8B7oQhN700?ooooo00Ko410@ohN7Qoooooook^k^
ojVYZOlQ8B42ooooo`07ogMgMom4A4CogMgMoooooooMgMgoQhN7ob4Q8@03ooooo`03o`000?oooooo
oooo00;ooooo00[o0000oooooooooooooooooa0@4?n7QhOoooooonk^k_nYZJWo8B4Q1Oooool00ol0
003oooooooooo`03ooooo`06o`000?nj^[[oooooomgMgOmgMgOo00001_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
ool0003oZJVY00;ooooo00?oZJVYoa0@4?ooool01Oooool00ol0003oooooooooo`03ooooo`07ohN7
QolQ8B7oc<c<ooooooo<c<co8B4Qo`000002ooooo`07ogMgMom4A4CogMgMoooooooMgMgoQhN7ob4Q
8@0;ooooo`06o`000?nj^[[oooooomgMgOmgMgOo00003?ooool01_l0003oZJVYooooooooooooZJVY
oa0@40Cooooo00Oo0000ob4Q8Oo<c<coooooolc<c?lQ8B7oMgMg00;ooooo00?o0000ooooooooool0
0_ooool02_l0003ooooooooooomgMgOoA4A4omgMgOoooooogMgMohN7QolQ8B44ooooo`03o`000?oo
oooooooo00Cooooo00OoMgMgodA4A?oMgMgoooooomgMgOn7QhOo8B4Q077ooooo001Qooooo`03o`00
0?oooooooooo00Gooooo00?o410@olc<c?ooool00_ooool00oo<c<co410@ooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o410@onk^k_ooool01oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002_ooool00ol0003oooooooooo`03ooooo`06oa0@4?n7QhOok^k^oooo
oooMgMgo00001_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03olc<c?l0003ooooo00Gooooo00?o0000
ooooooooool00oooool00ol@413oc<c<ooooo`02ooooo`06okZj^_l0003oooooooooool@413ok^k^
4?ooool01_l@413oQhN7onk^k_oooooogMgMo`00013ooooo00?oc<c<o`000?ooool00oooool00ol0
003oc<c<ooooo`02ooooo`05olc<c?l@413oooooooooool000001?ooool01Ol0003oooooooooool@
413ok^k^00Wooooo00?o0000ooooooooool01?ooool00ol@413ok^k^ooooo`1eooooo`00HOooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0007ooooo`Oo00000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
2_ooool00ol0003oooooooooo`03ooooo`06olc<c?m4A4Co0000o`000?l@413o00001_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooonYZJWo8B4Q00?o000000?oQhN7ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01ol0000;ooooo`06olc<c?m4A4Co
0000o`000?l@413o00003?ooool00onYZJWo8B4Qo`000002o`000003ohN7Qooooooooooo00;ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Oo
00001?ooool00ol0003oooooooooo`04ooooo`Oo0000LOooool0067ooooo1?l000001_mEEEGok^k^
oooooooooooo410@okZj^P?ooooo00?o^[Zjoa0@4?ooool00_ooool00ol0003oooooooooo`05oooo
o`03oa0@4?oMgMgooooo00;ooooo00?ogMgMo`000?ooool00_ooool00ol0003ok^k^ooooo`02oooo
o`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?o^k^ko
oooo00;ooooo00Go0000oooooooooooo0000oiRHV002okZj^PSooooo00?o0000ooooooooool00ooo
ool00ol@413oc<c<ooooo`02ooooo`06olc<c?l0003oooooooooool@413ogMgM0oooool00ooMgMgo
0000ooooo`0?ooooo`03o`000?oooooooooo00[ooooo00Co0000oiRHV?nj^[[o^[Zj1_ooool00ol0
003oc<c<ooooo`02ooooo`06olc<c?l@413oooooooooool0003ok^k^0oooool01Ol0003ooooooooo
ool@413ogMgM00?ooooo00?ogMgMo`000?ooool00oooool00ol0003ogMgMooooo`04ooooo`03oa0@
4?oMgMgooooo00;ooooo00?ogMgMo`000?ooool0L?ooool0067ooooo00Ko0000oooooooooooooooo
ohN7Qolb<S82ooooo`07ohN7QolQ8B7oc<c<ooooooo<c<co8B4QohN7Q`03ooooo`03o`000?oooooo
oooo00Gooooo00OoQhN7ob4Q8Onj^[[oooooomgMgOlQ8B7oMgMg00?ooooo00Ko0000odA4A?oMgMgo
ooooogMgMol@4103ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00on7
QhOo<S8booooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01_l0
003oA4A4omgMgOooooooMgMgoa0@40;ooooo00Ko0000okZj^_ooooook^k^ogMgMol00006ooooo`03
o`000?oooooooooo00?ooooo00OoZJVYob4Q8Oo<c<coooooolc<c?lQ8B7o000000;ooooo00OoQhN7
ob4Q8Onj^[[oooooomgMgOlQ8B7oMgMg00oooooo00?oQhN7oc8b<_ooool02oooool01_l0003o^[Zj
ooooooo^k^koMgMgo`0000Cooooo00Oo0000ob4Q8Oo<c<cooooookZj^_lQ8B7oZJVY00;ooooo00Ko
0000odA4A?oMgMgoooooogMgMolQ8B42ooooo`07ohN7QolQ8B7o^[ZjoooooooMgMgo8B4QogMgM`04
ooooo`;o000000?oV9RHooooooooool00_ooool01on7QhOo8B4QokZj^_oooooogMgMob4Q8OmgMgL0
LOooool0067ooooo00?o0000ooooooooool00_ooool02Ol0003oooooooooooooooooQhN7oa0@4?l0
003o410@ohN7Q`02ooooo`03oa0@4?l0003o000000?o000000?o410@ooooooooool00_ooool01On7
QhOo410@o`000?l@413oMgMg00?ooooo00Wo410@o`000?mgMgOo410@o`000?lQ8B7oc<c<ooooool@
41001Ol000000ol@413oooooooooo`02ooooo`03oa0@4?l0003o000000Kooooo00GoA4A4o`000?l0
003o410@olc<c006ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l000001Oooool01ol@
413o0000ogMgMol@413o0000ob4Q8Oo<c<`00_ooool01_o<c<co8B4Qo`000?l0003o<S8bo`0000Co
oooo00?o410@o`000?l000001_ooool01_nYZJWo410@o`000?l@413oQhN7o`0000?ooooo00GoQhN7
oa0@4?l0003o410@ogMgM`0=ooooo`05odA4A?l0003o0000oa0@4?o<c<`03?ooool01_o<c<co8B4Q
o`000?l0003o<S8bo`0000?ooooo00Oo410@o`000?n7QhOo410@o`000?l@413oZJVY00?ooooo00Ko
0000ogMgMol@413o0000ob4Q8Oo<c<`3ooooo`05ohN7Qol@413o0000oa0@4?mgMgL00oooool01Ol@
413o0000o`000?nj^[[oA4A400;o000000So8B4QooooooooooooQhN7oa0@4?l0003o410@ogMgMg;o
oooo001Qooooo`06o`000?oooooooooooooooon7QhOo<S8b3?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo08oooooo001Pooooo`Go000000?oEEEEonk^k_ooool02oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo08oooooo001cooooo`03oa0@4?oooooooooo01Sooooo
00?o410@ooooooooool02?ooool00ol@413oooooooooo`0=ooooo`03oa0@4?l0003o0000017ooooo
00?o410@ooooooooool06?ooool00ol@413oooooooooo`08ooooo`;o0000>?ooool00ol@413o0000
ooooo`2@ooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00
\
\>"],
  ImageRangeCache->{{{0, 431}, {369.312, 0}} -> {0.0498317, 0.00618555, \
0.00359581, 0.00359581}}]
}, Open  ]],

Cell[TextData[{
  "The solution varies smoothly throughout most of the spherical volume. \
However, near the surface at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  " there is a Gibbs phenomenon due to the discontinuity in the boundary \
conditions. Fortunately this phenomenon vanishes as one moves inward, away \
from the surface."
}], "Text",
  CellTags->"i:79"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2.5 3D Cylindrical Geometry", "Subsubtitle",
  CellTags->"c:39"],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  CellTags->"c:40"],

Cell[TextData[{
  " \tConsider a hollow cylindrical tube of length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " and radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", with closed ends at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z = L\)]],
  ". We will describe the solution in cylindrical coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta], z)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x = r\ cos\ \[Theta]\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = r\ sin\ \[Theta]\)]],
  ". The potential on the sides of the tube at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  " is specified by a function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_A\)(\[Theta], z)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](a, \[Theta], z) = \(\[Phi]\_A\)(\[Theta], 
          z)\)]],
  ","
}], "Text"],

Cell[TextData[{
  " and the potentials on the bottom and top of the tube are specified by \
functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_B\)(r, \[Theta])\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_C\)(r, \[Theta])\)]],
  " respectively:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta], 0) = \(\[Phi]\_B\)(
          r, \[Theta]), \[IndentingNewLine]\[Phi](r, \[Theta], 
          L) = \(\(\(\[Phi]\_C\)(r, \[Theta])\)\(.\)\(\ \)\)\)]],
  " "
}], "Text"],

Cell["\<\
In order to solve Laplace's equation for the potential within the \
cylinder, it is best to follow the strategy discussed in the previous section \
on rectangular geometry, and break the problem into three separate problems, \
each of which has a nonzero potential only on one surface.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Nonzero Potential on One Cylinder End: Bessel \
Functions", "Subsubsection"]], "Section",
  CellTags->{"i:68", "c:41"}],

Cell[TextData[{
  "\t One of these three problems has boundary conditions  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta], L) = \(\[Phi]\_C\)(
          r, \[Theta])\)]],
  " and",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\[Phi]\)\(=\)\(0\)\(\ \)\)\)\)]],
  "on the rest of the cylinder. Anticipating that the eigenmodes in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " vary as ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\)\)]],
  ", we look for a solution of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell["\[Phi]"], \((r, \[Theta], z)\)}], 
          "=", \(\(R(
              r)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\)\ \(\(Z(
                z)\)\(.\)\)\)}], TraditionalForm]]],
  " Applying ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " to this form using Eq. ",
  ButtonBox["(3.2.16)",
    ButtonData:>"(3.2.16)",
    ButtonStyle->"Hyperlink"],
  ", one finds that"
}], "Text",
  CellTags->"i:100"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi]\/\[Phi] = \(\(1\/\(r\ \(R(
                      r)\)\)\) \(\[PartialD]\/\[PartialD]r\) \((r \
\[PartialD]R\/\[PartialD]r)\)\  - 
            m\^2\/r\^2 + \(1\/\(Z(z)\)\) \[PartialD]\^2 Z\/\[PartialD]z\^2 = 
          0\)\)]],
  "."
}], "NE2",
  CellTags->"(3.2.43)"],

Cell[TextData[{
  "Separating variables results in the following equation for  ",
  Cell[BoxData[
      \(TraditionalForm\`Z(z)\)]],
  " :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 Z\/\[PartialD]z\^2 = \[Kappa]\ z\)]],
  ","
}], "NE2",
  CellTags->"(3.2.44)"],

Cell[TextData[{
  "where \[Kappa] is a separation constant. Thus, the general solution for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["Z",
            "TraditionalForm"], "(", "z", ")"}], TraditionalForm]]],
  "  is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(Z(z)\)\(\ \)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`A\ \[ExponentialE]\^\(\(\@\[Kappa]\) z\) + \ 
        B\[ExponentialE]\^\(\(-\@\[Kappa]\) z\)\)]],
  ","
}], "NE2",
  CellTags->"(3.2.45)"],

Cell[TextData[{
  "and can be either  exponential or oscillatory, depending on the sign of \
\[Kappa]. (We will find that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] > 0\)]],
  "). The  boundary condition that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " is satisfied by taking ",
  Cell[BoxData[
      \(TraditionalForm\`B = \(-A\)\)]],
  " . Thus, the ",
  StyleBox["z",
    FontSlant->"Italic"],
  "-solution is ",
  Cell[BoxData[
      \(TraditionalForm\`Z(z)\  = \ 2  A\ \(sinh(\(\@\[Kappa]\) z)\)\)]],
  " . "
}], "Text"],

Cell[CellGroupData[{

Cell["Bessel Functions", "Subsubsection",
  CellTags->"i:80"],

Cell[TextData[{
  "\t The separated equation for ",
  Cell[BoxData[
      \(TraditionalForm\`R(r)\)]],
  " is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/r\) \(\(\(\[PartialD]\)\(\ \)\)\/\[PartialD]r\) \
\((r \[PartialD]\ R\/\[PartialD]r)\) - \(m\^2\/r\^2\) R + \[Kappa]\ R\  = \ 
        0\)]],
  ". "
}], "NE2",
  CellTags->"(3.2.46)"],

Cell[TextData[{
  "This is a second order ODE with a regular singular point at the origin. \
The boundary conditions on this problem are that ",
  Cell[BoxData[
      \(TraditionalForm\`R\  = \ 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  ",",
  " and that ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " is finite at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  " (the regular singular point at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  " implies that the solution can blow up there.) With these boundary \
conditions, one possible solution is ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0\)]],
  ". Thus, Eq. ",
  ButtonBox["(3.2.46)",
    ButtonData:>"(3.2.46)",
    ButtonStyle->"Hyperlink"],
  " is another eigenvalue problem, where in this case the eigenvalue is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\)]],
  ". "
}], "Text",
  CellTags->"i:106"],

Cell[TextData[{
  "\tThe dependence of ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\)]],
  " can be taken into account through a simple change in variables,  "
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`r\&_ = \@\[Kappa]\ r\)]],
  ","
}], "NE2",
  CellTags->"(3.2.47)"],

Cell["yielding", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(\(r\&_\)\(\ \)\)\) \
\(\[PartialD]\/\[PartialD]r\&_\) \((\(r\&_\) \[PartialD]R\/\[PartialD]r\&_)\) \
- \((m\^2\/r\&_\^2 - 1)\) \(R(r\&_)\) = 0\)]],
  "."
}], "NE2",
  CellTags->"(3.2.48)"],

Cell[TextData[{
  "This ODE is ",
  StyleBox[ButtonBox["Bessel's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Bessel.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  " ",
  StyleBox["equation. ",
    FontSlant->"Italic"],
  " The general solution is in terms of two independent functions, called ",
  StyleBox["Bessel functions of the first kind, ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(J\_m\)(\ r\&_)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(Y\_m\)(r\&_)\)\)\)]],
  ":"
}], "Text",
  CellTags->"i:81"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`R(r\&_) = 
        A\ \(\(J\_m\)(\ r\&_)\) + B\ \(\(Y\_m\)(r\&_)\)\)]],
  "."
}], "NE2",
  CellTags->"(3.2.49)"],

Cell[TextData[{
  "The subscript ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " on these functions is the ",
  StyleBox["order",
    FontSlant->"Italic"],
  " of the Bessel function. The functions depend on ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " through its appearance in Bessel's equation, Eq. ",
  ButtonBox["(3.2.48)",
    ButtonData:>"(3.2.48)",
    ButtonStyle->"Hyperlink"],
  ".  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " calls these Bessel functions ",
  StyleBox["BesselJ[m,",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["r",
            FontSlant->"Plain"], "_"], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "and ",
  StyleBox["BesselY[m,",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["r",
            FontSlant->"Plain"], "_"], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "respectively. We plot these functions in Cells ",
  ButtonBox["3.25",
    ButtonData:>"Cell 3.25",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["3.26",
    ButtonData:>"Cell 3.26",
    ButtonStyle->"Hyperlink"],
  " for several integer values of ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ":"
}], "Text",
  CellTags->"i:82"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(Plot[{BesselJ[0, r], BesselJ[1, r], BesselJ[2, r]}, {r, 0, 10}, 
        PlotStyle \[Rule] {Red, Blue, Green}, 
        PlotLabel \[Rule] \*"\"\<\!\(J\_m\)(r) for m=0,1,2\>\"", 
        AxesLabel \[Rule] {"\<r\>", "\< \>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.25"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.183713 0.419605 [
[.21429 .17121 -3 -9 ]
[.21429 .17121 3 0 ]
[.40476 .17121 -3 -9 ]
[.40476 .17121 3 0 ]
[.59524 .17121 -3 -9 ]
[.59524 .17121 3 0 ]
[.78571 .17121 -3 -9 ]
[.78571 .17121 3 0 ]
[.97619 .17121 -6 -9 ]
[.97619 .17121 6 0 ]
[1.025 .18371 0 -6 ]
[1.025 .18371 10 6 ]
[.01131 .01587 -24 -4.5 ]
[.01131 .01587 0 4.5 ]
[.01131 .09979 -24 -4.5 ]
[.01131 .09979 0 4.5 ]
[.01131 .26763 -18 -4.5 ]
[.01131 .26763 0 4.5 ]
[.01131 .35156 -18 -4.5 ]
[.01131 .35156 0 4.5 ]
[.01131 .43548 -18 -4.5 ]
[.01131 .43548 0 4.5 ]
[.01131 .5194 -18 -4.5 ]
[.01131 .5194 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -52.75 0 ]
[.5 .63053 52.75 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .18371 m
.21429 .18996 L
s
[(2)] .21429 .17121 0 1 Mshowa
.40476 .18371 m
.40476 .18996 L
s
[(4)] .40476 .17121 0 1 Mshowa
.59524 .18371 m
.59524 .18996 L
s
[(6)] .59524 .17121 0 1 Mshowa
.78571 .18371 m
.78571 .18996 L
s
[(8)] .78571 .17121 0 1 Mshowa
.97619 .18371 m
.97619 .18996 L
s
[(10)] .97619 .17121 0 1 Mshowa
.125 Mabswid
.07143 .18371 m
.07143 .18746 L
s
.11905 .18371 m
.11905 .18746 L
s
.16667 .18371 m
.16667 .18746 L
s
.2619 .18371 m
.2619 .18746 L
s
.30952 .18371 m
.30952 .18746 L
s
.35714 .18371 m
.35714 .18746 L
s
.45238 .18371 m
.45238 .18746 L
s
.5 .18371 m
.5 .18746 L
s
.54762 .18371 m
.54762 .18746 L
s
.64286 .18371 m
.64286 .18746 L
s
.69048 .18371 m
.69048 .18746 L
s
.7381 .18371 m
.7381 .18746 L
s
.83333 .18371 m
.83333 .18746 L
s
.88095 .18371 m
.88095 .18746 L
s
.92857 .18371 m
.92857 .18746 L
s
.25 Mabswid
0 .18371 m
1 .18371 L
s
gsave
1.025 .18371 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01587 m
.03006 .01587 L
s
[(-0.4)] .01131 .01587 1 0 Mshowa
.02381 .09979 m
.03006 .09979 L
s
[(-0.2)] .01131 .09979 1 0 Mshowa
.02381 .26763 m
.03006 .26763 L
s
[(0.2)] .01131 .26763 1 0 Mshowa
.02381 .35156 m
.03006 .35156 L
s
[(0.4)] .01131 .35156 1 0 Mshowa
.02381 .43548 m
.03006 .43548 L
s
[(0.6)] .01131 .43548 1 0 Mshowa
.02381 .5194 m
.03006 .5194 L
s
[(0.8)] .01131 .5194 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03685 m
.02756 .03685 L
s
.02381 .05783 m
.02756 .05783 L
s
.02381 .07881 m
.02756 .07881 L
s
.02381 .12077 m
.02756 .12077 L
s
.02381 .14175 m
.02756 .14175 L
s
.02381 .16273 m
.02756 .16273 L
s
.02381 .20469 m
.02756 .20469 L
s
.02381 .22567 m
.02756 .22567 L
s
.02381 .24665 m
.02756 .24665 L
s
.02381 .28861 m
.02756 .28861 L
s
.02381 .3096 m
.02756 .3096 L
s
.02381 .33058 m
.02756 .33058 L
s
.02381 .37254 m
.02756 .37254 L
s
.02381 .39352 m
.02756 .39352 L
s
.02381 .4145 m
.02756 .4145 L
s
.02381 .45646 m
.02756 .45646 L
s
.02381 .47744 m
.02756 .47744 L
s
.02381 .49842 m
.02756 .49842 L
s
.02381 .54038 m
.02756 .54038 L
s
.02381 .56136 m
.02756 .56136 L
s
.02381 .58234 m
.02756 .58234 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -113.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(J) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.375 13.000 moveto
(H) show
80.375 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.375 13.000 moveto
(L) show
98.375 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(for) show
122.375 13.000 moveto
(m) show
128.500 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
140.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
146.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
152.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
158.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
164.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02499 .6033 L
.02605 .60326 L
.02729 .60318 L
.02846 .60307 L
.03053 .6028 L
.03279 .60239 L
.03527 .6018 L
.0379 .60103 L
.04262 .59924 L
.04749 .59686 L
.05205 .59414 L
.06244 .58623 L
.07305 .57575 L
.08274 .5641 L
.10458 .53119 L
.14429 .45151 L
.18248 .35892 L
.22313 .25533 L
.26226 .16264 L
.28223 .12146 L
.30384 .08336 L
.32471 .05395 L
.33464 .04272 L
.34391 .03392 L
.35375 .02637 L
.36273 .02113 L
.36785 .01884 L
.3727 .01714 L
.37518 .01644 L
.37782 .01583 L
.3792 .01557 L
.38072 .01532 L
.3821 .01513 L
.38339 .01498 L
.38453 .01488 L
.38574 .0148 L
.38643 .01476 L
.38709 .01474 L
.38831 .01472 L
.3896 .01472 L
.39079 .01475 L
.3921 .01482 L
.39276 .01486 L
.39349 .01492 L
.39579 .01517 L
.39827 .01555 L
.40274 .01651 L
.40833 .01822 L
.41364 .02033 L
Mistroke
.4236 .02558 L
.43321 .03214 L
.44344 .04062 L
.46184 .05938 L
.50348 .11424 L
.54359 .17477 L
.5822 .2303 L
.60178 .2547 L
.62325 .27711 L
.63313 .28565 L
.64371 .29343 L
.65363 .29938 L
.66279 .3037 L
.66764 .30551 L
.67299 .30713 L
.67837 .30835 L
.68131 .30885 L
.68407 .30921 L
.68654 .30944 L
.68778 .30952 L
.68849 .30956 L
.68913 .30959 L
.6903 .30962 L
.69154 .30964 L
.69268 .30964 L
.69377 .30962 L
.69504 .30958 L
.69567 .30955 L
.69638 .30951 L
.69878 .30932 L
.70013 .30918 L
.70158 .309 L
.70421 .30861 L
.70948 .30754 L
.71436 .30621 L
.72542 .30208 L
.73517 .29717 L
.74553 .29073 L
.78325 .25826 L
.82342 .21319 L
.86208 .16705 L
.90319 .12332 L
.92369 .10592 L
.94278 .09326 L
.95893 .08554 L
.96797 .08248 L
.97619 .08052 L
Mfstroke
0 0 1 r
.02381 .18371 m
.06244 .26709 L
.10458 .34612 L
.12507 .37671 L
.14415 .39931 L
.1536 .4082 L
.16254 .41512 L
.16748 .41832 L
.17284 .42127 L
.17735 .42334 L
.18221 .42513 L
.18475 .42589 L
.18708 .42648 L
.18945 .42697 L
.19165 .42733 L
.19298 .4275 L
.1942 .42763 L
.19554 .42774 L
.19628 .42779 L
.19698 .42782 L
.19825 .42786 L
.19941 .42787 L
.20069 .42785 L
.20134 .42782 L
.20205 .42779 L
.20345 .42769 L
.20479 .42757 L
.20729 .42724 L
.20999 .42676 L
.21292 .42608 L
.2182 .42446 L
.22307 .4225 L
.2327 .41739 L
.24174 .41112 L
.26234 .39182 L
.28252 .36688 L
.30103 .33964 L
.34065 .27166 L
.37876 .20163 L
.41932 .13243 L
.45837 .07989 L
.46861 .06927 L
.47971 .05945 L
.48931 .05242 L
.49986 .04633 L
.50482 .04406 L
.51013 .04206 L
.51515 .04057 L
.51974 .03956 L
.52242 .03913 L
Mistroke
.52491 .03882 L
.52634 .03869 L
.52763 .0386 L
.52835 .03856 L
.52913 .03852 L
.52986 .0385 L
.53054 .03849 L
.53177 .03848 L
.53291 .03849 L
.53417 .03853 L
.53488 .03856 L
.53552 .0386 L
.53682 .03869 L
.53823 .03882 L
.54078 .03913 L
.54313 .0395 L
.54565 .03999 L
.55021 .04112 L
.55563 .04286 L
.5606 .04483 L
.57084 .04997 L
.58162 .05687 L
.6014 .07316 L
.61978 .0919 L
.65888 .13972 L
.70043 .19482 L
.74046 .24303 L
.75881 .26133 L
.77898 .27769 L
.78859 .28392 L
.79889 .28941 L
.80458 .2919 L
.80978 .29382 L
.81471 .29534 L
.81995 .29662 L
.82465 .29747 L
.82733 .29783 L
.82985 .29809 L
.83097 .29818 L
.83215 .29826 L
.83315 .29831 L
.83425 .29835 L
.83545 .29838 L
.83672 .29839 L
.83792 .29838 L
.83901 .29836 L
.8403 .29831 L
.84096 .29828 L
.84167 .29824 L
.84413 .29806 L
Mistroke
.84551 .29792 L
.847 .29775 L
.84968 .29736 L
.85495 .29636 L
.85976 .29515 L
.86962 .29182 L
.87876 .28776 L
.89949 .2753 L
.92003 .25908 L
.93864 .24172 L
.97619 .20195 L
Mfstroke
0 1 0 r
.02381 .18371 m
.02499 .18372 L
.02605 .18374 L
.02729 .18378 L
.02846 .18384 L
.03053 .18397 L
.03279 .18418 L
.03527 .18447 L
.0379 .18486 L
.04262 .18575 L
.04749 .18694 L
.05205 .18829 L
.06244 .19223 L
.07305 .19742 L
.08274 .20316 L
.10458 .21923 L
.14429 .257 L
.18248 .29842 L
.22313 .34027 L
.24192 .35665 L
.26226 .3711 L
.27341 .37731 L
.28367 .38182 L
.29348 .385 L
.29842 .38617 L
.30101 .38666 L
.30384 .3871 L
.30656 .38743 L
.30776 .38754 L
.30908 .38765 L
.31024 .38772 L
.31149 .38779 L
.31281 .38783 L
.31404 .38785 L
.31517 .38785 L
.31641 .38783 L
.3177 .38779 L
.3189 .38774 L
.32003 .38767 L
.32105 .38759 L
.32335 .38737 L
.32603 .38702 L
.32851 .38662 L
.33411 .38541 L
.33904 .384 L
.34426 .38217 L
.3537 .37797 L
.36384 .3722 L
.38215 .35857 L
.40332 .33806 L
Mistroke
.42343 .3145 L
.46167 .26152 L
.50237 .19964 L
.54155 .1426 L
.56157 .11688 L
.58319 .09301 L
.60409 .07462 L
.61404 .06769 L
.6233 .06234 L
.63241 .05816 L
.63709 .05644 L
.64217 .0549 L
.64506 .05417 L
.64773 .0536 L
.65023 .05315 L
.65299 .05275 L
.65546 .05248 L
.65659 .05239 L
.65777 .0523 L
.65905 .05223 L
.66021 .05219 L
.66147 .05216 L
.66218 .05215 L
.66284 .05216 L
.66413 .05217 L
.66477 .05219 L
.66548 .05221 L
.66674 .05227 L
.66791 .05235 L
.67056 .05258 L
.67339 .05294 L
.6786 .05385 L
.68334 .05499 L
.69289 .05814 L
.70194 .06214 L
.72183 .07421 L
.74024 .08897 L
.77947 .12914 L
.81719 .1738 L
.85736 .22047 L
.89602 .25774 L
.91603 .27225 L
.92623 .27813 L
.93713 .28321 L
.94243 .28521 L
.94745 .28682 L
.95234 .28812 L
.95684 .28907 L
.96112 .28977 L
.96327 .29004 L
Mistroke
.96565 .29028 L
.96803 .29045 L
.96936 .29052 L
.97058 .29056 L
.97171 .29059 L
.97295 .2906 L
.97412 .2906 L
.9752 .29058 L
.97619 .29056 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003ooooooona
ooooo`00oooooonaooooo`00oooooonaooooo`00:?ooool00ol0003oooooooooo`3oooooohKooooo
000Xooooo`03o`000?oooooooooo0?ooooooQ_ooool002Sooooo00?o0000ooooooooool0oooooon6
ooooo`00:?ooool00ol0003oooooooooo`3oooooohKooooo000;ooooo`04okZj^_l@413o0000ogMg
M`Kooooo00?oEEEEo`000?mEEED01oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooon6ooooo`002_ooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00008
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooon6ooooo`002_ooool01_m4
A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED01?ooool6o`0000Kooooo1?l0
0021ooooo`Woo`00n_ooool00003ooooool0003o000000Go00000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00[ooooo00GoIVIVojVYZOooooooooooo`000007ooooo`03o`000?oo
oooooooo07gooooo1Ooo0009ooooo`Coo`00m_ooool000[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0:ooooo`05onk^k_lQ8B7ok^k^ooooool000001oooool00ol0003ooooooooo
o`1kooooo`;oo`004_ooool2ool00?Cooooo000:ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02oooool01?nYZJWoIVIVooooool00007ooooo`03o`000?oooooooooo07[ooooo00?o
o`00ooooooooool05?ooool2ool00?;ooooo000:ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A4
3_ooool00om4A4Coc<c<o`000007ooooo`03o`000?oooooooooo07Sooooo0_oo000Iooooo`;oo`00
l?ooool000[ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`>ooooo`03omgMgOm4A4Co000000Oo
oooo00?o0000ooooooooool0Moooool00ooo003oooooooooo`0Kooooo`;oo`00k_ooool000_ooooo
00Co^[Zjoa0@4?l@413oc<c<4?ooool00on7QhOo0000ooooo`06ooooo`03o`000?oooooooooo07Ko
oooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`3[ooooo`00:?ooool00ol0003ooooo
ooooo`1eooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool0joooool002Sooooo0ol0
001dooooo`03ool00?oooooooooo027ooooo00?oo`00ooooooooool0j_ooool002Sooooo00?o0000
ooooooooool0Loooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo01[ooooo3Ol00?o2
ooooo`00:?ooool00ol0003oooooooooo`1booooo`03ool00?oooooooooo02Gooooo00?oo`00oooo
ooooool05_ooool3o`00o`gooooo0_l00?o0ooooo`00:?ooool00ol0003oooooooooo`1booooo`03
ool00?oooooooooo02Kooooo00?oo`00ooooooooool04oooool2o`00oa;ooooo0ol00?nmooooo`00
:?ooool00ol0003oooooooooo`1aooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool0
4?ooool2o`00oaOooooo0_l00?nkooooo`00:?ooool00ol0003oooooooooo`1`ooooo`03ool00?oo
oooooooo02[ooooo00?oo`00ooooooooool03Oooool2o`00oa_ooooo0_l00?niooooo`00:?ooool0
0ol0003oooooooooo`1_ooooo`03ool00?oooooooooo02cooooo00?oo`00ooooooooool02_ooool2
o`00oaoooooo00?o003oooooooooool06Oooool;o`3o09;ooooo000Xooooo`03o`000?oooooooooo
06kooooo00?oo`00ooooooooool0;_ooool00ooo003oooooooooo`08ooooo`03o`00oooooooooooo
023ooooo00?o003oooooooooool05?ooool4o`3o00_ooooo1?l0o`2>ooooo`00:?ooool3o`0006ko
oooo00?oo`00ooooooooool0;oooool00ooo003oooooooooo`06ooooo`03o`00oooooooooooo02;o
oooo0_l00?l@ooooo`Co0?l04oooool3o`3o08_ooooo000Xooooo`03o`000?oooooooooo06gooooo
00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`03ooooo`;o003o9oooool00ol00?oooooo
ooooo`0<ooooo`03o`3o0?oooooooooo01Sooooo00?o0?l0ooooooooool0R?ooool002Sooooo00?o
0000ooooooooool0K?ooool00ooo003oooooooooo`0booooo`03ool00?oooooooooo00;ooooo00?o
003oooooooooool0:?ooool00ol00?ooooooooooo`09ooooo`;o0?l07?ooool2o`3o08Sooooo000X
ooooo`03o`000?oooooooooo06_ooooo00?oo`00ooooooooool0=?ooool01?oo003oooooooooool0
0?l/ooooo`;o003o1oooool2o`3o023ooooo0_l0o`26ooooo`00:?ooool00ol0003oooooooooo`1[
ooooo`03ool00?oooooooooo03Gooooo00?oo`00o`00ooooool0;_ooool00ol00?ooooooooooo`02
ooooo`;o0?l09?ooool2o`3o08Cooooo000Xooooo`03o`000?oooooooooo06[ooooo00?oo`00oooo
ooooool0=_ooool00ol00?ooo`00ooooo`0_ooooo`04o`00ooooooooooooo`3o02Sooooo0_l0o`22
ooooo`00:?ooool00ol0003oooooooooo`1Yooooo`03ool00?oooooooooo03Kooooo00Co003ooooo
ooooooooo`00<?ooool2o`3o02_ooooo0_l0o`20ooooo`00:?ooool00ol0003oooooooooo`1Yoooo
o`03ool00?oooooooooo03Gooooo00Go003oooooooooooooooooool0000_ooooo`03o`3o0?oooooo
003o02gooooo00?o0?l0ooooooooool0OOooool002Sooooo0ol0001Xooooo`03ool00?oooooooooo
03Gooooo00?o003oooooooooool00oooool00ooo003oooooooooo`0[ooooo`05o`3o0?oooooooooo
ooooool00?l0;Oooool00ol0o`3oooooooooo`1looooo`00:?ooool00ol0003oooooooooo`1Woooo
o`03ool00?oooooooooo03Kooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`0Yoooo
o`03o`3o0?oooooooooo00?ooooo00?o003oooooooooool0:oooool00ol0o`3oooooooooo`1Doooo
o`Goo`008_ooool002Sooooo00?o0000ooooooooool0I_ooool00ooo003oooooooooo`0fooooo`03
o`00oooooooooooo00Kooooo00?oo`00ooooooooool09oooool00ol0o`3oooooooooo`05ooooo`03
o`00oooooooooooo02_ooooo00?o0?l0ooooooooool0D_ooool00ooo003oooooooooo`0Uooooo`00
:?ooool00ol0003oooooooooo`1Vooooo`03ool00?oooooooooo03Gooooo00?o003oooooooooool0
2?ooool00ooo003oooooooooo`0Uooooo`03o`3o0?oooooooooo00Oooooo00?o003oooooooooool0
:oooool00ol0o`3oooooooooo`1?ooooo`;oo`00:?ooool002Sooooo00?o0000ooooooooool0IOoo
ool00ooo003oooooooooo`0eooooo`03o`00oooooooooooo00Wooooo00?oo`00ooooooooool09?oo
ool00ol0o`3oooooooooo`09ooooo`03o`00oooooooooooo02_ooooo00?o0?l0ooooooooool0Booo
ool3ool002[ooooo000;ooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?oo
ool6o`0000Kooooo00?o0000ooooooooool0IOooool00ooo003oooooooooo`0eooooo`03o`00oooo
oooooooo00[ooooo00?oo`00ooooooooool08_ooool00ol0o`3oooooooooo`0;ooooo`03o`00oooo
oooooooo02[ooooo00?o0?l0ooooooooool0B?ooool3ool002gooooo000:ooooo`06olc<c?lb<S;o
k^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00?oV9RHo`000?o<c<`00_ooool00ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo06Cooooo00?oo`00ooooooooool0=Oooool00ol00?oooooo
ooooo`0<ooooo`03ool00?oooooooooo027ooooo00?o0?l0ooooooooool02oooool00ol00?oooooo
ooooo`0[ooooo`03o`3o0?oooooooooo04Kooooo00?oo`00ooooooooool0;_ooool000[ooooo00Ko
A4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Gooooo00?oV9RHo`000?o<
c<`02?ooool00ol0003oooooooooo`1Sooooo`03ool00?oooooooooo03Gooooo00?o003ooooooooo
ool03_ooool00ooo003oooooooooo`0Oooooo`03o`3o0?oooooooooo00gooooo00?o003ooooooooo
ool0:oooool00ol0o`3oooooooooo`13ooooo`;oo`00<Oooool00003ooooool0003o000000Go0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?oZJVYoa0@4?o<c<`0
1oooool4o`0006;ooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`0@ooooo`03ool0
0?oooooooooo01gooooo00?o0?l0ooooooooool03oooool00ol00?ooooooooooo`0[ooooo`03o`3o
0?oooooooooo047ooooo00?oo`00ooooooooool0<Oooool000[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0=ooooo`03olc<c?l@413oc<c<00Kooooo00?o0000ooooooooool0H_oo
ool00ooo003oooooooooo`0eooooo`03o`00oooooooooooo013ooooo00?oo`00ooooooooool07?oo
ool00ol0o`3oooooooooo`0Aooooo`03o`00oooooooooooo02_ooooo00?o0?l0ooooooooool0?ooo
ool00ooo003oooooooooo`0booooo`002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00kooooo00?oZJVYoc8b<_ooool01Oooool00ol0003oooooooooo`1Rooooo`03ool00?oooooo
oooo03Cooooo00?o003oooooooooool04_ooool00ooo003oooooooooo`0Jooooo`03o`3o0?oooooo
oooo01?ooooo00?o003oooooooooool0:oooool00ol0o`3oooooooooo`0looooo`;oo`00=Oooool0
00[ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@Aooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0HOooool00ooo003oooooooooo`0dooooo`03o`00oooooooooooo01Cooooo00?o
o`00ooooooooool06?ooool00ol0o`3oooooooooo`0Dooooo`03o`00oooooooooooo02cooooo00?o
0?l0ooooooooool0>_ooool00ooo003oooooooooo`0eooooo`002_ooool01_o<c<co<S8bonk^k_o^
k^ko<S8bolc<c0cooooo00Ko0000ohN7Qoo^k^koooooogMgMolb<S86ooooo`03o`000?oooooooooo
067ooooo00?oo`00ooooooooool0<oooool00ol00?ooooooooooo`0Fooooo`03ool00?oooooooooo
01Kooooo00?o0?l0ooooooooool05_ooool00ol00?ooooooooooo`0/ooooo`03o`3o0?oooooooooo
03Sooooo00?oo`00ooooooooool0=_ooool000_ooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool01_nY
ZJWo<S8bo`000?l0003oEEEEonk^kPKooooo00?o0000ooooooooool0H?ooool00ooo003ooooooooo
o`0dooooo`03o`00oooooooooooo01Oooooo00?oo`00ooooooooool05?ooool00ol0o`3ooooooooo
o`0Hooooo`03o`00oooooooooooo02cooooo00?o0?l0ooooooooool0=_ooool00ooo003ooooooooo
o`0gooooo`00:?ooool00ol0003oooooooooo`1Oooooo`03ool00?oooooooooo03Cooooo00?o003o
ooooooooool06?ooool00ooo003oooooooooo`0Cooooo`03o`3o0?oooooooooo01[ooooo00?o003o
ooooooooool0;?ooool00ol0o`3oooooooooo`0dooooo`03ool00?oooooooooo03Sooooo000Xoooo
o`03o`000?oooooooooo05oooooo00?oo`00ooooooooool0<oooool00ol00?ooooooooooo`0Joooo
o`03ool00?oooooooooo01;ooooo00?o0?l0ooooooooool06_ooool00ol00?ooooooooooo`0]oooo
o`03o`3o0?oooooooooo03;ooooo00?oo`00ooooooooool0>Oooool002Sooooo0ol0001Nooooo`03
ool00?oooooooooo03?ooooo00?o003oooooooooool07?ooool00ooo003oooooooooo`0@ooooo`03
o`3o0?oooooooooo01cooooo00?o003oooooooooool0;Oooool00ol0o`3oooooooooo`0`ooooo`03
ool00?oooooooooo03[ooooo000Xooooo`03o`000?oooooooooo05kooooo00?oo`00ooooooooool0
<oooool00ol00?ooooooooooo`0Looooo`03ool00?oooooooooo00oooooo00?o0?l0ooooooooool0
7_ooool00ol00?ooooooooooo`0]ooooo`03o`3o0?oooooooooo02kooooo00?oo`00ooooooooool0
>oooool002Sooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`0cooooo`03o`00oooo
oooooooo01kooooo00?oo`00ooooooooool03Oooool00ol0o`3oooooooooo`0Pooooo`03o`00oooo
oooooooo02gooooo00?o0?l0ooooooooool0;?ooool00ooo003oooooooooo`0looooo`00:?ooool0
0ol0003oooooooooo`1Mooooo`03ool00?oooooooooo03;ooooo00?o003oooooooooool08?ooool0
0ooo003oooooooooo`0;ooooo`03o`3o0?oooooooooo02;ooooo00?o003oooooooooool0;Oooool0
0ol0o`3oooooooooo`0Zooooo`03ool00?oooooooooo03gooooo000Xooooo`03o`000?oooooooooo
05cooooo00?oo`00ooooooooool0<_ooool00ol00?ooooooooooo`0Qooooo`03ool00?oooooooooo
00_ooooo00?o0?l0ooooooooool08_ooool00ol00?ooooooooooo`0]ooooo`03o`3o0?oooooooooo
02Wooooo00?oo`00ooooooooool0?_ooool002Sooooo00?o0000ooooooooool0G?ooool00ooo003o
ooooooooo`0booooo`03o`00oooooooooooo02;ooooo00?oo`00ooooooooool02Oooool00ol0o`3o
ooooooooo`0Tooooo`03o`00oooooooooooo02gooooo00?o0?l0ooooooooool09oooool00ooo003o
ooooooooo`0oooooo`00:?ooool00ol0003oooooooooo`1Kooooo`03ool00?oooooooooo03;ooooo
00?o003oooooooooool09?ooool00ooo003oooooooooo`07ooooo`03o`3o0?oooooooooo02Kooooo
00?o003oooooooooool0;Oooool00ol0o`3oooooooooo`0Uooooo`03ool00?oooooooooo043ooooo
000Xooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool0<_ooool00ol00?oooooooooo
o`0Tooooo`03ool00?oooooooooo00Kooooo00?o0?l0ooooooooool0:?ooool00ol00?oooooooooo
o`0]ooooo`03o`3o0?oooooooooo02?ooooo00?oo`00ooooooooool0@Oooool002Sooooo0ol0001J
ooooo`03ool00?oooooooooo03;ooooo00?o003oooooooooool09_ooool00ooo003oooooooooo`04
ooooo`03o`3o0?oooooooooo02Wooooo00?o003oooooooooool0;_ooool00ol0o`3oooooooooo`0Q
ooooo`03ool00?oooooooooo04;ooooo000Xooooo`03o`000?oooooooooo047ooooo1_l0000Coooo
o`03ool00?oooooooooo02kooooo0_l000000ol@413o003oooooo`0Yooooo`03ool00?oooooooooo
00?ooooo00?o0?l0ooooooooool03_ooool01_o^k^koA4A4o`000?l0003oEEEEonk^kQKooooo00?o
003oooooooooool0:?ooool01oo^k^koA4A4o`000?l0003oA4A4onk^k_l0o`008Oooool00ooo003o
ooooooooo`0Iooooo`Co000000?o410@ooooooooool00_ooool01?nj^[[o410@o`000?mgMgLMoooo
o`00:?ooool00ol0003oooooooooo`11ooooo`03oiRHV?l0003oc<c<00;ooooo00?o410@oooooooo
ool04Oooool00ooo003oooooooooo`0_ooooo`03o`000?oooooo003o02[ooooo00?oo`00oooooooo
ool00_ooool00ol0o`3oooooooooo`0?ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE5oooool0
0ol00?ooooooooooo`0Wooooo`08oc8b<_mgMgOok^k^onk^k_mgMgOo<S8booooool0o`0Oooooo`03
ool00?oooooooooo01cooooo00?o0000ooooooooool00oooool01_o<c<co<S8bonk^k_o^k^ko8B4Q
ojVYZAcooooo000Xooooo`03o`000?oooooooooo04;ooooo00?oV9RHo`000?o<c<`05?ooool00ooo
003oooooooooo`0/ooooo`Go000000?o003oooooooooool0:_ooool01?oo003oooooooooool0o`0B
ooooo`03oa0@4?oooooooooo00;ooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`0V
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0?l07Oooool00ooo003ooooooooo
o`0Mooooo`03o`000?oooooooooo00?ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S8Looooo`00
:?ooool00ol0003oooooooooo`13ooooo`03ojVYZOl@413oc<c<01?ooooo00?oo`00ooooooooool0
;?ooool01_mVIVKoZJVYoooooooooooo0000o`00obcooooo00Coo`00oooooooooooo0?l04_ooool0
0ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool09Oooool0
1_lb<S;oMgMgonk^k_o^k^koMgMgoc8b<P?ooooo00?o0?l0ooooooooool06Oooool00ooo003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Jooooo`00:?ooool00ol0003oooooooooo`14ooooo`03olc<c?l@413oc<c<017ooooo00?o
o`00ooooooooool0;Oooool01Oo^k^ko8B4Qonk^k_oooooo003o02kooooo00?oo`00o`3o0?ooool0
4_ooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEAWooooo00?o003oooooooooool09Oooool00ooM
gMgo0000o`000002o`000005omgMgOooooooooooooooool0o`006_ooool00ooo003oooooooooo`0O
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0J
ooooo`00:?ooool00ol0003oooooooooo`15ooooo`03ojVYZOlb<S;ooooo013ooooo00?oo`00oooo
ooooool0;_ooool01?nYZJWoIVIVooooool00?l^ooooo`03o`3o0?oo003ooooo01;ooooo00Ko8B4Q
ofIVI_l0003o0000oeEEEOo^k^hJooooo`03o`00oooooooooooo02Cooooo00Ko<S8bofIVI_o^k^ko
k^k^ofIVI_lb<S84ooooo`03o`3o0?oooooooooo01Kooooo00?oo`00ooooooooool08?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool002So
oooo0ol00016ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0<?ooool00om4A4Co
003oo`00000^ooooo`03o`3o0?oo003ooooo01;ooooo00?oQhN7ofIVI_ooool07_ooool00ol00?oo
ooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0o`3o
ooooooooo`0Dooooo`03ool00?oooooooooo027ooooo00?o0000ooooooooool00oooool01_m4A4Co
ZJVYooooooooooooZJVYodA4A1cooooo000Xooooo`03o`000?oooooooooo047ooooo00Ko0000ohN7
Qoo^k^koooooogMgMolb<S8@ooooo`03ool00?oooooooooo033ooooo00?o003oodA4A?l00000;Ooo
ool01?l0o`3ooooooooooooo000Cooooo`03oc8b<_mVIVKogMgM01kooooo00?o003oooooooooool0
8_ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<PKooooo00?o0?l0ooooooooool04_ooool00ooo
003oooooooooo`0Pooooo`03o`000?m4A4Co000000Gooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<
c<`Looooo`00:?ooool00ol0003oooooooooo`11ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^
3oooool00ooo003oooooooooo`0aooooo`03o`00oon7QhOo000002cooooo00?o0?l0ooooooooool0
0_ooool00ooo003oooooooooo`0Aooooo`04ogMgMol@413o0000ob4Q8Agooooo00?o003ooooooooo
ool08Oooool01_o^k^koA4A4o`000?l0003oA4A4onk^kPOooooo00?o0?l0ooooooooool04?ooool0
0ooo003oooooooooo`0Qooooo`03olc<c?mEEEGo000000Kooooo00Co^[Zjoa0@4?l@413oc<c<7Ooo
ool002Sooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`0`ooooo`03o`00oooooooo
oooo02gooooo00?o0?l0ooooooooool00_ooool00ooo003oooooooooo`0booooo`03o`00oooooooo
oooo02oooooo00?o0?l0ooooooooool03oooool00ooo003oooooooooo`1;ooooo`00:?ooool00ol0
003oooooooooo`1Eooooo`03ool00?oooooooooo037ooooo00?o003oooooooooool0;?ooool00ol0
o`3oooooooooo`04ooooo`03ool00?oooooooooo03;ooooo00?o003oooooooooool0;oooool00ol0
o`3oooooooooo`0=ooooo`03ool00?oooooooooo04cooooo000Xooooo`03o`000?oooooooooo05Go
oooo00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`0/ooooo`03o`3o0?oooooooooo00Ko
oooo00?oo`00ooooooooool0<_ooool00ol00?ooooooooooo`0_ooooo`03o`3o0?oooooooooo00_o
oooo00?oo`00ooooooooool0@Oooool6o`0000Kooooo000Xooooo`03o`000?oooooooooo05Gooooo
00?oo`00ooooooooool0;oooool00ol00?ooooooooooo`0]ooooo`03o`3o0?oooooooooo00Kooooo
00?oo`00ooooooooool0<oooool00ol00?ooooooooooo`0^ooooo`03o`3o0?oooooooooo00[ooooo
00?oo`00ooooooooool0A?ooool00ol0003oooooooooo`07ooooo`00:?ooool00ol0003ooooooooo
o`1Dooooo`03ool00?oooooooooo033ooooo00?o003oooooooooool0;?ooool00ol0o`3ooooooooo
o`08ooooo`03ool00?oooooooooo03?ooooo00?o003oooooooooool0;_ooool00ol0o`3ooooooooo
o`08ooooo`03ool00?oooooooooo04Gooooo00?o0000ooooooooool01oooool001oooooo2Ol00005
o`3o05;o000000?oo`00o`000?l00000;ol000000ol00?oo0000o`00000/o`000003o`3o0?l0003o
000000[o000000?oo`00o`000?l00000<_l000000ol00?oo0000o`00000_o`000003o`3o0?l0003o
000000Ko000000?oo`00o`000?l00000=ol0000?ooooo`03o`000?oooooooooo00Oooooo000Xoooo
o`04o`00ooooooooooooooooo`Go0?l02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`04ool00?oooooo
ooooo`00017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`00oooo
oooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00;ooooo00?o0?l0ooooooooool02_ooool00ol0003oo`00ooooo`0>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03oooool00ol0003o003oooooo`0?ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03?ooool01?l0o`3oooooooooool00004ooooo`03ool0
0?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01Kooooo00?o0000omgMgOooool01oooool002Sooooo00?o0000o`00ooooool01_oo
ool5o`3o00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool02oooool01?oo003oooooooooool0000Aooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo0?l000go
oooo00?o0000ool00?ooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooool00?l03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00go
oooo00?o0?l0ooooool000000oooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`;o000000?oV9RHoooooooo
ool01Oooool002Sooooo00?o0000o`00ooooool02oooool3o`3o03Oooooo00?o0000ooooooooool0
2_ooool00ooo003oooooooooo`0`ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool0
9?ooool00ol0o`3oooooooooo`0>ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool0
9?ooool00ol00?ooooooooooo`0Nooooo`03o`000?oooooooooo00kooooo00Go0?l0oooooooooooo
ooooool0000aooooo`03o`000?oooooooooo01Cooooo00Go410@o`000?l0003o^[ZjodA4A002o`00
0003ob4Q8Ooooooooooo00;ooooo000Xooooo`03o`000?oooooo003o00kooooo0_l0o`12ooooo`03
ool00?oooooooooo02oooooo00?o003oooooooooool0;?ooool00ol0o`3oooooooooo`0?ooooo`03
ool00?oooooooooo03?ooooo00?o003oooooooooool0;oooool00ol0o`3oooooool0001Eooooo`00
:?ooool00ol0003oooooo`00o`0@ooooo`03o`3o0?oooooooooo03oooooo00?oo`00ooooooooool0
;_ooool00ol00?ooooooooooo`0/ooooo`03o`3o0?oooooooooo013ooooo00?oo`00ooooooooool0
<oooool00ol00?ooooooooooo`0`ooooo`03o`3o0?oooooooooo05Cooooo000Xooooo`04o`000?oo
ooooooooo`00oa3ooooo00?o0?l0ooooooooool0?Oooool00ooo003oooooooooo`0_ooooo`03o`00
oooooooooooo02_ooooo00?o0?l0ooooooooool04_ooool00ooo003oooooooooo`0cooooo`03o`00
oooooooooooo02oooooo00?oo`00o`3o0?ooool0E?ooool002Sooooo00Co0000oooooooooooo003o
4Oooool00ol0o`3oooooooooo`0looooo`03ool00?oooooooooo02kooooo00?o003oooooooooool0
;?ooool00ol0o`3oooooooooo`0Cooooo`03ool00?oooooooooo03?ooooo00?o003oooooooooool0
;Oooool00ooo003oooooo`3o000booooo`03o`00oooooooooooo023ooooo000Xooooo`?o000000?o
ooooo`00ooooool04?ooool2o`3o03_ooooo00?oo`00ooooooooool0;oooool00ol00?oooooooooo
o`0[ooooo`03o`3o0?oooooooooo01Gooooo00?oo`00ooooooooool0<oooool00ol00?oooooooooo
o`0[ooooo`05ool00?ooooooooooooooool0o`00<Oooool00ol00?ooooooooooo`0Pooooo`00:?oo
ool01Ol0003ooooooooooooooooo003o01?ooooo00?o0?l0ooooooooool0>?ooool00ooo003ooooo
ooooo`0^ooooo`03o`00oooooooooooo02_ooooo00?o0?l0ooooooooool05_ooool00ooo003ooooo
ooooo`0dooooo`03o`00oooooooooooo02Wooooo00?oo`00ooooooooool00oooool00ol0o`3ooooo
ooooo`0]ooooo`03o`00oooooooooooo027ooooo000Xooooo`05o`000?ooooooooooooooool00?l0
5?ooool00ol0o`3oooooooooo`0fooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
:oooool00ol0o`3oooooooooo`0Gooooo`03ool00?oooooooooo03?ooooo00?o003oooooooooool0
:?ooool00ooo003oooooooooo`05ooooo`03o`3o0?oooooooooo02_ooooo00?o003oooooooooool0
8_ooool002Sooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Booooo`;o0?l0=_oo
ool00ooo003oooooooooo`0^ooooo`03o`00oooooooooooo02_ooooo00?o0?l0ooooooooool06Ooo
ool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo02Kooooo00?oo`00ooooooooool01ooo
ool00ol0o`3oooooooooo`0Yooooo`03o`00oooooooooooo02?ooooo000Xooooo`03o`000?oooooo
oooo00;ooooo00?o003oooooooooool05?ooool00ol0o`3oooooooooo`0cooooo`03ool00?oooooo
oooo02kooooo00?o003oooooooooool0:_ooool00ol0o`3oooooooooo`0Jooooo`03ool00?oooooo
oooo03Cooooo00?o003oooooooooool09Oooool00ooo003oooooooooo`08ooooo`03o`3o0?oooooo
oooo02Oooooo00?o003oooooooooool09?ooool002Sooooo00?o0000ooooooooool00oooool00ol0
0?ooooooooooo`0Dooooo`03o`3o0?oooooooooo037ooooo00?oo`00ooooooooool0;_ooool00ol0
0?ooooooooooo`0Zooooo`03o`3o0?oooooooooo01cooooo00?oo`00ooooooooool0=?ooool00ol0
0?ooooooooooo`0Sooooo`03ool00?oooooooooo00[ooooo00?o0?l0ooooooooool09Oooool00ol0
0?ooooooooooo`0Uooooo`00:?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo01Go
oooo0_l0o`0aooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0:oooool00ol0o`3o
ooooooooo`0Mooooo`03ool00?oooooooooo03Cooooo00?o003oooooooooool08Oooool00ooo003o
ooooooooo`0<ooooo`03o`3o0?oooooooooo02?ooooo00?o003oooooooooool09_ooool002Sooooo
00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`3o0?oooooooooo02gooooo
00?oo`00ooooooooool0;_ooool00ol00?ooooooooooo`0Zooooo`03o`3o0?oooooooooo01oooooo
00?oo`00ooooooooool0<oooool00ol00?ooooooooooo`0Pooooo`03ool00?oooooooooo00kooooo
00?o0?l0ooooooooool08Oooool00ol00?ooooooooooo`0Wooooo`00:?ooool3o`0000Cooooo00?o
003oooooooooool05oooool00ol0o`3oooooooooo`0/ooooo`03ool00?oooooooooo02gooooo00?o
003oooooooooool0:_ooool00ol0o`3oooooooooo`0Pooooo`03ool00?oooooooooo03Cooooo00?o
003oooooooooool07_ooool00ooo003oooooooooo`0@ooooo`03o`3o0?oooooooooo01oooooo00?o
003oooooooooool0:?ooool002Sooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0G
ooooo`03o`3o0?oooooooooo02[ooooo00?oo`00ooooooooool0;_ooool00ol00?ooooooooooo`0Z
ooooo`03o`3o0?oooooooooo027ooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`0L
ooooo`03ool00?oooooooooo01;ooooo00?o0?l0ooooooooool07Oooool00ol00?ooooooooooo`0Y
ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo01Sooooo00?o0?l0oooo
ooooool0:Oooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo02[ooooo00?o0?l0oooo
ooooool08oooool00ooo003oooooooooo`0dooooo`03o`00oooooooooooo01[ooooo00?oo`00oooo
ooooool05?ooool00ol0o`3oooooooooo`0Kooooo`03o`00oooooooooooo02[ooooo000Xooooo`03
o`000?oooooooooo00Kooooo00?o003oooooooooool06?ooool00ol0o`3oooooooooo`0Xooooo`03
ool00?oooooooooo02gooooo00?o003oooooooooool0:Oooool00ol0o`3oooooooooo`0Tooooo`03
ool00?oooooooooo03Cooooo00?o003oooooooooool06Oooool00ooo003oooooooooo`0Fooooo`03
o`3o0?oooooooooo01Wooooo00?o003oooooooooool0:oooool002Sooooo00?o0000ooooooooool0
1_ooool00ol00?ooooooooooo`0Iooooo`03o`3o0?oooooooooo02Kooooo00?oo`00ooooooooool0
;Oooool00ol00?ooooooooooo`0Zooooo`03o`3o0?oooooooooo02Gooooo00?oo`00ooooooooool0
=?ooool00ol00?ooooooooooo`0Gooooo`03ool00?oooooooooo01Sooooo00?o0?l0ooooooooool0
5oooool00ol00?ooooooooooo`0/ooooo`00:?ooool00ol0003oooooooooo`07ooooo`03o`00oooo
oooooooo01Wooooo00?o0?l0ooooooooool09Oooool00ooo003oooooooooo`0]ooooo`03o`00oooo
oooooooo02Wooooo00?o0?l0ooooooooool09oooool00ooo003oooooooooo`0dooooo`03o`00oooo
oooooooo01Kooooo00?oo`00ooooooooool06Oooool00ol0o`3oooooooooo`0Eooooo`03o`00oooo
oooooooo02gooooo000Xooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool06_ooool0
0ol0o`3oooooooooo`0Sooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0:Oooool0
0ol0o`3oooooooooo`0Yooooo`03ool00?oooooooooo03Cooooo00?o003oooooooooool05?ooool0
0ooo003oooooooooo`0Kooooo`03o`3o0?oooooooooo01?ooooo00?o003oooooooooool0;_ooool0
02Sooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0Jooooo`03o`3o0?oooooooooo
02;ooooo00?oo`00ooooooooool0;Oooool00ol00?ooooooooooo`0Yooooo`03o`3o0?oooooooooo
02[ooooo00?oo`00ooooooooool0=?ooool2o`00oa?ooooo00?oo`00ooooooooool07Oooool00ol0
o`3oooooooooo`0Aooooo`03o`00oooooooooooo02oooooo000Xooooo`?o00002?ooool00ol00?oo
ooooooooo`0Kooooo`03o`3o0?oooooooooo023ooooo00?oo`00ooooooooool0;Oooool00ol00?oo
ooooooooo`0Yooooo`03o`3o0?oooooooooo02_ooooo00?oo`00ooooooooool0=_ooool00ol00?oo
ooooooooo`0?ooooo`03ool00?oooooooooo01oooooo00?o0?l0ooooooooool03oooool00ol00?oo
ooooooooo`0`ooooo`00:?ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo01cooooo
00?o0?l0ooooooooool07oooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo02Sooooo
00?o0?l0ooooooooool0;Oooool00ooo003oooooooooo`0fooooo`03o`00oooooooooooo00gooooo
00?oo`00ooooooooool08Oooool00ol0o`3oooooooooo`0=ooooo`03o`00oooooooooooo037ooooo
000Xooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool07?ooool00ol0o`3ooooooooo
o`0Nooooo`03ool00?oooooooooo02cooooo00?o003oooooooooool0:?ooool00ol0o`3ooooooooo
o`0_ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool02oooool00ooo003ooooooooo
o`0Sooooo`03o`3o0?oooooooooo00_ooooo00?o003oooooooooool0<_ooool002Sooooo00?o0000
ooooooooool02Oooool00ol00?ooooooooooo`0Mooooo`03o`3o0?oooooooooo01cooooo00?oo`00
ooooooooool0;?ooool00ol00?ooooooooooo`0Yooooo`03o`3o0?oooooooooo033ooooo00?oo`00
ooooooooool0=_ooool00ol00?ooooooooooo`09ooooo`03ool00?oooooooooo02Gooooo00?o0?l0
ooooooooool02Oooool00ol00?ooooooooooo`0cooooo`00:?ooool00ol0003oooooooooo`0:oooo
o`03o`00oooooooooooo01gooooo00?o0?l0ooooooooool06oooool00ooo003oooooooooo`0/oooo
o`03o`00oooooooooooo02Sooooo00?o0?l0ooooooooool0<_ooool00ooo003oooooooooo`0foooo
o`03o`00oooooooooooo00Kooooo0_oo000Yooooo`;o0?l02?ooool00ol00?ooooooooooo`0doooo
o`002oooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo1_l00006oooo
o`03o`000?oooooooooo00[ooooo00?o003oooooooooool07_ooool00ol0o`3oooooooooo`0Ioooo
o`03ool00?oooooooooo02cooooo00?o003oooooooooool0:?ooool00ol0o`3oooooooooo`0doooo
o`03ool00?oooooooooo03Kooooo00?o003oooooooooool01?ooool00ooo003oooooooooo`0[oooo
o`03o`3o0?oooooooooo00?ooooo0_l00?lgooooo`002_ooool01_o<c<co<S8bonk^k_o^k^ko8B4Q
ojVYZ@Gooooo0ol00004ooooo`03oiRHV?l0003oc<c<00;ooooo00?o410@ooooooooool01?ooool0
0ol0003oooooooooo`0;ooooo`03o`00oooooooooooo01kooooo00?o0?l0ooooooooool06?ooool0
0ooo003oooooooooo`0/ooooo`03o`00oooooooooooo02Sooooo00?o0?l0ooooooooool0=Oooool0
0ooo003oooooooooo`0fooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool0;Oooool2
o`3o00;ooooo00?o003oooooooooool0=oooool000[ooooo00KoA4A4ojVYZOooooooooooojVYZOlb
<S85ooooo`03oeEEEOl0003oEEEE00Gooooo00?oV9RHo`000?o<c<`02?ooool00ol0003ooooooooo
o`0;ooooo`03o`00oooooooooooo01oooooo00?o0?l0ooooooooool05oooool00ooo003ooooooooo
o`0[ooooo`03o`00oooooooooooo02Sooooo00?o0?l0ooooooooool0=oooool00ooo003ooooooooo
o`0fooooo`04o`00ooooooooooooool003;ooooo0_l0o`0jooooo`002_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo00?oZJVYoa0@4?o<c<`01oooool4o`0000_ooooo00?o
003oooooooooool07oooool00ol0o`3oooooooooo`0Eooooo`03ool00?oooooooooo02cooooo00?o
003oooooooooool09oooool00ol0o`3oooooooooo`0iooooo`03ool00?oooooooooo03Kooooo00?o
003oool00?ooool0<Oooool2o`00o`03ooooool0o`3ooooo03Sooooo000:ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03Oooool00oo<c<co410@olc<c006ooooo`03o`000?oooooo
oooo00cooooo00?o003oooooooooool08?ooool00ol0o`3oooooooooo`0Dooooo`03ool00?oooooo
oooo02_ooooo00?o003oooooooooool0:?ooool00ol0o`3oooooooooo`0jooooo`03ool00?oooooo
oooo03Gooooo00?oo`00o`00ooooool0<?ooool00ol00?ooooooooooo`02ooooo`03o`3o0?oooooo
oooo03Kooooo000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00onY
ZJWo<S8booooo`05ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool08?ooool00ol0
o`3oooooooooo`0Booooo`03ool00?oooooooooo02cooooo00?o003oooooooooool09oooool00ol0
o`3oooooooooo`0looooo`03ool00?oooooooooo03;ooooo0_oo0002ooooo`03o`00oooooooooooo
02gooooo00?o003oooooooooool01?ooool00ol0o`3oooooooooo`0eooooo`002_ooool01_m4A4Co
ZJVYooooooooooooZJVYodA4A17ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=
ooooo`03o`00oooooooooooo027ooooo00?o0?l0ooooooooool04Oooool00ooo003oooooooooo`0[
ooooo`03o`00oooooooooooo02Oooooo00?o0?l0ooooooooool0?_ooool00ooo003oooooooooo`0`
ooooo`03ool00?oooooooooo00?ooooo00?o003oooooooooool0:_ooool2o`00o`Sooooo00?o0?l0
ooooooooool0=?ooool000[ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`<ooooo`06o`000?n7
QhOok^k^oooooomgMgOo<S8b1_ooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo027o
oooo00?o0?l0ooooooooool04?ooool00ooo003oooooooooo`0[ooooo`03o`00oooooooooooo02Ko
oooo00?o0?l0ooooooooool0@?ooool00ooo003oooooooooo`0^ooooo`03ool00?oooooooooo00Go
oooo0_l00?lXooooo`;o003o2oooool2o`3o03Cooooo000;ooooo`04okZj^_l@413o410@olc<c0go
oooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h6ooooo`03o`000?oooooooooo00kooooo00?o003o
ooooooooool08_ooool00ol0o`3oooooooooo`0>ooooo`03ool00?oooooooooo02_ooooo00?o003o
ooooooooool09oooool00ol0o`3oooooooooo`11ooooo`03ool00?oooooooooo02cooooo00?oo`00
ooooooooool02?ooool2o`00obGooooo00?o003oooooooooool03Oooool3o`3o037ooooo000Xoooo
o`03o`000?oooooooooo00oooooo00?o003oooooooooool08_ooool00ol0o`3oooooooooo`0=oooo
o`03ool00?oooooooooo02[ooooo00?o003oooooooooool09oooool00ol0o`3oooooooooo`13oooo
o`03ool00?oooooooooo02[ooooo00?oo`00ooooooooool02oooool2o`00ob7ooooo0_l00?lCoooo
o`?o0?l0;_ooool002Sooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0Sooooo`03
o`3o0?oooooooooo00cooooo00?oo`00ooooooooool0:_ooool00ol00?ooooooooooo`0Vooooo`03
o`3o0?oooooooooo04Gooooo0_oo000Yooooo`03ool00?oooooooooo00kooooo0_l00?lMooooo`;o
003o6?ooool4o`3o02[ooooo000Xooooo`?o00004?ooool00ol00?ooooooooooo`0Sooooo`03o`3o
0?oooooooooo00[ooooo00?oo`00ooooooooool0:_ooool00ol00?ooooooooooo`0Wooooo`03o`3o
0?oooooooooo04Oooooo0_oo000Uooooo`;oo`004oooool2o`00oaWooooo0_l00?lNooooo`So0?l0
8_ooool002Sooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`0Tooooo`03o`3o0?oo
oooooooo00Wooooo00?oo`00ooooooooool0:_ooool00ol00?ooooooooooo`0Vooooo`03o`3o0?oo
oooooooo04[ooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0Eooooo`;o003o5Ooo
ool2o`00od[ooooo000Xooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool09?ooool0
0ol0o`3oooooooooo`07ooooo`03ool00?oooooooooo02[ooooo00?o003oooooooooool09_ooool0
0ol0o`3oooooooooo`1<ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool06?ooool4
o`00o`kooooo0ol00?m<ooooo`00:?ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo
02Gooooo00?o0?l0ooooooooool01_ooool00ooo003oooooooooo`0Zooooo`03o`00oooooooooooo
02Kooooo00?o0?l0ooooooooool0COooool00ooo003oooooooooo`0Looooo`;oo`007oooool>o`00
odoooooo000Xooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool09?ooool00ol0o`3o
ooooooooo`06ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool09_ooool00ol0o`3o
ooooooooo`1?ooooo`?oo`006Oooool2ool007kooooo000Xooooo`03o`000?oooooooooo01;ooooo
00?o003oooooooooool09Oooool00ol0o`3oooooooooo`04ooooo`03ool00?oooooooooo02Wooooo
00?o003oooooooooool09_ooool00ol0o`3oooooooooo`1Cooooo`?oo`004oooool3ool0083ooooo
000Xooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool09Oooool00ol0o`3ooooooooo
o`03ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool09Oooool00ol0o`3ooooooooo
o`1Gooooo`;oo`003_ooool3ool008?ooooo000Xooooo`?o00005?ooool00ol00?ooooooooooo`0U
ooooo`05o`3o0?oooooooooooooooooo0000:oooool00ol00?ooooooooooo`0Vooooo`03o`3o0?oo
oooooooo05Wooooo1ooo00000oooooooo`00ool00004ool008Kooooo000Xooooo`03o`000?oooooo
oooo01Cooooo00?o003oooooooooool09_ooool01?l0o`3ooooooooooooo000[ooooo`03o`00oooo
oooooooo02Gooooo00?o0?l0ooooooooool0H?ooool2ool008cooooo000Xooooo`03o`000?oooooo
oooo01Gooooo00?o003oooooooooool09_ooool00ol0o`3oooooool0000Zooooo`03o`00oooooooo
oooo02Gooooo00?o0?l0ooooooooool0koooool002Sooooo00?o0000ooooooooool05Oooool00ol0
0?ooooooooooo`0Wooooo`03o`3o0?oooooooooo02Sooooo00?o003oooooooooool09_ooool00ol0
o`3oooooooooo`3_ooooo`00:?ooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo02Ko
oooo00?oo`00o`3o0?ooool0:?ooool00ol00?ooooooooooo`0Uooooo`03o`3o0?oooooooooo0?3o
oooo000Xooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool09_ooool00ooo003ooooo
o`3o000Wooooo`03o`00oooooooooooo02Gooooo00?o0?l0ooooooooool0lOooool002Sooooo00?o
0000ooooooooool05oooool00ol00?ooooooooooo`0Tooooo`05ool00?ooooooooooooooool0o`00
9_ooool00ol00?ooooooooooo`0Tooooo`03o`3o0?oooooooooo0?;ooooo000Xooooo`03o`000?oo
oooooooo01Oooooo00?o003oooooooooool09?ooool00ooo003oooooooooo`02ooooo`03o`3o0?oo
oooooooo02;ooooo00?o003oooooooooool09?ooool00ol0o`3oooooooooo`3cooooo`00:?ooool3
o`0001Sooooo00?o003oooooooooool08_ooool00ooo003oooooooooo`04ooooo`03o`3o0?oooooo
oooo027ooooo00?o003oooooooooool08oooool00ol0o`3oooooooooo`3dooooo`00:?ooool00ol0
003oooooooooo`0Hooooo`03o`00oooooooooooo02;ooooo00?oo`00ooooooooool01Oooool00ol0
o`3oooooooooo`0Oooooo`03o`00oooooooooooo02?ooooo00?o0?l0ooooooooool0mOooool002So
oooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Qooooo`03ool00?oooooooooo00Ko
oooo00?o0?l0ooooooooool07Oooool00ol00?ooooooooooo`0Sooooo`03o`3o0?oooooooooo0?Ko
oooo000Xooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool08?ooool00ooo003ooooo
ooooo`08ooooo`03o`3o0?oooooooooo01cooooo00?o003oooooooooool08_ooool00ol0o`3ooooo
ooooo`3gooooo`00:?ooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo01oooooo00?o
o`00ooooooooool02Oooool2o`3o01_ooooo00?o003oooooooooool08oooool00ol0o`3ooooooooo
o`3gooooo`00:?ooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo01kooooo00?oo`00
ooooooooool03?ooool00ol0o`3oooooooooo`0Hooooo`03o`00oooooooooooo02;ooooo00?o0?l0
ooooooooool0n?ooool000_ooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@07
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`00oooooooo
oooo01gooooo00?oo`00ooooooooool03Oooool00ol0o`3oooooooooo`0Fooooo`03o`00oooooooo
oooo02;ooooo00?o0?l0ooooooooool0nOooool000[ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnY
ZJT5ooooo`?o00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo00?o
003oooooooooool07Oooool00ooo003oooooooooo`0>ooooo`03o`3o0?oooooooooo01Cooooo00?o
003oooooooooool08_ooool00ol0o`3oooooooooo`3jooooo`002_ooool01_m4A4CoZJVYoooooooo
ooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED01?ooool6o`0000Kooooo1?l0000Kooooo`03o`00
oooooooooooo01_ooooo00?oo`00ooooooooool04?ooool00ol0o`3oooooooooo`0Cooooo`03o`00
oooooooooooo027ooooo00?o0?l0ooooooooool0noooool000[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0:ooooo`05ofIVI_nYZJWoooooooooool000001oooool00ol0003ooooo
ooooo`0Mooooo`03o`00oooooooooooo01[ooooo00?oo`00ooooooooool04Oooool00ol0o`3ooooo
ooooo`0Aooooo`03o`00oooooooooooo027ooooo00?o0?l0ooooooooool0o?ooool000[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05onk^k_lQ8B7ok^k^ooooool00000
1oooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo01[ooooo00?oo`00ooooooooool0
4_ooool2o`3o013ooooo00?o003oooooooooool08Oooool00ol0o`3oooooooooo`3mooooo`002_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00CoZJVYofIVI_oooooo0000
1oooool00ol0003oooooooooo`0Nooooo`03o`00oooooooooooo01Sooooo00?oo`00ooooooooool0
5Oooool00ol0o`3oooooooooo`0<ooooo`03o`00oooooooooooo023ooooo0_l0o`3oooooo`7ooooo
000:ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A43_ooool00om4A4Coc<c<o`000007ooooo`03
o`000?oooooooooo01oooooo00?o003oooooooooool05oooool00ooo003oooooooooo`0Fooooo`03
o`3o0?oooooooooo00_ooooo00?o003oooooooooool07oooool00ol0o`3oooooooooo`3oooooo`7o
oooo000:ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3_ooool00ooMgMgoA4A4o`000007oooo
o`03o`000?oooooooooo01oooooo00?o003oooooooooool05_ooool00ooo003oooooooooo`0Hoooo
o`;o0?l02_ooool00ol00?ooooooooooo`0Nooooo`;o0?l0ooooool4ooooo`002oooool01?nj^[[o
410@oa0@4?o<c<`@ooooo`03ohN7Qol0003ooooo00Kooooo00?o0000ooooooooool08?ooool00ol0
0?ooooooooooo`0Eooooo`03ool00?oooooooooo01[ooooo00?o0?l0ooooooooool01_ooool00ol0
0?ooooooooooo`0Nooooo`03o`3o0?oooooooooo0?oooooo1?ooool002Sooooo00?o0000oooooooo
ool08Oooool00ol00?ooooooooooo`0Cooooo`03ool00?oooooooooo01cooooo00?o0?l0oooooooo
ool01Oooool00ol00?ooooooooooo`0Mooooo`03o`3o0?oooooooooo0?oooooo1Oooool002Sooooo
0ol0000Qooooo`03o`00oooooooooooo01?ooooo00?oo`00ooooooooool07Oooool2o`3o00Cooooo
00?o003oooooooooool07?ooool2o`3o0?oooooo2?ooool002Sooooo00?o0000ooooooooool08_oo
ool00ol00?ooooooooooo`0Booooo`03ool00?oooooooooo01oooooo0_l0o`000ooooooo003ooooo
o`0Looooo`;o0?l0ooooool:ooooo`00:?ooool00ol0003oooooooooo`0Sooooo`03o`00oooooooo
oooo013ooooo00?oo`00ooooooooool08_ooool2o`3o01_ooooo0_l0o`3oooooo`cooooo000Xoooo
o`03o`000?oooooooooo02?ooooo00?o003oooooooooool04?ooool00ooo003oooooooooo`0Qoooo
o`03o`00oooooooooooo00;o0?l05oooool2o`3o0?oooooo3_ooool002Sooooo00?o0000oooooooo
ool09?ooool00ol00?ooooooooooo`0>ooooo`03ool00?oooooooooo02;ooooo00?o003ooooooooo
ool00_ooool3o`3o017ooooo0ol0o`3ooooooa3ooooo000Xooooo`03o`000?oooooooooo02Gooooo
00?o003oooooooooool03Oooool00ooo003oooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo
1?l0o`09ooooo`Co0?l0oooooolCooooo`00:?ooool00ol0003oooooooooo`0Vooooo`03o`00oooo
oooooooo00_ooooo00?oo`00ooooooooool08Oooool00ol00?ooooooooooo`0;ooooo`Wo0?l0oooo
oolGooooo`00:?ooool00ol0003oooooooooo`0Wooooo`03o`00oooooooooooo00[ooooo00?oo`00
ooooooooool08?ooool00ol00?ooooooooooo`3oooooobcooooo000Xooooo`?o0000:?ooool00ol0
0?ooooooooooo`09ooooo`03ool00?oooooooooo01oooooo00?o003oooooooooool0ooooool]oooo
o`00:?ooool00ol0003oooooooooo`0Yooooo`03o`00oooooooooooo00Oooooo00?oo`00oooooooo
ool07oooool00ol00?ooooooooooo`3oooooobkooooo000Xooooo`03o`000?oooooooooo02[ooooo
0_l00?l7ooooo`03ool00?oooooooooo01kooooo00?o003oooooooooool0ooooool_ooooo`00:?oo
ool00ol0003oooooooooo`0/ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool07_oo
ool00ol00?ooooooooooo`3ooooooc3ooooo000Xooooo`03o`000?oooooooooo02gooooo00?o003o
ooooooooool00_ooool00ooo003oooooooooo`0Mooooo`03o`00oooooooooooo0?oooooo<Oooool0
02Sooooo00?o0000ooooooooool0;_ooool01?l00?oooooooooooooo000Oooooo`03o`00oooooooo
oooo0?oooooo<_ooool002Sooooo00?o0000ooooooooool0;oooool00ol00?ooooooool0000Noooo
o`03o`00oooooooooooo0?oooooo<oooool002Sooooo00?o0000ooooooooool0<?ooool00ol00?oo
o`00ooooo`0Kooooo`;o003ooooooolfooooo`00:?ooool3o`00033ooooo00?oo`00o`00ool00?l0
6Oooool2o`00oooooooo>?ooool002Sooooo00?o0000ooooooooool0<?ooool00ooo003ooooooooo
o`02o`00oaGooooo0_l00?oooooooc[ooooo000Xooooo`03o`000?oooooooooo02oooooo00?oo`00
ooooooooool00oooool2o`00oa;ooooo00?o003oooooooooool0ooooooljooooo`00:?ooool00ol0
003oooooooooo`0_ooooo`03ool00?oooooooooo00Gooooo0_l00?l>ooooo`;o003ooooooolmoooo
o`00:?ooool00ol0003oooooooooo`0^ooooo`03ool00?oooooooooo00Sooooo0ol00?l7ooooo`Co
003oooooooloooooo`002oooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Co
oooo00Kok^k^odA4A?l0003o0000oeEEEOo^k^h6ooooo`03o`000?oooooooooo02kooooo00?oo`00
ooooooooool02oooool7o`00oooooooo@oooool000[ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnY
ZJT5ooooo`?o00001?ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Kooooo00?o0000oooooooo
ool0;_ooool00ooo003oooooooooo`3ooooooeGooooo000:ooooo`06odA4A?nYZJWooooooooooonY
ZJWo<S8b1Oooool00omEEEGo0000oeEEE@04ooooo`03oa0@4?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0]ooooo`03ool00?oooooooooo0?ooooooE_ooool000[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?o^k^kooooo00;o
oooo00?o0000ooooooooool01?ooool4o`0002cooooo00?oo`00ooooooooool0oooooomFooooo`00
2_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko0000oeEEEOo^k^ko
ooooogMgMomEEED6ooooo`03o`000?oooooooooo02cooooo00?oo`00ooooooooool0oooooomGoooo
o`002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko8B4QofIVI_l0
003o0000oeEEEOo^k^h6ooooo`03o`000?oooooooooo02cooooo00?oo`00ooooooooool0oooooomG
ooooo`002_ooool01_m4A4CoZJVYooooooooooooZJVYodA4A0cooooo00?oQhN7ofIVI_ooool02Ooo
ool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo0?ooooooF?ooool000[ooooo00Koc<c<
oc8b<_o^k^kok^k^oc8b<_o<c<`=ooooo`03oc8b<_mVIVKogMgM00Sooooo00?o0000ooooooooool0
:oooool00ooo003oooooooooo`3ooooooeSooooo000;ooooo`04okZj^_l@413o410@olc<c0oooooo
00CoMgMgoa0@4?l0003o8B4Q1_ooool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo0?oo
ooooF?ooool002Sooooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`3ooooooeWooooo
000Xooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0oooooomIooooo`00:?ooool3
o`0002Wooooo00?oo`00ooooooooool0oooooomJooooo`00:?ooool00ol0003oooooooooo`0Yoooo
o`03ool00?oooooooooo0?ooooooF_ooool002Sooooo00?o0000ooooooooool0:?ooool00ooo003o
ooooooooo`3ooooooe_ooooo000Xooooo`03o`000?oooooooooo02Sooooo00?oo`00ooooooooool0
oooooomKooooo`00:?ooool00ol0003oooooooooo`0Wooooo`03ool00?oooooooooo0?ooooooG?oo
ool002Sooooo00?o0000ooooooooool09oooool00ooo003oooooooooo`3ooooooecooooo000Xoooo
o`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0oooooomMooooo`00:?ooool3o`0002Ko
oooo00?oo`00ooooooooool0oooooomMooooo`00:?ooool00ol0003oooooooooo`0Uooooo`03ool0
0?oooooooooo0?ooooooG_ooool002Sooooo00?o0000ooooooooool09Oooool00ooo003ooooooooo
o`3ooooooekooooo000Xooooo`03o`000?oooooooooo02Cooooo00?oo`00ooooooooool0oooooomO
ooooo`00:?ooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo0?ooooooGoooool002So
oooo00?o0000ooooooooool08oooool00ooo003oooooooooo`3oooooof3ooooo000Xooooo`03o`00
0?oooooooooo02?ooooo00?oo`00ooooooooool0oooooomPooooo`00:?ooool00ol0003ooooooooo
o`0Rooooo`03ool00?oooooooooo0?ooooooHOooool002Sooooo0ol0000Rooooo`03ool00?oooooo
oooo0?ooooooHOooool002Sooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`3ooooo
of;ooooo000Xooooo`03o`000?oooooooooo027ooooo00?oo`00ooooooooool0oooooomRooooo`00
:?ooool00ol0003oooooooooo`0Pooooo`03ool00?oooooooooo0?ooooooHoooool002Sooooo00?o
0000ooooooooool08?ooool00ooo003oooooooooo`3oooooof?ooooo000Xooooo`03o`000?oooooo
oooo01oooooo00?oo`00ooooooooool0oooooomTooooo`002oooool01?nj^[[o410@o`000?mgMgL6
ooooo`03oeEEEOl0003oEEEE00Cooooo00Kok^k^odA4A?l0003o0000odA4A?o^k^h6ooooo`03o`00
0?oooooooooo01oooooo00?oo`00ooooooooool0oooooomTooooo`002_ooool01_o<c<co<S8bonk^
k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`06oc8b<_mgMgOok^k^onk^k_mgMgOo<S8b1_ooool0
0ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0?ooooooIOooool000[ooooo00KoA4A4ojVY
ZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`Co00007Oooool00ooo003oooooooooo`3oooooofGooooo000:
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_lb<S;oMgMgonk^k_o^
k^koMgMgoc8b<PKooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`3oooooofKooooo
000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ooMgMgo0000o`00
0002o`000003omgMgOoooooooooo00Cooooo00?o0000ooooooooool07Oooool00ooo003ooooooooo
o`3oooooofKooooo000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool0
1_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<PKooooo00?o0000ooooooooool07?ooool00ooo003ooooo
ooooo`3oooooofOooooo000:ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A43?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool00ooo003o
ooooooooo`3oooooofOooooo000:ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool01_lb
<S;oIVIVonk^k_o^k^koIVIVoc8b<PKooooo00?o0000ooooooooool06oooool00ooo003ooooooooo
o`3oooooofSooooo000;ooooo`04okZj^_l@413o410@olc<c0gooooo00Kok^k^odA4A?l0003o0000
odA4A?o^k^h6ooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0oooooomXooooo`00
:?ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo0?ooooooJOooool002Sooooo0ol0
000Iooooo`03ool00?oooooooooo0?ooooooJ_ooool002Sooooo00?o0000ooooooooool06Oooool0
0ooo003oooooooooo`3oooooof[ooooo000Xooooo`03o`000?oooooooooo01Sooooo00?oo`00oooo
ooooool0oooooom[ooooo`00:?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0?oo
ooooK?ooool002Sooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`3oooooofcooooo
000Xooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0oooooom]ooooo`00:?ooool0
0ol0003oooooooooo`0Eooooo`03ool00?oooooooooo0?ooooooK_ooool002Sooooo00?o0000oooo
ooooool05Oooool00ooo003oooooooooo`3oooooofkooooo000Xooooo`?o00005?ooool00ooo003o
ooooooooo`3oooooofoooooo000Xooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0
oooooom`ooooo`00:?ooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo0?ooooooL?oo
ool002Sooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`3oooooog7ooooo000Xoooo
o`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0oooooombooooo`00:?ooool00ol0003o
ooooooooo`0@ooooo`03ool00?oooooooooo0?ooooooLoooool002Sooooo00?o0000ooooooooool0
3oooool00ooo003oooooooooo`3oooooogCooooo000Xooooo`03o`000?oooooooooo00kooooo00?o
o`00ooooooooool0oooooomeooooo`00:?ooool3o`0000gooooo00?oo`00ooooooooool0oooooomf
ooooo`00:?ooool00ol0003oooooooooo`0;ooooo`;oo`00oooooomiooooo`00:?ooool00ol0003o
ooooooooo`0:ooooo`03ool00?oooooooooo0?ooooooNOooool002Sooooo00?o0000ooooooooool0
2Oooool00ooo003oooooooooo`3oooooog[ooooo000Xooooo`03o`000?oooooooooo00Oooooo0_oo
003ooooooggooooo000Mooooo`Co000000?o410@ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`;oo`00oooooomoooooo`007oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo0_oo003ooooooh7ooooo000Oooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00ooo003ooooooh?ooooo000Oooooo`03o`000?oooooooooo00Kooooo0ooo00000ol0003ooooo
ooooo`3ooooooh?ooooo000Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oon6ooooo`007oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooQ_ooool0
01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooohKooooo000Mooooo`03
o`000?m4A4Co000000Sooooo00?o0000ooooooooool0oooooon6ooooo`007Oooool00oo<c<coEEEE
o`000008ooooo`03o`000?oooooooooo0?ooooooQ_ooool00?oooooo/Oooool00?oooooo/Oooool0
0?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00:Gooooo00?o^[Zj
oc8b<_ooool03?ooool00olb<S;o^[Zjooooo`3iooooo`00VOooool01Ol0003oooooo`000?oooooo
000000Oooooo00?o410@okZj^_ooool03?ooool00onj^[[o8B4Qooooo`1?ooooo`03o`000?nj^[[o
oooo00oooooo00?o0000okZj^_ooool0UOooool009Wooooo00Go0000ooooool0003oooooo`000006
ooooo`03okZj^_lb<S;ooooo00kooooo00?o<S8bokZj^_ooool0C_ooool00olQ8B7oEEEEooooo`0?
ooooo`03ob4Q8OmEEEGooooo09Gooooo002@ooooo`06ojVYZOlQ8B7o0000o`000?m4A4Coc<c<0ooo
ool01Ol0003oooooo`000?oooooo000000Kooooo00?oEEEEoiRHV?ooool00oooool6o`0000Gooooo
00?oV9RHoeEEEOooool03Oooool00ol@413o0000o`000002o`000003oa0@4?oooooooooo00;ooooo
00GoQhN7oa0@4?l0003o410@ohN7Q`03ooooo`Ko00002oooool02Ol@413o0000o`000?oooooo0000
oa0@4?oooooo0000oa0@400;ooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oIVIVo`000?o^k^h0
1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?oIVIVo`000?o^k^h01?ooool6o`0008_ooooo
002@ooooo`06o`000?n7QhOooooooooooomgMgOoA4A40oooool01Ol0003oooooo`000?oooooo0000
00Kooooo00?o410@olc<c?ooool01Oooool00ol0003oooooooooo`06ooooo`03omgMgOl@413ooooo
00oooooo00?o0000ooooooooool01?ooool01on7QhOo8B4Qolc<c?ooooooc<c<ob4Q8On7QhL01?oo
ool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
oooo1_l00002ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool00onHV9So0000ogMgM`07
ooooo`03o`000?oooooooooo00Gooooo00?oV9RHo`000?mgMgL01?ooool00onHV9So0000olc<c002
ooooo`03oa0@4?oooooooooo08Wooooo002@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o410@olc<c?ooool00_ooool00oo<
c<co410@ooooo`03ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`09ooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00ooMgMgo0000
oa0@4007ooooo`03o`000?oooooooooo00Gooooo00?ogMgMo`000?l@41001Oooool00onHV9So0000
olc<c02=ooooo`00T?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?oZJVYoa0@4?o<c<`0S?ooool009Gooooo00?o0000ooooooooool03?ooool00ol@413oc<c<oooo
o`05ooooo`03o`000?oMgMgooooo00Kooooo00?ogMgMoa0@4?ooool03oooool00ol0003ooooooooo
o`04ooooo`03oa0@4?nj^[[ooooo00;ooooo00?o^[Zjoa0@4?ooool00oooool00ol0003ogMgMoooo
o`0=ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo1_l00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03
olc<c?l@413oc<c<08_ooooo002Eooooo`03o`000?oooooooooo00cooooo00?oEEEEohN7Qoooool0
1Oooool2o`000003oiRHV?oooooooooo00Cooooo00?oV9RHoeEEEOooool03oooool00ol0003ooooo
ooooo`04ooooo`07ohN7QolQ8B7oc<c<ooooooo<c<co8B4QohN7Q`04ooooo`;o000000?oV9RHoooo
ooooool02oooool01ol0003oc<c<olc<c?l0003oQhN7olc<c?l000002oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool00onYZJWo<S8boooo
o`2:ooooo`00UOooool00ol0003oooooooooo`0<ooooo`03okZj^_l@413ooooo00?ooooo00Go410@
o`000?l0003o^[ZjodA4A002o`000006ob4Q8OoooooooooooooooolQ8B7o^[Zj3_ooool00ol@413o
0000o`000003o`0000Cooooo00GoQhN7oa0@4?l0003o410@ohN7Q`03ooooo`05oa0@4?l0003o0000
okZj^_m4A4@00_l000000olQ8B7oooooooooo`07ooooo`08oa0@4?l0003o8B4Qo`000?mgMgOo410@
o`000?n7QhL;ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A43oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo08Wooooo002Eooooo`03o`000?oooooooooo00gooooo00?o<S8bokZj
^_ooool03?ooool00onj^[[o8B4Qooooo`0@ooooo`03o`000?oooooooooo037ooooo00Koc<c<oc8b
<_o^k^kok^k^oc8b<_o<c<`=ooooo`03o`000?m4A4Co000000kooooo00Ko0000ohN7Qoo^k^kooooo
ogMgMolb<S:;ooooo`00T_ooool00ol@413o0000o`000002o`000003oa0@4?oooooooooo00_ooooo
00?o^[Zjoc8b<_ooool03?ooool00olb<S;o^[Zjooooo`0@ooooo`03oa0@4?nj^[[ooooo03;ooooo
00Co^[Zjoa0@4?l@413oc<c<3_ooool00oo<c<coEEEEo`00000>ooooo`06ojVYZOlb<S;o0000o`00
0?mEEEGok^k^Roooool00<Oooooo00Co^[Zjoa0@4?l0003o410@iOooool00?oooooo/Oooool00?oo
oooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oo
oooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00001
\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-1.13966, -0.462068, \
0.0420152, 0.00953623}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{BesselY[0, r], BesselY[1, r], BesselY[2, r]}, {r, 0, 10}, 
        PlotStyle \[Rule] {Red, Blue, Green}, PlotRange \[Rule] {\(-2\), 1}, 
        PlotLabel \[Rule] \*"\"\<\!\(Y\_m\)(r) for m=0,1,2\>\"", 
        AxesLabel \[Rule] {"\<r\>", "\< \>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.26"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.412023 0.206011 [
[.21429 .39952 -3 -9 ]
[.21429 .39952 3 0 ]
[.40476 .39952 -3 -9 ]
[.40476 .39952 3 0 ]
[.59524 .39952 -3 -9 ]
[.59524 .39952 3 0 ]
[.78571 .39952 -3 -9 ]
[.78571 .39952 3 0 ]
[.97619 .39952 -6 -9 ]
[.97619 .39952 6 0 ]
[1.025 .41202 0 -6 ]
[1.025 .41202 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -24 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -24 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -52.75 0 ]
[.5 .63053 52.75 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .41202 m
.21429 .41827 L
s
[(2)] .21429 .39952 0 1 Mshowa
.40476 .41202 m
.40476 .41827 L
s
[(4)] .40476 .39952 0 1 Mshowa
.59524 .41202 m
.59524 .41827 L
s
[(6)] .59524 .39952 0 1 Mshowa
.78571 .41202 m
.78571 .41827 L
s
[(8)] .78571 .39952 0 1 Mshowa
.97619 .41202 m
.97619 .41827 L
s
[(10)] .97619 .39952 0 1 Mshowa
.125 Mabswid
.07143 .41202 m
.07143 .41577 L
s
.11905 .41202 m
.11905 .41577 L
s
.16667 .41202 m
.16667 .41577 L
s
.2619 .41202 m
.2619 .41577 L
s
.30952 .41202 m
.30952 .41577 L
s
.35714 .41202 m
.35714 .41577 L
s
.45238 .41202 m
.45238 .41577 L
s
.5 .41202 m
.5 .41577 L
s
.54762 .41202 m
.54762 .41577 L
s
.64286 .41202 m
.64286 .41577 L
s
.69048 .41202 m
.69048 .41577 L
s
.7381 .41202 m
.7381 .41577 L
s
.83333 .41202 m
.83333 .41577 L
s
.88095 .41202 m
.88095 .41577 L
s
.92857 .41202 m
.92857 .41577 L
s
.25 Mabswid
0 .41202 m
1 .41202 L
s
gsave
1.025 .41202 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-1.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-0.5)] .01131 .30902 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(0.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -113.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.375 13.000 moveto
(H) show
80.375 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.375 13.000 moveto
(L) show
98.375 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(for) show
122.375 13.000 moveto
(m) show
128.500 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
140.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
146.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
152.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
158.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
164.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02842 0 m
.02846 .00104 L
.03053 .04977 L
.03279 .08808 L
.03527 .12061 L
.0379 .14835 L
.04262 .18757 L
.05205 .24408 L
.06244 .28924 L
.0842 .35711 L
.10458 .40357 L
.12312 .43692 L
.14335 .46584 L
.16449 .48883 L
.17502 .49775 L
.18458 .50444 L
.19403 .50978 L
.20425 .51419 L
.20987 .51602 L
.21505 .51734 L
.22 .51828 L
.22249 .51864 L
.22522 .51894 L
.22644 .51905 L
.22773 .51914 L
.22841 .51918 L
.22915 .51922 L
.23046 .51927 L
.23169 .5193 L
.23239 .51931 L
.23302 .51931 L
.23419 .5193 L
.23543 .51928 L
.23654 .51924 L
.23773 .51918 L
.23987 .51904 L
.24242 .5188 L
.24473 .51852 L
.24989 .51768 L
.25549 .51645 L
.26565 .51338 L
.27511 .50962 L
.28552 .50455 L
.30656 .49171 L
.3469 .45995 L
.38573 .4253 L
.427 .39019 L
.44764 .37507 L
.46677 .36319 L
.48529 .35399 L
Mistroke
.49557 .34996 L
.50501 .34696 L
.51532 .34447 L
.52074 .3435 L
.52351 .3431 L
.52646 .34273 L
.52907 .34246 L
.53145 .34226 L
.53383 .34211 L
.53491 .34205 L
.53609 .342 L
.53737 .34196 L
.53807 .34194 L
.53872 .34193 L
.53989 .34192 L
.54115 .34191 L
.54182 .34192 L
.54255 .34192 L
.54331 .34194 L
.54402 .34195 L
.54529 .34199 L
.54665 .34204 L
.54924 .34218 L
.55199 .34238 L
.55691 .34289 L
.56221 .34363 L
.56803 .34469 L
.57846 .34716 L
.5882 .35013 L
.60852 .35818 L
.62707 .36739 L
.66688 .39128 L
.70518 .41623 L
.74593 .44047 L
.76616 .45037 L
.78517 .45788 L
.80331 .46321 L
.81352 .46535 L
.82288 .46676 L
.82761 .46726 L
.83021 .46748 L
.83267 .46765 L
.83496 .46777 L
.83617 .46782 L
.83744 .46787 L
.83852 .4679 L
.8397 .46792 L
.84078 .46794 L
.84178 .46794 L
.84306 .46795 L
Mistroke
.84378 .46794 L
.84446 .46793 L
.84568 .46791 L
.84699 .46788 L
.84828 .46784 L
.84949 .4678 L
.85176 .46768 L
.85444 .46751 L
.85691 .46731 L
.86248 .46673 L
.86718 .46609 L
.87222 .46527 L
.88132 .46343 L
.90198 .45762 L
.92324 .44959 L
.94336 .44045 L
.97619 .42349 L
Mfstroke
0 0 1 r
.05718 0 m
.05752 .00401 L
.06244 .04957 L
.06757 .08629 L
.07299 .11705 L
.08269 .15891 L
.09312 .19243 L
.10458 .22133 L
.145 .29499 L
.18391 .35094 L
.22527 .40309 L
.26512 .44511 L
.28334 .46084 L
.30345 .47522 L
.32322 .48605 L
.33406 .49053 L
.34423 .49377 L
.35406 .496 L
.35901 .4968 L
.36184 .49716 L
.36441 .49742 L
.3668 .49761 L
.36905 .49774 L
.37028 .49779 L
.37142 .49783 L
.37267 .49786 L
.37331 .49787 L
.374 .49787 L
.37516 .49787 L
.37622 .49786 L
.37744 .49784 L
.37861 .4978 L
.37968 .49776 L
.38067 .49771 L
.38292 .49757 L
.38557 .49735 L
.38801 .49709 L
.39351 .49633 L
.39836 .49545 L
.40348 .49432 L
.4221 .4885 L
.4316 .48457 L
.44178 .47973 L
.46012 .4695 L
.50154 .44136 L
.54143 .41165 L
.57982 .38515 L
.59924 .37377 L
.62065 .36342 L
.63042 .35958 L
Mistroke
.64094 .35611 L
.65081 .35351 L
.65997 .35168 L
.66461 .35096 L
.66957 .35036 L
.67239 .3501 L
.67506 .34989 L
.67746 .34975 L
.6788 .34969 L
.68005 .34965 L
.68128 .34961 L
.68259 .34958 L
.68335 .34957 L
.68406 .34957 L
.6847 .34957 L
.68539 .34957 L
.68607 .34957 L
.68681 .34958 L
.68759 .34959 L
.68832 .3496 L
.68963 .34964 L
.69104 .34969 L
.69361 .34982 L
.69632 .35 L
.70116 .35045 L
.70615 .35107 L
.71069 .35177 L
.72088 .35381 L
.73924 .35902 L
.7584 .36634 L
.77919 .37609 L
.82007 .39881 L
.85944 .42183 L
.8973 .44151 L
.91835 .45032 L
.93761 .4566 L
.94707 .459 L
.95739 .46107 L
.96211 .46183 L
.96714 .46249 L
.97189 .46298 L
.97619 .46332 L
Mfstroke
0 1 0 r
.10845 0 m
.11421 .04344 L
.12324 .09343 L
.13399 .13789 L
.14385 .16901 L
.16277 .21275 L
.18347 .24674 L
.22403 .29534 L
.26308 .33461 L
.30457 .37434 L
.34456 .41067 L
.38302 .44168 L
.40251 .45507 L
.42394 .46751 L
.4443 .47676 L
.45341 .48004 L
.46334 .48296 L
.46874 .48426 L
.47375 .48529 L
.47894 .48616 L
.48363 .48679 L
.48586 .48704 L
.48826 .48726 L
.49033 .48742 L
.49261 .48756 L
.49503 .48767 L
.49636 .48771 L
.49759 .48774 L
.49875 .48776 L
.4998 .48776 L
.50102 .48776 L
.50217 .48775 L
.50331 .48773 L
.50454 .4877 L
.50571 .48766 L
.50677 .48762 L
.50925 .48748 L
.51185 .4873 L
.51676 .48682 L
.52212 .48611 L
.53167 .48437 L
.54055 .48223 L
.56105 .47548 L
.57965 .46738 L
.61968 .44511 L
.6582 .42028 L
.69917 .39428 L
.71957 .38275 L
.73863 .37338 L
.7581 .36552 L
Mistroke
.77657 .3599 L
.7863 .35772 L
.79143 .35679 L
.79689 .35597 L
.80147 .35542 L
.8039 .35518 L
.80652 .35496 L
.80892 .3548 L
.81112 .35468 L
.81323 .35459 L
.81428 .35456 L
.81544 .35453 L
.81676 .35451 L
.81797 .35449 L
.81861 .35449 L
.8193 .35449 L
.82003 .35449 L
.82072 .3545 L
.82197 .35451 L
.82312 .35454 L
.82444 .35457 L
.8257 .35462 L
.82801 .35472 L
.83016 .35485 L
.83503 .35524 L
.84035 .35582 L
.84517 .35649 L
.85597 .35845 L
.866 .36083 L
.87523 .36347 L
.89606 .37085 L
.93556 .3891 L
.97356 .40939 L
.97619 .41081 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003ooooooona
ooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`007?ooool6o`000?ooooooSooo
ool001cooooo00?oV9RHo`000?o<c<`00_ooool00ol@413oooooooooo`3oooooohgooooo000Moooo
o`03oiRHV?l0003oc<c<00Sooooo0_l000000ooo003o0000ooooo`08ooooo`03o`00oooooooooooo
013ooooo00?o0?l0ooooooooool0oooooomVooooo`004oooool7o`0000Cooooo00?oZJVYoa0@4?o<
c<`01oooool00ol0003oooooool0000:ooooo`03o`00oooooooooooo013ooooo00?o0?l0oooooooo
ool0oooooomVooooo`007oooool00oo<c<co410@olc<c006ooooo`03o`000?ooooooo`0000[ooooo
00?o003oooooooooool04?ooool00ol0o`3oooooooooo`3oooooofKooooo000Pooooo`03ojVYZOlb
<S;ooooo00Gooooo00?o0000oooooooo00002_ooool00ol00?ooooooooooo`0@ooooo`03o`3o0?oo
oooooooo0?ooooooI_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooool0000:
ooooo`03o`00oooooooooooo013ooooo00?o0?l0ooooooooool0oooooomVooooo`007?ooool01_l0
003oQhN7onk^k_ooooooMgMgoc8b<PKooooo00?o0000oooooooo00002_ooool00ol00?oooooooooo
o`0Aooooo`03o`3o0?oooooooooo0?ooooooIOooool001cooooo00KoZJVYoc8b<_l0003o0000oeEE
EOo^k^h6ooooo`03o`000?ooooooo`0000[ooooo00?o003oooooooooool04Oooool00ol0o`3ooooo
ooooo`3oooooofGooooo000Xooooo`03o`000?ooooooo`0000_ooooo00?o003oooooooooool04?oo
ool00ol0o`3oooooooooo`3oooooofGooooo000Xooooo`;o000000?oo`00ooooooooool02Oooool0
0ol00?ooooooooooo`0@ooooo`03o`3o0?oooooooooo0?ooooooIOooool002Sooooo00?o0000oooo
oooo00002oooool00ol00?ooooooooooo`0@ooooo`03o`3o0?oooooooooo0?ooooooIOooool002So
oooo00?o0000oooooooo00002oooool00ol00?ooooooooooo`0@ooooo`03o`3o0?oooooooooo0?oo
ooooIOooool002Sooooo00Co0000ooooooooooooo`002_ooool00ol00?ooooooooooo`0@ooooo`03
o`3o0?oooooooooo0?ooooooIOooool002Sooooo00Co0000ooooooooooooo`002_ooool00ol00?oo
ooooooooo`0@ooooo`03o`3o0?oooooooooo0?ooooooIOooool002Sooooo00Co0000oooooooooooo
o`002_ooool00ol00?ooooooooooo`0@ooooo`03o`3o0?oooooooooo0?ooooooIOooool002Sooooo
00Co0000ooooooooooooo`002_ooool00ol00?ooooooooooo`0Aooooo`03o`3o0?oooooooooo0?oo
ooooI?ooool002Sooooo00Co0000ooooooooooooo`002_ooool00ol00?ooooooooooo`0Aooooo`03
o`3o0?oooooooooo0?ooooooI?ooool002Sooooo0ol000000ooo003oooooooooo`09ooooo`03o`00
oooooooooooo013ooooo00?o0?l0ooooooooool0oooooomTooooo`00:?ooool01?l0003ooooooooo
oooo000;ooooo`03o`00oooooooooooo013ooooo00?o0?l0ooooooooool0oooooomTooooo`00:?oo
ool01?l0003ooooooooooooo000;ooooo`03o`00oooooooooooo013ooooo00?o0?l0ooooooooool0
oooooomTooooo`00:?ooool01?l0003ooooooooooooo000;ooooo`03o`00oooooooooooo013ooooo
00?o0?l0ooooooooool0oooooomTooooo`00:?ooool01?l0003ooooooooooooo000;ooooo`03o`00
oooooooooooo013ooooo00?o0?l0ooooooooool0oooooomTooooo`00:?ooool01?l0003ooooooooo
oooo000;ooooo`03o`00oooooooooooo017ooooo00?o0?l0ooooooooool0oooooomSooooo`00:?oo
ool01?l0003ooooooooooooo000;ooooo`03o`00oooooooooooo017ooooo00?o0?l0ooooooooool0
oooooomSooooo`00:?ooool01?l0003ooooooooooooo000<ooooo`03o`00oooooooooooo013ooooo
00?o0?l0ooooooooool0oooooomSooooo`00:?ooool3o`000003ool00?oooooooooo00[ooooo00?o
003oooooooooool04?ooool00ol0o`3oooooooooo`3oooooof?ooooo000Xooooo`04o`000?oooooo
ooooool000cooooo00?o003oooooooooool04?ooool00ol0o`3oooooooooo`3oooooof?ooooo000X
ooooo`04o`000?ooooooooooool000cooooo00?o003oooooooooool04?ooool00ol0o`3ooooooooo
o`3oooooof?ooooo000Xooooo`05o`000?oooooooooooooooooo00002oooool00ol00?oooooooooo
o`0Aooooo`03o`3o0?oooooooooo0?ooooooH_ooool002Sooooo00Go0000ooooooooooooooooool0
000;ooooo`03o`00oooooooooooo017ooooo00?o0?l0ooooooooool0oooooomRooooo`00:?ooool0
1Ol0003oooooooooooooooooo`0000_ooooo00?o003oooooooooool04Oooool00ol0o`3ooooooooo
o`3oooooof;ooooo000Xooooo`05o`000?oooooooooooooooooo00003?ooool00ol00?oooooooooo
o`0@ooooo`03o`3o0?oooooooooo0?ooooooH_ooool002Sooooo0ol000000oooooooo`00ooooo`0;
ooooo`03o`00oooooooooooo013ooooo00?o0?l0ooooooooool0oooooomRooooo`00:?ooool01Ol0
003oooooooooooooooooo`0000cooooo00?o003oooooooooool04?ooool00ol0o`3oooooooooo`3o
ooooof;ooooo000Xooooo`05o`000?oooooooooooooooooo00003?ooool00ol00?ooooooooooo`0A
ooooo`03o`3o0?oooooooooo0?ooooooHOooool002Sooooo00Go0000ooooooooooooooooool0000<
ooooo`03o`00oooooooooooo017ooooo00?o0?l0ooooooooool0oooooomQooooo`00:?ooool01Ol0
003oooooooooooooooooo`0000cooooo00?o003oooooooooool04Oooool00ol0o`3oooooooooo`3o
ooooof7ooooo000Xooooo`05o`000?oooooooooooooooooo00003?ooool00ol00?ooooooooooo`0A
ooooo`03o`3o0?oooooooooo0?ooooooHOooool000_ooooo1?l000000ol@413oooooooooo`03oooo
o`03oeEEEOl0003oEEEE00Cooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h6ooooo`05o`000?oo
oooooooooooooooo00003Oooool00ol00?ooooooooooo`0@ooooo`03o`3o0?oooooooooo0?oooooo
HOooool000gooooo00?o0000ooooooooool01Oooool3o`0000Cooooo00Ko410@ohN7Qooooooooooo
ogMgMom4A4@6ooooo`05o`000?oooooooooooooooooo00003Oooool00ol00?ooooooooooo`0Aoooo
o`03o`3o0?oooooooooo0?ooooooH?ooool000gooooo00?o0000ooooooooool01Oooool00omEEEGo
0000oeEEE@09ooooo`03o`000?oooooooooo00Cooooo1?l000000ooo003oooooooooo`0;ooooo`03
o`00oooooooooooo017ooooo00?o0?l0ooooooooool0oooooomPooooo`0000?oooooo`000?l00000
1Ol00005ooooo`03o`000?oooooooooo013ooooo00?ok^k^o`000?ooool01Oooool01Ol0003ooooo
ooooooooooooo`0000gooooo00?o003oooooooooool04Oooool00ol0o`3oooooooooo`3oooooof3o
oooo000=ooooo`03o`000?oooooooooo00cooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH6oooo
o`05o`000?oooooooooooooooooo00003Oooool00ol00?ooooooooooo`0Aooooo`03o`3o0?oooooo
oooo0?ooooooH?ooool000gooooo00?o0000ooooooooool03?ooool01Ol0003o8B4Qo`000?l0003o
IVIV00Oooooo00Go0000ooooooooooooooooool0000>ooooo`03o`00oooooooooooo017ooooo00?o
0?l0ooooooooool0oooooomOooooo`003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Wooooo00Go0000ooooooooooooooooool0000>ooooo`03o`00oooooooooooo017ooooo00?o
0?l0ooooooooool0oooooomOooooo`002oooool00ol0003oA4A4o`00000>ooooo`03o`000?oooooo
oooo00Wooooo00Go0000ooooooooooooooooool0000>ooooo`03o`00oooooooooooo017ooooo00?o
0?l0ooooooooool0oooooomOooooo`002oooool00oo<c<coEEEEo`00000>ooooo`Go00001oooool0
1Ol0003oooooooooooooooooo`0000kooooo00?o003oooooooooool04Oooool00ol0o`3ooooooooo
o`3ooooooeoooooo000Xooooo`05o`000?oooooooooooooooooo00003_ooool00ol00?oooooooooo
o`0Aooooo`03o`3o0?oooooooooo0?ooooooGoooool002Sooooo0ol000000oooooooo`00ooooo`0=
ooooo`03o`00oooooooooooo01;ooooo00?o0?l0ooooooooool0oooooomNooooo`00:?ooool01Ol0
003oooooooooooooooooo`0000oooooo00?o003oooooooooool04Oooool00ol0o`3oooooooooo`3o
oooooekooooo000Xooooo`05o`000?oooooooooooooooooo00003oooool00ol00?ooooooooooo`0A
ooooo`03o`3o0?oooooooooo0?ooooooG_ooool002Sooooo00Go0000ooooooooooooooooool0000?
ooooo`03o`00oooooooooooo017ooooo00?o0?l0ooooooooool0oooooomNooooo`00:?ooool01Ol0
003oooooooooooooooooo`0000oooooo00?o003oooooooooool04_ooool00ol0o`3oooooooooo`3o
oooooegooooo000Xooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool03?ooool00ol0
0?ooooooooooo`0Booooo`03o`3o0?oooooooooo0?ooooooGOooool002Sooooo00?o0000oooooooo
ool00_ooool00ooo003oooooooooo`0=ooooo`03o`00oooooooooooo017ooooo00?o0?l0oooooooo
ool0oooooomMooooo`00:?ooool3o`0000;ooooo00?oo`00ooooooooool03Oooool00ol00?oooooo
ooooo`0Booooo`03o`3o0?oooooooooo0?ooooooG?ooool002Sooooo00?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0=ooooo`03o`00oooooooooooo01;ooooo00?o0?l0ooooooooool0oooo
oomLooooo`00:?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo00gooooo00?o003o
ooooooooool04_ooool00ol0o`3oooooooooo`3ooooooecooooo000Xooooo`03o`000?oooooooooo
00;ooooo00?oo`00ooooooooool03Oooool00ol00?ooooooooooo`0Cooooo`03o`3o0?oooooooooo
0?ooooooFoooool002Sooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`03
o`00oooooooooooo01;ooooo00?o0?l0ooooooooool0oooooomKooooo`00:?ooool00ol0003ooooo
ooooo`02ooooo`03ool00?oooooooooo00kooooo00?o003oooooooooool04_ooool00ol0o`3ooooo
ooooo`3ooooooe_ooooo000Xooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool03_oo
ool00ol00?ooooooooooo`0Cooooo`03o`3o0?oooooooooo0?ooooooF_ooool002Sooooo00?o0000
ooooooooool00oooool00ooo003oooooooooo`0=ooooo`03o`00oooooooooooo01?ooooo00?o0?l0
ooooooooool0oooooomJooooo`00:?ooool3o`0000?ooooo00?oo`00ooooooooool03Oooool00ol0
0?ooooooooooo`0Cooooo`03o`3o0?oooooooooo0?ooooooF_ooool002Sooooo00?o0000oooooooo
ool00oooool00ooo003oooooooooo`0>ooooo`03o`00oooooooooooo01?ooooo00?o0?l0oooooooo
ool0oooooomIooooo`00:?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00kooooo
00?o003oooooooooool04oooool00ol0o`3oooooooooo`3ooooooeWooooo000Xooooo`03o`000?oo
oooooooo00?ooooo00?oo`00ooooooooool03_ooool00ol00?ooooooooooo`0Cooooo`03o`3o0?oo
oooooooo0?ooooooFOooool002Sooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0?
ooooo`03o`00oooooooooooo01?ooooo00?o0?l0ooooooooool0oooooomHooooo`00:?ooool00ol0
003oooooooooo`03ooooo`03ool00?oooooooooo00oooooo00?o003oooooooooool04oooool00ol0
o`3oooooooooo`3ooooooeSooooo000Xooooo`03o`000?oooooooooo00Cooooo00?oo`00oooooooo
ool03_ooool00ol00?ooooooooooo`0Dooooo`03o`3o0?oooooooooo0?ooooooEoooool002Sooooo
00?o0000ooooooooool01?ooool00ooo003oooooooooo`0?ooooo`03o`00oooooooooooo01?ooooo
00?o0?l0ooooooooool0oooooomGooooo`00:?ooool3o`0000Cooooo00?oo`00ooooooooool03ooo
ool00ol00?ooooooooooo`0Cooooo`03o`3o0?oooooooooo0?ooooooEoooool002Sooooo00?o0000
ooooooooool01?ooool00ooo003oooooooooo`0?ooooo`03o`00oooooooooooo01Cooooo00?o0?l0
ooooooooool0oooooomFooooo`00:?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
013ooooo00?o003oooooooooool04oooool00ol0o`3oooooooooo`3ooooooeKooooo000Xooooo`03
o`000?oooooooooo00Cooooo00?oo`00ooooooooool04?ooool00ol00?ooooooooooo`0Dooooo`03
o`3o0?oooooooooo0?ooooooEOooool002Sooooo00?o0000ooooooooool01?ooool00ooo003ooooo
ooooo`0@ooooo`03o`00oooooooooooo01Cooooo00?o0?l0ooooooooool0oooooomEooooo`007Ooo
ool4o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ooo003ooooooooo
o`0@ooooo`03o`00oooooooooooo01Cooooo00?o0?l0ooooooooool0oooooomDooooo`007oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool04?ooool0
0ol00?ooooooooooo`0Dooooo`03o`3o0?oooooooooo0?ooooooE?ooool001oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo013ooooo00?o003ooooo
ooooool05?ooool00ol0o`3oooooooooo`3ooooooeCooooo000Cooooo`Oo00001Oooool00ol0003o
ooooooooo`06ooooo`Co00001?ooool00ooo003oooooooooo`0Aooooo`03o`00oooooooooooo01Co
oooo00?o0?l0ooooooooool0oooooomCooooo`007oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?oo`00ooooooooool04Oooool00ol00?ooooooooooo`0Dooooo`03o`3o
0?oooooooooo0?ooooooDoooool001oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03ool00?oooooooooo017ooooo00?o003oooooooooool05?ooool00ol0o`3ooooooooo
o`3ooooooe;ooooo000Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ooo003oooooooooo`0Aooooo`03o`00oooooooooooo01Cooooo00?o0?l0ooooooooool0oooooomB
ooooo`007Oooool00ol0003oA4A4o`000008ooooo`03o`000?oooooooooo00Kooooo00?oo`00oooo
ooooool04Oooool00ol00?ooooooooooo`0Eooooo`03o`3o0?oooooooooo0?ooooooDOooool001go
oooo00?oc<c<oeEEEOl000002?ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo01;o
oooo00?o003oooooooooool05Oooool00ol0o`3oooooooooo`3ooooooe3ooooo000Xooooo`03o`00
0?oooooooooo00Kooooo00?oo`00ooooooooool04_ooool00ol00?ooooooooooo`0Eooooo`03o`3o
0?oooooooooo0?ooooooD?ooool002Sooooo0ol00007ooooo`03ool00?oooooooooo01;ooooo00?o
003oooooooooool05Oooool00ol0o`3oooooooooo`3oooooodoooooo000Xooooo`03o`000?oooooo
oooo00Oooooo00?oo`00ooooooooool04_ooool00ol00?ooooooooooo`0Eooooo`03o`3o0?oooooo
oooo0?ooooooCoooool002Sooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0Coooo
o`03o`00oooooooooooo01Gooooo00?o0?l0ooooooooool0oooooom>ooooo`00:?ooool00ol0003o
ooooooooo`07ooooo`03ool00?oooooooooo01Cooooo00?o003oooooooooool05Oooool00ol0o`3o
ooooooooo`3oooooodgooooo000Xooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0
5?ooool00ol00?ooooooooooo`0Eooooo`03o`3o0?oooooooooo0?ooooooCOooool002Sooooo00?o
0000ooooooooool02?ooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o
0?l0ooooooooool0oooooom<ooooo`00:?ooool00ol0003oooooooooo`08ooooo`03ool00?oooooo
oooo01Cooooo00?o003oooooooooool05Oooool00ol0o`3oooooooooo`3oooooodcooooo000Xoooo
o`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`3o0?oooooooooo0?ooooooBoooool002Sooooo0ol00008ooooo`03ool00?oooooooooo01Go
oooo00?o003oooooooooool05_ooool00ol0o`3oooooooooo`3ooooood[ooooo000Xooooo`03o`00
0?oooooooooo00Sooooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`0Eooooo`03o`3o
0?oooooooooo0?ooooooB_ooool002Sooooo00?o0000ooooooooool02Oooool00ooo003ooooooooo
o`0Fooooo`03o`00oooooooooooo01Gooooo00?o0?l0ooooooooool0oooooom9ooooo`00:?ooool0
0ol0003oooooooooo`09ooooo`03ool00?oooooooooo01Kooooo00?o003oooooooooool05_ooool0
0ol0o`3oooooooooo`3oooooodSooooo000Xooooo`03o`000?oooooooooo00Wooooo00?oo`00oooo
ooooool05oooool00ol00?ooooooooooo`0Fooooo`03o`3o0?oooooooooo0?ooooooAoooool002So
oooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0Gooooo`03o`00oooooooooooo01Oo
oooo00?o0?l0ooooooooool0oooooom6ooooo`00:?ooool00ol0003oooooooooo`0:ooooo`03ool0
0?oooooooooo01Oooooo00?o003oooooooooool05oooool00ol0o`3oooooooooo`3oooooodGooooo
000Xooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool05oooool00ol00?oooooooooo
o`0Gooooo`03o`3o0?oooooooooo0?ooooooAOooool002Sooooo0ol0000:ooooo`03ool00?oooooo
oooo01Sooooo00?o003oooooooooool05oooool00ol0o`3oooooooooo`3oooooodCooooo000Xoooo
o`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool06Oooool00ol00?ooooooooooo`0Goooo
o`03o`3o0?oooooooooo0?oooooo@oooool002Sooooo00?o0000ooooooooool02_ooool00ooo003o
ooooooooo`0Iooooo`03o`00oooooooooooo01Sooooo00?o0?l0ooooooooool0oooooom2ooooo`00
:?ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo01Wooooo00?o003oooooooooool0
6?ooool00ol0o`3oooooooooo`3ooooood7ooooo000Xooooo`03o`000?oooooooooo00_ooooo00?o
o`00ooooooooool06Oooool00ol00?ooooooooooo`0Iooooo`03o`3o0?oooooooooo0?oooooo@?oo
ool002Sooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0Jooooo`03o`00oooooooo
oooo01Sooooo00?o0?l0ooooooooool0oooooom0ooooo`00:?ooool00ol0003oooooooooo`0;oooo
o`03ool00?oooooooooo01[ooooo00?o003oooooooooool06Oooool00ol0o`3oooooooooo`3ooooo
ocoooooo000Xooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool06_ooool00ol00?oo
ooooooooo`0Iooooo`03o`3o0?oooooooooo0?oooooo?_ooool002Sooooo0ol0000<ooooo`03ool0
0?oooooooooo01_ooooo00?o003oooooooooool06Oooool00ol0o`3oooooooooo`3oooooocgooooo
000Xooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool06oooool00ol00?oooooooooo
o`0Jooooo`03o`3o0?oooooooooo0?oooooo??ooool002Sooooo00?o0000ooooooooool03?ooool0
0ooo003oooooooooo`0Looooo`03o`00oooooooooooo01[ooooo00?o0?l0ooooooooool0oooooolk
ooooo`00:?ooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo01_ooooo00?o003ooooo
ooooool06oooool00ol0o`3oooooooooo`3ooooooc[ooooo000Xooooo`03o`000?oooooooooo00go
oooo00?oo`00ooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`3o0?oooooooooo0?oo
oooo>Oooool000_ooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06
oiRHV?l@413o0000o`000?m4A4Cok^k^1_ooool00ol0003oooooooooo`0=ooooo`03ool00?oooooo
oooo01gooooo00?o003oooooooooool06oooool00ol0o`3oooooooooo`3oooooocSooooo000:oooo
o`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7Qooooooooooo
ogMgMom4A4@6ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool07?ooool00ol00?oo
ooooooooo`0Looooo`03o`3o0?oooooooooo0?oooooo=oooool000[ooooo00KoA4A4ojVYZOoooooo
ooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Wooooo00?o0000ooooooooool01?ooool4o`00
00gooooo00?oo`00ooooooooool07Oooool00ol00?ooooooooooo`0Looooo`03o`3o0?oooooooooo
0?oooooo=_ooool00003ooooool0003o000000Go00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00kooooo00?ok^k^o`000?ooool01Oooool00ol0003oooooooooo`0>ooooo`03
ool00?oooooooooo01kooooo00?o003oooooooooool07?ooool00ol0o`3oooooooooo`3oooooocGo
oooo000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_l@413oV9RH
ooooooooooooMgMgofIVIPKooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0Moooo
o`03o`00oooooooooooo01gooooo00?o0?l0ooooooooool0ooooooldooooo`002_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o0000ofIVIP07oooo
o`03o`000?oooooooooo00oooooo00?oo`00ooooooooool07_ooool00ol00?ooooooooooo`0Moooo
o`03o`3o0?oooooooooo0?oooooo<oooool000[ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0O
ooooo`03o`00oooooooooooo01gooooo00?o0?l0ooooooooool0oooooolbooooo`002_ooool01_o<
c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0@ooooo`03ool00?oooooooooo01kooooo00?o003oooooooooool07_ooool00ol0o`3ooooooooo
o`3ooooooc7ooooo000;ooooo`04okZj^_l@413o410@olc<c0gooooo1Ol00007ooooo`03o`000?oo
oooooooo013ooooo00?oo`00ooooooooool07oooool00ol00?ooooooooooo`0Nooooo`03o`3o0?oo
oooooooo0?oooooo<?ooool002Sooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`0P
ooooo`03o`00oooooooooooo01kooooo00?o0?l0ooooooooool0ooooool_ooooo`00:?ooool3o`00
017ooooo00?oo`00ooooooooool07oooool00ol00?ooooooooooo`0Oooooo`03o`3o0?oooooooooo
0?oooooo;_ooool002Sooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`0Pooooo`03
o`00oooooooooooo01oooooo00?o0?l0ooooooooool0ooooool]ooooo`00:?ooool00ol0003ooooo
ooooo`0Aooooo`03ool00?oooooooooo027ooooo00?o003oooooooooool07oooool00ol0o`3ooooo
ooooo`3oooooobcooooo000Xooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool08?oo
ool00ol00?ooooooooooo`0Pooooo`03o`3o0?oooooooooo0?oooooo:oooool002Sooooo00?o0000
ooooooooool04_ooool00ooo003oooooooooo`0Qooooo`03o`00oooooooooooo023ooooo00?o0?l0
ooooooooool0oooooolZooooo`00:?ooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo
02;ooooo00?o003oooooooooool08?ooool00ol0o`3oooooooooo`1Ioooooa?oo`00_?ooool002So
oooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0Qooooo`03o`00oooooooooooo027o
oooo00?o0?l0ooooooooool0Doooool5ool001?ooooo0ooo002iooooo`00:?ooool00ol0003ooooo
ooooo`0Cooooo`03ool00?oooooooooo02;ooooo00?o003oooooooooool08Oooool00ol0o`3ooooo
ooooo`1@ooooo`;oo`006oooool4ool002?ooooo1Ol00?n=ooooo`00:?ooool3o`0001?ooooo00?o
o`00ooooooooool08oooool00ol00?ooooooooooo`0Qooooo`03o`3o0?oooooooooo04cooooo0ooo
000Qooooo`?oo`005oooool9o`00o`Gooooo2_l00?n3ooooo`00:?ooool00ol0003oooooooooo`0D
ooooo`03ool00?oooooooooo02;ooooo00?o003oooooooooool08_ooool00ol0o`3oooooooooo`18
ooooo`?oo`009oooool3ool0017ooooo0ol00?lHooooo`?o003o7_ooool:o`3o05Sooooo000Xoooo
o`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool08oooool00ol00?ooooooooooo`0Roooo
o`03o`3o0?oooooooooo04Gooooo0_oo000]ooooo`;oo`002oooool4o`00oakooooo0ol00?lDoooo
o`Oo0?l02_ooool7o`3o057ooooo000Xooooo`03o`000?oooooooooo01Cooooo00?oo`00oooooooo
ool09?ooool00ol00?ooooooooooo`0Rooooo`03o`3o0?oooooooooo04?ooooo00?oo`00oooooooo
ool0;oooool2ool000Kooooo0ol00?lUooooo`?o003o2_ooool7o`3o01Sooooo1?l0o`1=ooooo`00
:?ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo02Cooooo00?o003oooooooooool0
8_ooool00ol0o`3oooooooooo`10ooooo`;oo`00=?ooool3ool00003ooooool00?oo003o02_ooooo
0ol00?l4ooooo`?o0?l08oooool4o`3o04Wooooo000Xooooo`03o`000?oooooooooo01Gooooo00?o
o`00ooooooooool09Oooool00ol00?ooooooooooo`0Rooooo`03o`3o0?oooooooooo03gooooo0_oo
000hooooo`;o003o00?oo`00ooooooooool0;Oooool01?l00?oo0?l0o`3o0?l0o`0Zooooo`?o0?l0
A_ooool002Sooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`0Uooooo`03o`00oooo
oooooooo02?ooooo00?o0?l0ooooooooool0>_ooool2ool003Sooooo0_l00?l3ooooo`;oo`00:ooo
ool3o`3o00;ooooo0_l00?l/ooooo`Co0?l0@_ooool002Sooooo0ol0000Fooooo`03ool00?oooooo
oooo02Gooooo00?o003oooooooooool08oooool00ol0o`3oooooooooo`0hooooo`03ool00?oooooo
oooo03Kooooo0_l00?l7ooooo`;oo`009oooool2o`3o00Oooooo0ol00?l]ooooo`?o0?l0?oooool0
02Sooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`0Vooooo`03o`00oooooooo0000
00Go00007_ooool00ol0o`3oooooooooo`0Sooooo`;o000000?o410@ooooooooool03Oooool2ool0
037ooooo00Kok^k^odA4A?l0003o0000oeEEEOo^k^h2o`00o`_ooooo00?oo`00ooooooooool08_oo
ool2o`3o00cooooo0_l00?l01Om4A4Co0000o`000?m4A4Cok^k^02Wooooo0_l0o`0Cooooo`Co0000
00?o410@ooooooooool00_ooool01?nj^[[o410@o`000?mgMgLMooooo`00:?ooool00ol0003ooooo
ooooo`0Gooooo`03ool00?oooooooooo02Kooooo00Co003ooiRHV?l0003oc<c<0_ooool00ol@413o
ooooooooo`0Mooooo`;o0?l09?ooool00ol0003oooooooooo`0<ooooo`;oo`00<oooool01?mEEEGo
MgMgooooooooool2o`00o`kooooo0_oo000Pooooo`;o0?l03oooool01_lb<S;o003oo`00ooo^k^ko
MgMgoc8b<R_ooooo0_l0o`0Cooooo`03o`000?oooooooooo00?ooooo00Koc<c<oc8b<_o^k^kok^k^
ob4Q8OnYZJTLooooo`00:?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo02Oooooo
00Co003ooiRHV?l0003oc<c<8oooool00ol0o`3oooooooooo`0Mooooo`Ko00003?ooool00ooo003o
ooooooooo`0cooooo`06oa0@4?oooooo003oo`00oooooooo00004?ooool2ool001gooooo00?o0?l0
ooooooooool03oooool00ol0003oooooooooo`02o`00o`03o`000?oooooooooo02_ooooo0ol0o`0@
ooooo`03o`000?oooooooooo00?ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S8Looooo`00:?oo
ool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo02Oooooo00Go003ooooooonYZJWo410@
olc<c00Sooooo`03o`3o0?oooooooooo01cooooo00GoIVIVojVYZOooooooooooo`00000<ooooo`03
ool00?oooooooooo03Cooooo00?o0000o`00ooooool00_ooool00ol0003oooooooooo`0@ooooo`03
ool00?oooooooooo01Sooooo0_l0o`0Booooo`06oc8b<_mgMgOok^k^onk^k_mgMgOo003o<?ooool2
o`3o00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01[ooooo000Xooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool09oooool01Ol0
0?ooooooolc<c?l@413oc<c<02?ooooo00?o0?l0ooooooooool06oooool01Oo^k^ko8B4Qonk^k_oo
oooo000000[ooooo0_oo000fooooo`;o003o00GoEEEEonk^k_ooooooMgMgoeEEE@0Cooooo`;oo`00
5_ooool2o`3o01Cooooo00?ogMgMo`000?l000000_l000000ooMgMgo003oo`00o`0`ooooo`;o0?l0
3?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
6_ooool002Sooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`0Xooooo`04o`00oooo
ooooZJVYoc8b<RCooooo00?o0?l0ooooooooool06oooool01?nYZJWoIVIVooooool00009ooooo`03
ool00?oooooooooo03Cooooo0_l00?l00ooooooo8B4QofIVIP02o`000003oeEEEOo^k^kooooo01Co
oooo0_oo000Booooo`;o0?l05_ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<P;ooooo0_l00?l`
ooooo`;o0?l02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06_ooool002Sooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`0Yoooo
o`03o`00oooooooo000002Gooooo00?o0?l0ooooooooool06oooool00om4A4Coc<c<o`000008oooo
o`03ool00?oooooooooo03Cooooo00Ko003oooooooooooooooooohN7QomVIVHKooooo`03ool00?oo
oooooooo00gooooo0_l0o`0Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool2o`00oc3ooooo0_l0o`08ooooo`03o`000?oooooooooo00?ooooo00KoA4A4ojVYZOoooooooooo
ojVYZOm4A4@Looooo`00:?ooool3o`0001Wooooo00?oo`00ooooooooool09Oooool01_l0003oQhN7
onk^k_oooooo003ooc8b<RKooooo0_l0o`0Kooooo`03omgMgOm4A4Co000000Kooooo0_oo000eoooo
o`;o003o1Oooool00olb<S;oIVIVomgMg@0Jooooo`;oo`002oooool2o`3o01[ooooo00Ko<S8bofIV
I_o^k^kok^k^ofIVI_lb<S86ooooo`;o003o<?ooool2o`3o00Cooooo00?o0000odA4A?l000001Ooo
ool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c1cooooo000Xooooo`03o`000?oooooooooo01Wooooo
00?oo`00ooooooooool09Oooool01_nYZJWo<S8bo`000?l0003o003oonk^kRSooooo00?o0?l0oooo
ooooool06Oooool00on7QhOo0000ooooo`04ooooo`03ool00?oooooooooo03Cooooo00?o003ooooo
ooooool01_ooool01?mgMgOo410@o`000?lQ8B4Jooooo`;oo`001oooool2o`3o01cooooo00Kok^k^
odA4A?l0003o0000odA4A?o^k^h8ooooo`03o`00oooooooooooo02oooooo00Oo0?l0oooooooooooo
ooooolc<c?mEEEGo000000Kooooo00Co^[Zjoa0@4?l@413oc<c<7Oooool002Sooooo00?o0000oooo
ooooool06_ooool00ooo003oooooooooo`0Yooooo`03o`00oooooooooooo02Oooooo00?o0?l0oooo
ooooool07_ooool00ooo003oooooooooo`0cooooo`;o003o:Oooool00ooo003oooooooooo`03oooo
o`03o`3o0?oooooooooo02_ooooo0_l00?l`ooooo`;o0?l0:oooool002Sooooo00?o0000oooooooo
ool06_ooool00ooo003oooooooooo`0Zooooo`03o`00oooooooooooo02Oooooo00?o0?l0oooooooo
ool07?ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo02[ooooo0_oo00000ooooooo
0?l0o`3o000`ooooo`;o003o<?ooool2o`3o02Wooooo000Xooooo`03o`000?oooooooooo01[ooooo
00?oo`00ooooooooool0:oooool00ol00?ooooooooooo`0Wooooo`03o`3o0?oooooooooo01[ooooo
00?oo`00ooooooooool0<_ooool2o`00oboooooo00?o0?l0ool00?ooool0<_ooool00ol00?oooooo
ooooo`0_ooooo`;o0?l06oooool6o`0000Kooooo000Xooooo`03o`000?oooooooooo01_ooooo00?o
o`00ooooooooool0:oooool00ol00?ooooooooooo`0Wooooo`03o`3o0?oooooooooo01Sooooo00?o
o`00ooooooooool0<_ooool00ol00?ooooooooooo`0]ooooo`;o0?l00_ooool00ooo003ooooooooo
o`0aooooo`;o003o<Oooool00ol0o`3oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo000X
ooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0;?ooool00ol00?ooooooooooo`0W
ooooo`03o`3o0?oooooooooo01Gooooo0_oo000cooooo`;o003o;oooool00ol0o`3oooooooooo`03
ooooo`;oo`00<oooool00ol00?ooooooooooo`0_ooooo`;o0?l06_ooool00ol0003oooooooooo`07
ooooo`00:?ooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo02cooooo00?o003ooooo
ooooool09oooool2o`3o01Cooooo00?oo`00ooooooooool0<_ooool00ol00?ooooooooooo`0]oooo
o`;o0?l02?ooool2ool003;ooooo0_l00?laooooo`;o0?l06?ooool00ol0003oooooooooo`07oooo
o`007ooooolXo`000003ool00?l0003o000002go000000?o003oo`000?l00000:?l000000ol0o`3o
0000o`00000@o`000003ool00?l0003o0000037o00000_l00?l_o`000003o`3o0?l0003o000000[o
000000?oo`00o`000?l00000<Ol00002o`00oc[o00003oooool00ol0003ogMgMooooo`07ooooo`00
:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00Goo`00oooooooooooo
ooooo`00000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol00?oo
ooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool00ol0o`3o
ooooo`00000>ooooo`04ool00?ooooooooooo`00017ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo0_l0o`08ooooo`03o`000?oooooooooo
00?ooooo0_oo000:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo0_l000000onHV9Soooooooooo`05oooo
o`00:?ooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo02Cooooo00?o0000oooooooo
ool01_ooool00ol00?ooooooooooo`0Xooooo`03o`3o0?oooooooooo00cooooo00Goo`00oooooooo
ooooooooo`00000_ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0
o`3oooooooooo`0@ooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool05Oooool2o`00
obgooooo00?o0000ooooooooool05?ooool01Ol@413o0000o`000?nj^[[oA4A400;o000000?o8B4Q
ooooooooool00_ooool002Sooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`0^oooo
o`03o`00oooooooooooo02Sooooo0_l0o`0;ooooo`03ool00?oooooooooo033ooooo0_l00?l^oooo
o`;o0?l05?ooool2ool003?ooooo00?o003oooooooooool0COooool002Sooooo00?o0000oooooooo
ool07oooool00ooo003oooooooooo`0^ooooo`03o`00oooooooooooo02Wooooo00?o0?l0oooooooo
ool01oooool00ooo003oooooooooo`0`ooooo`03o`00oooooooooooo02gooooo00?o0?l0oooooooo
ool05_ooool00ooo003oooooooooo`0aooooo`;o003o:Oooool2ool002;ooooo000Xooooo`03o`00
0?oooooooooo01oooooo00?oo`00ooooooooool0;oooool00ol00?ooooooooooo`0Yooooo`03o`3o
0?oooooooooo00Cooooo0_oo000aooooo`;o003o;_ooool2o`3o01[ooooo0_oo000cooooo`;o003o
9Oooool2ool002Cooooo000Xooooo`03o`000?oooooooooo023ooooo00?oo`00ooooooooool0;ooo
ool00ol00?ooooooooooo`0Yooooo`03o`3o0?oooooooooo00;ooooo00?oo`00ooooooooool0<?oo
ool00ol00?ooooooooooo`0]ooooo`03o`3o0?oooooooooo01cooooo00?oo`00ooooooooool0<_oo
ool2o`00ob;ooooo00?oo`00ooooooooool09?ooool002Sooooo00?o0000ooooooooool08Oooool0
0ooo003oooooooooo`0_ooooo`03o`00oooooooooooo02Wooooo0_l0o`000oooooooo`00ooooo`0a
ooooo`03o`00oooooooooooo02cooooo0_l0o`0Pooooo`;oo`00=?ooool3o`00oagooooo0_oo000W
ooooo`00:?ooool3o`00027ooooo00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`0Zoooo
o`03o`3o0?oooooooooo02oooooo0_l00?l]ooooo`;o0?l09?ooool00ooo003oooooooooo`0doooo
o`;o003o6Oooool2ool002Wooooo000Xooooo`03o`000?oooooooooo02;ooooo00?oo`00oooooooo
ool0<?ooool00ol00?ooooooooooo`0Xooooo`03ool00?oooooo0?l002oooooo00?o003ooooooooo
ool0;?ooool00ol0o`3oooooooooo`0Uooooo`;oo`00=_ooool2o`00oaKooooo00?oo`00oooooooo
ool0:Oooool002Sooooo00?o0000ooooooooool08_ooool00ooo003oooooooooo`0aooooo`03o`00
oooooooooooo02Kooooo00Goo`00ooooooooooooooooo`3o000]ooooo`03o`00oooooooooooo02_o
oooo0_l0o`0Zooooo`03ool00?oooooooooo03Gooooo0_l00?lBooooo`;oo`00;?ooool002Sooooo
00?o0000ooooooooool08oooool00ooo003oooooooooo`0aooooo`03o`00oooooooooooo02?ooooo
0_oo0005ooooo`;o0?l0:Oooool2o`00obgooooo00?o0?l0ooooooooool0:oooool2ool003Oooooo
0_l00?l>ooooo`;oo`00;_ooool002Sooooo00?o0000ooooooooool09?ooool00ooo003ooooooooo
o`0aooooo`03o`00oooooooooooo027ooooo00?oo`00ooooooooool01oooool00ol0o`3ooooooooo
o`0Uooooo`03o`00oooooooooooo02_ooooo0_l0o`0`ooooo`?oo`00=_ooool3o`00o`Sooooo0ooo
000`ooooo`00:?ooool00ol0003oooooooooo`0Uooooo`03ool00?oooooooooo037ooooo00?o003o
ooooooooool07oooool00ooo003oooooooooo`09ooooo`;o0?l08oooool2o`00obcooooo0_l0o`0e
ooooo`;oo`00=oooool3o`00o`;ooooo0ooo000cooooo`00:?ooool00ol0003oooooooooo`0Uoooo
o`03ool00?oooooooooo03;ooooo00?o003oooooooooool07Oooool00ooo003oooooooooo`0<oooo
o`03o`3o0?oooooooooo01oooooo00?o003oooooooooool0:oooool00ol0o`3oooooooooo`0goooo
o`;oo`00>?ooool2o`00ocKooooo000Xooooo`?o00009_ooool00ooo003oooooooooo`0booooo`03
o`00oooooooooooo01_ooooo00?oo`00ooooooooool03_ooool00ol0o`3oooooooooo`0Looooo`;o
003o;?ooool2o`3o03cooooo0ooo000booooo`?oo`000_ooool3o`00oc?ooooo000Xooooo`03o`00
0?oooooooooo02Oooooo00?oo`00ooooooooool0<_ooool00ol00?ooooooooooo`0Iooooo`03ool0
0?oooooooooo013ooooo0_l0o`0Kooooo`03o`00oooooooooooo02[ooooo0_l0o`11ooooo`?oo`00
;?ooool3ool000Sooooo0_l00?laooooo`00:?ooool00ol0003oooooooooo`0Wooooo`03ool00?oo
oooooooo03?ooooo00?o003oooooooooool05oooool00ooo003oooooooooo`0Cooooo`03o`3o0?oo
oooooooo01Kooooo0_l00?l/ooooo`03o`3o0?oooooooooo04Cooooo0ooo000Vooooo`?oo`003Ooo
ool6o`00ob_ooooo000Xooooo`03o`000?oooooooooo02Sooooo00?oo`00ooooooooool0<oooool2
o`00oaGooooo0_oo000Gooooo`;o0?l05Oooool00ol00?ooooooooooo`0Zooooo`;o0?l0B_ooool3
ool0023ooooo0ooo000Fooooo`?o003o:?ooool002Sooooo00?o0000ooooooooool0:Oooool00ooo
003oooooooooo`0dooooo`03o`00oooooooooooo017ooooo00?oo`00ooooooooool06Oooool2o`3o
017ooooo0_l00?l[ooooo`;o0?l0Coooool3ool001Wooooo1?oo000Looooo`Ko003o8_ooool002So
oooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`0dooooo`03o`00oooooooooooo00oo
oooo00?oo`00ooooooooool07?ooool00ol0o`3oooooooooo`0=ooooo`03o`00oooooooooooo02[o
oooo00?o0?l0ooooooooool0D_ooool7ool000cooooo1_oo0018ooooo`00:?ooool00ol0003ooooo
ooooo`0Zooooo`03ool00?oooooooooo03Gooooo0_l00?l>ooooo`03ool00?oooooooooo01kooooo
0_l0o`0;ooooo`;o003o:oooool2o`3o05cooooo3?oo001>ooooo`00:?ooool00ol0003ooooooooo
o`0[ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool02Oooool2ool002?ooooo0ol0
o`06ooooo`;o003o:_ooool3o`3o0;Sooooo000Xooooo`?o0000;?ooool00ooo003oooooooooo`0f
ooooo`03o`00oooooooooooo00Oooooo00?oo`00ooooooooool09_ooool3o`3o00;ooooo00?o003o
ooooooooool0:?ooool2o`3o0;_ooooo000Xooooo`03o`000?oooooooooo02gooooo00?oo`00oooo
ooooool0=_ooool2o`00o`Kooooo00?oo`00ooooooooool0:_ooool3o`3o02Oooooo0ol0o`2moooo
o`00:?ooool00ol0003oooooooooo`0^ooooo`03ool00?oooooooooo03Oooooo0_l00?l3ooooo`03
ool00?oooooooooo02Wooooo0_l00?l3ooooo`?o0?l08?ooool4o`3o0<3ooooo000Xooooo`03o`00
0?oooooooooo02oooooo00?oo`00ooooooooool0>?ooool00ol00?ooo`00ool0000Zooooo`;o003o
2?ooool3o`3o01[ooooo0ol0o`34ooooo`00:?ooool00ol0003oooooooooo`0`ooooo`03ool00?oo
oooooooo03Oooooo00?oo`00o`00ool00?l0:?ooool2o`00o`gooooo1?l0o`0Booooo`Co0?l0aooo
ool002Sooooo00?o0000ooooooooool0<Oooool00ooo003oooooooooo`0eooooo`04ool00?oooooo
ooooooooo`?o003o8oooool2o`00oa?ooooo4_l0o`3;ooooo`00:?ooool00ol0003oooooooooo`0b
ooooo`;oo`00=?ooool00ooo003oooooooooo`05ooooo`?o003o7_ooool2o`00oo;ooooo000Xoooo
o`03o`000?oooooooooo03Cooooo00?oo`00ooooooooool0;oooool2ool000_ooooo0_l00?lIoooo
o`?o003om?ooool002Sooooo0ol0000eooooo`03ool00?oooooooooo02gooooo00?oo`00oooooooo
ool03Oooool6o`00o`cooooo1ol00?ogooooo`00:?ooool00ol0003oooooooooo`0fooooo`03ool0
0?oooooooooo02[ooooo0_oo000Fooooo`co003oo_ooool002Sooooo00?o0000ooooooooool0=ooo
ool00ooo003oooooooooo`0Wooooo`;oo`00oooooolSooooo`00:?ooool00ol0003oooooooooo`0h
ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool0oooooolSooooo`00:?ooool00ol0
003oooooooooo`0iooooo`;oo`008_ooool3ool00?oooooo9_ooool000_ooooo00Co^[Zjoa0@4?l0
003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1_oo
ool00ol0003oooooooooo`0kooooo`;oo`007Oooool3ool00?oooooo:Oooool000[ooooo00Koc<c<
oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool01_l@413oQhN7ooooooooooooMgMgodA4
A0Kooooo00?o0000ooooooooool0?Oooool3ool001Wooooo00?oo`00ooooooooool0oooooolZoooo
o`002_ooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED02Oooool0
0ol0003oooooooooo`04ooooo`Co0000?oooool3ool001?ooooo0ooo003oooooobgooooo000:oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00oo^k^ko0000ooooo`05oooo
o`03o`000?oooooooooo04?ooooo1?oo000:ooooo`Goo`00ooooool`ooooo`002_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH6
ooooo`03o`000?oooooooooo04Oooooo2_oo003oooooocGooooo000:ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000
ooooooooool0oooooon6ooooo`002_ooool01_m4A4CoZJVYooooooooooooZJVYodA4A0cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`3oooooohKooooo000:ooooo`06olc<c?lb<S;o
k^k^onk^k_lb<S;oc<c<3?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo
Q_ooool000_ooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool5o`0000Oooooo00?o0000ooooooooool0
oooooon6ooooo`00:?ooool00ol0003oooooooooo`3oooooohKooooo000Xooooo`?o0000oooooon6
ooooo`00:?ooool00ol0003oooooooooo`3oooooohKooooo000Xooooo`03o`000?oooooooooo0?oo
ooooQ_ooool002Sooooo00?o0000ooooooooool0oooooon6ooooo`00:?ooool00ol0003ooooooooo
o`3oooooohKooooo000Xooooo`03o`000?oooooooooo0?ooooooQ_ooool002Sooooo00?o0000oooo
ooooool0oooooon6ooooo`00:?ooool00ol0003oooooooooo`3oooooohKooooo000Xooooo`?o0000
oooooon6ooooo`00:?ooool00ol0003oooooooooo`3oooooohKooooo000Xooooo`03o`000?oooooo
oooo0?ooooooQ_ooool002Sooooo00?o0000ooooooooool0oooooon6ooooo`00:?ooool00ol0003o
ooooooooo`3oooooohKooooo000Xooooo`03o`000?oooooooooo0?ooooooQ_ooool002Sooooo00?o
0000ooooooooool0oooooon6ooooo`00:?ooool00ol0003oooooooooo`3oooooohKooooo000Xoooo
o`?o0000oooooon6ooooo`00:?ooool00ol0003oooooooooo`3oooooohKooooo000Xooooo`03o`00
0?oooooooooo0?ooooooQ_ooool002Sooooo00?o0000ooooooooool0oooooon6ooooo`00:?ooool0
0ol0003oooooooooo`3oooooohKooooo000Xooooo`03o`000?oooooooooo0?ooooooQ_ooool002So
oooo00?o0000ooooooooool0oooooon6ooooo`00:?ooool3o`000?ooooooQ_ooool002Sooooo00?o
0000ooooooooool0oooooon6ooooo`00:?ooool00ol0003oooooooooo`3oooooohKooooo000Xoooo
o`03o`000?oooooooooo0?ooooooQ_ooool002Sooooo00?o0000ooooooooool0oooooon6ooooo`00
:?ooool00ol0003oooooooooo`3oooooohKooooo000Mooooo`Co000000?o410@ooooooooool01?oo
ool00ol0003oooooooooo`3oooooohKooooo000Oooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0oooooon6ooooo`007oooool00ol0003oooooooooo`06ooooo`Co0000oooooon5oooo
o`007oooool00ol0003oooooooooo`3oooooohoooooo000Oooooo`03o`000?oooooooooo0?oooooo
Soooool001oooooo00?o0000ooooooooool0oooooon?ooooo`007oooool00ol0003oooooooooo`3o
ooooohoooooo000Mooooo`03o`000?m4A4Co00000?ooooooTOooool001gooooo00?oc<c<oeEEEOl0
0000oooooonAooooo`00YOooool00onj^[[o<S8booooo`0<ooooo`03oc8b<_nj^[[ooooo0?Wooooo
002Iooooo`05o`000?oooooo0000ooooool000001oooool00ol@413o^[Zjooooo`0<ooooo`03okZj
^_lQ8B7ooooo04oooooo00?o0000okZj^_ooool03oooool00ol0003o^[Zjooooo`2Eooooo`00VOoo
ool01Ol0003oooooo`000?oooooo000000Kooooo00?o^[Zjoc8b<_ooool03_ooool00olb<S;o^[Zj
ooooo`1>ooooo`03ob4Q8OmEEEGooooo00oooooo00?o8B4QoeEEEOooool0UOooool0097ooooo00Go
410@o`000?l0003o0000oa0@4003ooooo`05o`000?oooooo0000ooooool000001_ooool00omEEEGo
V9RHooooo`03ooooo`Ko00001Oooool00onHV9SoEEEEooooo`0=ooooo`03oa0@4?l0003o000000;o
000000?o410@ooooooooool00_ooool01On7QhOo410@o`000?l@413oQhN700?ooooo1_l0000;oooo
o`09oa0@4?l0003o0000ooooool0003o410@ooooool0003o410@00_ooooo00Co^[Zjoa0@4?l0003o
MgMg1_ooool00omVIVKo0000onk^kP05ooooo`Co000000?o410@ooooooooool00oooool00omVIVKo
0000onk^kP04ooooo`Ko0000Roooool009?ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
o`000?oooooo000000Kooooo00?o410@olc<c?ooool01Oooool00ol0003oooooooooo`06ooooo`03
omgMgOl@413ooooo00oooooo00?o0000ooooooooool01?ooool01on7QhOo8B4Qolc<c?ooooooc<c<
ob4Q8On7QhL01?ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooooooo1_l00002ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool00onH
V9So0000ogMgM`07ooooo`03o`000?oooooooooo00Gooooo00?oV9RHo`000?mgMgL01?ooool00onH
V9So0000olc<c002ooooo`03oa0@4?oooooooooo08Wooooo002Cooooo`03o`000?oooooooooo00;o
oooo1_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o410@olc<c?ooool00_ooool00oo<c<co
410@ooooo`03ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`09ooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00ooMgMgo0000oa0@
4007ooooo`03o`000?oooooooooo00Gooooo00?ogMgMo`000?l@41001Oooool00onHV9So0000olc<
c02=ooooo`00T_ooool00oo^k^ko0000onk^kP0?ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03ojVYZOl@413oc<c<08cooooo002B
ooooo`03ogMgMol0003oMgMg00oooooo00?o410@olc<c?ooool01Oooool00ol0003ogMgMooooo`06
ooooo`03omgMgOl@413ooooo00oooooo00?o0000ooooooooool01?ooool00ol@413o^[Zjooooo`02
ooooo`03okZj^_l@413ooooo00?ooooo00?o0000omgMgOooool03Oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooooooo`Ko00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03oooool00oo<c<co410@olc<c02;ooooo`00TOoo
ool01Oo^k^ko0000okZj^_l0003ok^k^00kooooo00?oEEEEohN7Qoooool01Oooool2o`000003oiRH
V?oooooooooo00Cooooo00?oV9RHoeEEEOooool03oooool00ol0003oooooooooo`04ooooo`07ohN7
QolQ8B7oc<c<ooooooo<c<co8B4QohN7Q`04ooooo`;o000000?oV9RHooooooooool02oooool01ol0
003oc<c<olc<c?l0003oQhN7olc<c?l000002oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool04?ooool00onYZJWo<S8booooo`2:ooooo`00TOooool0
1OmgMgOoEEEEoooooomEEEGoMgMg00kooooo00?o^[Zjoa0@4?ooool00oooool01Ol@413o0000o`00
0?nj^[[oA4A400;o000000Ko8B4Qooooooooooooooooob4Q8Onj^[X>ooooo`03oa0@4?l0003o0000
00?o00001?ooool01On7QhOo410@o`000?l@413oQhN700?ooooo00Go410@o`000?l0003o^[ZjodA4
A002o`000003ob4Q8Ooooooooooo00Oooooo00So410@o`000?lQ8B7o0000ogMgMol@413o0000ohN7
Q`_ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@?ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0ROooool0093ooooo00Ook^k^o`000?oMgMgoooooomgMgOl0003ok^k^00kooooo
00?o<S8bokZj^_ooool03?ooool00onj^[[o8B4Qooooo`0@ooooo`03o`000?oooooooooo037ooooo
00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`=ooooo`03o`000?m4A4Co000000kooooo00Ko0000ohN7
Qoo^k^koooooogMgMolb<S:;ooooo`00T?ooool3o`000004ooooool0003o0000oa0@40kooooo00?o
^[Zjoc8b<_ooool03?ooool00olb<S;o^[Zjooooo`0@ooooo`03oa0@4?nj^[[ooooo03;ooooo00Co
^[Zjoa0@4?l@413oc<c<3_ooool00oo<c<coEEEEo`00000>ooooo`06ojVYZOlb<S;o0000o`000?mE
EEGok^k^Roooool00<Oooooo00Co^[Zjoa0@4?l0003o410@iOooool00?oooooo/Oooool00?oooooo
/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo
/Oooool00?oooooo/Oooool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-1.13966, -2.0879, \
0.0420152, 0.0194235}}]
}, Open  ]],

Cell[TextData[{
  "The reader is invited to reevaluate these plots for different values of ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " and over different ranges of ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " in order to get a feel for the behavior of these functions."
}], "Text"],

Cell[TextData[{
  "\t One thing that is immediately apparent is that the ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_m\)]],
  "'s are all singular at the origin, due to the regular singular point \
there. Therefore, we can rule out these functions for the eigenmodes in our \
problem, and write"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`R(r\&_) = A\ \(\(J\_m\)(\ r\&_)\)\)]],
  "."
}], "NE2",
  CellTags->"(3.2.50)"]
}, Closed]],

Cell[CellGroupData[{

Cell["Zeros of Bessel Functions", "Subsubsection",
  FontWeight->"Bold",
  CellTags->"i:85"],

Cell[TextData[{
  "\tAnother feature of Bessel functions also jumps out from the previous \
plots: like sines and cosines, these functions oscillate. In fact, one can \
think of ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_m\)(\ r\&_)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_m\)(r\&_)\)]],
  " as cylindrical coordinate versions of trigonometric functions.  Each \
function crosses through zero an infinite number of times in the range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < r < \[Infinity]\)]],
  ". However, unlike trigonometric functions, the location of the zero \
crossings of the Bessel functions cannot be written down with any simple \
formula (except in certain limiting cases such as the zeros at large ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ": see the exercises for Sec. ",
  ButtonBox["5.2",
    ButtonData:>{"Chapter5.nb", "c:33"},
    ButtonStyle->"Hyperlink"],
  "). "
}], "Text"],

Cell[TextData[{
  "\tStarting with the smallest zero and counting upwards, we can formally \
refer to the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th zero of ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_m\)(\ r\&_)\)]],
  "  as ",
  Cell[BoxData[
      \(TraditionalForm\`j\_\(m, \ n\)\)]],
  ": that is, ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(\(J\_m\)(j\_\(m, \ \ n\)) = 0\),
            "TraditionalForm"]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\  = \ 
        1\)\(,\)\(2\)\(,\)\(3\)\(,\)\(...\)\(\ \)\)\)]],
  ".Similarly, the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th zero of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(Y\_m\)(\ r\&_)\),
          "Text"], TraditionalForm]]],
  " is referred to as ",
  Cell[BoxData[
      \(TraditionalForm\`y\_\(m, \ n\)\)]],
  ", and satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_m\)(\ y\_\(m, \ n\)) = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tAlthough these zero crossings cannot be determined analytically, they \
can be found numerically. In fact, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has several intrinsic functions whose purpose is to evaluate the zeros of \
Bessel functions. They must be loaded from the add-on package ",
  StyleBox["NumericalMath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[
    \(<< NumericalMath`\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.27"],

Cell[TextData[{
  " To obtain the first 10 consecutive zeros of  ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_0\)(r)\)]],
  ", the syntax is as follows:"
}], "Text",
  CellTags->"i:86"],

Cell[CellGroupData[{

Cell[BoxData[
    \(j0\  = \ \ BesselJZeros[0, 10]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.28"],

Cell[BoxData[
    \({2.4048255576957467`, 5.520078110286313`, 8.653727913113732`, 
      11.791534439057065`, 14.930917708500882`, 18.071063967915954`, 
      21.211636629881514`, 24.35247153075043`, 27.49347913204087`, 
      30.634606468432334`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus, the smallest zero of ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_0\)(r)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j\_\(0, \ 1\)\)]],
  ", takes on the value ",
  Cell[BoxData[
      \(TraditionalForm\`j\_\(0, \ 1\) = 2.40483 ... \)]],
  ", while the next is at  ",
  Cell[BoxData[
      \(TraditionalForm\`j\_\(0, \ 2\) = 5.52008 ... \)]],
  ", and so on. Similarly, the first four consecutive zeros of ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_1\)(r)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({j\_\(1, \ 1\), j\_\(1, \ 2\), j\_\(1, \ 3\), 
        j\_\(1, \ 4\)}\)\(,\)\)\)]],
  " are obtained via"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BesselJZeros[1, 4]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.29"],

Cell[BoxData[
    \({3.831705970207512`, 7.015586669815622`, 10.173468135156398`, 
      13.323691936337989`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Although we do not need them here, the first ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " zeros of  the ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Y\_m\),
          "Text"], TraditionalForm]]],
  " Bessel function can also be obtained numerically, with the intrinsic \
function",
  StyleBox[" BesselYZeros[m,M]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". For instance, "
}], "Text",
  CellTags->"i:87"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BesselYZeros[2, 6]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.30"],

Cell[BoxData[
    \({3.384241767149627`, 6.793807513268267`, 10.023477979475338`, 
      13.20998671023323`, 16.37896655895625`, 
      19.539039990289947`}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Radial Eigenfunctions and Eigenvalues", "Subsubsection"],

Cell[TextData[{
  "\tThe potential is zero on the tube sides at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  ". We can use our knowledge of the zeros of the Bessel function in order to \
match the resulting boundary condition  ",
  Cell[BoxData[
      \(TraditionalForm\`R(a) = 0\)]],
  " . According to Eqs. ",
  ButtonBox["(3.2.50)",
    ButtonData:>"(3.2.50)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.2.47)",
    ButtonData:>"(3.2.47)",
    ButtonStyle->"Hyperlink"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`R(r) = A\ \(\(J\_m\)(\@\[Kappa]\ r)\)\)]],
  ". Therefore, ",
  Cell[BoxData[
      \(TraditionalForm\`R(a)\  = \ A\ \(\(J\_m\)(\@\[Kappa]\ a)\)\)]],
  ",",
  " so we must specify"
}], "Text"],

Cell[TextData[{
  " \[Kappa] = ",
  Cell[BoxData[
      \(TraditionalForm\`\((j\_\(m, \ n\)/a)\)\^2\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... , \)]]
}], "NE2",
  CellTags->"(3.2.51)"],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(j\_\(m, \ n\)\)\(\ \)\)\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th zero of the ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  "th Bessel function. This implies that the radial eigenfunctions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(R(r)\)\(\ \)\)\)]],
  "are"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`R(r)\  = \ 
        A\ \(\(J\_m\)(\(j\_\(m, \ n\)\) r/a)\)\)]],
  "."
}], "NE2",
  CellTags->"(3.2.52)"],

Cell[TextData[{
  "\tA few of the ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  " radial eigenmodes are plotted in Cell ",
  ButtonBox["3.31",
    ButtonData:>"Cell 3.31",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Evaluate[Table[BesselJ[0, j0[\([n]\)]\ r], {n, 1, 4}]], {r, 0, 1}, 
        PlotStyle \[Rule] {Red, Blue, Green, Purple}, 
        PlotLabel \[Rule] \*"\"\<\!\(J\_0\)(\!\(j\_\(0, n\)\) r/a) for n=1 to \
4\>\"", AxesLabel \[Rule] {"\<r/a\>", "\< \>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.31"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.183715 0.419604 [
[.21429 .17121 -9 -9 ]
[.21429 .17121 9 0 ]
[.40476 .17121 -9 -9 ]
[.40476 .17121 9 0 ]
[.59524 .17121 -9 -9 ]
[.59524 .17121 9 0 ]
[.78571 .17121 -9 -9 ]
[.78571 .17121 9 0 ]
[.97619 .17121 -3 -9 ]
[.97619 .17121 3 0 ]
[1.025 .18371 0 -6 ]
[1.025 .18371 22 6 ]
[.01131 .01587 -24 -4.5 ]
[.01131 .01587 0 4.5 ]
[.01131 .09979 -24 -4.5 ]
[.01131 .09979 0 4.5 ]
[.01131 .26764 -18 -4.5 ]
[.01131 .26764 0 4.5 ]
[.01131 .35156 -18 -4.5 ]
[.01131 .35156 0 4.5 ]
[.01131 .43548 -18 -4.5 ]
[.01131 .43548 0 4.5 ]
[.01131 .5194 -18 -4.5 ]
[.01131 .5194 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -74.4375 0 ]
[.5 .63053 74.4375 12.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .18371 m
.21429 .18996 L
s
[(0.2)] .21429 .17121 0 1 Mshowa
.40476 .18371 m
.40476 .18996 L
s
[(0.4)] .40476 .17121 0 1 Mshowa
.59524 .18371 m
.59524 .18996 L
s
[(0.6)] .59524 .17121 0 1 Mshowa
.78571 .18371 m
.78571 .18996 L
s
[(0.8)] .78571 .17121 0 1 Mshowa
.97619 .18371 m
.97619 .18996 L
s
[(1)] .97619 .17121 0 1 Mshowa
.125 Mabswid
.07143 .18371 m
.07143 .18746 L
s
.11905 .18371 m
.11905 .18746 L
s
.16667 .18371 m
.16667 .18746 L
s
.2619 .18371 m
.2619 .18746 L
s
.30952 .18371 m
.30952 .18746 L
s
.35714 .18371 m
.35714 .18746 L
s
.45238 .18371 m
.45238 .18746 L
s
.5 .18371 m
.5 .18746 L
s
.54762 .18371 m
.54762 .18746 L
s
.64286 .18371 m
.64286 .18746 L
s
.69048 .18371 m
.69048 .18746 L
s
.7381 .18371 m
.7381 .18746 L
s
.83333 .18371 m
.83333 .18746 L
s
.88095 .18371 m
.88095 .18746 L
s
.92857 .18371 m
.92857 .18746 L
s
.25 Mabswid
0 .18371 m
1 .18371 L
s
gsave
1.025 .18371 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01587 m
.03006 .01587 L
s
[(-0.4)] .01131 .01587 1 0 Mshowa
.02381 .09979 m
.03006 .09979 L
s
[(-0.2)] .01131 .09979 1 0 Mshowa
.02381 .26764 m
.03006 .26764 L
s
[(0.2)] .01131 .26764 1 0 Mshowa
.02381 .35156 m
.03006 .35156 L
s
[(0.4)] .01131 .35156 1 0 Mshowa
.02381 .43548 m
.03006 .43548 L
s
[(0.6)] .01131 .43548 1 0 Mshowa
.02381 .5194 m
.03006 .5194 L
s
[(0.8)] .01131 .5194 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03685 m
.02756 .03685 L
s
.02381 .05783 m
.02756 .05783 L
s
.02381 .07881 m
.02756 .07881 L
s
.02381 .12077 m
.02756 .12077 L
s
.02381 .14175 m
.02756 .14175 L
s
.02381 .16273 m
.02756 .16273 L
s
.02381 .20469 m
.02756 .20469 L
s
.02381 .22568 m
.02756 .22568 L
s
.02381 .24666 m
.02756 .24666 L
s
.02381 .28862 m
.02756 .28862 L
s
.02381 .3096 m
.02756 .3096 L
s
.02381 .33058 m
.02756 .33058 L
s
.02381 .37254 m
.02756 .37254 L
s
.02381 .39352 m
.02756 .39352 L
s
.02381 .4145 m
.02756 .4145 L
s
.02381 .45646 m
.02756 .45646 L
s
.02381 .47744 m
.02756 .47744 L
s
.02381 .49842 m
.02756 .49842 L
s
.02381 .54038 m
.02756 .54038 L
s
.02381 .56136 m
.02756 .56136 L
s
.02381 .58234 m
.02756 .58234 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -135.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(J) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.250 13.000 moveto
(H) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
86.250 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
90.438 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.625 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.875 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.875 13.000 moveto
(\\220) show
117.875 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.875 13.000 moveto
(L) show
135.875 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(for) show
159.875 13.000 moveto
(n) show
165.875 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
171.875 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
183.875 13.000 moveto
(to) show
201.875 13.000 moveto
(4) show
207.875 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60331 L
.02846 .6033 L
.03053 .60329 L
.03279 .60327 L
.03527 .60323 L
.0379 .60319 L
.04262 .60308 L
.04749 .60294 L
.05205 .60279 L
.06244 .60232 L
.07305 .6017 L
.08274 .601 L
.10458 .59897 L
.12357 .59669 L
.14429 .59367 L
.18493 .58613 L
.22406 .57692 L
.26565 .5651 L
.30571 .55183 L
.34426 .53739 L
.38527 .52038 L
.42475 .50249 L
.46273 .48403 L
.50315 .46315 L
.54206 .44202 L
.58342 .4186 L
.62326 .39528 L
.66159 .3723 L
.70238 .34745 L
.74164 .32331 L
.77939 .30004 L
.8196 .27538 L
.85828 .25193 L
.89942 .22746 L
.93905 .20452 L
.97619 .18371 L
s
0 0 1 r
.02381 .60332 m
.02499 .60331 L
.02605 .6033 L
.02729 .60328 L
.02846 .60324 L
.03053 .60316 L
.03279 .60304 L
.03527 .60286 L
.0379 .60262 L
.04262 .60207 L
.04749 .60135 L
.05205 .60051 L
.06244 .59807 L
.07305 .59482 L
.08274 .59117 L
.10458 .58064 L
.14429 .5537 L
.18248 .51917 L
.22313 .47457 L
.26226 .42564 L
.30384 .36928 L
.34391 .31287 L
.38246 .2587 L
.42346 .20331 L
.46295 .15408 L
.50092 .11211 L
.54134 .07464 L
.58025 .04665 L
.60149 .03498 L
.62161 .02634 L
.63127 .02305 L
.64152 .02015 L
.65028 .01817 L
.65994 .0165 L
.66486 .01587 L
.67003 .01535 L
.67445 .01503 L
.67696 .01489 L
.67929 .0148 L
.68059 .01477 L
.68128 .01475 L
.68201 .01474 L
.68264 .01473 L
.68334 .01472 L
.68457 .01472 L
.68577 .01472 L
.68705 .01473 L
.68826 .01475 L
.68937 .01477 L
.69074 .01481 L
Mistroke
.69202 .01486 L
.6949 .015 L
.69744 .01516 L
.70014 .01537 L
.70552 .01591 L
.71046 .01654 L
.7216 .01846 L
.73142 .02069 L
.74178 .02357 L
.7798 .03857 L
.82028 .06123 L
.85924 .08819 L
.90065 .12065 L
.94055 .15387 L
.97619 .18371 L
Mfstroke
0 1 0 r
.02381 .60332 m
.02499 .60331 L
.02605 .60328 L
.02729 .60321 L
.02846 .60313 L
.03053 .60293 L
.03279 .60262 L
.03527 .60218 L
.0379 .6016 L
.04262 .60026 L
.04749 .59848 L
.05205 .59644 L
.06244 .59049 L
.07305 .58258 L
.08274 .57377 L
.10458 .54869 L
.14429 .48671 L
.18248 .41201 L
.22313 .32367 L
.26226 .23784 L
.30384 .15424 L
.34391 .08826 L
.36228 .0643 L
.38246 .04321 L
.40239 .02799 L
.41329 .0221 L
.42346 .01816 L
.42847 .01677 L
.43111 .01618 L
.43391 .01566 L
.43635 .0153 L
.43765 .01515 L
.43905 .01501 L
.44033 .0149 L
.44151 .01483 L
.44263 .01477 L
.44381 .01474 L
.44497 .01472 L
.44603 .01472 L
.44725 .01474 L
.4484 .01477 L
.44947 .01482 L
.45045 .01489 L
.45267 .01507 L
.45492 .01533 L
.45738 .01569 L
.46237 .01667 L
.46758 .01805 L
.47253 .01968 L
.48182 .02358 L
Mistroke
.49181 .02896 L
.50271 .03612 L
.54341 .07321 L
.58259 .11995 L
.62422 .17446 L
.66434 .22481 L
.70294 .26548 L
.72292 .28205 L
.7331 .28912 L
.744 .29557 L
.7543 .30059 L
.76368 .30421 L
.76819 .30562 L
.7731 .30692 L
.7774 .30785 L
.78202 .30864 L
.78456 .30897 L
.78689 .30922 L
.78911 .3094 L
.79033 .30948 L
.79145 .30954 L
.79269 .30959 L
.79338 .30961 L
.79402 .30963 L
.79517 .30964 L
.79641 .30964 L
.79707 .30964 L
.79778 .30963 L
.79853 .30961 L
.79924 .30959 L
.80049 .30954 L
.80184 .30946 L
.80454 .30926 L
.80748 .30895 L
.81283 .30817 L
.81803 .30713 L
.82286 .30593 L
.83247 .30286 L
.8415 .29919 L
.86209 .28814 L
.90075 .25884 L
.94185 .21932 L
.97619 .18371 L
Mfstroke
.628 .126 .941 r
.02381 .60332 m
.02499 .6033 L
.02605 .60324 L
.02729 .60312 L
.02846 .60297 L
.03053 .60259 L
.03279 .60202 L
.03527 .60121 L
.0379 .60013 L
.04262 .59765 L
.04749 .59435 L
.05205 .59059 L
.06244 .57966 L
.07305 .56523 L
.08274 .5493 L
.10458 .50479 L
.14429 .40043 L
.18248 .28626 L
.22313 .17019 L
.24192 .12385 L
.26226 .08157 L
.27341 .06239 L
.28367 .04749 L
.2941 .03513 L
.30384 .0262 L
.31292 .02018 L
.31802 .01778 L
.32266 .01619 L
.3253 .01555 L
.32775 .01512 L
.32902 .01495 L
.32975 .01488 L
.33043 .01482 L
.33113 .01478 L
.3319 .01474 L
.33257 .01472 L
.33327 .01472 L
.33448 .01473 L
.33576 .01479 L
.33697 .01489 L
.33807 .01501 L
.33937 .01519 L
.34078 .01543 L
.34333 .016 L
.34822 .01755 L
.35279 .01952 L
.3632 .02583 L
.37335 .03428 L
.38424 .04567 L
.42552 .10559 L
Mistroke
.46528 .17595 L
.50353 .23975 L
.52489 .26875 L
.54423 .289 L
.55393 .29671 L
.55903 .30006 L
.56441 .30306 L
.56914 .30523 L
.57431 .30712 L
.57659 .30778 L
.57902 .30838 L
.58111 .3088 L
.58341 .30916 L
.58473 .30933 L
.58598 .30945 L
.58729 .30955 L
.58803 .30959 L
.58871 .30962 L
.58985 .30964 L
.5911 .30964 L
.5924 .30961 L
.59361 .30955 L
.5943 .3095 L
.59505 .30944 L
.59642 .3093 L
.59897 .30895 L
.60195 .30838 L
.60469 .30771 L
.60935 .30625 L
.61447 .30419 L
.62482 .29863 L
.63501 .29142 L
.64431 .28346 L
.66521 .26141 L
.70503 .20884 L
.74332 .15544 L
.76268 .13116 L
.78407 .10856 L
.7938 .10013 L
.8043 .09251 L
.81421 .0868 L
.82331 .0829 L
.82804 .0814 L
.83064 .08072 L
.83309 .08018 L
.83538 .07976 L
.83787 .07941 L
.83896 .07928 L
.84012 .07917 L
.84119 .07909 L
Mistroke
.84221 .07902 L
.84349 .07897 L
.84466 .07894 L
.84592 .07894 L
.84663 .07895 L
.84729 .07896 L
.8485 .07901 L
.8496 .07907 L
.85086 .07917 L
.85206 .07928 L
.85477 .07962 L
.85727 .08004 L
.8629 .08134 L
.8676 .0828 L
.87264 .08474 L
.88174 .08916 L
.90241 .10334 L
.92366 .12296 L
.94379 .14496 L
.97619 .18371 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003ooooooona
ooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00oooooona
ooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00:?ooool00ol0003ooooooooo
o`3oooooohKooooo000Xooooo`03o`000?oooooooooo0?ooooooQ_ooool002Sooooo00?o0000oooo
ooooool0oooooon6ooooo`002oooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE
00Oooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooQ_ooool000[o
oooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00002?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooQ_ooool000[ooooo00KoA4A4ojVYZOooooooooooojVYZOlb
<S85ooooo`03oeEEEOl0003oEEEE00Cooooo1_l00006ooooo`03o`000?oooooooooo0?ooooooQ_oo
ool00003ooooool0003o000000Go00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00GoIVIVojVYZOooooooooooo`000007ooooo`?o0000Ioooool:oj0Pl1cooooo3_l0
o`14oooooaKo003oT?ooool000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:
ooooo`05onk^k_lQ8B7ok^k^ooooool000001oooool00ol0003oooooooooo`1Tooooo`?oX23`2_oo
ool3oj0Pl1Kooooo0ol0o`0>ooooo`Co0?l0>_ooool6o`00oaKooooo1?l00?n<ooooo`002_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00CoZJVYofIVI_oooooo00001ooo
ool00ol0003oooooooooo`1Sooooo`03oj0Pl?oooooooooo00kooooo00?oX23`ooooooooool04?oo
ool3o`3o01Gooooo0_l0o`0fooooo`;o003o8?ooool4o`00ohSooooo000:ooooo`06odA4A?nYZJWo
oooooooooonYZJWoA4A43_ooool00om4A4Coc<c<o`000007ooooo`03o`000?oooooooooo06;ooooo
00?oX23`ooooooooool04?ooool00onP8?3oooooooooo`0=ooooo`;o0?l06_ooool2o`3o037ooooo
0ol00?lVooooo`;o003oQ_ooool000[ooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`>ooooo`03
omgMgOm4A4Co000000Oooooo00?o0000ooooooooool0H?ooool2oj0Pl1Cooooo0_nP8?0;ooooo`;o
0?l07_ooool00ol0o`3oooooooooo`0[ooooo`?o003o:oooool3o`00oh?ooooo000;ooooo`04okZj
^_l@413o410@olc<c13ooooo00?oQhN7o`000?ooool01_ooool00ol0003oooooooooo`1Oooooo`03
oj0Pl?oooooooooo01Kooooo00?oX23`ooooooooool01oooool00ol0o`3oooooooooo`0Oooooo`;o
0?l0:?ooool3o`00oc7ooooo0ol00?n0ooooo`00:?ooool00ol0003oooooooooo`1Nooooo`03oj0P
l?oooooooooo01Sooooo00?oX23`ooooooooool01Oooool00ol0o`3oooooooooo`0Rooooo`;o0?l0
9?ooool2o`00ocOooooo0ol00?mmooooo`00:?ooool2o`0005kooooo00?oX23`ooooooooool06_oo
ool00onP8?3oooooooooo`03ooooo`03o`3o0?oooooooooo02Gooooo0_l0o`0Pooooo`;o003o??oo
ool3o`00og[ooooo000Xooooo`03o`000?oooooooooo05gooooo00?oX23`ooooooooool06oooool0
1OnP8?3ooooooooooooooooo0?l002[ooooo00?o0?l0ooooooooool06oooool2o`00od7ooooo0_l0
0?mhooooo`00:?ooool00ol0003oooooooooo`1Looooo`03oj0Pl?oooooooooo01gooooo00?oX23`
ooooool0o`00;?ooool00ol0o`3oooooooooo`0Iooooo`03o`00oooooooooooo04?ooooo0_l00?mf
ooooo`00:?ooool00ol0003oooooooooo`1Kooooo`03oj0Pl?oooooooooo01oooooo00?oX23`oooo
ooooool0;?ooool00ol0o`3oooooooooo`0Fooooo`;o003oB?ooool00ol00?ooooooooooo`1coooo
o`00:?ooool00ol0003oooooooooo`1Jooooo`03oj0Pl?oooooooooo01oooooo00?o0?l0oooooonP
8?00;_ooool00ol0o`3oooooooooo`0Cooooo`;o003oBoooool2o`00og?ooooo000Xooooo`03o`00
0?oooooooooo05[ooooo00?oX23`ooooooooool07_ooool01?l0o`3ooooooooooonP8?0_ooooo`03
o`3o0?oooooooooo017ooooo00?o003oooooooooool0COooool2o`00og7ooooo000Xooooo`03o`00
0?oooooooooo05Wooooo00?oX23`ooooooooool07_ooool00ol0o`3oooooooooo`02ooooo`03oj0P
l?oooooooooo02gooooo0_l0o`0?ooooo`;o003oD_ooool2o`00ofoooooo000Xooooo`03o`000?oo
oooooooo05Sooooo00?oX23`ooooooooool07_ooool00ol0o`3oooooooooo`04ooooo`03oj0Pl?oo
oooooooo02kooooo00?o0?l0ooooooooool02oooool00ol00?ooooooooooo`1Dooooo`03o`00oooo
oooooooo06cooooo000Xooooo`;o0000FOooool00onP8?3oooooooooo`0Mooooo`03o`3o0?oooooo
oooo00Gooooo00?oX23`ooooooooool0;oooool00ol0o`3oooooooooo`09ooooo`03o`00oooooooo
oooo05Kooooo0_l00?m/ooooo`00:?ooool00ol0003oooooooooo`1Gooooo`03oj0Pl?oooooooooo
01gooooo00?o0?l0ooooooooool01oooool00onP8?3oooooooooo`0_ooooo`03o`3o0?oooooooooo
00Kooooo0_l00?mKooooo`;o003oJ_ooool002Sooooo00?o0000ooooooooool0E_ooool00onP8?3o
ooooooooo`0Mooooo`03o`3o0?oooooooooo00Wooooo00?oX23`ooooooooool0;oooool00ol0o`3o
ooooooooo`04ooooo`03o`00oooooooooooo05gooooo00?o003oooooooooool0Ioooool002Sooooo
00?o0000ooooooooool0E_ooool00onP8?3oooooooooo`0Mooooo`03o`3o0?oooooooooo00Wooooo
00?oX23`ooooooooool0<?ooool01?l0o`3oooooooooooooool2o`00of7ooooo0_l00?mWooooo`00
:?ooool00ol0003oooooooooo`1Eooooo`03oj0Pl?oooooooooo01gooooo00?o0?l0ooooooooool0
2oooool00onP8?3oooooooooo`0`ooooo`03o`3o0?oooooo003o06Gooooo00?o003oooooooooool0
I?ooool002Sooooo00?o0000ooooooooool0E?ooool00onP8?3oooooooooo`0Mooooo`03o`3o0?oo
oooooooo00gooooo00?oX23`ooooooooool0<?ooool00ol0o`3oooooooooo`1Uooooo`03o`00oooo
oooooooo06?ooooo000Xooooo`03o`000?oooooooooo05Cooooo00?oX23`ooooooooool07?ooool0
0ol0o`3oooooooooo`0>ooooo`03oj0Pl?oooooooooo02kooooo0_l00?l00ol0o`3oooooooooo`1V
ooooo`;o003oHoooool002Sooooo0_l0001Dooooo`03oj0Pl?oooooooooo01cooooo00?o0?l0oooo
ooooool04?ooool00onP8?3oooooooooo`0/ooooo`05o`00ooooooooooooooooool0o`00JOooool2
oj0Pl67ooooo000Xooooo`03o`000?oooooooooo05;ooooo00?oX23`ooooooooool07Oooool00ol0
o`3oooooooooo`0Aooooo`03oj0Pl?oooooooooo02[ooooo00?o003oooooooooool00oooool00ol0
o`3oooooooooo`1Oooooo`OoX23`00?ooooooj0Pl?nP8?001OnP8?1Kooooo`00:?ooool00ol0003o
ooooooooo`1Booooo`03oj0Pl?oooooooooo01cooooo00?o0?l0ooooooooool04_ooool00onP8?3o
ooooooooo`0Yooooo`03o`00oooooooooooo00Gooooo00?o0?l0ooooooooool0G?ooool2oj0Pl0[o
oooo00?o003oooooooooool00_ooool2oj0Pl5Wooooo000Xooooo`03o`000?oooooooooo057ooooo
00?oX23`ooooooooool07?ooool00ol0o`3oooooooooo`0Dooooo`03oj0Pl?oooooooooo02Oooooo
00?o003oooooooooool01oooool00ol0o`3oooooooooo`1Hooooo`?oX23`3Oooool00ol00?oooooo
ooooo`03ooooo`?oX23`E_ooool002Sooooo00?o0000ooooooooool0DOooool00onP8?3ooooooooo
o`0Kooooo`03o`3o0?oooooooooo01Kooooo00?oX23`ooooooooool09Oooool00ol00?oooooooooo
o`09ooooo`03o`3o0?oooooooooo05Kooooo00?oX23`ooooooooool03oooool2o`00o`Kooooo0_nP
8?1Dooooo`002oooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo1_l0
0006ooooo`03o`000?oooooooooo053ooooo00?oX23`ooooooooool07?ooool00ol0o`3ooooooooo
o`0Fooooo`03oj0Pl?oooooooooo02?ooooo0_l00?l<ooooo`03o`3o0?oooooooooo05Cooooo0_nP
8?0Dooooo`03o`00oooooooooooo00Gooooo00?oX23`ooooooooool0DOooool000[ooooo00Koc<c<
oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool00onHV9So0000olc<c002ooooo`03oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0D?ooool00onP8?3oooooooooo`0Kooooo`03o`3o
0?oooooooooo01Sooooo00?oX23`ooooooooool08Oooool00ol00?ooooooooooo`0=ooooo`03o`3o
0?oooooooooo05;ooooo00?oX23`ooooooooool05Oooool00ol00?ooooooooooo`05ooooo`;oX23`
DOooool000[ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Go
oooo00?oV9RHo`000?o<c<`02?ooool00ol0003oooooooooo`1@ooooo`03oj0Pl?oooooooooo01[o
oooo00?o0?l0ooooooooool06_ooool00onP8?3oooooooooo`0Oooooo`03o`00oooooooooooo00oo
oooo00?o0?l0ooooooooool0D?ooool00onP8?3oooooooooo`0Gooooo`;o003o1oooool2oj0Pl4oo
oooo00000ooooooo0000o`000005o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03ojVYZOl@413oc<c<00Oooooo0ol0001?ooooo`03oj0Pl?oooooooooo01_ooooo
00?o0?l0ooooooooool06_ooool00onP8?3oooooooooo`0Nooooo`03o`00oooooooooooo017ooooo
00?o0?l0ooooooooool0COooool2oj0Pl1cooooo00?o003oooooooooool01_ooool00onP8?3ooooo
ooooo`1<ooooo`002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o
c<c<oa0@4?o<c<`01_ooool00ol0003oooooooooo`1?ooooo`03oj0Pl?oooooooooo01[ooooo00?o
0?l0ooooooooool07?ooool00onP8?3oooooooooo`0Looooo`03o`00oooooooooooo01?ooooo00?o
0?l0ooooooooool0Boooool00onP8?3oooooooooo`0Mooooo`;o003o1oooool00onP8?3ooooooooo
o`1;ooooo`002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?oZJVY
oc8b<_ooool01Oooool00ol0003oooooooooo`1>ooooo`03oj0Pl?oooooooooo01_ooooo00?o0?l0
ooooooooool07Oooool00onP8?3oooooooooo`0Jooooo`03o`00oooooooooooo01Cooooo00?o0?l0
ooooooooool0B_ooool00onP8?3oooooooooo`0Pooooo`03o`00oooooooooooo00Gooooo00?oX23`
ooooooooool0B_ooool000[ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@Aooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0C_ooool00onP8?3oooooooooo`0Jooooo`03o`3o0?oo
oooooooo01kooooo00?oX23`ooooooooool06Oooool00ol00?ooooooooooo`0Fooooo`03o`3o0?oo
oooooooo04Sooooo00?oX23`ooooooooool08_ooool00ol00?ooooooooooo`05ooooo`03oj0Pl?oo
oooooooo04Wooooo000:ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool01_l0003oQhN7
onk^k_ooooooMgMgoc8b<PKooooo00?o0000ooooooooool0COooool00onP8?3oooooooooo`0Joooo
o`03o`3o0?oooooooooo023ooooo00?oX23`ooooooooool05oooool00ol00?ooooooooooo`0Hoooo
o`03o`3o0?oooooooooo04Oooooo00?oX23`ooooooooool08oooool2o`00o`Kooooo00?oX23`oooo
ooooool0B?ooool000_ooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool01_nYZJWo<S8bo`000?l0003o
EEEEonk^kPKooooo00?o0000ooooooooool0COooool00onP8?3oooooooooo`0Jooooo`03o`3o0?oo
oooooooo027ooooo00?oX23`ooooooooool05_ooool00ol00?ooooooooooo`0Iooooo`03o`3o0?oo
oooooooo04Gooooo00?oX23`ooooooooool09_ooool00ol00?ooooooooooo`04ooooo`03oj0Pl?oo
oooooooo04Oooooo000Xooooo`03o`000?oooooooooo04gooooo00?oX23`ooooooooool06Oooool0
0ol0o`3oooooooooo`0Rooooo`03oj0Pl?oooooooooo01Gooooo00?o003oooooooooool06oooool0
0ol0o`3oooooooooo`13ooooo`03oj0Pl?oooooooooo02Sooooo00?o003oooooooooool01?ooool0
0onP8?3oooooooooo`16ooooo`00:?ooool2o`0004gooooo00?oX23`ooooooooool06_ooool00ol0
o`3oooooooooo`0Sooooo`03oj0Pl?oooooooooo01?ooooo00?o003oooooooooool07Oooool00ol0
o`3oooooooooo`11ooooo`03oj0Pl?oooooooooo02[ooooo0_l00?l5ooooo`03oj0Pl?oooooooooo
04Gooooo000Xooooo`03o`000?oooooooooo04cooooo00?oX23`ooooooooool06Oooool00ol0o`3o
ooooooooo`0Tooooo`03oj0Pl?oooooooooo01;ooooo00?o003oooooooooool07_ooool00ol0o`3o
ooooooooo`10ooooo`03oj0Pl?oooooooooo02gooooo00?o003oooooooooool00oooool00onP8?3o
ooooooooo`14ooooo`00:?ooool00ol0003oooooooooo`1;ooooo`03oj0Pl?oooooooooo01Wooooo
00?o0?l0ooooooooool09_ooool00onP8?3oooooooooo`0@ooooo`03o`00oooooooooooo023ooooo
00?o0?l0ooooooooool0?_ooool00onP8?3oooooooooo`0_ooooo`03o`00oooooooooooo00;ooooo
00?oX23`ooooooooool0A?ooool002Sooooo00?o0000ooooooooool0Boooool00onP8?3ooooooooo
o`0Iooooo`03o`3o0?oooooooooo02Oooooo00?oX23`ooooooooool03_ooool00ol00?oooooooooo
o`0Rooooo`03o`3o0?oooooooooo03cooooo00?oX23`ooooooooool0<Oooool00ol00?oooooooooo
o`02ooooo`03oj0Pl?oooooooooo04?ooooo000Xooooo`03o`000?oooooooooo04[ooooo00?oX23`
ooooooooool06Oooool00ol0o`3oooooooooo`0Xooooo`03oj0Pl?oooooooooo00gooooo00?o003o
ooooooooool08oooool00ol0o`3oooooooooo`0kooooo`03oj0Pl?oooooooooo03?ooooo00?o003o
ooooooooool00_ooool00onP8?3oooooooooo`12ooooo`00:?ooool00ol0003oooooooooo`1:oooo
o`03oj0Pl?oooooooooo01Wooooo00?o0?l0ooooooooool0:Oooool00onP8?3oooooooooo`0;oooo
o`03o`00oooooooooooo02Gooooo00?o0?l0ooooooooool0>_ooool00onP8?3oooooooooo`0doooo
o`03o`00oooooooooooo00;ooooo00?oX23`ooooooooool0@Oooool002Sooooo00?o0000oooooooo
ool0BOooool00onP8?3oooooooooo`0Iooooo`03o`3o0?oooooooooo02[ooooo00?oX23`oooooooo
ool02oooool00ol00?ooooooooooo`0Vooooo`03o`3o0?oooooooooo03Sooooo00?oX23`oooooooo
ool0=_ooool2o`00o`?ooooo00?oX23`ooooooooool0@?ooool002Sooooo00?o0000ooooooooool0
BOooool00onP8?3oooooooooo`0Hooooo`03o`3o0?oooooooooo02cooooo00?oX23`ooooooooool0
2Oooool00ol00?ooooooooooo`0Xooooo`03o`3o0?oooooooooo03Kooooo00?oX23`ooooooooool0
>Oooool01Ol00?ooooooooooooooooooX23`047ooooo000Xooooo`;o0000=_ooool01?nj^[[o410@
o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo0ol000000onP8?3o0000o`00000Hooooo`03
o`3o0?oooooooooo01?ooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@07oooo
o`;o000000Go410@oooooooooooooooooj0Pl009ooooo`03o`00oooooooooooo01gooooo00Co^[Zj
oa0@4?l0003oMgMg1_ooool00omEEEGo0000o`3o0004ooooo`06onk^k_m4A4Co0000o`000?mEEEGo
k^k^;Oooool01?nP8?3o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE00Cooooo00Kok^k^odA4
A?l0003o0000odA4A?o^k^hWooooo`05o`00oooooooooooooooooonP8?002_ooool4o`000003oa0@
4?oooooooooo02oooooo000Xooooo`03o`000?oooooooooo03Cooooo00Koc<c<oc8b<_o^k^kok^k^
ob4Q8OnYZJT5ooooo`?o00001?ooool00onHV9So0000oj0Pl002ooooo`03oa0@4?oooooooooo01Go
oooo00?o0?l0ooooooooool04oooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00008
ooooo`03o`000?oooooooooo00;ooooo00?oX23`ooooooooool01_ooool00ol00?ooooooooooo`0M
ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`000006o`3o0?oooooooooooooooomE
EEGoMgMg0_ooool00omgMgOoEEEEooooo`0[ooooo`06oj0Pl?lb<S;ok^k^onk^k_lQ8B7oZJVY1Ooo
ool3o`0000Cooooo00Ko<S8bogMgMoo^k^kok^k^ogMgMolb<S8Xooooo`05o`00oooooooooooooooo
oonP8?002oooool00ol0003oooooooooo`0aooooo`00:?ooool00ol0003oooooooooo`0dooooo`06
odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@05ooooo`03oiRHV?nP8?3o
c<c<01Wooooo00?o0?l0ooooooooool04oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo
00?oEEEEo`000?mEEED01?ooool6o`0000Cooooo00?oX23`ooooooooool01?ooool00ol00?oooooo
ooooo`0Nooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool01OmEEEGo0000oeEEEOoooooo
0?l000;ooooo00?o410@ooooooooool00_ooool00ol0003oooooooooo`0Zooooo`06oj0Pl?nYZJWo
oooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool09oooool01?l00?oooooooooooonP8?0;ooooo`03o`000?oooooooooo037o
oooo000Xooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0;ooooo`04oj0Pl?nYZJWo410@olc<c1Oooooo00?o0?l0ooooooooool05?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00GoIVIVojVYZOooooooooooo`000005oooo
o`03oj0Pl?oooooooooo00?ooooo00?o003oooooooooool07oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00Go0?l0oooooooooooo0000onk^kP03ooooo`03o`000?oooooo
oooo02Wooooo00?oX23`o`000?ooool00oooool00ol0003oooooooooo`0:ooooo`06oc8b<_mgMgOo
k^k^onk^k_mgMgOo<S8b:_ooool01?l00?oooooooooooonP8?0:ooooo`03o`000?oooooooooo037o
oooo000Xooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0;ooooo`05oj0Pl?ooooooc<c<oa0@4?o<c<`05Oooool00ol0o`3oooooooooo`0Eooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01Oo^k^ko8B4Qonk^k_oooooo0000
00Kooooo00GoX23`ooooooooooooooooo`00o`0Rooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool02?l0o`3oooooo`000?mEEEGok^k^oooooomgMgOoEEEE:_ooool00onP8?3o
ooooo`000004ooooo`03o`000?oooooooooo00[ooooo00?ogMgMo`000?l000000_l000000ooMgMgo
ooooooooo`0Yooooo`;o003o00?ooooooj0Pl?ooool02?ooool00ol0003oooooooooo`0aooooo`00
:?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2_ooool01_nP8?3oooooooooooooooooZJVYoc8b<QGooooo00?o0?l0ooooooooool05Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00CoZJVYofIVI_oooooo00001oooool0
1?nP8?3oooooooooool00?lRooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Ooo
ool00ol0o`3o8B4QofIVIP02o`000003oeEEEOo^k^kooooo02Sooooo00CoX23`oooooooooooo0000
1?ooool00ol0003oooooooooo`0:ooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b;Oooool00ol0
0?oooooooj0Pl008ooooo`03o`000?oooooooooo037ooooo000Xooooo`03o`000?oooooooooo03Co
oooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03oj0Pl?oooooooooo00;ooooo00?o0000
ooooooooool04_ooool00ol0o`3oooooooooo`0Fooooo`06odA4A?nYZJWooooooooooonYZJWoA4A4
3_ooool00om4A4Coc<c<o`000007ooooo`03oj0Pl?oooooo003o02?ooooo00KoA4A4ojVYZOoooooo
ooooojVYZOm4A4@;ooooo`03o`3o0?n7QhOoIVIV02gooooo00GoX23`ooooooooooooA4A4ojVYZ@02
ooooo`03ojVYZOm4A4Cooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/
ooooo`03o`00ooooooooX23`00Oooooo00?o0000ooooooooool0<Oooool002Sooooo0_l0000eoooo
o`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool01_nP8?3oQhN7onk^k_ooooooMgMgoc8b<QCo
oooo00?o0?l0ooooooooool05_ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0kooooo00?ogMgM
odA4A?l000002?ooool00onP8?3oooooooooo`0Rooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<
3?ooool01?l0o`3o<S8bofIVI_oMgMdZooooo`06oj0Pl?ooooooooooooooooo<c<co<S8b0_o^k^h0
0olb<S;oc<c<ooooo`0;ooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b;oooool00ol00?oooooo
oj0Pl004ooooo`03o`000?m4A4Co000003?ooooo000Xooooo`03o`000?oooooooooo03Gooooo00Co
^[Zjoa0@4?l@413oc<c<3?ooool00onP8?3oZJVYoc8b<P02o`000003oeEEEOo^k^kooooo01;ooooo
00?o0?l0ooooooooool06?ooool01?nj^[[o410@oa0@4?o<c<`@ooooo`03ohN7Qol0003ooooo00Ko
oooo00?o003ooj0Pl?ooool09?ooool01?nj^[[o410@oa0@4?o<c<`>ooooo`05o`3o0?mgMgOo410@
o`000?lQ8B409oooool00onP8?3oooooooooo`03ooooo`04okZj^_l@413o410@olc<c0gooooo00Ko
k^k^odA4A?l0003o0000odA4A?o^k^h`ooooo`03o`00ooooooooX23`00?ooooo00?oc<c<oeEEEOl0
0000<oooool002Sooooo00?o0000ooooooooool0AOooool00onP8?3oooooooooo`0Gooooo`03o`3o
0?oooooooooo03Cooooo00Co003oooooooooooooX23`=oooool00ol0o`3oooooooooo`0Wooooo`03
oj0Pl?oooooooooo04cooooo00?o003ooj0Pl?ooool0>?ooool002Sooooo00?o0000ooooooooool0
A?ooool00onP8?3oooooooooo`0Gooooo`03o`3o0?oooooooooo03Gooooo00Go003ooooooooooooo
oooooj0Pl00fooooo`03o`3o0?oooooooooo02Oooooo00?oX23`ooooooooool0C_ooool00onP8?3o
ooooooooo`0Rooooo`03ob4Q8OoMgMgooooo017ooooo000Xooooo`03o`000?oooooooooo04Cooooo
00?oX23`ooooooooool05oooool00ol0o`3oooooooooo`0dooooo`03o`00oooooooooooo00;ooooo
00?oX23`ooooooooool0=Oooool00ol0o`3oooooooooo`0Uooooo`03oj0Pl?oooooooooo053ooooo
00?oX23`ooooooooool05oooool6o`0000Cooooo00?oQhN7ofIVI_ooool01Oooool01onYZJWo410@
o`000?lQ8B7oV9RHoa0@4?l000001Oooool002Sooooo00?o0000ooooooooool0@oooool00onP8?3o
ooooooooo`0Gooooo`03o`3o0?oooooooooo03Cooooo00?o003oooooooooool01?ooool00onP8?3o
ooooooooo`0eooooo`03o`3o0?oooooooooo02?ooooo00?oX23`ooooooooool0D_ooool00onP8?3o
ooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?ok^k^o`000?ooool01Oooool01_l0003o
^[ZjoooooooMgMgoMgMgo`0000Kooooo000Xooooo`03o`000?oooooooooo04?ooooo00?oX23`oooo
ooooool05oooool00ol0o`3oooooooooo`0cooooo`03o`00oooooooooooo00Gooooo00?oX23`oooo
ooooool0=Oooool00ol0o`3oooooooooo`0Rooooo`03oj0Pl?oooooooooo05Cooooo00?oX23`oooo
ooooool05oooool00ol0003oooooooooo`06ooooo`03oeEEEOnHV9Sooooo00Cooooo00Ko410@ohN7
Qoo^k^koooooomgMgOl00006ooooo`00:?ooool00ol0003oooooooooo`13ooooo`03oj0Pl?oooooo
oooo01Kooooo00?o0?l0ooooooooool0=?ooool00ol00?ooooooooooo`06ooooo`03oj0Pl?oooooo
oooo03Gooooo00?o0?l0ooooooooool08Oooool00onP8?3oooooooooo`1Eooooo`03oj0Pl?oooooo
oooo01Kooooo00?o0000ooooooooool01_ooool00onj^[[o<S8booooo`04ooooo`06olc<c?m4A4Co
0000o`000?l@413o00001_ooool001ooooooC_l000000onP8?3o0000o`00000Go`000003o`3o0?l0
003o000003?o000000?o003oo`000?l000001ol000000onP8?3o0000o`00000fo`000003o`3o0?l0
003o000001oo000000?oX23`o`000?l00000E_l000000ooo003oX23`o`000008o`0000kooooo00?o
0000omgMgOooool01oooool00ol@413oc<c<ooooo`08ooooo`03o`000?oooooooooo00Cooooo000X
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000oj0Pl?ooool03_ooool00ol0003oooooooooo`06
ooooo`03o`3o0?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03oj0Pl?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00[ooooo00Go0?l0ooooooooooooooooo`00000@ooooo`03o`000?oo
oooooooo00Sooooo00?oX23`ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00_ooooo0_oo00000ooooooo0?l0ooooo`0Fooooo`;o000000?oV9RHooooooooool01Ooo
ool00on7QhOoEEEEooooo`07ooooo`03ohN7Qolb<S;ooooo00Gooooo000Xooooo`03o`000?oooooo
oooo047ooooo00?o0000oj0Pl?ooool05oooool00ol0o`3oooooooooo`0Wooooo`03o`000?oooooo
oooo00Sooooo00?o003oooooooooool02oooool00onP8?3oooooooooo`0Xooooo`03o`000?oooooo
oooo00_ooooo00?o0?l0ooooooooool07?ooool00onP8?3oooooooooo`0Dooooo`03o`000?oooooo
oooo03cooooo0_oo0002ooooo`03o`3o0?l0003ooooo01Cooooo00Go410@o`000?l0003o^[ZjodA4
A002o`000003ob4Q8Ooooooooooo00;ooooo00?ok^k^oa0@4?o^k^h01?ooool01Om4A4Co0000o`00
0?l@413oc<c<00Kooooo000Xooooo`03o`000?oooooooooo047ooooo00?oX23`ooooooooool05_oo
ool00ol0o`3oooooooooo`0booooo`03o`00oooooooooooo00cooooo00?oX23`ooooooooool0=ooo
ool00ol0o`3oooooooooo`0Jooooo`03oj0Pl?oooooooooo05;ooooo0_oo0003ooooo`03o`3o0?oo
oooooooo02;ooooo00?oEEEEoiRHV?ooool03_ooool002Sooooo00?o0000ooooooooool0@Oooool0
0onP8?3oooooooooo`0Fooooo`03o`3o0?oooooooooo03;ooooo00?o003oooooooooool03Oooool0
0onP8?3oooooooooo`0fooooo`03o`3o0?oooooooooo01Wooooo00?oX23`ooooooooool0D_ooool0
0ooo003oooooooooo`02ooooo`03o`3o0?oooooooooo02?ooooo00?oc<c<oc8b<_ooool03_ooool0
02Sooooo00?o0000ooooooooool0@Oooool00onP8?3oooooooooo`0Eooooo`03o`3o0?oooooooooo
03;ooooo00?o003oooooooooool03_ooool00onP8?3oooooooooo`0gooooo`03o`3o0?oooooooooo
01Oooooo00?oX23`ooooooooool0DOooool2ool000Cooooo00?o0?l0ooooooooool0=Oooool002So
oooo00?o0000ooooooooool0@?ooool00onP8?3oooooooooo`0Fooooo`03o`3o0?oooooooooo037o
oooo00?o003oooooooooool04?ooool00onP8?3oooooooooo`0gooooo`03o`3o0?oooooooooo01Ko
oooo00?oX23`ooooooooool0Coooool2ool000Gooooo00?o0?l0ooooooooool0=_ooool002Sooooo
0_l00011ooooo`03oj0Pl?oooooooooo01Gooooo00?o0?l0ooooooooool0<Oooool00ol00?oooooo
ooooo`0Aooooo`03oj0Pl?oooooooooo03Sooooo00?o0?l0ooooooooool05?ooool00onP8?3ooooo
ooooo`1>ooooo`;oo`001_ooool00ol0o`3oooooooooo`0gooooo`00:?ooool00ol0003ooooooooo
o`10ooooo`03oj0Pl?oooooooooo01Gooooo00?o0?l0ooooooooool0<Oooool00ol00?oooooooooo
o`0Booooo`03oj0Pl?oooooooooo03Sooooo00?o0?l0ooooooooool04_ooool00onP8?3ooooooooo
o`1>ooooo`03ool00?oooooooooo00Gooooo00?o0?l0ooooooooool0>?ooool002Sooooo00?o0000
ooooooooool0?oooool00onP8?3oooooooooo`0Eooooo`03o`3o0?oooooooooo037ooooo00?o003o
ooooooooool05?ooool00onP8?3oooooooooo`0hooooo`03o`3o0?oooooooooo013ooooo00?oX23`
ooooooooool0COooool2ool000Oooooo00?o0?l0ooooooooool0>Oooool002Sooooo00?o0000oooo
ooooool0?oooool00onP8?3oooooooooo`0Eooooo`03o`3o0?oooooooooo033ooooo00?o003ooooo
ooooool05Oooool00onP8?3oooooooooo`0hooooo`03o`3o0?oooooooooo013ooooo00?oX23`oooo
ooooool0C?ooool00ooo003oooooooooo`06ooooo`03o`3o0?oooooooooo03[ooooo000Xooooo`03
o`000?oooooooooo03oooooo00?oX23`ooooooooool05?ooool00ol0o`3oooooooooo`0`ooooo`03
o`00oooooooooooo01Oooooo00?oX23`ooooooooool0>?ooool00ol0o`3oooooooooo`0>ooooo`03
oj0Pl?oooooooooo04_ooooo0_oo0008ooooo`03o`3o0?oooooooooo03_ooooo000Xooooo`03o`00
0?oooooooooo03kooooo00?oX23`ooooooooool05Oooool00ol0o`3oooooooooo`0`ooooo`03o`00
oooooooooooo01Oooooo00?oX23`ooooooooool0>Oooool00ol0o`3oooooooooo`0<ooooo`03oj0P
l?oooooooooo04[ooooo0_oo0009ooooo`03o`3o0?oooooooooo03cooooo000Xooooo`03o`000?oo
oooooooo03kooooo00?oX23`ooooooooool05?ooool00ol0o`3oooooooooo`0`ooooo`03o`00oooo
oooooooo01Wooooo00?oX23`ooooooooool0>Oooool00ol0o`3oooooooooo`0:ooooo`03oj0Pl?oo
oooooooo04[ooooo00?oo`00ooooooooool01oooool2o`3o03oooooo000Xooooo`03o`000?oooooo
oooo03kooooo00?oX23`ooooooooool05?ooool00ol0o`3oooooooooo`0_ooooo`03o`00oooooooo
oooo01[ooooo00?oX23`ooooooooool0>_ooool00ol0o`3oooooooooo`09ooooo`03oj0Pl?oooooo
oooo04Sooooo0_oo0009ooooo`03o`3o0?oooooooooo03oooooo000Xooooo`;o0000?_ooool00onP
8?3oooooooooo`0Dooooo`03o`3o0?oooooooooo02oooooo00?o003oooooooooool07?ooool00onP
8?3oooooooooo`0jooooo`03o`3o0?oooooooooo00Oooooo00?oX23`ooooooooool0B?ooool00ooo
003oooooooooo`08ooooo`03o`3o0?oooooooooo043ooooo000Xooooo`03o`000?oooooooooo03go
oooo00?oX23`ooooooooool05?ooool00ol0o`3oooooooooo`0_ooooo`03o`00oooooooooooo01co
oooo00?oX23`ooooooooool0>_ooool00ol0o`3oooooooooo`06ooooo`03oj0Pl?oooooooooo04Oo
oooo0_oo000:ooooo`03o`3o0?oooooooooo047ooooo000Xooooo`03o`000?oooooooooo03gooooo
00?oX23`ooooooooool04oooool00ol0o`3oooooooooo`0_ooooo`03o`00oooooooooooo01kooooo
00?oX23`ooooooooool0>_ooool00ol0o`3oooooooooo`04ooooo`03oj0Pl?oooooooooo04Kooooo
0_oo000;ooooo`03o`3o0?oooooooooo04;ooooo000Xooooo`03o`000?oooooooooo03cooooo00?o
X23`ooooooooool05?ooool00ol0o`3oooooooooo`0^ooooo`03o`00oooooooooooo023ooooo00?o
X23`ooooooooool0>_ooool00ol0o`3oooooooooo`03ooooo`03oj0Pl?oooooooooo04Cooooo0_oo
000<ooooo`03o`3o0?oooooooooo04?ooooo000Xooooo`03o`000?oooooooooo03cooooo00?oX23`
ooooooooool04oooool00ol0o`3oooooooooo`0^ooooo`03o`00oooooooooooo027ooooo00?oX23`
ooooooooool0>oooool01Ol0o`3oooooooooooooooooX23`04Gooooo0_oo000=ooooo`03o`3o0?oo
oooooooo04Cooooo000Xooooo`03o`000?oooooooooo03cooooo00?oX23`ooooooooool04oooool0
0ol0o`3oooooooooo`0^ooooo`03o`00oooooooooooo02;ooooo00?oX23`ooooooooool0>oooool0
0ol0o`3ooooooj0Pl015ooooo`03ool00?oooooooooo00cooooo00?o0?l0ooooooooool0AOooool0
02Sooooo00?o0000ooooooooool0>oooool00onP8?3oooooooooo`0Cooooo`03o`3o0?oooooooooo
02kooooo00?o003oooooooooool08oooool00onP8?3oooooooooo`0looooo`03o`3o0?nP8?3ooooo
04;ooooo0_oo000>ooooo`03o`3o0?oooooooooo04Kooooo000Xooooo`;o0000??ooool00onP8?3o
ooooooooo`0Cooooo`03o`3o0?oooooooooo02gooooo00?o003oooooooooool09Oooool00onP8?3o
ooooooooo`0kooooo`03oj0Pl?l0o`3ooooo043ooooo0_oo000?ooooo`03o`3o0?oooooooooo04Oo
oooo000Xooooo`03o`000?oooooooooo03_ooooo00?oX23`ooooooooool04_ooool00ol0o`3ooooo
ooooo`0]ooooo`03o`00oooooooooooo02Oooooo00?oX23`ooooooooool0>Oooool01?nP8?3ooooo
ooooool0o`0nooooo`;oo`004?ooool00ol0o`3oooooooooo`18ooooo`00:?ooool00ol0003ooooo
ooooo`0jooooo`03oj0Pl?oooooooooo01?ooooo00?o0?l0ooooooooool0;Oooool00ol00?oooooo
ooooo`0Xooooo`03oj0Pl?oooooooooo03Oooooo00?oX23`ooooooooool00_ooool00ol0o`3ooooo
ooooo`0iooooo`;oo`004Oooool00ol0o`3oooooooooo`19ooooo`00:?ooool00ol0003ooooooooo
o`0jooooo`03oj0Pl?oooooooooo01?ooooo00?o0?l0ooooooooool0;?ooool00ol00?oooooooooo
o`0Zooooo`03oj0Pl?oooooooooo03Kooooo00?oX23`ooooooooool00oooool00ol0o`3ooooooooo
o`0gooooo`03ool00?oooooooooo013ooooo00?o0?l0ooooooooool0B_ooool002Sooooo00?o0000
ooooooooool0>_ooool00onP8?3oooooooooo`0Booooo`03o`3o0?oooooooooo02cooooo00?o003o
ooooooooool0:oooool00onP8?3oooooooooo`0eooooo`03oj0Pl?oooooooooo00Gooooo00?o0?l0
ooooooooool0=?ooool2ool001;ooooo00?o0?l0ooooooooool0Boooool000_ooooo00Co^[Zjoa0@
4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`Ko00001_ooool00ol0003oooooooooo`0i
ooooo`03oj0Pl?oooooooooo01?ooooo00?o0?l0ooooooooool0:oooool00ol00?ooooooooooo`0]
ooooo`03oj0Pl?oooooooooo03?ooooo00?oX23`ooooooooool01oooool00ol0o`3oooooooooo`0b
ooooo`03ool00?oooooooooo013ooooo0_l0o`1>ooooo`002_ooool01_o<c<co<S8bonk^k_o^k^ko
8B4QojVYZ@Gooooo0ol00004ooooo`03oiRHV?l0003oc<c<00;ooooo00?o410@ooooooooool01?oo
ool00ol0003oooooooooo`0iooooo`03oj0Pl?oooooooooo01;ooooo00?o0?l0ooooooooool0;?oo
ool00ol00?ooooooooooo`0^ooooo`03oj0Pl?oooooooooo037ooooo00?oX23`ooooooooool02Ooo
ool00ol0o`3oooooooooo`0_ooooo`;oo`004_ooool00ol0o`3oooooooooo`1>ooooo`002_ooool0
1_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED01Oooool00onHV9So0000
olc<c008ooooo`03o`000?oooooooooo03Wooooo00?oX23`ooooooooool04_ooool00ol0o`3ooooo
ooooo`0[ooooo`03o`00oooooooooooo033ooooo00?oX23`ooooooooool0<?ooool00onP8?3ooooo
ooooo`0:ooooo`;o0?l0;Oooool2ool001;ooooo0_l0o`1Aooooo`002_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo00?oZJVYoa0@4?o<c<`01oooool3o`0003Sooooo00?o
X23`ooooooooool04_ooool00ol0o`3oooooooooo`0[ooooo`03o`00oooooooooooo03;ooooo00?o
X23`ooooooooool0;_ooool00onP8?3oooooooooo`0=ooooo`03o`3o0?oooooooooo02Wooooo00?o
o`00ooooooooool04Oooool00ol0o`3oooooooooo`1Aooooo`002_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00gooooo00?oc<c<oa0@4?o<c<`01_ooool00ol0003oooooooooo`0h
ooooo`03oj0Pl?oooooooooo01;ooooo00?o0?l0ooooooooool0:_ooool00ol00?ooooooooooo`0d
ooooo`03oj0Pl?oooooooooo02cooooo00?oX23`ooooooooool03oooool00ol0o`3oooooooooo`0V
ooooo`;oo`004oooool00ol0o`3oooooooooo`1Booooo`002_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00kooooo00?oZJVYoc8b<_ooool01Oooool00ol0003oooooooooo`0hoooo
o`03oj0Pl?oooooooooo017ooooo00?o0?l0ooooooooool0:oooool00ol00?ooooooooooo`0eoooo
o`03oj0Pl?oooooooooo02[ooooo00?oX23`ooooooooool04Oooool2o`3o02Gooooo00?oo`00oooo
ooooool04Oooool2o`3o05Gooooo000:ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A44Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Oooooo00?oX23`ooooooooool04_ooool0
0ol0o`3oooooooooo`0Zooooo`03o`00oooooooooooo03Oooooo00?oX23`ooooooooool0:?ooool0
0onP8?3oooooooooo`0Dooooo`03o`3o0?oooooooooo023ooooo0_oo000Cooooo`03o`3o0?oooooo
oooo05Gooooo000:ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool01_l0003oQhN7onk^
k_ooooooMgMgoc8b<PKooooo00?o0000ooooooooool0=oooool00onP8?3oooooooooo`0Aooooo`03
o`3o0?oooooooooo02[ooooo00?o003oooooooooool0>Oooool00onP8?3oooooooooo`0Vooooo`03
oj0Pl?oooooooooo01Kooooo00?o0?l0ooooooooool07Oooool2ool001?ooooo0_l0o`1Hooooo`00
2oooool01?nj^[[o410@oa0@4?o<c<`=ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1_ooool0
0ol0003oooooooooo`0gooooo`03oj0Pl?oooooooooo017ooooo00?o0?l0ooooooooool0:Oooool0
0ol00?ooooooooooo`0kooooo`03oj0Pl?oooooooooo02Cooooo00?oX23`ooooooooool06?ooool0
0ol0o`3oooooooooo`0Kooooo`03ool00?oooooooooo01;ooooo00?o0?l0ooooooooool0F?ooool0
02Sooooo00?o0000ooooooooool0=_ooool00onP8?3oooooooooo`0Booooo`03o`3o0?oooooooooo
02Wooooo00?o003oooooooooool0??ooool00onP8?3oooooooooo`0Qooooo`;oX23`7?ooool00ol0
o`3oooooooooo`0Hooooo`;oo`005?ooool00ol0o`3oooooooooo`1Iooooo`00:?ooool2o`0003Oo
oooo00?oX23`ooooooooool04Oooool00ol0o`3oooooooooo`0Yooooo`03o`00oooooooooooo03ko
oooo00?oX23`ooooooooool07_ooool2oj0Pl1oooooo00?o0?l0ooooooooool05Oooool2ool001Co
oooo0_l0o`1Looooo`00:?ooool00ol0003oooooooooo`0fooooo`03oj0Pl?oooooooooo017ooooo
00?o0?l0ooooooooool0:?ooool00ol00?ooooooooooo`10ooooo`03oj0Pl?oooooooooo01cooooo
00?oX23`ooooooooool08?ooool2o`3o01?ooooo0_oo000Dooooo`;o0?l0G_ooool002Sooooo00?o
0000ooooooooool0=Oooool00onP8?3oooooooooo`0Aooooo`03o`3o0?oooooooooo02Wooooo00?o
003oooooooooool0@Oooool00onP8?3oooooooooo`0Jooooo`03oj0Pl?oooooooooo02?ooooo0_l0
o`0@ooooo`03ool00?oooooooooo01?ooooo00?o0?l0ooooooooool0G_ooool002Sooooo00?o0000
ooooooooool0=Oooool00onP8?3oooooooooo`0Aooooo`03o`3o0?oooooooooo02Sooooo00?o003o
ooooooooool0@oooool2oj0Pl1Wooooo00?oX23`ooooooooool09_ooool2o`3o00cooooo0_oo000D
ooooo`;o0?l0HOooool002Sooooo00?o0000ooooooooool0=Oooool00onP8?3oooooooooo`0@oooo
o`03o`3o0?oooooooooo02Sooooo00?o003oooooooooool0A_ooool00onP8?3oooooooooo`0Doooo
o`;oX23`:oooool2o`3o00Sooooo0_oo000Dooooo`;o0?l0Hoooool002Sooooo00?o0000oooooooo
ool0=?ooool00onP8?3oooooooooo`0Aooooo`03o`3o0?oooooooooo02Oooooo00?o003ooooooooo
ool0B?ooool00onP8?3oooooooooo`0Aooooo`;oX23`;oooool3o`3o00Cooooo00?oo`00oooooooo
ool04Oooool3o`3o06Gooooo000Xooooo`03o`000?oooooooooo03Cooooo00?oX23`ooooooooool0
4?ooool00ol0o`3oooooooooo`0Xooooo`03o`00oooooooooooo04Wooooo1?nP8?0=ooooo`;oX23`
=?ooool4o`3o01;ooooo0_l0o`1Xooooo`00:?ooool00ol0003oooooooooo`0dooooo`03oj0Pl?oo
oooooooo013ooooo00?o0?l0ooooooooool09oooool00ol00?ooooooooooo`1>ooooo`;oX23`1ooo
ool4oj0Pl3Oooooo00?oo`00ooooooooool00ol0o`0:ooooo`Go0?l0J_ooool002Sooooo0_l0000d
ooooo`03oj0Pl?oooooooooo013ooooo00?o0?l0ooooooooool09oooool00ol00?ooooooooooo`1A
ooooo`OoX23`>Oooool2ool000Kooooo2_l0o`1_ooooo`00:?ooool00ol0003oooooooooo`0coooo
o`03oj0Pl?oooooooooo013ooooo00?o0?l0ooooooooool09_ooool00ol00?ooooooooooo`2@oooo
o`;oo`00POooool002Sooooo00?o0000ooooooooool0<oooool00onP8?3oooooooooo`0@ooooo`03
o`3o0?oooooooooo02Kooooo00?o003oooooooooool0Soooool00ooo003oooooooooo`21ooooo`00
:?ooool00ol0003oooooooooo`0booooo`03oj0Pl?oooooooooo013ooooo00?o0?l0ooooooooool0
9_ooool00ol00?ooooooooooo`2>ooooo`;oo`00Q?ooool002Sooooo00?o0000ooooooooool0<_oo
ool00onP8?3oooooooooo`0@ooooo`03o`3o0?oooooooooo02Gooooo00?o003oooooooooool0S_oo
ool00ooo003oooooooooo`24ooooo`00:?ooool00ol0003oooooooooo`0booooo`03oj0Pl?oooooo
oooo00oooooo00?o0?l0ooooooooool09_ooool00ol00?ooooooooooo`2<ooooo`;oo`00Qoooool0
02Sooooo00?o0000ooooooooool0<Oooool00onP8?3oooooooooo`0@ooooo`03o`3o0?oooooooooo
02Gooooo00?o003oooooooooool0Roooool2ool008Wooooo000Xooooo`;o0000<_ooool00onP8?3o
ooooooooo`0?ooooo`03o`3o0?oooooooooo02Gooooo00?o003oooooooooool0Roooool00ooo003o
ooooooooo`29ooooo`00:?ooool00ol0003oooooooooo`0aooooo`03oj0Pl?oooooooooo00oooooo
00?o0?l0ooooooooool09?ooool00ol00?ooooooooooo`2:ooooo`;oo`00S?ooool002Sooooo00?o
0000ooooooooool0<?ooool00onP8?3oooooooooo`0?ooooo`03o`3o0?oooooooooo02Gooooo00?o
003oooooooooool0R?ooool2ool008kooooo000Xooooo`03o`000?oooooooooo033ooooo00?oX23`
ooooooooool03oooool00ol0o`3oooooooooo`0Tooooo`03o`00oooooooooooo08Oooooo0_oo002@
ooooo`00:?ooool00ol0003oooooooooo`0`ooooo`03oj0Pl?oooooooooo00oooooo00?o0?l0oooo
ooooool08oooool00ol00?ooooooooooo`27ooooo`03ool00?oooooooooo093ooooo000;ooooo`04
okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED01oooool2o`000003oa0@4?oooooooooo
00Cooooo00?o0000ooooooooool0;oooool00onP8?3oooooooooo`0?ooooo`03o`3o0?oooooooooo
02Cooooo00?o003oooooooooool0QOooool2ool009?ooooo000:ooooo`06olc<c?lb<S;ok^k^onk^
k_lQ8B7oZJVY1Oooool3o`0000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0_
ooooo`03oj0Pl?oooooooooo00oooooo00?o0?l0ooooooooool08oooool00ol00?ooooooooooo`24
ooooo`;oo`00UOooool000[ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0
003oEEEE00Cooooo1_l00006ooooo`03o`000?oooooooooo02kooooo00?oX23`ooooooooool03ooo
ool00ol0o`3oooooooooo`0Sooooo`03o`00oooooooooooo08Cooooo00?oo`00ooooooooool0UOoo
ool000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05ofIVI_nYZJWo
ooooooooool000001oooool3o`0002kooooo00?oX23`ooooooooool03oooool00ol0o`3ooooooooo
o`0Sooooo`03o`00oooooooooooo08;ooooo0_oo002Hooooo`002_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00[ooooo00Gok^k^ob4Q8Oo^k^koooooo`000007ooooo`03o`000?oo
oooooooo02kooooo00?oX23`ooooooooool03_ooool00ol0o`3oooooooooo`0Sooooo`03o`00oooo
oooooooo08;ooooo00?oo`00ooooooooool0V?ooool000[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0;ooooo`04ojVYZOmVIVKoooooo`0000Oooooo00?o0000ooooooooool0;Ooo
ool00onP8?3oooooooooo`0?ooooo`03o`3o0?oooooooooo02;ooooo00?o003oooooooooool0POoo
ool2ool009_ooooo000:ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A43_ooool00om4A4Coc<c<
o`000007ooooo`03o`000?oooooooooo02gooooo00?oX23`ooooooooool03_ooool00ol0o`3ooooo
ooooo`0Rooooo`03o`00oooooooooooo083ooooo0_oo002Mooooo`002_ooool01_o<c<co<S8bonk^
k_o^k^ko<S8bolc<c0kooooo00?ogMgModA4A?l000001oooool00ol0003oooooooooo`0]ooooo`03
oj0Pl?oooooooooo00kooooo00?o0?l0ooooooooool08_ooool00ol00?ooooooooooo`1oooooo`03
ool00?oooooooooo09gooooo000;ooooo`04okZj^_l@413o410@olc<c13ooooo00?oQhN7o`000?oo
ool01_ooool00ol0003oooooooooo`0/ooooo`03oj0Pl?oooooooooo00kooooo00?o0?l0oooooooo
ool08_ooool00ol00?ooooooooooo`1nooooo`;oo`00X?ooool002Sooooo00?o0000ooooooooool0
;?ooool00onP8?3oooooooooo`0>ooooo`03o`3o0?oooooooooo027ooooo00?o003oooooooooool0
O_ooool00ooo003oooooooooo`2Pooooo`00:?ooool2o`0002gooooo00?oX23`ooooooooool03_oo
ool00ol0o`3oooooooooo`0Qooooo`03o`00oooooooooooo07cooooo0_oo002Sooooo`00:?ooool0
0ol0003oooooooooo`0[ooooo`03oj0Pl?oooooooooo00kooooo00?o0?l0ooooooooool08Oooool0
0ol00?ooooooooooo`1kooooo`;oo`00YOooool002Sooooo00?o0000ooooooooool0:oooool00onP
8?3oooooooooo`0>ooooo`03o`3o0?oooooooooo023ooooo00?o003oooooooooool0Noooool00ooo
003oooooooooo`2Uooooo`00:?ooool00ol0003oooooooooo`0[ooooo`03oj0Pl?oooooooooo00go
oooo00?o0?l0ooooooooool08?ooool00ol00?ooooooooooo`1jooooo`;oo`00Z?ooool002Sooooo
00?o0000ooooooooool0:_ooool00onP8?3oooooooooo`0>ooooo`03o`3o0?oooooooooo023ooooo
00?o003oooooooooool0N?ooool2ool00:[ooooo000Xooooo`03o`000?oooooooooo02[ooooo00?o
X23`ooooooooool03Oooool00ol0o`3oooooooooo`0Pooooo`03o`00oooooooooooo07Oooooo0_oo
002/ooooo`00:?ooool00ol0003oooooooooo`0Zooooo`03oj0Pl?oooooooooo00gooooo00?o0?l0
ooooooooool07oooool00ol00?ooooooooooo`1gooooo`03ool00?oooooooooo0:cooooo000Xoooo
o`03o`000?oooooooooo02Wooooo00?oX23`ooooooooool03Oooool00ol0o`3oooooooooo`0Ooooo
o`03o`00oooooooooooo07Kooooo0_oo002_ooooo`00:?ooool2o`0002[ooooo00?oX23`oooooooo
ool03Oooool00ol0o`3oooooooooo`0Oooooo`03o`00oooooooooooo07Cooooo0_oo002aooooo`00
:?ooool00ol0003oooooooooo`0Yooooo`03oj0Pl?oooooooooo00cooooo00?o0?l0ooooooooool0
7oooool00ol00?ooooooooooo`1dooooo`03ool00?oooooooooo0;7ooooo000Xooooo`03o`000?oo
oooooooo02Sooooo00?oX23`ooooooooool03Oooool00ol0o`3oooooooooo`0Nooooo`03o`00oooo
oooooooo07?ooooo0_oo002dooooo`00:?ooool00ol0003oooooooooo`0Xooooo`03oj0Pl?oooooo
oooo00gooooo00?o0?l0ooooooooool07Oooool00ol00?ooooooooooo`1cooooo`03ool00?oooooo
oooo0;Cooooo000Xooooo`03o`000?oooooooooo02Oooooo00?oX23`ooooooooool03Oooool00ol0
o`3oooooooooo`0Nooooo`03o`00oooooooooooo077ooooo0_oo002gooooo`00:?ooool00ol0003o
ooooooooo`0Wooooo`03oj0Pl?oooooooooo00gooooo00?o0?l0ooooooooool07Oooool00ol00?oo
ooooooooo`1`ooooo`;oo`00^Oooool002Sooooo00?o0000ooooooooool09oooool00onP8?3ooooo
ooooo`0<ooooo`03o`3o0?oooooooooo01gooooo00?o003oooooooooool0L?ooool00ooo003ooooo
ooooo`2iooooo`00:?ooool2o`0002Oooooo00?oX23`ooooooooool03Oooool00ol0o`3ooooooooo
o`0Looooo`03o`00oooooooooooo06oooooo0_oo002looooo`00:?ooool00ol0003oooooooooo`0V
ooooo`03oj0Pl?oooooooooo00cooooo00?o0?l0ooooooooool07Oooool00ol00?ooooooooooo`1^
ooooo`03ool00?oooooooooo0;cooooo000Xooooo`03o`000?oooooooooo02Kooooo00?oX23`oooo
ooooool03?ooool00ol0o`3oooooooooo`0Looooo`03o`00oooooooooooo06gooooo0_oo002ooooo
o`00:?ooool00ol0003oooooooooo`0Uooooo`03oj0Pl?oooooooooo00cooooo00?o0?l0oooooooo
ool07?ooool00ol00?ooooooooooo`1/ooooo`;oo`00`Oooool002Sooooo00?o0000ooooooooool0
9Oooool00onP8?3oooooooooo`0<ooooo`03o`3o0?oooooooooo01_ooooo00?o003oooooooooool0
Joooool2ool00<?ooooo000;ooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEEo`000?mEEED0
1?ooool01_o^k^koA4A4o`000?l0003oEEEEonk^kPKooooo00?o0000ooooooooool09?ooool00onP
8?3oooooooooo`0<ooooo`03o`3o0?oooooooooo01cooooo00?o003oooooooooool0JOooool2ool0
0<Gooooo000:ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00KoEEEE
ogMgMoooooooooooogMgMomEEED6ooooo`03o`000?oooooooooo02Cooooo00?oX23`ooooooooool0
3?ooool00ol0o`3oooooooooo`0Kooooo`03o`00oooooooooooo06Wooooo00?oo`00ooooooooool0
aOooool000[ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Co
oooo00?o410@ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Co
oooo00?oX23`ooooooooool02oooool00ol0o`3oooooooooo`0Kooooo`03o`00oooooooooooo06So
oooo0_oo0038ooooo`002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo
00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`04ooooo`?o00008oooool00onP8?3ooooo
ooooo`0<ooooo`03o`3o0?oooooooooo01[ooooo00?o003oooooooooool0Ioooool2ool00<[ooooo
000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_l0003oEEEEonk^
k_ooooooMgMgoeEEE@Kooooo00?o0000ooooooooool08oooool00onP8?3oooooooooo`0;ooooo`03
o`3o0?oooooooooo01[ooooo00?o003oooooooooool0I_ooool2ool00<cooooo000:ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_lQ8B7oIVIVo`000?l0003oEEEEonk^
kPKooooo00?o0000ooooooooool08oooool00onP8?3oooooooooo`0;ooooo`03o`3o0?oooooooooo
01[ooooo00?o003oooooooooool0I?ooool2ool00<kooooo000:ooooo`06odA4A?nYZJWooooooooo
oonYZJWoA4A43?ooool00on7QhOoIVIVooooo`09ooooo`03o`000?oooooooooo02;ooooo00?oX23`
ooooooooool02oooool00ol0o`3oooooooooo`0Jooooo`03o`00oooooooooooo06?ooooo0_oo003@
ooooo`002_ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0gooooo00?o<S8bofIVI_oMgMd02?oo
ool00ol0003oooooooooo`0Rooooo`03oj0Pl?oooooooooo00_ooooo00?o0?l0ooooooooool06Ooo
ool00ol00?ooooooooooo`1Sooooo`03ool00?oooooooooo0=3ooooo000;ooooo`04okZj^_l@413o
410@olc<c0oooooo00CoMgMgoa0@4?l0003o8B4Q1_ooool00ol0003oooooooooo`0Rooooo`03oj0P
l?oooooooooo00[ooooo00?o0?l0ooooooooool06Oooool00ol00?ooooooooooo`1Rooooo`;oo`00
doooool002Sooooo00?o0000ooooooooool08Oooool00onP8?3oooooooooo`0:ooooo`03o`3o0?oo
oooooooo01[ooooo00?o003oooooooooool0H?ooool2ool00=Gooooo000Xooooo`;o00008_ooool0
0onP8?3oooooooooo`0:ooooo`03o`3o0?oooooooooo01Wooooo00?o003oooooooooool0Goooool2
ool00=Oooooo000Xooooo`03o`000?oooooooooo023ooooo00?oX23`ooooooooool02_ooool00ol0
o`3oooooooooo`0Iooooo`03o`00oooooooooooo05oooooo00?oo`00ooooooooool0eoooool002So
oooo00?o0000ooooooooool08?ooool00onP8?3oooooooooo`0:ooooo`03o`3o0?oooooooooo01So
oooo00?o003oooooooooool0G_ooool2ool00=[ooooo000Xooooo`03o`000?oooooooooo023ooooo
00?oX23`ooooooooool02Oooool00ol0o`3oooooooooo`0Hooooo`03o`00oooooooooooo05gooooo
0_oo003Looooo`00:?ooool00ol0003oooooooooo`0Oooooo`03oj0Pl?oooooooooo00[ooooo00?o
0?l0ooooooooool06?ooool00ol00?ooooooooooo`1Kooooo`;oo`00g_ooool002Sooooo00?o0000
ooooooooool07oooool00onP8?3oooooooooo`09ooooo`03o`3o0?oooooooooo01Sooooo00?o003o
ooooooooool0F_ooool2ool00>3ooooo000Xooooo`03o`000?oooooooooo01oooooo00?oX23`oooo
ooooool02Oooool00ol0o`3oooooooooo`0Gooooo`03o`00oooooooooooo05Wooooo0_oo003Roooo
o`00:?ooool00ol0003oooooooooo`0Nooooo`03oj0Pl?oooooooooo00Wooooo00?o0?l0oooooooo
ool05oooool00ol00?ooooooooooo`1Hooooo`;oo`00i?ooool002Sooooo0_l0000Oooooo`03oj0P
l?oooooooooo00Wooooo00?o0?l0ooooooooool05oooool00ol00?ooooooooooo`1Fooooo`;oo`00
i_ooool002Sooooo00?o0000ooooooooool07Oooool00onP8?3oooooooooo`09ooooo`03o`3o0?oo
oooooooo01Oooooo00?o003oooooooooool0EOooool2ool00>Sooooo000Xooooo`03o`000?oooooo
oooo01gooooo00?oX23`ooooooooool02Oooool00ol0o`3oooooooooo`0Fooooo`03o`00oooooooo
oooo05Cooooo0_oo003Zooooo`00:?ooool00ol0003oooooooooo`0Mooooo`03oj0Pl?oooooooooo
00Sooooo00?o0?l0ooooooooool05_ooool00ol00?ooooooooooo`1Cooooo`;oo`00k?ooool002So
oooo00?o0000ooooooooool07?ooool00onP8?3oooooooooo`09ooooo`03o`3o0?oooooooooo01Go
oooo00?o003oooooooooool0D_ooool2ool00>kooooo000Xooooo`03o`000?oooooooooo01cooooo
00?oX23`ooooooooool02?ooool00ol0o`3oooooooooo`0Eooooo`03o`00oooooooooooo057ooooo
0_oo003`ooooo`00:?ooool00ol0003oooooooooo`0Looooo`03oj0Pl?oooooooooo00Oooooo00?o
0?l0ooooooooool05Oooool00ol00?ooooooooooo`1@ooooo`;oo`00l_ooool002Sooooo0_l0000L
ooooo`03oj0Pl?oooooooooo00Sooooo00?o0?l0ooooooooool05?ooool00ol00?ooooooooooo`1?
ooooo`;oo`00m?ooool002Sooooo00?o0000ooooooooool06oooool00onP8?3oooooooooo`07oooo
o`03o`3o0?oooooooooo01Gooooo00?o003oooooooooool0COooool2ool00?Kooooo000Xooooo`03
o`000?oooooooooo01_ooooo00?oX23`ooooooooool01_ooool00ol0o`3oooooooooo`0Eooooo`03
o`00oooooooooooo04cooooo0_oo003hooooo`00:?ooool00ol0003oooooooooo`0Jooooo`03oj0P
l?oooooooooo00Oooooo00?o0?l0ooooooooool05?ooool00ol00?ooooooooooo`1:ooooo`?oo`00
n_ooool002Sooooo00?o0000ooooooooool06_ooool00onP8?3oooooooooo`06ooooo`03o`3o0?oo
oooooooo01Cooooo00?o003oooooooooool0BOooool2ool00?gooooo000;ooooo`04okZj^_l@413o
0000ogMgM`Kooooo00?oEEEEo`000?mEEED01?ooool01_o^k^koA4A4o`000?l0003oA4A4onk^kPKo
oooo00?o0000ooooooooool06Oooool00onP8?3oooooooooo`07ooooo`03o`3o0?oooooooooo01?o
oooo00?o003oooooooooool0B?ooool2ool00?oooooo000:ooooo`06olc<c?lb<S;ok^k^onk^k_lQ
8B7oZJVY1Oooool3o`0000Cooooo00Ko<S8bogMgMoo^k^kok^k^ogMgMolb<S86ooooo`03o`000?oo
oooooooo01Wooooo00?oX23`ooooooooool01_ooool00ol0o`3oooooooooo`0Cooooo`03o`00oooo
oooooooo04Kooooo0ooo003oooooo`;ooooo000:ooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b
1Oooool00omEEEGo0000oeEEE@04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Hooooo`03oj0Pl?oooooooooo00Kooooo00?o0?l0ooooooooool0
4oooool00ol00?ooooooooooo`15ooooo`;oo`00ooooool5ooooo`002_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00[ooooo00Ko<S8bogMgMoo^k^kok^k^ogMgMolb<S86ooooo`?o
00006?ooool00onP8?3oooooooooo`06ooooo`03o`3o0?oooooooooo017ooooo0_l00?m6ooooo`;o
o`00ooooool7ooooo`002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo
00?ogMgMo`000?l000000_l000000ooMgMgoooooooooo`04ooooo`03o`000?oooooooooo01Oooooo
00?oX23`ooooooooool01_ooool00ol0o`3oooooooooo`0Aooooo`03o`00oooooooooooo04?ooooo
0ooo003oooooo`Wooooo000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<PKooooo00?o0000ooooooooool05oooool00onP8?3o
ooooooooo`05ooooo`03o`3o0?oooooooooo017ooooo00?o003oooooooooool0@_ooool2ool00?oo
oooo3?ooool000[ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03oj0Pl?oooooooooo
00Kooooo00?o0?l0ooooooooool04?ooool00ol00?ooooooooooo`10ooooo`?oo`00ooooool>oooo
o`002_ooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00Ko<S8bofIVI_o^k^kok^k^ofIV
I_lb<S86ooooo`03o`000?oooooooooo01Gooooo00?oX23`ooooooooool01_ooool00ol0o`3ooooo
ooooo`0@ooooo`03o`00oooooooooooo03oooooo0_oo003ooooooa7ooooo000;ooooo`04okZj^_l@
413o410@olc<c0gooooo00Kok^k^odA4A?l0003o0000odA4A?o^k^h6ooooo`03o`000?oooooooooo
01Gooooo00?oX23`ooooooooool01Oooool00ol0o`3oooooooooo`0@ooooo`03o`00oooooooooooo
03gooooo0ooo003ooooooa?ooooo000Xooooo`03o`000?oooooooooo01Cooooo00?oX23`oooooooo
ool01_ooool00ol0o`3oooooooooo`0>ooooo`;o003o?_ooool2ool00?oooooo5_ooool002Sooooo
0_l0000Eooooo`03oj0Pl?oooooooooo00Gooooo00?o0?l0ooooooooool03_ooool00ol00?oooooo
ooooo`0kooooo`?oo`00oooooolHooooo`00:?ooool00ol0003oooooooooo`0Cooooo`03oj0Pl?oo
oooooooo00Kooooo00?o0?l0ooooooooool03Oooool00ol00?ooooooooooo`0iooooo`?oo`00oooo
oolKooooo`00:?ooool00ol0003oooooooooo`0Cooooo`03oj0Pl?oooooooooo00Gooooo00?o0?l0
ooooooooool03Oooool00ol00?ooooooooooo`0hooooo`;oo`00oooooolNooooo`00:?ooool00ol0
003oooooooooo`0Booooo`03oj0Pl?oooooooooo00Gooooo00?o0?l0ooooooooool03Oooool00ol0
0?ooooooooooo`0fooooo`?oo`00oooooolPooooo`00:?ooool00ol0003oooooooooo`0Booooo`03
oj0Pl?oooooooooo00Gooooo00?o0?l0ooooooooool03?ooool00ol00?ooooooooooo`0eooooo`;o
o`00oooooolSooooo`00:?ooool00ol0003oooooooooo`0Aooooo`03oj0Pl?oooooooooo00Gooooo
00?o0?l0ooooooooool02oooool2o`00ocGooooo0ooo003oooooobGooooo000Xooooo`03o`000?oo
oooooooo017ooooo00?oX23`ooooooooool01?ooool00ol0o`3oooooooooo`0;ooooo`03o`00oooo
oooooooo03;ooooo0ooo003oooooobSooooo000Xooooo`03o`000?oooooooooo013ooooo00?oX23`
ooooooooool01?ooool00ol0o`3oooooooooo`0:ooooo`;o003o<_ooool3ool00?oooooo:oooool0
02Sooooo0_l0000Aooooo`03oj0Pl?oooooooooo00?ooooo00?o0?l0ooooooooool02_ooool00ol0
0?ooooooooooo`0_ooooo`?oo`00ooooool^ooooo`00:?ooool00ol0003oooooooooo`0?ooooo`03
oj0Pl?oooooooooo00?ooooo00?o0?l0ooooooooool02_ooool00ol00?ooooooooooo`0/ooooo`Co
o`00oooooolaooooo`00:?ooool00ol0003oooooooooo`0?ooooo`03oj0Pl?oooooooooo00;ooooo
00?o0?l0ooooooooool02Oooool2o`00ob_ooooo1?oo003oooooocGooooo000Xooooo`03o`000?oo
oooooooo00kooooo00?oX23`ooooooooool00_ooool00ol0o`3oooooooooo`09ooooo`03o`00oooo
oooooooo02Sooooo0ooo003oooooocWooooo000Xooooo`03o`000?oooooooooo00gooooo00?oX23`
ooooooooool00_ooool00ol0o`3oooooooooo`08ooooo`;o003o9oooool4ool00?oooooo??ooool0
02Sooooo00?o0000ooooooooool03?ooool00onP8?3oooooooooo`02ooooo`03o`3o0?oooooooooo
00Sooooo00?o003oooooooooool08oooool4ool00?oooooo@?ooool002Sooooo00?o0000oooooooo
ool02oooool00onP8?3oooooooooo`02ooooo`03o`3o0?oooooooooo00Sooooo00?o003ooooooooo
ool08Oooool3ool00?ooooooA?ooool002Sooooo0_l0000;ooooo`04oj0Pl?ooooooooooooooo`;o
0?l02Oooool2o`00ob7ooooo0ooo003oooooodOooooo000Xooooo`03o`000?oooooooooo00Wooooo
00GoX23`ooooooooooooooooo`3o0008ooooo`?o003o8?ooool3ool00?ooooooB_ooool002Sooooo
00?o0000ooooooooool02?ooool01OnP8?3ooooooooooooooooo0?l000Kooooo0ol00?lMooooo`Ko
o`00oooooom=ooooo`00:?ooool00ol0003oooooooooo`07ooooo`03oj0Pl?oooooooooo00;o0?l0
1Oooool2o`00oaWooooo1ooo003ooooooe?ooooo000Xooooo`03o`000?oooooooooo00Kooooo00Co
X23`ooooool0o`3o0?l01_ooool00ol00?ooooooooooo`0Booooo`Ooo`00oooooomJooooo`007Ooo
ool4o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00onP8?3o0?l0o`3o
0005ooooo`?o003o3_ooool7ool00?ooooooHOooool001oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`;oX23`00Co0?l0oooooooooooooooo1?l00?l9ooooo`Soo`00oooo
oomXooooo`007oooool00ol0003oooooooooo`06ooooo`03o`000?ooooooX23`00?oX23`0_l0o`04
o`00o`goo`00oooooom`ooooo`007oooool00ol0003oooooooooo`06ooooo`?oX23`0_l00?l7ool0
0?ooooooOOooool001oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooohKo
oooo000Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooon6ooooo`007ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooQ_ooool001gooooo00?o0000
odA4A?l000002?ooool00ol0003oooooooooo`3oooooohKooooo000Mooooo`03olc<c?mEEEGo0000
00Sooooo00?o0000ooooooooool0oooooon6ooooo`00oooooonaooooo`00oooooonaooooo`00oooo
oonaooooo`00oooooonaooooo`00oooooonaooooo`00oooooonaooooo`00T?ooool00ol0003ooooo
ooooo`3ooooooakooooo001kooooo`03okZj^_lb<S;ooooo00?ooooo00Go8B4Qo`000?l0003oEEEE
onk^kP0:ooooo`03o`000?oooooooooo033ooooo00?o<S8bokZj^_ooool0j_ooool0073ooooo0_l0
0009ooooo`03oa0@4?nj^[[ooooo00Kooooo00?oEEEEoc8b<_ooool00oooool2o`0000Cooooo0_l0
0004ooooo`;o000000?oooooo`000?l00000:?ooool00onj^[[o8B4Qooooo`3Zooooo`00Koooool0
1?l0003oooooooooool00007ooooo`03okZj^_lb<S;ooooo00Oooooo00?ok^k^o`000?ooool00_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00005oooool00olQ8B7ogMgMooooo`0@ooooo`03oc8b<_nj^[[ooooo0>Wooooo001Vooooo`06ojVY
ZOlQ8B7o0000o`000?m4A4Coc<c<0oooool01?l0003oooooooooool00007ooooo`03oeEEEOnHV9So
oooo00Sooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Oooooo00Co
0000oooooooooooo00003Oooool6o`0000Cooooo00?oQhN7ofIVI_ooool01Oooool01onYZJWo410@
o`000?lQ8B7oV9RHoa0@4?l000001?ooool00onHV9SoEEEEooooo`0=ooooo`03oa0@4?l0003o0000
00;o000000?o410@ooooooooool00_ooool01On7QhOo410@o`000?l@413oQhN700?ooooo1_l0000<
ooooo`03oa0@4?l0003o000000;ooooo0_l000000ol@413oooooooooo`09ooooo`Co000000?o410@
ooooooooool02oooool01_o<c<co8B4Qo`000?l0003oEEEEokZj^P?ooooo00GoQhN7oa0@4?l0003o
410@ohN7Q`0?ooooo`;o000000?o410@ooooooooool0LOooool006Kooooo00Ko0000ohN7Qooooooo
ooooogMgMom4A4@3ooooo`04o`000?ooooooooooo`0000Oooooo00?o410@olc<c?ooool02?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool0000?ooooo`03o`000?oooooooooo00Gooooo00?ok^k^o`000?ooool01Oooool01_l0003o^[Zj
oooooooMgMgoMgMgo`0000Gooooo00?ogMgMoa0@4?ooool03oooool00ol0003oooooooooo`04oooo
o`07ohN7QolQ8B7oc<c<ooooooo<c<co8B4QohN7Q`04ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooooooool6o`0000Gooooo00?o0000ooooooooool0
3Oooool01_l@413oQhN7ooooooo^k^koZJVYob4Q8@;ooooo00OoQhN7ob4Q8Oo<c<coooooolc<c?lQ
8B7oQhN700oooooo00?o0000ooooooooool0L_ooool006Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`08ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`06ooooo`Go0000
3oooool00ol0003oooooooooo`06ooooo`03oeEEEOnHV9Sooooo00Cooooo00Ko410@ohN7Qoo^k^ko
ooooomgMgOl00006ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol@
413oc<c<ooooo`02ooooo`03olc<c?l@413ooooo00?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`05ooooo`03oa0@4?o<c<cooooo00;ooooo00?oc<c<oa0@4?ooool02_ooool6o`00
07?ooooo001Vooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`06ooooo`03okZj^_lb<S;o
oooo00Cooooo00Koc<c<odA4A?l0003o0000oa0@4?l00006ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool01OmVIVKoZJVYoooooooooooo000007Cooooo001[ooooo`03o`00
0?oooooooooo00;ooooo0_l00008ooooo`03oa0@4?o<c<cooooo00Sooooo00?o0000ooooooooool0
0_ooool2o`0001gooooo00?o0000omgMgOooool01oooool00ol@413oc<c<ooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?ogMgMoa0@4?ooool03oooool00ol0003oooooooooo`04ooooo`03oa0@
4?nj^[[ooooo00;ooooo00?o^[Zjoa0@4?ooool00oooool00ol0003ogMgMooooo`0>ooooo`03o`00
0?o^k^kooooo00;ooooo00Co0000oooooooooooooooo1_l00005ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01Oooool00ol@413o^[Zjooooo`02ooooo`03okZj^_l@413ooooo00[o
oooo00Gok^k^ob4Q8Oo^k^koooooo`00001dooooo`00Joooool00ol0003oooooooooo`0<ooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool08Oooool2o`000003oiRHV?oooooooooo00Go
oooo00?oQhN7oeEEEOooool01oooool00on7QhOo<S8booooo`04ooooo`03oiRHV?mEEEGooooo00oo
oooo00?o0000ooooooooool01?ooool01on7QhOo8B4Qolc<c?ooooooc<c<ob4Q8On7QhL01?ooool2
o`000003oiRHV?oooooooooo00cooooo00Ko0000odA4A?oMgMgoooooogMgMol@410>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01Oooool01on7QhOo8B4Qolc<c?ooooooc<c<ob4Q
8On7QhL03?ooool01?nYZJWoIVIVooooool0001dooooo`00Joooool00ol0003oooooooooo`0<oooo
o`03okZj^_l@413ooooo00Cooooo00?o410@o`000?l000000_l0000Qooooo`05oa0@4?l0003o0000
okZj^_m4A4@00_l000000olQ8B7oooooooooo`02ooooo`03onk^k_l@413ok^k^00Cooooo00GoA4A4
o`000?l0003o410@olc<c005ooooo`03ob4Q8Onj^[[ooooo00gooooo00?o410@o`000?l000000ol0
0004ooooo`05ohN7Qol@413o0000oa0@4?n7QhL00oooool01Ol@413o0000o`000?nj^[[oA4A400;o
000000?o8B4Qooooooooool02?ooool01ol@413o0000ogMgMol@413o0000ob4Q8Oo<c<`03_ooool0
0ol0003oooooooooo`0;ooooo`03oa0@4?l0003o000000?o000000?o410@ooooooooool00_ooool0
1On7QhOo410@o`000?l@413oQhN700kooooo00?oA4A4olc<c?l00000M?ooool006_ooooo00?o0000
ooooooooool03Oooool00olb<S;o^[Zjooooo`0fooooo`03oeEEEOnHV9Sooooo00cooooo00?o^[Zj
ob4Q8Oooool04?ooool00ol0003oooooooooo`0booooo`03o`000?m4A4Co000000oooooo00?o0000
ooooooooool06Oooool00ooMgMgoA4A4o`00001dooooo`00J?ooool00ol@413o0000o`000002o`00
0003oa0@4?oooooooooo00_ooooo00?o^[Zjoc8b<_ooool01oooool00ol0003oooooooooo`0/oooo
o`03olc<c?lb<S;ooooo00cooooo00?o<S8bokZj^_ooool04?ooool00ol@413o^[Zjooooo`0boooo
o`03olc<c?mEEEGo000000oooooo00?o0000ooooooooool06_ooool00on7QhOo0000ooooo`1coooo
o`00QOooool00ol@413oooooooooo`1>ooooo`04okZj^_l@413o0000oa0@44?ooooo00?o410@oooo
ooooool0T?ooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool0
0?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool0
0?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool0
0?oooooo/Oooool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.11898, -0.502319, \
0.00441044, 0.0100104}}]
}, Open  ]],

Cell[TextData[{
  "Eigenfunctions for other values of ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " can be plotted in the same way. This is left as an exercise for the \
reader. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "The General Solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]]
}], "Subsubsection"],

Cell[TextData[{
  "\tThe full solution for \[Phi]  within the cylinder is obtained by summing \
over all radial eigenmodes, and all ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  "-eigenmodes:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell["\[Phi]"], \((r, \[Theta], z)\)}], 
          "=", \(\[Sum]\+\(n = 1\)\%\[Infinity]\(\[Sum]\+\(m = \(-\[Infinity]\
\)\)\%\[Infinity]\( A\_\(m\ n\)\) \(\(J\_m\)(
                  j\_\(m, \ n\)\ r/
                      a)\)\ \(\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\)\
\) sinh\ \((j\_\(m, \ n\)\ z/a)\)\)\)}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(3.2.53)"],

Cell[TextData[{
  "where the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_\(m\ n\)\)]],
  " remain to be determined. This solution matches the homogenous boundary \
conditions on ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ". To satisfy the inhomogeneous boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`z = L\)]],
  ", namely  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta], L) = \(\[Phi]\_C\)(
          r, \[Theta])\)]],
  ",",
  "  we choose the ",
  Cell[BoxData[
      \(TraditionalForm\`A\_\(m\ n\)\)]],
  "'s so that "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell[TextData[Cell[BoxData[
                \(TraditionalForm\`\[Phi]\_C\)]]]], \((r, \[Theta])\)}], 
          "=", \(\[Sum]\+\(n = 1\)\%\[Infinity]\(\[Sum]\+\(m = \(-\[Infinity]\
\)\)\%\[Infinity]\( A\_\(m\ n\)\) \(\(J\_m\)(
                  j\_\(m, \ n\)\ r/
                      a)\)\ \(\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\)\
\) sinh\ \(\((j\_\(m, \ n\)\ L/a)\)\(.\)\)\)\)}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "Putting aside the radial dependence for a moment, note that this is a \
Fourier series in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  ". Application of the orthogonality relation for the Fourier modes ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\)\)]],
  ", Eq. ",
  ButtonBox["(2.1.29)",
    ButtonData:>{"Chapter2.nb", "(2.1.29)"},
    ButtonStyle->"Hyperlink"],
  ",",
  " allows us to extract to extract a single value of ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " from the sum in the usual way:"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(n = 1\)\%\[Infinity] A\_\(m\ n\)\ sinh\ \
\((j\_\(m, \ n\)\ L/a)\) \(\(J\_m\)(j\_\(m, \ n\)\ r/a)\)\), "=", " ", 
          RowBox[{\(1\/\(2  \[Pi]\)\), 
            RowBox[{\(\[Integral]\_0\%\(2  \[Pi]\)\), 
              
              RowBox[{\(\[DifferentialD]\[Theta]\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ m\ \[Theta]\)\), Cell[TextData[Cell[BoxData[
                    \(TraditionalForm\`\[Phi]\_C\)]]]], \((r, \
\[Theta])\)}]}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(3.2.54)"],

Cell[TextData[{
  "However, this is not enough to determine ",
  Cell[BoxData[
      \(TraditionalForm\`A\_\(m\ n\)\)]],
  ". It would be nice if there were some equivalent orthogonality relation \
that we could apply to the Bessel functions. Amazingly, such an orthogonality \
relation exists:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%a\(\( J\_m\)(\(j\_\(m, n\&_\)\) 
                r/a)\) \(\(J\_m\)(\(j\_\(m, n\)\) r/a)\) 
            r \[DifferentialD]r = \(\[Delta]\_\(n\ n\&_\)\) \(a\^2\/2\) \(\(J\
\_\(m + 1\)\%2\)(j\_\(m, n\))\)\)]],
  ","
}], "NE2",
  CellTags->{"i:90", "(3.2.55)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_\(n\ n\&_\)\)]],
  " is a Kronecker delta function. Thus, for ",
  Cell[BoxData[
      \(TraditionalForm\`n \[NotEqual] \ n\&_\)]],
  ", the different radial eigenmodes ",
  "are orthogonal",
  " with respect to the radial integral ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%a r \[DifferentialD]r\)]],
  ".  This result can be checked using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      Integrate[
          BesselJ[m, j\_\(m\ , n\)\ r/a] 
            BesselJ[m\ , j\_\(m\ , n\&_\)\ r/a]\ r, {r, 0, a}] /. \ 
        BesselJ[m, j\_\(m\ , n_\)]\  \[Rule] \ \ 0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.32"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[
      Integrate[
          BesselJ[m, j\_\(m\ , n\)\ r/a]^2\ \ r, {r, 0, a}] - \(a\^2\/2\) 
          BesselJ[m + 1, j\_\(m\ , n\)]^2, \ 
      BesselJ[m, j\_\(m\ , n\)]\  == \ 0\ ]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.33"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tWe can use Eq. ",
  ButtonBox["(3.2.55)",
    ButtonData:>"(3.2.55)",
    ButtonStyle->"Hyperlink"],
  "  to extract a single term from the sum over ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " in Eq. ",
  ButtonBox["(3.2.55)",
    ButtonData:>"(3.2.55)",
    ButtonStyle->"Hyperlink"],
  ". Multiplying both sides of the equation by ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_m\)(\(j\_\(m, n\&_\)\) r/a)\)]],
  " and applying the integral ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%a r \[DifferentialD]r\)]],
  ", we find"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(n = 1\)\%\[Infinity] A\_\(m\ n\)\ sinh\ \((j\_\(m\
\ n\)\ L/a)\) \(\[Integral]\_0\%a 
                  r \[DifferentialD]r\ \(\(J\_m\)(\(j\_\(m, n\&_\)\) 
                      r/a)\)\ \(\(J\_m\)(j\_\(m\ n\)\ r/a)\)\)\), "=", " ", 
          RowBox[{\(1\/\(2  \[Pi]\)\), 
            RowBox[{\(\[Integral]\_0\%a\), 
              RowBox[{
              "r", \(\[DifferentialD]r\), 
                " ", \(\(J\_m\)(\(j\_\(m, n\&_\)\) r/a)\), 
                RowBox[{\(\[Integral]\_0\%\(2  \[Pi]\)\), 
                  
                  RowBox[{\(\[DifferentialD]\[Theta]\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ m\ \[Theta]\)\), Cell[TextData[Cell[BoxData[
                        \(TraditionalForm\`\[Phi]\_C\)]]]], \(\((r, \[Theta])\
\)\(.\)\)}]}]}]}]}]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "Substituting for the radial integral on the ",
  "left-hand",
  " side using Eq. ",
  ButtonBox["(3.2.55)",
    ButtonData:>"(3.2.55)",
    ButtonStyle->"Hyperlink"],
  ", we see that only the term with ",
  Cell[BoxData[
      \(TraditionalForm\`n = n\&_\)]],
  " contributes, leaving us with the equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(A\_\(\(m\)\(\ \)\(n\&_\)\(\ \)\)\ sinh\ \((j\_\(m\ n\&_\)\ \
L/a)\)\ \(a\^2\/2\) \(\(J\_\(m + 1\)\%2\)(j\_\(m, n\&_\))\)\), "=", 
          RowBox[{\(1\/\(2  \[Pi]\)\), 
            RowBox[{\(\[Integral]\_0\%a\), 
              RowBox[{
              "r", \(\[DifferentialD]r\), 
                " ", \(\(J\_m\)(\(j\_\(m, n\&_\)\) r/a)\), 
                RowBox[{\(\[Integral]\_0\%\(2  \[Pi]\)\), 
                  
                  RowBox[{\(\[DifferentialD]\[Theta]\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ m\ \[Theta]\)\), Cell[TextData[Cell[BoxData[
                        \(TraditionalForm\`\[Phi]\_C\)]]]], \((r, \
\[Theta])\)}]}]}]}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(3.2.56)"],

Cell[TextData[{
  "This equation provides us with the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_\(m\ n\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tIt is really quite surprising that the Bessel functions form an \
orthogonal set. It appears that every time we solve an eigenvalue problem, we \
obtain an orthogonal set of eigenmodes. The reasons for this will be \
discussed in Chapter ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:107"],

Cell[TextData[{
  "\tA trivial extension of the same method used here could also be used to \
determine the form of the potential due to the nonzero potential at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta], 0) = \(\[Phi]\_B\)(
          r, \[Theta])\)]],
  ". This part of the problem is left as an exercise. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example", "Subsubsection"],

Cell[TextData[{
  "\tSay the potential on the top of the cylinder is fixed at",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell[""], \(\(\[Phi]\_C\)(r, \[Theta])\)}], "=", \(V\_o\)}],
         TraditionalForm]]],
  ", and the other sides of the cylinder are grounded. Then according to Eq. \
",
  ButtonBox["(3.2.56)",
    ButtonData:>"(3.2.56)",
    ButtonStyle->"Hyperlink"],
  ", only the ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  " Fourier coefficients  ",
  Cell[BoxData[
      \(TraditionalForm\`A\_\(0\ n\)\)]],
  " are nonzero, and the potential within the cylinder is given by Eq. ",
  ButtonBox["(3.2.56)",
    ButtonData:>"(3.2.56)",
    ButtonStyle->"Hyperlink"],
  " by a sum over the zeros of a single Bessel function, ",
  Cell[BoxData[
      \(TraditionalForm\`J\_o\)]],
  ":  "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell["\[Phi]"], \((r, \[Theta], z)\)}], 
          "=", \(\[Sum]\+\(n = 1\)\%\[Infinity]\( 
                  A\_\(\(\ \)\(0\ n\)\)\) \(\(J\_0\)(
                j\_\(0\ n\)\ r/a)\)\ sinh\ \((j\_\(0\ n\)\ z/a)\)\)}], 
        TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(3.2.57)"],

Cell[TextData[{
  "As expected from the symmetry of the problem, the potential is \
cylindrically symmetric. The Fourier coefficients are given by Eq. ",
  ButtonBox["(3.2.56)",
    ButtonData:>"(3.2.56)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`A\_\(0\ n\) = \(V\_o\/\(\(a\^2\/2\) \(\(J\_1\%2\)(
                  j\_\(0, n\))\) 
                sinh\ \((j\_\(0, \ n\)\ L/
                      a)\)\)\) \(\[Integral]\_0\%a\( \(r\) \
\(\[DifferentialD]r\)\(\ \)\(\(J\_0\)(\(j\_\(0, n\)\) r/a)\)\(\ \)\)\)\)]]
}], "Text"],

Cell[TextData[{
  "The required integral can be performed analytically using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A[n_]\  = \ 
      V0\/\(a\^2\ BesselJ[1, \ j[n]]^2\ \ \ Sinh[\ j[n]\ L/a]\)\ Integrate[
          r\ BesselJ[0, j[n]\ r/a], {r, 0, a}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.34"],

Cell[BoxData[
    \(\(V0\ Csch[\(L\ j[n]\)\/a]\)\/\(BesselJ[1, j[n]]\ j[n]\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here we have introduced the notation ",
  StyleBox["j[n] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "for the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th zero of the Bessel function ",
  Cell[BoxData[
      \(TraditionalForm\`J\_o\)]],
  ". For the first 20 zeros, this function can be defined in the following \
way:"
}], "Text"],

Cell[BoxData[{
    \(\(<< NumericalMath`;\)\), "\n", 
    \(\ j0\  = \ BesselJZeros[0, 20]; \ 
    j[n_]\  := \ \ j0[\([n]\)]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.35"],

Cell[TextData[{
  "Now the potential can be evaluated numerically, keeping the first 20 terms \
in the sum in Eq. ",
  ButtonBox["(3.2.57)",
    ButtonData:>"(3.2.57)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\[Phi][r_, z_]\  = \ 
        Sum[A[n]\ BesselJ[0, j[n]\ r/a]\ Sinh[j[n]\ z/a], {n, 1, 
            20}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.36"],

Cell[TextData[{
  "\tThis potential is plotted in Cell ",
  ButtonBox["3.37",
    ButtonData:>"Cell 3.37",
    ButtonStyle->"Hyperlink"],
  " as a contour plot, taking ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(V\_o\), "=", 
            RowBox[{"1", " ", 
              StyleBox["V",
                FontSlant->"Plain"]}]}], ",", " ", Cell[TextData[{
            "and ",
            Cell[BoxData[
                \(TraditionalForm\`L/a\  = \ 2\)]]
          }]]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(L = 2\ a; \ a = 1; \ V0\  = \ 1;\), "\n", 
    \(\(ContourPlot[\[Phi][r, z], {r, 0, a}, {z, 0, L}, 
        AspectRatio \[Rule] 2, PlotPoints \[Rule] 40, 
        FrameLabel \[Rule] {"\<r\>", "\<z\>"}, 
        PlotLabel \[Rule] "\<\[Phi](r,z) in a cylinder \n with grounded sides\
\>"];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.37"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0384615 0.961538 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.21154 -0.0125 -9 -9 ]
[.21154 -0.0125 9 0 ]
[.40385 -0.0125 -9 -9 ]
[.40385 -0.0125 9 0 ]
[.59615 -0.0125 -9 -9 ]
[.59615 -0.0125 9 0 ]
[.78846 -0.0125 -9 -9 ]
[.78846 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .03846 -6 -4.5 ]
[-0.0125 .03846 0 4.5 ]
[-0.0125 .51923 -18 -4.5 ]
[-0.0125 .51923 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[-0.0125 1.48077 -18 -4.5 ]
[-0.0125 1.48077 0 4.5 ]
[-0.0125 1.96154 -6 -4.5 ]
[-0.0125 1.96154 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 1 -30 -5 ]
[-0.01875 1 -18 5 ]
[ 0 2 .125 0 ]
[ 1 0 .125 0 ]
[.5 2.0125 -65 0 ]
[.5 2.0125 65 24.5 ]
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(0.2)] .21154 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(0.4)] .40385 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(0.6)] .59615 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(0.8)] .78846 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.5 0 m
.5 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03846 m
.00625 .03846 L
s
[(0)] -0.0125 .03846 1 0 Mshowa
0 .51923 m
.00625 .51923 L
s
[(0.5)] -0.0125 .51923 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
0 1.48077 m
.00625 1.48077 L
s
[(1.5)] -0.0125 1.48077 1 0 Mshowa
0 1.96154 m
.00625 1.96154 L
s
[(2)] -0.0125 1.96154 1 0 Mshowa
.125 Mabswid
0 .13462 m
.00375 .13462 L
s
0 .23077 m
.00375 .23077 L
s
0 .32692 m
.00375 .32692 L
s
0 .42308 m
.00375 .42308 L
s
0 .61538 m
.00375 .61538 L
s
0 .71154 m
.00375 .71154 L
s
0 .80769 m
.00375 .80769 L
s
0 .90385 m
.00375 .90385 L
s
0 1.09615 m
.00375 1.09615 L
s
0 1.19231 m
.00375 1.19231 L
s
0 1.28846 m
.00375 1.28846 L
s
0 1.38462 m
.00375 1.38462 L
s
0 1.57692 m
.00375 1.57692 L
s
0 1.67308 m
.00375 1.67308 L
s
0 1.76923 m
.00375 1.76923 L
s
0 1.86538 m
.00375 1.86538 L
s
.25 Mabswid
0 0 m
0 2 L
s
gsave
-0.01875 1 -90 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01923 1.99375 m
.01923 2 L
s
.21154 1.99375 m
.21154 2 L
s
.40385 1.99375 m
.40385 2 L
s
.59615 1.99375 m
.59615 2 L
s
.78846 1.99375 m
.78846 2 L
s
.98077 1.99375 m
.98077 2 L
s
.125 Mabswid
.06731 1.99625 m
.06731 2 L
s
.11538 1.99625 m
.11538 2 L
s
.16346 1.99625 m
.16346 2 L
s
.25962 1.99625 m
.25962 2 L
s
.30769 1.99625 m
.30769 2 L
s
.35577 1.99625 m
.35577 2 L
s
.45192 1.99625 m
.45192 2 L
s
.5 1.99625 m
.5 2 L
s
.54808 1.99625 m
.54808 2 L
s
.64423 1.99625 m
.64423 2 L
s
.69231 1.99625 m
.69231 2 L
s
.74038 1.99625 m
.74038 2 L
s
.83654 1.99625 m
.83654 2 L
s
.88462 1.99625 m
.88462 2 L
s
.93269 1.99625 m
.93269 2 L
s
.25 Mabswid
0 2 m
1 2 L
s
.99375 .03846 m
1 .03846 L
s
.99375 .51923 m
1 .51923 L
s
.99375 1 m
1 1 L
s
.99375 1.48077 m
1 1.48077 L
s
.99375 1.96154 m
1 1.96154 L
s
.125 Mabswid
.99625 .13462 m
1 .13462 L
s
.99625 .23077 m
1 .23077 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .42308 m
1 .42308 L
s
.99625 .61538 m
1 .61538 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .80769 m
1 .80769 L
s
.99625 .90385 m
1 .90385 L
s
.99625 1.09615 m
1 1.09615 L
s
.99625 1.19231 m
1 1.19231 L
s
.99625 1.28846 m
1 1.28846 L
s
.99625 1.38462 m
1 1.38462 L
s
.99625 1.57692 m
1 1.57692 L
s
.99625 1.67308 m
1 1.67308 L
s
.99625 1.76923 m
1 1.76923 L
s
.99625 1.86538 m
1 1.86538 L
s
.25 Mabswid
1 0 m
1 2 L
s
gsave
.5 2.0125 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(in) show
123.000 13.000 moveto
(a) show
135.000 13.000 moveto
(cylinder) show
69.125 25.500 moveto
(with) show
99.125 25.500 moveto
(grounded) show
153.125 25.500 moveto
(sides) show
183.125 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
.01923 1.96154 m
.98077 1.96154 L
.98077 .03846 L
.01923 .03846 L
F
.5 Mabswid
.1 g
.01923 .79478 m
.04389 .79513 L
.06854 .79617 L
.0932 .79791 L
.11785 .80035 L
.1425 .8035 L
.16716 .80737 L
.19181 .81197 L
.21647 .81732 L
.24112 .82344 L
.25568 .82742 L
.26578 .83035 L
.29043 .83807 L
.31509 .84664 L
.33974 .85607 L
.3644 .86641 L
.38702 .87673 L
.38905 .8777 L
.41371 .88999 L
.43836 .90333 L
.46302 .91777 L
.47631 .92604 L
.48767 .93339 L
.51233 .95028 L
.53698 .9685 L
.54579 .97535 L
.56164 .98817 L
.58629 1.00942 L
.60287 1.02465 L
.61095 1.03238 L
.6356 1.05723 L
.65117 1.07396 L
.66026 1.08416 L
.68491 1.11342 L
.69278 1.12327 L
.70957 1.14531 L
.72905 1.17258 L
.73422 1.18018 L
.75888 1.21852 L
.76094 1.22189 L
.78353 1.26093 L
.78914 1.2712 L
.80819 1.30817 L
.8142 1.32051 L
.83284 1.36129 L
.83653 1.36982 L
.8565 1.41913 L
.8575 1.42175 L
.87438 1.46844 L
.88215 1.49168 L
.89044 1.51775 L
.90488 1.56706 L
.9068 1.57406 L
.9179 1.61637 L
.92964 1.66568 L
.93146 1.67383 L
.94027 1.71499 L
.94992 1.7643 L
.95611 1.79929 L
.95868 1.81361 L
.96661 1.86292 L
.97237 1.91223 L
.97909 1.96154 L
.01923 1.96154 L
F
0 g
.01923 .79478 m
.04389 .79513 L
.06854 .79617 L
.0932 .79791 L
.11785 .80035 L
.1425 .8035 L
.16716 .80737 L
.19181 .81197 L
.21647 .81732 L
.24112 .82344 L
.25568 .82742 L
.26578 .83035 L
.29043 .83807 L
.31509 .84664 L
.33974 .85607 L
.3644 .86641 L
.38702 .87673 L
.38905 .8777 L
.41371 .88999 L
.43836 .90333 L
.46302 .91777 L
.47631 .92604 L
.48767 .93339 L
.51233 .95028 L
.53698 .9685 L
.54579 .97535 L
.56164 .98817 L
.58629 1.00942 L
.60287 1.02465 L
.61095 1.03238 L
.6356 1.05723 L
.65117 1.07396 L
.66026 1.08416 L
.68491 1.11342 L
.69278 1.12327 L
.70957 1.14531 L
.72905 1.17258 L
.73422 1.18018 L
.75888 1.21852 L
.76094 1.22189 L
.78353 1.26093 L
.78914 1.2712 L
.80819 1.30817 L
.8142 1.32051 L
.83284 1.36129 L
.83653 1.36982 L
.8565 1.41913 L
.8575 1.42175 L
.87438 1.46844 L
.88215 1.49168 L
Mistroke
.89044 1.51775 L
.90488 1.56706 L
.9068 1.57406 L
.9179 1.61637 L
.92964 1.66568 L
.93146 1.67383 L
.94027 1.71499 L
.94992 1.7643 L
.95611 1.79929 L
.95868 1.81361 L
.96661 1.86292 L
.97237 1.91223 L
.97909 1.96154 L
Mfstroke
.2 g
.01923 1.14166 m
.04389 1.14198 L
.06854 1.14297 L
.0932 1.14461 L
.11785 1.14691 L
.1425 1.14989 L
.16716 1.15353 L
.19181 1.15786 L
.21647 1.16289 L
.24112 1.16862 L
.25661 1.17258 L
.26578 1.17508 L
.29043 1.18228 L
.31509 1.19024 L
.33974 1.19898 L
.3644 1.20853 L
.38905 1.21891 L
.39578 1.22189 L
.41371 1.23017 L
.43836 1.24234 L
.46302 1.25545 L
.48767 1.26954 L
.49047 1.2712 L
.51233 1.2847 L
.53698 1.30095 L
.56164 1.31837 L
.56456 1.32051 L
.58629 1.33706 L
.61095 1.35708 L
.62582 1.36982 L
.6356 1.37853 L
.66026 1.40155 L
.67799 1.41913 L
.68491 1.42626 L
.70957 1.45284 L
.72326 1.46844 L
.73422 1.48145 L
.75888 1.51232 L
.76303 1.51775 L
.78353 1.54576 L
.79829 1.56706 L
.80819 1.58203 L
.82976 1.61637 L
.83284 1.62152 L
.8575 1.66473 L
.85801 1.66568 L
.88215 1.71227 L
.88351 1.71499 L
.9066 1.7643 L
.9068 1.76477 L
.92763 1.81361 L
.93146 1.82367 L
.94685 1.86292 L
.95611 1.89421 L
.96304 1.91223 L
.97669 1.96154 L
.01923 1.96154 L
F
0 g
.01923 1.14166 m
.04389 1.14198 L
.06854 1.14297 L
.0932 1.14461 L
.11785 1.14691 L
.1425 1.14989 L
.16716 1.15353 L
.19181 1.15786 L
.21647 1.16289 L
.24112 1.16862 L
.25661 1.17258 L
.26578 1.17508 L
.29043 1.18228 L
.31509 1.19024 L
.33974 1.19898 L
.3644 1.20853 L
.38905 1.21891 L
.39578 1.22189 L
.41371 1.23017 L
.43836 1.24234 L
.46302 1.25545 L
.48767 1.26954 L
.49047 1.2712 L
.51233 1.2847 L
.53698 1.30095 L
.56164 1.31837 L
.56456 1.32051 L
.58629 1.33706 L
.61095 1.35708 L
.62582 1.36982 L
.6356 1.37853 L
.66026 1.40155 L
.67799 1.41913 L
.68491 1.42626 L
.70957 1.45284 L
.72326 1.46844 L
.73422 1.48145 L
.75888 1.51232 L
.76303 1.51775 L
.78353 1.54576 L
.79829 1.56706 L
.80819 1.58203 L
.82976 1.61637 L
.83284 1.62152 L
.8575 1.66473 L
.85801 1.66568 L
.88215 1.71227 L
.88351 1.71499 L
.9066 1.7643 L
.9068 1.76477 L
Mistroke
.92763 1.81361 L
.93146 1.82367 L
.94685 1.86292 L
.95611 1.89421 L
.96304 1.91223 L
.97669 1.96154 L
Mfstroke
.3 g
.01923 1.33747 m
.04389 1.33776 L
.06854 1.33864 L
.0932 1.34009 L
.11785 1.34214 L
.1425 1.34477 L
.16716 1.348 L
.19181 1.35183 L
.21647 1.35627 L
.24112 1.36133 L
.26578 1.36701 L
.27705 1.36982 L
.29043 1.37334 L
.31509 1.38034 L
.33974 1.388 L
.3644 1.39635 L
.38905 1.40541 L
.41371 1.41519 L
.42315 1.41913 L
.43836 1.42573 L
.46302 1.43706 L
.48767 1.4492 L
.51233 1.46218 L
.52368 1.46844 L
.53698 1.47605 L
.56164 1.49085 L
.58629 1.5066 L
.60286 1.51775 L
.61095 1.52338 L
.6356 1.54127 L
.66026 1.56027 L
.66872 1.56706 L
.68491 1.58051 L
.70957 1.60205 L
.72517 1.61637 L
.73422 1.62498 L
.75888 1.64943 L
.77449 1.66568 L
.78353 1.67547 L
.80819 1.70329 L
.81816 1.71499 L
.83284 1.73303 L
.85721 1.7643 L
.8575 1.76468 L
.88215 1.79901 L
.89245 1.81361 L
.9068 1.83595 L
.92451 1.86292 L
.93146 1.87707 L
.95358 1.91223 L
.95611 1.91645 L
.97413 1.96154 L
.01923 1.96154 L
F
0 g
.01923 1.33747 m
.04389 1.33776 L
.06854 1.33864 L
.0932 1.34009 L
.11785 1.34214 L
.1425 1.34477 L
.16716 1.348 L
.19181 1.35183 L
.21647 1.35627 L
.24112 1.36133 L
.26578 1.36701 L
.27705 1.36982 L
.29043 1.37334 L
.31509 1.38034 L
.33974 1.388 L
.3644 1.39635 L
.38905 1.40541 L
.41371 1.41519 L
.42315 1.41913 L
.43836 1.42573 L
.46302 1.43706 L
.48767 1.4492 L
.51233 1.46218 L
.52368 1.46844 L
.53698 1.47605 L
.56164 1.49085 L
.58629 1.5066 L
.60286 1.51775 L
.61095 1.52338 L
.6356 1.54127 L
.66026 1.56027 L
.66872 1.56706 L
.68491 1.58051 L
.70957 1.60205 L
.72517 1.61637 L
.73422 1.62498 L
.75888 1.64943 L
.77449 1.66568 L
.78353 1.67547 L
.80819 1.70329 L
.81816 1.71499 L
.83284 1.73303 L
.85721 1.7643 L
.8575 1.76468 L
.88215 1.79901 L
.89245 1.81361 L
.9068 1.83595 L
.92451 1.86292 L
.93146 1.87707 L
.95358 1.91223 L
Mistroke
.95611 1.91645 L
.97413 1.96154 L
Mfstroke
.4 g
.01923 1.47938 m
.04389 1.47963 L
.06854 1.48038 L
.0932 1.48162 L
.11785 1.48337 L
.1425 1.48561 L
.16716 1.48837 L
.19181 1.49163 L
.21647 1.49542 L
.24112 1.49972 L
.26578 1.50455 L
.29043 1.50992 L
.31509 1.51584 L
.3226 1.51775 L
.33974 1.52232 L
.3644 1.52937 L
.38905 1.537 L
.41371 1.54522 L
.43836 1.55405 L
.46302 1.5635 L
.47189 1.56706 L
.48767 1.57361 L
.51233 1.58439 L
.53698 1.59586 L
.56164 1.60803 L
.57775 1.61637 L
.58629 1.62094 L
.61095 1.63463 L
.6356 1.64912 L
.66026 1.66442 L
.66223 1.66568 L
.68491 1.68064 L
.70957 1.69776 L
.73317 1.71499 L
.73422 1.71578 L
.75888 1.73492 L
.78353 1.75504 L
.79451 1.7643 L
.80819 1.77632 L
.83284 1.79883 L
.84858 1.81361 L
.8575 1.82249 L
.88215 1.84782 L
.89697 1.86292 L
.9068 1.87434 L
.93146 1.90268 L
.9413 1.91223 L
.95611 1.92955 L
.97137 1.96154 L
.01923 1.96154 L
F
0 g
.01923 1.47938 m
.04389 1.47963 L
.06854 1.48038 L
.0932 1.48162 L
.11785 1.48337 L
.1425 1.48561 L
.16716 1.48837 L
.19181 1.49163 L
.21647 1.49542 L
.24112 1.49972 L
.26578 1.50455 L
.29043 1.50992 L
.31509 1.51584 L
.3226 1.51775 L
.33974 1.52232 L
.3644 1.52937 L
.38905 1.537 L
.41371 1.54522 L
.43836 1.55405 L
.46302 1.5635 L
.47189 1.56706 L
.48767 1.57361 L
.51233 1.58439 L
.53698 1.59586 L
.56164 1.60803 L
.57775 1.61637 L
.58629 1.62094 L
.61095 1.63463 L
.6356 1.64912 L
.66026 1.66442 L
.66223 1.66568 L
.68491 1.68064 L
.70957 1.69776 L
.73317 1.71499 L
.73422 1.71578 L
.75888 1.73492 L
.78353 1.75504 L
.79451 1.7643 L
.80819 1.77632 L
.83284 1.79883 L
.84858 1.81361 L
.8575 1.82249 L
.88215 1.84782 L
.89697 1.86292 L
.9068 1.87434 L
.93146 1.90268 L
.9413 1.91223 L
.95611 1.92955 L
.97137 1.96154 L
s
.5 g
.01923 1.59439 m
.04389 1.59459 L
.06854 1.5952 L
.0932 1.59622 L
.11785 1.59764 L
.1425 1.59947 L
.16716 1.60172 L
.19181 1.60438 L
.21647 1.60746 L
.24112 1.61097 L
.26578 1.6149 L
.2744 1.61637 L
.29043 1.61926 L
.31509 1.62406 L
.33974 1.62931 L
.3644 1.63501 L
.38905 1.64116 L
.41371 1.64778 L
.43836 1.65488 L
.46302 1.66246 L
.47303 1.66568 L
.48767 1.67054 L
.51233 1.67914 L
.53698 1.68826 L
.56164 1.6979 L
.58629 1.70809 L
.60227 1.71499 L
.61095 1.71885 L
.6356 1.7302 L
.66026 1.74215 L
.68491 1.7547 L
.70301 1.7643 L
.70957 1.76788 L
.73422 1.78178 L
.75888 1.79633 L
.78353 1.81152 L
.78686 1.81361 L
.80819 1.82758 L
.83284 1.84442 L
.8575 1.86173 L
.85919 1.86292 L
.88215 1.88014 L
.9068 1.90025 L
.9242 1.91223 L
.93146 1.91753 L
.95611 1.93938 L
.96838 1.96154 L
.01923 1.96154 L
F
0 g
.01923 1.59439 m
.04389 1.59459 L
.06854 1.5952 L
.0932 1.59622 L
.11785 1.59764 L
.1425 1.59947 L
.16716 1.60172 L
.19181 1.60438 L
.21647 1.60746 L
.24112 1.61097 L
.26578 1.6149 L
.2744 1.61637 L
.29043 1.61926 L
.31509 1.62406 L
.33974 1.62931 L
.3644 1.63501 L
.38905 1.64116 L
.41371 1.64778 L
.43836 1.65488 L
.46302 1.66246 L
.47303 1.66568 L
.48767 1.67054 L
.51233 1.67914 L
.53698 1.68826 L
.56164 1.6979 L
.58629 1.70809 L
.60227 1.71499 L
.61095 1.71885 L
.6356 1.7302 L
.66026 1.74215 L
.68491 1.7547 L
.70301 1.7643 L
.70957 1.76788 L
.73422 1.78178 L
.75888 1.79633 L
.78353 1.81152 L
.78686 1.81361 L
.80819 1.82758 L
.83284 1.84442 L
.8575 1.86173 L
.85919 1.86292 L
.88215 1.88014 L
.9068 1.90025 L
.9242 1.91223 L
.93146 1.91753 L
.95611 1.93938 L
.96838 1.96154 L
s
.6 g
.01923 1.69399 m
.04389 1.69414 L
.06854 1.69461 L
.0932 1.69539 L
.11785 1.69648 L
.1425 1.69788 L
.16716 1.6996 L
.19181 1.70164 L
.21647 1.70399 L
.24112 1.70667 L
.26578 1.70966 L
.29043 1.71299 L
.30424 1.71499 L
.31509 1.71664 L
.33974 1.72063 L
.3644 1.72496 L
.38905 1.72962 L
.41371 1.73464 L
.43836 1.74 L
.46302 1.74572 L
.48767 1.7518 L
.51233 1.75825 L
.53425 1.7643 L
.53698 1.76508 L
.56164 1.77229 L
.58629 1.7799 L
.61095 1.7879 L
.6356 1.79631 L
.66026 1.80512 L
.683 1.81361 L
.68491 1.81434 L
.70957 1.82403 L
.73422 1.83419 L
.75888 1.84477 L
.78353 1.85578 L
.79907 1.86292 L
.80819 1.8672 L
.83284 1.87948 L
.8575 1.8922 L
.88215 1.90487 L
.89576 1.91223 L
.9068 1.91675 L
.93146 1.92849 L
.95611 1.94743 L
.96507 1.96154 L
.01923 1.96154 L
F
0 g
.01923 1.69399 m
.04389 1.69414 L
.06854 1.69461 L
.0932 1.69539 L
.11785 1.69648 L
.1425 1.69788 L
.16716 1.6996 L
.19181 1.70164 L
.21647 1.70399 L
.24112 1.70667 L
.26578 1.70966 L
.29043 1.71299 L
.30424 1.71499 L
.31509 1.71664 L
.33974 1.72063 L
.3644 1.72496 L
.38905 1.72962 L
.41371 1.73464 L
.43836 1.74 L
.46302 1.74572 L
.48767 1.7518 L
.51233 1.75825 L
.53425 1.7643 L
.53698 1.76508 L
.56164 1.77229 L
.58629 1.7799 L
.61095 1.7879 L
.6356 1.79631 L
.66026 1.80512 L
.683 1.81361 L
.68491 1.81434 L
.70957 1.82403 L
.73422 1.83419 L
.75888 1.84477 L
.78353 1.85578 L
.79907 1.86292 L
.80819 1.8672 L
.83284 1.87948 L
.8575 1.8922 L
.88215 1.90487 L
.89576 1.91223 L
.9068 1.91675 L
.93146 1.92849 L
.95611 1.94743 L
.96507 1.96154 L
s
.7 g
.01923 1.78433 m
.04389 1.78444 L
.06854 1.78476 L
.0932 1.7853 L
.11785 1.78604 L
.1425 1.787 L
.16716 1.78818 L
.19181 1.78957 L
.21647 1.79118 L
.24112 1.79301 L
.26578 1.79506 L
.29043 1.79732 L
.31509 1.79981 L
.33974 1.80253 L
.3644 1.80547 L
.38905 1.80864 L
.41371 1.81205 L
.42451 1.81361 L
.43836 1.81568 L
.46302 1.81957 L
.48767 1.82367 L
.51233 1.82802 L
.53698 1.83265 L
.56164 1.83751 L
.58629 1.84258 L
.61095 1.84794 L
.6356 1.85358 L
.66026 1.85945 L
.67428 1.86292 L
.68491 1.86551 L
.70957 1.87179 L
.73422 1.8789 L
.75888 1.88594 L
.78353 1.89223 L
.80819 1.90039 L
.83284 1.90807 L
.84624 1.91223 L
.8575 1.91636 L
.88215 1.92745 L
.9068 1.92874 L
.93146 1.93737 L
.95611 1.95433 L
.96136 1.96154 L
.01923 1.96154 L
F
0 g
.01923 1.78433 m
.04389 1.78444 L
.06854 1.78476 L
.0932 1.7853 L
.11785 1.78604 L
.1425 1.787 L
.16716 1.78818 L
.19181 1.78957 L
.21647 1.79118 L
.24112 1.79301 L
.26578 1.79506 L
.29043 1.79732 L
.31509 1.79981 L
.33974 1.80253 L
.3644 1.80547 L
.38905 1.80864 L
.41371 1.81205 L
.42451 1.81361 L
.43836 1.81568 L
.46302 1.81957 L
.48767 1.82367 L
.51233 1.82802 L
.53698 1.83265 L
.56164 1.83751 L
.58629 1.84258 L
.61095 1.84794 L
.6356 1.85358 L
.66026 1.85945 L
.67428 1.86292 L
.68491 1.86551 L
.70957 1.87179 L
.73422 1.8789 L
.75888 1.88594 L
.78353 1.89223 L
.80819 1.90039 L
.83284 1.90807 L
.84624 1.91223 L
.8575 1.91636 L
.88215 1.92745 L
.9068 1.92874 L
.93146 1.93737 L
.95611 1.95433 L
.96136 1.96154 L
s
.8 g
.01923 1.86795 m
.04389 1.86867 L
.06854 1.86956 L
.0932 1.8699 L
.11785 1.86748 L
.1425 1.87013 L
.16716 1.87145 L
.19181 1.87218 L
.21647 1.87098 L
.24112 1.87369 L
.26578 1.87516 L
.29043 1.87624 L
.31509 1.87559 L
.33974 1.87891 L
.3644 1.88073 L
.38905 1.88207 L
.41371 1.88218 L
.43836 1.88599 L
.46302 1.88818 L
.48767 1.88978 L
.51233 1.89106 L
.53698 1.89492 L
.56164 1.89749 L
.58629 1.89969 L
.61095 1.90237 L
.6356 1.90562 L
.66026 1.90868 L
.68276 1.91223 L
.68491 1.91262 L
.70957 1.91597 L
.73422 1.91789 L
.75888 1.92184 L
.78353 1.93009 L
.80819 1.93116 L
.83284 1.93101 L
.8575 1.93683 L
.88215 1.95402 L
.9068 1.94113 L
.93146 1.94493 L
.95611 1.96043 L
.95705 1.96154 L
.01923 1.96154 L
F
0 g
.01923 1.86795 m
.04389 1.86867 L
.06854 1.86956 L
.0932 1.8699 L
.11785 1.86748 L
.1425 1.87013 L
.16716 1.87145 L
.19181 1.87218 L
.21647 1.87098 L
.24112 1.87369 L
.26578 1.87516 L
.29043 1.87624 L
.31509 1.87559 L
.33974 1.87891 L
.3644 1.88073 L
.38905 1.88207 L
.41371 1.88218 L
.43836 1.88599 L
.46302 1.88818 L
.48767 1.88978 L
.51233 1.89106 L
.53698 1.89492 L
.56164 1.89749 L
.58629 1.89969 L
.61095 1.90237 L
.6356 1.90562 L
.66026 1.90868 L
.68276 1.91223 L
.68491 1.91262 L
.70957 1.91597 L
.73422 1.91789 L
.75888 1.92184 L
.78353 1.93009 L
.80819 1.93116 L
.83284 1.93101 L
.8575 1.93683 L
.88215 1.95402 L
.9068 1.94113 L
.93146 1.94493 L
.95611 1.96043 L
.95705 1.96154 L
s
.7 g
.01923 1.95311 m
.03192 1.96154 L
.01923 1.96154 L
F
0 g
.01923 1.95311 m
.03192 1.96154 L
s
.9 g
.1076 1.96154 m
.0932 1.94325 L
.06854 1.94162 L
.05385 1.96154 L
F
0 g
.1076 1.96154 m
.0932 1.94325 L
.06854 1.94162 L
.05385 1.96154 L
s
.9 g
.20415 1.96154 m
.19181 1.94695 L
.16716 1.94297 L
.14549 1.96154 L
F
0 g
.20415 1.96154 m
.19181 1.94695 L
.16716 1.94297 L
.14549 1.96154 L
s
.9 g
.30017 1.96154 m
.29043 1.95072 L
.26578 1.94386 L
.24112 1.95705 L
.23804 1.96154 L
F
0 g
.30017 1.96154 m
.29043 1.95072 L
.26578 1.94386 L
.24112 1.95705 L
.23804 1.96154 L
s
.9 g
.3953 1.96154 m
.38905 1.95504 L
.3644 1.94484 L
.33974 1.9525 L
.33153 1.96154 L
F
0 g
.3953 1.96154 m
.38905 1.95504 L
.3644 1.94484 L
.33974 1.9525 L
.33153 1.96154 L
s
.9 g
.48914 1.96154 m
.48767 1.9601 L
.46302 1.94605 L
.43836 1.95043 L
.42627 1.96154 L
F
0 g
.48914 1.96154 m
.48767 1.9601 L
.46302 1.94605 L
.43836 1.95043 L
.42627 1.96154 L
s
.9 g
.58289 1.96154 m
.56164 1.94764 L
.53698 1.94951 L
.52179 1.96154 L
F
0 g
.58289 1.96154 m
.56164 1.94764 L
.53698 1.94951 L
.52179 1.96154 L
s
.9 g
.67681 1.96154 m
.66026 1.94973 L
.6356 1.94927 L
.61777 1.96154 L
F
0 g
.67681 1.96154 m
.66026 1.94973 L
.6356 1.94927 L
.61777 1.96154 L
s
.9 g
.77033 1.96154 m
.75888 1.95255 L
.73422 1.94953 L
.71393 1.96154 L
F
0 g
.77033 1.96154 m
.75888 1.95255 L
.73422 1.94953 L
.71393 1.96154 L
s
.9 g
.86282 1.96154 m
.8575 1.95633 L
.83284 1.94977 L
.81 1.96154 L
F
0 g
.86282 1.96154 m
.8575 1.95633 L
.83284 1.94977 L
.81 1.96154 L
s
.9 g
.95177 1.96154 m
.93146 1.95156 L
.9068 1.95882 L
.90471 1.96154 L
F
0 g
.95177 1.96154 m
.93146 1.95156 L
.9068 1.95882 L
.90471 1.96154 L
s
1 g
.9444 1.96154 m
.93146 1.9575 L
.91725 1.96154 L
F
0 g
.9444 1.96154 m
.93146 1.9575 L
.91725 1.96154 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{191.188, 382.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004N0002?B000`400?l00000o`00003ooooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00Xoooool6o`0007Gooooo002U
ooooo`03o`000?oooooooooo07Kooooo002Uooooo`03o`000?oooooooooo07Kooooo002Uooooo`03
o`000?oooooooooo07Kooooo002Uooooo`03o`000?oMgMgooooo07Kooooo002Uooooo`;o000000?o
V9RHooooooooool0M?ooool00:?ooooo00Go410@o`000?l0003o^[ZjodA4A002o`000003ob4Q8Ooo
oooooooo077ooooo003ooooooaoooooo003ooooooaoooooo003ooooooaoooooo003ooooooaoooooo
003ooooooaoooooo003ooooooaoooooo003ooooooaoooooo003ooooooaoooooo003ooooooaoooooo
000cooooo`04okZj^_l@413o0000ogMgMb3ooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo
0000oeEEE@04ooooo`Ko00005oooool01?nj^[[o410@o`000?mgMgL6ooooo`03oeEEEOl0003oEEEE
00Oooooo0_l000000ol@413oooooooooo`0Dooooo`04okZj^_l@413o0000ogMgM`Kooooo00?oEEEE
o`000?mEEED01?ooool01_o^k^koA4A4o`000?l0003oEEEEonk^kQOooooo00Co^[Zjoa0@4?l0003o
MgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06onk^k_m4A4Co0000o`000?m4A4Cok^k^7oooool4
o`000003oa0@4?oooooooooo007ooooo000booooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY7_oo
ool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00004ooooo`03oiRHV?l0003oc<c<00;o
oooo00?o410@ooooooooool05?ooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo0ol00008
ooooo`03o`000?oooooooooo01Cooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o0000
1?ooool01_mEEEGoMgMgooooooooooooMgMgoeEEEAKooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnY
ZJT5ooooo`?o00001?ooool01_lb<S;oMgMgonk^k_o^k^koMgMgoc8b<R7ooooo00?o0000oooooooo
ool00oooool003;ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S8Nooooo`06odA4A?nYZJWooooo
oooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@05ooooo`03oiRHV?l0003oc<c<01Sooooo00Ko
A4A4ojVYZOooooooooooojVYZOlb<S85ooooo`03oeEEEOl0003oEEEE00Cooooo1_l0000Eooooo`06
odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@04ooooo`03oa0@4?oooooo
oooo00;ooooo00?o0000ooooooooool05?ooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo
00?oEEEEo`000?mEEED01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool00oooool003;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00onYZJWo410@olc<
c00Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01OmVIVKoZJVYoooo
oooooooo000001Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?o^k^kooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00[ooooo00Ko<S8bogMgMoo^k^kok^k^ogMgMolb<S8Qooooo`03o`000?oooooooooo
00?ooooo000booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?oc<c<oa0@4?o<c<`05_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Gok^k^ob4Q8Oo^k^koooooo`00000Foooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_l0003oEEEEonk^k_oooooo
MgMgoeEEEAKooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03omgMgOl0
003o000000;o000000?ogMgMooooooooool07oooool00ol0003oooooooooo`03ooooo`00<_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0>ooooo`03ojVYZOlb<S;ooooo01Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0;ooooo`04ojVYZOmVIVKoooooo`0001Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0:ooooo`06ob4Q8OmVIVKo0000o`000?mEEEGok^k^5_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb<S8Q
ooooo`03o`000?oooooooooo00?ooooo000booooo`06odA4A?nYZJWooooooooooonYZJWoA4A47_oo
ool01_m4A4CoZJVYooooooooooooZJVYodA4A17ooooo00?o0000ooooooooool05?ooool01_m4A4Co
ZJVYooooooooooooZJVYodA4A0kooooo00?oA4A4olc<c?l000005_ooool01_m4A4CoZJVYoooooooo
ooooZJVYodA4A0cooooo00?oQhN7ofIVI_ooool06Oooool01_m4A4CoZJVYooooooooooooZJVYodA4
A0cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00?ooooo000booooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<7_ooool01_o<c<co<S8bonk^k_o^
k^ko<S8bolc<c0cooooo00Ko0000ohN7Qoo^k^koooooogMgMolb<S8Fooooo`06olc<c?lb<S;ok^k^
onk^k_lb<S;oc<c<3_ooool00ooMgMgoA4A4o`00000Fooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;o
c<c<3Oooool00olb<S;oIVIVomgMg@0Hooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?ooool0
1_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<Qoooooo00?o0000odA4A?l000001Oooool003?ooooo00Co
^[Zjoa0@4?l@413oc<c<8?ooool01?nj^[[o410@oa0@4?o<c<`=ooooo`06ojVYZOlb<S;o0000o`00
0?mEEEGok^k^5oooool01?nj^[[o410@oa0@4?o<c<`@ooooo`03ohN7Qol0003ooooo01Kooooo00Co
^[Zjoa0@4?l@413oc<c<3oooool01?mgMgOo410@o`000?lQ8B4Gooooo`04okZj^_l@413o410@olc<
c0gooooo00Kok^k^odA4A?l0003o0000odA4A?o^k^hOooooo`03olc<c?mEEEGo000000Gooooo003o
oooooaoooooo003ooooooaoooooo003ooooooaoooooo000aooooongo0000000aooooo`05o`000?oo
ooooooooooooool000002oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooooooo`7o
0000000aooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0[ooooo`04
o`000?ooooooooooooooo`7o0000000aooooo`03o`000?oooooooooo0>Wooooo0Ol00000037ooooo
00?o0000ooooooooool0jOooool1o`000000<Oooool00ol0003oooooooooo`3Yooooo`7o0000000a
ooooo`03o`000?oooooooooo0>Wooooo0Ol0000002Oooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool0
0ol0003oooooooooo`3Yooooo`7o0000000Vooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1Ooo
ool00ol0003oooooooooo`3Yooooo`7o0000000Vooooo`06odA4A?nYZJWooooooooooonYZJWo<S8b
1Oooool00ol0003oooooooooo`3Yooooo`7o0000000Vooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool2o`000>Wooooo0_l0000002Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooonCo00001?ooool1o`0000009_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000ooooooooooooooooi?l0
0004ooooo`7o0000000Vooooo`06odA4A?nYZJWooooooooooonYZJWoA4A41Oooool01?l0003ooooo
oooooooooooTo`0000Cooooo0Ol0000002Kooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`5oooo
o`04o`000?ooooooooooooooonCo00001?ooool1o`0000009oooool01?nj^[[o410@oa0@4?o<c<`6
ooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooo
oooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000a
ooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooo
oooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000a
ooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooo
oooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000a
ooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooo
oooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000a
ooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooo
oooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000a
ooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooo
oooTo`0000Cooooo0Ol00000037ooooo0_l00002ooooonCo00000oooool2o`000000<Oooool01?l0
003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004
ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0
003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004
ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0
003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004
ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0
003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004
ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0
003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004
ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0
003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004
ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0
003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004
ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0
003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo0_l00002ooooonCo00000oooool2o`00
0000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
ooooooooi?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`00
0000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
ooooooooi?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`00
0000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
ooooooooi?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`00
0000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
ooooooooi?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`00
0000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
ooooooooi?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`00
0000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
ooooooooi?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`00
0000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
ooooooooi?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`00
0000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo0_l00002ooooonCo
00000oooool2o`000000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo
00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo
00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo
00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo
00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo
00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo
00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo
00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo
00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo
00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo
00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo
00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo
00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo
00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo
00001?ooool1o`000000<Oooool2o`0000;oooooi?l00003ooooo`;o0000000aooooo`04o`000?oo
ooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo
0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`000?oo
ooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo
0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`000?oo
ooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo
0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`000?oo
ooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo
0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`000?oo
ooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo
0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`000?oo
ooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo
0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`000?oo
ooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Cooooo
0Ol0000001Gooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06oiRH
V?l@413o0000o`000?m4A4Cok^k^1Oooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol00000
01Cooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`?o00001?ooool01_l@413oQhN7oooo
ooooooooMgMgodA4A0Gooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000Dooooo`06
odA4A?nYZJWooooooooooonYZJWo<S8b1Oooool00omEEEGo0000oeEEE@09ooooo`03o`000?oooooo
oooo00?ooooo0_l00002ooooonCo00000oooool2o`0000005?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00kooooo00?ok^k^o`000?ooool01?ooool01?l0003ooooooooooooooooT
o`0000Cooooo0Ol0000001Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:oooo
o`06oa0@4?nHV9SooooooooooomgMgOoIVIV1Oooool01?l0003ooooooooooooooooTo`0000Cooooo
0Ol0000001Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?lQ
8B7o0000o`000?mVIVH01_ooool01?l0003ooooooooooooooooTo`0000Cooooo0Ol0000001Cooooo
00KoA4A4ojVYZOooooooooooojVYZOm4A4@<ooooo`03o`000?oooooooooo00Sooooo00Co0000oooo
ooooooooooooi?l00004ooooo`7o0000000Dooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3?oo
ool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooooooonCo00001?ooool1o`0000005Ooo
ool01?nj^[[o410@oa0@4?o<c<`=ooooo`Go00001_ooool01?l0003ooooooooooooooooTo`0000Co
oooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`00
0?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Co
oooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`00
0?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Co
oooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`00
0?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Co
oooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`00
0?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Co
oooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`04o`00
0?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooooTo`0000Co
oooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000000aooooo`;o0000
0_oooooTo`0000?ooooo0_l00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000
000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooo
oooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000
000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooo
oooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000
000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooo
oooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000
000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooo
oooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000
000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooo
oooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000
000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooo
oooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l00004ooooo`7o0000
000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool01?l0003ooooooooo
oooooooTo`0000Cooooo0Ol00000037ooooo0_l00002ooooonCo00000oooool2o`000000<Oooool0
1?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l0
0004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool0
1?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l0
0004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool0
1?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l0
0004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool0
1?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l0
0004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool0
1?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l0
0004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool0
1?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l0
0004ooooo`7o0000000aooooo`04o`000?ooooooooooooooonCo00001?ooool1o`000000<Oooool0
1?l0003ooooooooooooooooTo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooi?l0
0004ooooo`7o0000000aooooo`04o`000?oooooooooooooooa3o6ATIe?l00004ooooo`7o0000000a
ooooo`04o`000?oooooooooooooooaco6ATIb?l00004ooooo`7o0000000aooooo`;o00000_oooolR
oaTI6L;o00000oooool2o`000000<Oooool01?l0003ooooooooooooooolWoaTI6Kgo00001?ooool1
o`000000<Oooool01?l0003oooooooooooooool]oaTI6KOo00001?ooool1o`000000<Oooool01?l0
003ooooooooooooooolboaTI6K;o00001?ooool1o`000000<Oooool01?l0003ooooooooooooooole
oaTI6Joo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooolhoaTI6Jco00001?ooool1
o`000000<Oooool01?l0003ooooooooooooooolkoaTI6JWo00001?ooool1o`000000<Oooool01?l0
003ooooooooooooooolooaTI6JGo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooom3
oaTI6J7o00001?ooool1o`000000<Oooool01?l0003ooooooooooooooom6oaTI6Iko00001?ooool1
o`000000<Oooool01?l0003ooooooooooooooom8oaTI6Ico00001?ooool1o`000000<Oooool01?l0
003ooooooooooooooom:oaTI6I[o00001?ooool1o`000000<Oooool01?l0003ooooooooooooooom<
oaTI6ISo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooom?oaTI6IGo00001?ooool1
o`000000<Oooool01?l0003ooooooooooooooomBoaTI6I;o00001?ooool1o`000000<Oooool01?l0
003ooooooooooooooomDoaTI6I3o00001?ooool1o`000000<Oooool01?l0003ooooooooooooooomG
oaTI6Hgo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooomHoaTI6Hco00001?ooool1
o`000000<Oooool01?l0003ooooooooooooooomJoaTI6H[o00001?ooool1o`000000<Oooool01?l0
003ooooooooooooooomLoaTI6HSo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooomN
oaTI6HKo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooomPoaTI6HCo00001?ooool1
o`000000<Oooool01?l0003ooooooooooooooomRoaTI6H;o00001?ooool1o`000000<Oooool2o`00
00;oooooHolI6AV1o`0000?ooooo0_l00000037ooooo00Co0000ooooooooooooooooIOlI6AUoo`00
00Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooIolI6AUmo`0000Cooooo0Ol00000037o
oooo00Co0000ooooooooooooooooJOlI6AUko`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
ooooooooJolI6AUio`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooK?lI6AUho`00
00Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooK_lI6AUfo`0000Cooooo0Ol00000037o
oooo00Co0000ooooooooooooooooKolI6AUeo`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
ooooooooLOlI6AUco`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooL_lI6AUbo`00
00Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooM?lI6AU`o`0000Cooooo0Ol00000037o
oooo00Co0000ooooooooooooooooMOlI6AU_o`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
ooooooooMolI6AU]o`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooN?lI6AU/o`00
00Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooN_lI6AUZo`0000Cooooo0Ol00000037o
oooo00Co0000ooooooooooooooooNolI6AUYo`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
ooooooooO?lI6AUXo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooOOlI6AUWo`00
00Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooOolI6AUUo`0000Cooooo0Ol0000000oo
oooo1_l0000Looooo`04o`000?oooooooooooooooh3o6ATII?l00004ooooo`7o0000000?ooooo`03
oiRHV?mEEEGooooo00;ooooo00?o0000ooooooooool04?ooool4o`000003oa0@4?oooooooooo00?o
oooo00Co0000ooooooooooooooooPOlI6AUSo`0000Cooooo0Ol00000013ooooo00?oV9RHoeEEEOoo
ool05_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooooooooh;o6ATIH_l00004oooo
o`7o0000000Aooooo`03oiRHV?mEEEGooooo01Gooooo00?o0000ooooooooool01Oooool01?l0003o
oooooooooooooon3oaTI6F7o00001?ooool1o`0000004_ooool00onHV9SoEEEEooooo`0Dooooo`03
o`000?oooooooooo00Gooooo0_l00002ooooohCo6ATIH?l00003ooooo`;o0000000?ooooo`06o`00
0?oooooooooooooooonHV9SoEEEE5?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
ooooohGo6ATIGol00004ooooo`7o0000000?ooooo`Ko00005?ooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooooooohKo6ATIG_l00004ooooo`7o0000000Yooooo`03o`000?oooooooooo
00Gooooo00Co0000ooooooooooooooooR?lI6AULo`0000Cooooo0Ol0000002Oooooo00?o0000odA4
A?l000001oooool01?l0003ooooooooooooooon9oaTI6E_o00001?ooool1o`0000009oooool00oo<
c<coEEEEo`000007ooooo`04o`000?oooooooooooooooh[o6ATIF_l00004ooooo`7o0000000aoooo
o`04o`000?oooooooooooooooh_o6ATIFOl00004ooooo`7o0000000aooooo`04o`000?oooooooooo
ooooohco6ATIF?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooohgo6ATIEol00004
ooooo`7o0000000aooooo`04o`000?ooooooooooooooohko6ATIE_l00004ooooo`7o0000000aoooo
o`04o`000?ooooooooooooooohoo6ATIEOl00004ooooo`7o0000000aooooo`04o`000?oooooooooo
oooooi3o6ATIE?l00004ooooo`7o0000000aooooo`04o`000?oooooooooooooooi7o6ATIDol00004
ooooo`7o0000000aooooo`04o`000?oooooooooooooooi;o6ATID_l00004ooooo`7o0000000aoooo
o`04o`000?oooooooooooooooi?o6ATIDOl00004ooooo`7o0000000aooooo`04o`000?oooooooooo
oooooiCo6ATID?l00004ooooo`7o0000000aooooo`04o`000?oooooooooooooooiGo6ATICol00004
ooooo`7o0000000aooooo`04o`000?oooooooooooooooiKo6ATIC_l00004ooooo`7o0000000aoooo
o`04o`000?oooooooooooooooiOo6ATICOl00004ooooo`7o0000000aooooo`04o`000?oooooooooo
oooooiSo6ATIC?l00004ooooo`7o0000000aooooo`04o`000?oooooooooooooooiSo6ATIC?l00004
ooooo`7o0000000aooooo`04o`000?oooooooooooooooiWo6ATIBol00004ooooo`7o0000000aoooo
o`;o00000_oooonJoaTI6D[o00000oooool2o`000000<Oooool01?l0003ooooooooooooooonKoaTI
6DWo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooonLoaTI6DSo00001?ooool1o`00
0000<Oooool01?l0003ooooooooooooooonMoaTI6DOo00001?ooool1o`000000<Oooool01?l0003o
oooooooooooooonNoaTI6DKo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooonNoaTI
6DKo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooonOoaTI6DGo00001?ooool1o`00
0000<Oooool01?l0003ooooooooooooooonPoaTI6DCo00001?ooool1o`000000<Oooool01?l0003o
oooooooooooooonPoaTI6DCo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooonQoaTI
6D?o00001?ooool1o`000000<Oooool01?l0003ooooooooooooooonRoaTI6D;o00001?ooool1o`00
0000<Oooool01?l0003oooooooooooooool@o`0009;o6ATI@_l00004ooooo`7o0000000aooooo`04
o`000?oooooooooooooooa3o<c<c3?l00027oaTI6D7o00001?ooool1o`000000<Oooool01?l0003o
oooooooooooooolLoc<c<`Ko0000POlI6AU1o`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
oooooooo8_lc<c<5o`0007go6ATI@?l00004ooooo`7o0000000aooooo`04o`000?oooooooooooooo
obOo<c<c1_l0001hoaTI6Coo00001?ooool1o`000000<Oooool01?l0003oooooooooooooool]oc<c
<`Ko0000LolI6ATno`0000Cooooo0Ol00000037ooooo00Co0000oooooooooooooooo<olc<c<5o`00
06oo6ATI?Ol00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooocSo<c<c0ol0001]oaTI
6Cco00001?ooool1o`000000<Oooool01?l0003ooooooooooooooolkoc<c<`?o0000J_lI6ATlo`00
00Cooooo0Ol00000037ooooo00Co0000oooooooooooooooo?_lc<c<3o`0006So6ATI>ol00004oooo
o`7o0000000aooooo`04o`000?oooooooooooooood7o<c<c0_l0001VoaTI6C_o00001?ooool1o`00
0000<Oooool01?l0003ooooooooooooooom3oc<c<`?o0000I?lI6ATjo`0000Cooooo0Ol00000037o
oooo0_l00002ooooodKo<c<c0ol0001RoaTI6CWo00000oooool2o`000000<Oooool01?l0003ooooo
oooooooooom9oc<c<`?o0000GolI6ATio`0000Cooooo0Ol00000037ooooo00Co0000oooooooooooo
ooooC?lc<c<3o`0005go6ATI>?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooodoo
<c<c0ol0001KoaTI6COo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooomBoc<c<`?o
0000F?lI6ATgo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooEOlc<c<3o`0005Ko
6ATI=_l00004ooooo`7o0000000aooooo`04o`000?oooooooooooooooeSo<c<c00?o0000oaTI6OlI
6AT0E?lI6ATeo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooFOlc<c<2o`0005Go
6ATI=?l00004ooooo`7o0000000aooooo`04o`000?oooooooooooooooe_o<c<c0ol0001BoaTI6CCo
00001?ooool1o`000000<Oooool01?l0003ooooooooooooooomNoc<c<`;o0000DOlI6ATco`0000Co
oooo0Ol00000037ooooo00Co0000ooooooooooooooooH?lc<c<2o`0004oo6ATI<ol00004ooooo`7o
0000000aooooo`04o`000?ooooooooooooooof;o<c<c00?o0000oaTI6OlI6AT0COlI6ATbo`0000Co
oooo0Ol00000037ooooo00Co0000ooooooooooooooooHolc<c<2o`0004ko6ATI<Ol00004ooooo`7o
0000000aooooo`04o`000?ooooooooooooooofGo<c<c0_l0001<oaTI6C7o00001?ooool1o`000000
<Oooool01?l0003ooooooooooooooomWoc<c<`;o0000BolI6AT`o`0000Cooooo0Ol00000037ooooo
00Co0000ooooooooooooooooJOlc<c<2o`0004Wo6ATI<?l00004ooooo`7o0000000aooooo`04o`00
0?ooooooooooooooof_o<c<c0_l00018oaTI6Boo00001?ooool1o`000000<Oooool01?l0003ooooo
oooooooooom]oc<c<`;o0000A_lI6AT_o`0000Cooooo0Ol00000037ooooo00Co0000oooooooooooo
ooooKolc<c<00ol0003o6ATIoaTI6@14oaTI6Bko00001?ooool1o`000000<Oooool01?l0003ooooo
oooooooooom`oc<c<`;o0000A?lI6AT^o`0000Cooooo0Ol00000037ooooo00Co0000oooooooooooo
ooooL_lc<c<2o`0004;o6ATI;_l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooogCo
<c<c00?o0000oaTI6OlI6AT0@?lI6AT]o`0000Cooooo0Ol00000037ooooo00Co0000oooooooooooo
ooooMOlc<c<2o`00047o6ATI;?l00004ooooo`7o0000000aooooo`;o00000_oooomgoc<c<`03o`00
0?lI6AWo6ATI03ko6ATI;?l00003ooooo`;o0000000aooooo`04o`000?ooooooooooooooogSo<c<c
0_l0000ooaTI6B_o00001?ooool1o`000000<Oooool01?l0003ooooooooooooooomjoc<c<`03o`00
0?lI6AWo6ATI03co6ATI:ol00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooog_o<c<c
0_l0000moaTI6B[o00001?ooool1o`000000<Oooool01?l0003ooooooooooooooommoc<c<`03o`00
0?lI6AWo6ATI03_o6ATI:Ol00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooogko<c<c
0_l0000koaTI6BWo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooon0oc<c<`03o`00
0?lI6AWo6ATI03Wo6ATI:?l00004ooooo`7o0000000aooooo`04o`000?oooooooooooooooh7o<c<c
0_l0000ioaTI6BSo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooon3oc<c<`03o`00
0?lI6AWo6ATI03Ko6ATI:?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooohCo<c<c
00?o0000oaTI6OlI6AT0=_lI6ATWo`0000Cooooo0Ol00000037ooooo00Co0000oooooooooooooooo
QOlc<c<00ol0003o6ATIoaTI6@0eoaTI6BOo00001?ooool1o`000000<Oooool01?l0003ooooooooo
ooooool:o`0007co<c<c0_l0000foaTI6BKo00001?ooool1o`000000<Oooool01?l0003ooooooooo
ooooool:oda<C1;o0000K?lc<c<00ol0003o6ATIoaTI6@0coaTI6BKo00001?ooool1o`000000<Ooo
ool01?l0003ooooooooooooooolLoda<C0Ko0000Iolc<c<00ol0003o6ATIoaTI6@0coaTI6BGo0000
1?ooool1o`000000<Oooool01?l0003ooooooooooooooolRoda<C0Go0000Holc<c<00ol0003o6ATI
oaTI6@0boaTI6BGo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooolWoda<C0Ko0000
G_lc<c<00ol0003o6ATIoaTI6@0boaTI6BCo00001?ooool1o`000000<Oooool01?l0003ooooooooo
ooooool]oda<C0Ko0000FOlc<c<2o`0003;o6ATI9?l00004ooooo`7o0000000aooooo`04o`000?oo
oooooooooooooc?oC4a<1_l0001Eoc<c<`03o`000?lI6AWo6ATI033o6ATI8ol00004ooooo`7o0000
000aooooo`04o`000?ooooooooooooooocWoC4a<1?l0001Boc<c<`03o`000?lI6AWo6ATI02oo6ATI
8ol00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooocgoC4a<0ol0001@oc<c<`03o`00
0?lI6AWo6ATI02ko6ATI8ol00004ooooo`7o0000000aooooo`04o`000?oooooooooooooood3oC4a<
1Ol0001<oc<c<`03o`000?lI6AWo6ATI02go6ATI8ol00004ooooo`7o0000000aooooo`04o`000?oo
ooooooooooooodGoC4a<1?l00019oc<c<`;o0000;_lI6ATRo`0000Cooooo0Ol00000037ooooo0_l0
0002ooooodWoC4a<0ol00018oc<c<`03o`000?lI6AWo6ATI02_o6ATI8_l00003ooooo`;o0000000a
ooooo`04o`000?ooooooooooooooodcoC4a<0ol00016oc<c<`03o`000?lI6AWo6ATI02[o6ATI8_l0
0004ooooo`7o0000000aooooo`04o`000?ooooooooooooooodooC4a<0ol00014oc<c<`03o`000?lI
6AWo6ATI02[o6ATI8Ol00004ooooo`7o0000000aooooo`04o`000?oooooooooooooooe;oC4a<0ol0
0012oc<c<`03o`000?lI6AWo6ATI02Wo6ATI8Ol00004ooooo`7o0000000aooooo`04o`000?oooooo
oooooooooeGoC4a<0ol00010oc<c<`03o`000?lI6AWo6ATI02Wo6ATI8?l00004ooooo`7o0000000a
ooooo`04o`000?oooooooooooooooeSoC4a<0_l0000noc<c<`03o`000?lI6AWo6ATI02Wo6ATI8?l0
0004ooooo`7o0000000aooooo`04o`000?oooooooooooooooe[oC4a<0_l0000moc<c<`03o`000?lI
6AWo6ATI02Wo6ATI7ol00004ooooo`7o0000000aooooo`04o`000?oooooooooooooooecoC4a<0_l0
000loc<c<`03o`000?lI6AWo6ATI02So6ATI7ol00004ooooo`7o0000000aooooo`04o`000?oooooo
oooooooooekoC4a<0_l0000koc<c<`03o`000?lI6AWo6ATI02Oo6ATI7ol00004ooooo`7o0000000a
ooooo`04o`000?ooooooooooooooof3oC4a<0ol0000ioc<c<`;o0000:?lI6ATNo`0000Cooooo0Ol0
0000037ooooo00Co0000ooooooooooooooooHom<C4`2o`0003Wo<c<c00?o0000oaTI6OlI6AT09OlI
6ATNo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooIOm<C4`2o`0003Oo<c<c00?o
0000oaTI6OlI6AT09_lI6ATMo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooIom<
C4`2o`0003Ko<c<c00?o0000oaTI6OlI6AT09OlI6ATMo`0000Cooooo0Ol00000037ooooo00Co0000
ooooooooooooooooJOm<C4`2o`0003Go<c<c00?o0000oaTI6OlI6AT09?lI6ATMo`0000Cooooo0Ol0
0000037ooooo00Co0000ooooooooooooooooJom<C4`2o`0003Co<c<c00?o0000oaTI6OlI6AT09?lI
6ATLo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooKOm<C4`2o`0003;o<c<c00?o
0000oaTI6OlI6AT09?lI6ATLo`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooKom<
C4`2o`00037o<c<c00?o0000oaTI6OlI6AT08olI6ATLo`0000Cooooo0Ol00000037ooooo00Co0000
ooooooooooooooooLOm<C4`2o`00033o<c<c0_l0000ToaTI6A_o00001?ooool1o`000000<Oooool0
1?l0003ooooooooooooooomcoda<C0;o0000<?lc<c<00ol0003o6ATIoaTI6@0QoaTI6A_o00001?oo
ool1o`000000<Oooool01?l0003ooooooooooooooomeoda<C0?o0000;_lc<c<00ol0003o6ATIoaTI
6@0PoaTI6A_o00001?ooool1o`000000<Oooool01?l0003ooooooooooooooomhoda<C0;o0000;Olc
<c<00ol0003o6ATIoaTI6@0PoaTI6A[o00001?ooool1o`0000005Oooool4o`000003oa0@4?oooooo
oooo00?ooooo00?oEEEEo`000?mEEED01?ooool01_nHV9So410@o`000?l0003oA4A4onk^kPGooooo
00Co0000ooooooooooooooooN_m<C4`00ol0003o<c<coc<c<`0Zoc<c<`03o`000?lI6AWo6ATI023o
6ATI6_l00004ooooo`7o0000000Gooooo`03o`000?oooooooooo00Gooooo0ol00004ooooo`06oa0@
4?n7QhOooooooooooomgMgOoA4A41Oooool01?l0003ooooooooooooooomkoda<C0;o0000:olc<c<0
0ol0003o6ATIoaTI6@0PoaTI6AWo00001?ooool1o`0000005oooool00ol0003oooooooooo`05oooo
o`03oeEEEOl0003oEEEE00Wooooo00?o0000ooooooooool00oooool2o`0000;ooooo5_l0001Woda<
C0;o0000:_lc<c<00ol0003o6ATIoaTI6@0OoaTI6AWo00000oooool2o`0000005oooool00ol0003o
ooooooooo`0@ooooo`03onk^k_l0003ooooo00Cooooo00Co0000oooooooooooooooo5_mVIVH<o`00
05goC4a<0_l0000Xoc<c<`03o`000?lI6AWo6ATI01oo6ATI6Ol00004ooooo`7o0000000Gooooo`03
o`000?oooooooooo00cooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH5ooooo`04o`000?oooooo
ooooooooob;oIVIV1Ol0001Joda<C0;o00009olc<c<00ol0003o6ATIoaTI6@0OoaTI6ASo00001?oo
ool1o`0000005oooool00ol0003oooooooooo`0<ooooo`05o`000?lQ8B7o0000o`000?mVIVH01_oo
ool01?l0003ooooooooooooooolWofIVIPKo0000E_m<C4`00ol0003o<c<coc<c<`0Uoc<c<`03o`00
0?lI6AWo6ATI01ko6ATI6?l00004ooooo`7o0000000Gooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02?ooool01?l0003oooooooooooooool]ofIVIPKo0000DOm<C4`00ol0003o<c<c
oc<c<`0Uoc<c<`03o`000?lI6AWo6ATI01go6ATI6?l00004ooooo`7o0000000Eooooo`03o`000?m4
A4Co000000kooooo00?o0000ooooooooool02?ooool01?l0003ooooooooooooooolcofIVIPKo0000
C?m<C4`00ol0003o<c<coc<c<`0Toc<c<`03o`000?lI6AWo6ATI01ko6ATI5ol00004ooooo`7o0000
000Eooooo`03olc<c?mEEEGo000000kooooo1Ol00006ooooo`04o`000?ooooooooooooooocWoIVIV
1_l00017oda<C0;o00009Olc<c<00ol0003o6ATIoaTI6@0MoaTI6AOo00001?ooool1o`000000<Ooo
ool01?l0003oooooooooooooooloofIVIPKo0000@om<C4`00ol0003o<c<coc<c<`0Soc<c<`03o`00
0?lI6AWo6ATI01co6ATI5ol00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooodGoIVIV
0ol00011oda<C003o`000?lc<c?o<c<c02?o<c<c00?o0000oaTI6OlI6AT07?lI6ATFo`0000Cooooo
0Ol00000037ooooo00Co0000ooooooooooooooooB?mVIVH3o`0003ooC4a<0_l0000Toc<c<`03o`00
0?lI6AWo6ATI01_o6ATI5_l00004ooooo`7o0000000aooooo`04o`000?oooooooooooooood_oIVIV
1?l0000moda<C0;o00008_lc<c<00ol0003o6ATIoaTI6@0KoaTI6AKo00001?ooool1o`000000<Ooo
ool01?l0003ooooooooooooooom?ofIVIP?o0000??m<C4`00ol0003o<c<coc<c<`0Poc<c<`03o`00
0?lI6AWo6ATI01_o6ATI5Ol00004ooooo`7o0000000aooooo`04o`000?oooooooooooooooe;oIVIV
1?l0000ioda<C0;o00008Olc<c<00ol0003o6ATIoaTI6@0JoaTI6AGo00001?ooool1o`000000<Ooo
ool01?l0003ooooooooooooooomFofIVIPGo0000=_m<C4`00ol0003o<c<coc<c<`0Ooc<c<`03o`00
0?lI6AWo6ATI01Wo6ATI5Ol00004ooooo`7o0000000aooooo`04o`000?oooooooooooooooe_oIVIV
0ol0000doda<C0;o00008?lc<c<00ol0003o6ATIoaTI6@0IoaTI6ACo00001?ooool1o`000000<Ooo
ool01?l0003ooooooooooooooomNofIVIP;o0000=?m<C4`00ol0003o<c<coc<c<`0Noc<c<`03o`00
0?lI6AWo6ATI01So6ATI5?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooof3oIVIV
0ol0000boda<C003o`000?lc<c?o<c<c01go<c<c00?o0000oaTI6OlI6AT06?lI6ATDo`0000Cooooo
0Ol00000037ooooo00Co0000ooooooooooooooooHomVIVH2o`00037oC4a<00?o0000oc<c<olc<c<0
7Olc<c<00ol0003o6ATIoaTI6@0HoaTI6A?o00001?ooool1o`000000<Oooool01?l0003ooooooooo
oooooomUofIVIP;o0000<?m<C4`00ol0003o<c<coc<c<`0Moc<c<`03o`000?lI6AWo6ATI01Oo6ATI
4ol00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooofOoIVIV0_l0000_oda<C0;o0000
7Olc<c<00ol0003o6ATIoaTI6@0GoaTI6A?o00001?ooool1o`000000<Oooool01?l0003ooooooooo
oooooomYofIVIPCo0000;Om<C4`00ol0003o<c<coc<c<`0Koc<c<`03o`000?lI6AWo6ATI01Oo6ATI
4_l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooofgoIVIV0_l0000/oda<C003o`00
0?lc<c?o<c<c01[o<c<c00?o0000oaTI6OlI6AT05olI6ATBo`0000Cooooo0Ol00000037ooooo00Co
0000ooooooooooooooooKomVIVH2o`0002_oC4a<00?o0000oc<c<olc<c<06_lc<c<00ol0003o6ATI
oaTI6@0FoaTI6A;o00001?ooool1o`000000<Oooool2o`0000;oooooLOmVIVH2o`0002[oC4a<00?o
0000oc<c<olc<c<06_lc<c<00ol0003o6ATIoaTI6@0EoaTI6A;o00000oooool2o`000000<Oooool0
1?l0003ooooooooooooooomcofIVIP;o0000:Om<C4`00ol0003o<c<coc<c<`0Joc<c<`03o`000?lI
6AWo6ATI01Co6ATI4_l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooogGoIVIV0ol0
000Woda<C003o`000?lc<c?o<c<c01Wo<c<c00?o0000oaTI6OlI6AT05OlI6ATAo`0000Cooooo0Ol0
0000037ooooo00Co0000ooooooooooooooooN?mVIVH3o`0002GoC4a<00?o0000oc<c<olc<c<06Olc
<c<00ol0003o6ATIoaTI6@0DoaTI6A7o00001?ooool1o`000000<Oooool01?l0003ooooooooooooo
oolFo`0006GoIVIV0_l0000Toda<C003o`000?lc<c?o<c<c01Wo<c<c00?o0000oaTI6OlI6AT04olI
6ATAo`0000Cooooo0Ol00000037ooooo00Co0000oooooooooooooooo5_moOgl<o`0005_oIVIV0_l0
000Soda<C003o`000?lc<c?o<c<c01So<c<c00?o0000oaTI6OlI6AT05?lI6AT@o`0000Cooooo0Ol0
0000037ooooo00Co0000oooooooooooooooo8_moOgl;o`0005;oIVIV0_l0000Roda<C0;o00006Olc
<c<00ol0003o6ATIoaTI6@0CoaTI6A3o00001?ooool1o`000000<Oooool01?l0003ooooooooooooo
ool]ogmoO`Ko0000C_mVIVH2o`0002;oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI
6@0CoaTI6A3o00001?ooool1o`000000<Oooool01?l0003ooooooooooooooolcogmoO`Ko0000B_mV
IVH00ol0003oC4a<oda<C00Poda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT04olI
6AT?o`0000Cooooo0Ol00000037ooooo00Co0000oooooooooooooooo>OmoOgl7o`0004CoIVIV0_l0
000Qoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT04_lI6AT?o`0000Cooooo0Ol0
0000037ooooo00Co0000oooooooooooooooo@?moOgl5o`00047oIVIV0_l0000Poda<C003o`000?lc
<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT04OlI6AT?o`0000Cooooo0Ol00000037ooooo00Co0000
ooooooooooooooooAOmoOgl5o`0003koIVIV0_l0000Ooda<C003o`000?lc<c?o<c<c01Go<c<c00?o
0000oaTI6OlI6AT04OlI6AT?o`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooB_mo
Ogl5o`0003_oIVIV0_l0000Noda<C003o`000?lc<c?o<c<c01Go<c<c00?o0000oaTI6OlI6AT04?lI
6AT?o`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooComoOgl3o`0003[oIVIV0_l0
000Moda<C003o`000?lc<c?o<c<c01Co<c<c00?o0000oaTI6OlI6AT04OlI6AT>o`0000Cooooo0Ol0
0000037ooooo00Co0000ooooooooooooooooD_moOgl4o`0003SoIVIV00?o0000oda<C?m<C4`06om<
C4`00ol0003o<c<coc<c<`0Doc<c<`03o`000?lI6AWo6ATI013o6ATI3_l00004ooooo`7o0000000a
ooooo`04o`000?oooooooooooooooeKoOgmo1Ol0000dofIVIP;o00007?m<C4`00ol0003o<c<coc<c
<`0Coc<c<`03o`000?lI6AWo6ATI013o6ATI3_l00004ooooo`7o0000000aooooo`04o`000?oooooo
oooooooooe_oOgmo0ol0000cofIVIP03o`000?m<C4coC4a<01[oC4a<00?o0000oc<c<olc<c<04olc
<c<00ol0003o6ATIoaTI6@0?oaTI6@ko00001?ooool1o`000000<Oooool01?l0003ooooooooooooo
oomNogmoO`Co0000<?mVIVH2o`0001_oC4a<00?o0000oc<c<olc<c<04_lc<c<00ol0003o6ATIoaTI
6@0?oaTI6@ko00001?ooool1o`000000<Oooool01?l0003ooooooooooooooomRogmoO`Co0000;_mV
IVH2o`0001[oC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0?oaTI6@ko00001?oo
ool1o`000000<Oooool01?l0003ooooooooooooooomVogmoO`?o0000;OmVIVH2o`0001WoC4a<00?o
0000oc<c<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0?oaTI6@go00001?ooool1o`000000<Oooool0
1?l0003ooooooooooooooomYogmoO`?o0000;?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?lc
<c?o<c<c013o<c<c00?o0000oaTI6OlI6AT03olI6AT=o`0000Cooooo0Ol00000037ooooo00Co0000
ooooooooooooooooK?moOgl3o`0002WoIVIV0_l0000Ioda<C003o`000?lc<c?o<c<c013o<c<c0_l0
000?oaTI6@go00001?ooool1o`000000<Oooool01?l0003ooooooooooooooom_ogmoO`?o0000:?mV
IVH2o`0001SoC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0003o6ATIoaTI6@0=oaTI6@go00001?oo
ool1o`000000<Oooool2o`0000;oooooL_moOgl3o`0002OoIVIV0_l0000Goda<C003o`000?lc<c?o
<c<c013o<c<c00?o0000oaTI6OlI6AT03OlI6AT<o`0000?ooooo0_l00000037ooooo00Co0000oooo
ooooooooooooMOmoOgl3o`0002KoIVIV0_l0000Eoda<C003o`000?lc<c?o<c<c013o<c<c00?o0000
oaTI6OlI6AT03OlI6AT<o`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooN?moOgl3
o`0002GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0@oc<c<`03o`000?lI6AWo
6ATI00co6ATI3?l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooog_oOgmo0ol0000S
ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000oc<c<olc<c<03olc<c<00ol0003o6ATIoaTI6@0=
oaTI6@_o00001?ooool1o`000000<Oooool01?l0003oooooooooooooool4o`0007[oOgmo0ol0000Q
ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000oc<c<olc<c<03olc<c<00ol0003o6ATIoaTI6@0<
oaTI6@_o00001?ooool1o`000000<Oooool01?l0003oooooooooooooool4oiVIVAko0000GomoOgl2
o`00023oIVIV0_l0000Doda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI6OlI6AT03?lI6AT;
o`0000Cooooo0Ol00000037ooooo00Co0000oooooooooooooooo8_nIVIT;o`0005KoOgmo0_l0000P
ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0<
oaTI6@_o00001?ooool1o`000000<Oooool01?l0003oooooooooooooool]oiVIV@co0000C?moOgl0
0ol0003oIVIVofIVIP0NofIVIP;o00004om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo
6ATI00_o6ATI2ol00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooocWoVIVI1_l00017
ogmoO`?o00007omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c00co<c<c00?o0000
oaTI6OlI6AT03?lI6AT:o`0000Cooooo0Ol00000037ooooo00Co0000oooooooooooooooo?onIVIT7
o`0004?oOgmo0ol0000MofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<03?lc<c<2
o`0000co6ATI2_l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooodKoVIVI1?l00012
ogmoO`;o00006omVIVH2o`0001;oC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0:
oaTI6@[o00001?ooool1o`000000<Oooool01?l0003ooooooooooooooom:oiVIV@Ko0000?_moOgl2
o`0001_oIVIV00?o0000oda<C?m<C4`04?m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo
6ATI00Wo6ATI2_l00004ooooo`7o0000000aooooo`04o`000?oooooooooooooooe3oVIVI1_l0000j
ogmoO`;o00006_mVIVH2o`00017oC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@09
oaTI6@[o00001?ooool1o`000000<Oooool01?l0003ooooooooooooooomFoiVIV@Ko0000=_moOgl2
o`0001[oIVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo
6ATI00[o6ATI2Ol00004ooooo`7o0000000aooooo`04o`000?oooooooooooooooecoVIVI1_l0000b
ogmoO`;o00006OmVIVH2o`00013oC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@09
oaTI6@Wo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooomRoiVIV@Co0000<?moOgl2
o`0001WoIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo
6ATI00Wo6ATI2Ol00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooofKoVIVI0ol0000_
ogmoO`;o00006?mVIVH00ol0003oC4a<oda<C00=oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000
oaTI6OlI6AT02?lI6AT9o`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooJOnIVIT4
o`0002goOgmo0_l0000GofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc<c<02_lc<c<0
0ol0003o6ATIoaTI6@08oaTI6@Wo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooom]
oiVIV@Go0000:_moOgl2o`0001KoIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c<`0:
oc<c<`03o`000?lI6AWo6ATI00Oo6ATI2Ol00004ooooo`7o0000000aooooo`04o`000?oooooooooo
ooooog;oVIVI0ol0000YogmoO`;o00005OmVIVH2o`0000goC4a<00?o0000oc<c<olc<c<02_lc<c<0
0ol0003o6ATIoaTI6@08oaTI6@So00001?ooool1o`000000<Oooool01?l0003ooooooooooooooome
oiVIV@Co00009omoOgl2o`0001GoIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`09
oc<c<`03o`000?lI6AWo6ATI00So6ATI2?l00004ooooo`7o0000000aooooo`04o`000?oooooooooo
ooooogWoVIVI1Ol0000TogmoO`03o`000?mVIVKoIVIV01?oIVIV00?o0000oda<C?m<C4`02om<C4`0
0ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00Oo6ATI2?l00004ooooo`7o0000000aoooo
o`;o00000_oooomnoiVIV@?o00008_moOgl2o`0001CoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0
003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00Oo6ATI2?l00003ooooo`;o0000000aooooo`04
o`000?oooooooooooooooh7oVIVI0_l0000RogmoO`;o00004omVIVH00ol0003oC4a<oda<C00:oda<
C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT01_lI6AT8o`0000Cooooo0Ol00000037o
oooo00Co0000ooooooooooooooooPonIVIT3o`00027oOgmo0_l0000BofIVIP;o00002om<C4`00ol0
003o<c<coc<c<`08oc<c<`03o`000?lI6AWo6ATI00Oo6ATI1ol00004ooooo`7o0000000aooooo`04
o`000?ooooooooooooooohKoVIVI0ol0000PogmoO`;o00004_mVIVH00ol0003oC4a<oda<C009oda<
C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oaTI6OlI6AT01olI6AT7o`0000Cooooo0Ol00000037o
oooo00Co0000oooooooooooooooo8_l0001WoiVIV@?o00007omoOgl00ol0003oIVIVofIVIP0@ofIV
IP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02?lc<c<00ol0003o6ATIoaTI6@06oaTI
6@Oo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooolRok>c/a7o0000FOnIVIT3o`00
01goOgmo0_l0000AofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<01olc<c<00ol0
003o6ATIoaTI6@06oaTI6@Oo00001?ooool1o`000000<Oooool01?l0003ooooooooooooooolcok>c
/`co0000D?nIVIT3o`0001coOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<oda<C008oda<
C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oaTI6OlI6AT01_lI6AT6o`0000Cooooo0Ol00000037o
oooo00Co0000oooooooooooooooo?onc/k<;o`0004SoVIVI0ol0000JogmoO`;o00004?mVIVH00ol0
003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oaTI6OlI6AT01_lI6AT6o`00
00Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooB_nc/k<6o`0004GoVIVI0ol0000Iogmo
O`;o00003_mVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oaTI
6OlI6AT01OlI6AT6o`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooD?nc/k<6o`00
04;oVIVI0_l0000IogmoO`;o00003OmVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c
00Ko<c<c00?o0000oaTI6OlI6AT01OlI6AT6o`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
ooooooooE_nc/k<:o`0003[oVIVI0ol0000HogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`02?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?lI6AWo6ATI00Go6ATI1_l00004oooo
o`7o0000000aooooo`04o`000?ooooooooooooooof3o/k>c1ol0000foiVIV@?o00005_moOgl2o`00
00coIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?lI6AWo6ATI
00Co6ATI1_l00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooofOo/k>c1_l0000coiVI
V@?o00005OmoOgl2o`0000_oIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`05oc<c
<`03o`000?lI6AWo6ATI00Co6ATI1_l00004ooooo`7o0000000aooooo`04o`000?oooooooooooooo
ofgo/k>c1_l0000`oiVIV@;o00005OmoOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<
00OoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003o6ATIoaTI6@03oaTI6@Ko00001?ooool1o`00
0000<Oooool01?l0003ooooooooooooooomcok>c/`Ko0000;?nIVIT2o`0001CoOgmo0_l0000:ofIV
IP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003o6ATIoaTI6@03oaTI
6@Ko00001?ooool1o`000000<Oooool01?l0003ooooooooooooooomiok>c/`Ko0000:?nIVIT2o`00
01CoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000oaTI6OlI6AT00olI6AT5o`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
ooooooooOonc/k<4o`0002KoVIVI0ol0000BogmoO`;o00002OmVIVH00ol0003oC4a<oda<C006oda<
C003o`000?lc<c?o<c<c00Co<c<c00?o0000oaTI6OlI6AT00olI6AT5o`0000Cooooo0Ol00000037o
oooo00Co0000ooooooooooooooooPonc/k<3o`0002KoVIVI0ol0000AogmoO`03o`000?mVIVKoIVIV
00OoIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?lI6AWo6ATI
00;o6ATI1Ol00004ooooo`7o0000000aooooo`04o`000?ooooooooooooooohKo/k>c1?l0000UoiVI
V@;o00004?moOgl2o`0000SoIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?lI6AWo6ATI00;o6ATI1Ol00004ooooo`7o0000000aooooo`04o`000?oooooooooooooo
oh[o/k>c1_l0000QoiVIV@;o00004?moOgl00ol0003oIVIVofIVIP06ofIVIP;o00001_m<C4`00ol0
003o<c<coc<c<`03oc<c<`03o`000?lI6AWo6ATI00;o6ATI1Ol00004ooooo`7o0000000aooooo`04
o`000?oooooooooooooooi3o/k>c1Ol0000NoiVIV@;o00003omoOgl00ol0003oIVIVofIVIP07ofIV
IP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003o6ATIoaTI6@02oaTI
6@Co00001?ooool1o`000000<Oooool01?l0003ooooooooooooooonEok>c/`?o00007OnIVIT3o`00
00goOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c
00?o<c<c00?o0000oaTI6OlI6AT00_lI6AT4o`0000Cooooo0Ol00000037ooooo00Co0000oooooooo
ooooooooV?nc/k<6o`0001[oVIVI0ol0000;ogmoO`?o00001omVIVH00ol0003oC4a<oda<C003oda<
C003o`000?lc<c?o<c<c00?o<c<c00Co0000oaTI6OlI6AWo6ATI1?l00004ooooo`7o0000000aoooo
o`;o00000_oooolEok>c/`Oo0000P_nc/k<4o`0001WoVIVI0_l0000<ogmoO`03o`000?mVIVKoIVIV
00CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`03oc<c<`04o`000?lI6AWo6ATI
oaTI6@Co00000oooool2o`000000<Oooool01?l0003ooooooooooooooolEo`0000Ooc<c<2ol00005
ok>c/`Oo0000Konc/k<4o`0001OoVIVI0_l0000;ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000
oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`02oc<c<`04o`000?lI6AWo6ATIoaTI6@Co00001?oo
ool1o`000000<Oooool01?l0003ooooooooooooooolWolc<c0Go00001oo<c<`<o`0000Go/k>c1_l0
001Lok>c/`?o00005_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<
C002oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oaTI6OlI6AT01?l00004ooooo`7o0000000a
ooooo`04o`000?ooooooooooooooocooc<c<1Ol00006olc<c0Ko0000FOnc/k<3o`0001GoVIVI0_l0
0009ogmoO`;o00001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00;o<c<c00Co
0000oaTI6OlI6AWo6ATI0ol00004ooooo`7o0000000aooooo`04o`000?oooooooooooooooe3oc<c<
4_l0001:ok>c/`?o00005?nIVIT2o`0000WoOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<
oda<C002oda<C003o`000?lc<c?o<c<c00;o<c<c00Co0000oaTI6OlI6AWo6ATI0ol00004ooooo`7o
0000000aooooo`04o`000?ooooooooooooooof;oc<c<2ol00012ok>c/`Co00004_nIVIT00ol0003o
OgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`00_m<C4`01Ol0003o
<c<coc<c<olc<c?o000000?o6ATI0ol00004ooooo`7o0000000aooooo`04o`000?oooooooooooooo
ofgoc<c<3?l0000jok>c/`Go00003_nIVIT2o`0000SoOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0
003oC4a<oda<C002oda<C005o`000?lc<c?o<c<coc<c<ol000000_lI6AT3o`0000Cooooo0Ol00000
037ooooo00Co0000ooooooooooooooooNOo<c<`6o`0003Wo/k>c0ol0000=oiVIV@;o00001omoOgl0
0ol0003oIVIVofIVIP02ofIVIP05o`000?m<C4coC4a<oda<C?l000000olc<c<00ol0003o6ATIoaTI
6@03o`0000Cooooo0Ol00000037ooooo00Co0000ooooooooooooooooOoo<c<`;o`00037o/k>c0ol0
000<oiVIV@;o00001_moOgl2o`0000?oIVIV00Go0000oda<C?m<C4coC4a<o`000002oc<c<`03o`00
0?lI6AWo6ATI00?o00001?ooool1o`000000<Oooool01?l0003ooooooooooooooon:olc<c0co0000
:?nc/k<3o`0000_oVIVI0_l00006ogmoO`05o`000?mVIVKoIVIVofIVI_l000000_m<C4`01?l0003o
<c<coc<c<ol00003oaTI6@;o00001?ooool1o`000000<Oooool01?l0003ooooooooooooooonFolc<
c0Ko00009Onc/k<3o`0000[oVIVI00?o0000ogmoOomoOgl01?moOgl01Ol0003oIVIVofIVI_mVIVKo
000000;oC4a<00Co0000oc<c<olc<c?o00000_lI6AT2o`0000Cooooo0Ol00000037ooooo00Co0000
ooooooooooooooooW?o<c<`6o`0002;o/k>c0_l00009oiVIV@?o00001?moOgl2o`0000;oIVIV00Ko
0000oda<C?m<C4co0000oc<c<ol00002oaTI6@;o00001?ooool1o`000000<Oooool01?l0003ooooo
oooooooooonRolc<c0_o00006Onc/k<2o`0000[oVIVI0_l00004ogmoO`;o000000CoIVIVo`000?m<
C4coC4a<0_l00002oaTI6@;o00001?ooool1o`000000<Oooool01?l0003ooooooooooooooon]olc<
c0Go00005_nc/k<2o`0000[oVIVI0_l00004ogmoO`08o`000?mVIVKo0000oda<C?l0003o<c<co`00
0?lI6AT2o`0000Cooooo0Ol00000037ooooo00Co0000oooooooooooooooo/_o<c<`3o`0001Go/k>c
0_l0000:oiVIV@;o00000omoOgl01?l0003oIVIVo`000?m<C4`2o`000003oaTI6Ol0003o000000Co
oooo0Ol00000037ooooo00Co0000oooooooooooooooo]Oo<c<`>o`0000Wo/k>c2Ol00003oiVIV@;o
00000_moOgl00ol0003oIVIVo`000002o`000003oaTI6Ol0003o000000Cooooo0Ol00000037ooooo
00Co0000oooooooooooooooo`oo<c<`3o`0000oo/k>c0ol00002oiVIV@03o`000?moOgooOgmo00?o
000000Co<c<co`000?l0003o00001?ooool1o`000000<Oooool01?l0003oooooooooooooooo6olc<
c0;o00004?nc/k<2o`000004oiVIVOl0003o0000ogmoO`Ko00001?ooool1o`000000<Oooool01?l0
003oooooooooooooool<olc<c0Oo00004?o<c<`4o`0001?oc<c<1?l0002:olc<c003o`000?nc/k?o
/k>c00Ko/k>c1Ol00004ok>c/`03o`000?nIVIWoVIVI00Go000000?o6ATIo`000?ooool00oooool1
o`000000<Oooool01?l0003oooooooooooooool<olc<c003o`000?oVi^Koi^KV00?oi^KV00?o0000
olc<c?o<c<`03Oo<c<`00ol0003oi^KVonKViP02onKViP?o00003oo<c<`00ol0003oi^KVonKViP02
onKViP?o00004?o<c<`4o`00017oc<c<1Ol0000Colc<c0Go0000A_o<c<`2o`0000Co/k>c0_l00005
olc<c0Co000000Co/k>co`000?l0003oVIVI0ol000000olc<c?o0000o`000004ooooo`7o0000000V
ooooo`Ko00001Oooool01?l0003oooooooooooooool;olc<c003o`000?oVi^Koi^KV00Goi^KV00?o
0000olc<c?o<c<`02oo<c<`00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00_oc<c<0_l0
0008onKViP03o`000?o<c<coc<c<00[oc<c<0ol00004onKViP?o00002oo<c<`3o`0000Goi^KV0_l0
000=olc<c0Co00001OoVi^H00ol0003oc<c<olc<c00;olc<c0Wo00003_o<c<`5o`0001?oc<c<1Ol0
0006olc<c004o`000?nc/k?o0000o`0000Soc<c<1Ol000000onc/k?o0000o`000005o`0000Cooooo
0Ol0000002Kooooo00?oV9RHo`000?o<c<`00_ooool00ol@413oooooooooo`03ooooo`04o`000?oo
ooooooooooooo`;o00002?o<c<`00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Woc<c<
00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c009olc<c003o`000?oVi^Koi^KV00Soi^KV
00?o0000olc<c?o<c<`02?o<c<`2o`0000[oi^KV00?o0000olc<c?o<c<`02?o<c<`00ol0003oi^KV
onKViP07onKViP;o00002_o<c<`00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00Woc<c<
00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c00:olc<c003o`000?oVi^Koi^KV00?oi^KV
1?l0000=olc<c0;o00001OoVi^H2o`0000Goc<c<00?o0000olc<c?o<c<`01Oo<c<`3o`0000?oi^KV
2_l00004ooooo`7o0000000Wooooo`03oiRHV?l0003oc<c<00Oooooo00Co0000oooooooooooooooo
0_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`0
2?o<c<`00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H0
2_oVi^H00ol0003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<c<`0
1oo<c<`00ol0003oi^KVonKViP0:onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H0
2_oVi^H00ol0003oc<c<olc<c007olc<c003o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`0
2?o<c<`00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00Soc<c<0_l00009onKViP03o`00
0?o<c<coc<c<00Soc<c<0_l00003onKViPCo000000?oi^KVo`000?o<c<`01?l000000olc<c?o0000
ooooo`03ooooo`7o0000000Xooooo`03ojVYZOl@413oc<c<00Kooooo0_l00002ooooo`?o/k>c00?o
0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00Koc<c<00?o
0000onKVi_oVi^H02ooVi^H00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00coi^KV00?o
0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP0<onKViP03o`000?o<c<coc<c<00Goc<c<00?o
0000onKVi_oVi^H02ooVi^H00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00coi^KV00?o
0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP0;onKViP03o`000?o<c<coc<c<00Koc<c<00?o
0000onKVi_oVi^H02_oVi^H00ol0003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV00[oi^KV00?o
0000olc<c?o<c<`01oo<c<`00ol0003oi^KVonKViP02o`0000Cooooo00?o0000onKVi_l000001_l0
0003ooooo`;o0000000Yooooo`03olc<c?l@413oc<c<00Gooooo00?o0000ooooooooool0jOooool1
o`000000:_ooool00onYZJWo<S8booooo`04ooooo`03o`000?oooooooooo0>Wooooo0Ol0000002_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Yooooo`7o0000000Vooooo`06o`00
0?n7QhOok^k^oooooomgMgOo<S8b1Oooool00ol0003oooooooooo`3Yooooo`7o0000000Vooooo`06
ojVYZOlb<S;o0000o`000?mEEEGok^k^1Oooool00ol0003oooooooooo`3Yooooo`7o0000000aoooo
o`03o`000?oooooooooo0>Wooooo0Ol00000037ooooo00Go0000ooooooooooooooooo`00000]oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo02_ooooo00Co0000oooooooooooooooo0Ol00000037ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooooooo0Ol0
0000037oooookOl000000?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7ooo
ool008;ooooo00Go8B4Qo`000?l0003oA4A4omgMg@2Gooooo`00QOooool00omgMgOo<S8booooo`2F
ooooo`00Q_ooool00ol0003oooooooooo`2Eooooo`00E?ooool2oeEEE@03oooooon7QhOo<S8b00?o
oooo00?o410@o`000?l000000ol000001_l@413oooooooooooooooooc<c<ob4Q8@;o000000GoEEEE
okZj^_oooooooooooa0@4002o`0000;ooooo0_l000000ol@413oooooooooo`09ooooo`06ohN7Qol@
413o0000oc8b<_oMgMgo00000_ooool6o`0000Cooooo00GoQhN7oa0@4?l0003o410@ohN7Q`04oooo
o`09olc<c?l@413o0000oa0@4?mgMgOo0000oa0@4?oooooo410@00;o00000_ooool2o`00000:oa0@
4?ooooooooooohN7Qol@413o0000ob4Q8OnYZJWo0000oa0@40;ooooo00KoMgMgoa0@4?l0003o410@
oeEEEOoMgMd3ooooo`07ohN7Qol@413o0000ob4Q8OnYZJWo0000oa0@400:ooooo`06oa0@4?lb<S;o
0000o`000?lQ8B7oc<c<0oooool00ol@413o0000o`000003o`00000;oa0@4?oooooooooooooooon7
QhOo410@o`000?lQ8B7oZJVYo`000?l@41000_ooool01_mgMgOo410@o`000?l@413oEEEEomgMg@;o
oooo00Ko410@oc8b<_l0003o0000ob4Q8Oo<c<`Sooooo`00E?ooool01_l0003o410@oooooolb<S;o
0000onk^kPGooooo00?o0000ooooooooool01?ooool01_l@413oQhN7ooooooo^k^koZJVYob4Q8@?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`07ohN7QolQ8B7oc<c<oooo
ooo<c<co8B4Qo`000004ooooo`03o`000?oooooooooo00Cooooo00OoQhN7ob4Q8Oo<c<coooooolc<
c?lQ8B7oQhN700?ooooo00Ko410@ogMgMoooooook^k^oeEEEOl00003ooooo`03o`000?oooooooooo
00;ooooo00[o0000ooooooooooooQhN7ob4Q8Oo<c<coooooolc<c?lQ8B7o00000_ooool01omgMgOo
A4A4omgMgOoooooogMgMohN7QolQ8B400_ooool01on7QhOo8B4Qolc<c?ooooooc<c<ob4Q8Ol00000
2oooool01_l0003oZJVYooooooooooooZJVYoa0@40Kooooo00?o0000ooooooooool00oooool01on7
QhOo8B4Qolc<c?ooooooc<c<ob4Q8Ol000000_ooool01omgMgOoA4A4omgMgOoooooogMgMohN7QolQ
8B400_ooool01_l0003oZJVYooooooooooooZJVYoa0@42?ooooo001Cooooo`07ojVYZOlb<S;oA4A4
oiRHV?lQ8B7oA4A4oiRHV005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o410@olc<c?ooool00_oo
ool00oo<c<co0000ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o410@olc<c?ooool00_oo
ool00oo<c<co410@ooooo`02ooooo`06o`000?ooooooooooooooooo^k^ko00000oooool00ol0003o
ooooooooo`02ooooo`05o`000?oooooooooooa0@4?o<c<`00oooool01_nj^[[o0000oooooooooooo
410@onk^kPOooooo00?o410@olc<c?ooool00_ooool00onj^[[o0000ooooo`0>ooooo`03olc<c?l0
003ooooo00Gooooo00?o0000ooooooooool00oooool00ol@413oc<c<ooooo`02ooooo`06okZj^_l0
003oooooooooool@413ok^k^2oooool00oo<c<co0000ooooo`0Rooooo`00Doooool01omEEEGoQhN7
oiRHV?l@413oMgMgoiRHV?m4A4@01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Oo00000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?oZJVYob4Q8Ol000000_l000000on7QhOooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07o`0000;ooooo00?oZJVYob4Q8Ol000000_l000000on7QhOoooooooooo`0Qooooo`00Dooo
ool01ol@413ogMgMonk^k_l0003oc<c<omgMgOl000001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Kooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`09ooooo`03
oa0@4?o<c<cooooo00;ooooo00?oc<c<o`000?ooool00oooool00ol0003ogMgMooooo`04ooooo`03
oa0@4?nj^[[ooooo00;ooooo00?o^[Zjoa0@4?ooool00_ooool00ol0003oooooooooo`02ooooo`06
o`000?ooooooooooooooool0003ok^k^0oooool01Ol0003oooooooooool@413oc<c<00?ooooo00Ko
c<c<o`000?oooooooooooa0@4?oMgMd3ooooo`06omgMgOl0003oooooooooool@413oc<c<0oooool0
0oo<c<co0000ooooo`0:ooooo`04o`000?nHV9So^[ZjokZj^PSooooo00?o0000ooooooooool00ooo
ool00ol@413oc<c<ooooo`02ooooo`06olc<c?l0003oooooooooool@413ogMgM0oooool01_oMgMgo
0000oooooooooooo0000oiRHV0;o^[Zj9Oooool005;ooooo00?oc<c<oa0@4?ooool01?ooool00olQ
8B7o^[Zjooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool01_l0
003oA4A4omgMgOooooooMgMgob4Q8@_ooooo00OoV9RHob4Q8Oo<c<coooooolc<c?lQ8B7o000000Co
oooo0_l000000onHV9Soooooooooo`02ooooo`07ohN7QolQ8B7oc<c<ooooooo<c<co8B4QohN7Q`03
ooooo`03o`000?oooooooooo00;ooooo00[o0000ooooooooooooooooo`000?m4A4CogMgMoooooomg
MgOo410@0_ooool01onYZJWo8B4Qolc<c?ooooooc<c<ob4Q8Ol000000_ooool01on7QhOo8B4QokZj
^_oooooogMgMob4Q8OmgMgL00_ooool01onYZJWo8B4Qolc<c?ooooooc<c<ob4Q8Ol000002oooool0
1_l0003o^[Zjooooooo^k^koMgMgo`0000Kooooo00?o0000ooooooooool00oooool01onYZJWo8B4Q
olc<c?ooooooc<c<ob4Q8Ol000000_ooool01on7QhOo8B4QokZj^_oooooogMgMob4Q8OmgMgL00_oo
ool01_l0003o^[Zjooooooo^k^koMgMgo`0002?ooooo001Booooo`03oa0@4?l0003o000000?ooooo
0ol00002ooooo`03oa0@4?l0003o000000Cooooo00?o410@o`000?l000000ol000000ol@413ooooo
ooooo`02ooooo`06o`000?mgMgOo410@o`000?lQ8B7oc<c<3?ooool02OnYZJWo410@o`000?l@413o
MgMgo`000?l@413ooooooa0@4002o`000005okZj^_m4A4Co0000o`000?lQ8B400_ooool01On7QhOo
410@o`000?l@413oQhN700?ooooo00Go410@o`000?oooooooooooa0@4002o`0000;ooooo00Oo410@
o`000?mgMgOo410@o`000?lQ8B7oc<c<00?ooooo00KoZJVYoa0@4?l0003o410@ohN7Qol00003oooo
o`05ohN7Qol@413o0000oa0@4?mgMgL01?ooool01_nYZJWo410@o`000?l@413oQhN7o`0000_ooooo
00Koc<c<ob4Q8Ol0003o0000oc8b<_l00004ooooo`03oa0@4?l0003o000000Kooooo00KoZJVYoa0@
4?l0003o410@ohN7Qol00003ooooo`05ohN7Qol@413o0000oa0@4?mgMgL00oooool01_o<c<co8B4Q
o`000?l0003o<S8bo`0002?ooooo001Vooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0<_ooool005oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0<_ooool005oooooo00?o410@ooooooooool01?oo
ool00ol@413oooooooooo`05ooooo`03oa0@4?l0003ooooo047ooooo0_l0000@ooooo`;o00005ooo
ool00ol@413oooooooooo`08ooooo`;o0000=?ooool00?oooooo7oooool00?oooooo7oooool00?oo
oooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool005Oooooo00?o^[Zjoc8b
<_ooool07_ooool00olb<S;o^[Zjooooo`13ooooo`05oa0@4?l0003o0000o`000?l@4100Foooool0
04cooooo00?o0000onk^k_ooool02?ooool00ol@413o^[Zjooooo`0=ooooo`03o`000?nj^[[ooooo
00kooooo00?o^[Zjob4Q8Oooool0AOooool00onHV9So<S8booooo`1Kooooo`00C?ooool00olb<S;o
^[Zjooooo`07ooooo`03okZj^_lb<S;ooooo00kooooo00?o8B4QoeEEEOooool03oooool00olb<S;o
^[Zjooooo`15ooooo`03oa0@4?oMgMgooooo05[ooooo001:ooooo`06onk^k_lb<S;o0000o`000?lb
<S;o^[Zj1_ooool00omEEEGoV9RHooooo`03ooooo`Ko00001Oooool00omVIVKo0000onk^kP05oooo
o`Ko00001?ooool00onHV9SoEEEEooooo`0=ooooo`03oa0@4?l0003o000000?o000000Co410@oooo
oooooooo410@0_l00002ooooo`;o000000?o410@ooooooooool02?ooool01onYZJWo410@o`000?lQ
8B7oV9RHoa0@4?l000003?ooool01_nYZJWo410@o`000?l0003oEEEEomgMg@Cooooo0_mEEED5oooo
o`03oa0@4?l0003o000000Co00000_ooool00ol@413o0000o`000003o`000004oa0@4?oooooooooo
oa0@40;o00000_ooool2o`00000:oa0@4?ooooooooooohN7Qol@413o0000ob4Q8OnYZJWo0000oa0@
40;ooooo00KoMgMgoa0@4?l0003o410@oeEEEOoMgMd2ooooo`Ko00008oooool004[ooooo00OoA4A4
ohN7QomgMgOoMgMgokZj^_l0003oc<c<00Gooooo00?o410@olc<c?ooool01Oooool00ol0003ooooo
ooooo`06ooooo`03oiRHV?l0003oMgMg00Gooooo00?oV9RHoeEEEOooool00_ooool00ol0003ooooo
ooooo`02ooooo`03omgMgOl@413ooooo013ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Ko0000okZj^_oooooogMgMogMgMol0000<oooo
o`03ojVYZOlQ8B7o^[Zj00;ooooo00?o^[Zjob4Q8Oooool00_ooool01?oMgMgo410@ob4Q8OoMgMd7
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`0:o`000?ooooooooooohN7QolQ8B7oc<c<ooooooo<c<co8B4Qo`0000;ooooo00OoMgMgodA4
A?oMgMgoooooomgMgOn7QhOo8B4Q00Cooooo00?o0000ooooooooool09?ooool004[ooooo00Oo0000
oooooonj^[[o<S8boooooonHV9SoA4A400Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03omgMgOl0003o410@00Kooooo00?oV9RHoeEEEOooool01oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`09ooooo`06oa0@4?n7QhOok^k^oooooooMgMgo00003?ooool00ol@413o^[Zjooooo`07oooo
o`04oeEEEOmgMgOoV9RHoeEEE@Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo410@olc<c003ooooo`06okZj^_l0
003oooooooooool@413ok^k^2Oooool00ol0003oooooooooo`0Tooooo`00B_ooool01?l0003ooooo
onk^k_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0@ooooo`03oiRHV?mEEEGooooo00Kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01_o<c<co
A4A4o`000?l0003o410@o`0000cooooo00?o0000ooooooooool01_ooool01_o^k^ko410@onk^k_oo
oooo0000omgMg@Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`07o`0000Co
oooo00?o0000ooooooooool09?ooool004[ooooo00OoA4A4ojVYZOoooooo410@omgMgOo^k^ko0000
00Gooooo00?o410@olc<c?ooool01Oooool00ol0003ogMgMooooo`0Aooooo`03oiRHV?mEEEGooooo
00Cooooo00?ogMgMoa0@4?ooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?o^k^kooooo
00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03oa0@4?nj^[[ooooo
00Kooooo00KoMgMgoeEEEOooooooooooogMgMomVIVH6ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01?ooool00ol0003ok^k^ooooo`02ooooo`05o`000?oooooooooooa0@4?o<c<`0
0oooool01_o<c<co0000oooooooooooo410@omgMg@?ooooo00?ogMgMo`000?ooool00oooool00ol0
003ogMgMooooo`0Tooooo`00B_ooool01onj^[[o0000okZj^_m4A4CoV9RHoeEEEOm4A4@01Oooool0
0omEEEGoQhN7ooooo`05ooooo`;o000000?oV9RHooooooooool03?ooool01_l0003ooooooooooooo
ooooV9RHoeEEE@Cooooo00?oV9RHoeEEEOooool04?ooool00ol0003oooooooooo`04ooooo`06o`00
0?m4A4CogMgMoooooomgMgOo410@3oooool00on7QhOo<S8booooo`0;ooooo`07ojVYZOlQ8B7o^[Zj
ooooooo^k^koQhN7o`000002ooooo`07o`000?oMgMgoooooooooooo^k^ko0000onk^kP05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool01_l0003oA4A4omgMgOooooooMgMg
oa0@40;ooooo00OoZJVYob4Q8Oo<c<coooooolc<c?lQ8B7o000000;ooooo00OoQhN7ob4Q8Onj^[[o
ooooomgMgOlQ8B7oMgMg00Cooooo0_l000000onHV9Soooooooooo`0Rooooo`00Boooool01_nj^[[o
8B4Qo`000?l0003o<S8bonk^kPGooooo00?o^[Zjoa0@4?ooool00oooool01Ol@413o0000o`000?nj
^[[oA4A400;o000000?o8B4Qooooooooool02Oooool6o`0000Cooooo00?o8B4QokZj^_ooool03_oo
ool00ol@413o0000o`000005ooooo`07oa0@4?l0003oMgMgoa0@4?l0003o8B4Qolc<c00<ooooo`05
odA4A?l0003o0000oa0@4?o<c<`03Oooool02?nYZJWo8B4Qo`000?l0003oA4A4o`000?oooooo410@
0_l00002ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`04ooooo`03oa0@
4?l0003o000000Gooooo00Oo410@o`000?mgMgOo410@o`000?lQ8B7oc<c<00?ooooo00KoZJVYoa0@
4?l0003o410@ohN7Qol00003ooooo`05ohN7Qol@413o0000oa0@4?mgMgL00oooool01Ol@413o0000
o`000?nj^[[oA4A400;o000000?o8B4Qooooooooool07oooool004gooooo00?oV9RHodA4A?ooool0
1oooool00olb<S;o^[Zjooooo`0Nooooo`03okZj^_lQ8B7ooooo053ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0booooo`00COooool00ooMgMgo410@ooooo`07ooooo`03okZj^_lb
<S;ooooo01kooooo00?o<S8bokZj^_ooool04Oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0booooo`00S?ooool0
0ol@413oooooooooo`0jooooo`03oa0@4?l0003o000000Sooooo00?o410@ooooooooool04Oooool2
o`0003Cooooo003ooooooaoooooo003ooooooaoooooo003ooooooaoooooo003ooooooaoooooo003o
oooooaoooooo003ooooooaoooooo003ooooooaoooooo003ooooooaoooooo003ooooooaoooooo003o
oooooaoooooo003ooooooaoooooo003ooooooaoooooo003ooooooaoooooo003ooooooaoooooo003o
oooooaoooooo003ooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 285.75}, {572.562, 0}} -> {-0.237699, -0.249309, \
0.00660646, 0.00660646}}]
}, Open  ]],

Cell["\<\
There is a Gibbs phenomenon near the top of the cylinder, because \
of the discontinuity in the potential between the top and the grounded sides. \
 However, this phenomenon dies away rapidly with distance from the top, \
leaving a well-behaved solution for the potential in the cylinder.\
\>", \
"Text",
  CellTags->"i:91"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Nonzero Potential on the Cylinder Sides: Modified Bessel \
Functions\
\>", "Section",
  CellTags->"c:42"],

Cell[TextData[{
  "We now consider the solution to the Laplace equation for a potential \
applied only to the sides of a cylinder of finite length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " and radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](a, \[Theta], z) = \(\[Phi]\_A\)(\[Theta], 
          z)\)]],
  ".  On the ends of the cylinder at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z = L\)]],
  ", the boundary conditions are ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = 0\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThis problem is still solved by a sum of terms of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(R(
          r)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\)\ \(Z(
          z)\)\)]],
  ". Furthermore, separation of variables implies that  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(R(r)\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Z(z)\)]],
  " are still governed by the same  ODEs, Eqs. ",
  ButtonBox["(3.2.43)",
    ButtonData:>"(3.2.43)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.2.45)",
    ButtonData:>"(3.2.45)",
    ButtonStyle->"Hyperlink"],
  ", with the same general solutions, Eqs. ",
  ButtonBox["(3.2.45)",
    ButtonData:>"(3.2.45)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.2.49)",
    ButtonData:>"(3.2.49)",
    ButtonStyle->"Hyperlink"],
  ".  However, the boundary conditions dictate that the coefficients in these \
general solutions must be chosen differently than in the previous case. "
}], "Text"],

Cell[TextData[{
  "\t In order to satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta], 0) = 0\)]],
  ", we require that ",
  Cell[BoxData[
      \(TraditionalForm\`B = \(-A\)\)]],
  " in Eq. ",
  ButtonBox["(3.2.45)",
    ButtonData:>"(3.2.45)",
    ButtonStyle->"Hyperlink"],
  ",  and in order to satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta], L) = 0\)]],
  ", we require that"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^2 = \(-\((n\ \[Pi]/L)\)\^2\)\)]],
  ","
}], "NE2",
  CellTags->"(3.2.58)"],

Cell[TextData[{
  " so that ",
  Cell[BoxData[
      \(TraditionalForm\`Z(z)\  = \ 
        2\ A\ \[ImaginaryI]\ \(sin(n\ \[Pi]\ z/L)\)\)]],
  ".   Now the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-equation has provided us with eigenmodes and eigenvalues, and they are \
standard trigonometric Fourier modes. "
}], "Text"],

Cell[TextData[{
  "\t The radial solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(R(r)\)\(\ \)\)\)]],
  " is still given by Eq. ",
  ButtonBox["(3.2.49)",
    ButtonData:>"(3.2.49)",
    ButtonStyle->"Hyperlink"],
  " but with the imaginary value of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Kappa]\)\(\ \)\)\)]],
  " given in Eq. ",
  ButtonBox["(3.2.58)",
    ButtonData:>"(3.2.58)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`R(r)\  = \ 
        C\ \(\(J\_m\)(\[ImaginaryI]\ n\ \[Pi]\ r/L\ )\)\  + \ 
          D\ \(\(Y\_m\)(\[ImaginaryI]\ n\ \[Pi]\ r/L)\)\)]]
}], "NE2",
  CellTags->"(3.2.59)"],

Cell[TextData[{
  " Bessel functions of an imaginary argument are called ",
  StyleBox["modified Bessel functions, ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`I\_m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`K\_m\)]],
  ".",
  " These functions are defined below for integer ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ":"
}], "Text",
  CellTags->"i:88"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(I\_m\)(
          x)\  = \ \(\[ImaginaryI]\^\(-m\)\) \(\(J\_m\)(\[ImaginaryI]\ \
x)\)\)]],
  " (for integer ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ");\n",
  Cell[BoxData[
      \(TraditionalForm\`\(K\_m\)(
          x) = \(\(\(\[Pi]\)\(\ \)\(\[ImaginaryI]\^\(m + 
                      1\)\)\(\ \)\)\/2\)[\(J\_m\)(\[ImaginaryI]\ x)\  + \ \
\[ImaginaryI]\ \(\(Y\_m\)(\[ImaginaryI]\ x)\)\ ]\)]],
  " (for integer ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ").  "
}], "NE2",
  CellTags->"(3.2.60)"],

Cell[TextData[{
  "The modified Bessel functions bear a similar relation to ",
  Cell[BoxData[
      \(TraditionalForm\`J\_m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_m\)]],
  " to the one the hyperbolic functions ",
  Cell[BoxData[
      FormBox[
        FormBox["sinh",
          "TraditionalForm"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[Cell["cosh"], TraditionalForm]]],
  " bear to the trigonometric functions ",
  Cell[BoxData[
      FormBox[Cell["sin"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[Cell["cos"], TraditionalForm]]],
  ". In ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " these functions are called ",
  StyleBox["BesselI[m,x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and\n",
  StyleBox["BesselK[m,x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The first few modified Bessel functions are plotted in Cells ",
  ButtonBox["3.38",
    ButtonData:>"Cell 3.38",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["3.39",
    ButtonData:>"Cell 3.39",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:89"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(Plot[{BesselI[0, x], BesselI[1, x], BesselI[2, x]}, {x, 0, 4}, 
        PlotStyle \[Rule] {Red, \ Green, Blue}, 
        PlotLabel \[Rule] \*"\"\<\!\(I\_m\)(r) for m=0,1,2\>\"", 
        AxesLabel \[Rule] {"\<x\>", "\<\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.38"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 0.05208 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .11888 -6 -4.5 ]
[.01131 .11888 0 4.5 ]
[.01131 .22304 -6 -4.5 ]
[.01131 .22304 0 4.5 ]
[.01131 .32719 -6 -4.5 ]
[.01131 .32719 0 4.5 ]
[.01131 .43135 -6 -4.5 ]
[.01131 .43135 0 4.5 ]
[.01131 .53551 -12 -4.5 ]
[.01131 .53551 0 4.5 ]
[.5 .63053 -52.75 0 ]
[.5 .63053 52.75 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(1)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(2)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(3)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(4)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .11888 m
.03006 .11888 L
s
[(2)] .01131 .11888 1 0 Mshowa
.02381 .22304 m
.03006 .22304 L
s
[(4)] .01131 .22304 1 0 Mshowa
.02381 .32719 m
.03006 .32719 L
s
[(6)] .01131 .32719 1 0 Mshowa
.02381 .43135 m
.03006 .43135 L
s
[(8)] .01131 .43135 1 0 Mshowa
.02381 .53551 m
.03006 .53551 L
s
[(10)] .01131 .53551 1 0 Mshowa
.125 Mabswid
.02381 .04076 m
.02756 .04076 L
s
.02381 .0668 m
.02756 .0668 L
s
.02381 .09284 m
.02756 .09284 L
s
.02381 .14492 m
.02756 .14492 L
s
.02381 .17096 m
.02756 .17096 L
s
.02381 .197 m
.02756 .197 L
s
.02381 .24908 m
.02756 .24908 L
s
.02381 .27512 m
.02756 .27512 L
s
.02381 .30115 m
.02756 .30115 L
s
.02381 .35323 m
.02756 .35323 L
s
.02381 .37927 m
.02756 .37927 L
s
.02381 .40531 m
.02756 .40531 L
s
.02381 .45739 m
.02756 .45739 L
s
.02381 .48343 m
.02756 .48343 L
s
.02381 .50947 m
.02756 .50947 L
s
.02381 .56155 m
.02756 .56155 L
s
.02381 .58759 m
.02756 .58759 L
s
.02381 .61363 m
.02756 .61363 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -113.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(I) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.375 13.000 moveto
(H) show
80.375 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.375 13.000 moveto
(L) show
98.375 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(for) show
122.375 13.000 moveto
(m) show
128.500 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
140.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
146.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
152.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
158.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
164.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .0668 m
.02499 .0668 L
.02605 .0668 L
.02729 .0668 L
.02846 .0668 L
.03053 .06681 L
.03279 .06681 L
.03527 .06683 L
.0379 .06684 L
.04262 .06688 L
.04749 .06692 L
.05205 .06698 L
.06244 .06714 L
.07305 .06735 L
.08274 .0676 L
.10458 .0683 L
.12357 .06911 L
.14429 .07018 L
.18493 .07293 L
.22406 .07642 L
.26565 .08112 L
.30571 .08671 L
.34426 .09319 L
.38527 .10141 L
.42475 .1108 L
.46273 .12137 L
.50315 .13454 L
.54206 .14934 L
.58342 .16771 L
.62326 .18839 L
.66159 .21147 L
.70238 .24002 L
.74164 .27199 L
.77939 .30756 L
.8196 .35147 L
.85828 .40052 L
.89942 .46123 L
.93905 .52939 L
.97619 .60332 L
s
0 1 0 r
.02381 .01472 m
.06244 .01895 L
.10458 .02368 L
.14415 .0283 L
.18221 .03302 L
.22272 .03842 L
.26171 .04412 L
.30316 .05083 L
.34309 .05809 L
.3815 .06596 L
.42237 .07546 L
.46172 .08592 L
.49955 .09741 L
.53984 .11145 L
.57861 .12702 L
.61984 .14618 L
.65954 .16761 L
.69774 .19143 L
.73838 .22083 L
.77751 .25374 L
.81909 .2945 L
.85916 .3404 L
.89771 .39173 L
.93871 .45535 L
.97619 .52299 L
s
0 0 1 r
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.03053 .01472 L
.03279 .01472 L
.03527 .01473 L
.0379 .01474 L
.04262 .01476 L
.04749 .01478 L
.05205 .01481 L
.06244 .01489 L
.07305 .01499 L
.08274 .01512 L
.10458 .01547 L
.12357 .01587 L
.14429 .01642 L
.18493 .01781 L
.22406 .0196 L
.26565 .02203 L
.30571 .02495 L
.34426 .02839 L
.38527 .03282 L
.42475 .03794 L
.46273 .04381 L
.50315 .05122 L
.54206 .05969 L
.58342 .07037 L
.62326 .08259 L
.66159 .09643 L
.70238 .11381 L
.74164 .13357 L
.77939 .15585 L
.8196 .18373 L
.85828 .21529 L
.89942 .25485 L
.93905 .29983 L
.97619 .34918 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003ooooooona
ooooo`00oooooonaooooo`00oooooonaooooo`00M_ooool4o`000003oa0@4?oooooooooo057ooooo
1_l0001Cooooo`06ojVYZOlQ8B7o0000o`000?mEEEGok^k^E_ooool2o`000003oa0@4?oooooooooo
02Sooooo001hooooo`03o`000?oooooooooo05?ooooo00?oV9RHo`000?o<c<`00_ooool00ol@413o
ooooooooo`1Aooooo`06oa0@4?nYZJWooooooooooomgMgOo<S8bEoooool00ol0003oooooooooo`0Y
ooooo`00N?ooool00ol0003oooooooooo`1Dooooo`03oiRHV?l0003oc<c<05[ooooo00?o0000oooo
ooooool0DOooool6o`0002[ooooo001hooooo`03o`000?oooooooooo05Gooooo00?oZJVYoa0@4?o<
c<`0F?ooool00omgMgOo8B4Qooooo`1Booooo`05ofIVI_nYZJWoooooooooool00000:oooool007So
oooo00?o0000ooooooooool0E_ooool00oo<c<co410@olc<c01Eooooo`04ob4Q8Ol0003o0000okZj
^U?ooooo00Gok^k^ob4Q8Oo^k^koooooo`00000[ooooo`00N?ooool00ol0003oooooooooo`1Goooo
o`03ojVYZOlb<S;ooooo05Gooooo00?ok^k^ogMgMolb<S80E?ooool01?nYZJWoIVIVooooool0000[
ooooo`00N?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool0Doooool00om4A4Coc<c<o`00000[ooooo`00M_ooool00ol0003oA4A4o`00001Eooooo`06
o`000?n7QhOok^k^oooooomgMgOo<S8bDoooool01_lQ8B7oQhN7ooooooooooooIVIVoc8b<UGooooo
00?ogMgModA4A?l00000:oooool007Kooooo00?oc<c<oeEEEOl00000EOooool01_nYZJWo<S8bo`00
0?l0003oEEEEonk^kU?ooooo00Ko^[ZjodA4A?l0003o0000odA4A?o^k^iFooooo`03ohN7Qol0003o
oooo02[ooooo000Pooooo`03o`000?oooooooooo0?ooooooS_ooool0023ooooo00?o0000oooooooo
ool0oooooon>ooooo`008?ooool00ol0003oooooooooo`3oooooogSooooo00Oo410@o`000?l@413o
oooooa0@4?l0003o410@00oooooo000Pooooo`03o`000?oooooooooo0?ooooooNOooool01_lb<S;o
QhN7oooooonj^[[o0000onk^kPoooooo000Pooooo`03o`000?oooooooooo0?ooooooNOooool01Oo^
k^ko8B4Qolc<c?lQ8B7oc<c<013ooooo000Pooooo`03o`000?oooooooooo0?ooooooN_ooool00onj
^[[o0000ohN7Q`0Aooooo`005oooool9o`0003Ko003oool0000ho`0000kooooo00Gok^k^oc8b<_o<
c<co<S8bonk^kP0@ooooo`008?ooool00ol0003oooooooooo`06ooooo`_o0?l04?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?l00?oo003o00go003o0_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01Gooooo00GoEEEEogMgMoooooooQhN7oeEEE@0@ooooo`008?ooool00ol0003o
ooooooooo`0Aooooo`Oo0?l0:_ooool?o`00o`Gooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool05?ooool01ol@413o
0000oa0@4?oooooo410@o`000?l@41003oooool0023ooooo00?o0000ooooooooool06?ooool8o`3o
037ooooo3ol00?ooooooobkooooo000Pooooo`03o`000?oooooooooo023ooooo1ol0o`0iooooo`oo
003ooooooolOooooo`008?ooool00ol0003oooooooooo`0Wooooo`So0?l0@?ooool;o`00oooooooo
5?ooool0023ooooo00?o0000ooooooooool0;oooool7o`3o04Cooooo1ol00?ooooooo`gooooo000P
ooooo`03o`000?oooooooooo03Kooooo1ol0o`14ooooo`co003oooooool1ooooo`008?ooool00ol0
003oooooooooo`0mooooo`Oo0?l0BOooool9o`00ooOooooo000Pooooo`03o`000?oooooooooo04Co
oooo2?l0o`1:ooooo`Go003ol_ooool0023ooooo0_l0001=ooooo`Oo0?l0B?ooool5o`00ongooooo
000Pooooo`03o`000?oooooooooo05?ooooo2?l0o`15ooooo`Ko003oioooool0023ooooo00?o0000
ooooooooool0Foooool7o`3o04Cooooo1ol00?oPooooo`008?ooool00ol0003oooooooooo`1Roooo
o`Oo0?l0A?ooool6o`00om[ooooo000Pooooo`03o`000?oooooooooo06Wooooo1Ol0o`15ooooo`?o
003oeoooool0023ooooo00?o0000ooooooooool0K_ooool5o`3o04?ooooo1?l00?oCooooo`008?oo
ool00ol0003oooooooooo`1cooooo`Go0?l0@_ooool3o`00om3ooooo000Pooooo`03o`000?oooooo
oooo07Sooooo1Ol0o`10ooooo`Co003oc?ooool0023ooooo00?o0000ooooooooool0OOooool5o`3o
03oooooo1?l00?o8ooooo`008?oooolEool0073ooooo1Ol0o`0nooooo`Co003oa?ooool0023ooooo
00?o0000ooooooooool04_oooolMool005Sooooo1Ol0o`0mooooo`Co003o`?ooool0023ooooo00?o
0000ooooooooool0;oooool7ool005Kooooo1Ol0o`0looooo`Co003o_?ooool0023ooooo00?o0000
ooooooooool0=_ooool<ool004oooooo1?l0o`0looooo`Co003o^?ooool0023ooooo00?o0000oooo
ooooool0@_ooool;ool004Sooooo0ol0o`0mooooo`?o003o]Oooool0023ooooo00?o0000oooooooo
ool0COooool7ool004Cooooo1?l0o`0looooo`Co003o/Oooool0023ooooo00?o0000ooooooooool0
E?ooool8ool0043ooooo0ol0o`0mooooo`?o003o[_ooool0023ooooo00?o0000ooooooooool0G?oo
ool7ool003cooooo1?l0o`0looooo`?o003oZoooool0023ooooo00?o0000ooooooooool0Hoooool8
ool003Sooooo0ol0o`0looooo`?o003oZ?ooool0023ooooo00?o0000ooooooooool0Joooool7ool0
03Cooooo0ol0o`0looooo`?o003oYOooool0023ooooo0_l0001cooooo`Ooo`00<?ooool3o`3o03co
oooo0ol00?nRooooo`008?ooool00ol0003oooooooooo`1iooooo`Goo`00;_ooool3o`3o03cooooo
0_l00?nPooooo`008?ooool00ol0003oooooooooo`1nooooo`Goo`00;?ooool3o`3o03_ooooo0_l0
0?nNooooo`008?ooool00ol0003oooooooooo`23ooooo`Coo`00:oooool3o`3o03[ooooo0_l00?nL
ooooo`008?ooool00ol0003oooooooooo`27ooooo`Coo`00:_ooool3o`3o03Wooooo0ol00?nIoooo
o`008?ooool00ol0003oooooooooo`2;ooooo`?oo`00:_ooool3o`3o03Wooooo0_l00?nGooooo`00
8?ooool00ol0003oooooooooo`2>ooooo`Coo`00:Oooool3o`3o03Sooooo0_l00?nEooooo`004ooo
ool6o`0000Oooooo00?o0000ooooooooool0T_ooool4ool002Sooooo0_l0o`0hooooo`;o003oTooo
ool001?ooooo00?oV9RHo`000?o<c<`00_ooool00ol@413oooooooooo`05ooooo`03o`000?oooooo
oooo09Kooooo0ooo000Wooooo`?o0?l0=oooool2o`00oi7ooooo000Dooooo`03oiRHV?l0003oc<c<
00Wooooo00?o0000ooooooooool0VOooool4ool002Kooooo0_l0o`0gooooo`;o003oSoooool001Go
oooo00?oZJVYoa0@4?o<c<`02?ooool3o`0009gooooo0ooo000Uooooo`;o0?l0=oooool2o`00ohgo
oooo000Fooooo`03olc<c?l@413oc<c<00Oooooo00?o0000ooooooooool0X?ooool4ool002?ooooo
0ol0o`0fooooo`?o003oR_ooool001Oooooo00?oZJVYoc8b<_ooool01_ooool00ol0003ooooooooo
o`2Tooooo`Coo`008_ooool2o`3o03Oooooo0_l00?n8ooooo`006?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0:Sooooo0ooo000Qooooo`;o0?l0=oooool2o`00ohKooooo000Coooo
o`06o`000?n7QhOok^k^oooooomgMgOo<S8b1oooool00ol0003oooooooooo`2[ooooo`Coo`007ooo
ool2o`3o03Oooooo0_l00?n4ooooo`004oooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPOooooo
00?o0000ooooooooool0[oooool3ool001kooooo0_l0o`0gooooo`;o003oP_ooool0023ooooo00?o
0000ooooooooool0/_ooool3ool001gooooo0ol0o`0fooooo`;o003oP?ooool0023ooooo00?o0000
ooooooooool0]Oooool2ool001kooooo0_l0o`0fooooo`03o`00oooooooooooo07gooooo000Poooo
o`03o`000?oooooooooo0;Oooooo0_oo000Nooooo`;o0?l0=Oooool2o`00oggooooo000Pooooo`;o
0000^_ooool3ool001gooooo0_l0o`0eooooo`;o003oNoooool0023ooooo00?o0000ooooooooool0
_?ooool2ool001gooooo0_l0o`0eooooo`;o003oNOooool0023ooooo00?o0000ooooooooool0__oo
ool2ool001gooooo0_l0o`0eooooo`03o`00oooooooooooo07Kooooo000Pooooo`03o`000?oooooo
oooo0<3ooooo0_oo000Mooooo`;o0?l0=?ooool2o`00ogKooooo000Pooooo`03o`000?oooooooooo
0<;ooooo0ooo000Looooo`;o0?l0=?ooool2o`00ogCooooo000Pooooo`03o`000?oooooooooo0<Go
oooo0_oo000Looooo`03o`3o0?oooooooooo03?ooooo00?o003oooooooooool0LOooool0023ooooo
00?o0000ooooooooool0aoooool2ool001_ooooo0_l0o`0dooooo`03o`00oooooooooooo073ooooo
000Pooooo`03o`000?oooooooooo0<Wooooo0ooo000Jooooo`;o0?l0<oooool2o`00og3ooooo000P
ooooo`03o`000?oooooooooo0<cooooo0_oo000Jooooo`;o0?l0<oooool00ol00?ooooooooooo`1]
ooooo`008?ooool00ol0003oooooooooo`3>ooooo`;oo`006_ooool2o`3o03;ooooo0_l00?m]oooo
o`008?ooool2o`000=7ooooo0_oo000Jooooo`03o`3o0?oooooooooo037ooooo00?o003ooooooooo
ool0J_ooool0023ooooo00?o0000ooooooooool0d_ooool2ool001Wooooo0_l0o`0booooo`03o`00
oooooooooooo06Wooooo000Pooooo`03o`000?oooooooooo0=Cooooo0_oo000Iooooo`03o`3o0?oo
oooooooo033ooooo0_l00?mYooooo`008?ooool00ol0003oooooooooo`3Fooooo`03ool00?oooooo
oooo01Oooooo0_l0o`0booooo`03o`00oooooooooooo06Kooooo000Pooooo`03o`000?oooooooooo
0=Oooooo0_oo000Iooooo`;o0?l0<Oooool00ol00?ooooooooooo`1Uooooo`008?ooool00ol0003o
ooooooooo`3Iooooo`;oo`006Oooool00ol0o`3oooooooooo`0_ooooo`;o003oIOooool0023ooooo
00?o0000ooooooooool0foooool2ool001Sooooo0_l0o`0aooooo`03o`00oooooooooooo06;ooooo
000Pooooo`03o`000?oooooooooo0=gooooo0_oo000Hooooo`03o`3o0?oooooooooo02oooooo00?o
003oooooooooool0HOooool0023ooooo00?o0000ooooooooool0goooool2ool001Oooooo0_l0o`0`
ooooo`03o`00oooooooooooo063ooooo000Pooooo`03o`000?oooooooooo0>7ooooo00?oo`00oooo
ooooool05_ooool00ol0o`3oooooooooo`0^ooooo`03o`00oooooooooooo05oooooo000Pooooo`;o
0000hoooool2ool001Oooooo0_l0o`0_ooooo`03o`00oooooooooooo05kooooo000Pooooo`03o`00
0?oooooooooo0>Cooooo0_oo000Gooooo`03o`3o0?oooooooooo02gooooo0_l00?mNooooo`008?oo
ool00ol0003oooooooooo`3Vooooo`;oo`005_ooool2o`3o02oooooo00?o003oooooooooool0Fooo
ool0023ooooo00?o0000ooooooooool0j?ooool00ooo003oooooooooo`0Eooooo`03o`3o0?oooooo
oooo02gooooo00?o003oooooooooool0F_ooool0023ooooo00?o0000ooooooooool0jOooool2ool0
01Kooooo00?o0?l0ooooooooool0;Oooool00ol00?ooooooooooo`1Iooooo`008?ooool00ol0003o
ooooooooo`3[ooooo`;oo`005Oooool2o`3o02kooooo00?o003oooooooooool0F?ooool0023ooooo
00?o0000ooooooooool0kOooool00ooo003oooooooooo`0Dooooo`03o`3o0?oooooooooo02cooooo
00?o003oooooooooool0Eoooool001Kooooo0_l000000ol@413oooooooooo`05ooooo`03o`000?oo
oooooooo0>kooooo00?oo`00ooooooooool05?ooool2o`3o02gooooo0_l00?mGooooo`005oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0>oooooo0_oo000Fooooo`03o`3o0?oooooo
oooo02cooooo00?o003oooooooooool0E?ooool001?ooooo1_l00007ooooo`?o0000lOooool00ooo
003oooooooooo`0Dooooo`;o0?l0;Oooool00ol00?ooooooooooo`1Cooooo`004oooool01OmVIVKo
ZJVYoooooooooooo000000Sooooo00?o0000ooooooooool0l_ooool2ool001Kooooo00?o0?l0oooo
ooooool0:oooool00ol00?ooooooooooo`1Booooo`004oooool01Oo^k^ko8B4Qonk^k_oooooo0000
00Sooooo00?o0000ooooooooool0m?ooool00ooo003oooooooooo`0Dooooo`03o`3o0?oooooooooo
02_ooooo00?o003oooooooooool0DOooool001Cooooo00CoZJVYofIVI_oooooo00002?ooool00ol0
003oooooooooo`3eooooo`03ool00?oooooooooo01Cooooo00?o0?l0ooooooooool0:oooool00ol0
0?ooooooooooo`1@ooooo`005Oooool00om4A4Coc<c<o`000008ooooo`03o`000?oooooooooo0?Ko
oooo0_oo000Eooooo`03o`3o0?oooooooooo02_ooooo00?o003oooooooooool0Coooool001Gooooo
00?ogMgModA4A?l000002?ooool00ol0003oooooooooo`3hooooo`03ool00?oooooooooo01?ooooo
00?o0?l0ooooooooool0:oooool2o`00odoooooo000Fooooo`03ohN7Qol0003ooooo00Oooooo00?o
0000ooooooooool0nOooool00ooo003oooooooooo`0Cooooo`;o0?l0;Oooool00ol00?oooooooooo
o`1<ooooo`008?ooool00ol0003oooooooooo`3jooooo`;oo`005Oooool00ol0o`3oooooooooo`0[
ooooo`03o`00oooooooooooo04_ooooo000Pooooo`03o`000?oooooooooo0?cooooo00?oo`00oooo
ooooool04oooool00ol0o`3oooooooooo`0[ooooo`03o`00oooooooooooo04[ooooo000Pooooo`03
o`000?oooooooooo0?gooooo00?oo`00ooooooooool04oooool00ol0o`3oooooooooo`0[ooooo`03
o`00oooooooooooo04Wooooo000Pooooo`;o0000ooooool00ooo003oooooooooo`0Cooooo`03o`3o
0?oooooooooo02_ooooo00?o003oooooooooool0B?ooool0023ooooo00?o0000ooooooooool0oooo
ool2ool001Cooooo00?o0?l0ooooooooool0:oooool00ol00?ooooooooooo`17ooooo`008?ooool0
0ol0003oooooooooo`3oooooo`;ooooo00?oo`00ooooooooool04_ooool2o`3o02cooooo00?o003o
ooooooooool0A_ooool0023ooooo00?o0000ooooooooool0ooooool3ooooo`03ool00?oooooooooo
01?ooooo00?o0?l0ooooooooool0:Oooool00ol00?ooooooooooo`16ooooo`008?ooool00ol0003o
ooooooooo`3oooooo`Cooooo00?oo`00ooooooooool04oooool00ol0o`3oooooooooo`0Yooooo`03
o`00oooooooooooo04Gooooo000Pooooo`03o`000?oooooooooo0?oooooo1Oooool2ool001Cooooo
00?o0?l0ooooooooool0:Oooool00ol00?ooooooooooo`14ooooo`008?ooool00ol0003ooooooooo
o`3oooooo`Oooooo00?oo`00ooooooooool04_ooool00ol0o`3oooooooooo`0Yooooo`03o`00oooo
oooooooo04?ooooo000Pooooo`03o`000?oooooooooo0?oooooo2?ooool00ooo003oooooooooo`0B
ooooo`03o`3o0?oooooooooo02Wooooo00?o003oooooooooool0@_ooool0023ooooo00?o0000oooo
ooooool0ooooool9ooooo`03ool00?oooooooooo01;ooooo00?o0?l0ooooooooool0:Oooool00ol0
0?ooooooooooo`11ooooo`008?ooool00ol0003oooooooooo`3oooooo`[ooooo0_oo000Cooooo`03
o`3o0?oooooooooo02Wooooo00?o003oooooooooool0@?ooool0023ooooo0_l0003oooooo`gooooo
00?oo`00ooooooooool04Oooool00ol0o`3oooooooooo`0Yooooo`03o`00oooooooooooo03oooooo
000Pooooo`03o`000?oooooooooo0?oooooo3Oooool00ooo003oooooooooo`0Aooooo`03o`3o0?oo
oooooooo02Wooooo00?o003oooooooooool0?_ooool0023ooooo00?o0000ooooooooool0ooooool>
ooooo`03ool00?oooooooooo017ooooo00?o0?l0ooooooooool0:?ooool00ol00?ooooooooooo`0n
ooooo`008?ooool00ol0003oooooooooo`3oooooo`oooooo00?oo`00ooooooooool04Oooool00ol0
o`3oooooooooo`0Xooooo`03o`00oooooooooooo03gooooo000Pooooo`03o`000?oooooooooo0?oo
oooo4?ooool00ooo003oooooooooo`0Aooooo`03o`3o0?oooooooooo02Sooooo00?o003ooooooooo
ool0??ooool0023ooooo00?o0000ooooooooool0oooooolAooooo`03ool00?oooooooooo017ooooo
00?o0?l0ooooooooool0:?ooool00ol00?ooooooooooo`0kooooo`008?ooool00ol0003ooooooooo
o`3ooooooa;ooooo00?oo`00ooooooooool04Oooool00ol0o`3oooooooooo`0Xooooo`03o`00oooo
oooooooo03[ooooo000Pooooo`03o`000?oooooooooo0?oooooo4oooool00ooo003oooooooooo`0A
ooooo`03o`3o0?oooooooooo02Sooooo00?o003oooooooooool0>Oooool0023ooooo00?o0000oooo
ooooool0oooooolDooooo`03ool00?oooooooooo013ooooo00?o0?l0ooooooooool0:Oooool00ol0
0?ooooooooooo`0hooooo`008?ooool00ol0003oooooooooo`3ooooooaGooooo00?oo`00oooooooo
ool04?ooool00ol0o`3oooooooooo`0Yooooo`03o`00oooooooooooo03Oooooo000Pooooo`;o0000
oooooolGooooo`03ool00?oooooooooo013ooooo00?o0?l0ooooooooool0:?ooool00ol00?oooooo
ooooo`0gooooo`008?ooool00ol0003oooooooooo`3ooooooaOooooo00?oo`00ooooooooool04?oo
ool00ol0o`3oooooooooo`0Xooooo`03o`00oooooooooooo03Kooooo000Pooooo`03o`000?oooooo
oooo0?oooooo6?ooool00ooo003oooooooooo`0@ooooo`03o`3o0?oooooooooo02Sooooo00?o003o
ooooooooool0=Oooool0023ooooo00?o0000ooooooooool0oooooolHooooo`03ool00?oooooooooo
017ooooo00?o0?l0ooooooooool09oooool00ol00?ooooooooooo`0eooooo`008?ooool00ol0003o
ooooooooo`3ooooooaWooooo00?oo`00ooooooooool04Oooool00ol0o`3oooooooooo`0Wooooo`03
o`00oooooooooooo03Cooooo000Pooooo`03o`000?oooooooooo0?oooooo6_ooool00ooo003ooooo
ooooo`0Aooooo`03o`3o0?oooooooooo02Oooooo00?o003oooooooooool0<oooool0023ooooo00?o
0000ooooooooool0oooooolKooooo`03ool00?oooooooooo017ooooo00?o0?l0ooooooooool09_oo
ool00ol00?ooooooooooo`0cooooo`004oooool01_o^k^koA4A4o`000?l0003oEEEEonk^kPOooooo
00?o0000ooooooooool0oooooolLooooo`03ool00?oooooooooo013ooooo00?o0?l0ooooooooool0
9oooool00ol00?ooooooooooo`0booooo`004oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Oo
oooo00?o0000ooooooooool0oooooolMooooo`03ool00?oooooooooo013ooooo00?o0?l0oooooooo
ool09oooool00ol00?ooooooooooo`0aooooo`004oooool00ol@413oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo0ol0003ooooooakooooo00?oo`00ooooooooool04?ooool00ol0o`3ooooo
ooooo`0Wooooo`03o`00oooooooooooo033ooooo000Cooooo`03o`000?o^k^kooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooaoooooo00?oo`00ooooooooool04?oo
ool00ol0o`3oooooooooo`0Vooooo`03o`00oooooooooooo033ooooo000Cooooo`06o`000?mEEEGo
k^k^oooooomgMgOoEEEE1oooool00ol0003oooooooooo`3oooooob3ooooo00?oo`00ooooooooool0
4?ooool00ol0o`3oooooooooo`0Vooooo`03o`00oooooooooooo02oooooo000Cooooo`06ob4Q8OmV
IVKo0000o`000?mEEEGok^k^1oooool00ol0003oooooooooo`3oooooob7ooooo00?oo`00oooooooo
ool04?ooool00ol0o`3oooooooooo`0Vooooo`03o`00oooooooooooo02kooooo000Cooooo`03ohN7
QomVIVKooooo00[ooooo00?o0000ooooooooool0oooooolRooooo`03ool00?oooooooooo013ooooo
00?o0?l0ooooooooool09Oooool00ol00?ooooooooooo`0^ooooo`005?ooool00olb<S;oIVIVomgM
g@09ooooo`03o`000?oooooooooo0?oooooo8oooool00ooo003oooooooooo`0@ooooo`03o`3o0?oo
oooooooo02Gooooo00?o003oooooooooool0;Oooool001Gooooo00CoMgMgoa0@4?l0003o8B4Q1ooo
ool00ol0003oooooooooo`3oooooobCooooo00?oo`00ooooooooool03oooool00ol0o`3ooooooooo
o`0Vooooo`03o`00oooooooooooo02cooooo000Pooooo`03o`000?oooooooooo0?oooooo9Oooool0
0ooo003oooooooooo`0?ooooo`03o`3o0?oooooooooo02Gooooo00?o003oooooooooool0;?ooool0
023ooooo00?o0000ooooooooool0oooooolVooooo`03ool00?oooooooooo00oooooo00?o0?l0oooo
ooooool09Oooool00ol00?ooooooooooo`0[ooooo`008?ooool00ol0003oooooooooo`3oooooobOo
oooo00?oo`00ooooooooool03oooool00ol0o`3oooooooooo`0Uooooo`03o`00oooooooooooo02[o
oooo000Pooooo`;o0000oooooolXooooo`03ool00?oooooooooo00oooooo00?o0?l0ooooooooool0
D_ooool0023ooooo00?o0000ooooooooool0oooooolXooooo`03ool00?oooooooooo00oooooo00?o
0?l0ooooooooool0DOooool0023ooooo00?o0000ooooooooool0oooooolYooooo`03ool00?oooooo
oooo00oooooo00?o0?l0ooooooooool0D?ooool0023ooooo00?o0000ooooooooool0oooooolZoooo
o`03ool00?oooooooooo00oooooo00?o0?l0ooooooooool0Coooool0023ooooo00?o0000oooooooo
ool0oooooolZooooo`03ool00?oooooooooo00oooooo00?o0?l0ooooooooool0Coooool0023ooooo
00?o0000ooooooooool0ooooool[ooooo`03ool00?oooooooooo00oooooo00?o0?l0ooooooooool0
C_ooool0023ooooo00?o0000ooooooooool0ooooool/ooooo`03ool00?oooooooooo00oooooo00?o
0?l0ooooooooool0COooool0023ooooo00?o0000ooooooooool0ooooool]ooooo`03ool00?oooooo
oooo00kooooo00?o0?l0ooooooooool0COooool0023ooooo00?o0000ooooooooool0ooooool]oooo
o`03ool00?oooooooooo00oooooo00?o0?l0ooooooooool0C?ooool0023ooooo00?o0000oooooooo
ool0ooooool^ooooo`03ool00?oooooooooo00oooooo00?o0?l0ooooooooool0Boooool0023ooooo
0_l0003ooooooc3ooooo00?oo`00ooooooooool03oooool00ol0o`3oooooooooo`1:ooooo`008?oo
ool00ol0003oooooooooo`3ooooooboooooo00?oo`00ooooooooool03oooool00ol0o`3ooooooooo
o`1:ooooo`008?ooool00ol0003oooooooooo`3ooooooc3ooooo00?oo`00ooooooooool03oooool0
0ol0o`3oooooooooo`19ooooo`008?ooool00ol0003oooooooooo`3ooooooc7ooooo00?oo`00oooo
ooooool03oooool00ol0o`3oooooooooo`18ooooo`008?ooool00ol0003oooooooooo`3ooooooc;o
oooo00?oo`00ooooooooool03oooool00ol0o`3oooooooooo`17ooooo`008?ooool00ol0003ooooo
ooooo`3ooooooc;ooooo00?oo`00ooooooooool03oooool00ol0o`3oooooooooo`17ooooo`008?oo
ool00ol0003oooooooooo`3ooooooc?ooooo00?oo`00ooooooooool03oooool00ol0o`3ooooooooo
o`16ooooo`008?ooool00ol0003oooooooooo`3oooooocCooooo00?oo`00ooooooooool03oooool0
0ol0o`3oooooooooo`15ooooo`008?ooool00ol0003oooooooooo`3oooooocGooooo00?oo`00oooo
ooooool03_ooool00ol0o`3oooooooooo`15ooooo`008?ooool2o`000?oooooo=_ooool00ooo003o
ooooooooo`0?ooooo`03o`3o0?oooooooooo04Cooooo000Pooooo`03o`000?oooooooooo0?oooooo
=_ooool00ooo003oooooooooo`0>ooooo`03o`3o0?oooooooooo04Cooooo000Pooooo`03o`000?oo
oooooooo0?oooooo=oooool00ooo003oooooooooo`0>ooooo`03o`3o0?oooooooooo04?ooooo000P
ooooo`03o`000?oooooooooo0?oooooo>?ooool00ooo003oooooooooo`0>ooooo`03o`3o0?oooooo
oooo04;ooooo000Pooooo`03o`000?oooooooooo0?oooooo>?ooool00ooo003oooooooooo`0>oooo
o`03o`3o0?oooooooooo04;ooooo000Pooooo`03o`000?oooooooooo0?oooooo>Oooool00ooo003o
ooooooooo`0>ooooo`03o`3o0?oooooooooo047ooooo000Pooooo`03o`000?oooooooooo0?oooooo
>_ooool00ooo003oooooooooo`0>ooooo`03o`3o0?oooooooooo043ooooo000Pooooo`03o`000?oo
oooooooo0?oooooo>_ooool00ooo003oooooooooo`0>ooooo`03o`3o0?oooooooooo043ooooo000C
ooooo`06onk^k_m4A4Co0000o`000?m4A4Cok^k^1oooool00ol0003oooooooooo`3ooooooc_ooooo
00?oo`00ooooooooool03_ooool00ol0o`3oooooooooo`0oooooo`004oooool01_lb<S;oMgMgonk^
k_o^k^koMgMgoc8b<POooooo00?o0000ooooooooool0oooooollooooo`03ool00?oooooooooo00go
oooo00?o0?l0ooooooooool0?oooool001?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`?o0000oooooolmooooo`03ool00?oooooooooo00gooooo00?o0?l0ooooooooool0
?_ooool001?ooooo00Ko<S8bogMgMoo^k^kok^k^ogMgMolb<S87ooooo`03o`000?oooooooooo0?oo
oooo?Oooool00ooo003oooooooooo`0>ooooo`03o`3o0?oooooooooo03gooooo000Cooooo`03omgM
gOl0003o000000;o000000?ogMgMooooooooool01Oooool00ol0003oooooooooo`3oooooockooooo
00?oo`00ooooooooool03Oooool00ol0o`3oooooooooo`0mooooo`004oooool01_lb<S;oIVIVonk^
k_o^k^koIVIVoc8b<POooooo00?o0000ooooooooool0ooooooloooooo`03ool00?oooooooooo00go
oooo00?o0?l0ooooooooool0??ooool001?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool00ooo003oooooooooo`0=ooooo`03o`3o
0?oooooooooo03_ooooo000Cooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b1oooool00ol0003o
ooooooooo`3ooooood3ooooo00?oo`00ooooooooool03Oooool00ol0o`3oooooooooo`0kooooo`00
4oooool01_o^k^koA4A4o`000?l0003oA4A4onk^kPOooooo00?o0000ooooooooool0oooooom1oooo
o`03ool00?oooooooooo00gooooo00?o0?l0ooooooooool0>_ooool0023ooooo00?o0000oooooooo
ool0oooooom2ooooo`03ool00?oooooooooo00cooooo00?o0?l0ooooooooool0>_ooool0023ooooo
00?o0000ooooooooool0oooooom2ooooo`03ool00?oooooooooo00gooooo00?o0?l0ooooooooool0
>Oooool0023ooooo00?o0000ooooooooool0oooooom3ooooo`03ool00?oooooooooo00gooooo00?o
0?l0ooooooooool0>?ooool0023ooooo0_l0003oooooodGooooo00?oo`00ooooooooool03?ooool0
0ol0o`3oooooooooo`0hooooo`008?ooool00ol0003oooooooooo`3oooooodGooooo00?oo`00oooo
ooooool03?ooool00ol0o`3oooooooooo`0gooooo`008?ooool00ol0003oooooooooo`3oooooodGo
oooo00?oo`00ooooooooool03?ooool00ol0o`3oooooooooo`0gooooo`008?ooool00ol0003ooooo
ooooo`3oooooodKooooo00?oo`00ooooooooool03?ooool00ol0o`3oooooooooo`0fooooo`008?oo
ool00ol0003oooooooooo`3oooooodKooooo00?oo`00ooooooooool03Oooool00ol0o`3ooooooooo
o`0eooooo`008?ooool00ol0003oooooooooo`3oooooodOooooo00?oo`00ooooooooool03?ooool0
0ol0o`3oooooooooo`0eooooo`008?ooool00ol0003oooooooooo`3oooooodSooooo00?oo`00oooo
ooooool03?ooool00ol0o`3oooooooooo`0dooooo`008?ooool00ol0003oooooooooo`3oooooodSo
oooo00?oo`00ooooooooool03?ooool00ol0o`3oooooooooo`0dooooo`008?ooool00ol0003ooooo
ooooo`3oooooodWooooo00?oo`00ooooooooool03?ooool00ol0o`3oooooooooo`0cooooo`008?oo
ool00ol0003oooooooooo`3oooooodWooooo00?oo`00ooooooooool03?ooool00ol0o`3ooooooooo
o`0cooooo`008?ooool2o`000?ooooooBoooool00ooo003oooooooooo`0<ooooo`03o`3o0?oooooo
oooo03;ooooo000Pooooo`03o`000?oooooooooo0?ooooooB_ooool00ooo003oooooooooo`0<oooo
o`03o`3o0?oooooooooo03;ooooo000Pooooo`03o`000?oooooooooo0?ooooooBoooool00ooo003o
ooooooooo`0<ooooo`03o`3o0?oooooooooo037ooooo000Pooooo`03o`000?oooooooooo0?oooooo
C?ooool00ooo003oooooooooo`0<ooooo`03o`3o0?oooooooooo033ooooo000Pooooo`03o`000?oo
oooooooo0?ooooooC?ooool00ooo003oooooooooo`0<ooooo`03o`3o0?oooooooooo033ooooo000P
ooooo`03o`000?oooooooooo0?ooooooCOooool00ooo003oooooooooo`0<ooooo`03o`3o0?oooooo
oooo02oooooo000Pooooo`03o`000?oooooooooo0?ooooooCOooool00ooo003oooooooooo`0<oooo
o`03o`3o0?oooooooooo02oooooo000Pooooo`03o`000?oooooooooo0?ooooooC_ooool00ooo003o
ooooooooo`0<ooooo`03o`3o0?oooooooooo02kooooo000Pooooo`03o`000?oooooooooo0?oooooo
Coooool00ooo003oooooooooo`0;ooooo`03o`3o0?oooooooooo02kooooo000Pooooo`;o0000oooo
oom@ooooo`03ool00?oooooooooo00cooooo00?o0?l0ooooooooool0;Oooool0023ooooo00?o0000
ooooooooool0oooooom@ooooo`03ool00?oooooooooo00_ooooo00?o0?l0ooooooooool0;Oooool0
023ooooo00?o0000ooooooooool0oooooom@ooooo`03ool00?oooooooooo00cooooo00?o0?l0oooo
ooooool0;?ooool0023ooooo00?o0000ooooooooool0oooooomAooooo`03ool00?oooooooooo00co
oooo00?o0?l0ooooooooool0:oooool0023ooooo00?o0000ooooooooool0oooooomAooooo`03ool0
0?oooooooooo00cooooo00?o0?l0ooooooooool0:oooool0023ooooo00?o0000ooooooooool0oooo
oomBooooo`03ool00?oooooooooo00cooooo00?o0?l0ooooooooool0:_ooool0023ooooo00?o0000
ooooooooool0oooooomCooooo`03ool00?oooooooooo03Sooooo000Pooooo`03o`000?oooooooooo
0?ooooooDoooool00ooo003oooooooooo`0hooooo`002oooool4o`000003oa0@4?oooooooooo00;o
oooo00Co^[Zjoa0@4?l0003oMgMg2?ooool00ol0003oooooooooo`3ooooooeCooooo00?oo`00oooo
ooooool0=oooool000gooooo00?o0000ooooooooool00oooool01_o<c<co<S8bonk^k_o^k^ko8B4Q
ojVYZ@Oooooo00?o0000ooooooooool0oooooomDooooo`03ool00?oooooooooo03Oooooo000=oooo
o`03o`000?oooooooooo00?ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S87ooooo`?o0000oooo
oomEooooo`03ool00?oooooooooo03Kooooo000=ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooEOooool0
0ooo003oooooooooo`0fooooo`003Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooeKooooo00?oo`00oooo
ooooool0=Oooool000gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooomFooooo`03ool00?oooooooooo03Go
oooo000=ooooo`03o`000?oooooooooo00?ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@7oooo
o`03o`000?oooooooooo0?ooooooEoooool00ooo003oooooooooo`0dooooo`002oooool00ol0003o
A4A4o`000005ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<1oooool00ol0003oooooooooo`3o
oooooeOooooo00?oo`00ooooooooool0=?ooool000_ooooo00?oc<c<oeEEEOl000001_ooool01?nj
^[[o410@oa0@4?o<c<`8ooooo`03o`000?oooooooooo0?ooooooF?ooool00ooo003oooooooooo`0c
ooooo`008?ooool00ol0003oooooooooo`3ooooooeSooooo00?oo`00ooooooooool0<oooool0023o
oooo00?o0000ooooooooool0oooooomIooooo`03ool00?oooooooooo03;ooooo000Pooooo`03o`00
0?oooooooooo0?ooooooFOooool00ooo003oooooooooo`0booooo`008?ooool2o`000?ooooooFooo
ool00ooo003oooooooooo`0aooooo`008?ooool00ol0003oooooooooo`3ooooooe[ooooo00?oo`00
ooooooooool0<Oooool0023ooooo00?o0000ooooooooool0oooooomKooooo`03ool00?oooooooooo
033ooooo000Pooooo`03o`000?oooooooooo0?ooooooFoooool00ooo003oooooooooo`0`ooooo`00
8?ooool00ol0003oooooooooo`3ooooooe_ooooo00?oo`00ooooooooool0<?ooool0023ooooo00?o
0000ooooooooool0oooooomLooooo`03ool00?oooooooooo02oooooo000Pooooo`03o`000?oooooo
oooo0?ooooooG?ooool00ooo003oooooooooo`0_ooooo`008?ooool00ol0003oooooooooo`3ooooo
oegooooo00?oo`00ooooooooool0;_ooool0023ooooo00?o0000ooooooooool0oooooomMooooo`03
ool00?oooooooooo02kooooo000Pooooo`;o0000oooooomOooooo`03ool00?oooooooooo02gooooo
000Pooooo`03o`000?oooooooooo0?ooooooG_ooool00ooo003oooooooooo`0]ooooo`008?ooool0
0ol0003oooooooooo`3ooooooeoooooo00?oo`00ooooooooool0;?ooool0023ooooo00?o0000oooo
ooooool0oooooomOooooo`03ool00?oooooooooo02cooooo000Pooooo`03o`000?oooooooooo0?oo
ooooH?ooool00ooo003oooooooooo`0[ooooo`008?ooool00ol0003oooooooooo`3oooooof3ooooo
00?oo`00ooooooooool0:oooool0023ooooo00?o0000ooooooooool0oooooomQooooo`03ool00?oo
oooooooo02[ooooo000Pooooo`03o`000?oooooooooo0?ooooooS_ooool0023ooooo00?o0000oooo
ooooool0oooooon>ooooo`008?ooool00ol0003oooooooooo`3oooooohkooooo000Pooooo`;o0000
oooooon?ooooo`008?ooool00ol0003oooooooooo`3oooooohkooooo000Pooooo`03o`000?oooooo
oooo0?ooooooS_ooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Ooo
ool00?oooooo/Oooool00?oooooo/Oooool009cooooo00?o^[Zjoc8b<_ooool03?ooool00olb<S;o
^[Zjooooo`3oooooo`?ooooo002@ooooo`05o`000?oooooo0000ooooool000001oooool00ol@413o
^[Zjooooo`0<ooooo`03okZj^_lQ8B7ooooo04oooooo00?o0000okZj^_ooool03oooool00ol0003o
^[Zjooooo`2Nooooo`00T?ooool01Ol0003oooooo`000?oooooo000000Kooooo00?o^[Zjoc8b<_oo
ool03_ooool00olb<S;o^[Zjooooo`1>ooooo`03ob4Q8OmEEEGooooo00oooooo00?o8B4QoeEEEOoo
ool0W_ooool008Oooooo00?o410@o`000?l000000ol000002?l@413oooooooooool0003oooooo`00
0?oooooo00001_ooool00omEEEGoV9RHooooo`03ooooo`Ko00001Oooool00onHV9SoEEEEooooo`0=
ooooo`03oa0@4?l0003o000000;o000000?o410@ooooooooool00_ooool01On7QhOo410@o`000?l@
413oQhN700?ooooo1_l0000;ooooo`09oa0@4?l0003o0000ooooool0003o410@ooooool0003o410@
00_ooooo00Co^[Zjoa0@4?l0003oMgMg1_ooool00omVIVKo0000onk^kP05ooooo`Co000000?o410@
ooooooooool00oooool00omVIVKo0000onk^kP04ooooo`Ko0000U?ooool008[ooooo00?o0000oooo
ooooool00oooool01Ol0003oooooo`000?oooooo000000Kooooo00?o410@olc<c?ooool01Oooool0
0ol0003oooooooooo`06ooooo`03omgMgOl@413ooooo00oooooo00?o0000ooooooooool01?ooool0
1on7QhOo8B4Qolc<c?ooooooc<c<ob4Q8On7QhL01?ooool00ol0003oooooooooo`0=ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo1_l00002ooooo`06olc<c?lb<S;ok^k^
onk^k_lQ8B7oZJVY1Oooool00onHV9So0000ogMgM`07ooooo`03o`000?oooooooooo00Gooooo00?o
V9RHo`000?mgMgL01?ooool00onHV9So0000olc<c002ooooo`03oa0@4?oooooooooo09;ooooo002:
ooooo`03o`000?oooooooooo00;ooooo1_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o410@
olc<c?ooool00_ooool00oo<c<co410@ooooo`03ooooo`03o`000?oooooooooo00gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`09ooooo`06odA4A?nYZJWooooooooooonYZJWo
<S8b1Oooool00ooMgMgo0000oa0@4007ooooo`03o`000?oooooooooo00Gooooo00?ogMgMo`000?l@
41001Oooool00onHV9So0000olc<c02Fooooo`00R_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03
ojVYZOl@413oc<c<09Gooooo002:ooooo`03o`000?oooooooooo00kooooo00?o410@olc<c?ooool0
1Oooool00ol0003ogMgMooooo`06ooooo`03omgMgOl@413ooooo00oooooo00?o0000ooooooooool0
1?ooool00ol@413o^[Zjooooo`02ooooo`03okZj^_l@413ooooo00?ooooo00?o0000omgMgOooool0
3Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`Ko00000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool00oo<
c<co410@olc<c02Dooooo`00R_ooool00ol0003oooooooooo`0>ooooo`03oeEEEOn7QhOooooo00Go
oooo0_l000000onHV9Soooooooooo`04ooooo`03oiRHV?mEEEGooooo00oooooo00?o0000oooooooo
ool01?ooool01on7QhOo8B4Qolc<c?ooooooc<c<ob4Q8On7QhL01?ooool2o`000003oiRHV?oooooo
oooo00_ooooo00Oo0000olc<c?o<c<co0000ohN7Qoo<c<co000000_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo00?oZJVYoc8b<_ooool0
Toooool008[ooooo00?o0000ooooooooool03_ooool00onj^[[o410@ooooo`03ooooo`05oa0@4?l0
003o0000okZj^_m4A4@00_l000001_lQ8B7ooooooooooooooooo8B4QokZj^Pkooooo00?o410@o`00
0?l000000ol00004ooooo`05ohN7Qol@413o0000oa0@4?n7QhL00oooool01Ol@413o0000o`000?nj
^[[oA4A400;o000000?o8B4Qooooooooool01oooool02?l@413o0000ob4Q8Ol0003oMgMgoa0@4?l0
003oQhN72oooool01_m4A4CoZJVYooooooooooooZJVYodA4A0oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`2Booooo`00R_ooool00ol0003oooooooooo`0?ooooo`03oc8b<_nj^[[o
oooo00cooooo00?o^[Zjob4Q8Oooool04?ooool00ol0003oooooooooo`0aooooo`06olc<c?lb<S;o
k^k^onk^k_lb<S;oc<c<3Oooool00ol0003oA4A4o`00000>ooooo`06o`000?n7QhOok^k^oooooomg
MgOo<S8bU?ooool008Oooooo00?o410@o`000?l000000ol000000ol@413oooooooooo`0<ooooo`03
okZj^_lb<S;ooooo00cooooo00?o<S8bokZj^_ooool04?ooool00ol@413o^[Zjooooo`0booooo`04
okZj^_l@413o410@olc<c0kooooo00?oc<c<oeEEEOl000003_ooool01_nYZJWo<S8bo`000?l0003o
EEEEonk^kYCooooo002nooooo`04okZj^_l@413o0000oa0@4>kooooo003ooooook7ooooo003ooooo
ok7ooooo003ooooook7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.367045, -0.934894, \
0.0168892, 0.0772125}}]
}, Open  ]],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`I\_m\)]],
  "'s are finite at the origin, but become exponentially large at large ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{BesselK[0, x], BesselK[1, x], BesselK[2, x]}, {x, 0, 4}, 
        PlotStyle \[Rule] {Red, \ Green, Blue}, 
        PlotLabel \[Rule] \*"\"\<\!\(K\_m\)(r) for m=0,1,2\>\"", 
        AxesLabel \[Rule] {"\<x\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 3.39"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 0.00344508 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .10084 -12 -4.5 ]
[.01131 .10084 0 4.5 ]
[.01131 .18697 -12 -4.5 ]
[.01131 .18697 0 4.5 ]
[.01131 .2731 -12 -4.5 ]
[.01131 .2731 0 4.5 ]
[.01131 .35922 -18 -4.5 ]
[.01131 .35922 0 4.5 ]
[.01131 .44535 -18 -4.5 ]
[.01131 .44535 0 4.5 ]
[.01131 .53148 -18 -4.5 ]
[.01131 .53148 0 4.5 ]
[.01131 .6176 -18 -4.5 ]
[.01131 .6176 0 4.5 ]
[.5 .63053 -52.75 0 ]
[.5 .63053 52.75 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(1)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(2)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(3)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(4)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10084 m
.03006 .10084 L
s
[(25)] .01131 .10084 1 0 Mshowa
.02381 .18697 m
.03006 .18697 L
s
[(50)] .01131 .18697 1 0 Mshowa
.02381 .2731 m
.03006 .2731 L
s
[(75)] .01131 .2731 1 0 Mshowa
.02381 .35922 m
.03006 .35922 L
s
[(100)] .01131 .35922 1 0 Mshowa
.02381 .44535 m
.03006 .44535 L
s
[(125)] .01131 .44535 1 0 Mshowa
.02381 .53148 m
.03006 .53148 L
s
[(150)] .01131 .53148 1 0 Mshowa
.02381 .6176 m
.03006 .6176 L
s
[(175)] .01131 .6176 1 0 Mshowa
.125 Mabswid
.02381 .03194 m
.02756 .03194 L
s
.02381 .04917 m
.02756 .04917 L
s
.02381 .06639 m
.02756 .06639 L
s
.02381 .08362 m
.02756 .08362 L
s
.02381 .11807 m
.02756 .11807 L
s
.02381 .13529 m
.02756 .13529 L
s
.02381 .15252 m
.02756 .15252 L
s
.02381 .16974 m
.02756 .16974 L
s
.02381 .20419 m
.02756 .20419 L
s
.02381 .22142 m
.02756 .22142 L
s
.02381 .23865 m
.02756 .23865 L
s
.02381 .25587 m
.02756 .25587 L
s
.02381 .29032 m
.02756 .29032 L
s
.02381 .30755 m
.02756 .30755 L
s
.02381 .32477 m
.02756 .32477 L
s
.02381 .342 m
.02756 .342 L
s
.02381 .37645 m
.02756 .37645 L
s
.02381 .39367 m
.02756 .39367 L
s
.02381 .4109 m
.02756 .4109 L
s
.02381 .42812 m
.02756 .42812 L
s
.02381 .46258 m
.02756 .46258 L
s
.02381 .4798 m
.02756 .4798 L
s
.02381 .49703 m
.02756 .49703 L
s
.02381 .51425 m
.02756 .51425 L
s
.02381 .5487 m
.02756 .5487 L
s
.02381 .56593 m
.02756 .56593 L
s
.02381 .58315 m
.02756 .58315 L
s
.02381 .60038 m
.02756 .60038 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -113.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.375 13.000 moveto
(H) show
80.375 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.375 13.000 moveto
(L) show
98.375 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(for) show
122.375 13.000 moveto
(m) show
128.500 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
140.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
146.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
152.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
158.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
164.500 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .06888 m
.02499 .03341 L
.02605 .03118 L
.02729 .02967 L
.02846 .02868 L
.03053 .02741 L
.03279 .02641 L
.03527 .02558 L
.0379 .02487 L
.04262 .02388 L
.04749 .0231 L
.05205 .0225 L
.06244 .02145 L
.07305 .02064 L
.08274 .02006 L
.10458 .01906 L
.12357 .01842 L
.14429 .01787 L
.16561 .01741 L
.18493 .01708 L
.22406 .01655 L
.26413 .01615 L
.30268 .01586 L
.34368 .01562 L
.38317 .01544 L
.42114 .01531 L
.46157 .01519 L
.50048 .01511 L
.54184 .01503 L
.58168 .01497 L
.62001 .01493 L
.66079 .01489 L
.70006 .01486 L
.73781 .01483 L
.77801 .01481 L
.8167 .0148 L
.85784 .01478 L
.89747 .01477 L
.93557 .01476 L
.97614 .01475 L
.97619 .01475 L
s
0 1 0 r
.02529 .61803 m
.02605 .37996 L
.02729 .25031 L
.02846 .19108 L
.02954 .15778 L
.03053 .13652 L
.03163 .11942 L
.03279 .10584 L
.03395 .09533 L
.0352 .08642 L
.03746 .07444 L
.03884 .06891 L
.04016 .06451 L
.04262 .0579 L
.045 .05296 L
.04753 .04879 L
.0521 .04315 L
.05752 .03842 L
.06244 .03526 L
.06787 .03259 L
.07287 .03065 L
.07824 .02895 L
.08414 .02743 L
.09408 .02544 L
.10458 .02386 L
.12409 .02178 L
.13503 .02093 L
.145 .02029 L
.16409 .01932 L
.18485 .01852 L
.20462 .01793 L
.22563 .01743 L
.26338 .01677 L
.28273 .01651 L
.30359 .01627 L
.34473 .01591 L
.38435 .01565 L
.42246 .01546 L
.46302 .01531 L
.50206 .01519 L
.54356 .0151 L
.58354 .01502 L
.62201 .01497 L
.66293 .01492 L
.70233 .01488 L
.74022 .01485 L
.78056 .01483 L
.81938 .01481 L
.86066 .01479 L
.90042 .01478 L
Mistroke
.93867 .01477 L
.97619 .01476 L
Mfstroke
0 0 1 r
.04931 .61803 m
.05014 .5763 L
.0529 .4746 L
.05532 .40649 L
.05787 .34969 L
.06244 .2747 L
.06507 .24249 L
.06746 .21804 L
.07283 .17556 L
.07781 .14698 L
.08253 .12633 L
.08802 .10781 L
.09309 .09444 L
.09862 .08287 L
.10458 .07296 L
.11421 .06091 L
.12324 .05263 L
.13399 .04532 L
.14385 .04028 L
.16277 .03344 L
.17349 .03066 L
.18347 .02857 L
.20393 .02534 L
.22252 .02323 L
.2417 .02161 L
.2625 .02028 L
.28237 .01931 L
.30342 .01851 L
.3413 .01746 L
.36075 .01707 L
.38164 .01672 L
.42292 .01619 L
.46268 .01584 L
.50093 .01558 L
.54162 .01539 L
.58081 .01524 L
.62244 .01513 L
.66256 .01504 L
.70116 .01498 L
.74222 .01492 L
.78176 .01488 L
.81978 .01485 L
.86026 .01482 L
.89922 .0148 L
.94063 .01479 L
.97619 .01478 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003ooooooona
ooooo`00oooooonaooooo`00oooooonaooooo`00Noooool4o`000003oa0@4?oooooooooo057ooooo
1_l0001Cooooo`06ojVYZOlQ8B7o0000o`000?mEEEGok^k^EOooool2o`000003oa0@4?oooooooooo
02Cooooo001mooooo`03o`000?oooooooooo05?ooooo00?oV9RHo`000?o<c<`00_ooool00ol@413o
ooooooooo`1Aooooo`06oa0@4?nYZJWooooooooooomgMgOo<S8bE_ooool00ol0003oooooooooo`0U
ooooo`00OOooool00ol0003oooooooooo`1Dooooo`03oiRHV?l0003oc<c<05[ooooo00?o0000oooo
ooooool0D?ooool6o`0002Kooooo001mooooo`03o`000?oooooooooo05Gooooo00?oZJVYoa0@4?o<
c<`0F?ooool00omgMgOo8B4Qooooo`1Aooooo`05ofIVI_nYZJWoooooooooool000009oooool007go
oooo00?o0000ooooooooool0E_ooool00oo<c<co410@olc<c01Eooooo`04ob4Q8Ol0003o0000okZj
^U;ooooo00Gok^k^ob4Q8Oo^k^koooooo`00000Wooooo`00OOooool00ol0003oooooooooo`1Goooo
o`03ojVYZOlb<S;ooooo05Gooooo00?ok^k^ogMgMolb<S80Doooool01?nYZJWoIVIVooooool0000W
ooooo`00OOooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool0D_ooool00om4A4Coc<c<o`00000Wooooo`00Noooool00ol0003oA4A4o`00001Eooooo`06
o`000?n7QhOok^k^oooooomgMgOo<S8bDoooool01_lQ8B7oQhN7ooooooooooooIVIVoc8b<UCooooo
00?ogMgModA4A?l000009oooool007_ooooo00?oc<c<oeEEEOl00000EOooool01_nYZJWo<S8bo`00
0?l0003oEEEEonk^kU?ooooo00Ko^[ZjodA4A?l0003o0000odA4A?o^k^iEooooo`03ohN7Qol0003o
oooo02Kooooo000Uooooo`03o`000?oooooooooo0?ooooooROooool002Gooooo00?o0000oooooooo
ool0oooooon9ooooo`009Oooool00ol0003oooooooooo`3oooooogOooooo00Oo410@o`000?l@413o
oooooa0@4?l0003o410@00_ooooo000Uooooo`03o`000?oooooooooo0?ooooooN?ooool01_lb<S;o
QhN7oooooonj^[[o0000onk^kP_ooooo000Uooooo`03o`000?oooooooooo0?ooooooN?ooool01Oo^
k^ko8B4Qolc<c?lQ8B7oc<c<00cooooo000Uooooo`03o`000?oooooooooo0?ooooooNOooool00onj
^[[o0000ohN7Q`0=ooooo`007?oooom<o`0001[oo`00<?l0o`3Go`00o`Wo00003Oooool01Oo^k^ko
<S8bolc<c?lb<S;ok^k^00cooooo000Uooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01_oooolNool002Go0?l0<?l00?l00ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`05oeEEEOmgMgOoooooohN7
QomEEED03?ooool002Gooooo00?o0000ooooooooool02Oooool>ool000Sooooo5_l0o`0Fooooo`oo
003oE?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool04oooool01ol@413o0000oa0@4?oooooo410@o`000?l@41002oooool002Gooooo00?o0000oooo
ooooool00oooool6ool0013ooooo1_l0o`0Uooooo`Oo003ooooooolnooooo`009Oooool00ol0003o
ooooooooo`03ool001;ooooo1?l0o`0Sooooo`So003ooooooom5ooooo`009Oooool00ol0003oo`00
ool0000@ooooo`Go0?l08Oooool6o`00ooooooooCOooool002Gooooo00?oo`00o`000?ooool03?oo
ool4o`3o02;ooooo1?l00?oooooooe?ooooo000Uooooo`03ool00?oooooooooo00_ooooo00?o0?l0
ooooooooool08?ooool4o`00ooooooooEoooool002Gooooo00?oo`00ooooooooool02_ooool00ol0
o`3oooooooooo`0Nooooo`?o003ooooooomKooooo`009Oooool00ooo003oooooooooo`08ooooo`;o
0?l07_ooool3o`00ooooooooG_ooool002Gooooo00?oo`00ooooooooool01oooool00ol0o`3ooooo
ooooo`0Mooooo`03o`00oooooooooooo0?ooooooGoooool002Gooooo00?oo`00ooooooooool01_oo
ool00ol0o`3oooooooooo`0Looooo`;o003ooooooomRooooo`009Oooool00ooo003oooooooooo`05
ooooo`03o`3o0?oooooooooo01cooooo00?o003oooooooooool0oooooomRooooo`009Oooool00ooo
003o0000ooooo`05ooooo`03o`3o0?oooooooooo01_ooooo00?o003oooooooooool0oooooomSoooo
o`009Oooool00ooo003oooooooooo`05ooooo`03o`3o0?oooooooooo01Wooooo0_l00?ooooooofKo
oooo000Uooooo`03ool00?oooooooooo00Gooooo00?o0?l0ooooooooool06?ooool00ol00?oooooo
ooooo`3oooooofKooooo000Uooooo`03ool00?oooooooooo00Cooooo00?o0?l0ooooooooool06?oo
ool00ol00?ooooooooooo`3oooooofOooooo000Uooooo`03ool00?oooooooooo00Cooooo00?o0?l0
ooooooooool05oooool00ol00?ooooooooooo`3oooooofSooooo000Uooooo`03ool00?oooooooooo
00?ooooo00?o0?l0ooooooooool06?ooool00ol00?ooooooooooo`3oooooofSooooo000Uooooo`03
ool00?l0003ooooo00?ooooo00?o0?l0ooooooooool05oooool00ol00?ooooooooooo`3oooooofWo
oooo000Uooooo`03ool00?oooooooooo00;ooooo00?o0?l0ooooooooool05oooool00ol00?oooooo
ooooo`3oooooof[ooooo000Uooooo`03o`000?oooooooooo00;ooooo00?o0?l0ooooooooool05ooo
ool00ol00?ooooooooooo`3oooooof[ooooo000Uooooo`03o`000?oooooooooo00;ooooo00?o0?l0
ooooooooool05_ooool00ol00?ooooooooooo`3oooooof_ooooo000Uooooo`03o`000?oooooooooo
00;ooooo00?o0?l0ooooooooool05_ooool00ol00?ooooooooooo`3oooooof_ooooo000Uooooo`03
o`000?oooooooooo00;ooooo00?o0?l0ooooooooool05Oooool00ol00?ooooooooooo`3oooooofco
oooo000Uooooo`;o00000_ooool00ol0o`3oooooooooo`0Eooooo`03o`00oooooooooooo0?oooooo
KOooool002Gooooo00Go0000ooooooooooooooooo`3o000Gooooo`03o`00oooooooooooo0?oooooo
KOooool002Gooooo00Go0000ooooooooooooooooo`3o000Fooooo`03o`00oooooooooooo0?oooooo
K_ooool002Gooooo00Go0000ooooooooooooooooo`3o000Eooooo`03o`00oooooooooooo0?oooooo
Koooool000oooooo1_l00003ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1oooool01?l0003o
ooooooooool0o`0Fooooo`03o`00oooooooooooo0?ooooooKoooool000oooooo00?oV9RHo`000?o<
c<`00_ooool01_l@413ooooooooooooooooo410@ohN7Q`;ooooo00?oMgMgodA4A?ooool01_ooool0
1?l0003oooooooooool0o`0Eooooo`03o`00oooooooooooo0?ooooooL?ooool0013ooooo00?oV9RH
o`000?o<c<`02_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`3o01Gooooo00?o
003oooooooooool0oooooom`ooooo`004Oooool00onYZJWo410@olc<c008ooooo`03onk^k_l0003o
oooo00Kooooo0ol000000ol0o`3oooooooooo`0Cooooo`03o`00oooooooooooo0?ooooooL?ooool0
01;ooooo00?oc<c<oa0@4?o<c<`00oooool01_l@413oV9RHooooooooooooMgMgofIVIPOooooo00Co
0000oooooooooooo0?l05?ooool00ol00?ooooooooooo`3oooooog7ooooo000Cooooo`03ojVYZOlb
<S;ooooo00;ooooo00Go0000ob4Q8Ol0003o0000ofIVIP08ooooo`04o`000?ooooooooooo`3o01Co
oooo00?o003oooooooooool0oooooomaooooo`005?ooool01Ol0003ooooooooooooooooo000000co
oooo00Co0000oooooooooooo0?l05?ooool00ol00?ooooooooooo`3oooooog7ooooo000?ooooo`06
o`000?n7QhOok^k^oooooomgMgOo<S8b0oooool00ol0003oooooooooo`0:ooooo`04o`000?oooooo
ooooo`3o01Cooooo00?o003oooooooooool0oooooomaooooo`003oooool01_nYZJWo<S8bo`000?l0
003oEEEEonk^kP?ooooo1Ol00008ooooo`04o`000?ooooooooooo`3o01?ooooo00?o003ooooooooo
ool0oooooombooooo`009Oooool2o`000003ooooool0o`3ooooo01;ooooo00?o003oooooooooool0
oooooombooooo`009Oooool01?l0003oooooooooool0o`0Cooooo`03o`00oooooooooooo0?oooooo
L_ooool002Gooooo00Co0000oooooooooooo0?l04_ooool00ol00?ooooooooooo`3oooooog?ooooo
000Uooooo`04o`000?ooooooooooo`3o01;ooooo00?o003oooooooooool0oooooomcooooo`009Ooo
ool01?l0003oooooooooool0o`0Booooo`03o`00oooooooooooo0?ooooooLoooool002Gooooo00?o
0000ooooool0o`004oooool00ol00?ooooooooooo`3oooooog?ooooo000Uooooo`03o`000?oooooo
0?l001;ooooo00?o003oooooooooool0oooooomdooooo`009Oooool2o`000003o`3o0?oooooooooo
013ooooo00?o003oooooooooool0oooooomdooooo`009Oooool00ol0003oooooo`3o000Booooo`03
o`00oooooooooooo0?ooooooM?ooool002Gooooo00?o0000ooooool0o`004_ooool00ol00?oooooo
ooooo`3oooooogCooooo000Uooooo`03o`000?oooooo0?l0017ooooo00?o003oooooooooool0oooo
oomeooooo`009Oooool00ol0003oooooo`3o000Aooooo`03o`00oooooooooooo0?ooooooMOooool0
02Gooooo00?o0000ooooool0o`004Oooool00ol00?ooooooooooo`3oooooogGooooo000Uooooo`;o
000000?o0?l0ooooooooool03oooool00ol00?ooooooooooo`3oooooogGooooo000Uooooo`03o`00
0?oooooo0?l0017ooooo00?o003oooooooooool0oooooomeooooo`009Oooool00ol0003oooooo`3o
000@ooooo`03o`00oooooooooooo0?ooooooM_ooool002Gooooo00?o0000ooooool0o`004?ooool0
0ol00?ooooooooooo`3oooooogKooooo000Uooooo`03o`000?oooooo0?l0013ooooo00?o003ooooo
ooooool0oooooomfooooo`009Oooool00ol0003oooooo`3o000@ooooo`03o`00oooooooooooo0?oo
ooooM_ooool002Gooooo00?o0000ooooool0o`004?ooool00ol00?ooooooooooo`3oooooogKooooo
000Uooooo`;o000000?o0?l0ooooooooool03Oooool00ol00?ooooooooooo`3oooooogOooooo000U
ooooo`03o`000?oooooo0?l000oooooo00?o003oooooooooool0oooooomgooooo`009Oooool00ol0
003o0?l0ooooo`0?ooooo`03o`00oooooooooooo0?ooooooMoooool002Gooooo00?o0000o`3o0?oo
ool03oooool00ol00?ooooooooooo`3oooooogOooooo000?ooooo`06oiRHV?l@413o0000o`000?m4
A4Cok^k^1?ooool01?nj^[[o410@o`000?mgMgL8ooooo`03o`000?l0o`3ooooo00oooooo00?o003o
ooooooooool0oooooomgooooo`003oooool01_l@413oQhN7ooooooooooooMgMgodA4A0?ooooo00Ko
c<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT7ooooo`03o`000?l0o`3ooooo00oooooo00?o003ooooooooo
ool0oooooomgooooo`005?ooool01_l0003oooooooooooooooooA4A4ojVYZ@;ooooo00?oZJVYoc8b
<_ooool01_ooool00ol0003o0?l0o`00000?ooooo`03o`00oooooooooooo0?ooooooMoooool001?o
oooo00?ok^k^o`000?ooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000o`3o0?ooool03_ooool00ol00?ooooooooooo`3oooooogSooooo000?ooooo`06oa0@
4?nHV9SooooooooooomgMgOoIVIV0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000o`3o0?ooool03_ooool00ol00?ooooooooooo`3oooooogSooooo000?ooooo`05
o`000?lQ8B7o0000o`000?mVIVH01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000o`3o0?ooool03_ooool00ol00?ooooooooooo`3oooooogSooooo000?ooooo`03
o`000?oooooooooo00Kooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@7ooooo`03o`000?l0o`3o
oooo00kooooo00?o003oooooooooool0oooooomhooooo`003oooool00ol0003oooooooooo`06oooo
o`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<1oooool00ol0003o0?l0ooooo`0>ooooo`03o`00oooo
oooooooo0?ooooooN?ooool000oooooo1Ol00005ooooo`04okZj^_l@413o410@olc<c0Sooooo00?o
0000o`3o0?ooool03_ooool00ol00?ooooooooooo`3oooooogSooooo000Uooooo`03o`000?l0o`3o
oooo00kooooo00?o003oooooooooool0oooooomhooooo`009Oooool00ol0003o0?l0ooooo`0>oooo
o`03o`00oooooooooooo0?ooooooN?ooool002Gooooo00?o0000o`3o0?ooool03Oooool00ol00?oo
ooooooooo`3oooooogWooooo000Uooooo`03o`000?l0o`3ooooo00gooooo00?o003oooooooooool0
oooooomiooooo`009Oooool00ol0003o0?l0ooooo`0=ooooo`03o`00oooooooooooo0?ooooooNOoo
ool002Gooooo00?o0000o`3o0?ooool03Oooool00ol00?ooooooooooo`3oooooogWooooo000Uoooo
o`03o`000?l0o`3ooooo00gooooo00?o003oooooooooool0oooooomiooooo`009Oooool00ol0003o
0?l0ooooo`0=ooooo`03o`00oooooooooooo0?ooooooNOooool002Gooooo00?o0000o`3o0?ooool0
3Oooool00ol00?ooooooooooo`3oooooogWooooo000Uooooo`03o`000?l0o`3ooooo00gooooo00?o
003oooooooooool0oooooomiooooo`009Oooool00ol0003o0?l0ooooo`0<ooooo`03o`00oooooooo
oooo0?ooooooN_ooool002Gooooo00?o0000o`3o0?ooool03?ooool00ol00?ooooooooooo`3ooooo
og[ooooo000Uooooo`03o`000?l0o`3ooooo00cooooo00?o003oooooooooool0oooooomjooooo`00
9Oooool00ol0003o0?l0ooooo`0<ooooo`03o`00oooooooooooo0?ooooooN_ooool002Gooooo00?o
0000o`3o0?ooool03?ooool00ol00?ooooooooooo`3oooooog[ooooo000Uooooo`03o`000?l0o`3o
oooo00cooooo00?o003oooooooooool0oooooomjooooo`009Oooool00ol0003o0?l0ooooo`0<oooo
o`03o`00oooooooooooo0?ooooooN_ooool002Gooooo00?o0000o`3o0?ooool03?ooool00ol00?oo
ooooooooo`3oooooog[ooooo000Uooooo`03o`000?l0o`3ooooo00cooooo00?o003oooooooooool0
oooooomjooooo`009Oooool00ol0003o0?l0ooooo`0<ooooo`03o`00oooooooooooo0?ooooooN_oo
ool002Gooooo00?o0000o`3o0?ooool03?ooool00ol00?ooooooooooo`3oooooog[ooooo000Uoooo
o`03o`000?l0o`3ooooo00_ooooo00?o003oooooooooool0oooooomkooooo`009Oooool00ol0003o
0?l0ooooo`0;ooooo`03o`00oooooooooooo0?ooooooNoooool0017ooooo00?o8B4QoiRHV?ooool0
1?ooool01_nHV9So410@o`000?l0003oA4A4onk^kPOooooo00?o0000o`3o0?ooool02oooool00ol0
0?ooooooooooo`3oooooog_ooooo000Aooooo`03oiRHV?m4A4Cooooo00Cooooo00Ko410@ohN7Qooo
ooooooooogMgMom4A4@7ooooo`03o`000?l0o`3ooooo00_ooooo00?o003oooooooooool0oooooomk
ooooo`004Oooool00oo^k^ko0000onk^kP09ooooo`03o`000?oooooooooo00Gooooo00?o0000o`3o
0?l000002oooool00ol00?ooooooooooo`3oooooog_ooooo000Booooo`03oeEEEOnHV9Sooooo00Oo
oooo00?ok^k^o`000?ooool01_ooool00ol0003o0?l0ooooo`0;ooooo`03o`00oooooooooooo0?oo
ooooNoooool001;ooooo00?oZJVYodA4A?ooool00oooool01_l@413oV9RHooooooooooooMgMgofIV
IPOooooo00?o0000o`3o0?ooool02oooool00ol00?ooooooooooo`3oooooog_ooooo000Cooooo`03
o`000?o^k^kooooo00;ooooo00Go0000ob4Q8Ol0003o0000ofIVIP08ooooo`03o`000?l0o`3ooooo
00_ooooo00?o003oooooooooool0oooooomkooooo`004oooool00omEEEGoV9RHooooo`02ooooo`03
o`000?oooooooooo00[ooooo00?o0000o`3o0?ooool02oooool00ol00?ooooooooooo`3oooooog_o
oooo000?ooooo`06oa0@4?oooooooooooooooonYZJWoA4A40oooool00ol0003oooooooooo`0:oooo
o`03o`000?l0o`3ooooo00_ooooo00?o003oooooooooool0oooooomkooooo`003oooool6o`0000?o
oooo1Ol00008ooooo`03o`000?l0o`3ooooo00_ooooo00?o003oooooooooool0oooooomkooooo`00
9Oooool00ol0003o0?l0ooooo`0;ooooo`03o`00oooooooooooo0?ooooooNoooool002Gooooo00?o
0000o`3o0?ooool02oooool00ol00?ooooooooooo`3oooooog_ooooo000Uooooo`03o`000?l0o`3o
oooo00[ooooo00?o003oooooooooool0oooooomlooooo`009Oooool00ol0003o0?l0ooooo`0:oooo
o`03o`00oooooooooooo0?ooooooO?ooool002Gooooo00?o0000o`3o0?ooool02_ooool00ol00?oo
ooooooooo`3oooooogcooooo000Uooooo`03o`000?l0o`3ooooo00[ooooo00?o003oooooooooool0
oooooomlooooo`009Oooool00ol0003o0?l0ooooo`0:ooooo`03o`00oooooooooooo0?ooooooO?oo
ool002Gooooo00?o0000o`3o0?ooool02_ooool00ol00?ooooooooooo`3oooooogcooooo000Uoooo
o`03o`000?l0o`3ooooo00[ooooo00?o003oooooooooool0oooooomlooooo`009Oooool00ol0003o
0?l0ooooo`0:ooooo`03o`00oooooooooooo0?ooooooO?ooool002Gooooo00?o0?l0ooooooooool0
2_ooool00ol00?ooooooooooo`3oooooogcooooo000Uooooo`03o`3o0?oooooooooo00[ooooo00?o
003oooooooooool0oooooomlooooo`009Oooool00ol0o`3o0000ooooo`0:ooooo`03o`00oooooooo
oooo0?ooooooO?ooool002Gooooo00?o0?l0ooooooooool02_ooool00ol00?ooooooooooo`3ooooo
ogcooooo000Uooooo`03o`3o0?oooooooooo00[ooooo00?o003oooooooooool0oooooomlooooo`00
9Oooool00ol0o`3oooooooooo`0:ooooo`03o`00oooooooooooo0?ooooooO?ooool002Gooooo00?o
0?l0ooooooooool02Oooool00ol00?ooooooooooo`3ooooooggooooo000Uooooo`03o`3o0?oooooo
oooo00Wooooo00?o003oooooooooool0oooooommooooo`009Oooool00ol0o`3oooooooooo`09oooo
o`03o`00oooooooooooo0?ooooooOOooool002Gooooo00?o0?l0o`000?ooool02Oooool00ol00?oo
ooooooooo`3ooooooggooooo000Uooooo`03o`3o0?oooooooooo00Wooooo00?o003oooooooooool0
oooooommooooo`009Oooool00ol0o`3oooooooooo`09ooooo`03o`00oooooooooooo0?ooooooOOoo
ool002Gooooo00?o0?l0ooooooooool02Oooool00ol00?ooooooooooo`3ooooooggooooo0007oooo
o`Co000000?o410@ooooooooool00_ooool01?nj^[[o410@o`000?mgMgL5ooooo`04okZj^_l@413o
0000ogMgM`Sooooo00?o0?l0ooooooooool02Oooool00ol00?ooooooooooo`3ooooooggooooo0009
ooooo`03o`000?oooooooooo00?ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT3ooooo`06olc<
c?lb<S;ok^k^onk^k_lQ8B7oZJVY1oooool00ol0o`3oooooooooo`09ooooo`03o`00oooooooooooo
0?ooooooOOooool000Wooooo00?o0000ooooooooool00oooool01_m4A4CoZJVYooooooooooooZJVY
oc8b<P?ooooo00KoA4A4ojVYZOooooooooooojVYZOlb<S87ooooo`03o`3o0?l0003o000000Wooooo
00?o003oooooooooool0oooooommooooo`002Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo
00?o0?l0ooooooooool02Oooool00ol00?ooooooooooo`3ooooooggooooo0009ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool01Oooool00ol0o`3oooooooooo`09ooooo`03o`00oooooooooooo0?oooooo
OOooool000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`05ooooo`03o`3o0?oooooooooo00Wooooo
00?o003oooooooooool0oooooommooooo`002Oooool00ol0003oooooooooo`03ooooo`06odA4A?nY
ZJWooooooooooonYZJWoA4A40oooool01_m4A4CoZJVYooooooooooooZJVYodA4A0Oooooo00?o0?l0
ooooooooool02Oooool00ol00?ooooooooooo`3ooooooggooooo0007ooooo`03o`000?m4A4Co0000
00Gooooo00Koc<c<oc8b<_o^k^kok^k^oc8b<_o<c<`3ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;o
c<c<1oooool00ol0o`3oooooooooo`09ooooo`03o`00oooooooooooo0?ooooooOOooool000Oooooo
00?oc<c<oeEEEOl000001_ooool01?nj^[[o410@oa0@4?o<c<`5ooooo`04okZj^_l@413o410@olc<
c0Sooooo00?o0?l0ooooooooool02Oooool00ol00?ooooooooooo`3ooooooggooooo000Uooooo`03
o`3o0?l0003ooooo00Wooooo00?o003oooooooooool0oooooommooooo`009Oooool00ol0o`3ooooo
ooooo`08ooooo`03o`00oooooooooooo0?ooooooO_ooool002Gooooo00?o0?l0ooooooooool02?oo
ool00ol00?ooooooooooo`3oooooogkooooo000Uooooo`03o`3o0?oooooooooo00Sooooo00?o003o
ooooooooool0oooooomnooooo`009Oooool00ol0o`3oooooooooo`08ooooo`03o`00oooooooooooo
0?ooooooO_ooool002Gooooo00?o0?l0ooooooooool02?ooool00ol00?ooooooooooo`3oooooogko
oooo000Uooooo`03o`3o0?l0003ooooo00Sooooo00?o003oooooooooool0oooooomnooooo`009Ooo
ool00ol0o`3oooooooooo`08ooooo`03o`00oooooooooooo0?ooooooO_ooool002Gooooo00?o0?l0
ooooooooool02?ooool00ol00?ooooooooooo`3oooooogkooooo000Uooooo`03o`3o0?oooooooooo
00Sooooo00?o003oooooooooool0oooooomnooooo`009Oooool00ol0o`3oooooooooo`08ooooo`03
o`00oooooooooooo0?ooooooO_ooool002Gooooo00?o0?l0ooooooooool02?ooool00ol00?oooooo
ooooo`3oooooogkooooo000Uooooo`03o`3o0?oooooooooo00Sooooo00?o003oooooooooool0oooo
oomnooooo`009Oooool00ol0o`3o0000ooooo`08ooooo`03o`00oooooooooooo0?ooooooO_ooool0
02Gooooo00?o0?l0ooooooooool02?ooool00ol00?ooooooooooo`3oooooogkooooo000Uooooo`03
o`3o0?oooooooooo00Sooooo00?o003oooooooooool0oooooomnooooo`009Oooool00ol0o`3ooooo
ooooo`08ooooo`03o`00oooooooooooo0?ooooooO_ooool002Gooooo00?o0?l0ooooooooool02?oo
ool00ol00?ooooooooooo`3oooooogkooooo000Uooooo`03o`3o0?oooooooooo00Sooooo00?o003o
ooooooooool0oooooomnooooo`009Oooool00ol0o`3o0000ooooo`08ooooo`03o`00oooooooooooo
0?ooooooO_ooool002Gooooo00?o0?l0ooooooooool02?ooool00ol00?ooooooooooo`3oooooogko
oooo000Uooooo`03o`3o0?oooooooooo00Sooooo00?o003oooooooooool0oooooomnooooo`009Ooo
ool00ol0o`3oooooooooo`08ooooo`03o`00oooooooooooo0?ooooooO_ooool000Oooooo1?l00000
1?l@413oooooooooooooool6o`0000?ooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h7ooooo`03
o`3o0?oooooooooo00Sooooo00?o003oooooooooool0oooooomnooooo`002Oooool00ol0003ooooo
ooooo`03ooooo`03oiRHV?l0003oc<c<00;ooooo00Ko410@oooooooooooooooooa0@4?n7QhL2oooo
o`03ogMgMom4A4Cooooo00Kooooo00?o0?l0ooooooooool01oooool00ol00?ooooooooooo`3ooooo
ogoooooo0009ooooo`03o`000?oooooooooo00Cooooo00?oV9RHo`000?o<c<`02_ooool00ol0003o
ooooooooo`05ooooo`03o`3o0?l0003o000000Oooooo00?o003oooooooooool0oooooomoooooo`00
2Oooool00ol0003oooooooooo`05ooooo`03ojVYZOl@413oc<c<00Sooooo00?ok^k^o`000?ooool0
1_ooool00ol0o`3oooooooooo`07ooooo`03o`00oooooooooooo0?ooooooOoooool000Wooooo00?o
0000ooooooooool01_ooool00oo<c<co410@olc<c003ooooo`06oa0@4?nHV9SooooooooooomgMgOo
IVIV1oooool00ol0o`3oooooooooo`07ooooo`03o`00oooooooooooo0?ooooooOoooool000Wooooo
00?o0000ooooooooool01oooool00onYZJWo<S8booooo`02ooooo`05o`000?lQ8B7o0000o`000?mV
IVH02?ooool00ol0o`3oooooooooo`07ooooo`03o`00oooooooooooo0?ooooooOoooool000Wooooo
00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000cooooo00?o0?l0oooooooo
ool01oooool00ol00?ooooooooooo`3oooooogoooooo0007ooooo`03o`000?m4A4Co000000Gooooo
00Ko0000ohN7Qoo^k^koooooogMgMolb<S83ooooo`03o`000?oooooooooo00[ooooo00?o0?l0oooo
ooooool01oooool00ol00?ooooooooooo`3oooooogoooooo0007ooooo`03olc<c?mEEEGo000000Go
oooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h3ooooo`Go00002?ooool00ol0o`3oooooooooo`07
ooooo`03o`00oooooooooooo0?ooooooOoooool002Gooooo00?o0?l0o`000?ooool01oooool00ol0
0?ooooooooooo`3oooooogoooooo000Uooooo`03o`3o0?oooooooooo00Oooooo00?o003ooooooooo
ool0oooooomoooooo`009Oooool00ol0o`3oooooooooo`07ooooo`03o`00oooooooooooo0?oooooo
Ooooool002Gooooo00?o0?l0ooooooooool01oooool00ol00?ooooooooooo`3oooooogoooooo000U
ooooo`03o`3o0?oooooooooo00Oooooo00?o003oooooooooool0oooooomoooooo`009Oooool00ol0
o`3oooooooooo`07ooooo`03o`00oooooooooooo0?ooooooOoooool002Gooooo00?o0?l0o`000?oo
ool01oooool00ol00?ooooooooooo`3oooooogoooooo000Uooooo`03o`3o0?oooooooooo00Oooooo
00?o003oooooooooool0oooooomoooooo`009Oooool00ol0o`3oooooooooo`07ooooo`03o`00oooo
oooooooo0?ooooooOoooool002Gooooo00?o0?l0ooooooooool01oooool00ol00?ooooooooooo`3o
ooooogoooooo000Uooooo`03o`3o0?oooooooooo00Oooooo00?o003oooooooooool0oooooomooooo
o`009Oooool00ol0o`3oooooooooo`07ooooo`03o`00oooooooooooo0?ooooooOoooool002Gooooo
00?o0?l0ooooooooool01oooool00ol00?ooooooooooo`3oooooogoooooo000Uooooo`03o`3o0?l0
003ooooo00Oooooo00?o003oooooooooool0oooooomoooooo`009Oooool00ol0o`3oooooooooo`07
ooooo`03o`00oooooooooooo0?ooooooOoooool002Gooooo00?o0?l0ooooooooool01oooool00ol0
0?ooooooooooo`3oooooogoooooo000Uooooo`03o`3o0?oooooooooo00Oooooo00?o003ooooooooo
ool0oooooomoooooo`009Oooool00ol0o`3oooooooooo`07ooooo`03o`00oooooooooooo0?oooooo
Ooooool002Gooooo00?o0?l0ooooooooool01oooool00ol00?ooooooooooo`3oooooogoooooo000U
ooooo`03o`3o0?l0003ooooo00Oooooo00?o003oooooooooool0oooooomoooooo`009Oooool00ol0
o`3oooooooooo`07ooooo`03o`00oooooooooooo0?ooooooOoooool002Gooooo00?o0?l0oooooooo
ool01oooool00ol00?ooooooooooo`3oooooogoooooo000Uooooo`03o`3o0?oooooooooo00Oooooo
00?o003oooooooooool0oooooomoooooo`001oooool4o`000006oa0@4?oooooooooooooooonHV9So
410@0_l000000om4A4Cok^k^ooooo`03ooooo`04okZj^_l@413o0000ogMgM`Sooooo00?o0?l0oooo
ooooool01oooool00ol00?ooooooooooo`3oooooogoooooo0009ooooo`03o`000?oooooooooo00?o
oooo00Ko410@ohN7QoooooooooooogMgMom4A4@3ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY
1oooool00ol0o`3oooooooooo`06ooooo`03o`00oooooooooooo0?ooooooP?ooool000Wooooo00?o
0000ooooooooool02?ooool01_l0003oooooooooooooooooA4A4ojVYZ@;ooooo00?oZJVYoc8b<_oo
ool01_ooool00ol0o`3oooooooooo`06ooooo`03o`00oooooooooooo0?ooooooP?ooool000Wooooo
00?o0000ooooooooool01oooool00oo^k^ko0000ooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0o`3o0000o`000006ooooo`03o`00oooooooooooo0?oooooo
P?ooool000Wooooo00?o0000ooooooooool00oooool01_l@413oV9RHooooooooooooMgMgofIVIP?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`3o0?oooooooooo00Ko
oooo00?o003oooooooooool0oooooon0ooooo`002Oooool00ol0003oooooooooo`03ooooo`05o`00
0?lQ8B7o0000o`000?mVIVH01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0?l0ooooooooool01_ooool00ol00?ooooooooooo`3ooooooh3ooooo0009ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01_m4A4CoZJVYooooooooooooZJVYodA4
A0Oooooo00?o0?l0ooooooooool01_ooool00ol00?ooooooooooo`3ooooooh3ooooo0007ooooo`03
o`000?m4A4Co000000Gooooo00?o0000ooooooooool01_ooool01_o<c<co<S8bonk^k_o^k^ko<S8b
olc<c0Oooooo00?o0?l0ooooooooool01_ooool00ol00?ooooooooooo`3ooooooh3ooooo0007oooo
o`03olc<c?mEEEGo000000Gooooo1Ol00005ooooo`04okZj^_l@413o410@olc<c0Sooooo00?o0?l0
ooooooooool01_ooool00ol00?ooooooooooo`3ooooooh3ooooo000Uooooo`03o`3o0?l0003ooooo
00Kooooo00?o003oooooooooool0oooooon0ooooo`009Oooool00ol0o`3oooooooooo`06ooooo`03
o`00oooooooooooo0?ooooooP?ooool002Gooooo00?o0?l0ooooooooool01_ooool00ol00?oooooo
ooooo`3ooooooh3ooooo000Uooooo`03o`3o0?oooooooooo00Kooooo00?o003oooooooooool0oooo
oon0ooooo`009Oooool00ol0o`3oooooooooo`06ooooo`03o`00oooooooooooo0?ooooooP?ooool0
02Gooooo00?o0?l0ooooooooool01_ooool00ol00?ooooooooooo`3ooooooh3ooooo000Uooooo`03
o`3o0?l0003ooooo00Kooooo00?o003oooooooooool0oooooon0ooooo`009Oooool00ol0o`3ooooo
ooooo`06ooooo`03o`00oooooooooooo0?ooooooP?ooool002Gooooo00?o0?l0ooooooooool01_oo
ool00ol00?ooooooooooo`3ooooooh3ooooo000Uooooo`03o`3o0?oooooooooo00Kooooo00?o003o
ooooooooool0oooooon0ooooo`009Oooool00ol0o`3oooooooooo`06ooooo`03o`00oooooooooooo
0?ooooooP?ooool002Gooooo00?o0?l0ooooooooool01_ooool00ol00?ooooooooooo`3ooooooh3o
oooo000Uooooo`03o`3o0?oooooooooo00Kooooo00?o003oooooooooool0oooooon0ooooo`009Ooo
ool00ol0o`3o0000ooooo`06ooooo`03o`00oooooooooooo0?ooooooP?ooool002Gooooo00?o0?l0
ooooooooool01_ooool00ol00?ooooooooooo`3ooooooh3ooooo000Uooooo`03o`3o0?oooooooooo
00Kooooo00?o003oooooooooool0oooooon0ooooo`009Oooool00ol0o`3oooooooooo`06ooooo`03
o`00oooooooooooo0?ooooooP?ooool002Gooooo00?o0?l0ooooooooool01_ooool00ol00?oooooo
ooooo`3ooooooh3ooooo000Uooooo`03o`3o0?oooooooooo00Kooooo00?o003oooooooooool0oooo
oon0ooooo`009Oooool00ol0o`3o0000ooooo`06ooooo`03o`00oooooooooooo0?ooooooP?ooool0
02Gooooo00?o0?l0ooooooooool01_ooool00ol00?ooooooooooo`3ooooooh3ooooo000Uooooo`03
o`3o0?oooooooooo00Kooooo00?o003oooooooooool0oooooon0ooooo`009Oooool00ol0o`3ooooo
ooooo`06ooooo`03o`00oooooooooooo0?ooooooP?ooool000Oooooo1?l000000ol@413ooooooooo
o`03ooooo`03ob4Q8OnHV9Sooooo00Cooooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h7ooooo`03
o`3o0?oooooooooo00Kooooo00?o003oooooooooool0oooooon0ooooo`002Oooool00ol0003ooooo
ooooo`05ooooo`03oiRHV?m4A4Cooooo00Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@7oooo
o`03o`3o0?oooooooooo00Kooooo00?o003oooooooooool0oooooon0ooooo`002Oooool00ol0003o
ooooooooo`05ooooo`03onk^k_l0003ok^k^00Wooooo00?o0000ooooooooool01Oooool00ol0o`3o
ooooooooo`06ooooo`03o`00oooooooooooo0?ooooooP?ooool000Wooooo00?o0000ooooooooool0
1_ooool00omEEEGoV9RHooooo`07ooooo`03onk^k_l0003ooooo00Kooooo00?o0?l0o`000?l00000
1_ooool00ol00?ooooooooooo`3ooooooh3ooooo0009ooooo`03o`000?oooooooooo00Kooooo00?o
ZJVYodA4A?ooool00oooool01_l@413oV9RHooooooooooooMgMgofIVI_ooooooToooool000Wooooo
00?o0000ooooooooool01oooool00ol0003ok^k^ooooo`02ooooo`05o`000?lQ8B7o0000o`000?mV
IVH0oooooonDooooo`002Oooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00;ooooo
00?o0000ooooooooool0oooooonFooooo`001oooool00ol0003oA4A4o`000005ooooo`06oa0@4?oo
oooooooooooooonYZJWoA4A40oooool00ol0003oooooooooo`3ooooooiKooooo0007ooooo`03olc<
c?mEEEGo000000Gooooo1_l00003ooooo`Go0000oooooonDooooo`00oooooonaooooo`00X?ooool0
0onj^[[o<S8booooo`0<ooooo`03oc8b<_nj^[[ooooo0?kooooo002Dooooo`05o`000?oooooo0000
ooooool000001oooool00ol@413o^[Zjooooo`0<ooooo`03okZj^_lQ8B7ooooo04oooooo00?o0000
okZj^_ooool03oooool00ol0003o^[Zjooooo`2Jooooo`00U?ooool01Ol0003oooooo`000?oooooo
000000Kooooo00?o^[Zjoc8b<_ooool03_ooool00olb<S;o^[Zjooooo`1>ooooo`03ob4Q8OmEEEGo
oooo00oooooo00?o8B4QoeEEEOooool0V_ooool008_ooooo0ol00003ooooo`08ofIVI_l0003ooooo
o`000?oooooo0000ooooool00006ooooo`03oeEEEOnHV9Sooooo00?ooooo1_l00005ooooo`03oiRH
V?mEEEGooooo00gooooo00?o410@o`000?l000000_l000000ol@413oooooooooo`02ooooo`05ohN7
Qol@413o0000oa0@4?n7QhL00oooool6o`0000_ooooo00Wo410@o`000?l0003oooooo`000?l@413o
ooooo`000?l@41002oooool01?nj^[[o410@o`000?mgMgL6ooooo`03ofIVI_l0003ok^k^00Gooooo
1?l000000ol@413oooooooooo`03ooooo`03ofIVI_l0003ok^k^00Cooooo1_l0002@ooooo`00S?oo
ool03Ol0003ooooooooooooooooogMgMo`000?o^k^koooooo`000?oooooo0000ooooool000001_oo
ool00ol@413oc<c<ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?ogMgMoa0@4?ooool03ooo
ool00ol0003oooooooooo`04ooooo`07ohN7QolQ8B7oc<c<ooooooo<c<co8B4QohN7Q`04ooooo`03
o`000?oooooooooo00gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooooooool6
o`0000;ooooo00Koc<c<oc8b<_o^k^kok^k^ob4Q8OnYZJT5ooooo`03oiRHV?l0003oMgMg00Oooooo
00?o0000ooooooooool01Oooool00onHV9So0000ogMgM`04ooooo`03oiRHV?l0003oc<c<00;ooooo
00?o410@ooooooooool0S_ooool008cooooo00Oo0000oooooooooooooooooc8b<_nHV9Sooooo00Ko
00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`04ooooo`03oa0@4?o<c<cooooo00;ooooo00?oc<c<oa0@4?oo
ool00oooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool02Oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?ogMgMo`000?l@41001ooo
ool00ol0003oooooooooo`05ooooo`03omgMgOl0003o410@00Gooooo00?oV9RHo`000?o<c<`0T_oo
ool008cooooo00Go0000olc<c?ooooooV9RHoc8b<P0>ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03ojVYZOl@413oc<c<097ooooo
002<ooooo`;o000000?oA4A4ob4Q8Oo^k^h03_ooool00ol@413oc<c<ooooo`05ooooo`03o`000?oM
gMgooooo00Kooooo00?ogMgMoa0@4?ooool03oooool00ol0003oooooooooo`04ooooo`03oa0@4?nj
^[[ooooo00;ooooo00?o^[Zjoa0@4?ooool00oooool00ol0003ogMgMooooo`0=ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooooooo1_l00002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03olc<c?l@413oc<c<093o
oooo002<ooooo`04o`000?nYZJWo410@okZj^Poooooo00?oEEEEohN7Qoooool01Oooool2o`000003
oiRHV?oooooooooo00Cooooo00?oV9RHoeEEEOooool03oooool00ol0003oooooooooo`04ooooo`07
ohN7QolQ8B7oc<c<ooooooo<c<co8B4QohN7Q`04ooooo`;o000000?oV9RHooooooooool02oooool0
1ol0003oc<c<olc<c?l0003oQhN7olc<c?l000002oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool04?ooool00onYZJWo<S8booooo`2?ooooo`00S?oo
ool01Ol0003oooooolc<c?l0003oV9RH00kooooo00?o^[Zjoa0@4?ooool00oooool01Ol@413o0000
o`000?nj^[[oA4A400;o000000Ko8B4Qooooooooooooooooob4Q8Onj^[X>ooooo`03oa0@4?l0003o
000000?o00001?ooool01On7QhOo410@o`000?l@413oQhN700?ooooo00Go410@o`000?l0003o^[Zj
odA4A002o`000003ob4Q8Ooooooooooo00Oooooo00So410@o`000?lQ8B7o0000ogMgMol@413o0000
ohN7Q`_ooooo00KoA4A4ojVYZOooooooooooojVYZOm4A4@?ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0S_ooool008cooooo00Ko0000ooooooooooooc<c<o`000?nHV9P>ooooo`03
oc8b<_nj^[[ooooo00cooooo00?o^[Zjob4Q8Oooool04?ooool00ol0003oooooooooo`0aooooo`06
olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<3Oooool00ol0003oA4A4o`00000>ooooo`06o`000?n7QhOo
k^k^oooooomgMgOo<S8bT?ooool008_ooooo0ol00002ooooo`?o00003Oooool00onj^[[o<S8boooo
o`0<ooooo`03oc8b<_nj^[[ooooo013ooooo00?o410@okZj^_ooool0<_ooool01?nj^[[o410@oa0@
4?o<c<`>ooooo`03olc<c?mEEEGo000000kooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^j@oooo
o`00`_ooool01?nj^[[o410@o`000?l@413Zooooo`00oooooonaooooo`00oooooonaooooo`00oooo
oonaooooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.417713, -14.133, \
0.0168892, 1.16724}}]
}, Open  ]],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`K\_m\)]],
  "'s are singular at the origin, but approach zero (with exponential \
rapidity) at large ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe general solution for ",
  Cell[BoxData[
      \(TraditionalForm\`R(r)\)]],
  " is, according to Eq. ",
  ButtonBox["(3.2.59)",
    ButtonData:>"(3.2.59)",
    ButtonStyle->"Hyperlink"],
  ", a sum of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(I\_m\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`K\_m\)]],
  ". However, the previous plots show that only the ",
  Cell[BoxData[
      \(TraditionalForm\`I\_m\)]],
  " term should be kept, in order that the solution be finite at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ". Therefore, we find that the radial function is ",
  Cell[BoxData[
      \(TraditionalForm\`R(r)\  = \ \(I\_m\)(n\ \[Pi]\ r/L)\)]],
  ", and the full solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta], z)\)]],
  " is a linear combination of these functions:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta], 
          z) = \[Sum]\+\(m = \(-\[Infinity]\)\)\%\[Infinity]\(\[Sum]\+\(n = 1\
\)\%\[Infinity]\( B\_\(n\ m\)\) \(\(I\_m\)(
                n\ \[Pi]\ r/
                    L)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\)\) \
\(sin(n\ \[Pi]\ z/L)\)\)\)]],
  "."
}], "NE2",
  CellTags->"(3.2.61)"],

Cell[TextData[{
  "The Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(m\ n\)\)]],
  " are determined by matching to the inhomogeneous boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](a, \[Theta], 
          z) = \(\(\[Phi]\_A\)(\[Theta], 
            z) = \[Sum]\+\(m = \(-\[Infinity]\)\)\%\[Infinity]\(\[Sum]\+\(n = \
1\)\%\[Infinity]\( B\_\(n\ m\)\) \(\(I\_m\)(
                  n\ \[Pi]\ a/
                      L)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ m\ \
\[Theta]\)\) \(sin(n\ \[Pi]\ z/L)\)\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Since this sum is a regular Fourier series in both ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ",",
  " we can use orthogonality of the trigonometric functions  to find the \
Fourier coefficients:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(n\ m\)\ \(\(I\_m\)(
            n\ \[Pi]\ a/
                L)\) = \(1\/\(\[Pi]\ L\)\) \(\[Integral]\_0\%\(2  \[Pi]\)\
\[DifferentialD]\[Theta]\ \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ m\ \
\[Theta]\)\) \(\[Integral]\_0\%L\(\(\[DifferentialD]z\)\(\ \)\(sin(
                    n\ \[Pi]\ z/L)\)\(\ \)\(\(\[Phi]\_A\)(\[Theta], 
                    z)\)\(\ \)\)\)\)\)]],
  "."
}], "Text"],

Cell["\<\
This completes the problem of determining the potential inside a \
cylindrical tube of finite length. More examples of such problems are left to \
the exercises. \
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 3.2", "Subsubtitle",
  CellTags->"c:43"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Solve ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(\[Del]\^2\( \[Phi](x, y)\) = 0\),
            "TraditionalForm"]}], TraditionalForm]]],
  " for the following boundary conditions Plot the solutions using ",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](0, 
          y) = \(\[Phi](2, y) = \(\[Phi](x, 0) = 0\)\); \ \(\(\[Phi](x, 
          1)\)\(=\)\)\)]],
  "1."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\[Phi]\/\[PartialD]x\) \((0, 
            y)\) = \(\(\[PartialD]\[Phi]\/\[PartialD]x\) \((1, 
              y)\) = \(\(\[PartialD]\[Phi]\/\[PartialD]y\) \((x, 0)\) = 
            0\)\); \ \ \(\[PartialD]\[Phi]\/\[PartialD]y\) \((x, 1)\) = 
        cos\ 2\ \[Pi]\ n\ x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\)\(\ \)\)\)]],
  " an integer. (What happens for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  "?)"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](0, y) = 
        2; \ \[Phi](1, y) = \(\[Phi](x, 0) = 
          0\); \ \(\[PartialD]\[Phi]\/\[PartialD]y\) \((x, 1)\) = 1\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\[Phi]\/\[PartialD]x\) \((0, 
            y)\) = \(\(\[PartialD]\[Phi]\/\[PartialD]x\) \((1, 
              y)\) = \(\(\[PartialD]\[Phi]\/\[PartialD]y\) \((x, 0)\) = 
            0\)\), \ \(\[PartialD]\[Phi]\/\[PartialD]y\) \((x, 1)\) = 1. \)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " A battery consists of a cube of side ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " filled with fluid of conductivity \[Sigma]. The electrodes in the battery \
consist of two plates on the base at ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  ", one grounded and one at potential ",
  Cell[BoxData[
      \(TraditionalForm\`V = 12\ Volts\)]],
  " (see Fig. ",
  ButtonBox["3.13",
    ButtonData:>"Fig. 3.13",
    ButtonStyle->"Hyperlink"],
  "). The other sides of the battery casing are not conductive. Find the \
potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " everywhere inside the battery. "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008T0001Q2000`400?l00000o`00003oo`3ooooo
0?ooobH0oooo003o0?ooool0oooo9P3oool00?l0ooooo`3ooolV0?ooo`00o`3ooooo0?ooobH0oooo
003o0?ooool0oooo9P3oool00?l0ooooo`3ooolV0?ooo`00o`3ooooo0?ooobH0oooo003o0?ooool0
oooo9P3oool00?l0ooooo`3ooolV0?ooo`00o`3ooooo0?ooobH0oooo003o0?ooool0oooo9P3oool0
0?l0ooooo`3ooolV0?ooo`00o`3ooooo0?ooobH0oooo003o0?ooool0oooo9P3oool00?l0ooooo`3o
oolV0?ooo`00o`3ooooo0?ooobH0oooo003o0?ooool0oooo9P3oool00?l0ooooo`3ooolV0?ooo`00
MP3oool00`30`<00@4100000000<000000030410@03oool0000000L0oooo00<0@410000000000000
200000000`20P800oooo0?ooo`1Y0?ooo`030820P0000000000000`0000000<0`<300820P020P800
1P3oool00`30`<00000000000008000000030410@03oool0oooo0?P0oooo001h0?ooo`040820P000
000000000<30`0H0oooo00L0`<300820P010@40000000?ooo`10@400P82000L0oooo00<0@4100000
000000002000001]0?ooo`80000000<0P8200?ooo`3oool01@3oool20820P00400000020P800`<30
0410@0L0oooo00<0`<300000000000002000003j0?ooo`00N03oool00`20P80000000000000:0?oo
o`040410@020P800P820000000P0oooo00<0P8200<30`03oool01P3oool20820P6`0oooo0P00000:
0?ooo`040<30`0000000oooo000000P0oooo00<0`<300820P03oool01P3oool00`30`<00P8200?oo
o`3h0?ooo`00N03oool00`20P80000000000000;0?ooo`80P82000<000000820P03oool01`3oool0
0`20P800oooo0?ooo`060?ooo`030820P03oool0oooo06X0oooo0P00000;0?ooo`040820P03oool0
0000000000T0oooo00<0P8200?ooo`3oool01@3oool00`20P800oooo0?ooo`3g0?ooo`00N03oool0
0`20P80000000000000;0?ooo`040820P03oool000000820P0T0oooo00<0P8200?ooo`3oool0LP3o
ool2000000/0oooo0P30`<000`20P80000000?ooo`080?ooo`80`<30o`3oool10?ooo`00N03oool0
0`20P80000000000000=0?ooo`030820P010@400oooo00T0oooo00<0P8200?ooo`3oool0L@3oool2
000000d0oooo00<0`<3000000030`<002@3oool20<30`?l0oooo001h0?ooo`030820P00000000000
00h0oooo00<000000?ooo`3oool02@3oool00`20P800oooo0?ooo`1`0?ooo`8000003P3oool00`00
0000P8200?ooo`090?ooo`80`<30oP3oool007P0oooo00<0P8200000000000003P3oool20820P0X0
oooo00<0`<3000000030`<00L03oool2000000l0oooo00<000000?ooo`3oool02@3oool00`10@400
P8200?ooo`3l0?ooo`00N03oool00`20P80000000000000>0?ooo`80P820303oool00`000000oooo
0?ooo`1^0?ooo`8000003`3oool00`000000oooo0?ooo`0:0?ooo`0300000020P800oooo0?/0oooo
001h0?ooo`030820P0000000000000h0oooo00<0`<300410@03oool02`3oool20410@6l0oooo0P00
000?0?ooo`030410@030`<00oooo00X0oooo00<0P82000000030`<00n`3oool007P0oooo00<0P820
0000000000003`3oool00`000000oooo0?ooo`0:0?ooo`030<30`0000000`<3006h0oooo0P00000?
0?ooo`80P820303oool20410@?/0oooo001h0?ooo`030820P0000000000000l0oooo0P20P80<0?oo
o`0300000010@400oooo06d0oooo0P00000@0?ooo`030000003oool0oooo00X0oooo00<0P8200000
0030`<00nP3oool007P0oooo00<0P8200000000000003`3oool20820P0<0oooo00<0`<300?ooo`3o
ool01P3oool2000006h0oooo0P00000@0?ooo`050000003oool0oooo0?ooo`30`<00203oool00`20
P80000000820P03j0?ooo`00N03oool00`20P80000000000000@0?ooo`050000003oool0oooo0?oo
o`000000203oool2000006h0oooo0P00000@0?ooo`80P8200P3oool20820P0L0oooo00<0P8200000
0020P800nP3oool007P0oooo00<0P820000000000000403oool010000000oooo0?ooo`3oool20820
P0H0oooo00<0P820000000000000KP3oool200000100oooo0P20P8030?ooo`030000003oool0oooo
00D0oooo0P0000000`20P800oooo0?ooo`3h0?ooo`00N03oool00`20P80000000000000@0?ooo`03
0820P0000000oooo0080oooo00<000000820P030`<000P3oool01@30`<00P820000000000000P820
06h0oooo0P00000A0?ooo`070000003oool0oooo0?ooo`20P800@4100820P0030?ooo`040820P000
0000000000000?/0oooo001h0?ooo`040410@000000000000<30`0l0oooo00<0P8200000003oool0
0P3oool00`30`<00000000000005000000030410@03oool0oooo06`0oooo00@0`<30000000000000
P820403oool00`000000oooo0?ooo`020?ooo`030410@0000000000000D0000000<0`<300?ooo`3o
ool0n@3oool007L0oooo00<0P8200000000000000P00000@0?ooo`0300000020P800oooo00<0oooo
1P00001_0?ooo`@0000000<0P8200?ooo`3oool03@3oool20820P0@0oooo1P0000000`20P800oooo
0?ooo`3j0?ooo`00MP3oool00`30`<00P8200820P0040820P0l0oooo00<000000820P03oool0103o
ool01030`<00P8200820P020P81_0?ooo`H0P82000<0`<300?ooo`3oool0303oool20820P0H0oooo
0`20P83n0?ooo`00o`3ooooo0?ooobH0oooo003o0?ooool0oooo9P3oool00?l0ooooo`3ooolV0?oo
o`00o`3ooooo0?ooobH0oooo003o0?ooool0oooo9P3oool00?l0ooooo`3ooolV0?ooo`00o`3ooooo
0?ooobH0oooo003o0?ooool0oooo9P3oool00?l0ooooo`3ooolV0?ooo`00o`3ooooo0?ooobH0oooo
001Q0?ooo`050820P0000000000000000030`<00@P3oool01@20P800000000000010@400`<3004<0
oooo00D0`<300410@000000000000410@0120?ooo`050<30`0000000000000000020P800j03oool0
05l0oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`100?ooo`H0000000<0P8200?oo
o`3oool0?@3oool00`20P800@4100000000400000480oooo00<0P8200000000000000`0000000`20
P800`<300?ooo`3T0?ooo`00G03oool00`20P80000000000000700000440oooo00<0P82000000000
00001`00000k0?ooo`T0000000<0P8200?ooo`3oool0?`3oool9000000030820P03oool0oooo0>40
oooo001I0?ooo`030820P010@400000000X00000@@3oool00`20P800000000000009000000030410
@020P800oooo0380oooo00<0`<300820P00000002P0000000`20P800oooo0?ooo`0o0?ooo``00000
00<0P8200<30`03oool0gP3oool005H0oooo00<0P8200410@00000003@0000000`30`<00oooo0?oo
o`0n0?ooo`030820P0000000000000`000000P20P80]0?ooo`80P8203P0000000`10@400oooo0?oo
o`0o0?ooo`h0000000<0@4100820P030`<00g03oool005<0oooo00<0`<300410@000000040000000
0`20P800oooo0?ooo`0n0?oooa80000000<0P8200<30`03oool09`3oool00`20P80000000000000@
00000400oooo00<0P8200000000000003`0000000`10@400P8200?ooo`3I0?ooo`00D03oool20820
P1@0000000<0P8200?ooo`3oool0?P3ooolE000000030820P030`<00oooo0200oooo00<0`<300820
P010@400500000100?ooo`030820P00000000000018000000P20P83G0?ooo`00CP3oool00`20P800
00000000000E000000030820P03oool0oooo03h0oooo6000000O0?oooaP00000@03oool00`20P800
00000000000E000000030820P03oool0oooo0=<0oooo001<0?ooo`030820P010@400000007800000
00<0P8200?ooo`3oool05`3oool20820P7<0000000<0P8200<30`03oool0A03oool00`20P800`<30
0?ooo`2:0?ooo`00C@3oool00`20P800@4100000001_00000080P8206`3oool20820P700000000<0
@4100820P03oool0=`3oool;0820P0070<30`03oool0oooo0?ooo`20P80000000<30`02:0?ooo`00
D03oool20820P1@0000000<0P8200?ooo`3oool0?@3oool00`30`<0000000000000C000000030410
@030`<00oooo0200oooo00<0`<300820P010@400500000000`20P800oooo0?ooo`0m0?ooo`030410
@0000000000001<0000000<0P8200?ooo`3oool0>P3oool2000000030<30`03oool0oooo00@0oooo
00<0@4100820P03oool00P3oool01020P800000000000020P8290?ooo`00D`3oool00`20P800@410
0000000@000000030820P03oool0oooo03h0oooo4P0000000`20P800`<300?ooo`0V0?ooo`030<30
`020P800000001400000@03oool00`20P80000000000000?000000030410@020P800oooo03h0oooo
00<0`<300000000000001`3oool01@20P800oooo0?ooo`3oool0P82000<0000000<0@4100<30`03o
ool0QP3oool005H0oooo00<0P8200000000000003@0000000`20P800oooo0?ooo`0n0?oooa000000
00<0P8200?ooo`3oool0;03oool@00000400oooo00<0P8200000000000003P0000130?ooo`<00000
1P3oool00`20P800oooo0?ooo`020?ooo`D00000Q`3oool005P0oooo0P20P80<000000030<30`03o
ool0oooo03h0oooo00<0P8200000000000002P0000000`20P800`<300?ooo`0`0?ooo`030<30`020
P800000000/0000000<0@4100?ooo`3oool0?`3oool<000000030410@020P800oooo04@0oooo00@0
`<30000000000000`<302P3oool5000000030410@03oool0oooo08@0oooo001K0?ooo`030<30`020
P800000000P00000@@3oool00`20P800000000000006000000030410@020P800oooo03P0oooo00<0
P8200410@00000001`0000000`20P800oooo0?ooo`0o0?ooo`T0000000<0P8200<30`03oool0B03o
ool00`10@40000000000000:0?ooo`H0000000<0@4100?ooo`3oool0P`3oool005l0oooo00<0P820
0000000000000`0000000`10@400oooo0?ooo`100?ooo`H0000000<0P8200<30`03oool0?@3oool0
0`20P800@41000000004000000030<30`03oool0oooo03l0oooo00<0P8200000000000000`000002
0820P4d0oooo0P0000000`10@400oooo0?ooo`070?ooo`P0000000<0`<300?ooo`3oool0P@3oool0
0640oooo00D0P82000000000000000000820P0120?ooo`@00000A@3oool400000480oooo00D0P820
00000000000000000820P01A0?ooo`8000002@3oool00`20P800000000000006000008<0oooo001S
0?ooo`<0P820@P3oool00`000000P8200<30`0170?ooo`030<30`020P800@4100480oooo0`20P81C
0?ooo`030410@0000000@41000P0oooo00<0P8200000000000001P0000000`10@400oooo0?ooo`20
0?ooo`00o`3ooon?0?ooo`80000000<0`<300?ooo`3oool01@3oool00`20P8000000000000070000
00030410@03oool0oooo07l0oooo003o0?ooohX0oooo00<0P8200?ooo`3oool00P3oool00`30`<00
0000000000070?ooo`030820P0000000000000P0000000<0@4100?ooo`3oool0OP3oool00?l0oooo
RP3oool00`20P800oooo0?ooo`030?ooo`040410@000000000000<30`0D0oooo00<0`<3000000000
00002P0000000`30`<00oooo0?ooo`1l0?ooo`00o`3ooon:0?ooo`030000003oool0oooo00@0oooo
0P0000000`20P800oooo0?ooo`040?ooo`d0000000<0P8200?ooo`3oool0N`3oool00?l0ooooRP3o
ool:0820P0H0oooo3P0000000`30`<00oooo0?ooo`1j0?ooo`00o`3ooonJ0?ooo`l0000000<0P820
0?ooo`3oool0N@3oool00?l0ooooVP3oool00`20P80000000000000=000000030410@03oool0oooo
07P0oooo003o0?oooiX0oooo00<0P8200000000000003P0000000`10@400oooo0?ooo`1g0?ooo`00
o`3ooonK0?oooa400000N@3oool00?l0ooooV`3oool?000000030410@03oool0oooo07P0oooo001W
0?ooo`@0P8205P3oool00`30`<00oooo0?ooo`0<0?ooo`050<30`020P800P8200820P030`<001@3o
ool60820P0D0oooo0P20P8130?ooo`030<30`020P800P82000D0P8200`3oool00`30`<00P8200820
P0080820P0030<30`03oool0oooo0140oooo00<0`<300?ooo`3oool0303oool01@30`<00P8200820
P020P800`<3000D0oooo1@20P8000`30`<00oooo0?ooo`020?ooo`030<30`020P800P8200600oooo
3P0000000`20P800oooo0?ooo`1i0?ooo`00I@3oool00`30`<0000000820P0020?ooo`030<30`010
@400P82001@0oooo00<0@4100820P03oool02P3oool01030`<00@4100410@020P8020?ooo`030<30
`010@400P82000@0oooo00@0`<30000000000000`<301@3oool4000000030820P03oool0oooo0440
oooo00@0`<30000000000000@4101P3oool00`10@400000000000008000001<0oooo00<0@4100820
P03oool02P3oool01020P800@4100410@030`<020?ooo`030<30`010@400`<3000@0oooo00@0@410
000000000000`<301@3oool4000000030<30`03oool0oooo05`0oooo00<0P8200000000000002P00
00000`30`<00oooo0?ooo`1j0?ooo`00I@3oool00`000000P8200?ooo`040?ooo`0300000020P800
oooo0180oooo00<000000820P03oool02P3oool2000000D0oooo00<0P82000000020P800103oool2
000000D0oooo00H0P820000000000000P8200?ooo`0000140?ooo`80000000<0P8200?ooo`3oool0
1@3oool:000001<0oooo00<000000820P03oool02@3oool00`20P8000000000000050?ooo`030820
P0000000oooo00<0oooo00<0P8200000000000001@3oool00`20P8000000000000020?ooo`030820
P03oool0oooo05d0oooo2`0000000`20P800oooo0?ooo`1k0?ooo`00I03oool00`20P80000000?oo
o`050?ooo`030820P0000000oooo0140oooo00<0P8200000000000002P3oool00`20P80000000820
P0060?ooo`800000103oool2000000D0oooo00<0P8200000000000000`3oool00`30`<00oooo0?oo
o`110?ooo`80000000<0P8200?ooo`3oool01P3oool00`20P800oooo0?ooo`050?ooo`030<30`000
0000oooo0100oooo0`00000:0?ooo`80000000<0P8200?ooo`3oool0103oool00`000000P8200?oo
o`020?ooo`030820P0000000000000D0oooo00<0P82000000020P8000P3oool00`30`<00oooo0?oo
o`1M0?ooo`X0000000<0P8200?ooo`3oool0O03oool006@0oooo00<000000820P03oool01P3oool0
0`000000P8200?ooo`0@0?ooo`80000000<0@4100000003oool0203oool2000000P0oooo00<00000
0820P03oool00P3oool2000000D0oooo00<0P820000000000000A`3oool2000000030820P03oool0
oooo00L0oooo00<0P8200?ooo`3oool01P3oool00`30`<00oooo0?ooo`0=0?ooo`050820P0000000
00000410@020P800203oool00`20P8000000000000070?ooo`030820P0000000oooo0080oooo00<0
P8200000000000001@3oool00`20P80000000820P01R0?ooo`L0000000@0P820000000000000P820
OP3oool006<0oooo0P0000000`30`<00oooo0?ooo`050?ooo`030410@0000000oooo00l0oooo00H0
P82000000010@400P82000000030`<070?ooo`80000000<0@4100?ooo`3oool01P3oool2000000<0
oooo0P0000050?ooo`030820P0000000000004L0oooo0P0000000`20P800oooo0?ooo`080?ooo`03
0820P03oool0oooo01D0oooo0P0000000`10@400P8200410@0080?ooo`80000000<0P8200?ooo`3o
ool01@3oool00`20P8000000000000020?ooo`030820P0000000000000D0oooo00<0P82000000020
P800HP3oool01P20P800000000000010@400P8200<30`080oooo00<0P820000000000000OP3oool0
0680oooo00<0`<30000000000000203oool00`20P80000000?ooo`0?0?ooo`060410@0000000`<30
0?ooo`000000P8201`3oool2000000030820P03oool0oooo00H0oooo0P0000030?ooo`8000001@3o
ool00`20P8000000000000170?ooo`80000000<0P8200?ooo`3oool02@3oool00`20P800oooo0?oo
o`0C0?ooo`060<30`000000000000<30`03oool00000203oool2000000P0oooo00<0P82000000000
00000P3oool00`20P8000000000000050?ooo`030820P0000000P82006/0oooo0P0000000`20P800
oooo0?ooo`1k0?ooo`00HP3oool00`20P8000000000000080?ooo`030820P0000000P82000l0oooo
0P0000030?ooo`030000003oool0oooo00D0oooo0P0000000`20P800oooo0?ooo`060?ooo`800000
0`3oool2000000D0oooo00<0P820000000000000A`3oool2000000030820P03oool0oooo00X0oooo
00<000000?ooo`3oool04P3oool00`20P8000000000000020?ooo`80P8201`3oool2000000P0oooo
00<0P8200000000000000P3oool00`20P8000000000000050?ooo`030820P0000000P82006`0oooo
0P00001m0?ooo`00HP3oool00`20P8000000000000080?ooo`030820P0000000P82000h0oooo0P00
00001@10@400oooo0?ooo`3oool0000000L0oooo0P0000000`20P800oooo0?ooo`050?ooo`030820
P0000000000000<0oooo0P0000050?ooo`030820P0000000000004L0oooo0P0000000`20P800oooo
0?ooo`0:0?ooo`030820P010@400oooo0180oooo0P0000000`20P800oooo0?ooo`020820P0L0oooo
0P0000080?ooo`030410@000000000000080oooo00<0P8200000000000001@3oool00`20P8000000
0820P01/0?ooo`030410@0000000`<3007`0oooo001R0?ooo`030820P0000000000000P0oooo00<0
P82000000020P8003@3oool01020P800000000000030`<030?ooo`80P8201`3oool00`000000P820
0?ooo`060?ooo`80000000@0P8200?ooo`3oool0oooo0P0000050?ooo`030820P0000000000004L0
oooo0P0000000`20P800oooo0?ooo`0;0?ooo`030820P010@400oooo0100oooo00<0P82000000010
@400103oool00`000000oooo0?ooo`050?ooo`030820P0000000oooo00L0oooo0P0000030?ooo`03
0820P0000000000000D0oooo00<0P82000000020P800K03oool00`30`<0000000000001l0?ooo`00
HP3oool00`20P8000000000000080?ooo`030820P0000000P82000d0oooo00<0@41000000010@400
103oool00`30`<00@4100?ooo`060?ooo`030820P0000000oooo00D0oooo00@0P820000000000000
`<300`3oool2000000D0oooo00<0P820000000000000A`3oool2000000030820P03oool0oooo00`0
oooo00<000000820P03oool03`3oool00`10@40000000<30`0040?ooo`030410@020P800oooo00H0
oooo0P0000060?ooo`030820P0000000@41000<0oooo00<0P8200000000000001@3oool00`20P800
00000820P01]0?ooo`030820P0000000000007/0oooo001R0?ooo`030820P0000000000000P0oooo
00<0P82000000020P800303oool01030`<00000000000020P8050?ooo`0300000030`<00oooo00H0
oooo0P10@4040?ooo`040<30`000000000000<30`0@0oooo0P0000050?ooo`030820P00000000000
04L0oooo0P0000000`20P800oooo0?ooo`0<0?ooo`030820P0000000oooo00h0oooo00<0P8200000
000000001@3oool00`20P80000000<30`0060?ooo`030<30`0000000@41000@0oooo00<0`<300000
0010@400103oool00`20P8000000000000050?ooo`030820P0000000P82006h0oooo0P0000000`20
P800oooo0?ooo`1h0?ooo`00HP3oool00`20P8000000000000080?ooo`030820P0000000P82000`0
oooo00<0P8200000000000001P3oool20820P0P0oooo00L000000820P03oool0oooo0820P0000000
P82000H0oooo0P0000050?ooo`030820P0000000000004L0oooo0P0000000`20P800oooo0?ooo`0<
0?ooo`030820P0000000P82000h0oooo0P0000000`20P800oooo0?ooo`040?ooo`0300000020P800
oooo00L0oooo00@000000820P03oool0oooo0P0000000`20P800oooo0?ooo`030?ooo`030820P000
0000000000D0oooo00<0P82000000020P800KP3oool00`20P80000000000001j0?ooo`00H`3oool2
000000030<30`03oool0oooo00D0oooo00<0@4100000003oool0303oool2000000030820P03oool0
oooo00@0oooo00<0`<300410@03oool0203oool01@30`<00P8200820P020P800`<3000L0oooo0P00
00040?ooo`040820P00000000000000000<0P820A03oool2000000030820P03oool0oooo00<0oooo
00<0`<300?ooo`3oool01P3oool00`20P80000000820P00=0?ooo`040820P000000000000<30`0H0
oooo00<0P8200410@03oool0203oool01@30`<00P8200820P020P800`<3000H0oooo00<0P8200000
00000000103oool01020P800000000000010@4020820P0030<30`03oool0oooo06T0oooo00@0`<30
000000000000`<30N@3oool006<0oooo00<0P82000000020P8001`3oool00`000000@4100?ooo`0;
0?ooo`030820P0000000@41000P0oooo00<000000?ooo`3oool04`3oool2000000D0oooo00<0`<30
000000000000A`3oool2000000030820P03oool0oooo00<0oooo00<0`<300410@03oool01P3oool0
0`10@40000000820P00=0?ooo`80000000<0@4100?ooo`3oool01P3oool00`000000oooo0?ooo`0B
0?ooo`030820P0000000000000D0oooo00<0`<3000000020P800K`3oool00`20P80000000410@01i
0?ooo`00I03oool20410@0H0oooo00<0P82000000030`<00303oool00`10@40000000820P0080?oo
o`80P820503oool2000000L0oooo00<000000?ooo`3oool0A@3oool2000000030820P03oool0oooo
00@0oooo00<0@4100820P03oool0103oool01030`<00000000000030`<0<0?ooo`040<30`0000000
00000820P0P0oooo0P20P80C0?ooo`030820P0000000000000H0oooo0P20P81`0?ooo`030410@000
0000`<3007P0oooo001T0?ooo`030820P0000000oooo00D0oooo0P00000=0?ooo`8000002@3oool2
0820P1@0oooo0P0000070?ooo`030820P03oool0oooo0480oooo00<0P8200?ooo`3oool00P000000
0`20P800oooo0?ooo`040?ooo`030820P0000000000000<0oooo1000000=0?ooo`030820P0000000
000000T0oooo0P20P80C0?ooo`030820P0000000000000L0oooo00<0P8200?ooo`3oool0KP3oool0
0`20P80000000820P01h0?ooo`00I@3oool20410@0@0oooo00<0@41000000030`<00303oool30000
00T0oooo00<0P8200000003oool04`3oool2000004d0oooo00D0P82000000000000000000820P007
0?ooo`030820P0000000000000D0000000<0`<300?ooo`3oool02`3oool3000000T0oooo00<0P820
0000003oool04P3oool00`20P80000000000001i0?ooo`800000N03oool006H0oooo00H0P8200000
0020P800P8200410@020P80<0?ooo`030<30`010@4000000008000000P20P8000`30`<00oooo0?oo
o`030?ooo`050820P010@400000000000010@400403oool01020P800@41000000000001?0?ooo`<0
P820203oool00`30`<00P82000000002000000030410@030`<00oooo00/0oooo00<0`<300410@000
00000P0000020820P0D0oooo00<0`<300820P010@4000P0000000`30`<00oooo0?ooo`0>0?ooo`04
0820P00000000000000007T0oooo00<0P82000000010@400M`3oool009d0oooo00<0P8200?ooo`3o
ool0T03oool00`20P800oooo0?ooo`1h0?ooo`030410@0000000P82003T0oooo00@0@41000000020
P800`<30>@3oool00?l0oooo[03oool01030`<00000000000030`<0h0?ooo`D0000000<0P8200<30
`03oool0=@3oool00?l0oooo[@3oool2000000030820P03oool0oooo03D0oooo00<0P82000000000
00001P0000000`20P800oooo0?ooo`0b0?ooo`00@@3oool2000000030820P03oool0oooo0?l0oooo
5P3oool00`20P80000000000001>0?ooo`030820P0000000000003L0oooo00<0P820000000000000
1`0000000`10@400P8200?ooo`0a0?ooo`00@@3ooon:000000030820P03oool0oooo00H0ooooRP00
001?0?ooo`80000000<0P8200?ooo`3oool0=03oool00`20P80000000000000;000000030410@020
P800`<3002d0oooo000]0?ooo`030<30`03oool0oooo0140ooooRP0000000`20P800oooo0?ooo`06
0?ooohX00000D03oool2000003H0oooo4P0000000`20P800`<300?ooo`0Y0?ooo`00;03oool20820
P1<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D03oool01020
P80000000410@020P80d0?oooa@0000000<0@4100820P020P8009`3oool002`0oooo00<0P8200000
003oool04P3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P80000000000001A0?oo
o`<00000=03ooolH000000030820P03oool0oooo02<0oooo000/0?ooo`8000004`3oool200000003
0820P03oool0oooo0?l0oooo5P3oool00`20P80000000000001A0?ooo`030410@0000000000004d0
000000<0@4100<30`03oool08P3oool002/0oooo0`0000000`20P800oooo0?ooo`0@0?ooo`800000
00<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000540oooo00<0P820000000000000
CP0000020820P280oooo000Z0?ooo`050<30`0000000000000000010@4004P3oool2000000030820
P03oool0oooo0?l0oooo5P3oool00`20P80000000000001A0?ooo`030820P0000000000003@0oooo
5`0000000`20P800`<300?ooo`0T0?ooo`00:P3oool00`20P80000000000000200000180oooo0P00
00000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P80000000000
000d0?oooaD00000:@3oool002X0oooo00<0@4100000000000000`00000A0?ooo`80000000<0P820
0?ooo`3oool0o`3ooolF0?ooo`030820P000000000000540oooo00<0P820000000000000=03ooolB
000000030820P030`<00oooo02T0oooo000Y0?ooo`030<30`0000000000000@0000000<0`<300?oo
o`3oool03P3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P80000000000001A0?oo
o`030820P0000000000003@0oooo00<0@410000000000000300000000`20P800oooo0?ooo`0/0?oo
o`00:@3oool00`20P800000000000004000000030820P03oool0oooo00h0oooo0P0000000`20P800
oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P80000000000000d0?ooo`03
0820P0000000000000P0000000<0@4100820P03oool04P3oool01030`<00@4100410@030`<030?oo
o`030<30`010@40000000080000000<0P8200?ooo`3oool03`3oool002T0oooo2000000@0?ooo`80
000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000540oooo00<0P82000000000
0000=03oool00`30`<0000000000000500000080P820603oool00`20P800oooo0?ooo`030?ooo`04
0410@000000000000<30`180oooo000X0?ooo`030820P0000000000000H00000403oool200000003
0820P03oool0oooo0?l0oooo5P3oool00`20P80000000000001A0?ooo`030820P0000000000003D0
oooo1@0000000`20P800oooo0?ooo`0I0?ooo`030820P03oool0oooo00<0oooo0P0000000`20P800
oooo0?ooo`0A0?ooo`00:03oool00`20P800000000000006000000030820P03oool0oooo00d0oooo
0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P8000000
0000000e0?ooo`040820P0000000P8200820P1h0oooo00D0P8200?ooo`3oool0oooo0820P0020000
00030<30`03oool0oooo0140oooo000X0?ooo`T0000000<0@4100?ooo`3oool03@3oool200000003
0820P03oool0oooo0?l0oooo5P3oool00`20P80000000000001A0?ooo`030820P0000000000005L0
oooo00@0`<300820P03oool0`<300P00000E0?ooo`009`3oool00`20P800000000000008000000l0
oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P800
00000000001I0?ooo`040820P010@40000000820P1D0oooo000W0?ooo`030410@0000000000000P0
000000<0P8200?ooo`3oool0303oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P800
00000000001A0?ooo`030820P0000000000005T0oooo00<0P82000000010@4005P3oool002L0oooo
2`0000000`20P800oooo0?ooo`0<0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820
P000000000000540oooo00<0P820000000000000F@3oool2000000030820P03oool0oooo01@0oooo
000V0?ooo`030820P0000000000000X000003P3oool2000000030820P03oool0oooo0?l0oooo5P3o
ool00`20P80000000000001A0?ooo`030820P0000000000005P0oooo0P0000000`10@400`<300?oo
o`0E0?ooo`009@3oool00`30`<0000000000000;000000030<30`03oool0oooo00/0oooo0P000000
0`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P80000000000001G
0?ooo`050410@000000000000<30`020P8005P3oool002D0oooo00<0P8200000000000002`000000
0`10@400oooo0?ooo`0;0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P0000000
00000540oooo00<0P820000000000000EP3oool01030`<00000000000020P8020?ooo`030820P03o
ool0oooo01<0oooo000U0?ooo`030820P0000000000000`000003@3oool2000000030820P03oool0
oooo0?l0oooo5P3oool00`20P80000000000001A0?ooo`030820P0000000000005H0oooo0`000003
0?ooo`030820P03oool0oooo01<0oooo000U0?ooo`l0000000<0P8200?ooo`3oool02P3oool20000
00030820P03oool0oooo0?l0oooo5P3oool00`20P80000000000001A0?ooo`030820P00000000000
05@0oooo00<0`<300410@00000000P0000001`10@400oooo0<30`010@40000000410@020P8004P3o
ool002@0oooo00<0`<300000000000003P00000<0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF
0?ooo`030820P000000000000540oooo00<0P820000000000000LP3oool002@0oooo00<0P8200000
000000003P0000000`20P800oooo0?ooo`090?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?oo
o`030820P000000000000540oooo00<0P820000000000000LP3oool002@0oooo00<0@41000000000
00003P0000000`10@400oooo0?ooo`090?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`03
0820P000000000000540oooo00<0P820000000000000LP3oool002@0oooo4P00000;0?ooo`800000
00<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000540oooo00<0P820000000000000
LP3oool002D0oooo00<0`<300820P010@4002P0000001010@400P8200820P030`<0;0?ooo`800000
00<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000540oooo00<0P820000000000000
LP3oool002T0oooo00<0P8200410@00000000P0000020820P0030<30`03oool0oooo00h0oooo0P00
00000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P80000000000
001b0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820
000000000000D@3oool00`20P80000000000001b0?ooo`00;03oool2000001<0oooo0P0000000`20
P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P80000000000001b0?oo
o`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P82000000000
0000D@3oool00`20P80000000000001b0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo
0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P80000000000001b0?ooo`00;03o
ool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3o
ool00`20P80000000000001b0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o
0?oooaH0oooo00<0P820000000000000D@3oool00`20P80000000000001b0?ooo`00;03oool20000
01<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20
P80000000000001b0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0
oooo00<0P820000000000000D@3oool00`20P80000000000001b0?ooo`00;03oool2000001<0oooo
0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P8000000
0000001b0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0
P820000000000000D@3oool00`20P80000000000001b0?ooo`00;03oool2000001<0oooo0P000000
0`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P80000000000001b
0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P8200000
00000000D@3oool00`20P80000000000001b0?ooo`00;03oool2000001<0oooo0P0000000`20P800
oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P80000000000001b0?ooo`00
;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000
D@3oool00`20P80000000000001b0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?oo
o`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P80000000000001b0?ooo`00;03oool2
000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool0
0`20P80000000000001b0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oo
oaH0oooo00<0P820000000000000D@3oool00`20P80000000000001b0?ooo`00;03oool2000001<0
oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P800
00000000001b0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo
00<0P820000000000000D@3oool00`20P80000000000001b0?ooo`00;03oool2000001<0oooo0P00
00000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P80000000000
001b0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820
000000000000D@3oool00`20P80000000000001b0?ooo`00;03oool2000001<0oooo0P0000000`20
P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P80000000000001b0?oo
o`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P82000000000
0000D@3oool00`20P80000000000001b0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo
0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20P80000000000001b0?ooo`00;03o
ool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3o
ool00`20P80000000000001b0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o
0?oooaH0oooo00<0P820000000000000D@3oool00`20P80000000000001b0?ooo`00;03oool20000
01<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D@3oool00`20
P80000000000001b0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0
oooo00<0P820000000000000C03oool00`30`<00P8200820P0020820P0030410@0000000000000@0
P820KP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820
P0000000000004T0oooo00<0`<300820P00000003P0000000`20P800`<300?ooo`1Y0?ooo`00;03o
ool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000B@3o
ool00`10@40000000000000?000000030<30`03oool0oooo06P0oooo000/0?ooo`8000004`3oool2
000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000190?ooo`030820P0000000
000000l00000J`3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?oo
o`030820P0000000000004T0oooo00<0`<300000000000003P0000000`10@400oooo0?ooo`1Y0?oo
o`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P82000000000
0000BP3oool@000000030<30`03oool0oooo06T0oooo000/0?ooo`8000004`3oool2000000030820
P03oool0oooo0?l0oooo5P3oool00`20P80000000000001;0?ooo`l00000K03oool002`0oooo0P00
000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P0000000000004/0oooo3P00
00000`20P800oooo0?ooo`1Z0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o
0?oooaH0oooo00<0P820000000000000B`3oool00`20P80000000000000;000000030820P03oool0
oooo06X0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20
P80000000000001<0?ooo`d00000K@3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooolF0?ooo`030820P0000000000004`0oooo00<0@4100000000000002@0000000`20P800
oooo0?ooo`1[0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo
00<0P820000000000000C03oool00`20P800000000000008000000030410@03oool0oooo06`0oooo
000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P80000000000
001=0?ooo`X0000000<0P8200?ooo`3oool0K03oool002`0oooo0P00000C0?ooo`80000000<0P820
0?ooo`3oool0o`3ooolF0?ooo`030820P0000000000004d0oooo2P0000000`30`<00oooo0?ooo`1/
0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P8200000
00000000C@3oool00`20P800000000000007000000L0oooo00D0`<300410@000000000000<30`01S
0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P8200000
00000000C@3oool00`30`<00000000000006000000030820P03oool0oooo00D0oooo00<0P8200000
000000000P0000000`30`<00oooo0?ooo`1P0?ooo`00;03oool2000001<0oooo0P0000000`20P800
oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000CP3oool8000000T0oooo0P20P8000`3oool0
`<300000001R0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo
00<0P820000000000000CP3oool00`20P800000000000005000000d0oooo0P20P81Q0?ooo`00;03o
ool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000CP3o
ool00`20P800000000000004000000030410@03oool0oooo00`0oooo00<0P8200?ooo`3oool0G`3o
ool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P0000000
000004l0oooo1P0000000`20P800oooo0?ooo`0<0?ooo`030820P03oool0oooo05l0oooo000/0?oo
o`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P80000000000001?0?oo
o`030820P0000000000000<000003`3oool00`10@400P8200?ooo`1O0?ooo`00;03oool2000001<0
oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000D03oool5000000l0
oooo00<000000820P03oool0G`3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolF0?ooo`030820P000000000000500oooo00D0P82000000000000000000820P00>0?ooo`03
0820P000000000000600oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo
5P3oool00`20P80000000000001@0?ooo`040<30`00000000000000000l0oooo0P0000020820P5l0
oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000
0000001A0?ooo`80000000<0P8200?ooo`3oool0303oool01P20P80000000410@03oool000000<30
`5h0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P800
00000000001A0?ooo`030820P0000000oooo00h0oooo00<0@41000000030`<000P3oool00`20P800
oooo0?ooo`1L0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo
00<0P820000000000000D@3oool20820P0l0oooo0P0000030?ooo`030820P03oool0oooo05`0oooo
000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P80000000000
001B0?ooo`030<30`03oool0oooo00`0oooo0P0000001@10@400oooo0?ooo`3oool0P82005h0oooo
000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P80000000000
001P0?ooo`040820P000000000000<30`0@0oooo00<0P8200?ooo`3oool0F`3oool002`0oooo0P00
000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000600oooo0P00
00000`10@400oooo0?ooo`030?ooo`030820P03oool0oooo05/0oooo000/0?ooo`8000004`3oool2
000000030820P03oool0oooo0?l0oooo5P3oool00`20P80000000000001O0?ooo`040820P0000000
00000<30`0D0oooo00<0P8200<30`03oool0F`3oool002`0oooo0P00000C0?ooo`80000000<0P820
0?ooo`3oool0o`3ooolF0?ooo`030820P0000000000005l0oooo0`0000070?ooo`030820P03oool0
oooo05X0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20
P80000000000001N0?ooo`060410@0000000000000000010@400`<300`3oool01030`<00@4100000
0030`<1K0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0
P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF
0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo
0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800
oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`800000
00<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3o
ool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2
000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool0
02`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P00000000000
0<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P800
0000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo
00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3o
oolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0
oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20
P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80
000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`800000
4`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03o
ool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3o
ool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P0000000
00000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20
P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0
oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03o
ool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P000000
0`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?oo
o`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`80
00004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00
;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000
aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000
000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool0
0`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oo
oaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820
P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P00
00000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C
0?ooo`80000000<0P8200?ooo`3oool0Q`3oool40820P0030<30`03oool0oooo08L0oooo00<0P820
000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0Q03oool01030
`<00@41000000020P8030?ooo`040<30`020P800@4100<30`8H0oooo00<0P820000000000000aP3o
ool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0P`3oool01020P800000000000030
`<060?ooo`030410@0000000`<3008D0oooo00<0P820000000000000aP3oool002`0oooo0P00000C
0?ooo`80000000<0P8200?ooo`3oool0PP3oool01020P800000000000010@4080?ooo`800000Q@3o
ool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`22
0?ooo`<0000000<0P8200?ooo`3oool01P3oool2000008D0oooo00<0P820000000000000aP3oool0
02`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0PP3oool3000000T0oooo0P0000000`20
P800oooo0?ooo`220?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool200000003
0820P03oool0oooo0880oooo0`0000090?ooo`80000000<0P8200?ooo`3oool0PP3oool00`20P800
0000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`220?ooo`<00000
2@3oool2000000030820P03oool0oooo0880oooo00<0P820000000000000aP3oool002`0oooo0P00
000C0?ooo`80000000<0P8200?ooo`3oool0PP3oool00`20P8000000000000080?ooo`030820P000
0000000008D0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P820
0?ooo`3oool0P`3oool2000000030820P03oool0oooo00D0oooo0P0000000`20P800oooo0?ooo`23
0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo
08<0oooo00<0P82000000010@4001P3oool00`20P80000000410@0260?ooo`030820P00000000000
0<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo08D0oooo0P10@4030?ooo`03
0<30`010@400000000@0000000<0P8200?ooo`3oool0P@3oool00`20P8000000000000360?ooo`00
;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`270?ooo`X0P82000<000000820P03oool0
P@3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?oo
o`3o0?oooaH0oooo00<0P820000000000000aP3oool000d0oooo00<0`<300410@000000030000000
0`10@400oooo0?ooo`0=0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool0
0`20P8000000000000360?ooo`00403oool2000000030<30`03oool0oooo00D0oooo00<0P8200410
@00000003`3oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P8200000
00000000aP3oool00100oooo0P00000:0?ooo`030410@0000000oooo00d0oooo0P00000C0?ooo`80
000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000@0?ooo`800000
2`3oool00`000000`<300?ooo`0<0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo
5P3oool00`20P8000000000000360?ooo`00403oool2000001X0oooo0P00000C0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000@0?ooo`8000006P3oool2
000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool0
0100oooo0P00000J0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20
P8000000000000360?ooo`00403oool2000001X0oooo0P00000C0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooolF0?ooo`030820P000000000000<H0oooo000@0?ooo`8000006P3oool2000001<0oooo
0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool00100oooo0P00
000J0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P80000000000
00360?ooo`00403oool2000001X0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF
0?ooo`030820P000000000000<H0oooo000@0?ooo`8000006P3oool2000001<0oooo0P0000000`20
P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool00100oooo0P00000J0?ooo`80
00004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00
403oool2000001X0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820
P000000000000<H0oooo000@0?ooo`8000006P3oool2000001<0oooo0P0000000`20P800oooo0?oo
o`3o0?oooaH0oooo00<0P820000000000000aP3oool00100oooo0P00000J0?ooo`8000004`3oool2
000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`003`3oool01020
P800000000000030`<0I0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool0
0`20P8000000000000360?ooo`003@3oool00`30`<00@41000000003000000030820P030`<00oooo
01H0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P00000000000
0<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P800
0000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo
00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3o
oolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0
oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20
P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80
000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`800000
4`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03o
ool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3o
ool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P0000000
00000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20
P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0
oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03o
ool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P000000
0`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?oo
o`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`80
00004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00
;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000
aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000
000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool0
0`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oo
oaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820
P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P00
00000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?oo
o`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?oo
o`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P82000000000
0000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820
P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3o
ool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o
0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?oo
o`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool200000003
0820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo
0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00
000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/
0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P800000000000036
0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P8200000
00000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`03
0820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo
5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?oo
o`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P820
0?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool20000
00030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0
oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo
0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo
000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P80000000000
00360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820
000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?oo
o`030820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0
oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo
0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool2
000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool20000
01<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0
oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0
oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000
000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0
P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF
0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo
0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800
oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`800000
00<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3o
ool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2
000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool0
02`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P00000000000
0<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P800
0000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo
00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3o
oolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0
oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20
P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80
000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`800000
4`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03o
ool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3o
ool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P0000000
00000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20
P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0
oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03o
ool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P000000
0`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?oo
o`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`80
00004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00
;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000
aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000
000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool0
0`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oo
oaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820
P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P00
00000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?oo
o`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?oo
o`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P82000000000
0000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820
P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3o
ool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o
0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?oo
o`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool200000003
0820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo
0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00
000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/
0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P800000000000036
0?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P8200000
00000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`03
0820P000000000000<H0oooo000/0?ooo`8000004`3oool2000000030820P03oool0oooo0?l0oooo
5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0oooo0P0000000`20P800oooo0?oo
o`3o0?oooaH0oooo00<0P820000000000000aP3oool002`0oooo0P00000C0?ooo`80000000<0P820
0?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000/0?ooo`8000004`3oool20000
00030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00;03oool2000001<0
oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002H0oooo
00<0P8200410@00000001`0000001010@400P8200820P020P80=0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooolF0?ooo`030820P000000000000<H0oooo000T0?ooo`030820P0000000000000h00000
00<0@4100?ooo`3oool02@3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000
000000360?ooo`00903ooolA000000030820P03oool0oooo00T0oooo0P0000000`20P800oooo0?oo
o`3o0?oooaH0oooo00<0P820000000000000aP3oool002@0oooo00<0P8200000000000003P000000
0`20P800oooo0?ooo`090?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P0000000
00000<H0oooo000T0?ooo`030820P0000000000000h00000303oool2000000030820P03oool0oooo
0?l0oooo5P3oool00`20P8000000000000360?ooo`009@3oool?000000030820P03oool0oooo00X0
oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002D0oooo
3`00000=0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo
000U0?ooo`030410@0000000000000/0000000<0@4100?ooo`3oool02`3oool2000000030820P03o
ool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`009@3oool00`20P80000000000000;
000000030820P03oool0oooo00/0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820
000000000000aP3oool002H0oooo3@00000>0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?oo
o`030820P000000000000<H0oooo000W0?ooo`/0000000<0@4100?ooo`3oool0303oool200000003
0820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`009`3oool00`20P8000000
00000008000000030820P03oool0oooo00`0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo
00<0P820000000000000aP3oool002L0oooo00<0P820000000000000200000000`30`<00oooo0?oo
o`0<0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000X
0?ooo`X000003`3oool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P800000000000036
0?ooo`00:03oool00`20P800000000000006000000030820P03oool0oooo00d0oooo0P0000000`20
P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3oool002P0oooo00<0`<3000000000
00001P0000000`30`<00oooo0?ooo`0=0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`03
0820P000000000000<H0oooo000Y0?ooo`P00000403oool2000000030820P03oool0oooo0?l0oooo
5P3oool00`20P8000000000000360?ooo`00:@3oool00`10@400000000000004000000030820P03o
ool0oooo00h0oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P820000000000000aP3o
ool002T0oooo00<0`<30000000000000100000000`30`<00oooo0?ooo`0>0?ooo`80000000<0P820
0?ooo`3oool0o`3ooolF0?ooo`030820P000000000000<H0oooo000Z0?ooo`H000004@3oool20000
00030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00:P3oool00`20P800
00000000000200000180oooo0P0000000`20P800oooo0?ooo`3o0?oooaH0oooo00<0P82000000000
0000aP3oool002X0oooo00<0P8200000000000000P00000B0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolF0?ooo`030820P000000000000<H0oooo000[0?ooo`<0000000<0P8200?ooo`3oool0403o
ool2000000030820P03oool0oooo0?l0oooo5P3oool00`20P8000000000000360?ooo`00:`3oool0
1020P800000000000030`<0B0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P000
000000000<H0oooo000/0?ooo`030410@0000000oooo0180oooo0P0000000`10@400P8200820P03o
0820P1H0P82000<0@410000000000000aP3oool002`0oooo0P20P80C0?ooool000007P0000360?oo
o`00;@3oool00`20P800oooo0?ooo`0A0?ooool000007P0000360?ooo`00o`3ooooo0?ooobH0oooo
003o0?ooool0oooo9P3oool00?l0ooooo`3ooolV0?ooo`00o`3ooooo0?ooobH0oooo003o0?ooool0
oooo9P3oool00?l0ooooo`3ooolV0?ooo`00o`3ooooo0?ooobH0oooo003o0?ooool0oooo9P3oool0
0?l0ooooo`3ooolV0?ooo`00o`3ooooo0?ooobH0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{182.938, 129.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 3.13 Exercise (2).", "Caption",
  CellTags->"Fig. 3.13"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Find the solution to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](r, \[Theta])\) = 0\)]],
  " inside a 2D cylinder for the following boundary conditions. Plot the \
solutions using  contour plots."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](1, \[Theta]) = cos\ n\ \[Theta]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " an integer."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](
          1, \[Theta]) = \ \(\(0\)\(\ \)\(for\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`x > 0\)]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](1, \[Theta]) = 1\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x < 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Phi](1, \[Theta]) = 0\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](2, \[Theta]) = h(\[Theta])\)]],
  " (find ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " between the concentric cylinders, ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is a Heaviside step function, ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Pi]\) < \[Theta] < \[Pi]\)]],
  " assumed)"
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Phi]\/\[PartialD]r\)]],
  Cell[BoxData[
      \(TraditionalForm\`\((1, \[Theta])\) = sin\ 2\ \[Theta]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](2, \[Theta]) = cos\ \[Theta]\)]],
  " (find ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " between the concentric cylinders). "
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " A long conducting cylinder of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 5\ cm\)]],
  " has a sector of opening angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 20  \[Degree]\)]],
  " that is electrically isolated from the rest of the cylinder by small gaps \
(see Fig. ",
  ButtonBox["3.14",
    ButtonData:>"Fig. 3.14",
    ButtonStyle->"Hyperlink"],
  "). The sector is placed at potential ",
  Cell[BoxData[
      \(TraditionalForm\`V\_o = 1\ Volt\)]],
  ". Find the potential and plot it  throughout the cylinder."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007G0001eb000`400?l00000o`00003oo`3ooooH
0?ooo`00o`3ooooH0?ooo`00o`3ooooH0?ooo`00o`3ooooH0?ooo`00o`3ooooH0?ooo`00o`3ooooH
0?ooo`00o`3ooooH0?ooo`00o`3ooooH0?ooo`00o`3ooooH0?ooo`00o`3ooooH0?ooo`00o`3ooooH
0?ooo`00o`3ooooH0?ooo`00o`3ooooH0?ooo`00e03oool]00000=H0oooo003?0?ooocP00000d03o
ool00<@0oooo1@20P814000000D0P820a@3oool00;h0oooo5P00000]0?oooaH00000`03oool00;/0
oooo5000000g0?oooaD00000_03oool00;P0oooo4P0000120?oooa400000^P3oool00;@0oooo4000
001=0?oooa000000]P3oool00;80oooo3@00001G0?ooo`d00000]03oool00:`0oooo0P20P80;0000
00<0P820GP3oool20820P0030410@0000000000000P000000P20P82^0?ooo`00Z03oool=000006/0
oooo3@00002Z0?ooo`00YP3oool=000006l0oooo00<0P8200000000000002P00002X0?ooo`00X`3o
ool<000007L0oooo3000002U0?ooo`00X@3oool<000007/0oooo00<0P8200000000000002@000000
0`20P800oooo0?ooo`2P0?ooo`00WP3oool;000008<0oooo2`00002P0?ooo`00V@3oool20820P003
0410@0000000000000H000000`20P8270?ooo`030<30`020P800P82000T000000P20P82K0?ooo`00
UP3oool;000000030820P03oool0oooo0900oooo2`00002H0?ooo`00U03oool<000009H0oooo2`00
002F0?ooo`00U03oool9000009/0oooo2@00002F0?ooo`00TP3oool9000009l0oooo00<0P8200000
000000001P00002D0?ooo`00T03oool800000:D0oooo2000002B0?ooo`00S03oool20820P0H00000
00<0P8200<30`03oool0Z@3oool00`20P800000000000004000000030410@020P800oooo08d0oooo
002:0?ooo`P00000/@3oool8000008`0oooo00280?ooo`030820P0000000000000D00000]@3oool8
000008X0oooo00270?ooo`L0000000<0P8200?ooo`3oool0]P3oool7000008T0oooo00240?ooo`T0
0000^`3oool9000008H0oooo00220?ooo`030820P0000000000000H00000`03oool8000008@0oooo
00210?ooo`H0000000<0P8200<30`03oool0``3oool00`20P800000000000004000000030820P03o
ool0oooo0800oooo001n0?ooo`L00000b`3oool700000800oooo001m0?ooo`H00000c`3oool60000
07l0oooo001l0?ooo`H0000000<0P8200?ooo`3oool0cP3oool6000000030820P03oool0oooo07/0
oooo001k0?ooo`H00000d`3oool6000007d0oooo001i0?ooo`L00000e@3oool7000007/0oooo001f
0?ooo`030<30`0000000000000<0000000<0@4100820P03oool0f03oool20820P0D0000000<0P820
0?ooo`3oool0MP3oool007D0oooo1`00003M0?ooo`030820P0000000000000@00000M`3oool007@0
oooo1P00003Q0?ooo`L00000M@3oool00780oooo1P00003U0?ooo`H00000M03oool00700oooo00<0
P8200000000000001000003X0?ooo`H00000LP3oool00700oooo1P00003Y0?ooo`030820P0000000
000000<0000000<0P8200?ooo`3oool0K`3oool006d0oooo00<0P8200000000000000P0000020820
P>d0oooo0P20P804000000030820P03oool0oooo06d0oooo001[0?ooo`H00000l`3oool6000006d0
oooo001Z0?ooo`030820P0000000000000<00000m@3oool00`20P800000000000003000006`0oooo
001Z0?ooo`D00000m`3oool5000000030820P03oool0oooo06T0oooo001X0?ooo`H00000nP3oool5
000006X0oooo001W0?ooo`D00000o@3oool5000006T0oooo001V0?ooo`D00000o`3oool5000006P0
oooo001S0?ooo`030<30`0000000000000<0000000<0P8200<30`03oool0o`3oool00`20P8000000
00000003000000030820P03oool0oooo06<0oooo001S0?ooo`D00000o`3oool60?ooo`D0000000<0
P8200?ooo`3oool0HP3oool00640oooo1P00003o0?ooo`P0oooo1P00001S0?ooo`00H03oool60000
0?l0oooo2P3oool600000680oooo001O0?ooo`D00000o`3oool>0?ooo`D00000H@3oool005d0oooo
00<0P8200000000000000`0000000`20P800oooo0?ooo`3o0?ooo`d0oooo1P00001O0?ooo`00G03o
ool00`20P800000000000003000000030820P03oool0oooo0?l0oooo3P3oool00`30`<0000000000
0003000000030410@03oool0oooo05`0oooo001K0?ooo`D00000o`3ooolF0?ooo`D00000G@3oool0
05X0oooo1@00003o0?oooaP0oooo1@00001L0?ooo`00F@3oool500000?l0oooo6P3oool6000005X0
oooo001G0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0o`3ooolI0?ooo`H00000
F@3oool005L0oooo1@00003o0?oooah0oooo1@0000000`20P800oooo0?ooo`1F0?ooo`00E@3oool0
0`20P800000000000002000000030820P03oool0oooo0?l0oooo7P3oool00`20P800000000000002
000000030820P03oool0oooo05D0oooo001D0?ooo`D00000o`3ooolT0?ooo`D00000EP3oool005<0
oooo1@00003o0?ooobH0oooo1@00001E0?ooo`00DP3oool5000000030820P03oool0oooo0?l0oooo
9@3oool00`20P800000000000002000005@0oooo001A0?ooo`030820P0000000000000800000o`3o
oolZ0?ooo`D0000000<0P8200?ooo`3oool0D03oool00500oooo1@00003o0?ooob`0oooo1@00001B
0?ooo`00CP3oool00`20P800000000000002000000030820P03oool0oooo0?l0oooo;03oool00`20
P800000000000002000000030820P03oool0oooo04h0oooo001=0?ooo`D00000o`3ooolb0?ooo`D0
0000C`3oool004`0oooo1@00003o0?oooc@0oooo00<0P8200000000000000P00001>0?ooo`00B`3o
ool00`20P80000000000000200000?l0oooo=P3oool5000004d0oooo001;0?ooo`D00000o`3ooolg
0?ooo`@0000000<0P8200?ooo`3oool0BP3oool004X0oooo1@00003o0?ooocT0oooo1000001<0?oo
o`00B@3oool4000000030820P03oool0oooo0?l0oooo>@3oool01020P800000000000000001;0?oo
o`00B03oool400000?l0oooo?P3oool4000004X0oooo00170?ooo`D00000o`3ooolo0?ooo`@00000
B@3oool004H0oooo1@0000000`20P800oooo0?ooo`3o0?ooocd0oooo00<0P8200000000000000P00
00180?ooo`00A@3oool00`20P80000000000000300000?l0oooo@@3oool5000004L0oooo00150?oo
o`D00000o`3ooom30?ooo`@0000000<0P8200?ooo`3oool0A03oool004<0oooo00<0P82000000000
00000P0000000`20P800oooo0?ooo`3o0?oood<0oooo100000000`20P800oooo0?ooo`130?ooo`00
@P3oool500000?l0ooooB03oool5000004@0oooo00120?ooo`@00000o`3ooom:0?ooo`@00000A03o
ool00440oooo100000000`20P800oooo0?ooo`3o0?ooodT0oooo100000130?ooo`00@03oool50000
00030820P03oool0oooo0?l0ooooB@3oool00`20P80000000000000200000480oooo000o0?ooo`03
0820P0000000000000<00000o`3ooom=0?ooo`D00000@@3oool003h0oooo00<0P820000000000000
0P0000000`20P800oooo0?ooo`3o0?oood`0oooo00<0P8200000000000000P0000000`10@400oooo
0?ooo`0n0?ooo`00?P3oool400000?l0ooooDP3oool5000003l0oooo000m0?ooo`@00000o`3ooomD
0?ooo`@00000?`3oool003`0oooo1000003o0?oooeH0oooo1000000n0?ooo`00>`3oool400000003
0820P03oool0oooo0?l0ooooE@3oool4000003d0oooo000k0?ooo`@0000000<0P8200?ooo`3oool0
o`3ooomE0?ooo`D00000?03oool003T0oooo00<0`<300000000000000P0000000`20P800oooo0?oo
o`3o0?oooeH0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`0i0?ooo`00>@3oool4
00000?l0ooooG03oool4000000030820P03oool0oooo03P0oooo000i0?ooo`@00000o`3ooomM0?oo
o`@00000>P3oool003P0oooo1000003o0?oooeh0oooo1000000j0?ooo`00=`3oool400000?l0oooo
H03oool4000003T0oooo000f0?ooo`@00000o`3ooomR0?ooo`@00000>03oool003H0oooo0`000000
0`20P800oooo0?ooo`3o0?ooof40oooo1000000g0?ooo`00=03oool00`20P8000000000000020000
00030<30`03oool0oooo0?l0ooooH@3oool01@10@4000000000000000000P82003H0oooo000c0?oo
o`D00000o`3ooomV0?ooo`D00000=@3oool003<0oooo1000003o0?ooofP0oooo1@00000d0?ooo`00
<P3oool01020P800000000000000003o0?ooofX0oooo1000000d0?ooo`00<P3oool400000?l0oooo
JP3oool4000000030820P03oool0oooo0340oooo000a0?ooo`@00000o`3ooom/0?ooo`@00000<`3o
ool00300oooo00@0P820000000000000P820o`3ooom^0?ooo`040820P000000000000820P380oooo
000`0?ooo`<00000o`3ooom`0?ooo`<00000<P3oool002l0oooo0`0000000`20P800oooo0?ooo`3o
0?ooofl0oooo0`00000a0?ooo`00;P3oool4000000030820P03oool0oooo0?l0ooooK`3oool40000
0300oooo000^0?ooo`@00000o`3ooomb0?ooo`040820P0000000000000000300oooo000]0?ooo`@0
0000o`3ooomd0?ooo`@00000;`3oool002`0oooo00D0P82000000000000000000820P03o0?ooog@0
oooo00<0P8200000000000000P00000^0?ooo`00;03oool400000?l0ooooMP3oool4000000030820
P03oool0oooo02/0oooo000/0?ooo`<00000o`3ooomh0?ooo`<0000000<0P8200?ooo`3oool0:`3o
ool002/0oooo1000003o0?ooogT0oooo0`00000]0?ooo`00:P3oool400000?l0ooooNP3oool40000
02`0oooo000Z0?ooo`<00000o`3oooml0?ooo`<00000;03oool002T0oooo0`0000000`10@400oooo
0?ooo`3o0?ooogX0oooo00D0P82000000000000000000820P00Z0?ooo`00:03oool4000000030820
P03oool0oooo0?l0ooooN`3oool4000002X0oooo000W0?ooo`D00000o`3ooomn0?ooo`030820P000
0000000000800000:@3oool002L0oooo1000003o0?oooh00oooo1000000Y0?ooo`009P3oool00`20
P80000000000000200000?l0ooooP03oool5000002P0oooo000V0?ooo`040820P000000000000000
0?l0ooooPP3oool4000000030820P03oool0oooo02D0oooo000V0?ooo`040410@000000000000820
P?l0ooooPP3oool01@20P8000000000000000000@41002L0oooo000V0?ooo`800000o`3ooon60?oo
o`<000009`3oool002D0oooo0`00003o0?ooohH0oooo1000000V0?ooo`009@3oool200000?l0oooo
R03oool3000002H0oooo000T0?ooo`<00000o`3ooon80?ooo`@000009@3oool002@0oooo0P000000
0`20P800oooo0?ooo`3o0?ooohL0oooo0`00000U0?ooo`008`3oool3000000030<30`03oool0oooo
0?l0ooooQ`3oool01010@400000000000000000T0?ooo`008P3oool400000?l0ooooRP3oool00`20
P800000000000002000002<0oooo000R0?ooo`<00000o`3ooon<0?ooo`@000008`3oool00240oooo
1000003o0?oooh`0oooo1000000S0?ooo`008@3oool300000?l0ooooSP3oool400000280oooo000P
0?ooo`040820P0000000000000000?l0ooooSP3oool400000280oooo000P0?ooo`030410@0000000
00000?l0ooooT03oool3000000030820P03oool0oooo01l0oooo000P0?ooo`800000o`3ooonB0?oo
o`<000008@3oool001l0oooo0`00003o0?oooi80oooo0`00000Q0?ooo`007`3oool200000?l0oooo
U03oool300000200oooo000N0?ooo`<00000o`3ooonD0?ooo`<00000803oool001h0oooo0P000000
0`20P800oooo0?ooo`3o0?oooi<0oooo0`00000O0?ooo`007@3oool3000000030820P03oool0oooo
0?l0ooooT`3oool3000001l0oooo000L0?ooo`050820P0000000000000000030`<00o`3ooonE0?oo
o`050820P0000000000000000020P8007@3oool001`0oooo1000003o0?oooiH0oooo00<0P8200000
000000000P00000M0?ooo`00703oool300000?l0ooooV03oool4000001d0oooo000K0?ooo`@00000
o`3ooonH0?ooo`D00000703oool001/0oooo1000003o0?oooiP0oooo1@00000L0?ooo`006P3oool0
1020P800000000000000003o0?oooiX0oooo1000000L0?ooo`006P3oool01020P800000000000000
003o0?oooiX0oooo100000000`20P800oooo0?ooo`0I0?ooo`006P3oool300000?l0ooooW03oool3
000000030820P03oool0oooo01T0oooo000J0?ooo`<00000o`3ooonL0?ooo`@000006`3oool001X0
oooo0`00003o0?oooi`0oooo1000000K0?ooo`006@3oool300000?l0ooooWP3oool3000001/0oooo
000I0?ooo`<00000o`3ooonN0?ooo`@000006P3oool001P0oooo0`0000000`20P800oooo0?ooo`3o
0?oooid0oooo0`00000J0?ooo`00603oool300000?l0ooooX03oool4000001T0oooo000G0?ooo`<0
000000<0P8200?ooo`3oool0o`3ooonO0?ooo`<000006@3oool001L0oooo0`0000000`20P800oooo
0?ooo`3o0?oooil0oooo0`00000I0?ooo`005`3oool3000000030820P03oool0oooo0?l0ooooW`3o
ool4000001P0oooo000F0?ooo`@00000o`3ooonR0?ooo`040820P00000000000000001P0oooo000E
0?ooo`030820P0000000000000800000o`3ooonR0?ooo`050820P0000000000000000020P8005`3o
ool001D0oooo1000003o0?oooj@0oooo1000000G0?ooo`005@3oool400000?l0ooooY03oool40000
01L0oooo000D0?ooo`030820P0000000000000800000o`3ooonT0?ooo`D000005P3oool001@0oooo
00@0P8200000000000000000o`3ooonV0?ooo`@000005P3oool001@0oooo00@0P820000000000000
0000o`3ooonV0?ooo`@000005P3oool001@0oooo00@0@4100000000000000000o`3ooonV0?ooo`@0
000000<0`<300?ooo`3oool04`3oool001@0oooo0`00003o0?ooojP0oooo0`0000000`20P800oooo
0?ooo`0C0?ooo`00503oool300000?l0ooooZ03oool3000000030820P03oool0oooo01<0oooo000D
0?ooo`<00000o`3ooonX0?ooo`@000005@3oool001<0oooo1000003o0?ooojT0oooo0`00000E0?oo
o`004`3oool300000?l0ooooZP3oool3000001D0oooo000B0?ooo`040820P0000000000000000?l0
ooooZP3oool3000000030820P03oool0oooo0180oooo000B0?ooo`<00000o`3ooon/0?ooo`<00000
503oool00180oooo0`00003o0?oooj`0oooo0`00000D0?ooo`004P3oool300000?l0oooo[03oool3
000001@0oooo000A0?ooo`@00000o`3ooon/0?ooo`@000004`3oool00140oooo0`0000000`20P800
oooo0?ooo`3o0?oooj/0oooo0`00000C0?ooo`00403oool01@20P8000000000000000000P8200?l0
oooo[@3oool3000000030820P03oool0oooo0100oooo000@0?ooo`@00000o`3ooon^0?ooo`040820
P0000000000000000180oooo000@0?ooo`@00000o`3ooon^0?ooo`040820P0000000000000000180
oooo000@0?ooo`@00000o`3ooon^0?ooo`040820P0000000000000000180oooo000?0?ooo`D00000
o`3ooon^0?ooo`030820P00000000000008000004@3oool000l0oooo1000003o0?oook00oooo1000
000A0?ooo`003`3oool400000?l0oooo/03oool400000140oooo000?0?ooo`@00000o`3ooon`0?oo
o`@000004@3oool000h0oooo00<0P8200000000000000P00003o0?oook00oooo1@00000@0?ooo`00
3P3oool01020P800000000000000003o0?oook80oooo1000000@0?ooo`003P3oool01020P8000000
00000000003o0?oook80oooo1000000@0?ooo`003P3oool01020P800000000000000003o0?oook80
oooo1000000@0?ooo`003P3oool01020P800000000000000003o0?oook80oooo1000000@0?ooo`00
3P3oool01010@400000000000000003o0?oook80oooo100000000`30`<00oooo0?ooo`0=0?ooo`00
3P3oool300000?l0oooo]03oool3000000030820P03oool0oooo00d0oooo000>0?ooo`<00000o`3o
oond0?ooo`<0000000<0P8200?ooo`3oool03@3oool000h0oooo0`00003o0?oook@0oooo0`000000
0`20P800oooo0?ooo`0=0?ooo`003P3oool300000?l0oooo]03oool3000000030820P03oool0oooo
00d0oooo000>0?ooo`<00000o`3ooond0?ooo`<0000000<0P8200?ooo`3oool03@3oool000d0oooo
0`0000000`20P800oooo0?ooo`3o0?oook80oooo00@0P82000000000000000003`3oool000d0oooo
0`00003o0?oookH0oooo0`00000?0?ooo`003@3oool300000?l0oooo]P3oool3000000l0oooo000=
0?ooo`<00000o`3ooonf0?ooo`<000003`3oool000d0oooo0`00003o0?oookH0oooo0`00000?0?oo
o`003@3oool300000?l0oooo]P3oool4000000h0oooo000<0?ooo`<0000000<0P8200?ooo`3oool0
o`3ooone0?ooo`<000003P3oool000`0oooo0`00003o0?oookP0oooo0`00000>0?ooo`00303oool4
00000?l0oooo]`3oool3000000h0oooo000<0?ooo`@00000o`3ooong0?ooo`<000003P3oool000`0
oooo1000003o0?oookL0oooo0`00000>0?ooo`00303oool400000?l0oooo]`3oool3000000h0oooo
000<0?ooo`@00000o`3ooong0?ooo`<000003P3oool000`0oooo1000003o0?oookL0oooo0`00000>
0?ooo`00303oool300000?l0oooo^03oool3000000h0oooo000<0?ooo`<00000o`3ooonh0?ooo`<0
00003P3oool000`0oooo0`00003o0?oookP0oooo0`00000>0?ooo`00303oool300000?l0oooo^03o
ool3000000h0oooo000<0?ooo`<00000o`3ooonh0?ooo`<000003P3oool000`0oooo0`00003o0?oo
okT0oooo0`00000=0?ooo`002`3oool400000?l0oooo^@3oool3000000d0oooo000;0?ooo`@00000
o`3oooni0?ooo`<000003@3oool000/0oooo1000003o0?oookT0oooo0`00000=0?ooo`002`3oool4
00000?l0oooo^@3oool3000000d0oooo000;0?ooo`@00000o`3oooni0?ooo`<000003@3oool000/0
oooo0`0000000`20P800oooo0?ooo`3o0?oookL0oooo0`00000=0?ooo`002`3oool3000000030820
P03oool0oooo0?l0oooo]`3oool3000000d0oooo000;0?ooo`<0000000<0P8200?ooo`3oool0o`3o
oong0?ooo`<000003@3oool000/0oooo0`0000000`20P800oooo0?ooo`3o0?oookL0oooo0`00000=
0?ooo`002`3oool3000000030820P03oool0oooo0?l0oooo]`3oool3000000d0oooo000;0?ooo`<0
000000<0P8200?ooo`3oool0o`3ooong0?ooo`<000003@3oool000/0oooo0`0000000`20P800oooo
0?ooo`3F0?ooo`X0P82000<0`<300?ooo`3oool03`3oool00`30`<00P8200820P0090820P180oooo
2P20P80B0?ooo`X0P82000<0`<300?ooo`3oool03`3oool00`30`<00P8200820P0090820P180oooo
2P20P80B0?ooo`X0P8204P3oool00`30`<00P8200820P0090820P0`0oooo0`20P80=0?ooo`002`3o
ool3000000030820P03oool0oooo0=H0oooo2P0000000`20P800oooo0?ooo`0?0?ooo`030820P000
0000000000T000004P3oool:00000180oooo2P0000000`20P800oooo0?ooo`0?0?ooo`030820P000
0000000000T000004P3oool:00000180oooo2P00000B0?ooo`030820P0000000000000T00000703o
ool000/0oooo0`0000000`20P800oooo0?ooo`3F0?ooo`X0000000<0P8200?ooo`3oool03`3oool0
0`20P80000000000000900000180oooo2P00000B0?ooo`X0000000<0P8200?ooo`3oool03`3oool0
0`20P80000000000000900000180oooo2P00000B0?ooo`X000004P3oool00`20P800000000000009
000001`0oooo000;0?ooo`<0000000<0P8200?ooo`3oool0eP3oool:000000030820P03oool0oooo
00l0oooo00<0P8200000000000002@00000B0?ooo`X000004P3oool:000000030820P03oool0oooo
00l0oooo00<0P8200000000000002@00000B0?ooo`X000004P3oool:00000180oooo00<0P8200000
000000002@00000L0?ooo`002`3oool3000000030820P03oool0oooo0=T0oooo00<0P82000000000
00000`00003W0?ooo`002`3oool3000000030820P03oool0oooo0=X0oooo1P00003V0?ooo`002`3o
ool400000=d0oooo0P20P804000000030820P03oool0oooo0>80oooo000;0?ooo`@00000h03oool5
00000><0oooo000;0?ooo`@00000h@3oool300000=@0oooo0`00000=0?ooo`002`3oool400000>80
oooo00<000000?ooo`3oool0d`3oool3000000d0oooo000;0?ooo`@00000o`3ooolH0?ooo`<00000
WP3oool3000000d0oooo000<0?ooo`<00000o`3ooolH0?ooo`<00000WP3oool3000000d0oooo000<
0?ooo`<00000o`3ooolG0?ooo`040820P000000000000410@9h0oooo0`00000=0?ooo`00303oool3
00000?l0oooo5`3oool3000000030820P03oool0oooo09/0oooo0`00000>0?ooo`00303oool30000
0?l0oooo5`3oool3000000030820P03oool0oooo09/0oooo0`00000>0?ooo`00303oool300000?l0
oooo5P3oool4000000030820P03oool0oooo09/0oooo0`00000>0?ooo`00303oool300000?l0oooo
5P3oool4000009h0oooo0`00000>0?ooo`00303oool400000?l0oooo5@3oool4000009h0oooo0`00
000>0?ooo`00303oool400000?l0oooo503oool5000009h0oooo0`00000>0?ooo`00303oool40000
0?l0oooo5P3oool2000009l0oooo0`00000>0?ooo`00303oool400000?l0oooo<P3oool6000000L0
oooo0`00001e0?ooo`<000003P3oool000`0oooo1000003`0?ooo`800000?@3oool3000000D0oooo
00<000000?ooo`3oool00`3oool00`20P800000000000002000007@0oooo0`00000>0?ooo`00303o
ool400000>l0oooo1000000k0?ooo`<000001P3oool00`20P8000000000000030?ooo`030820P000
0000000000<00000L`3oool3000000h0oooo000<0?ooo`<00000k`3oool5000000030820P03oool0
oooo03L0oooo0`0000000`20P800oooo0?ooo`050?ooo`<000000P3oool6000007<0oooo0`00000>
0?ooo`00303oool300000?00oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`0c0?oo
o`030820P00000000000008000002@3oool2000000040820P03oool000000820P080oooo00<0P820
0000003oool0L@3oool3000000l0oooo000=0?ooo`<00000l@3oool6000003@0oooo1@0000090?oo
o`@0000000<0P8200?ooo`3oool0M@3oool3000000l0oooo000=0?ooo`<00000l`3oool5000003<0
oooo1000000;0?ooo`<0000000<0P8200?ooo`3oool0M@3oool3000000l0oooo000=0?ooo`<00000
l`3oool00`20P80000000000000300000340oooo00<0P8200000000000000P00000;0?ooo`<00000
00<0P8200?ooo`3oool0M@3oool3000000l0oooo000=0?ooo`<00000m03oool400000380oooo00<0
P8200000000000000P00000;0?ooo`<0000000<0P8200?ooo`3oool0M@3oool3000000l0oooo000=
0?ooo`<00000m@3oool2000003<0oooo00<0P8200000000000000P00000<0?ooo`<00000M`3oool3
000000l0oooo000=0?ooo`040820P000000000000820P?l0oooo:P3oool00`20P800000000000002
000000`0oooo0`00001f0?ooo`040820P00000000000000000l0oooo000>0?ooo`<00000o`3ooolZ
0?ooo`030820P00000000000008000002`3oool5000007D0oooo0`0000000`20P800oooo0?ooo`0=
0?ooo`003P3oool300000?l0oooo:`3oool4000000/0oooo1@00001e0?ooo`<0000000<0P8200?oo
o`3oool03@3oool000h0oooo0`00003o0?ooob/0oooo1@00000:0?ooo`030000003oool000000080
0000M@3oool3000000030820P03oool0oooo00d0oooo000>0?ooo`<00000o`3oool/0?ooo`@00000
2@3oool2000000030?ooo`000000000000800000M03oool3000000030820P03oool0oooo00d0oooo
000>0?ooo`<00000o`3oool<0?ooo`030000003oool0oooo01d0oooo100000090?ooo`80000000<0
oooo0000000000000P00001c0?ooo`@0000000<0P8200?ooo`3oool03@3oool000h0oooo00@0@410
0000000000000000o`3oool:0?ooo`<0000000<0P8200?ooo`3oool0703oool01020P80000000000
0010@4060?ooo`030<30`0000000P82000<0oooo0`0000000`20P800oooo0?ooo`1`0?ooo`@00000
403oool000h0oooo00@0P8200000000000000000o`3oool90?ooo`@000008@3oool3000000D0oooo
00<000000?ooo`3oool00`3oool400000780oooo1000000@0?ooo`003P3oool01020P80000000000
0000003o0?ooo`P0oooo1000000T0?ooo`H00000O03oool400000100oooo000>0?ooo`040820P000
0000000000000?l0oooo1`3oool500000:H0oooo1000000@0?ooo`003P3oool01020P80000000000
0000003o0?ooo`H0oooo1@0000000`20P800oooo0?ooo`2S0?ooo`D00000403oool000h0oooo00<0
P8200000000000000P00003o0?ooo`<0oooo00<000000?ooo`0000001000002V0?ooo`@000004@3o
ool000l0oooo1000003o0?ooo`40oooo00<0P820000000000000100000000`20P800oooo0?ooo`2U
0?ooo`@000004@3oool000l0oooo1000003o0?ooo`80oooo1P00002X0?ooo`@000004@3oool000l0
oooo1000003o0?ooo`<0oooo1P00002W0?ooo`@000004@3oool000l0oooo1@00003o0?ooo`80oooo
00<0P8200000000000001000002U0?ooo`030820P00000000000008000004@3oool00100oooo1000
003o0?ooo`@0oooo1@0000000`20P800oooo0?ooo`2R0?ooo`040820P0000000000000000180oooo
000@0?ooo`@00000o`3oool50?ooo`D00000Y03oool01020P800000000000000000B0?ooo`00403o
ool400000?l0oooo1P3oool3000000030820P03oool0oooo0:80oooo00@0P8200000000000000000
4P3oool00100oooo00D0P82000000000000000000820P03o0?ooo`H0oooo0P20P82U0?ooo`040410
@0000000000000000180oooo000A0?ooo`<0000000<0P8200?ooo`3oool0o`3ooon[0?ooo`<00000
4`3oool00140oooo1000003o0?ooojd0oooo0`00000C0?ooo`004P3oool300000?l0oooo[@3oool3
000001<0oooo000B0?ooo`<00000o`3ooon/0?ooo`@000004`3oool00180oooo0`00003o0?oooj`0
oooo0`00000D0?ooo`004P3oool01020P800000000000000003o0?oooj/0oooo0`00000D0?ooo`00
4`3oool300000?l0ooooZ`3oool3000001@0oooo000C0?ooo`<00000o`3ooonZ0?ooo`@00000503o
ool001<0oooo1000003o0?ooojT0oooo0`00000E0?ooo`00503oool300000?l0ooooZ@3oool30000
01D0oooo000D0?ooo`<00000o`3ooonY0?ooo`<000005@3oool001@0oooo00@0@410000000000000
0000o`3ooolA0?ooo`040<30`000000000000820P980oooo0`0000000`10@400oooo0?ooo`0C0?oo
o`00503oool01020P800000000000000003o0?oooa40oooo1@00002A0?ooo`<0000000<0P8200?oo
o`3oool04`3oool001@0oooo00@0P8200000000000000000o`3ooolA0?ooo`030820P00000000000
00<0000000<0P8200?ooo`3oool0S@3oool3000000030820P03oool0oooo01<0oooo000D0?ooo`03
0820P0000000000000800000o`3ooolA0?ooo`H00000SP3oool4000000030820P03oool0oooo01<0
oooo000E0?ooo`@00000o`3ooolB0?ooo`H00000S@3oool4000001H0oooo000E0?ooo`@00000o`3o
oolD0?ooo`D00000S03oool4000001H0oooo000E0?ooo`030820P0000000000000800000o`3ooolD
0?ooo`050820P0000000000000000020P800RP3oool00`20P800000000000002000001H0oooo000F
0?ooo`@00000o`3ooolE0?ooo`030820P0000000oooo08/0oooo1000000G0?ooo`005`3oool30000
00030820P03oool0oooo0?l0ooooX03oool4000001L0oooo000G0?ooo`<0000000<0P8200?ooo`3o
ool0o`3ooonO0?ooo`030820P00000000000008000005`3oool001L0oooo0`0000000`20P800oooo
0?ooo`3o0?oooil0oooo00@0P8200000000000000000603oool001P0oooo0`00003o0?oooj40oooo
1000000H0?ooo`00603oool300000?l0ooooX@3oool3000001T0oooo000I0?ooo`<00000o`3ooonO
0?ooo`@000006@3oool001T0oooo0`00003o0?oooil0oooo0`00000J0?ooo`006P3oool300000?l0
ooooW@3oool4000001X0oooo000J0?ooo`<00000o`3ooonM0?ooo`@000006P3oool001X0oooo0`00
003o0?oooid0oooo0`00000K0?ooo`006P3oool01020P800000000000000003o0?oooi/0oooo1000
000K0?ooo`006P3oool01020P800000000000000003o0?ooob40oooo0P00001h0?ooo`<0000000<0
P8200?ooo`3oool06@3oool001/0oooo1000003o0?oooal0oooo0`0000000`20P800oooo0?ooo`1d
0?ooo`@0000000<0P8200?ooo`3oool06@3oool001/0oooo1000003o0?oooah0oooo1@00001f0?oo
o`@00000703oool001`0oooo0`00003o0?oooal0oooo1P00001c0?ooo`D00000703oool001`0oooo
1000003h0?ooo`@0000000<0P8200?ooo`3oool00`3oool00`20P80000000000000I0?ooo`H00000
LP3oool5000001`0oooo000L0?ooo`040820P0000000000000000?H0oooo00<0P820000000000000
1@0000001020P800oooo0?ooo`20P805000000030820P03oool0oooo01D0oooo00<0P8200410@000
00000`0000000`20P800oooo0?ooo`1]0?ooo`030<30`00000000000008000007@3oool001d0oooo
0`0000000`20P800oooo0?ooo`3b0?ooo`030820P0000000000000<000000`3oool6000000<0oooo
00<000000?ooo`3oool05`3oool6000006h0oooo00<0P8200000000000000P00000M0?ooo`007P3o
ool2000000030820P03oool0oooo0?80oooo00<0P8200000000000000P0000060?ooo`@000007P3o
ool4000006l0oooo1000000N0?ooo`007P3oool300000?@0oooo00@0P8200000000000000000203o
ool3000001l0oooo0P00001`0?ooo`@000007P3oool001l0oooo0P00003d0?ooo`040820P0000000
0000000000P0oooo0`00002@0?ooo`@000007`3oool001l0oooo0`00003c0?ooo`040820P0000000
0000000000P0oooo0`00002@0?ooo`@000007`3oool00200oooo0P00003d0?ooo`<00000203oool3
000008l0oooo1000000P0?ooo`00803oool00`10@40000000000003d0?ooo`040820P00000000000
0820P0H0oooo0`00002>0?ooo`050820P0000000000000000020P800803oool00200oooo00@0P820
0000000000000000m@3oool3000000D0oooo0`00002>0?ooo`@000008@3oool00240oooo0`00003h
0?ooo`030000003oool0oooo0080oooo0`00002=0?ooo`@0000000<0P8200?ooo`3oool07`3oool0
0240oooo1000003h0?ooo`<0000000@0oooo0000000000000000S@3oool4000000030820P03oool0
oooo01l0oooo000R0?ooo`<00000n`3oool4000008`0oooo1@00000R0?ooo`008P3oool400000?/0
oooo0`00002<0?ooo`D000008P3oool002<0oooo0`0000000`30`<00oooo0?ooo`3]0?ooo`040820
P000000000000820P0L0oooo0`00002;0?ooo`030820P00000000000008000008`3oool002@0oooo
0P0000000`20P800oooo0?ooo`3]0?ooo`@000001`3oool3000008/0oooo1000000T0?ooo`00903o
ool300000>l0oooo100000070?ooo`800000<03oool00`000000oooo0?ooo`1I0?ooo`@00000903o
ool002D0oooo0P00003`0?ooo`<000001P3oool3000002l0oooo0`00001I0?ooo`@000009@3oool0
02D0oooo0`00003`0?ooo`<00000103oool3000000030820P03oool0oooo02`0oooo1@00001G0?oo
o`D000009@3oool002H0oooo0P00003c0?ooo`H00000<@3oool6000005D0oooo1000000V0?ooo`00
9P3oool01010@400000000000020P83o0?ooobX0oooo00<0@4100000000000000`0000000`30`<00
oooo0?ooo`1@0?ooo`@000009`3oool002H0oooo00@0P8200000000000000000o`3oool/0?ooo`D0
0000D@3oool4000000030820P03oool0oooo02D0oooo000V0?ooo`030820P0000000000000800000
o`3oool/0?ooo`D00000D03oool4000000030820P03oool0oooo02D0oooo000W0?ooo`@00000o`3o
ool]0?ooo`<00000D03oool5000002P0oooo000W0?ooo`D00000o`3oool]0?ooo`0300000020P800
oooo04l0oooo1@00000X0?ooo`00:03oool4000000030820P03oool0oooo0?l0ooooN`3oool00`20
P800000000000002000002T0oooo000X0?ooo`050820P0000000000000000010@400o`3ooomm0?oo
o`050410@0000000000000000020P800:@3oool002X0oooo0`00003o0?ooog`0oooo1@00000Z0?oo
o`00:P3oool400000?l0ooooN`3oool4000002/0oooo000[0?ooo`@00000o`3ooomi0?ooo`@00000
;03oool002`0oooo0`00003o0?ooogT0oooo1000000/0?ooo`00;03oool400000?l0ooooM`3oool4
000002d0oooo000/0?ooo`050820P0000000000000000020P800o`3ooome0?ooo`050820P0000000
000000000010@400;@3oool002d0oooo1000003o0?ooogD0oooo100000000`20P800oooo0?ooo`0[
0?ooo`00;P3oool400000?l0ooooL`3oool5000002h0oooo000^0?ooo`@0000000<0P8200?ooo`3o
ool0o`3ooom_0?ooo`030820P0000000000000<00000;P3oool002l0oooo0`0000000`20P800oooo
0?ooo`3o0?oooc<0oooo0P00000j0?ooo`030820P0000000000000800000;`3oool00300oooo0`00
003o0?oooc@0oooo1000000i0?ooo`<00000<@3oool00300oooo00@0P820000000000000P820o`3o
oolb0?ooo`030<30`0000000000000<0000000<0P8200?ooo`3oool0<`3oool01@20P80000000000
00000000P8200340oooo000a0?ooo`@00000o`3ooolc0?ooo`H00000=03oool3000003<0oooo000b
0?ooo`@00000o`3ooolc0?ooo`H00000<P3oool4000003<0oooo000b0?ooo`040820P00000000000
00000?l0oooo=@3oool500000300oooo100000000`20P800oooo0?ooo`0a0?ooo`00<`3oool40000
0?l0oooo=@3oool5000002h0oooo1@00000d0?ooo`00<`3oool500000?l0oooo=03oool01020P800
000000000000000_0?ooo`D00000=03oool003@0oooo00<0P8200000000000000P0000000`30`<00
oooo0?ooo`3o0?oooc40oooo0P20P80^0?ooo`030<30`000000000000080000000<0P8200?ooo`3o
ool0<`3oool003H0oooo0`0000000`20P800oooo0?ooo`3o0?ooof40oooo1@00000f0?ooo`00=P3o
ool400000?l0ooooH`3oool4000003L0oooo000g0?ooo`@00000o`3ooomQ0?ooo`@00000>03oool0
03P0oooo1000003o0?oooel0oooo1000000i0?ooo`00>@3oool300000?l0ooooG`3oool4000003T0
oooo000i0?ooo`@00000o`3ooomM0?ooo`@00000>P3oool003T0oooo00<0`<300000000000000P00
00000`20P800oooo0?ooo`3o0?oooeL0oooo00<0P8200000000000000P0000000`20P800oooo0?oo
o`0h0?ooo`00>`3oool4000000030820P03oool0oooo0?l0ooooEP3oool5000003/0oooo000k0?oo
o`@0000000<0P8200?ooo`3oool0o`3ooomE0?ooo`030820P0000000000000800000?03oool003`0
oooo1000003o0?oooeL0oooo1000000m0?ooo`00?@3oool400000?l0ooooE@3oool4000003h0oooo
000n0?ooo`@00000o`3ooolk0?ooo`8000005P3oool4000003l0oooo000n0?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool0o`3ooole0?ooo`050820P0000000000000000010@4004`3o
ool00`20P800000000000002000000030820P03oool0oooo03d0oooo000o0?ooo`030820P0000000
000000<00000o`3ooolg0?ooo`H000004@3oool4000000030820P03oool0oooo03h0oooo00100?oo
o`D00000o`3ooolh0?ooo`H000003`3oool500000440oooo00110?ooo`@0000000<0P8200?ooo`3o
ool0o`3ooolf0?ooo`H000003@3oool00`20P80000000000000200000480oooo00120?ooo`@00000
o`3oooli0?ooo`030820P0000000000000<00000303oool4000004<0oooo00120?ooo`D00000o`3o
ooli0?ooo`D0000000<0P8200?ooo`3oool0203oool4000004@0oooo00130?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool0o`3ooolf0?ooo`040820P000000000000820P0X0oooo0`00
00000`20P800oooo0?ooo`130?ooo`00A@3oool500000?l0ooooA03oool4000004H0oooo00150?oo
o`030820P0000000000000<00000o`3ooom20?ooo`@0000000<0P8200?ooo`3oool0A03oool004H0
oooo1@0000000`20P800oooo0?ooo`3o0?oooch0oooo1@0000170?ooo`00A`3oool500000?l0oooo
@P3oool2000004P0oooo00180?ooo`@00000o`3ooon<0?ooo`00B@3oool4000000030820P03oool0
oooo0?l0ooooR03oool004X0oooo1@00003o0?ooohT0oooo001;0?ooo`D00000o`3ooon80?ooo`00
B`3oool00`20P80000000000000300000?l0oooo=@3oool200000500oooo001<0?ooo`D0000000<0
P8200?ooo`3oool0o`3ooola0?ooo`040820P00000000000000004l0oooo001=0?ooo`D00000o`3o
oolc0?ooo`D00000CP3oool004h0oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`3o
0?ooob/0oooo0P20P804000000030820P03oool0oooo04d0oooo001@0?ooo`H00000o`3oool[0?oo
o`H00000D@3oool00540oooo00<0P8200000000000000`00003o0?ooobT0oooo1P00001B0?ooo`00
DP3oool5000000030820P03oool0oooo0?l0oooo9@3oool00`20P800000000000003000000030820
P03oool0oooo0500oooo001C0?ooo`D00000o`3ooolW0?ooo`H00000D`3oool005@0oooo1@00003o
0?ooobD0oooo1P00001D0?ooo`00E@3oool00`20P80000000000000200000080P820o`3ooolP0?oo
o`030820P0000000000000<0000000<0P8200?ooo`3oool0D`3oool005L0oooo1P00003o0?oooah0
oooo1@00001H0?ooo`00E`3oool00`20P800000000000003000000030820P03oool0oooo0?l0oooo
6@3oool00`20P800000000000003000000030820P03oool0oooo05H0oooo001I0?ooo`D00000o`3o
oolK0?ooo`H00000F@3oool005X0oooo1@00003o0?oooaT0oooo1P00001J0?ooo`00F`3oool50000
0?l0oooo5`3oool6000005/0oooo001L0?ooo`030820P0000000000000<0000000<0P8200?ooo`3o
ool0o`3oool@0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0FP3oool005d0oooo
00<0P8200000000000000`0000000`20P800oooo0?ooo`3o0?ooo`d0oooo00<0P820000000000000
1000001N0?ooo`00G`3oool500000?l0oooo3`3oool6000000030820P03oool0oooo05`0oooo001P
0?ooo`H00000o`3oool<0?ooo`H00000H03oool00640oooo1P00003o0?ooo`X0oooo1@00001R0?oo
o`00H`3oool500000?l0oooo1`3oool6000006<0oooo001S0?ooo`030<30`0000000000000<00000
00<0P8200<30`03oool0o`3oool10?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0
HP3oool006H0oooo1@00003o0?ooo`40oooo00<0P8200000000000000`00001V0?ooo`00I`3oool5
00000?h0oooo1P00001W0?ooo`00J03oool500000?`0oooo1@00001Y0?ooo`00JP3oool500000?T0
oooo1@00001Z0?ooo`00JP3oool00`20P80000000000000300000?L0oooo1@00001[0?ooo`00J`3o
ool600000?@0oooo00<0P8200000000000000`00001/0?ooo`00K@3oool00`20P800000000000002
00000080P820kP3oool00`20P800000000000004000000030820P03oool0oooo06/0oooo001`0?oo
o`H00000jP3oool700000700oooo001`0?ooo`030820P0000000000000<0000000<0P8200?ooo`3o
ool0iP3oool700000740oooo001b0?ooo`H00000iP3oool700000780oooo001c0?ooo`L00000hP3o
ool8000007<0oooo001e0?ooo`L00000gP3oool8000007D0oooo001f0?ooo`030<30`00000000000
00<0000000<0@4100820P03oool0f@3oool00`20P800@41000000004000000030410@03oool0oooo
07D0oooo001i0?ooo`L00000eP3oool8000007T0oooo001k0?ooo`H00000d`3oool8000007/0oooo
001l0?ooo`H0000000<0P8200?ooo`3oool0cP3oool00`20P800000000000005000007`0oooo001m
0?ooo`H00000c`3oool7000000030820P03oool0oooo07/0oooo001n0?ooo`L00000b`3oool80000
07l0oooo00200?ooo`80P82000<0@4100000000000000P0000000`20P800`<300?ooo`330?ooo`03
0820P0000000000000D0000000<0P8200?ooo`3oool0O`3oool008@0oooo1P0000310?ooo`P00000
00<0P8200?ooo`3oool0P@3oool008H0oooo1`00002l0?ooo`T00000Q@3oool008P0oooo1P000000
0`20P800oooo0?ooo`2f0?ooo`030820P0000000000000H00000Q`3oool008T0oooo1`00002f0?oo
o`P00000R@3oool008/0oooo1`00002b0?ooo`T00000RP3oool008d0oooo00<0P8200410@0000000
100000000`20P800`<300?ooo`2Y0?ooo`030<30`020P800000000H000000P20P82<0?ooo`00T03o
ool800000:L0oooo200000000`20P800oooo0?ooo`2=0?ooo`00TP3oool900000:40oooo2P00002A
0?ooo`00U03oool9000009d0oooo2P00002C0?ooo`00UP3oool:000009L0oooo2`00002E0?ooo`00
V03oool9000000030820P03oool0oooo0940oooo2`0000000`20P800oooo0?ooo`2D0?ooo`00V`3o
ool20820P0L000000`20P8290?ooo`<0P820200000030820P9T0oooo002O0?ooo`X00000Q@3oool;
000009h0oooo002Q0?ooo`030820P0000000000000T00000OP3oool;00000:40oooo002T0?ooo`/0
0000N@3oool<00000:<0oooo002V0?ooo`d00000L@3oool=00000:H0oooo002X0?ooo`d00000K03o
ool=000000030820P03oool0oooo0:H0oooo002/0?ooo`80P8202`0000020820P5l0oooo0`20P80;
000000040410@020P800P8200820P:/0oooo002b0?ooo`d00000E`3oool?00000;80oooo002d0?oo
oa000000C@3ooolA00000;D0oooo002h0?oooa800000@P3ooolB00000;T0oooo002j0?oooaD00000
=`3ooolE00000;`0oooo002n0?ooob4000008P3ooolF00000<00oooo00330?ooo`H0P820@`000006
0820P<D0oooo003>0?ooocT00000d03oool00=<0oooo;P00003F0?ooo`00o`3ooooH0?ooo`00o`3o
oooH0?ooo`00o`3ooooH0?ooo`00o`3ooooH0?ooo`00o`3ooooH0?ooo`00o`3ooooH0?ooo`00o`3o
oooH0?ooo`00o`3ooooH0?ooo`00o`3ooooH0?ooo`00o`3ooooH0?ooo`00o`3ooooH0?ooo`00o`3o
oooH0?ooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{157.312, 157.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 3.14 Exercise (4).", "Caption",
  CellTags->"Fig. 3.14"],

Cell[TextData[{
  StyleBox["(5)(a)",
    FontWeight->"Bold"],
  "  The bottom and top of the of the wedge shown in Fig. ",
  ButtonBox["3.15",
    ButtonData:>"Fig. 3.15",
    ButtonStyle->"Hyperlink"],
  " are grounded, but the end at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  " is held at ",
  Cell[BoxData[
      FormBox[
        RowBox[{"V", "=", 
          RowBox[{"5", " ", 
            StyleBox["V",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". Find the potential everywhere inside the wedge by using separation of \
variables, and plot is as a surface plot for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 30  \[Degree]\)]],
  ". "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003:0000^b000`400?l00000o`00003obP3oool0
0<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3o
ool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00I@3oool00`20P800000000000002
00000080P8200`3oool00`20P8000000000000020820P5H0oooo001T0?ooo`030820P00000000000
00D0000000<0P8200?ooo`0000001@0000000`20P800oooo0?ooo`1C0?ooo`00I03oool400000004
0820P03oool0oooo0?ooo`D000000`3oool00`20P800oooo0?ooo`1C0?ooo`00I03oool4000000D0
oooo1000001I0?ooo`00I03oool3000000L0oooo0`00001I0?ooo`00I03oool3000000L0oooo0`00
001I0?ooo`00I03oool00`20P8000000000000070?ooo`<00000F@3oool006D0oooo0`0000060?oo
o`<00000F@3oool006H0oooo00<0P82000000010@4001@3oool3000005T0oooo001Y0?ooo`800000
0`3oool3000005T0oooo001[0?ooo`80000000@0oooo0000000000000000F@3oool006d0oooo1000
001I0?ooo`00I@3oool20820P0L0oooo0`00001I0?ooo`00I03oool01020P8000000000000000006
0?ooo`<00000F@3oool006@0oooo00@0P82000000000000000001P3oool3000005T0oooo001T0?oo
o`040820P00000000000000000H0oooo0P0000000`20P800oooo0?ooo`1G0?ooo`00I@3oool01020
P800000000000030`<030?ooo`050<30`0000000000000000030`<00F@3oool006P0oooo00<0P820
0000000000000`00001L0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?oo
o`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo0005
0?oookd00000203oool000D0oooo_@0000020820P0H0oooo00050?oookl000001P3oool000L0oooo
00<0P8200000000000000P00002e0?ooo`<000001P3oool000P0oooo1@00000^0?ooo`040820P000
0000000000000880oooo0`0000060?ooo`002@3oool00`20P800000000000002000000030820P03o
ool0oooo02X0oooo00@0P8200000000000000000PP3oool3000000H0oooo000;0?ooo`@0000000<0
P8200?ooo`3oool0:@3oool01020P80000000000000000220?ooo`<000001P3oool000/0oooo00<0
P8200000000000000P00000[0?ooo`040820P0000000000000000880oooo0`0000060?ooo`00303o
ool5000002X0oooo00@0P8200000000000000000PP3oool3000000H0oooo000=0?ooo`030820P000
000000000080000000<0P8200?ooo`3oool09P3oool01010@40000000000000000220?ooo`<00000
1P3oool000l0oooo100000000`20P800oooo0?ooo`0U0?ooo`<00000P`3oool3000000H0oooo000?
0?ooo`030820P00000000000008000009`3oool300000880oooo0`0000070?ooo`00403oool50000
02H0oooo0`0000220?ooo`<000001`3oool00140oooo00<0P8200000000000000P0000000`20P800
oooo0?ooo`0R0?ooo`<00000PP3oool3000000L0oooo000C0?ooo`@0000000<0P8200?ooo`3oool0
8@3oool300000880oooo0`0000070?ooo`004`3oool00`20P80000000000000200000280oooo1000
00220?ooo`<000001`3oool001@0oooo1@00000Q0?ooo`@00000PP3oool3000000L0oooo000E0?oo
o`D00000803oool3000008<0oooo0`0000070?ooo`005P3oool00`20P80000000000000200000003
0<30`03oool0oooo01/0oooo100000230?ooo`<000001`3oool001L0oooo00<0P820000000000000
0P00002T0?ooo`<000001`3oool001P0oooo1@00002S0?ooo`<000001`3oool001T0oooo1@00002R
0?ooo`<000001`3oool001X0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`2M0?oo
o`040820P00000000000000000L0oooo000K0?ooo`030820P0000000000000800000W`3oool40000
00L0oooo000L0?ooo`D00000WP3oool3000000P0oooo000M0?ooo`D00000W@3oool3000000P0oooo
000N0?ooo`030820P000000000000080000000<0`<300?ooo`3oool09P3oool40820P0030<30`03o
ool0oooo00D0oooo0`20P81S0?ooo`040820P00000000000000000P0oooo000O0?ooo`030820P000
00000000008000009P3oool2000000050820P03oool0oooo0?ooo`20P8000P0000050?ooo`@00000
HP3oool4000000P0oooo000P0?ooo`D000004@3oool00`000000P8200?ooo`0?0?ooo`040820P000
00000000000000H0oooo0P0000030?ooo`D00000HP3oool4000000P0oooo000Q0?ooo`D000003`3o
ool4000000l0oooo00<0P820000000000000203oool010000000P8200?ooo`3oool5000000030820
P03oool0oooo05l0oooo100000080?ooo`008P3oool00`20P800000000000002000000030<30`03o
ool0oooo00X0oooo100000000`20P800oooo0?ooo`0<0?ooo`040820P00000000000000000T0oooo
00D000000820P03oool000000410@0020?ooo`80P820H@3oool3000000030820P03oool0oooo00H0
oooo000S0?ooo`030820P00000000000008000002`3oool01@20P8000000000000000000P82000l0
oooo100000090?ooo`040820P00000000000000006D0oooo00D0P82000000000000000000820P008
0?ooo`00903oool5000000X0oooo00D0P82000000000000000000820P00?0?ooo`@000002@3oool0
1020P800000000000000001U0?ooo`050820P0000000000000000020P800203oool002D0oooo1@00
00090?ooo`@00000403oool4000000X0oooo0`00001U0?ooo`050820P0000000000000000020P800
203oool002H0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`040?ooo`@0000000<0
P8200?ooo`3oool03P3oool4000000X0oooo00@0P820000000000000@410I03oool01@20P8000000
000000000000P82000P0oooo000W0?ooo`030820P00000000000008000001@3oool400000180oooo
1000000;0?ooo`<00000I03oool01@20P8000000000000000000P82000P0oooo000X0?ooo`D00000
0`3oool4000001@0oooo1000000:0?ooo`@00000H`3oool4000000T0oooo000Y0?ooo`D0000000<0
oooo0820P00000000P0000000`20P800oooo0?ooo`0B0?ooo`@000002P3oool4000006<0oooo1000
00090?ooo`00:P3oool00`20P800000000000006000001D0oooo00D0@41000000000000000000<30
`0090?ooo`0300000020P800000000800000HP3oool4000000T0oooo000[0?ooo`030820P0000000
000000@000005`3oool3000000030820P03oool0oooo00L0oooo00<000000?ooo`0000000`00001Q
0?ooo`<000002P3oool002`0oooo1@00000I0?ooo`<00000203oool2000000030?ooo`20P8000000
00800000H03oool4000000X0oooo000/0?ooo`H000006@3oool3000000L0oooo0P0000000`3oool0
P82000000002000000030820P03oool0oooo05d0oooo0`00000;0?ooo`00;P3oool00`20P8000000
00000002000000030<30`03oool0oooo01H0oooo00@0P820000000000000P820103oool00`10@400
P8200?ooo`020?ooo`<0000000<0@4100?ooo`3oool0G@3oool3000000/0oooo000_0?ooo`030820
P00000000000008000006`3oool5000006L0oooo1000000;0?ooo`00<03oool5000008H0oooo0`00
000<0?ooo`00<@3oool5000008D0oooo0`00000<0?ooo`00<P3oool5000008@0oooo0`00000<0?oo
o`00<`3oool01@10@4000000000000000000@4100880oooo00@0P8200000000000000000303oool0
03@0oooo1@0000210?ooo`<0000000<0P8200?ooo`3oool02P3oool003D0oooo1@0000200?ooo`<0
000000<0P8200?ooo`3oool02P3oool003H0oooo1@00001o0?ooo`<0000000<0P8200?ooo`3oool0
2P3oool003L0oooo00D0@41000000000000000000410@01m0?ooo`050820P0000000000000000030
`<00303oool003P0oooo1@00001l0?ooo`040820P00000000000000000d0oooo000i0?ooo`D00000
N`3oool01020P800000000000000000=0?ooo`00>P3oool5000007X0oooo1000000=0?ooo`00>`3o
ool01@10@4000000000000000000@41007T0oooo0`00000>0?ooo`00?03oool5000007P0oooo0`00
000>0?ooo`00?@3oool5000007H0oooo1000000>0?ooo`00?P3oool5000007D0oooo0`00000?0?oo
o`00?`3oool01@10@4000000000000000000@41007<0oooo00@0P82000000000000000003`3oool0
0400oooo1@00001b0?ooo`<00000403oool00440oooo1@00001a0?ooo`<00000403oool00480oooo
1@00001_0?ooo`@00000403oool004<0oooo00<0@4100000000000000P0000000`30`<00oooo0?oo
o`1[0?ooo`<0000000<0P8200?ooo`3oool03P3oool004@0oooo1@00001/0?ooo`050820P0000000
000000000020P800403oool004D0oooo1@00001[0?ooo`040820P0000000000000000140oooo0016
0?ooo`D00000JP3oool01020P800000000000000000A0?ooo`00A`3oool00`20P800000000000002
000000030<30`03oool0oooo06H0oooo0`0000000`20P800oooo0?ooo`0?0?ooo`00B03oool00`20
P800000000000002000006P0oooo0`00000B0?ooo`00B@3oool5000006H0oooo1000000B0?ooo`00
BP3oool5000006D0oooo0`00000C0?ooo`00B`3oool00`20P800000000000002000000030<30`03o
ool0oooo0600oooo00@0P82000000000000000004`3oool004`0oooo00<0P8200000000000000P00
001R0?ooo`<00000503oool004d0oooo1@00001P0?ooo`@00000503oool004h0oooo1@00001O0?oo
o`@00000503oool003T0oooo1020P8060?ooo`80P8202P3oool00`20P80000000000000200000003
0<30`03oool0oooo05X0oooo00D0P82000000000000000000820P00D0?ooo`00>03oool7000000<0
oooo1@0000090?ooo`030820P0000000000000800000G03oool4000001D0oooo000g0?ooo`030820
P0000000000000D0000000<0P8200?ooo`0000001P0000090?ooo`D00000F`3oool4000001D0oooo
000g0?ooo`@0000000@0P8200?ooo`3oool0oooo1@0000030?ooo`030000003oool0oooo00P0oooo
1@00001I0?ooo`@000005P3oool003L0oooo100000050?ooo`@000003`3oool5000005P0oooo1000
000F0?ooo`00=`3oool3000000L0oooo0`00000@0?ooo`050410@0000000000000000010@400EP3o
ool4000001L0oooo000g0?ooo`<000001`3oool300000140oooo1@00001D0?ooo`@00000603oool0
03L0oooo00<0P8200000000000001`3oool300000180oooo1@00001C0?ooo`@00000603oool003P0
oooo0`0000060?ooo`<000004`3oool500000540oooo00D0P82000000000000000000820P00H0?oo
o`00>@3oool00`20P80000000410@0050?ooo`<00000503oool01@10@4000000000000000000@410
0500oooo00D0@41000000000000000000<30`00H0?ooo`00?03oool2000000<0oooo0`00000E0?oo
o`D00000C`3oool4000001T0oooo000n0?ooo`80000000@0oooo00000000000000005P3oool50000
04d0oooo1000000J0?ooo`00@03oool4000001L0oooo1@00001<0?ooo`@000006P3oool003P0oooo
0P20P8070?ooo`<00000603oool01@10@4000000000000000000@41004T0oooo0P20P803000001/0
oooo000g0?ooo`040820P00000000000000000H0oooo0`00000I0?ooo`D00000B03oool4000001`0
oooo000g0?ooo`040820P00000000000000000H0oooo0`00000J0?ooo`D00000AP3oool01@20P800
0000000000000000P82001`0oooo000g0?ooo`040820P00000000000000000H0oooo0P0000000`20
P800oooo0?ooo`0I0?ooo`D00000A@3oool01@20P8000000000000000000P82001`0oooo000h0?oo
o`040820P000000000000<30`0<0oooo00D0`<3000000000000000000<30`00L0?ooo`050410@000
0000000000000010@400A03oool4000001d0oooo000k0?ooo`030820P0000000000000<00000803o
ool500000480oooo1000000N0?ooo`00HP3oool500000440oooo0`00000O0?ooo`00H`3oool50000
03l0oooo1000000O0?ooo`00I03oool01@10@4000000000000000000@41003d0oooo00@0P8200000
000000000000803oool006D0oooo1@00000k0?ooo`050820P0000000000000000020P800803oool0
06H0oooo1@00000j0?ooo`040820P0000000000000000240oooo001W0?ooo`D00000>@3oool40000
0240oooo001X0?ooo`050410@0000000000000000010@400=`3oool01020P800000000000000000R
0?ooo`00J@3oool5000003H0oooo0`00000S0?ooo`00JP3oool5000003@0oooo0`00000T0?ooo`00
J`3oool5000003<0oooo0`00000T0?ooo`00K03oool01@10@4000000000000000000@4100300oooo
00D0P82000000000000000000820P00T0?ooo`00K@3oool5000002l0oooo1000000U0?ooo`00KP3o
ool5000002d0oooo1000000V0?ooo`00K`3oool5000002/0oooo1000000W0?ooo`00L03oool40000
00030820P03oool0oooo02P0oooo1000000W0?ooo`00L03oool00`30`<0000000000000200000003
0820P03oool0oooo02D0oooo00D0`<3000000000000000000410@00X0?ooo`00LP3oool5000002H0
oooo1000000Y0?ooo`00L`3oool5000002D0oooo1000000Y0?ooo`00M03oool4000000030820P03o
ool0oooo0240oooo1000000Z0?ooo`00M03oool00`30`<00000000000002000000030820P03oool0
oooo01h0oooo00D0P82000000000000000000820P00[0?ooo`00MP3oool5000001l0oooo0`000000
0`20P800oooo0?ooo`0Z0?ooo`00M`3oool5000001d0oooo00D0P82000000000000000000820P00/
0?ooo`00N03oool4000000030820P03oool0oooo01X0oooo1000000]0?ooo`00N03oool00`30`<00
000000000002000000030820P03oool0oooo01P0oooo00@0P820000000000000P820;P3oool007X0
oooo1@00000H0?ooo`@00000;`3oool007/0oooo1@00000F0?ooo`@00000<03oool007`0oooo1000
00000`20P800oooo0?ooo`0B0?ooo`050820P0000000000000000020P800<03oool007`0oooo00<0
`<300000000000000P0000000`20P800oooo0?ooo`0@0?ooo`050820P0000000000000000020P800
<@3oool007h0oooo1@00000@0?ooo`@00000<`3oool007l0oooo1@00000>0?ooo`@00000=03oool0
0800oooo1@00000<0?ooo`030820P0000000000000800000=03oool00800oooo00<0`<3000000000
00000P0000000`10@400oooo0?ooo`090?ooo`050410@0000000000000000030`<00=03oool00880
oooo1@0000090?ooo`@00000=P3oool008<0oooo1@0000070?ooo`@00000=`3oool008@0oooo1@00
00050?ooo`@00000>03oool008D0oooo00D0@41000000000000000000410@0030?ooo`050410@000
0000000000000030`<00>03oool008H0oooo1@0000000`3oool0000000000002000003X0oooo0027
0?ooo`T00000>P3oool008P0oooo1`00000k0?ooo`00R@3oool01@10@4000000000000000000@410
03`0oooo002:0?ooo`800000?P3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{67.5625, 62.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 3.15 Exercise (5).", "Caption",
  CellTags->"Fig. 3.15"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show that the radial electric field near ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  " is singular near ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\  > \[Pi]\)]],
  ", and find the form of the singularity [Answer: ",
  Cell[BoxData[
      \(TraditionalForm\`E\_r\  \[Proportional] \(r\^\(\[Pi]/\[Alpha]\  - 
                1\)\) sin\ \((\[Pi]\ \[Theta]/\[Alpha])\)\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`r \[Rule] \ 0\)]],
  ".] "
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " An electrolytic cell consists of two plastic concentric cylinders of \
radii ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a < b\)]],
  ", and length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ". Between the cylinders is an acid with conductivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  ". Two conducting vanes of width ",
  Cell[BoxData[
      \(TraditionalForm\`b - a\)]],
  " and length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " are placed in the cell between the cylinders, parallel to the axis of the \
cell, one along the positive ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-axis and one along the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(negative\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-axis. If the vanes are held at a fixed potential difference ",
  Cell[BoxData[
      \(TraditionalForm\`V\_o\)]],
  ", find the total current running between the vanes. Plot the contours of \
constant potential. [Hint: The potential satisfies Laplace's equation with \
von Neumann boundary conditions at the nonconducting surfaces and Dirichlet \
conditions at the conductors: see Exercise (2) above and Example 2 in Sec. ",
  ButtonBox["3.2.2",
    ButtonData:>"c:27",
    ButtonStyle->"Hyperlink"],
  ". Be careful to keep ",
  StyleBox["all ",
    FontSlant->"Italic"],
  " of the radial eigenmodes, including the ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  " (constant) mode.] "
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " Find the solution to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[CapitalPsi](r, \[Theta], \[Phi])\) = 
        0\)]],
  " inside a sphere with the following boundary conditions. "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPsi](
          1, \[Theta], \[Phi]) = \(sin\^2\) \[Theta]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPsi](1, \[Theta], \[Phi]) = 
        V\_o\ \(\(\[Theta]\^2\)(\[Pi] - \[Theta])\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\[CapitalPsi]\/\[PartialD]r\) \((1, \
\[Theta], \[Phi])\) = sin2\[Theta]\ cos\[Phi]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " A conducting sphere of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 2\ cm\)]],
  " is cut in half (see Fig. ",
  ButtonBox["3.16",
    ButtonData:>"Fig. 3.16",
    ButtonStyle->"Hyperlink"],
  "). The left half is grounded,  and the right half is at 10V.  Find the \
electrostatic potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta])\)]],
  " everywhere outside the sphere, assuming that the potential goes to zero \
at infinity. Plot the potential for ",
  Cell[BoxData[
      \(TraditionalForm\`a < r < 6\ cm\)]],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007H0001K2000`400?l00000o`00003oo`3ooooI
0?ooo`00o`3ooooI0?ooo`00o`3ooooI0?ooo`00o`3ooooI0?ooo`00o`3ooooI0?ooo`00o`3ooooI
0?ooo`00o`3ooooI0?ooo`00o`3ooooI0?ooo`00o`3ooooI0?ooo`00Y`3ooolA000000<0oooo4@00
003o0?ooo`d0oooo002Q0?ooo`030820P0000000000001@000000`3ooolG00000?l0oooo1`3oool0
09/0oooo7@0000030?oooad00000o`3oool10?ooo`00TP3oool30820P18000003@20P80300000004
0820P03oool0oooo0?ooo`<000003@20P8000`10@40000000000000?000000<0P82000<0`<300?oo
o`3oool0m@3oool008l0oooo4P0000000`20P800oooo0?ooo`0@0?ooo`<00000103oool3000001@0
oooo4P00003d0?ooo`00S03oool@000001P0oooo0`0000040?ooo`<000006@3oool@00000?40oooo
00280?ooo`h000007P3oool3000000@0oooo0`00000N0?ooo`h00000kP3oool008D0oooo3P00000Q
0?ooo`<00000103oool300000280oooo3P00003Z0?ooo`00P`3oool=000002@0oooo0`0000040?oo
o`<000009@3oool=00000>P0oooo00200?ooo``0000000<0P8200?ooo`3oool09@3oool3000000@0
oooo0`00000X0?ooo``00000iP3oool007`0oooo0P20P808000000<0P820:`3oool3000000@0oooo
0`00000[0?ooo`@0P820200000000`20P800`<300?ooo`3P0?ooo`00N@3oool<000002l0oooo0`00
00040?ooo`<00000<@3oool00`20P80000000000000700000=l0oooo001g0?ooo`030820P0000000
000000P00000<P3oool3000000@0oooo0`00000c0?ooo`X00000g@3oool007D0oooo2P00000e0?oo
o`<00000103oool3000003H0oooo2@0000000`20P800oooo0?ooo`3H0?ooo`00L`3oool;000003H0
oooo0`0000040?ooo`<00000>03oool900000=T0oooo001a0?ooo`X00000>@3oool3000000@0oooo
0`00000j0?ooo`X00000eP3oool00700oooo2@00000k0?ooo`<00000103oool3000003`0oooo2P00
003D0?ooo`00J`3oool30820P0L000000P20P80m0?ooo`<00000103oool3000003l0oooo00<0P820
0000000000001@0000020820P=40oooo001Y0?ooo`030820P0000000000000L00000@@3oool30000
00@0oooo0`0000120?ooo`X00000cP3oool006P0oooo2@0000130?ooo`<00000103oool3000004@0
oooo2@0000000`20P800oooo0?ooo`3:0?ooo`00IP3oool:000004@0oooo0`0000040?ooo`<00000
AP3oool00`20P80000000000000600000</0oooo001T0?ooo`T00000A`3oool3000000@0oooo0`00
00180?ooo`T00000b@3oool006<0oooo200000190?ooo`<00000103oool3000004X0oooo20000038
0?ooo`00HP3oool7000000030820P03oool0oooo04P0oooo0`0000040?ooo`<00000C03oool80000
0<H0oooo001O0?ooo`80P8201@0000020820P4`0oooo0`0000040?ooo`<00000C@3oool00`30`<00
P82000000004000000030410@020P800oooo0<<0oooo001M0?ooo`P00000C`3oool3000000@0oooo
0`00001@0?ooo`P00000`P3oool005`0oooo1`00001A0?ooo`<00000103oool300000580oooo1`00
00310?ooo`00F`3oool7000000030820P03oool0oooo04l0oooo0`0000040?ooo`<00000D`3oool8
00000;l0oooo001J0?ooo`L00000D`3oool3000000@0oooo0`00001D0?ooo`030820P00000000000
00@0000000<0P8200?ooo`3oool0_03oool005P0oooo1`00001E0?ooo`<00000103oool3000005H0
oooo1`00002m0?ooo`00E`3oool7000005H0oooo0`0000040?ooo`<00000E`3oool700000;`0oooo
001D0?ooo`030<30`0000000000000@0000000<0@4100?ooo`3oool0EP3oool3000000@0oooo0`00
001I0?ooo`030820P0000000000000@0000000<0P8200?ooo`3oool0]`3oool005@0oooo1P00001J
0?ooo`<00000103oool3000005/0oooo00<0P8200000000000001000002h0?ooo`00DP3oool70000
05/0oooo0`0000040?ooo`<00000G03oool6000000030820P03oool0oooo0;D0oooo001A0?ooo`H0
0000G@3oool3000000@0oooo0`00001N0?ooo`H00000]P3oool00500oooo1P00001N0?ooo`<00000
103oool3000005l0oooo1P00002e0?ooo`00CP3oool7000005l0oooo0`0000040?ooo`<00000H03o
ool600000;@0oooo001=0?ooo`030820P0000000000000@00000H03oool3000000@0oooo0`00001R
0?ooo`D00000/`3oool004/0oooo0P20P805000000030820P03oool0oooo05l0oooo0`0000040?oo
o`<00000HP3oool00`30`<00P82000000004000000030<30`03oool0oooo0:h0oooo001:0?ooo`H0
0000I03oool3000000@0oooo0`00001U0?ooo`D00000/03oool004T0oooo1P00001U0?ooo`<00000
103oool3000006H0oooo1@00002_0?ooo`00B03oool5000000030820P03oool0oooo06@0oooo0`00
00040?ooo`<00000J03oool400000:h0oooo00170?ooo`H00000I`3oool3000000@0oooo0`00001X
0?ooo`H00000[03oool004H0oooo1P00001X0?ooo`<00000103oool3000006T0oooo1P00002[0?oo
o`00A@3oool6000006T0oooo0`0000040?ooo`<00000J@3oool00`20P80000000000000400000:X0
oooo00140?ooo`H00000JP3oool3000000@0oooo0`00001[0?ooo`D0000000<0P8200?ooo`3oool0
Y`3oool00480oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`1Z0?ooo`<00000103o
ool3000006`0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`2V0?ooo`00@@3oool5
000000030820P03oool0oooo06/0oooo0`0000040?ooo`<00000KP3oool600000:H0oooo000o0?oo
o`030820P0000000000000@00000KP3oool3000000@0oooo0`00001_0?ooo`H00000Y@3oool003l0
oooo1P00001_0?ooo`<00000103oool300000700oooo1P00002T0?ooo`00?P3oool600000700oooo
0`0000040?ooo`<00000L@3oool600000:<0oooo000m0?ooo`D00000LP3oool3000000@0oooo0`00
001b0?ooo`D0000000<0P8200?ooo`3oool0X03oool003`0oooo1@00001c0?ooo`<00000103oool3
000007<0oooo1@00002R0?ooo`00>`3oool4000000030410@03oool0oooo0780oooo0`0000040?oo
o`<00000M03oool00`20P800000000000002000000030820P03oool0oooo09h0oooo000j0?ooo`D0
0000M@3oool3000000@0oooo0`00001f0?ooo`D00000W`3oool003T0oooo1@00001f0?ooo`<00000
103oool3000007L0oooo1@00002N0?ooo`00>03oool00`20P800000000000003000007H0oooo0`00
00040?ooo`<00000M`3oool00`20P800000000000003000009d0oooo000h0?ooo`D00000M`3oool3
000000@0oooo0`00001h0?ooo`D00000W@3oool003L0oooo1@00001h0?ooo`<00000103oool30000
07T0oooo1@00002L0?ooo`00=P3oool5000007T0oooo0`0000040?ooo`<00000NP3oool400000003
0820P03oool0oooo09T0oooo000e0?ooo`050820P0000000000000000020P800NP3oool3000000@0
oooo0`00001j0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0V03oool003@0oooo
100000000`20P800oooo0?ooo`1i0?ooo`<00000103oool3000007`0oooo1@00002I0?ooo`00<`3o
ool5000000030820P03oool0oooo07T0oooo0`0000040?ooo`<00000O@3oool5000009P0oooo000b
0?ooo`H00000O03oool3000000@0oooo0`00001n0?ooo`@00000V03oool00340oooo00<0P8200000
000000000`00001m0?ooo`<00000103oool3000007h0oooo00<0P8200000000000000P00002G0?oo
o`00<@3oool00`20P800000000000002000007h0oooo0`0000040?ooo`<00000O`3oool4000009L0
oooo000a0?ooo`@00000O`3oool3000000@0oooo0`0000200?ooo`@00000UP3oool002l0oooo00<0
P8200000000000000P0000200?ooo`<00000103oool300000800oooo00<0P8200000000000000P00
00000`30`<00oooo0?ooo`2B0?ooo`00;`3oool400000840oooo0`0000040?ooo`<00000PP3oool3
000000030820P03oool0oooo0980oooo000^0?ooo`@00000PP3oool3000000@0oooo0`0000230?oo
o`<00000U03oool002d0oooo100000000`20P800oooo0?ooo`200?ooo`<00000103oool3000008<0
oooo1000002C0?ooo`00;03oool5000008<0oooo0`0000040?ooo`<00000Q03oool400000980oooo
000/0?ooo`D00000P`3oool3000000@0oooo0`0000250?ooo`<00000TP3oool002/0oooo1@000024
0?ooo`<00000103oool3000008D0oooo00@0P8200000000000000000T@3oool002X0oooo00D0P820
00000000000000000820P0250?ooo`<00000103oool3000008D0oooo00<0`<300000000000000P00
00000`20P800oooo0?ooo`2=0?ooo`00:P3oool3000008L0oooo0`0000040?ooo`<00000Q`3oool4
000008l0oooo000Y0?ooo`@00000Q`3oool3000000@0oooo0`0000280?ooo`@00000SP3oool002P0
oooo100000280?ooo`<00000103oool3000008P0oooo1@00002=0?ooo`00:03oool4000008P0oooo
0`0000040?ooo`<00000R@3oool4000008d0oooo000W0?ooo`@00000R@3oool3000000@0oooo0`00
002:0?ooo`@00000S03oool002L0oooo100000290?ooo`<00000103oool3000008X0oooo1000002<
0?ooo`009@3oool00`20P800000000000002000000030820P03oool0oooo08L0oooo0`0000040?oo
o`<00000R`3oool01020P800000000000000002;0?ooo`009@3oool5000008X0oooo0`0000040?oo
o`<00000S03oool4000008X0oooo000T0?ooo`D00000R`3oool3000000@0oooo0`00002<0?ooo`03
0820P0000000000000800000R@3oool002<0oooo00<0P8200000000000000`00002;0?ooo`<00000
103oool3000008`0oooo00<0P8200000000000000P0000290?ooo`008`3oool00`20P80000000000
0002000008`0oooo0`0000040?ooo`<00000S@3oool5000008P0oooo000S0?ooo`@00000S@3oool3
000000@0oooo0`00002>0?ooo`@00000R03oool002<0oooo1000002=0?ooo`<00000103oool30000
08h0oooo1@0000270?ooo`008@3oool00`20P800000000000002000008h0oooo0`0000040?ooo`<0
0000S`3oool01@20P8000000000000000000`<3008H0oooo000Q0?ooo`@00000S`3oool3000000@0
oooo0`00002@0?ooo`<0000000<0P8200?ooo`3oool0Q03oool00200oooo1000002@0?ooo`<00000
103oool300000940oooo0`0000260?ooo`00803oool400000900oooo0`0000040?ooo`<00000T@3o
ool4000008D0oooo000O0?ooo`@0000000<0P8200?ooo`3oool0SP3oool3000000@0oooo0`00002B
0?ooo`@00000Q03oool001l0oooo100000000`20P800oooo0?ooo`2>0?ooo`<00000103oool30000
0980oooo100000240?ooo`007P3oool500000940oooo0`0000040?ooo`<00000T`3oool4000008<0
oooo000M0?ooo`030820P0000000000000800000TP3oool3000000@0oooo0`00002C0?ooo`050410
@0000000000000000020P800PP3oool001d0oooo1000002C0?ooo`<00000103oool3000009<0oooo
00<0P8200000000000000P0000220?ooo`00703oool00`20P800000000000002000009<0oooo0`00
00040?ooo`<00000U03oool500000840oooo000L0?ooo`040820P00000000000000009@0oooo0`00
00040?ooo`<00000U03oool500000840oooo000L0?ooo`@00000U03oool3000000@0oooo0`00002E
0?ooo`D00000P03oool001`0oooo0`00002E0?ooo`<00000103oool3000009D0oooo1@0000200?oo
o`006`3oool4000009D0oooo0`0000040?ooo`<00000UP3oool4000000030820P03oool0oooo07d0
oooo000J0?ooo`040820P00000000000000009H0oooo0`0000040?ooo`<00000UP3oool01@20P800
0000000000000000@41007l0oooo000J0?ooo`<00000U`3oool3000000@0oooo0`00002G0?ooo`@0
0000O`3oool001X0oooo0`00002G0?ooo`<00000103oool3000009P0oooo1000001n0?ooo`006@3o
ool3000000030820P03oool0oooo09D0oooo0`0000040?ooo`<00000V03oool4000007h0oooo000I
0?ooo`<0000000<0P8200?ooo`3oool0U@3oool3000000@0oooo0`00002I0?ooo`<00000OP3oool0
01P0oooo100000000`20P800oooo0?ooo`2E0?ooo`<00000103oool3000009T0oooo1000001m0?oo
o`00603oool4000000030820P03oool0oooo09D0oooo0`0000040?ooo`<00000V@3oool4000007d0
oooo000G0?ooo`D00000V03oool3000000@0oooo0`00002J0?ooo`@00000O03oool001L0oooo1000
002I0?ooo`<00000103oool3000009X0oooo00@0P8200000000000000000O03oool001H0oooo1@00
002I0?ooo`<00000103oool3000009X0oooo00<0P8200000000000000P00001k0?ooo`005P3oool5
000009T0oooo0`0000040?ooo`<00000VP3oool00`20P800000000000002000007/0oooo000F0?oo
o`@00000VP3oool3000000@0oooo0`00002K0?ooo`D00000NP3oool001D0oooo00<0P82000000000
00000P00002J0?ooo`<00000103oool3000009/0oooo1@00001j0?ooo`005@3oool00`20P8000000
00000002000009X0oooo0`0000040?ooo`<00000W03oool4000007X0oooo000E0?ooo`@00000V`3o
ool3000000@0oooo0`00002L0?ooo`D00000N@3oool001D0oooo0`00002L0?ooo`<00000103oool3
000009d0oooo1000001i0?ooo`00503oool4000009`0oooo0`0000040?ooo`<00000W@3oool40000
00030820P03oool0oooo07H0oooo000D0?ooo`@00000W03oool3000000@0oooo0`00002M0?ooo`@0
000000<0P8200?ooo`3oool0MP3oool001<0oooo1000002M0?ooo`<00000103oool3000009h0oooo
1000001h0?ooo`004`3oool4000009d0oooo0`0000040?ooo`<00000WP3oool4000007P0oooo000C
0?ooo`<00000WP3oool3000000@0oooo0`00002O0?ooo`<00000N03oool00180oooo00@0P8200000
000000000000WP3oool3000000@0oooo0`00002O0?ooo`<00000N03oool00180oooo0`0000000`20
P800oooo0?ooo`2L0?ooo`<00000103oool3000009l0oooo1000001g0?ooo`004P3oool300000003
0820P03oool0oooo09`0oooo0`0000040?ooo`<00000X03oool3000007L0oooo000B0?ooo`<00000
00<0P8200?ooo`3oool0W03oool3000000@0oooo0`00002P0?ooo`<00000M`3oool00140oooo1000
00000`20P800oooo0?ooo`2L0?ooo`<00000103oool300000:00oooo0`00001g0?ooo`004@3oool4
000009l0oooo0`0000040?ooo`<00000X03oool4000007H0oooo000A0?ooo`@00000W`3oool30000
00@0oooo0`00002Q0?ooo`<00000MP3oool00140oooo1000002O0?ooo`<00000103oool300000:40
oooo0`00001f0?ooo`00403oool4000000030820P03oool0oooo09d0oooo0`0000040?ooo`<00000
X@3oool3000007H0oooo000@0?ooo`@00000X03oool3000000@0oooo0`00002Q0?ooo`@00000M@3o
ool000l0oooo1@00002P0?ooo`<00000103oool300000:40oooo00@0P8200000000000000000M@3o
ool000l0oooo1000002Q0?ooo`<00000103oool300000:40oooo00@0P8200000000000000000M@3o
ool000l0oooo1000002Q0?ooo`<00000103oool300000:40oooo00@0P8200000000000000000M@3o
ool000l0oooo1000002Q0?ooo`<00000103oool300000:40oooo00<0P8200000000000000P00001d
0?ooo`003P3oool00`20P80000000000000200000:40oooo0`0000040?ooo`<00000XP3oool40000
07@0oooo000>0?ooo`040820P0000000000000000:80oooo0`0000040?ooo`<00000XP3oool40000
00030820P03oool0oooo0740oooo000>0?ooo`040820P0000000000000000:80oooo0`0000040?oo
o`<00000XP3oool5000007<0oooo000>0?ooo`040820P0000000000000000:80oooo0`0000040?oo
o`<00000XP3oool5000007<0oooo000>0?ooo`@00000XP3oool3000000@0oooo0`00002R0?ooo`H0
0000LP3oool000h0oooo0`00002S0?ooo`<00000103oool300000:<0oooo1@00001b0?ooo`003P3o
ool300000:<0oooo0`0000040?ooo`<00000X`3oool500000780oooo000>0?ooo`<00000X`3oool3
000000@0oooo0`00002S0?ooo`D00000LP3oool000h0oooo0`00002S0?ooo`<00000103oool30000
0:<0oooo1@00001b0?ooo`003P3oool300000:<0oooo0`0000040?ooo`<00000X`3oool500000003
0820P03oool0oooo06l0oooo000=0?ooo`<00000Y03oool3000000@0oooo0`00002T0?ooo`@00000
00<0P8200?ooo`3oool0K`3oool000d0oooo0`00002T0?ooo`<00000103oool300000:@0oooo1000
00000`20P800oooo0?ooo`1_0?ooo`003@3oool300000:@0oooo0`0000040?ooo`<00000Y03oool4
000000030820P03oool0oooo06l0oooo000=0?ooo`<00000Y03oool3000000@0oooo0`00002T0?oo
o`@0000000<0P8200?ooo`3oool0K`3oool000d0oooo0`00002T0?ooo`<00000103oool300000:@0
oooo100000000`20P800oooo0?ooo`1_0?ooo`00303oool01020P800000000000000002T0?ooo`<0
0000103oool300000:@0oooo00D0P82000000000000000000410@01a0?ooo`00303oool300000:D0
oooo0`0000040?ooo`<00000Y@3oool400000740oooo000<0?ooo`<00000Y@3oool3000000@0oooo
0`00002U0?ooo`@00000L@3oool000`0oooo0`00002U0?ooo`<00000103oool300000:D0oooo1000
001a0?ooo`00303oool300000:D0oooo0`0000040?ooo`<00000Y@3oool400000740oooo000<0?oo
o`<00000Y@3oool3000000@0oooo0`00002U0?ooo`@00000L@3oool000`0oooo0`00002U0?ooo`<0
0000103oool300000:D0oooo1000001a0?ooo`00303oool300000:D0oooo0`0000040?ooo`<00000
Y@3oool400000740oooo000<0?ooo`<00000Y@3oool3000000@0oooo0`00002U0?ooo`@00000L@3o
ool000`0oooo0`00002U0?ooo`<00000103oool300000:D0oooo1000001a0?ooo`00303oool30000
0:D0oooo0`0000040?ooo`<00000Y@3oool400000740oooo000<0?ooo`<00000Y@3oool3000000@0
oooo0`00002U0?ooo`@00000<P3oool5000003X0oooo000<0?ooo`<00000Y@3oool3000000@0oooo
0`00002V0?ooo`@00000<03oool7000003T0oooo000;0?ooo`<0000000<0P8200?ooo`3oool0X`3o
ool3000000@0oooo0`00002V0?ooo`@00000<03oool:000003H0oooo000;0?ooo`<0000000<0P820
0?ooo`3oool0X`3oool3000000@0oooo0`00002V0?ooo`@00000;`3oool00`30`<0000000000000:
000000<0P820<@3oool000/0oooo0`0000000`20P800oooo0?ooo`2S0?ooo`<00000103oool30000
0:H0oooo1000000_0?ooo`030820P0000000000001000000;P3oool000/0oooo0`0000000`20P800
oooo0?ooo`2S0?ooo`<00000103oool300000:H0oooo1000000_0?ooo`030820P000000000000180
000000<0P8200?ooo`3oool0:@3oool000/0oooo0`0000000`20P800oooo0?ooo`2S0?ooo`<00000
103oool300000:H0oooo1000000_0?ooo`030820P0000000000001@00000:P3oool000/0oooo0`00
00000`20P800oooo0?ooo`2S0?ooo`<00000103oool300000:H0oooo1000000_0?ooo`030820P000
0000000001L000009`3oool000/0oooo0`0000000`20P800oooo0?ooo`2S0?ooo`<00000103oool3
00000:H0oooo1000000_0?oooa`0000000<0P8200?ooo`3oool08P3oool000/0oooo0`0000000`20
P800oooo0?ooo`2S0?ooo`<00000103oool300000:H0oooo1000000_0?oooah000008`3oool000/0
oooo0`0000000`20P800oooo0?ooo`2S0?ooo`<00000103oool300000:H0oooo1000000_0?ooob40
00000P20P8000`30`<00oooo0?ooo`0K0?ooo`002`3oool3000000030820P03oool0oooo0:<0oooo
0`0000040?ooo`<00000YP3oool4000002l0oooo9P00000K0?ooo`002`3oool3000000030820P03o
ool0oooo0:<0oooo0`0000020?ooool000001`00000I0?ooo`002`3oool3000000030820P03oool0
oooo0:<0oooo0`0000020?ooool000002@00000G0?ooo`002`3oool3000000030820P03oool0oooo
0:<0oooo0`0000020?ooool000002000000H0?ooo`002`3oool3000000030820P03oool0oooo0:<0
oooo0`0000020?ooool000001@00000K0?ooo`002`3oool3000000030820P03oool0oooo0:<0oooo
0`0000040?ooo`<00000YP3oool4000002l0oooo8`0000000`20P800oooo0?ooo`0K0?ooo`002`3o
ool3000000030820P03oool0oooo0:<0oooo0`0000040?ooo`<00000YP3oool4000002l0oooo7P00
00030820P200oooo000<0?ooo`<00000Y@3oool3000000@0oooo0`00002V0?ooo`@00000;`3ooolL
000002D0oooo000<0?ooo`<00000Y@3oool3000000@0oooo0`00002U0?ooo`@00000<03ooolI0000
02P0oooo000<0?ooo`<00000Y@3oool3000000@0oooo0`00002U0?ooo`@00000<03oool00`20P800
00000000000D000002X0oooo000<0?ooo`<00000Y@3oool3000000@0oooo0`00002U0?ooo`@00000
<03oool00`20P80000000000000B000002`0oooo000<0?ooo`<00000Y@3oool3000000@0oooo0`00
002U0?ooo`@00000<03oool00`20P80000000000000?000002l0oooo000<0?ooo`<00000Y@3oool3
000000@0oooo0`00002U0?ooo`@00000<03oool00`20P80000000000000<00000380oooo000<0?oo
o`<00000Y@3oool3000000@0oooo0`00002U0?ooo`@00000<@3oool9000000<0P820=03oool000`0
oooo0`00002U0?ooo`<00000103oool300000:D0oooo1000000a0?ooo`H0000000<0P8200?ooo`3o
ool0=`3oool000`0oooo0`00002U0?ooo`<00000103oool300000:D0oooo1000000b0?ooo`<00000
?03oool000`0oooo0`00002U0?ooo`<00000103oool300000:D0oooo1000001a0?ooo`00303oool3
00000:D0oooo0`0000040?ooo`<00000Y@3oool400000740oooo000<0?ooo`<00000Y@3oool30000
00@0oooo0`00002U0?ooo`@00000L@3oool000`0oooo0`00002U0?ooo`<00000103oool300000:D0
oooo1000001a0?ooo`003@3oool300000:@0oooo0`0000040?ooo`<00000Y03oool4000000030820
P03oool0oooo06l0oooo000=0?ooo`<00000Y03oool3000000@0oooo0`00002T0?ooo`@0000000<0
P8200?ooo`3oool0K`3oool000d0oooo0`00002T0?ooo`<00000103oool300000:@0oooo10000000
0`20P800oooo0?ooo`1_0?ooo`003@3oool300000:@0oooo0`0000040?ooo`<00000Y03oool40000
00030820P03oool0oooo06l0oooo000=0?ooo`<00000Y03oool3000000@0oooo0`00002T0?ooo`@0
000000<0P8200?ooo`3oool0K`3oool000h0oooo0`00002S0?ooo`<00000103oool300000:<0oooo
1@0000000`20P800oooo0?ooo`1_0?ooo`003P3oool300000:<0oooo0`0000040?ooo`<00000X`3o
ool500000780oooo000>0?ooo`<00000X`3oool3000000@0oooo0`00002S0?ooo`D00000LP3oool0
00h0oooo0`00002S0?ooo`<00000103oool300000:<0oooo1@00001b0?ooo`003P3oool300000:<0
oooo0`0000040?ooo`<00000X`3oool500000780oooo000>0?ooo`@00000XP3oool3000000@0oooo
0`00002S0?ooo`D00000LP3oool000h0oooo00@0P8200000000000000000XP3oool3000000@0oooo
0`00002R0?ooo`D00000L`3oool000h0oooo00@0P8200000000000000000XP3oool3000000@0oooo
0`00002R0?ooo`D00000L`3oool000h0oooo00@0P8200000000000000000XP3oool3000000@0oooo
0`00002R0?ooo`D00000L`3oool000h0oooo00D0P82000000000000000000820P02Q0?ooo`<00000
103oool300000:80oooo100000000`20P800oooo0?ooo`1a0?ooo`003`3oool400000:40oooo0`00
00040?ooo`<00000X@3oool00`20P800000000000002000005D0oooo4@00000>0?ooo`003`3oool4
00000:40oooo0`0000040?ooo`<00000X@3oool01020P800000000000000001G0?ooo`<000002`3o
ool2000000h0oooo000?0?ooo`@00000X@3oool3000000@0oooo0`00002Q0?ooo`040820P0000000
0000000005L0oooo1000000:0?ooo`030820P0000000oooo00d0oooo000?0?ooo`D00000X03oool3
000000@0oooo0`00002Q0?ooo`040820P00000000000000005L0oooo00<0P8200000000000000P00
000:0?ooo`030000003oool0oooo00`0oooo000@0?ooo`@00000X03oool3000000@0oooo0`00002Q
0?ooo`040820P00000000000000005P0oooo1000000:0?ooo`030000003oool0oooo00`0oooo000@
0?ooo`@00000X03oool3000000@0oooo0`00002Q0?ooo`@00000F03oool5000000T0oooo00<00000
0?ooo`3oool0303oool00100oooo100000000`20P800oooo0?ooo`2M0?ooo`<00000103oool30000
0:40oooo0`00001J0?ooo`050820P0000000000000000020P8005`3oool00140oooo1000002O0?oo
o`<00000103oool300000:40oooo0`00001K0?ooo`@0000000<0P8200?ooo`3oool0503oool00140
oooo1000002O0?ooo`<00000103oool300000:40oooo0`00001L0?ooo`<0000000<0P8200?ooo`3o
ool0503oool00140oooo1000002O0?ooo`<00000103oool300000:00oooo1000001M0?ooo`<00000
5P3oool00140oooo100000000`20P800oooo0?ooo`2L0?ooo`<00000103oool300000:00oooo0`00
001N0?ooo`@000005@3oool00180oooo0`0000000`20P800oooo0?ooo`2L0?ooo`<00000103oool3
00000:00oooo0`00001O0?ooo`<000005@3oool00180oooo0`0000000`20P800oooo0?ooo`2L0?oo
o`<00000103oool300000:00oooo0`00001O0?ooo`@00000503oool00180oooo0`0000000`20P800
oooo0?ooo`2L0?ooo`<00000103oool3000009l0oooo1000001P0?ooo`@000004`3oool00180oooo
00@0P8200000000000000000WP3oool3000000@0oooo0`00002O0?ooo`<00000H@3oool01@20P800
0000000000000000P8200180oooo000C0?ooo`@00000W@3oool3000000@0oooo0`00002N0?ooo`@0
0000FP3oool00`20P800oooo0?ooo`050?ooo`D000004@3oool001<0oooo1000002M0?ooo`<00000
103oool3000009h0oooo1000001J0?ooo`030820P03oool0oooo00H0oooo1000000A0?ooo`00503o
ool4000009`0oooo0`0000040?ooo`<00000W@3oool4000000030820P03oool0oooo05P0oooo00<0
P8200?ooo`3oool01P3oool500000100oooo000D0?ooo`@00000W03oool3000000@0oooo0`00002M
0?ooo`@0000000<0P8200?ooo`3oool0F03oool00`20P800oooo0?ooo`070?ooo`@0000000<0P820
0?ooo`3oool03@3oool001D0oooo0`00002L0?ooo`<00000103oool3000009d0oooo1000001K0?oo
o`030000003oool0oooo00P0oooo0`0000000`20P800oooo0?ooo`0=0?ooo`005@3oool4000009/0
oooo0`0000040?ooo`<00000W03oool5000005/0oooo3`00000?0?ooo`005@3oool01@10@4000000
000000000000P82009X0oooo0`0000040?ooo`<00000W03oool4000000030820P03oool0oooo07L0
oooo000E0?ooo`030820P0000000000000800000VP3oool3000000@0oooo0`00002K0?ooo`D00000
NP3oool001H0oooo1000002J0?ooo`<00000103oool3000009/0oooo1@00001j0?ooo`005P3oool5
000009T0oooo0`0000040?ooo`<00000VP3oool00`20P800000000000002000007/0oooo000F0?oo
o`D00000V@3oool3000000@0oooo0`00002J0?ooo`030820P0000000000000800000N`3oool001L0
oooo1000002I0?ooo`<00000103oool3000009X0oooo00@0P8200000000000000000O03oool001L0
oooo1@00002H0?ooo`<00000103oool3000009X0oooo1000001l0?ooo`005`3oool00`20P8000000
00000002000000030<30`03oool0oooo09D0oooo0`0000040?ooo`<00000V@3oool01@20P8000000
000000000000P82007`0oooo000H0?ooo`@0000000<0P8200?ooo`3oool0U@3oool3000000@0oooo
0`00002I0?ooo`@00000O@3oool001T0oooo0`0000000`20P800oooo0?ooo`2E0?ooo`<00000103o
ool3000009T0oooo0`00001n0?ooo`006@3oool3000000030820P03oool0oooo09D0oooo0`000004
0?ooo`<00000V03oool4000007h0oooo000I0?ooo`@00000U`3oool3000000@0oooo0`00002H0?oo
o`@00000OP3oool001X0oooo0`00002G0?ooo`<00000103oool3000009L0oooo1000001o0?ooo`00
6P3oool4000009H0oooo0`0000040?ooo`<00000U`3oool4000007l0oooo000K0?ooo`<0000000<0
P8200?ooo`3oool0T`3oool3000000@0oooo0`00002F0?ooo`@0000000<0P8200?ooo`3oool0O@3o
ool001`0oooo0`00002E0?ooo`<00000103oool3000009D0oooo1@0000200?ooo`00703oool40000
09@0oooo0`0000040?ooo`<00000U@3oool500000800oooo000L0?ooo`040820P000000000000000
09@0oooo0`0000040?ooo`<00000U03oool500000840oooo000L0?ooo`030820P000000000000080
0000T`3oool3000000@0oooo0`00002D0?ooo`D00000P@3oool001d0oooo1000002C0?ooo`<00000
103oool3000009<0oooo00<0P8200000000000000P0000220?ooo`007@3oool500000980oooo0`00
00040?ooo`<00000T`3oool00`20P80000000000000200000880oooo000N0?ooo`@0000000<0P820
0?ooo`3oool0S`3oool3000000@0oooo0`00002C0?ooo`@00000P`3oool001l0oooo1000002A0?oo
o`<00000103oool3000009<0oooo0`0000240?ooo`007`3oool4000000030820P03oool0oooo08h0
oooo0`0000040?ooo`<00000TP3oool4000008@0oooo000P0?ooo`@00000T03oool3000000@0oooo
0`00002A0?ooo`D00000Q03oool00200oooo1000002@0?ooo`<00000103oool300000940oooo1000
00250?ooo`008@3oool4000008l0oooo0`0000040?ooo`<00000T03oool3000000030820P03oool0
oooo08@0oooo000Q0?ooo`D00000SP3oool3000000@0oooo0`00002@0?ooo`<0000000<0P8200?oo
o`3oool0Q03oool00280oooo00D0P82000000000000000000820P02=0?ooo`<00000103oool30000
08h0oooo00<0P8200000000000000P0000270?ooo`008`3oool4000008d0oooo0`0000040?ooo`<0
0000SP3oool4000008P0oooo000S0?ooo`030820P0000000000000800000S03oool3000000@0oooo
0`00002=0?ooo`D00000R03oool002<0oooo00<0P8200000000000000`00002;0?ooo`<00000103o
ool3000008`0oooo00<0P8200000000000000P0000290?ooo`00903oool5000008/0oooo0`000004
0?ooo`<00000S03oool00`20P800000000000002000008T0oooo000U0?ooo`D00000RP3oool30000
00@0oooo0`00002<0?ooo`@00000RP3oool002D0oooo1@0000000`20P800oooo0?ooo`270?ooo`<0
0000103oool3000008`0oooo0`00002;0?ooo`009P3oool01@20P8000000000000000000@41008T0
oooo0`0000040?ooo`<00000RP3oool01@20P8000000000000000000P82008/0oooo000W0?ooo`@0
0000R@3oool3000000@0oooo0`00002:0?ooo`@00000S03oool002P0oooo100000280?ooo`<00000
103oool3000008T0oooo1000002=0?ooo`00:03oool4000008P0oooo0`0000040?ooo`<00000R03o
ool5000008d0oooo000Y0?ooo`@00000Q`3oool3000000@0oooo0`0000280?ooo`@0000000<0P820
0?ooo`3oool0R`3oool002X0oooo0`0000270?ooo`<00000103oool3000008L0oooo1000002?0?oo
o`00:P3oool4000008H0oooo0`0000040?ooo`<00000QP3oool5000008l0oooo000Z0?ooo`030<30
`000000000000080000000<0P8200?ooo`3oool0PP3oool3000000@0oooo0`0000250?ooo`050820
P0000000000000000020P800T03oool002/0oooo1P0000230?ooo`<00000103oool3000008D0oooo
1000002A0?ooo`00;03oool5000008<0oooo0`0000040?ooo`<00000Q03oool400000980oooo000]
0?ooo`@0000000<0P8200?ooo`3oool0P03oool3000000@0oooo0`0000230?ooo`@00000T`3oool0
02h0oooo100000220?ooo`<00000103oool3000008<0oooo1000002C0?ooo`00;P3oool500000840
oooo0`0000040?ooo`<00000PP3oool4000009@0oooo000_0?ooo`D00000P03oool3000000@0oooo
0`0000210?ooo`@0000000<0P8200?ooo`3oool0TP3oool00300oooo100000000`20P800oooo0?oo
o`1m0?ooo`<00000103oool300000800oooo00<0P8200000000000000P00002E0?ooo`00<@3oool5
000007h0oooo0`0000040?ooo`<00000O`3oool5000009H0oooo000a0?ooo`030820P00000000000
00<00000O@3oool3000000@0oooo0`00001n0?ooo`030820P0000000000000800000U`3oool00340
oooo00<0P8200000000000001000001l0?ooo`<00000103oool3000007h0oooo1@00002G0?ooo`00
8@3oool6000000/0oooo1P0000000`20P800oooo0?ooo`1i0?ooo`<00000103oool3000007d0oooo
1@0000050?ooo``0000000<0P8200?ooo`3oool02P3oool6000001L0oooo00<0P8200?ooo`3oool0
FP3oool001l0oooo0`0000040?ooo`<000002`3oool4000000030820P03oool0oooo07T0oooo0`00
00040?ooo`<00000O03oool5000000X0oooo1@00000>0?ooo`<00000103oool3000001D0oooo00<0
P8200000003oool0FP3oool001h0oooo0`0000070?ooo`8000002`3oool4000007/0oooo0`000004
0?ooo`<00000N`3oool5000000`0oooo0`00000>0?ooo`<000001`3oool00`000000P8200?ooo`0C
0?ooo`800000F`3oool001`0oooo00@0`<30000000000000P8202@3oool00`000000@4100?ooo`0:
0?ooo`@0000000<0P8200?ooo`3oool0M`3oool3000000@0oooo0`00001j0?ooo`@0000000<0@410
0?ooo`3oool02`3oool3000000`0oooo00@0P820000000000000P8202@3oool00`000000P8200?oo
o`0A0?ooo`040820P000000000000820P5X0oooo000L0?ooo`030820P0000000000000/0oooo00<0
00000?ooo`3oool02P3oool5000007P0oooo0`0000040?ooo`<00000N@3oool5000000h0oooo0`00
000<0?ooo`<000002P3oool00`20P80000000?ooo`0A0?ooo`@00000FP3oool001`0oooo0P00000<
0?ooo`800000303oool5000007L0oooo0`0000040?ooo`<00000N03oool5000000l0oooo0`00000;
0?ooo`030820P0000000000000/0oooo00<0P820000000000000403oool6000005T0oooo000L0?oo
o`800000303oool2000000`0oooo00<0P8200000000000000`00001f0?ooo`<00000103oool30000
07L0oooo00<0P8200000000000000`00000?0?ooo`<000002`3oool00`20P80000000000000;0?oo
o`030820P000000000000100oooo0`0000000`3oool000000000001I0?ooo`006`3oool3000000`0
oooo0`00000<0?ooo`D00000MP3oool3000000@0oooo0`00001g0?ooo`D00000403oool3000000/0
oooo0`00000;0?ooo`040820P00000000000000000h0oooo100000000`3oool000000000001I0?oo
o`006`3oool2000000d0oooo00<0P8200000000000003@3oool5000007D0oooo0`0000040?ooo`<0
0000MP3oool500000140oooo0`00000;0?ooo`8000003@3oool3000000h0oooo0`0000000`20P800
oooo00000002000005P0oooo000K0?ooo`8000003@3oool00`20P80000000000000>0?ooo`@00000
00<0P8200?ooo`3oool0LP3oool3000000@0oooo0`00001e0?ooo`D000004P3oool3000000/0oooo
0P00000=0?ooo`<000003P3oool3000000030820P03oool0oooo00800000F03oool001X0oooo0`00
000=0?ooo`040820P000000000000820P0d0oooo00<0P8200000000000000P0000000`20P800oooo
0?ooo`1a0?ooo`<00000103oool3000007<0oooo00<0P8200000000000000P0000000`20P800oooo
0?ooo`0A0?ooo`<000002P3oool3000000d0oooo0`0000000`20P800oooo0?ooo`0:0?ooo`@00000
0`3oool00`20P80000000820P01G0?ooo`006P3oool3000000d0oooo00@0P8200000000000000000
3`3oool500000780oooo0`0000040?ooo`<00000LP3oool5000000030820P03oool0oooo0180oooo
0`00000:0?ooo`<000003@3oool4000000/0oooo1@0000040?ooo`800000E`3oool001X0oooo0`00
000=0?ooo`040820P0000000000000000100oooo1P00001`0?ooo`<00000103oool300000740oooo
1P00000E0?ooo`<000002P3oool3000000d0oooo1000000;0?ooo`@000001@3oool2000005L0oooo
000J0?ooo`<000003@3oool01020P800000000000000000A0?ooo`H00000K`3oool3000000@0oooo
0`00001`0?ooo`H000005P3oool3000000X0oooo0`00000=0?ooo`@000002P3oool5000000H0oooo
0P00001F0?ooo`006P3oool3000000d0oooo00@0P82000000000000000004@3oool00`20P8000000
00000004000006h0oooo0`0000040?ooo`<00000K`3oool6000001L0oooo0`00000:0?ooo`<00000
3@3oool4000000X0oooo100000070?ooo`800000EP3oool001X0oooo0`00000=0?ooo`040820P000
0000000000000180oooo1P0000000`20P800oooo0?ooo`1[0?ooo`<00000103oool3000006h0oooo
1P00000H0?ooo`<000002P3oool3000000d0oooo1000000:0?ooo`@000001`3oool2000005H0oooo
000J0?ooo`<000003@3oool01020P800000000000000000C0?ooo`H00000K@3oool3000000@0oooo
0`00001]0?ooo`H000006@3oool3000000X0oooo0`00000=0?ooo`@000002@3oool01020P8000000
0000000000090?ooo`0300000020P800oooo05@0oooo000J0?ooo`<000003@3oool01020P8000000
00000000000D0?ooo`030820P0000000000000<000000P20P81Z0?ooo`<00000103oool3000006/0
oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`0H0?ooo`<000002P3oool3000000d0
oooo100000090?ooo`040410@00000000000000000T0oooo00<000000410@03oool0E03oool001X0
oooo0`00000=0?ooo`040820P00000000000000001L0oooo1P00001Y0?ooo`<00000103oool30000
06T0oooo00<0P820000000000000100000000`20P800oooo0?ooo`0I0?ooo`<000002P3oool30000
00d0oooo100000090?ooo`<000002`3oool00`000000oooo0?ooo`1C0?ooo`006`3oool2000000d0
oooo00<0P8200000000000006@3oool6000006P0oooo0`0000040?ooo`<00000J@3oool6000001d0
oooo0`00000;0?ooo`8000003@3oool3000000T0oooo1000000;0?ooo`030000003oool0oooo05<0
oooo000K0?ooo`<00000303oool3000001T0oooo00<0P8200000000000001000001W0?ooo`<00000
103oool3000006P0oooo1P00000N0?ooo`<000002`3oool3000000/0oooo00@0P820000000000000
00002@3oool3000000`0oooo00<0P8200000003oool0D`3oool001/0oooo0`00000<0?ooo`<00000
6P3oool6000000030820P03oool0oooo06@0oooo0`0000040?ooo`<00000J03oool5000001l0oooo
0`00000;0?ooo`<000002`3oool01020P80000000000000000080?ooo`@00000303oool00`20P800
00000?ooo`1C0?ooo`00703oool2000000`0oooo0P00000L0?ooo`L00000I@3oool3000000@0oooo
0`00001W0?ooo`D00000803oool3000000/0oooo00<0P8200000000000002`3oool00`20P8000000
000000090?ooo`<000003@3oool00`20P80000000?ooo`1C0?ooo`00703oool2000000`0oooo0P00
000M0?ooo`L00000I03oool3000000@0oooo0`00001U0?ooo`H000008@3oool3000000/0oooo00<0
P8200000000000002`3oool00`20P8000000000000090?ooo`<000003P3oool2000005<0oooo000L
0?ooo`030820P0000000000000X0oooo0P00000O0?ooo`L00000H`3oool3000000@0oooo0`00001T
0?ooo`H000008P3oool3000000`0oooo0`00000:0?ooo`8000002@3oool4000000h0oooo0P00001C
0?ooo`00703oool01030`<00000000000020P8080?ooo`030820P0000000@4100200oooo0P20P805
00000080P820H03oool3000000@0oooo0`00001R0?ooo`030<30`0000000000000<0000000<0P820
0<30`03oool0703oool50820P0<00000303oool01020P800000000000020P8080?ooo`030820P000
0000P82000P0oooo00D0P82000000000000000000820P00>0?ooo`80000000<0P8200?ooo`3oool0
D03oool001h0oooo0`0000060?ooo`<000008`3oool00`20P800000000000004000000030820P03o
ool0oooo05d0oooo0`0000040?ooo`<00000H@3oool6000002<0oooo1@00000>0?ooo`<000001P3o
ool2000000030820P03oool0oooo00L0oooo100000000`20P800oooo0?ooo`0<0?ooo`<00000DP3o
ool001l0oooo0`0000040?ooo`<000009P3oool6000005l0oooo0`0000040?ooo`<00000H03oool6
000002H0oooo0`00000?0?ooo`<00000103oool3000000T0oooo1@0000000`20P800oooo0?ooo`0<
0?ooo`D00000D03oool00240oooo1P00000Y0?ooo`H00000GP3oool3000000@0oooo0`00001O0?oo
o`D00000:P3oool00`000000oooo0?ooo`0?0?ooo`H000002@3oool00`20P8000000000000080000
00T0oooo2000001?0?ooo`00DP3oool6000005`0oooo0`0000040?ooo`<00000GP3oool500000;L0
oooo001C0?ooo`H00000F`3oool3000000@0oooo0`00001L0?ooo`H0000000<0P8200?ooo`3oool0
]@3oool005@0oooo00<0P820000000000000100000000`20P800oooo0?ooo`1F0?ooo`<00000103o
ool3000005X0oooo1`00002i0?ooo`00E@3oool20820P0D000000P20P81F0?ooo`<00000103oool3
000005L0oooo0P20P80500000080P820^P3oool005P0oooo1`00001E0?ooo`<00000103oool30000
05H0oooo1`00002m0?ooo`00FP3oool7000005<0oooo0`0000040?ooo`<00000E03oool00`20P800
000000000004000000030820P03oool0oooo0;`0oooo001K0?ooo`L0000000<0P8200?ooo`3oool0
C`3oool3000000@0oooo0`00001C0?ooo`P00000_`3oool005`0oooo1`00001A0?ooo`<00000103o
ool300000580oooo1`0000310?ooo`00G@3oool8000004l0oooo0`0000040?ooo`<00000D03oool8
00000<80oooo001O0?ooo`L00000CP3oool3000000@0oooo0`00001?0?ooo`L00000a03oool00640
oooo00<0P820000000000000100000000`20P800`<300?ooo`190?ooo`<00000103oool3000004`0
oooo00<0P8200410@00000001@0000000`30`<00oooo0?ooo`330?ooo`00H`3oool8000004T0oooo
0`0000040?ooo`<00000BP3oool800000<P0oooo001T0?ooo`T00000A`3oool3000000@0oooo0`00
00180?ooo`T00000b@3oool006H0oooo2@0000150?ooo`<00000103oool3000004L0oooo2000003;
0?ooo`00J03oool8000004@0oooo0`0000040?ooo`<00000AP3oool7000000030820P03oool0oooo
0<X0oooo001Y0?ooo`030820P0000000000000D00000@`3oool3000000@0oooo0`0000140?ooo`P0
0000cP3oool006/0oooo200000110?ooo`<00000103oool300000480oooo1`00003A0?ooo`00KP3o
ool20820P0D000001020P80k0?ooo`<00000103oool3000003d0oooo0`20P806000000030820P03o
ool0oooo0=40oooo001a0?ooo`X00000>@3oool3000000@0oooo0`00000j0?ooo`X00000eP3oool0
07<0oooo2`00000f0?ooo`<00000103oool3000003P0oooo2@00003I0?ooo`00M@3oool:000003D0
oooo0`0000040?ooo`<00000=P3oool9000000030820P03oool0oooo0=P0oooo001g0?ooo`030820
P0000000000000P00000<P3oool3000000@0oooo0`00000c0?ooo`/00000g03oool007T0oooo2`00
000`0?ooo`<00000103oool300000340oooo00<0P8200000000000001`00003O0?ooo`00O03oool:
000002h0oooo0`0000040?ooo`<00000;`3oool9000000030820P03oool0oooo0=l0oooo001n0?oo
o`80P8202@0000030820P0030<30`03oool0oooo02D0oooo0`0000040?ooo`<00000:@3oool20820
P0T000000`20P83S0?ooo`00PP3oool=000002D0oooo0`0000040?ooo`<000009@3oool=00000>P0
oooo00250?ooo`h000008@3oool3000000@0oooo0`00000R0?ooo`h00000jP3oool008P0oooo3P00
000N0?ooo`<00000103oool3000001h0oooo3P00003^0?ooo`00S03oool?000001T0oooo0`000004
0?ooo`<000006P3oool?000000030820P03oool0oooo0>h0oooo002>0?oooa<0000000<0P8200?oo
o`3oool0403oool3000000@0oooo0`00000D0?oooa800000m03oool00980oooo5@00000=0?ooo`<0
0000103oool3000000d0oooo00<0P8200000000000004P0000000`20P800oooo0?ooo`3e0?ooo`00
U@3oool60820P1d000000`3ooolM000000D0P820n`3oool00:40oooo5`0000030?oooaL0000000<0
P8200?ooo`3oool0o`3oool40?ooo`00Y`3ooolA000000<0oooo4@00003o0?ooo`d0oooo003o0?oo
omT0oooo003o0?ooomT0oooo003o0?ooomT0oooo003o0?ooomT0oooo003o0?ooomT0oooo003o0?oo
omT0oooo003o0?ooomT0oooo003o0?ooomT0oooo003o0?ooomT0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{113.875, 87.875},
  ImageMargins->{{0, 0}, {0, 11.5625}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 3.16 Exercise (8).", "Caption",
  CellTags->"Fig. 3.16"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " Two concentric spheres have radii ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`b > a\)]],
  "). Each is divided into two hemispheres by the same horizontal plane. The \
upper hemisphere of the outer sphere and the lower hemisphere of the inner \
sphere are maintained at potential ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  ". The other hemispheres are grounded. Determine the potential in the \
region ",
  Cell[BoxData[
      \(TraditionalForm\`a \[LessEqual] \ r \[LessEqual] \ b\)]],
  " in terms of Legendre polynomials. Plot the result for ",
  Cell[BoxData[
      \(TraditionalForm\`b = 3  a/2\)]],
  ".  Check your result against known solutions in the limiting cases ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] \ \[Infinity]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`a \[Rule] \ 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " A grounded conducting sphere of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " is placed with its center at the origin, in a uniform electric field ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["E",
            FontWeight->"Bold",
            FontSlant->"Plain"], " ", "=", " ", 
          RowBox[{"E", " ", 
            StyleBox[
              OverscriptBox[
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"],
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  " that is created by an external potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_e = \(-E\)\ z\)]],
  ".  Find the total potential ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " outside the sphere. (Hint: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  "; write ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_e\)]],
  " in spherical coordinates.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(11)",
    FontWeight->"Bold"],
  " By applying the Taylor expansion function ",
  StyleBox["Series",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to the Bessel functions, investigate the small-",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " form of ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_m\)(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_m\)(x)\)]],
  ". Answer the following questions:"
}], "Text",
  CellTags->"i:93"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find a simple analytic expression for ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_m\)(x)\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " an integer)  as ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " approaches zero. Does your expression apply for ",
  Cell[BoxData[
      \(TraditionalForm\`m < 0\)]],
  " as well as ",
  Cell[BoxData[
      \(TraditionalForm\`m > 0\)]],
  "?"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " The ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_m\)]],
  "'s are singular near the origin. Find the form of the singularity for ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0, 1, 2,  ... \)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(12)",
    FontWeight->"Bold"],
  " Repeat the previous Exercise for the modified Bessel functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(I\_m\)(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(K\_m\)(x)\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " an integer)."
}], "Text",
  CellTags->"i:94"],

Cell[TextData[{
  StyleBox["(13) ",
    FontWeight->"Bold"],
  "A cylinder has length ",
  Cell[BoxData[
      \(TraditionalForm\`L = 1\ meter\)]],
  " and radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1/2\ meter\)]],
  ". The sides and the top of the cylinder are grounded, but the base at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " is held at potential ",
  Cell[BoxData[
      FormBox[
        RowBox[{"V", "=", 
          RowBox[{"50", " ", 
            RowBox[{
              StyleBox["V",
                FontSlant->"Plain"], "."}]}]}], TraditionalForm]]],
  " Find the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, z)\)]],
  " throughout the interior. Plot the result using ",
  StyleBox["ContourPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(14)",
    FontWeight->"Bold"],
  " A cylinder of unit height and radius has grounded ends, at ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(-1\)/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z = 1/2\)]],
  ". The cylindrical wall  at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 1\)]],
  " is split in half lengthwise along the ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " plane. The half with ",
  Cell[BoxData[
      \(TraditionalForm\`x > 0\)]],
  " is held at 10 V, and the half for which ",
  Cell[BoxData[
      \(TraditionalForm\`x < 0\)]],
  " is grounded. Find the potential and obtain the value of the electric \
field, ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Del]\[Phi]\)\)]],
  " (magnitude and direction),  at the origin. Plot the potential in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z\)\(=\)\(0\)\(\ \)\)\)]],
  " plane using a surface plot. "
}], "Text"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " In a ",
  StyleBox["Penning-Malmberg  trap",
    FontSlant->"Italic"],
  ",  used to trap charged particles with static electric and magnetic \
fields,  potentials are applied to coaxial cylindrical electrodes of radius \
",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", shown in Fig. ",
  ButtonBox["3.17",
    ButtonData:>"Fig. 3.17",
    ButtonStyle->"Hyperlink"],
  ",  in order to provide an axial trapping potential. "
}], "Text",
  CellTags->"i:92"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P0000db000`400?l00000o`00003oo`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooogH0oooo2000003o0?ooon@0oooo003o0?ooogL0oooo00<0P8200000000000000P00003o
0?ooonH0oooo003o0?ooogP0oooo0`00003o0?ooonL0oooo003o0?ooogP0oooo0`00003o0?ooonL0
oooo003o0?ooogP0oooo0`00003o0?ooonL0oooo003o0?ooogP0oooo0`00003o0?ooonL0oooo003o
0?ooogP0oooo0`00003o0?ooonL0oooo003o0?ooogP0oooo0`00003o0?ooonL0oooo003o0?ooof80
oooo00<0`<300?ooo`3oool04`3oool300000?l0ooooi`3oool00?l0ooooH@3oool00`000000P820
0?ooo`0D0?ooo`<00000o`3ooooW0?ooo`00o`3ooomQ0?ooo`0300000020P800oooo01@0oooo0`00
003o0?ooonL0oooo003o0?ooof00oooo00<0P8200000000000005@3oool300000?l0ooooi`3oool0
0?l0ooooH03oool3000001D0oooo0`00003o0?ooonL0oooo003o0?ooof00oooo1000000D0?ooo`<0
0000o`3ooooW0?ooo`00?03oool?0820P0030<30`03oool0oooo0240oooo5020P8170?ooo`030<30
`020P800P82000`0P82000<0`<300?ooo`3oool09`3oool60820P5D0oooo00<0P820000000000000
0P0000000`20P800oooo0?ooo`0@0?ooo`030<30`0000000000000800000103oool00`20P800`<30
0?ooo`1=0?ooo`l0P8207@3oool60820P5H0oooo00<0`<300820P020P8003020P8000`30`<00oooo
0?ooo`0E0?oooa@0P820cP3oool003d0oooo0`0000090?ooo`80000000<0P8200?ooo`3oool08P3o
oolD000004L0oooo0`0000090?ooo`80000000<0P8200?ooo`3oool09@3oool9000005@0oooo00<0
P8200000000000000`00000A0?ooo`D0000000@0oooo000000000000P8200`00001?0?ooo`<00000
2@3oool2000001/0oooo00<0P8200000000000001P0000000`20P800oooo0?ooo`1C0?ooo`<00000
2@3oool2000000030820P03oool0oooo01H0oooo5000003=0?ooo`00?@3oool4000000T0oooo00<0
00000820P03oool09@3oool3000000030820P03oool0oooo00L0oooo1@0000170?ooo`@000002@3o
ool00`000000P8200?ooo`0U0?ooo`@000001@3oool2000005<0oooo1P0000000`20P800oooo0?oo
o`0?0?ooo`040820P0000000000000000080oooo1@00001?0?ooo`@000002@3oool00`000000oooo
0?ooo`0H0?ooo`@0000000<0P8200?ooo`3oool00P3oool2000005D0oooo100000090?ooo`030000
0020P800oooo01T0oooo0`0000000`20P800oooo0?ooo`070?ooo`D00000c@3oool003h0oooo00@0
@410000000000000P8202@3oool00`20P800oooo0?ooo`0T0?ooo`<00000303oool01030`<000000
00000030`<170?ooo`040820P00000000000000000T0oooo00<0P8200?ooo`3oool0903oool30000
00H0oooo00@0`<30000000000000P820D@3oool6000000030820P03oool0oooo0180oooo00D0P820
0?ooo`3oool0oooo0<30`0020820P0030<30`03oool0oooo04h0oooo00@0@410000000000000P820
203oool00`20P800oooo0?ooo`0H0?ooo`<000001`3oool00`10@40000000000001D0?ooo`040820
P00000000000000000T0oooo00<0P8200?ooo`3oool0603oool3000000`0oooo00@0`<3000000000
0000`<30c03oool003h0oooo00@0P82000000000000000002@3oool00`20P800oooo0?ooo`0T0?oo
o`<000003P3oool00`000000P8200?ooo`170?ooo`<0000000<0P8200?ooo`3oool01P3oool00`20
P800oooo0?ooo`0T0?ooo`<00000203oool200000500oooo2000001/0?ooo`040820P00000000000
000000P0oooo00<0P8200?ooo`3oool0603oool3000000P0oooo0P0000000`20P800oooo0?ooo`1B
0?ooo`<0000000<0P8200?ooo`3oool01P3oool00`20P800oooo0?ooo`0H0?ooo`<000003P3oool0
0`000000P8200?ooo`3;0?ooo`00?`3oool3000000/0oooo4`00000B0?ooo`<000003`3oool00`20
P800oooo0?ooo`160?ooo`040820P000000000000820P0/0oooo4P0000000`20P800oooo0?ooo`0?
0?ooo`<00000203oool3000004l0oooo2000001]0?ooo`<000002`3oool00`20P80000000000000@
000000030820P03oool0oooo0080oooo0`0000080?ooo`<00000E03oool01020P800000000000020
P80:0?oooa<000001P3oool3000000l0oooo00<0P8200?ooo`3oool0bP3oool00400oooo0`000000
0`20P800oooo0?ooo`070?oooa<000004P3oool3000000l0oooo00<0P8200?ooo`3oool0A`3oool3
000000030820P03oool0oooo00P0oooo4P0000000`20P800oooo0?ooo`0?0?ooo`<000002@3oool2
000004h0oooo00<0P8200000000000001P00001^0?ooo`<0000000<0P8200?ooo`3oool01`3oool0
0`20P80000000000000@000000030820P03oool0oooo0080oooo0`0000090?ooo`800000E@3oool3
000000030820P03oool0oooo00L0oooo4`0000060?ooo`<000003`3oool00`20P800oooo0?ooo`3:
0?ooo`00@@3oool3000002h0oooo0`00001J0?ooo`<00000;P3oool3000000T0oooo0`00001=0?oo
o`X00000KP3oool300000240oooo0`0000090?ooo`<00000E@3oool300000280oooo0`00003L0?oo
o`00@@3oool01020P800000000000020P80N0?ooo`T000001P3oool3000005/0oooo0`00000N0?oo
o`030820P0000000000000H0000000<0P8200?ooo`3oool00`3oool3000000T0oooo0`00001=0?oo
o`X00000KP3oool01020P800000000000020P80P0?ooo`<000002@3oool3000005H0oooo0`00000Q
0?ooo`<00000g03oool00440oooo00@0`<3000000000000000007P3oool9000000H0oooo0`00001K
0?ooo`040410@000000000000820P1d0oooo00<0P8200000000000001P0000000`20P800oooo0?oo
o`030?ooo`<000002@3oool3000004`0oooo00<0P8200000000000002000001^0?ooo`040<30`000
0000000000000200oooo0`0000090?ooo`<00000EP3oool01010@400000000000020P80P0?ooo`<0
0000g03oool00480oooo1000000/0?ooo`<00000F`3oool01020P800000000000000000/0?ooo`<0
00002@3oool3000004`0oooo00<0P8200000000000002@00001^0?ooo`@000007`3oool3000000T0
oooo0`00001F0?ooo`040820P0000000000000000200oooo0`00003L0?ooo`00@`3oool4000002/0
oooo0`00001L0?ooo`@00000:`3oool3000000P0oooo1000001<0?ooo``00000K`3oool4000001h0
oooo0`0000080?ooo`@00000E`3oool4000001l0oooo0`00003L0?ooo`00A03oool3000000030<30
`03oool0oooo02P0oooo0`00001M0?ooo`<0000000<0P8200?ooo`3oool0:03oool3000000P0oooo
0`0000000`20P800oooo0?ooo`1:0?ooo``0000000<0P8200?ooo`3oool0K@3oool3000000030<30
`03oool0oooo01/0oooo0`0000080?ooo`<0000000<0P8200?ooo`3oool0EP3oool3000000030820
P03oool0oooo01`0oooo0`00003L0?ooo`00?@3oool00`000000oooo0?ooo`040?ooo`040820P000
00000000000000D0oooo4`00000B0?ooo`<00000EP3oool00`000000oooo0?ooo`050?ooo`<00000
00<0P8200?ooo`3oool00`3ooolB000000030820P03oool0oooo00l0oooo0`0000070?ooo`@00000
C03oool=000000030820P03oool0oooo06H0oooo00<000000?ooo`3oool0103oool01020P8000000
0000000000050?ooo`030820P000000000000100000000<0P8200?ooo`3oool00P3oool3000000L0
oooo00@0P8200000000000000000DP3oool00`000000oooo0?ooo`050?ooo`<0000000<0P8200?oo
o`3oool00P3ooolC000000H0oooo0`00003L0?ooo`00?@3oool00`000000oooo0?ooo`050?ooo`<0
00001@3ooolC00000180oooo0`00001F0?ooo`030000003oool0oooo00D0oooo00@0P82000000000
0000P8201@3ooolB000000030820P03oool0oooo00l0oooo0`0000000`20P800oooo0?ooo`030?oo
o`030820P0000000000000800000C03oool>000006P0oooo00<000000?ooo`3oool01@3oool30000
00D0oooo00<0P820000000000000400000000`20P800oooo0?ooo`020?ooo`@000001P3oool40000
0580oooo00<000000?ooo`3oool01@3oool01020P800000000000020P8040?oooa<000001P3oool3
00000=`0oooo000m0?ooo`030000003oool0oooo00D0oooo00D0P82000000000000000000820P003
0?oooa<0P8204P3oool3000005H0oooo00<000000?ooo`3oool01@3oool01@30`<00000000000000
0000P82000@0oooo4P20P8000`30`<00oooo0?ooo`0?0?ooo`<0000000<0@41000000020P8000`20
P803000000030410@03oool0oooo04X0oooo3`00001X0?ooo`030000003oool0oooo00D0oooo00D0
P82000000000000000000820P0030?ooo`030<30`020P800P8200100P82000<0`<300?ooo`3oool0
0P3oool3000000030820P0000000P82000<0P820100000000`30`<00oooo0?ooo`1@0?ooo`030000
003oool0oooo00D0oooo00D0`<3000000000000000000820P0030?oooa<0P8201P3oool300000=`0
oooo000m0?ooo`0300000020P800oooo00L0oooo0`00000X0?ooo`<00000EP3oool2000000P0oooo
0`00000X0?ooo`<0000000<0oooo0000000000001P00001=0?oooa000000I`3oool00`000000P820
0?ooo`070?ooo`<000006`3oool3000000030?ooo`20P800000000H00000E03oool2000000P0oooo
0`00000L0?ooo`<00000g03oool003d0oooo3P00000W0?ooo`<00000EP3oool>000002L0oooo0`00
00030?ooo`@00000CP3oool00`20P80000000000000>000006L0oooo3@0000000`20P800oooo0?oo
o`0H0?ooo`<000000`3oool4000000030820P03oool0oooo05<0oooo3P00000K0?ooo`<00000g03o
ool00780oooo0`00002;0?ooo`<00000E@3oool00`20P80000000000000?000008h0oooo0`000026
0?ooo`<00000g03oool00780oooo0`00002;0?ooo`<00000E@3ooolB000000030820P03oool0oooo
08/0oooo0`0000260?ooo`<00000g03oool00780oooo0`00002;0?ooo`<00000E@3ooolB00000003
0820P03oool0oooo08/0oooo0`0000260?ooo`<00000g03oool00780oooo0`00002;0?ooo`<00000
E03oool00`20P80000000000000@000000030410@03oool0oooo08/0oooo0`0000260?ooo`<00000
g03oool00780oooo0`00002;0?ooo`<00000E03ooolD000008d0oooo0`0000260?ooo`<00000g03o
ool00740oooo100000000`20P800oooo0?ooo`280?ooo`<00000E03ooolD000008d0oooo0`000025
0?ooo`@0000000<0P8200?ooo`3oool0f@3oool006l0oooo00<0P820000000000000100000020820
P8D0oooo00<0`<300820P00000000`00001C0?oooaD0000000<0P8200?ooo`3oool0R03oool00`20
P800000000000002000008<0oooo00<0P820000000000000100000020820P=T0oooo003o0?ooo`80
oooo0P00001C0?oooaH00000S@3oool00`20P80000000?ooo`3o0?ooofD0oooo003o0?oooeH0oooo
00<0P8200000000000005000003o0?ooooD0oooo003o0?oooeH0oooo00<0P8200000000000005@00
003o0?oooo@0oooo003o0?oooeH0oooo600000000`20P800oooo0?ooo`3o0?oooo40oooo003o0?oo
oeH0oooo600000000`20P800oooo0?ooo`3o0?oooo40oooo003o0?oooeP0oooo0P20P80@00000080
P820o`3oooof0?ooo`00o`3ooomM0?ooo`P0000000<0P8200?ooo`3oool0o`3ooooj0?ooo`00o`3o
oomP0?ooo`<00000o`3ooooo0?ooo`00o`3ooomP0?ooo`<00000o`3ooooo0?ooo`00o`3ooomP0?oo
o`<00000o`3ooooo0?ooo`00o`3ooomP0?ooo`<00000o`3ooooo0?ooo`00H03ooon603Tio`H0oooo
L`0i>Ol3000008D0>CWo1P3oool00`2LW?l0>CWo03Tio`2503Tion/0oooo001P0?ooohH0>CWo1P3o
oomc03Tio`<00000Q@0i>Ol60?ooo`0309bLo`0i>Ol0>CWo08D0>CWoj`3oool00600ooooQP0i>Ol6
0?ooog<0>CWo0`00002503Tio`H0oooo00<0W9co03Tio`0i>Ol0Q@0i>Oo[0?ooo`00H03ooon603Ti
o`H0ooooL`0i>Ol3000008D0>CWo1P3oool00`2LW?l0>CWo03Tio`2503Tion/0oooo001P0?ooohH0
>CWo1P3ooomc03Tio`<00000Q@0i>Ol60?ooo`0309bLo`0i>Ol0>CWo08D0>CWoj`3oool005T0oooo
S@0i>Ol60?ooog<0>CWo0`00002503Tio`H0oooo00<0W9co03Tio`0i>Ol0Q@0i>Oo[0?ooo`00F@3o
ool703Tiool0oooo0`00003o0?oooaD0oooo1P2LW?oT0?ooo`00F@3oool703Tiool0oooo0`00003o
0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?oo
o`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo
0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i
>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Ti
ool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0
oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3o
ool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o
0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?oo
o`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo
0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i
>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Ti
ool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0
oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3o
ool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o
0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?oo
o`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo
0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i
>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Ti
ool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0
oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OoT0?ooo`00F@3o
ool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OnX0?ooo`050820P0000000000000000020P800
=`3oool005T0oooo1`0i>Ooo0?ooo`<00000o`3ooolE0?ooo`H0>CWoZ03oool7000000030820P03o
ool0oooo0380oooo001I0?ooo`L0>CWoo`3oool300000?l0oooo5@3oool603TiojL0oooo2P00000c
0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OnV0?ooo`030<30`00000000000
00/000000P20P80^0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OnV0?ooo`03
0820P0000000000000l0000000<0P8200?ooo`3oool0:@3oool005T0oooo1`0i>Ooo0?ooo`<00000
o`3ooolE0?ooo`H0>CWoYP3oool00`20P80000000000000A000002X0oooo001I0?ooo`L0>CWoo`3o
ool300000?l0oooo5@3oool603TiojH0oooo00<0@4100000000000004`0000020820P0030<30`03o
ool0oooo02<0oooo001I0?ooo`L0>CWoo`3oool300000?l0oooo5@3oool603TiojH0oooo6P00000T
0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OnV0?oooa`000000P20P8000`30
`<00oooo0?ooo`0M0?ooo`00F@3oool703Tiool0oooo0`00003o0?oooaD0oooo1P0i>OnV0?ooob40
00007@3oool005T0oooo1`0i>Ooo0?ooo`40ooooo`00003U000001`0oooo001I0?ooo`L0>CWoo`3o
ool10?ooool00000iP0000000`20P800oooo0?ooo`0H0?ooo`00F@3oool703Tiool0oooo0@3ooooo
00000>@000007@3oool005T0oooo1`0i>Ooo0?ooool0oooo603oool603TiojH0oooo7P0000000`20
P800oooo0?ooo`0M0?ooo`00F@3oool703Tiool0ooooo`3ooolH0?ooo`H0>CWoYP3oool00`20P800
00000000000G00000080P8208P3oool005T0oooo1`0i>Ooo0?ooool0oooo603oool603TiojH0oooo
00<0P8200000000000005@00000V0?ooo`00F@3oool703Tiool0ooooo`3ooolH0?ooo`H0>CWoYP3o
ool00`20P80000000000000B000000030820P03oool0oooo02H0oooo001I0?ooo`L0>CWoo`3ooooo
0?oooaP0oooo1P0i>OnV0?ooo`030820P0000000000000l000000P20P80Z0?ooo`00F@3oool703Ti
ool0ooooo`3ooolH0?ooo`H0>CWoYP3oool00`20P80000000000000<000000030820P03oool0oooo
02`0oooo001I0?ooo`L0>CWoo`3ooooo0?oooaP0oooo1P0i>OnV0?ooo`030820P0000000000000X0
0000<@3oool005T0oooo1`0i>Ooo0?ooool0oooo603oool603TiojL0oooo200000020820P3<0oooo
001I0?ooo`L0>CWoo`3ooooo0?oooaP0oooo1P0i>OnW0?ooo`D0000000<0P8200?ooo`3oool0=@3o
ool005T0oooo1`0i>Ooo0?ooool0oooo603oool603TiojP0oooo0P00000j0?ooo`00F@3oool703Ti
ool0ooooo`3ooolH0?ooo`H0>CWoi03oool002<0oooo00<0P8200?ooo`3oool0:03oool5000000H0
oooo1`0i>Ooo0?ooool0oooo603oool603Tio`/0oooo00<0P8200?ooo`3oool09P3oool500000003
0820P03oool0oooo0:P0oooo000S0?ooo`030820P0000000oooo02H0oooo0P0000001020P800oooo
0?ooo`3oool2000000030820P03oool0oooo0080oooo1`0i>Ooo0?ooool0oooo603oool603Tio`/0
oooo00<000000?ooo`3oool09@3oool2000000@0oooo0P00002Y0?ooo`008`3oool2000002H0oooo
00<0@41000000020P8001P3oool00`10@400P8200?ooo`020?ooo`L0>CWoo`3ooooo0?oooaP0oooo
1P0i>Ol:0?ooo`8000009@3oool00`20P80000000410@0060?ooo`030820P0000000`<300:L0oooo
000R0?ooo`@00000903oool2000000P0oooo00<0P8200000000000000P3oool703Tiool0ooooo`3o
oolH0?ooo`H0>CWo2@3oool4000002<0oooo0`0000080?ooo`800000Y`3oool00280oooo1000000T
0?ooo`8000002@3oool200000080oooo1`0i>Ooo0?ooool0oooo603oool603Tio`T0oooo1000000S
0?ooo`<000002@3oool00`000000oooo0?ooo`1i0?ooo`030820P0000000000000`0000000<0P820
0?ooo`3oool06P3oool00240oooo0`0000000`20P80000000820P00;0?oooa80000000<0P8200?oo
o`3oool00P3oool2000000030820P03oool0oooo00L0oooo0P0000000`20P800oooo03Tio`0603Ti
ool0ooooo`3ooolH0?ooo`H0>CWo203oool01020P800000000000010@402000000/0oooo4`000003
0?ooo`030820P0000000000000X0oooo0P00001k0?ooo`<0000000<0P8200?ooo`3oool01P3oool0
0`20P80000000820P00L0?ooo`00803oool01`20P8000000000000000000oooo00000020P8002`3o
oolB000000040820P03oool0oooo0?ooo`<0000000<0P8200?ooo`3oool01`3oool3000000030?oo
o`0i>Ol0>CWo00D0>CWoo`3ooooo0?oooaP0oooo1P0i>Ol80?ooo`<0000000<0P820000000000000
2`3ooolC000000<0oooo0`00000:0?ooo`<00000N`3oool4000000T0oooo00<0P8200?ooo`3oool0
6P3oool00200oooo00D0P820000000000000P8200?ooo`0200000240oooo0`00000;0?ooo`800000
00<0oooo03Tio`0i>Ol01@0i>Ooo0?ooool0oooo603oool603Tio`P0oooo0`000000103oool00000
00000020P80P0?ooo`8000002`3oool00`20P80000000000001l0?ooo`<000002@3oool00`20P800
oooo0?ooo`0J0?ooo`00803oool01010@400000000000030`<020?ooo`030000003oool0oooo01h0
oooo00@0`<3000000000000000002`3oool2000000030?ooo`0i>Ol0>CWo00D0>CWoo`3ooooo0?oo
oaP0oooo1P0i>Ol70?ooo`040820P000000000000820P080oooo00<000000820P03oool07P3oool0
0`20P80000000000000;0?ooo`030820P0000000000007`0oooo00@0@410000000000000P820203o
ool00`30`<00oooo0?ooo`0J0?ooo`00803oool3000000<0oooo00<0P8200000003oool07P3oool0
1020P800000000000000000;0?ooo`<000001`0i>Ooo0?ooool0oooo603oool603Tio`L0oooo0`00
00040?ooo`030000003oool0oooo01d0oooo0`00000;0?ooo`040820P000000000000820P7`0oooo
0`00000U0?ooo`007`3oool4000000<0oooo00<0P8200000003oool07P3oool01020P80000000000
0000000;0?ooo`<000001`0i>Ooo0?ooool0oooo603oool603Tio`H0oooo100000040?ooo`030000
003oool0oooo01d0oooo0`00000;0?ooo`040820P000000000000820P7`0oooo1000000T0?ooo`00
7P3oool01020P80000000000000000040?ooo`030<30`0000000P82001h0oooo00@0P82000000000
000000002`3oool3000000L0>CWoo`3ooooo0?oooaP0oooo1P0i>Ol50?ooo`040<30`00000000000
000000D0oooo00<0@4100820P03oool07@3oool3000000/0oooo00@0P820000000000000P820O@3o
ool01020P800000000000020P80S0?ooo`007P3oool3000000H0oooo0P00000N0?ooo`040820P000
00000000000000/0oooo0`00000703Tiool0ooooo`3ooolH0?ooo`H0>CWo1@3oool01020P8000000
00000020P8050?ooo`030820P0000000oooo01d0oooo0`00000;0?ooo`040820P000000000000820
P7h0oooo0`0000000`20P800oooo0?ooo`0P0?ooo`007P3oool3000000H0oooo0P0000090?oooa80
000000@0P8200?ooo`3oool0P8200`00000;0?ooo`<000001`0i>Ooo0?ooool0oooo603oool603Ti
o`D0oooo00@0P820000000000000P8201@3oool00`20P80000000?ooo`080?oooa<000000P3oool3
000000/0oooo00@0P820000000000000P820OP3oool01020P800000000000020P80R0?ooo`007@3o
ool01020P800000000000020P8070?ooo`0300000020P800oooo00L0oooo4P0000001020P800oooo
0?ooo`20P803000000/0oooo0`00000703Tiool0ooooo`3ooolH0?ooo`H0>CWo1@3oool3000000L0
oooo0P0000080?oooa<000000P3oool3000000/0oooo00@0P820000000000000P820OP3oool01@30
`<000000000000000000P8200240oooo000M0?ooo`<0000000<0P8200?ooo`3oool01@3oool20000
01d0oooo00@0P82000000000000000002`3oool3000000L0>CWoo`3ooooo0?oooaP0oooo1P0i>Ol4
0?ooo`@000001`3oool2000000030820P03oool0oooo01X0oooo0`00000;0?ooo`040820P0000000
00000820P800oooo0`00000Q0?ooo`007@3oool3000000T0oooo00<000000?ooo`3oool06`3oool0
1020P800000000000000000;0?ooo`<000001`0i>Ooo0?ooool0oooo603oool603Tio`@0oooo0`00
00090?ooo`0300000020P800oooo01/0oooo0`00000;0?ooo`040820P000000000000820P800oooo
1000000P0?ooo`00703oool3000000030820P03oool0oooo00L0oooo00<0@4100820P03oool0703o
ool3000000030<30`03oool0oooo00L0oooo00@0P820000000000000oooo1`0i>Ooo0?ooool0oooo
603oool603Tio`<0oooo0`0000000`20P800oooo0?ooo`070?ooo`030820P010@400oooo01`0oooo
0P0000000`20P800oooo0?ooo`080?ooo`030410@0000000000007X0oooo00<000000?ooo`3oool0
1@3oool01010@400000000000020P80O0?ooo`006`3oool4000000X0oooo00<0P8200000003oool0
703oool3000000030820P03oool0oooo00L0oooo0`0000000`3oool0>CWo03Tio`0503Tiool0oooo
o`3ooolH0?ooo`H0>CWo0P3oool01020P800000000000000000;0?ooo`030000003oool0oooo01/0
oooo0`00000:0?ooo`<00000NP3oool00`000000oooo0?ooo`050?ooo`040820P000000000000000
01l0oooo000K0?ooo`<000002`3oool00`20P80000000?ooo`0M0?ooo`80000000<0P8200?ooo`3o
ool01`3oool2000000030820P03oool0>CWo00H0>CWoo`3ooooo0?oooaP0oooo1P0i>Ol20?ooo`04
0820P000000000000820P0/0oooo00<000000?ooo`3oool06`3oool00`20P80000000000000:0?oo
o`800000N`3oool00`000000oooo0?ooo`060?ooo`@000007P3oool001X0oooo00@0`<3000000000
00000000303oool2000001d0oooo00<0P82000000010@400203oool01@30`<00000000000030`<00
oooo00L0>CWoo`3ooooo0?oooaP0oooo1P0i>Ol20?ooo`040410@000000000000820P0/0oooo00<0
P8200000003oool06`3oool01030`<00000000000020P8080?ooo`030820P0000000P82007/0oooo
0P0000080820P0<0000000<0P8200?ooo`3oool06`3oool001X0oooo00@0P820000000000000P820
303oool2000001h0oooo0P0000080?ooo`030820P000000000000080oooo1`0i>Ooo0?ooool0oooo
603oool603Tio`80oooo0`00000<0?ooo`030820P0000000oooo01`0oooo0`0000080?ooo`800000
Y`3oool001X0oooo0`0000000`20P800oooo0?ooo`0:0?ooo`80000000<0P8200?ooo`3oool0703o
ool2000000L0oooo0P0000030?ooo`L0>CWoo`3ooooo0?oooaP0oooo1P0i>Ol00`3oool000000000
0002000000`0oooo00<0P8200000000000007@3oool2000000030820P03oool0oooo00@0oooo0P00
00000`20P800oooo0?ooo`2U0?ooo`006@3oool01@20P8000000000000000000P82000`0oooo0P00
00000`10@400P8200?ooo`0L0?ooo`040<30`000000000000<30`0<0oooo00<0P82000000010@400
103oool703Tiool0ooooo`3ooolH0?ooo`H0>CWo00<0P8200000000000000P00000<0?ooo`040820
P000000000000820P1d0oooo00<0P82000000020P800103oool00`10@40000000820P02X0?ooo`00
5`3oool00`20P800000000000006000000030820P03oool0oooo00D0oooo1`00000O0?ooo`D00000
1P3oool703Tiool0ooooo`3ooolH0?ooo`D0>CWo2@0000070?ooo`L000007P3oool5000000030820
P03oool0oooo0:P0oooo001I0?ooo`L0>CWoo`3ooooo0?oooaP0oooo1P0i>OoT0?ooo`00F@3oool7
03Tiool0ooooo`3ooolH0?ooo`H0>CWoi03oool005T0oooo1`0i>Ooo0?ooool0oooo603oool603Ti
on@0oooo001I0?ooo`L0>CWoo`3ooooo0?oooaP0oooo1P0i>OoT0?ooo`00F@3oool703Tiool0oooo
o`3ooolH0?ooo`H0>CWoi03oool00?l0ooooo`3ooomh0?ooo`H0>CWoi03oool00600ooooQP0i>Ol6
0?oooo/0>CWo1P3oool00`2LW?l0>CWo03Tio`2503Tio`030?ooo`0i>Ol0>CWo00@0>CWoi03oool0
0600ooooQP0i>Ol60?oooo/0>CWo1P3oool00`2LW?l0>CWo03Tio`2503Tion/0oooo001P0?ooohH0
>CWo1P3ooook03Tio`H0oooo00<0W9co03Tio`0i>Ol0Q@0i>Oo[0?ooo`00H03ooon603Tio`H0oooo
n`0i>Ol60?ooo`0309bLo`0i>Ol0>CWo08D0>CWoj`3oool00600ooooQP0i>Ol60?oooo/0>CWo1P3o
ool00`2LW?l0>CWo03Tio`2503Tion/0oooo001P0?ooohH0>CWo1P3ooook03Tio`H0oooo00<0W9co
03Tio`0i>Ol0Q@0i>Oo[0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0
oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo
0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0oooo
o`3ooooo0?ooof<0oooo002o0?ooo`@00000o`3ooonB0?ooo`<0000000<0P8200?ooo`3oool0o`3o
ool70?ooo`00_P3oool2000000<0oooo00<000000820P03oool0o`3ooon=0?ooo`80000000D0P820
0?ooo`3oool0P8200000003o0?ooo`P0oooo002l0?ooo`80000000<0@4100?ooo`3oool00`3oool0
0`10@40000000?ooo`210?ooo`030820P03oool0oooo02L0oooo1@20P83J0?ooo`80000000<0P820
0?ooo`3oool00P3oool00`20P80000000820P03o0?ooo`H0oooo002k0?ooo`030820P00000000000
00L0oooo0P0000210?ooo`0300000020P800oooo02D0oooo00<0P8200000000000000`3oool00`20
P80000000000003G0?ooo`800000203oool00`000000oooo0?ooo`3o0?ooo`@0oooo002k0?ooo`03
0820P0000000000000L0oooo0P0000200?ooo`80000000<0P8200?ooo`3oool0903oool2000000H0
oooo00<000000820P03oool0e@3oool2000000P0oooo00<000000?ooo`3oool0o`3oool40?ooo`00
^`3oool2000000P0oooo0P0000000`20P800oooo0?ooo`1l0?ooo`040<30`000000000000410@2@0
oooo00<0P82000000010@400203oool00`000000P8200?ooo`3C0?ooo`80000000<0P8200?ooo`3o
ool01P3oool200000?l0oooo1@3oool00;/0oooo0P0000080?ooo`80000000<0P8200?ooo`3oool0
O03oool01020P800000000000000000T0?ooo`80000000<0P8200?ooo`3oool01P3oool00`20P800
00000?ooo`3C0?ooo`80000000<0P8200?ooo`3oool01P3oool200000?l0oooo1@3oool00;/0oooo
0P0000080?ooo`80000000<0P8200?ooo`3oool0O03oool5000000/0oooo4`0000040?ooo`030820
P0000000000000T0oooo00<0P820000000000000d`3oool2000000030820P03oool0oooo00H0oooo
0P00003o0?ooo`D0oooo002k0?ooo`8000001`3oool01030`<00000000000020P81m0?ooo`060820
P0000000000000000020P80000002`3ooolC000000@0oooo00<0@4100000000000002@3oool01020
P800000000000020P83B0?ooo`80000000<0P8200?ooo`3oool01@3oool00`20P80000000000003o
0?ooo`D0oooo001k0?ooo`030820P03oool0oooo02d0oooo00<0P8200?ooo`3oool03@3oool00`20
P80000000?ooo`060?ooo`030820P0000000000007h0oooo0`000000103oool0P82000000000000Q
0?ooo`8000002`3oool3000009@0oooo00<0P8200?ooo`3oool0;@3oool00`20P800oooo0?ooo`0<
0?ooo`0300000020P800oooo00H0oooo0P00003o0?ooo`H0oooo001k0?ooo`030820P0000000oooo
02d0oooo00<0P8200000003oool03@3oool00`20P8000000000000060?ooo`<00000OP3oool30000
0080oooo0P00000Q0?ooo`8000002`3oool3000009@0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0<0?ooo`8000001P3oool300000?l0oooo1P3oool007/0oooo0P00000^0?ooo`80
00003`3oool00`20P80000000820P0030?ooo`80P82000<000000820P03oool0O@3oool3000000<0
oooo00<0P82000000030`<007`3oool3000000/0oooo0`0000000`30`<00oooo0?ooo`2@0?ooo`80
0000;P3oool2000000l0oooo00<0@4100820P020P8000`3oool01020P800000000000030`<3o0?oo
o`H0oooo001j0?ooo`@00000;03oool400000100oooo00<0P8200000000000000`00001o0?ooo`04
0820P00000000000000000@0oooo00<000000820P03oool07P3oool3000000/0oooo0`0000000`20
P800oooo0?ooo`2?0?ooo`@00000;03oool400000100oooo1@00003o0?ooo`T0oooo001j0?ooo`@0
0000;03oool4000009D0oooo00@0P820000000000000P820103oool00`000000P8200?ooo`0N0?oo
o`<000002`3oool3000000030820P03oool0oooo08l0oooo1000000/0?ooo`@00000o`3ooolN0?oo
o`00N@3oool3000000030820P0000000P82000/0oooo4P0000000`20P800oooo0?ooo`0:0?ooo`<0
000000<0P82000000020P800U03oool3000000030<30`03oool0oooo00<0oooo00<000000?ooo`3o
ool07@3oool3000000/0oooo0`0000000`20P800oooo0?ooo`2>0?ooo`040820P000000000000410
@08000002`3ooolC000000`0oooo00@0P820000000000000@4100P00003o0?oooad0oooo001h0?oo
o`070820P000000000000000003oool000000820P00;0?oooa80000000<0P8200?ooo`3oool02@3o
ool01`20P8000000000000000000oooo00000020P800U03oool3000000H0oooo00<000000?ooo`3o
ool01`3ooolC000000<0oooo0`00000;0?ooo`<0000000<0P8200?ooo`3oool0SP3oool300000003
0820P0000000000000/0oooo4`00000<0?ooo`<0000000<0P820000000000000o`3ooolM0?ooo`00
N03oool01@20P800000000000020P800oooo00800000:@3oool01@20P800000000000020P800oooo
00800000T`3oool3000000L0oooo00<0P8200000003oool01`3ooolC000000<0oooo0`00000;0?oo
o`<0000000<0P8200?ooo`3oool0SP3oool3000000040?ooo`00000000000820P2T0oooo0`000000
103oool0000000000020P83o0?oooa`0oooo001h0?ooo`040410@000000000000<30`080oooo00<0
00000?ooo`3oool09`3oool01010@400000000000030`<020?ooo`030000003oool0oooo0900oooo
00@0P82000000000000000001`3oool00`20P80000000820P0070?oooa<0P8200`3oool3000000/0
oooo0`0000000`20P800oooo0?ooo`2=0?ooo`040820P000000000000820P080oooo00<000000820
P03oool09`3oool01020P800000000000020P8020?ooo`0300000020P800oooo0?l0oooo6`3oool0
07P0oooo0`0000030?ooo`030820P0000000oooo02L0oooo0`0000030?ooo`030820P0000000oooo
0900oooo0`0000090?ooo`8000007@3oool3000000/0oooo0`0000000`20P800oooo0?ooo`2=0?oo
o`<00000103oool00`000000oooo0?ooo`0V0?ooo`<00000103oool00`000000oooo0?ooo`3o0?oo
oaX0oooo001g0?ooo`@000000`3oool00`20P80000000?ooo`0V0?ooo`@000000`3oool00`20P800
00000?ooo`2?0?ooo`040820P00000000000000000T0oooo0P00000N0?ooo`8000002`3oool30000
08l0oooo100000040?ooo`030000003oool0oooo02D0oooo100000040?ooo`030000003oool0oooo
0?l0oooo6P3oool007H0oooo00@0P8200000000000000000103oool00`30`<0000000820P00U0?oo
o`040820P00000000000000000@0oooo00<0`<3000000020P800S`3oool01010@400000000000020
P80:0?ooo`0300000020P800oooo01`0oooo0`0000090?ooo`040820P00000000000000008h0oooo
00@0`<3000000000000000001@3oool00`10@400P8200?ooo`0T0?ooo`040<30`000000000000000
00D0oooo00<0@4100820P03oool0o`3ooolJ0?ooo`00MP3oool3000000H0oooo0P00000U0?ooo`<0
00001P3oool2000008l0oooo0`00000;0?ooo`0300000020P800oooo01`0oooo00<0P82000000000
00002@3oool00`20P80000000000002?0?ooo`040820P000000000000820P0D0oooo00<0P8200000
003oool0903oool01020P800000000000020P8050?ooo`030820P0000000oooo0?l0oooo6P3oool0
07H0oooo0`0000060?ooo`8000002@3ooolB000000030820P03oool0oooo00L0oooo0`0000060?oo
o`800000S`3oool3000000`0oooo00<000000?ooo`3oool06`3oool00`20P8000000000000090?oo
o`030820P0000000000008l0oooo00@0P820000000000000P8201@3oool00`20P80000000?ooo`08
0?oooa<000002@3oool01020P800000000000020P8050?ooo`030820P0000000oooo0?l0oooo6P3o
ool007D0oooo00@0P820000000000000P8201`3oool00`000000P8200?ooo`070?oooa80000000<0
P8200?ooo`3oool01P3oool01020P800000000000020P8070?ooo`800000S@3oool3000000030820
P03oool0oooo00X0oooo00<000000?ooo`3oool0703oool2000000030820P03oool0oooo00H0oooo
0P00002@0?ooo`<000001`3oool2000000P0oooo4`0000090?ooo`<000001`3oool200000?l0oooo
6P3oool007D0oooo0`0000000`20P800oooo0?ooo`050?ooo`8000008`3oool3000000030820P03o
ool0oooo00D0oooo0P0000000`20P800oooo0?ooo`290?ooo`@000003@3oool2000001h0oooo0P00
00070?ooo`800000T03oool4000000L0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`@000001`3o
ool2000000030820P03oool0oooo0?l0oooo5`3oool007D0oooo0`0000090?ooo`030000003oool0
oooo0240oooo0`0000090?ooo`0300000020P800oooo08X0oooo1000000=0?ooo`8000007`3oool2
000000D0oooo0P0000000`20P800oooo0?ooo`2>0?ooo`<000002@3oool00`000000P8200?ooo`0Q
0?ooo`<000002@3oool00`000000P8200?ooo`3o0?oooaP0oooo001d0?ooo`<0000000<0P8200?oo
o`3oool01`3oool00`10@400P8200?ooo`0P0?ooo`<0000000<0P8200?ooo`3oool01`3oool00`20
P800@4100?ooo`280?ooo`030820P010@400000000<000000`20P8070?ooo`030<30`020P800P820
00<0000000<0@4100?ooo`3oool06`3oool00`30`<00P820000000030820P0030410@020P800P820
0900oooo0`0000000`20P800oooo0?ooo`070?ooo`030820P010@400oooo0200oooo0`0000000`20
P800oooo0?ooo`070?ooo`030820P010@400oooo0?l0oooo603oool007<0oooo1000000:0?ooo`03
0820P0000000oooo01l0oooo1000000;0?ooo`030000003oool0oooo0?l0ooooE03oool01020P800
000000000000000;0?ooo`030000003oool0oooo01h0oooo00@0P82000000000000000002`3oool0
0`000000oooo0?ooo`3o0?oooaL0oooo001c0?ooo`<000002`3oool00`20P80000000?ooo`0O0?oo
o`<00000303oool00`000000oooo0?ooo`3o0?oooe@0oooo00@0P820000000000000P8202`3oool0
0`000000oooo0?ooo`0N0?ooo`040820P000000000000820P0/0oooo00<000000?ooo`3oool0o`3o
oolG0?ooo`00LP3oool01030`<00000000000000000<0?ooo`8000007P3oool01030`<0000000000
0000000<0?ooo`030820P0000000oooo0?l0ooooE03oool01010@400000000000020P80;0?ooo`03
0820P0000000oooo01h0oooo00@0@410000000000000P8202`3oool00`20P80000000?ooo`3o0?oo
oaL0oooo001b0?ooo`040820P000000000000820P0`0oooo0P00000N0?ooo`040820P00000000000
0820P0`0oooo00<0P8200000003oool0o`3ooomD0?ooo`<00000303oool00`20P80000000?ooo`0N
0?ooo`<00000303oool00`20P80000000?ooo`3o0?oooaL0oooo001b0?ooo`<0000000<0P8200?oo
o`3oool02P3oool2000000030820P03oool0oooo01/0oooo0`0000000`20P800oooo0?ooo`0:0?oo
o`030820P000000000000?l0ooooD`3oool4000000`0oooo00<0P8200000000000007@3oool40000
00`0oooo00<0P820000000000000o`3ooolG0?ooo`00L@3oool01@20P8000000000000000000P820
00`0oooo0P0000000`10@400P8200?ooo`0J0?ooo`050820P0000000000000000020P800303oool0
1020P800000000000020P83o0?oooe40oooo00<0P8200000000000000P00000<0?ooo`040820P000
000000000820P1/0oooo00<0P8200000000000000P00000<0?ooo`050820P000000000000820P030
`<00o`3ooolE0?ooo`00K`3oool00`20P800000000000006000000030820P03oool0oooo00D0oooo
1`00000H0?ooo`030820P0000000000000H0000000<0P8200?ooo`3oool01@3oool700000?l0oooo
C`3oool9000000L0oooo1`00000I0?ooo`T000001`3oool700000?l0oooo5@3oool00?l0ooooo`3o
oooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0
ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3o
ool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{288, 70.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 3.17 Exercise (15).", "Caption",
  CellTags->"Fig. 3.17"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, z)\)]],
  " in the central region around ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " as a Fourier series involving the Bessel function ",
  Cell[BoxData[
      \(TraditionalForm\`I\_0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Taylor-expand this expression in  ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " to show that the potential near ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Bold"]}], TraditionalForm]]],
  "has the form"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, z)\  = \ A\ r\^2\  + \ B\ z\^2 + C\)]],
  " ."
}], "NE2",
  CellTags->"(3.2.62)"],

Cell[TextData[{
  " This form of \[Phi] is simply an even Taylor expansion in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(r\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", as required by the symmetry of the system. Find values for ",
  Cell[BoxData[
      \(TraditionalForm\`A, \ B, \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  "  when ",
  Cell[BoxData[
      \(TraditionalForm\`a = 5\ cm\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(b = 5\ cm\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L = 10\ cm\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " By direct substitution of Eq. ",
  ButtonBox["(3.2.62)",
    ButtonData:>"(3.2.62)",
    ButtonStyle->"Hyperlink"],
  "  into Laplace's equation, show that ",
  Cell[BoxData[
      \(TraditionalForm\`A = \(-B\)/2\)]],
  ". This implies that the center of the trap is a saddlepoint of the \
potential.  Does your solution from part (a) satisfy this?"
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " By carefully taking a limit as ",
  Cell[BoxData[
      \(TraditionalForm\`L \[Rule] \ \[Infinity]\)]],
  ", show that your result from part (a) can be written as the following \
Fourier integral:"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, z) = \(V\_o\)(
          1 - \(2\/\[Pi]\) \
\(\[Integral]\_0\%\[Infinity]\(\[DifferentialD]k\/k\) 
                  sin\ k\ b\ cos\ k\ z\ \(\(I\_o\)(k\ r)\)\/\(\(I\_o\)(k\ \
a)\)\))\)]],
  "."
}], "Text"],

Cell[TextData[{
  " [Hint: ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can do the following sum analytically: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(n = 0\)\%\[Infinity]\((\(-1\))\)\^n/\((2  
                n + 1)\)\)]],
  ". ] Use the integral form to plot ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Phi](0, z)\)\(\ \)\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\) b \[LessEqual] \ z \[LessEqual] \ 2  b\)]],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`a = b/2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(16)",
    FontWeight->"Bold"],
  " A cylindrical copper bar of conductivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  " has radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`0 < z < L\)]],
  ". The surface of the bar is insulated, except on the ends at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ", where wires are attached. The wire at ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(r = 0\)\)]],
  " injects current ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  ", and the wire at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0, \ z = L\)]],
  " removes the same current. Therefore, the form of the current density at \
",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["j",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", \(r, z = 0\), ")"}], "=", 
          RowBox[{
            RowBox[{
              StyleBox["j",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", \(r, z = L\), ")"}], "=", 
            RowBox[{"I", " ", \(\(\[Delta](r)\)\/\(2\ \[Pi]\ r\)\), " ", 
              OverscriptBox[
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"]}]}]}], TraditionalForm]]],
  ".  Find the electrostatic potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, z)\)]],
  " throughout the bar, and plot it as a contour plot, in suitably normalized \
coordinates, assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](0, L/2) = 0. \)]],
  " Show that your solution satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(2  \[Pi] \(\[Integral]\_0\%a 
              r \[DifferentialD]r\ \(\(j\_z\)(r, z)\)\) = I\)\(,\)\)\)]],
  " and plot ",
  Cell[BoxData[
      \(TraditionalForm\`\(j\_z\)(r, L/2)\)]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ". (Hint: keep ",
  StyleBox["all",
    FontSlant->"Italic"],
  " eigenmodes, including one with a zero eigenvalue. See ",
  ButtonBox["Example 2",
    ButtonData:>"c:30",
    ButtonStyle->"Hyperlink"],
  " in Sec. 3.2.2.)"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subtitle",
  CellTags->"c:44"],

Cell[TextData[{
  "Arthur C. Clarke, ",
  StyleBox["The Fountains of Paradise ",
    FontSlant->"Italic"],
  "(Harcourt Brace Jovanovitch, New York, 1979)",
  StyleBox[".",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "D. G. Zill and M. R. Cullen, ",
  StyleBox["Advanced Engineering Mathematics, ",
    FontSlant->"Italic"],
  "2nd ed",
  StyleBox[". ",
    FontSlant->"Italic"],
  " (Jones and Bartlett, Sudbury, Mass., 2000)."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{800, 556},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Chapter 3, Section 3.", 
          CounterBox[ "Subtitle"]}], "Header"]}, {Cell[ 
        TextData[ "Dubin"], "Header"], Cell[ 
        TextData[ 
        "Numerical and Analytical Methods for Scientists and Engineers"], 
        FontWeight -> Bold, FontSlant -> Italic, FontFamily -> Times], 
      Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 117, "IndexEntries" -> {{"i:1", "Wave \
equation"}, {"i:10", "Dirichlet, Johann"}, {"i:103", "Eigenvalue problem"}, \
{"i:104", "Eigenvalue problem"}, {"i:105", "Eigenvalue problem"}, {"i:106", \
"Eigenvalue problem"}, {"i:107", "Eigenvalue problem"}, {"i:113", "Fick's \
law"}, {"i:115", "(* *) (brackets used for comments)"}, {"i:16", \
"Superposition principle"}, {"i:19", "Catenary"}, {"i:21", "Thermal \
conductivity"}, {"i:25", "Heat equation"}, {"i:26", "Thermal diffusivity"}, \
{"i:45", "Clarke, Arthur C."}, {"i:45", "Nanotubes"}, {"i:45", "Tether"}, \
{"i:52", "Skipping rope"}, {"i:53", "Shroedinger, Erwin"}, {"i:53", \
"Shroedinger's equation"}, {"i:55", "Blackbody"}, {"i:55", "Stefan-Boltzmann \
constant"}, {"i:57", "Laplace, Pierre"}, {"i:57", "Laplace's equation"}, \
{"i:6", "Separation of variables"}, {"i:63", "Gauss, Johann Carl Friedrich"}, \
{"i:63", "Gauss' law"}, {"i:69", "Eigenvalue problem"}, {"i:71", "Spherical \
harmonics"}, {"i:79", "Gibbs phenomenon"}, {"i:80", "Bessel functions"}, \
{"i:81", "Bessel, Friedrich W."}, {"i:82", {
  StyleBox[ "BesselJ", FontWeight -> "Bold"], " and ", 
  StyleBox[ "BesselY", FontWeight -> "Bold"]}}, {"i:83", 
  StyleBox[ "LegendreP", FontWeight -> "Bold"]}, {"i:84", 
  StyleBox[ "SphericalHarmonicY", FontWeight -> "Bold"]}, {"i:86", {
  StyleBox[ "BesselJZeros", FontWeight -> "Bold"], " and ", 
  StyleBox[ "BesselYZeros", FontWeight -> "Bold"]}}, {"i:87", {
  StyleBox[ "BesselJZeros", FontWeight -> "Bold"], " and ", 
  StyleBox[ "BesselYZeros", FontWeight -> "Bold"]}}, {"i:89", {
  StyleBox[ "BesselI", FontWeight -> "Bold"], " and ", 
  StyleBox[ 
  "BesselK", FontWeight -> 
    "Bold"]}}, {"i:91", "Gibbs phenomenon"}, {"i:92", "Penning trap"}, \
{"i:95", {"Speed of sound (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Wave speed)"}}, {"i:1", "Partial differential equations", \
{"wave equation (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Wave equation)"}}, {"i:10", "Boundary conditions", \
"Dirichlet"}, {"i:100", "Separation of variables", "for Laplace's equation in \
cylindrical coordinates"}, {"i:101", "Energy", "flux"}, {"i:102", "Energy", \
"conservation, in heat equation"}, {"i:105", "Boundary conditions", \
"periodic"}, {"i:108", "Heat equation", "derivation"}, {"i:109", {"Laplacian \
operator ( ", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ "\[Del]", "2"], 
        TraditionalForm]]], ")"}, "in cylindrical coordinates"}, {"i:11", \
"Boundary conditions", "von Neumann"}, {"i:110", {"Laplacian operator ( ", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ "\[Del]", "2"], 
        TraditionalForm]]], ")"}, "in spherical coordinates"}, {"i:112", \
"Potential", {"electrostatic (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Laplace's equation, Poisson's equation)"}}, {"i:114", \
"Diffusion", "equation"}, {"i:116", "Heat equation", "beneral solution, von \
Neumann bcs"}, {"i:12", "Eigenmodes", "Dirichlet, in wave equation"}, \
{"i:13", "Fourier series", "in solution of wave equation"}, {"i:14", \
"Boundary value problems", "existence and uniqueness of solution"}, {"i:15", \
"Wave equation", "d'Alembert's solution"}, {"i:17", "Wave equation", \
"inhomogeneous"}, {"i:18", "Wave equation", "solution for a uniform string"}, \
{"i:2", "Wave equation", "for uniform system"}, {"i:23", "Continuity \
equation", "for energy density"}, {"i:27", "Boundary conditions", \
"Dirichlet"}, {"i:28", "Boundary conditions", "von Neumann"}, {"i:29", \
"Boundary conditions", "mixed"}, {"i:3", "Wave equation", "derivation"}, \
{"i:30", "Equilibrium", "temperature in heat equation"}, {"i:31", \
"Equilibrium", "existence of, in heat equation"}, {"i:33", "Heat equation", \
"general solution"}, {"i:34", "Fourier series", "in solution of heat \
equation"}, {"i:35", "Eigenmodes", "Dirichlet, in heat equation"}, {"i:36", \
"Heat equation", "approach to equilibrium"}, {"i:37", "Eigenvalue problem", \
"von Neumann, for heat equation"}, {"i:38", "Eigenmodes", "mixed, for heat \
equation"}, {"i:39", "Eigenmodes", "von Neumann, for heat equation"}, {"i:4", \
"Equilibrium", "of a stretched string"}, {"i:41", "Orthogonality", "of \
eigenmodes satisfying mixed boundary conditions"}, {"i:42", "Heat equation", \
"general solution with mixed boundary conditions"}, {"i:43", "Separation of \
variables", "for heat equation"}, {"i:46", "Equilibrium", "of a vertical rod \
in gravity"}, {"i:47", "Equilibrium", "of a stretched string"}, {"i:5", \
"Equilibrium", "of a string in gravity (catenary)"}, {"i:51", "Wave \
equation", "vector"}, {"i:57", "Laplace's equation", "boundary conditions"}, \
{"i:57", "Partial differential equations", {"Laplace's equation (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Laplace's equation)"}}, {"i:57", "Poisson's equation", \
{"boundary conditions (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Laplace's equation, boundary conditions)"}}, {"i:58", \
"Boundary conditions", "Dirichlet"}, {"i:60", "Boundary conditions", \
"mixed"}, {"i:61", "Laplace's equation", "uniqueness of solution"}, {"i:62", \
"Laplace's equation", "existence of solution"}, {"i:64", "Laplace's \
equation", "analytic solution via separation of variables"}, {"i:65", \
"Laplace's equation", "analytic solution via separation of variables"}, \
{"i:67", "Laplace's equation", "analytic solution via separation of \
variables"}, {"i:67", "Separation of variables", "for Laplace's equation in \
spherical coordinates"}, {"i:68", "Laplace's equation", "analytic solution \
via separation of variables"}, {"i:72", "Orthogonality", "of associated \
Legendre functions"}, {"i:73", "Orthogonality", "of spherical harmonics"}, \
{"i:75", "Coordinates", "cylindrical"}, {"i:76", "Coordinates", \
"rectangular"}, {"i:76", "Separation of variables", "for Laplace's equation \
in rectangular coordinates"}, {"i:78", "Coordinates", "spherical"}, {"i:8", \
"Boundary conditions", "homogeneous"}, {"i:81", "Ordinary differential \
equations", "Bessel's equation"}, {"i:85", "Bessel functions", "zeros"}, \
{"i:88", "Bessel functions", "modified"}, {"i:9", "Boundary conditions", \
"homogeneous"}, {"i:90", "Bessel functions", "orthogonality relation"}, \
{"i:90", "Orthogonality", "of Bessel functions"}, {"i:93", "Bessel \
functions", "form for small argument"}, {"i:94", "Bessel functions", "form \
for small argument"}, {"i:96", "Equilibrium", "of a string in gravity \
(catenary)"}, {"i:111", {"Wavefunction (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Shroedinger's equation, Eigenmodes)"}, "", ""}, {"i:12", \
{"Normal modes (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Eigenvalue problems, Eigenmodes)"}, "", ""}, {"i:20", \
"Flux", {"heat (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Energy flux)"}, ""}, {"i:22", "Density", {"energy (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Energy density)"}, ""}, {"i:24", "Specific heat(s)", "", ""}, \
{"i:25", "Partial differential equations", {"heat equation (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Heat equation)"}, ""}, {"i:32", "Eigenvalue problem", \
"Dirichlet, for heat equation", ""}, {"i:40", "Eigenvalue problem", "mixed, \
for heat equation", ""}, {"i:48", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "shallow water", ""}, {"i:49", {"Wave speed (", \

  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Phase velocity, Group velocity)"}, "", ""}, {"i:49", {"Wave \
speed (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Phase velocity, Group velocity)"}, "on a string", ""}, \
{"i:50", {"Wave speed (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Phase velocity, Group velocity)"}, "for shallow water \
waves", ""}, {"i:53", "Partial differential equations", {"Shroedinger's \
equation (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Shroedinger's equation)"}, ""}, {"i:55", {"Radiation (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Wavepacket energy and momentum flux)"}, "", ""}, {"i:56", \
"Boundary conditions", "mixed", ""}, {"i:57", "Boundary conditions", "for \
Laplace's and Poisson's equation", ""}, {"i:59", "Boundary conditions", "von \
Neumann", ""}, {"i:69", "Function(s)", "hypergeometric", ""}, {"i:7", \
"Eigenvalue problem", "", ""}, {"i:70", "Function(s)", "associated Legendre", \
""}, {"i:75", "Separation of variables", "for Laplace's equation in \
cylindrical coordinates", ""}, {"i:77", "Density", "current", ""}, {"i:80", \
"Function(s)", {"Bessel (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Bessel functions)"}, ""}, {"i:9", {"Eigenvalues (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " Eigenmodes, Eigenvalue problems)"}, "", ""}, {"i:95", \
"Sound", {"speed (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " Speed of sound, Wave speed)"}, ""}, {"i:97", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "tidal", ""}, {"i:98", "Eigenmodes", "in a \
water channel of uniform depth", ""}, {"i:99", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "on a uniform string with fixed ends", ""}}},
CellLabelAutoDelete->True,
ScriptSizeMultipliers->0.85,
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{20, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(3.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE2"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(3.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE2"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE2",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE2", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE3"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(3.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE3"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE3",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE3", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE4"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(3.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE4"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE4",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE4", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE5"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(3.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE5"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE5",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE5", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE6"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(3.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE6"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE6",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE6", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
01L0001804P000000^l2@?okonh34`9B;@85:0?l0@00009H0UP00P0067@B`001
0@00I0010000000030000BL?0040000000000000000006L001000`00000@0?oH
ofXIX1=F8040800000400000000000l1\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1727, 52, 92, 1, 107, "Title",
      CellTags->"c:1"]},
  "c:3"->{
    Cell[2467, 75, 147, 4, 69, "Subtitle",
      CellTags->"c:3"]},
  "i:3"->{
    Cell[2659, 85, 88, 1, 40, "Subsubtitle",
      CellTags->{"i:3", "c:4"}]},
  "c:4"->{
    Cell[2659, 85, 88, 1, 40, "Subsubtitle",
      CellTags->{"i:3", "c:4"}]},
  "c:5"->{
    Cell[2772, 90, 50, 1, 42, "Section",
      CellTags->"c:5"]},
  "i:4"->{
    Cell[3231, 104, 65, 1, 31, "Section",
      CellTags->{"i:4", "c:6"}]},
  "c:6"->{
    Cell[3231, 104, 65, 1, 31, "Section",
      CellTags->{"i:4", "c:6"}]},
  "Fig. 3.1"->{
    Cell[46100, 671, 76, 1, 16, "Caption",
      CellTags->"Fig. 3.1"]},
  "Fig. 3.2"->{
    Cell[80360, 1127, 99, 1, 16, "Caption",
      CellTags->"Fig. 3.2"]},
  "(3.1.1)"->{
    Cell[81140, 1153, 195, 6, 29, "NumberedEquation",
      CellTags->"(3.1.1)"]},
  "(3.1.2)"->{
    Cell[81811, 1178, 156, 3, 27, "NumberedEquation",
      CellTags->"(3.1.2)"]},
  "c:7"->{
    Cell[83589, 1231, 72, 1, 31, "Section",
      CellTags->"c:7"]},
  "Fig. 3.3"->{
    Cell[150757, 2082, 159, 4, 16, "Caption",
      CellTags->"Fig. 3.3"]},
  "(3.1.3)"->{
    Cell[151875, 2121, 295, 8, 38, "NumberedEquation",
      CellTags->"(3.1.3)"]},
  "(3.1.4)"->{
    Cell[152365, 2139, 283, 4, 42, "NumberedEquation",
      CellTags->"(3.1.4)"]},
  "(3.1.5)"->{
    Cell[153766, 2180, 177, 6, 30, "NumberedEquation",
      CellTags->"(3.1.5)"]},
  "(3.1.6)"->{
    Cell[155123, 2225, 197, 7, 30, "NumberedEquation",
      CellTags->"(3.1.6)"]},
  "(3.1.7)"->{
    Cell[155669, 2249, 312, 7, 45, "NumberedEquation",
      CellTags->{"(3.1.7)", "i:1"}]},
  "i:1"->{
    Cell[155669, 2249, 312, 7, 45, "NumberedEquation",
      CellTags->{"(3.1.7)", "i:1"}]},
  "(3.1.8)"->{
    Cell[157712, 2311, 125, 2, 27, "NumberedEquation",
      CellTags->"(3.1.8)"]},
  "(3.1.9)"->{
    Cell[157884, 2317, 258, 9, 56, "NumberedEquation",
      CellTags->"(3.1.9)"]},
  "(3.1.10)"->{
    Cell[158794, 2353, 237, 6, 42, "NumberedEquation",
      CellTags->{"(3.1.10)", "i:2"}]},
  "i:2"->{
    Cell[158794, 2353, 237, 6, 42, "NumberedEquation",
      CellTags->{"(3.1.10)", "i:2"}]},
  "(3.1.11)"->{
    Cell[159153, 2368, 144, 5, 33, "NumberedEquation",
      CellTags->{"(3.1.11)", "i:49"}]},
  "i:49"->{
    Cell[159153, 2368, 144, 5, 33, "NumberedEquation",
      CellTags->{"(3.1.11)", "i:49"}]},
  "(3.1.12)"->{
    Cell[160487, 2414, 585, 16, 32, "NumberedEquation",
      CellTags->"(3.1.12)"]},
  "i:95"->{
    Cell[161595, 2453, 1419, 34, 163, "Text",
      CellTags->"i:95"]},
  "c:8"->{
    Cell[163063, 2493, 117, 4, 29, "Subsubtitle",
      CellTags->"c:8"]},
  "c:9"->{
    Cell[163205, 2501, 113, 4, 42, "Section",
      CellTags->"c:9"]},
  "i:6"->{
    Cell[163415, 2511, 801, 26, 61, "Text",
      CellTags->"i:6"]},
  "(3.1.13)"->{
    Cell[164219, 2539, 148, 5, 29, "NumberedEquation",
      CellTags->"(3.1.13)"]},
  "(3.1.14)"->{
    Cell[165300, 2580, 263, 8, 46, "NumberedEquation",
      CellTags->"(3.1.14)"]},
  "(3.1.15)"->{
    Cell[166771, 2631, 199, 4, 46, "NumberedEquation",
      CellTags->"(3.1.15)"]},
  "(3.1.16)"->{
    Cell[166973, 2637, 222, 7, 46, "NumberedEquation",
      CellTags->"(3.1.16)"]},
  "i:8"->{
    Cell[167198, 2646, 862, 24, 78, "Text",
      CellTags->"i:8"]},
  "i:7"->{
    Cell[168097, 2675, 66, 1, 29, "Subsubsection",
      CellTags->"i:7"]},
  "i:9"->{
    Cell[168166, 2678, 1388, 43, 70, "Text",
      CellTags->"i:9"]},
  "(3.1.17)"->{
    Cell[169944, 2737, 209, 4, 70, "NumberedEquation",
      CellTags->"(3.1.17)"]},
  "(3.1.18)"->{
    Cell[171661, 2796, 240, 8, 70, "NumberedEquation",
      CellTags->"(3.1.18)"]},
  "(3.1.19)"->{
    Cell[171933, 2808, 245, 6, 70, "NumberedEquation",
      CellTags->"(3.1.19)"]},
  "i:14"->{
    Cell[172524, 2828, 854, 22, 70, "Text",
      CellTags->"i:14"]},
  "(3.1.20)"->{
    Cell[175178, 2926, 345, 9, 70, "NumberedEquation",
      CellTags->"(3.1.20)"]},
  "i:18"->{
    Cell[175526, 2937, 342, 9, 70, "Text",
      CellTags->"i:18"]},
  "i:99"->{
    Cell[175905, 2951, 76, 1, 29, "Subsubsection",
      CellTags->"i:99"]},
  "i:12"->{
    Cell[175984, 2954, 778, 18, 95, "Text",
      CellTags->"i:12"]},
  "Cell 3.1"->{
    Cell[176787, 2976, 587, 13, 200, "Input",
      CellTags->"Cell 3.1"]},
  "i:13"->{
    Cell[3063674, 94928, 682, 25, 44, "Text",
      CellTags->"i:13"]},
  "(3.1.21)"->{
    Cell[3064359, 94955, 231, 7, 30, "NumberedEquation",
      CellTags->"(3.1.21)"]},
  "(3.1.22)"->{
    Cell[3064892, 94976, 230, 6, 38, "NumberedEquation",
      CellTags->"(3.1.22)"]},
  "(3.1.23)"->{
    Cell[3065668, 95003, 237, 4, 29, "NumberedEquation",
      CellTags->"(3.1.23)"]},
  "(3.1.24)"->{
    Cell[3066060, 95016, 248, 7, 38, "NumberedEquation",
      CellTags->"(3.1.24)"]},
  "c:10"->{
    Cell[3067581, 95072, 47, 1, 31, "Section",
      CellTags->"c:10"]},
  "Cell 3.2"->{
    Cell[3070039, 95157, 288, 7, 124, "Input",
      CellTags->"Cell 3.2"]},
  "(3.1.25)"->{
    Cell[3070495, 95172, 234, 7, 30, "NumberedEquation",
      CellTags->"(3.1.25)"]},
  "Cell 3.3"->{
    Cell[3071609, 95212, 467, 11, 143, "Input",
      CellTags->"Cell 3.3"]},
  "Cell 3.4"->{
    Cell[3643307, 112725, 523, 10, 200, "Input",
      CellTags->"Cell 3.4"]},
  "Cell 3.5"->{
    Cell[3685343, 113958, 270, 6, 99, "Input",
      CellTags->"Cell 3.5"]},
  "Cell 3.6"->{
    Cell[3685957, 113978, 454, 11, 124, "Input",
      CellTags->"Cell 3.6"]},
  "(3.1.26)"->{
    Cell[4072938, 136347, 161, 6, 29, "NumberedEquation",
      CellTags->"(3.1.26)"]},
  "i:15"->{
    Cell[4073102, 136355, 356, 13, 27, "Text",
      CellTags->"i:15"]},
  "c:11"->{
    Cell[4074331, 136398, 92, 1, 31, "Section",
      CellTags->"c:11"]},
  "i:10"->{
    Cell[4075193, 136429, 1087, 31, 95, "Text",
      CellTags->"i:10"]},
  "i:11"->{
    Cell[4076283, 136462, 1175, 30, 129, "Text",
      CellTags->"i:11"]},
  "(3.1.27)"->{
    Cell[4078599, 136525, 296, 5, 42, "NumberedEquation",
      CellTags->"(3.1.27)"]},
  "(3.1.28)"->{
    Cell[4079321, 136547, 341, 9, 45, "NumberedEquation",
      CellTags->{"(3.1.28)", "i:17"}]},
  "i:17"->{
    Cell[4079321, 136547, 341, 9, 45, "NumberedEquation",
      CellTags->{"(3.1.28)", "i:17"}]},
  "(3.1.29)"->{
    Cell[4080930, 136599, 585, 17, 70, "NumberedEquation",
      CellTags->"(3.1.29)"]},
  "(3.1.30)"->{
    Cell[4081618, 136623, 560, 13, 70, "NumberedEquation",
      CellTags->"(3.1.30)"]},
  "(3.1.31)"->{
    Cell[4082404, 136648, 690, 13, 70, "NumberedEquation",
      CellTags->"(3.1.31)"]},
  "(3.1.32)"->{
    Cell[4083825, 136687, 258, 5, 70, "NumberedEquation",
      CellTags->{"(3.1.32)", "i:5"}]},
  "i:5"->{
    Cell[4083825, 136687, 258, 5, 70, "NumberedEquation",
      CellTags->{"(3.1.32)", "i:5"}]},
  "i:19"->{
    Cell[4084086, 136694, 1314, 35, 70, "Text",
      CellTags->"i:19"]},
  "(3.1.33)"->{
    Cell[4086108, 136756, 418, 13, 70, "NumberedEquation",
      CellTags->"(3.1.33)"]},
  "(3.1.34)"->{
    Cell[4087515, 136810, 792, 21, 70, "NumberedEquation",
      CellTags->"(3.1.34)"]},
  "(3.1.35)"->{
    Cell[4088310, 136833, 555, 18, 70, "NumberedEquation",
      CellTags->"(3.1.35)"]},
  "(3.1.36)"->{
    Cell[4089210, 136868, 751, 24, 70, "NumberedEquation",
      CellTags->"(3.1.36)"]},
  "i:16"->{
    Cell[4090494, 136912, 724, 17, 70, "Text",
      CellTags->"i:16"]},
  "c:12"->{
    Cell[4091267, 136935, 46, 1, 31, "Section",
      CellTags->"c:12"]},
  "i:103"->{
    Cell[4092652, 136985, 701, 16, 70, "Text",
      CellTags->"i:103"]},
  "i:108"->{
    Cell[4093634, 137013, 91, 1, 29, "Subsubtitle",
      CellTags->{"i:108", "c:13"}]},
  "c:13"->{
    Cell[4093634, 137013, 91, 1, 29, "Subsubtitle",
      CellTags->{"i:108", "c:13"}]},
  "i:20"->{
    Cell[4093750, 137018, 58, 1, 42, "Section",
      CellTags->{"i:20", "c:14"}]},
  "c:14"->{
    Cell[4093750, 137018, 58, 1, 42, "Section",
      CellTags->{"i:20", "c:14"}]},
  "i:101"->{
    Cell[4093811, 137021, 2086, 64, 70, "Text",
      CellTags->"i:101"]},
  "(3.1.37)"->{
    Cell[4096653, 137111, 204, 6, 70, "NumberedEquation",
      CellTags->{"(3.1.37)", "i:113"}]},
  "i:113"->{
    Cell[4096653, 137111, 204, 6, 70, "NumberedEquation",
      CellTags->{"(3.1.37)", "i:113"}]},
  "i:21"->{
    Cell[4096860, 137119, 2319, 70, 70, "Text",
      CellTags->"i:21"]},
  "Fig. 3.4"->{
    Cell[4150329, 137831, 470, 18, 70, "Caption",
      CellTags->"Fig. 3.4"]},
  "c:15"->{
    Cell[4150836, 137854, 58, 1, 31, "Section",
      CellTags->"c:15"]},
  "Fig. 3.5"->{
    Cell[7503346, 183973, 461, 16, 70, "Caption",
      CellTags->"Fig. 3.5"]},
  "i:22"->{
    Cell[7503810, 183991, 3637, 106, 70, "Text",
      CellTags->"i:22"]},
  "i:102"->{
    Cell[7508707, 184133, 1434, 36, 70, "Text",
      CellTags->"i:102"]},
  "(3.1.38)"->{
    Cell[7510144, 184171, 228, 6, 70, "NumberedEquation",
      CellTags->{"(3.1.38)", "i:23"}]},
  "i:23"->{
    Cell[7510144, 184171, 228, 6, 70, "NumberedEquation",
      CellTags->{"(3.1.38)", "i:23"}]},
  "c:16"->{
    Cell[7510409, 184182, 137, 4, 31, "Section",
      CellTags->"c:16"]},
  "(3.1.39)"->{
    Cell[7510845, 184200, 249, 7, 38, "NumberedEquation",
      CellTags->"(3.1.39)"]},
  "(3.1.40)"->{
    Cell[7511413, 184217, 178, 6, 29, "NumberedEquation",
      CellTags->"(3.1.40)"]},
  "i:24"->{
    Cell[7511594, 184225, 1619, 42, 137, "Text",
      CellTags->"i:24"]},
  "(3.1.41)"->{
    Cell[7513611, 184287, 289, 8, 38, "NumberedEquation",
      CellTags->{"(3.1.41)", "i:25"}]},
  "i:25"->{
    Cell[7513611, 184287, 289, 8, 38, "NumberedEquation",
      CellTags->{"(3.1.41)", "i:25"}]},
  "(3.1.42)"->{
    Cell[7514518, 184319, 204, 6, 42, "NumberedEquation",
      CellTags->"(3.1.42)"]},
  "i:26"->{
    Cell[7514725, 184327, 219, 9, 27, "Text",
      CellTags->"i:26"]},
  "(3.1.43)"->{
    Cell[7514947, 184338, 135, 5, 29, "NumberedEquation",
      CellTags->"(3.1.43)"]},
  "i:114"->{
    Cell[7515085, 184345, 1229, 41, 48, "Text",
      CellTags->"i:114"]},
  "(3.1.44)"->{
    Cell[7516514, 184394, 148, 3, 27, "NumberedEquation",
      CellTags->"(3.1.44)"]},
  "(3.1.45)"->{
    Cell[7517213, 184414, 234, 6, 47, "NumberedEquation",
      CellTags->"(3.1.45)"]},
  "i:27"->{
    Cell[7517450, 184422, 157, 4, 27, "Text",
      CellTags->"i:27"]},
  "(3.1.46)"->{
    Cell[7518167, 184442, 384, 7, 74, "NumberedEquation",
      CellTags->"(3.1.46)"]},
  "i:28"->{
    Cell[7518554, 184451, 473, 12, 61, "Text",
      CellTags->"i:28"]},
  "i:29"->{
    Cell[7519030, 184465, 358, 8, 61, "Text",
      CellTags->"i:29"]},
  "(3.1.47)"->{
    Cell[7519391, 184475, 357, 9, 69, "NumberedEquation",
      CellTags->"(3.1.47)"]},
  "Table 3.1"->{
    Cell[7521481, 184543, 1605, 41, 166, "2ColumnBox",
      CellTags->"Table 3.1"]},
  "c:17"->{
    Cell[7523380, 184602, 118, 4, 29, "Subsubtitle",
      CellTags->"c:17"]},
  "c:18"->{
    Cell[7523523, 184610, 51, 1, 42, "Section",
      CellTags->"c:18"]},
  "c:19"->{
    Cell[7525156, 184658, 85, 1, 31, "Section",
      CellTags->"c:19"]},
  "(3.1.48)"->{
    Cell[7525773, 184679, 231, 6, 70, "NumberedEquation",
      CellTags->"(3.1.48)"]},
  "(3.1.49)"->{
    Cell[7526113, 184692, 544, 13, 70, "NumberedEquation",
      CellTags->"(3.1.49)"]},
  "i:30"->{
    Cell[7526660, 184707, 502, 16, 70, "Text",
      CellTags->"i:30"]},
  "i:31"->{
    Cell[7528331, 184763, 146, 4, 29, "Subsubsection",
      CellTags->"i:31"]},
  "(3.1.50)"->{
    Cell[7528777, 184778, 552, 15, 70, "NumberedEquation",
      CellTags->"(3.1.50)"]},
  "(3.1.51)"->{
    Cell[7530586, 184835, 281, 8, 34, "NumberedEquation",
      CellTags->"(3.1.51)"]},
  "(3.1.52)"->{
    Cell[7535587, 184985, 419, 13, 30, "NumberedEquation",
      CellTags->"(3.1.52)"]},
  "(3.1.53)"->{
    Cell[7536590, 185021, 771, 20, 38, "NumberedEquation",
      CellTags->"(3.1.53)"]},
  "(3.1.54)"->{
    Cell[7537507, 185050, 383, 13, 30, "NumberedEquation",
      CellTags->"(3.1.54)"]},
  "(3.1.55)"->{
    Cell[7541198, 185167, 610, 17, 42, "NumberedEquation",
      CellTags->"(3.1.55)"]},
  "i:43"->{
    Cell[7541811, 185186, 622, 20, 44, "Text",
      CellTags->"i:43"]},
  "(3.1.56)"->{
    Cell[7542436, 185208, 259, 7, 46, "NumberedEquation",
      CellTags->"(3.1.56)"]},
  "(3.1.57)"->{
    Cell[7543143, 185233, 187, 6, 42, "NumberedEquation",
      CellTags->"(3.1.57)"]},
  "(3.1.58)"->{
    Cell[7543333, 185241, 211, 7, 46, "NumberedEquation",
      CellTags->"(3.1.58)"]},
  "i:32"->{
    Cell[7543581, 185253, 67, 1, 29, "Subsubsection",
      CellTags->"i:32"]},
  "(3.1.59)"->{
    Cell[7544355, 185276, 149, 3, 27, "NumberedEquation",
      CellTags->"(3.1.59)"]},
  "(3.1.60)"->{
    Cell[7544529, 185283, 254, 9, 32, "NumberedEquation",
      CellTags->"(3.1.60)"]},
  "(3.1.61)"->{
    Cell[7545338, 185316, 463, 13, 38, "NumberedEquation",
      CellTags->{"(3.1.61)", "i:33"}]},
  "i:33"->{
    Cell[7545338, 185316, 463, 13, 38, "NumberedEquation",
      CellTags->{"(3.1.61)", "i:33"}]},
  "i:34"->{
    Cell[7546644, 185361, 167, 6, 27, "Text",
      CellTags->"i:34"]},
  "(3.1.62)"->{
    Cell[7546814, 185369, 245, 4, 38, "NumberedEquation",
      CellTags->"(3.1.62)"]},
  "i:35"->{
    Cell[7547062, 185375, 1496, 45, 113, "Text",
      CellTags->"i:35"]},
  "Cell 3.7"->{
    Cell[7548583, 185424, 595, 12, 162, "Input",
      CellTags->"Cell 3.7"]},
  "(3.1.63)"->{
    Cell[8298400, 223506, 197, 4, 29, "NumberedEquation",
      CellTags->"(3.1.63)"]},
  "Cell 3.8"->{
    Cell[8298898, 223526, 267, 7, 88, "Input",
      CellTags->"Cell 3.8"]},
  "Cell 3.9"->{
    Cell[8317769, 224081, 1482, 30, 317, "Input",
      CellTags->"Cell 3.9"]},
  "i:115"->{
    Cell[8814851, 236847, 439, 10, 62, "Text",
      CellTags->"i:115"]},
  "i:36"->{
    Cell[8815293, 236859, 556, 13, 68, "Text",
      CellTags->"i:36"]},
  "(3.1.64)"->{
    Cell[8815852, 236874, 299, 8, 37, "NumberedEquation",
      CellTags->"(3.1.64)"]},
  "c:20"->{
    Cell[8817126, 236913, 82, 1, 31, "Section",
      CellTags->"c:20"]},
  "(3.1.65)"->{
    Cell[8817747, 236932, 187, 6, 42, "NumberedEquation",
      CellTags->"(3.1.65)"]},
  "(3.1.66)"->{
    Cell[8818004, 236942, 222, 4, 38, "NumberedEquation",
      CellTags->"(3.1.66)"]},
  "(3.1.67)"->{
    Cell[8818270, 236950, 148, 3, 27, "NumberedEquation",
      CellTags->"(3.1.67)"]},
  "(3.1.68)"->{
    Cell[8819679, 236997, 187, 6, 42, "NumberedEquation",
      CellTags->"(3.1.68)"]},
  "(3.1.69)"->{
    Cell[8819869, 237005, 211, 7, 46, "NumberedEquation",
      CellTags->"(3.1.69)"]},
  "i:37"->{
    Cell[8820117, 237017, 67, 1, 29, "Subsubsection",
      CellTags->"i:37"]},
  "i:39"->{
    Cell[8820994, 237045, 1138, 35, 83, "Text",
      CellTags->"i:39"]},
  "(3.1.70)"->{
    Cell[8822135, 237082, 149, 3, 27, "NumberedEquation",
      CellTags->"(3.1.70)"]},
  "(3.1.71)"->{
    Cell[8822309, 237089, 250, 8, 32, "NumberedEquation",
      CellTags->"(3.1.71)"]},
  "(3.1.72)"->{
    Cell[8822655, 237104, 256, 7, 38, "NumberedEquation",
      CellTags->{"(3.1.72)", "i:116"}]},
  "i:116"->{
    Cell[8822655, 237104, 256, 7, 38, "NumberedEquation",
      CellTags->{"(3.1.72)", "i:116"}]},
  "(3.1.73)"->{
    Cell[8824025, 237159, 433, 13, 81, "NumberedEquation",
      CellTags->"(3.1.73)"]},
  "Cell 3.10"->{
    Cell[8826206, 237225, 339, 7, 160, "Input",
      CellTags->"Cell 3.10"]},
  "Cell 3.11"->{
    Cell[8826742, 237246, 84, 3, 67, "Input",
      CellTags->"Cell 3.11"]},
  "Cell 3.12"->{
    Cell[8826905, 237257, 117, 3, 67, "Input",
      CellTags->"Cell 3.12"]},
  "Cell 3.13"->{
    Cell[8827615, 237284, 916, 20, 227, "Input",
      CellTags->"Cell 3.13"]},
  "c:21"->{
    Cell[8989090, 247146, 76, 1, 31, "Section",
      CellTags->"c:21"]},
  "i:40"->{
    Cell[8989566, 247163, 1360, 46, 85, "Text",
      CellTags->"i:40"]},
  "(3.1.74)"->{
    Cell[8991477, 247231, 277, 5, 46, "NumberedEquation",
      CellTags->"(3.1.74)"]},
  "(3.1.75)"->{
    Cell[8991937, 247246, 293, 9, 33, "NumberedEquation",
      CellTags->"(3.1.75)"]},
  "Cell 3.14"->{
    Cell[8993602, 247304, 193, 4, 67, "Input",
      CellTags->"Cell 3.14"]},
  "Cell 3.15"->{
    Cell[9030488, 248100, 291, 7, 105, "Input",
      CellTags->"Cell 3.15"]},
  "i:38"->{
    Cell[9031026, 248116, 641, 23, 47, "Text",
      CellTags->"i:38"]},
  "Cell 3.16"->{
    Cell[9031692, 248143, 930, 19, 306, "Input",
      CellTags->"Cell 3.16"]},
  "i:42"->{
    Cell[9675662, 284811, 273, 8, 38, "NumberedEquation",
      CellTags->{"i:42", "(3.1.76)"}]},
  "(3.1.76)"->{
    Cell[9675662, 284811, 273, 8, 38, "NumberedEquation",
      CellTags->{"i:42", "(3.1.76)"}]},
  "i:41"->{
    Cell[9676840, 284854, 281, 10, 32, "Text",
      CellTags->"i:41"]},
  "Cell 3.17"->{
    Cell[9677196, 284870, 187, 5, 86, "Input",
      CellTags->"Cell 3.17"]},
  "(3.1.77)"->{
    Cell[9680128, 284967, 310, 8, 34, "NumberedEquation",
      CellTags->"(3.1.77)"]},
  "c:22"->{
    Cell[9681068, 285004, 46, 1, 31, "Section",
      CellTags->"c:22"]},
  "c:23"->{
    Cell[9683135, 285060, 65, 1, 29, "Subsubtitle",
      CellTags->"c:23"]},
  "i:47"->{
    Cell[9683203, 285063, 768, 27, 61, "Text",
      CellTags->"i:47"]},
  "i:46"->{
    Cell[9683974, 285092, 1242, 38, 82, "Text",
      CellTags->"i:46"]},
  "i:45"->{
    Cell[9685219, 285132, 1546, 35, 163, "Text",
      CellTags->"i:45"]},
  "Fig. 3.6"->{
    Cell[10827329, 300489, 139, 4, 16, "Caption",
      CellTags->"Fig. 3.6"]},
  "i:48"->{
    Cell[10834703, 300708, 1350, 40, 95, "Text",
      CellTags->"i:48"]},
  "Fig. 3.7"->{
    Cell[10923412, 301834, 120, 4, 16, "Caption",
      CellTags->"Fig. 3.7"]},
  "(3.1.78)"->{
    Cell[10925907, 301918, 196, 6, 42, "NumberedEquation",
      CellTags->"(3.1.78)"]},
  "i:50"->{
    Cell[10926106, 301926, 140, 6, 27, "Text",
      CellTags->"i:50"]},
  "(3.1.79)"->{
    Cell[10926249, 301934, 115, 2, 31, "NumberedEquation",
      CellTags->"(3.1.79)"]},
  "i:97"->{
    Cell[10926367, 301938, 407, 10, 61, "Text",
      CellTags->"i:97"]},
  "i:98"->{
    Cell[10926777, 301950, 799, 28, 61, "Text",
      CellTags->"i:98"]},
  "i:51"->{
    Cell[10932042, 302146, 1142, 36, 78, "Text",
      CellTags->"i:51"]},
  "(3.1.80)"->{
    Cell[10933187, 302184, 1043, 32, 43, "NumberedEquation",
      CellTags->"(3.1.80)"]},
  "i:52"->{
    Cell[10935004, 302247, 1048, 36, 61, "Text",
      CellTags->"i:52"]},
  "i:96"->{
    Cell[10936055, 302285, 583, 18, 44, "Text",
      CellTags->"i:96"]},
  "i:53"->{
    Cell[10943714, 302527, 494, 17, 44, "Text",
      CellTags->"i:53"]},
  "(3.1.81)"->{
    Cell[10944211, 302546, 226, 7, 38, "NumberedEquation",
      CellTags->"(3.1.81)"]},
  "i:111"->{
    Cell[10944440, 302555, 260, 9, 31, "Text",
      CellTags->"i:111"]},
  "(3.1.82)"->{
    Cell[10944703, 302566, 195, 6, 42, "NumberedEquation",
      CellTags->"(3.1.82)"]},
  "i:55"->{
    Cell[10953581, 302875, 1820, 52, 122, "Text",
      CellTags->"i:55"]},
  "i:56"->{
    Cell[10957368, 302993, 1106, 35, 65, "Text",
      CellTags->"i:56"]},
  "c:24"->{
    Cell[10959416, 303063, 91, 1, 38, "Subtitle",
      CellTags->"c:24"]},
  "i:112"->{
    Cell[10959530, 303068, 357, 10, 44, "Text",
      CellTags->"i:112"]},
  "(3.2.1)"->{
    Cell[10959890, 303080, 316, 11, 32, "NE2",
      CellTags->"(3.2.1)"]},
  "(3.2.2)"->{
    Cell[10960563, 303107, 225, 6, 45, "NE2",
      CellTags->"(3.2.2)"]},
  "i:57"->{
    Cell[10960791, 303115, 970, 32, 61, "Text",
      CellTags->"i:57"]},
  "i:58"->{
    Cell[10961764, 303149, 766, 28, 27, "Text",
      CellTags->"i:58"]},
  "i:59"->{
    Cell[10962533, 303179, 1418, 47, 48, "Text",
      CellTags->"i:59"]},
  "i:60"->{
    Cell[10963954, 303228, 2013, 68, 46, "Text",
      CellTags->"i:60"]},
  "Fig. 3.8"->{
    Cell[11147130, 305548, 258, 9, 16, "Caption",
      CellTags->"Fig. 3.8"]},
  "c:26"->{
    Cell[11147413, 305561, 89, 1, 40, "Subsubtitle",
      CellTags->"c:26"]},
  "i:61"->{
    Cell[11147652, 305569, 317, 6, 61, "Text",
      CellTags->"i:61"]},
  "i:62"->{
    Cell[11154863, 305783, 629, 16, 61, "Text",
      CellTags->"i:62"]},
  "(3.2.3)"->{
    Cell[11155495, 305801, 519, 16, 34, "NE2",
      CellTags->"(3.2.3)"]},
  "i:63"->{
    Cell[11156818, 305842, 595, 16, 61, "Text",
      CellTags->"i:63"]},
  "c:27"->{
    Cell[11158469, 305895, 69, 1, 29, "Subsubtitle",
      CellTags->"c:27"]},
  "i:64"->{
    Cell[11158563, 305900, 65, 1, 42, "Section",
      CellTags->{"i:64", "c:28"}]},
  "c:28"->{
    Cell[11158563, 305900, 65, 1, 42, "Section",
      CellTags->{"i:64", "c:28"}]},
  "i:76"->{
    Cell[11158631, 305903, 346, 10, 44, "Text",
      CellTags->"i:76"]},
  "(3.2.4)"->{
    Cell[11158980, 305915, 119, 2, 27, "NE2",
      CellTags->"(3.2.4)"]},
  "(3.2.5)"->{
    Cell[11159917, 305952, 291, 6, 83, "NE2",
      CellTags->"(3.2.5)"]},
  "(3.2.6)"->{
    Cell[11160398, 305968, 405, 7, 65, "NE2",
      CellTags->"(3.2.6)"]},
  "c:29"->{
    Cell[11160840, 305980, 79, 1, 31, "Section",
      CellTags->"c:29"]},
  "Fig. 3.9"->{
    Cell[11230350, 306855, 51, 1, 16, "Caption",
      CellTags->"Fig. 3.9"]},
  "i:104"->{
    Cell[11230820, 306875, 1120, 36, 86, "Text",
      CellTags->"i:104"]},
  "(3.2.7)"->{
    Cell[11231943, 306913, 143, 6, 29, "NE2",
      CellTags->"(3.2.7)"]},
  "(3.2.8)"->{
    Cell[11232114, 306923, 225, 8, 32, "NE2",
      CellTags->"(3.2.8)"]},
  "(3.2.9)"->{
    Cell[11232488, 306938, 303, 8, 38, "NE2",
      CellTags->"(3.2.9)"]},
  "(3.2.10)"->{
    Cell[11234963, 307022, 206, 4, 28, "NE2",
      CellTags->"(3.2.10)"]},
  "(3.2.11)"->{
    Cell[11235623, 307045, 243, 7, 30, "NE2",
      CellTags->"(3.2.11)"]},
  "(3.2.12)"->{
    Cell[11236436, 307075, 257, 4, 38, "NE2",
      CellTags->"(3.2.12)"]},
  "Cell 3.18"->{
    Cell[11237917, 307128, 495, 11, 177, "Input",
      CellTags->"Cell 3.18"]},
  "c:30"->{
    Cell[11472568, 311418, 133, 4, 31, "Section",
      CellTags->"c:30"]},
  "i:77"->{
    Cell[11473780, 311455, 1748, 59, 70, "Text",
      CellTags->"i:77"]},
  "Fig. 3.10"->{
    Cell[11596709, 313017, 79, 1, 70, "Caption",
      CellTags->"Fig. 3.10"]},
  "(3.2.13)"->{
    Cell[11597563, 313045, 211, 4, 70, "NE2",
      CellTags->"(3.2.13)"]},
  "(3.2.14)"->{
    Cell[11601177, 313166, 294, 10, 70, "NE2",
      CellTags->"(3.2.14)"]},
  "c:31"->{
    Cell[11603062, 313229, 72, 1, 29, "Subsubtitle",
      CellTags->"c:31"]},
  "i:65"->{
    Cell[11603159, 313234, 72, 1, 42, "Section",
      CellTags->{"i:65", "c:32"}]},
  "c:32"->{
    Cell[11603159, 313234, 72, 1, 42, "Section",
      CellTags->{"i:65", "c:32"}]},
  "i:75"->{
    Cell[11603234, 313237, 970, 28, 78, "Text",
      CellTags->"i:75"]},
  "(3.2.15)"->{
    Cell[11604207, 313267, 179, 6, 29, "NE2",
      CellTags->"(3.2.15)"]},
  "i:109"->{
    Cell[11604526, 313282, 305, 7, 43, "NE2",
      CellTags->{"i:109", "(3.2.16)"}]},
  "(3.2.16)"->{
    Cell[11604526, 313282, 305, 7, 43, "NE2",
      CellTags->{"i:109", "(3.2.16)"}]},
  "(3.2.17)"->{
    Cell[11605154, 313305, 311, 5, 44, "NE2",
      CellTags->"(3.2.17)"]},
  "(3.2.18)"->{
    Cell[11606184, 313337, 243, 7, 41, "NE2",
      CellTags->"(3.2.18)"]},
  "(3.2.19)"->{
    Cell[11606941, 313363, 205, 7, 42, "NE2",
      CellTags->"(3.2.19)"]},
  "i:105"->{
    Cell[11607149, 313372, 1077, 30, 78, "Text",
      CellTags->"i:105"]},
  "(3.2.20)"->{
    Cell[11608229, 313404, 290, 8, 32, "NE2",
      CellTags->"(3.2.20)"]},
  "(3.2.21)"->{
    Cell[11609223, 313436, 257, 8, 32, "NE2",
      CellTags->"(3.2.21)"]},
  "(3.2.22)"->{
    Cell[11610039, 313469, 226, 6, 42, "NE2",
      CellTags->"(3.2.22)"]},
  "(3.2.23)"->{
    Cell[11610336, 313479, 853, 25, 70, "NE2",
      CellTags->"(3.2.23)"]},
  "(3.2.24)"->{
    Cell[11611334, 313511, 446, 11, 57, "NE2",
      CellTags->"(3.2.24)"]},
  "c:33"->{
    Cell[11611817, 313527, 46, 1, 31, "Section",
      CellTags->"c:33"]},
  "(3.2.25)"->{
    Cell[11612241, 313542, 150, 3, 27, "NE2",
      CellTags->"(3.2.25)"]},
  "(3.2.26)"->{
    Cell[11613963, 313603, 308, 8, 38, "NE2",
      CellTags->"(3.2.26)"]},
  "c:34"->{
    Cell[11615741, 313662, 67, 1, 29, "Subsubtitle",
      CellTags->"c:34"]},
  "i:67"->{
    Cell[11615833, 313667, 72, 1, 42, "Section",
      CellTags->{"i:67", "c:35"}]},
  "c:35"->{
    Cell[11615833, 313667, 72, 1, 42, "Section",
      CellTags->{"i:67", "c:35"}]},
  "i:78"->{
    Cell[11615908, 313670, 667, 20, 61, "Text",
      CellTags->"i:78"]},
  "i:110"->{
    Cell[11616578, 313692, 492, 11, 45, "NE2",
      CellTags->{"i:110", "(3.2.27)"}]},
  "(3.2.27)"->{
    Cell[11616578, 313692, 492, 11, 45, "NE2",
      CellTags->{"i:110", "(3.2.27)"}]},
  "(3.2.28)"->{
    Cell[11617828, 313735, 508, 11, 45, "NE2",
      CellTags->"(3.2.28)"]},
  "Fig. 3.11"->{
    Cell[11662024, 314293, 171, 6, 16, "Caption",
      CellTags->"Fig. 3.11"]},
  "(3.2.29)"->{
    Cell[11662632, 314319, 191, 3, 45, "NE2",
      CellTags->"(3.2.29)"]},
  "(3.2.30)"->{
    Cell[11662826, 314324, 365, 8, 42, "NE2",
      CellTags->"(3.2.30)"]},
  "(3.2.31)"->{
    Cell[11663194, 314334, 231, 7, 38, "NE2",
      CellTags->"(3.2.31)"]},
  "(3.2.32)"->{
    Cell[11663946, 314361, 256, 9, 32, "NE2",
      CellTags->"(3.2.32)"]},
  "c:36"->{
    Cell[11664239, 314375, 161, 6, 31, "Section",
      CellTags->"c:36"]},
  "(3.2.33)"->{
    Cell[11665517, 314418, 295, 5, 42, "NE2",
      CellTags->"(3.2.33)"]},
  "i:69"->{
    Cell[11665815, 314425, 681, 17, 78, "Text",
      CellTags->"i:69"]},
  "(3.2.34)"->{
    Cell[11666499, 314444, 335, 12, 29, "NE2",
      CellTags->"(3.2.34)"]},
  "i:70"->{
    Cell[11666837, 314458, 212, 6, 44, "Text",
      CellTags->"i:70"]},
  "Table 3.2"->{
    Cell[11668045, 314501, 4281, 135, 183, "Text",
      CellTags->"Table 3.2"]},
  "i:83"->{
    Cell[11672622, 314650, 747, 27, 62, "Text",
      CellTags->"i:83"]},
  "Cell 3.19"->{
    Cell[11673394, 314681, 420, 10, 143, "Input",
      CellTags->"Cell 3.19"]},
  "Cell 3.20"->{
    Cell[11674458, 314714, 251, 7, 105, "Input",
      CellTags->"Cell 3.20"]},
  "(3.2.35)"->{
    Cell[11675481, 314758, 464, 10, 40, "NE2",
      CellTags->"(3.2.35)"]},
  "(3.2.36)"->{
    Cell[11676736, 314794, 347, 10, 40, "NE2",
      CellTags->"(3.2.36)"]},
  "i:72"->{
    Cell[11677379, 314813, 392, 9, 40, "NE2",
      CellTags->{"i:72", "(3.2.37)"}]},
  "(3.2.37)"->{
    Cell[11677379, 314813, 392, 9, 40, "NE2",
      CellTags->{"i:72", "(3.2.37)"}]},
  "(3.2.38)"->{
    Cell[11678598, 314848, 521, 12, 40, "NE2",
      CellTags->"(3.2.38)"]},
  "i:71"->{
    Cell[11679969, 314895, 110, 2, 31, "Section",
      CellTags->{"i:71", "c:37"}]},
  "c:37"->{
    Cell[11679969, 314895, 110, 2, 31, "Section",
      CellTags->{"i:71", "c:37"}]},
  "(3.2.39)"->{
    Cell[11680587, 314914, 342, 9, 57, "NE2",
      CellTags->"(3.2.39)"]},
  "i:84"->{
    Cell[11680932, 314925, 710, 23, 61, "Text",
      CellTags->"i:84"]},
  "i:73"->{
    Cell[11681645, 314950, 541, 15, 36, "NE2",
      CellTags->{"i:73", "(3.2.40)"}]},
  "(3.2.40)"->{
    Cell[11681645, 314950, 541, 15, 36, "NE2",
      CellTags->{"i:73", "(3.2.40)"}]},
  "Cell 3.21"->{
    Cell[11683458, 315003, 1460, 28, 333, "Input",
      CellTags->"Cell 3.21"]},
  "Fig. 3.12"->{
    Cell[12106531, 327358, 148, 6, 16, "Caption",
      CellTags->"Fig. 3.12"]},
  "c:38"->{
    Cell[12107731, 327401, 46, 1, 31, "Section",
      CellTags->"c:38"]},
  "(3.2.41)"->{
    Cell[12108828, 327443, 365, 8, 40, "NE2",
      CellTags->"(3.2.41)"]},
  "(3.2.42)"->{
    Cell[12109806, 327471, 325, 5, 34, "NE2",
      CellTags->"(3.2.42)"]},
  "Cell 3.22"->{
    Cell[12111167, 327512, 273, 8, 105, "Input",
      CellTags->"Cell 3.22"]},
  "Cell 3.23"->{
    Cell[12112339, 327549, 255, 6, 86, "Input",
      CellTags->"Cell 3.23"]},
  "Cell 3.24"->{
    Cell[12112937, 327573, 515, 11, 162, "Input",
      CellTags->"Cell 3.24"]},
  "i:79"->{
    Cell[12600160, 345445, 377, 9, 61, "Text",
      CellTags->"i:79"]},
  "c:39"->{
    Cell[12600586, 345460, 72, 1, 29, "Subsubtitle",
      CellTags->"c:39"]},
  "c:40"->{
    Cell[12600683, 345465, 51, 1, 42, "Section",
      CellTags->"c:40"]},
  "i:68"->{
    Cell[12602650, 345537, 143, 2, 31, "Section",
      CellTags->{"i:68", "c:41"}]},
  "c:41"->{
    Cell[12602650, 345537, 143, 2, 31, "Section",
      CellTags->{"i:68", "c:41"}]},
  "i:100"->{
    Cell[12602796, 345541, 1058, 31, 68, "Text",
      CellTags->"i:100"]},
  "(3.2.43)"->{
    Cell[12603857, 345574, 341, 9, 46, "NE2",
      CellTags->"(3.2.43)"]},
  "(3.2.44)"->{
    Cell[12604355, 345592, 150, 5, 43, "NE2",
      CellTags->"(3.2.44)"]},
  "(3.2.45)"->{
    Cell[12604765, 345609, 272, 8, 37, "NE2",
      CellTags->"(3.2.45)"]},
  "i:80"->{
    Cell[12605682, 345644, 61, 1, 27, "Subsubsection",
      CellTags->"i:80"]},
  "(3.2.46)"->{
    Cell[12605872, 345654, 245, 7, 42, "NE2",
      CellTags->"(3.2.46)"]},
  "i:106"->{
    Cell[12606120, 345663, 930, 31, 78, "Text",
      CellTags->"i:106"]},
  "(3.2.47)"->{
    Cell[12607293, 345706, 130, 6, 33, "NE2",
      CellTags->"(3.2.47)"]},
  "(3.2.48)"->{
    Cell[12607453, 345716, 252, 7, 42, "NE2",
      CellTags->"(3.2.48)"]},
  "i:81"->{
    Cell[12607708, 345725, 642, 22, 44, "Text",
      CellTags->"i:81"]},
  "(3.2.49)"->{
    Cell[12608353, 345749, 169, 6, 29, "NE2",
      CellTags->"(3.2.49)"]},
  "i:82"->{
    Cell[12608525, 345757, 1526, 58, 63, "Text",
      CellTags->"i:82"]},
  "Cell 3.25"->{
    Cell[12610076, 345819, 344, 7, 124, "Input",
      CellTags->"Cell 3.25"]},
  "Cell 3.26"->{
    Cell[12671306, 347186, 339, 6, 105, "Input",
      CellTags->"Cell 3.26"]},
  "(3.2.50)"->{
    Cell[12723309, 348431, 143, 6, 29, "NE2",
      CellTags->"(3.2.50)"]},
  "i:85"->{
    Cell[12723489, 348442, 92, 2, 29, "Subsubsection",
      CellTags->"i:85"]},
  "Cell 3.27"->{
    Cell[12725962, 348522, 97, 3, 67, "Input",
      CellTags->"Cell 3.27"]},
  "i:86"->{
    Cell[12726062, 348527, 189, 6, 27, "Text",
      CellTags->"i:86"]},
  "Cell 3.28"->{
    Cell[12726276, 348537, 110, 3, 67, "Input",
      CellTags->"Cell 3.28"]},
  "Cell 3.29"->{
    Cell[12727366, 348574, 98, 3, 67, "Input",
      CellTags->"Cell 3.29"]},
  "i:87"->{
    Cell[12727605, 348584, 456, 16, 44, "Text",
      CellTags->"i:87"]},
  "Cell 3.30"->{
    Cell[12728086, 348604, 98, 3, 67, "Input",
      CellTags->"Cell 3.30"]},
  "(3.2.51)"->{
    Cell[12729216, 348646, 214, 8, 32, "NE2",
      CellTags->"(3.2.51)"]},
  "(3.2.52)"->{
    Cell[12729824, 348672, 171, 7, 29, "NE2",
      CellTags->"(3.2.52)"]},
  "Cell 3.31"->{
    Cell[12730254, 348694, 349, 7, 105, "Input",
      CellTags->"Cell 3.31"]},
  "(3.2.53)"->{
    Cell[12796831, 350144, 464, 12, 38, "NE2",
      CellTags->"(3.2.53)"]},
  "(3.2.54)"->{
    Cell[12799095, 350216, 586, 15, 38, "NE2",
      CellTags->"(3.2.54)"]},
  "i:90"->{
    Cell[12799994, 350242, 330, 8, 42, "NE2",
      CellTags->{"i:90", "(3.2.55)"}]},
  "(3.2.55)"->{
    Cell[12799994, 350242, 330, 8, 42, "NE2",
      CellTags->{"i:90", "(3.2.55)"}]},
  "Cell 3.32"->{
    Cell[12800861, 350272, 269, 7, 108, "Input",
      CellTags->"Cell 3.32"]},
  "Cell 3.33"->{
    Cell[12801205, 350287, 275, 7, 123, "Input",
      CellTags->"Cell 3.33"]},
  "(3.2.56)"->{
    Cell[12803343, 350355, 774, 18, 42, "NE2",
      CellTags->"(3.2.56)"]},
  "i:107"->{
    Cell[12804277, 350382, 387, 10, 44, "Text",
      CellTags->"i:107"]},
  "(3.2.57)"->{
    Cell[12805988, 350439, 368, 11, 31, "NE2",
      CellTags->"(3.2.57)"]},
  "Cell 3.34"->{
    Cell[12807136, 350480, 215, 5, 116, "Input",
      CellTags->"Cell 3.34"]},
  "Cell 3.35"->{
    Cell[12807837, 350506, 186, 5, 86, "Input",
      CellTags->"Cell 3.35"]},
  "Cell 3.36"->{
    Cell[12808246, 350522, 189, 5, 67, "Input",
      CellTags->"Cell 3.36"]},
  "Cell 3.37"->{
    Cell[12808993, 350551, 371, 8, 124, "Input",
      CellTags->"Cell 3.37"]},
  "i:91"->{
    Cell[12894837, 352852, 334, 7, 61, "Text",
      CellTags->"i:91"]},
  "c:42"->{
    Cell[12895220, 352865, 115, 4, 31, "Section",
      CellTags->"c:42"]},
  "(3.2.58)"->{
    Cell[12897450, 352944, 148, 6, 32, "NE2",
      CellTags->"(3.2.58)"]},
  "(3.2.59)"->{
    Cell[12898392, 352982, 233, 7, 29, "NE2",
      CellTags->"(3.2.59)"]},
  "i:88"->{
    Cell[12898628, 352991, 402, 15, 44, "Text",
      CellTags->"i:88"]},
  "(3.2.60)"->{
    Cell[12899033, 353008, 578, 19, 59, "NE2",
      CellTags->"(3.2.60)"]},
  "i:89"->{
    Cell[12899614, 353029, 1140, 42, 73, "Text",
      CellTags->"i:89"]},
  "Cell 3.38"->{
    Cell[12900779, 353075, 344, 7, 124, "Input",
      CellTags->"Cell 3.38"]},
  "Cell 3.39"->{
    Cell[12939055, 353946, 308, 6, 105, "Input",
      CellTags->"Cell 3.39"]},
  "(3.2.61)"->{
    Cell[12978585, 354914, 379, 10, 38, "NE2",
      CellTags->"(3.2.61)"]},
  "c:43"->{
    Cell[12980645, 354984, 65, 1, 29, "Subsubtitle",
      CellTags->"c:43"]},
  "Fig. 3.13"->{
    Cell[13032424, 355691, 67, 1, 16, "Caption",
      CellTags->"Fig. 3.13"]},
  "Fig. 3.14"->{
    Cell[13065246, 356171, 67, 1, 16, "Caption",
      CellTags->"Fig. 3.14"]},
  "Fig. 3.15"->{
    Cell[13077043, 356340, 67, 1, 16, "Caption",
      CellTags->"Fig. 3.15"]},
  "Fig. 3.16"->{
    Cell[13113341, 356884, 67, 1, 16, "Caption",
      CellTags->"Fig. 3.16"]},
  "i:93"->{
    Cell[13115725, 356964, 495, 18, 44, "Text",
      CellTags->"i:93"]},
  "i:94"->{
    Cell[13116991, 357017, 362, 14, 27, "Text",
      CellTags->"i:94"]},
  "i:92"->{
    Cell[13119137, 357094, 527, 17, 61, "Text",
      CellTags->"i:92"]},
  "Fig. 3.17"->{
    Cell[13148657, 357476, 68, 1, 16, "Caption",
      CellTags->"Fig. 3.17"]},
  "(3.2.62)"->{
    Cell[13149866, 357525, 156, 6, 32, "NE2",
      CellTags->"(3.2.62)"]},
  "c:44"->{
    Cell[13154634, 357696, 50, 1, 38, "Subtitle",
      CellTags->"c:44"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 13198572, 359017},
  {"c:3", 13198648, 359020},
  {"i:3", 13198727, 359023},
  {"c:4", 13198817, 359026},
  {"c:5", 13198907, 359029},
  {"i:4", 13198984, 359032},
  {"c:6", 13199071, 359035},
  {"Fig. 3.1", 13199163, 359038},
  {"Fig. 3.2", 13199252, 359041},
  {"(3.1.1)", 13199341, 359044},
  {"(3.1.2)", 13199439, 359047},
  {"c:7", 13199533, 359050},
  {"Fig. 3.3", 13199618, 359053},
  {"(3.1.3)", 13199709, 359056},
  {"(3.1.4)", 13199808, 359059},
  {"(3.1.5)", 13199907, 359062},
  {"(3.1.6)", 13200006, 359065},
  {"(3.1.7)", 13200105, 359068},
  {"i:1", 13200209, 359071},
  {"(3.1.8)", 13200317, 359074},
  {"(3.1.9)", 13200416, 359077},
  {"(3.1.10)", 13200516, 359080},
  {"i:2", 13200621, 359083},
  {"(3.1.11)", 13200731, 359086},
  {"i:49", 13200838, 359089},
  {"(3.1.12)", 13200949, 359092},
  {"i:95", 13201047, 359095},
  {"c:8", 13201130, 359098},
  {"c:9", 13201216, 359101},
  {"i:6", 13201298, 359104},
  {"(3.1.13)", 13201383, 359107},
  {"(3.1.14)", 13201484, 359110},
  {"(3.1.15)", 13201585, 359113},
  {"(3.1.16)", 13201686, 359116},
  {"i:8", 13201782, 359119},
  {"i:7", 13201862, 359122},
  {"i:9", 13201949, 359125},
  {"(3.1.17)", 13202035, 359128},
  {"(3.1.18)", 13202136, 359131},
  {"(3.1.19)", 13202237, 359134},
  {"i:14", 13202334, 359137},
  {"(3.1.20)", 13202420, 359140},
  {"i:18", 13202517, 359143},
  {"i:99", 13202598, 359146},
  {"i:12", 13202687, 359149},
  {"Cell 3.1", 13202773, 359152},
  {"i:13", 13202861, 359155},
  {"(3.1.21)", 13202949, 359158},
  {"(3.1.22)", 13203052, 359161},
  {"(3.1.23)", 13203155, 359164},
  {"(3.1.24)", 13203258, 359167},
  {"c:10", 13203357, 359170},
  {"Cell 3.2", 13203446, 359173},
  {"(3.1.25)", 13203539, 359176},
  {"Cell 3.3", 13203642, 359179},
  {"Cell 3.4", 13203736, 359182},
  {"Cell 3.5", 13203831, 359185},
  {"Cell 3.6", 13203924, 359188},
  {"(3.1.26)", 13204019, 359191},
  {"i:15", 13204119, 359194},
  {"c:11", 13204204, 359197},
  {"i:10", 13204290, 359200},
  {"i:11", 13204376, 359203},
  {"(3.1.27)", 13204467, 359206},
  {"(3.1.28)", 13204571, 359209},
  {"i:17", 13204681, 359212},
  {"(3.1.29)", 13204795, 359215},
  {"(3.1.30)", 13204900, 359218},
  {"(3.1.31)", 13205005, 359221},
  {"(3.1.32)", 13205110, 359224},
  {"i:5", 13205218, 359227},
  {"i:19", 13205327, 359230},
  {"(3.1.33)", 13205417, 359233},
  {"(3.1.34)", 13205522, 359236},
  {"(3.1.35)", 13205627, 359239},
  {"(3.1.36)", 13205732, 359242},
  {"i:16", 13205833, 359245},
  {"c:12", 13205918, 359248},
  {"i:103", 13206005, 359251},
  {"i:108", 13206092, 359254},
  {"c:13", 13206193, 359257},
  {"i:20", 13206294, 359260},
  {"c:14", 13206390, 359263},
  {"i:101", 13206487, 359266},
  {"(3.1.37)", 13206578, 359269},
  {"i:113", 13206690, 359272},
  {"i:21", 13206801, 359275},
  {"Fig. 3.4", 13206891, 359278},
  {"c:15", 13206983, 359281},
  {"Fig. 3.5", 13207073, 359284},
  {"i:22", 13207165, 359287},
  {"i:102", 13207253, 359290},
  {"(3.1.38)", 13207344, 359293},
  {"i:23", 13207454, 359296},
  {"c:16", 13207564, 359299},
  {"(3.1.39)", 13207655, 359302},
  {"(3.1.40)", 13207759, 359305},
  {"i:24", 13207859, 359308},
  {"(3.1.41)", 13207950, 359311},
  {"i:25", 13208060, 359314},
  {"(3.1.42)", 13208174, 359317},
  {"i:26", 13208274, 359320},
  {"(3.1.43)", 13208362, 359323},
  {"i:114", 13208463, 359326},
  {"(3.1.44)", 13208554, 359329},
  {"(3.1.45)", 13208658, 359332},
  {"i:27", 13208758, 359335},
  {"(3.1.46)", 13208846, 359338},
  {"i:28", 13208946, 359341},
  {"i:29", 13209031, 359344},
  {"(3.1.47)", 13209119, 359347},
  {"Table 3.1", 13209224, 359350},
  {"c:17", 13209322, 359353},
  {"c:18", 13209413, 359356},
  {"c:19", 13209499, 359359},
  {"(3.1.48)", 13209589, 359362},
  {"(3.1.49)", 13209693, 359365},
  {"i:30", 13209794, 359368},
  {"i:31", 13209879, 359371},
  {"(3.1.50)", 13209976, 359374},
  {"(3.1.51)", 13210081, 359377},
  {"(3.1.52)", 13210185, 359380},
  {"(3.1.53)", 13210290, 359383},
  {"(3.1.54)", 13210395, 359386},
  {"(3.1.55)", 13210500, 359389},
  {"i:43", 13210601, 359392},
  {"(3.1.56)", 13210690, 359395},
  {"(3.1.57)", 13210794, 359398},
  {"(3.1.58)", 13210898, 359401},
  {"i:32", 13210998, 359404},
  {"(3.1.59)", 13211094, 359407},
  {"(3.1.60)", 13211198, 359410},
  {"(3.1.61)", 13211302, 359413},
  {"i:33", 13211413, 359416},
  {"i:34", 13211524, 359419},
  {"(3.1.62)", 13211612, 359422},
  {"i:35", 13211712, 359425},
  {"Cell 3.7", 13211803, 359428},
  {"(3.1.63)", 13211898, 359431},
  {"Cell 3.8", 13212002, 359434},
  {"Cell 3.9", 13212095, 359437},
  {"i:115", 13212188, 359440},
  {"i:36", 13212274, 359443},
  {"(3.1.64)", 13212363, 359446},
  {"c:20", 13212463, 359449},
  {"(3.1.65)", 13212553, 359452},
  {"(3.1.66)", 13212657, 359455},
  {"(3.1.67)", 13212761, 359458},
  {"(3.1.68)", 13212865, 359461},
  {"(3.1.69)", 13212969, 359464},
  {"i:37", 13213069, 359467},
  {"i:39", 13213161, 359470},
  {"(3.1.70)", 13213251, 359473},
  {"(3.1.71)", 13213355, 359476},
  {"(3.1.72)", 13213459, 359479},
  {"i:116", 13213571, 359482},
  {"(3.1.73)", 13213686, 359485},
  {"Cell 3.10", 13213792, 359488},
  {"Cell 3.11", 13213888, 359491},
  {"Cell 3.12", 13213982, 359494},
  {"Cell 3.13", 13214077, 359497},
  {"c:21", 13214169, 359500},
  {"i:40", 13214255, 359503},
  {"(3.1.74)", 13214345, 359506},
  {"(3.1.75)", 13214449, 359509},
  {"Cell 3.14", 13214554, 359512},
  {"Cell 3.15", 13214649, 359515},
  {"i:38", 13214740, 359518},
  {"Cell 3.16", 13214830, 359521},
  {"i:42", 13214922, 359524},
  {"(3.1.76)", 13215036, 359527},
  {"i:41", 13215146, 359530},
  {"Cell 3.17", 13215236, 359533},
  {"(3.1.77)", 13215330, 359536},
  {"c:22", 13215430, 359539},
  {"c:23", 13215516, 359542},
  {"i:47", 13215606, 359545},
  {"i:46", 13215691, 359548},
  {"i:45", 13215777, 359551},
  {"Fig. 3.6", 13215868, 359554},
  {"i:48", 13215960, 359557},
  {"Fig. 3.7", 13216051, 359560},
  {"(3.1.78)", 13216147, 359563},
  {"i:50", 13216248, 359566},
  {"(3.1.79)", 13216337, 359569},
  {"i:97", 13216438, 359572},
  {"i:98", 13216524, 359575},
  {"i:51", 13216610, 359578},
  {"(3.1.80)", 13216701, 359581},
  {"i:52", 13216804, 359584},
  {"i:96", 13216891, 359587},
  {"i:53", 13216977, 359590},
  {"(3.1.81)", 13217067, 359593},
  {"i:111", 13217169, 359596},
  {"(3.1.82)", 13217259, 359599},
  {"i:55", 13217360, 359602},
  {"i:56", 13217448, 359605},
  {"c:24", 13217535, 359608},
  {"i:112", 13217624, 359611},
  {"(3.2.1)", 13217714, 359614},
  {"(3.2.2)", 13217805, 359617},
  {"i:57", 13217892, 359620},
  {"i:58", 13217978, 359623},
  {"i:59", 13218064, 359626},
  {"i:60", 13218151, 359629},
  {"Fig. 3.8", 13218242, 359632},
  {"c:26", 13218334, 359635},
  {"i:61", 13218425, 359638},
  {"i:62", 13218510, 359641},
  {"(3.2.3)", 13218599, 359644},
  {"i:63", 13218687, 359647},
  {"c:27", 13218773, 359650},
  {"i:64", 13218864, 359653},
  {"c:28", 13218961, 359656},
  {"i:76", 13219058, 359659},
  {"(3.2.4)", 13219147, 359662},
  {"(3.2.5)", 13219237, 359665},
  {"(3.2.6)", 13219327, 359668},
  {"c:29", 13219414, 359671},
  {"Fig. 3.9", 13219505, 359674},
  {"i:104", 13219597, 359677},
  {"(3.2.7)", 13219688, 359680},
  {"(3.2.8)", 13219778, 359683},
  {"(3.2.9)", 13219868, 359686},
  {"(3.2.10)", 13219959, 359689},
  {"(3.2.11)", 13220051, 359692},
  {"(3.2.12)", 13220143, 359695},
  {"Cell 3.18", 13220236, 359698},
  {"c:30", 13220329, 359701},
  {"i:77", 13220417, 359704},
  {"Fig. 3.10", 13220509, 359707},
  {"(3.2.13)", 13220605, 359710},
  {"(3.2.14)", 13220697, 359713},
  {"c:31", 13220786, 359716},
  {"i:65", 13220877, 359719},
  {"c:32", 13220974, 359722},
  {"i:75", 13221071, 359725},
  {"(3.2.15)", 13221161, 359728},
  {"i:109", 13221250, 359731},
  {"(3.2.16)", 13221353, 359734},
  {"(3.2.17)", 13221456, 359737},
  {"(3.2.18)", 13221548, 359740},
  {"(3.2.19)", 13221640, 359743},
  {"i:105", 13221729, 359746},
  {"(3.2.20)", 13221821, 359749},
  {"(3.2.21)", 13221913, 359752},
  {"(3.2.22)", 13222005, 359755},
  {"(3.2.23)", 13222097, 359758},
  {"(3.2.24)", 13222190, 359761},
  {"c:33", 13222279, 359764},
  {"(3.2.25)", 13222370, 359767},
  {"(3.2.26)", 13222462, 359770},
  {"c:34", 13222550, 359773},
  {"i:67", 13222641, 359776},
  {"c:35", 13222738, 359779},
  {"i:78", 13222835, 359782},
  {"i:110", 13222922, 359785},
  {"(3.2.27)", 13223026, 359788},
  {"(3.2.28)", 13223130, 359791},
  {"Fig. 3.11", 13223224, 359794},
  {"(3.2.29)", 13223321, 359797},
  {"(3.2.30)", 13223413, 359800},
  {"(3.2.31)", 13223505, 359803},
  {"(3.2.32)", 13223597, 359806},
  {"c:36", 13223685, 359809},
  {"(3.2.33)", 13223777, 359812},
  {"i:69", 13223865, 359815},
  {"(3.2.34)", 13223955, 359818},
  {"i:70", 13224044, 359821},
  {"Table 3.2", 13224134, 359824},
  {"i:83", 13224228, 359827},
  {"Cell 3.19", 13224319, 359830},
  {"Cell 3.20", 13224417, 359833},
  {"(3.2.35)", 13224513, 359836},
  {"(3.2.36)", 13224606, 359839},
  {"i:72", 13224695, 359842},
  {"(3.2.37)", 13224797, 359845},
  {"(3.2.38)", 13224899, 359848},
  {"i:71", 13224988, 359851},
  {"c:37", 13225086, 359854},
  {"(3.2.39)", 13225188, 359857},
  {"i:84", 13225276, 359860},
  {"i:73", 13225362, 359863},
  {"(3.2.40)", 13225465, 359866},
  {"Cell 3.21", 13225569, 359869},
  {"Fig. 3.12", 13225668, 359872},
  {"c:38", 13225761, 359875},
  {"(3.2.41)", 13225852, 359878},
  {"(3.2.42)", 13225944, 359881},
  {"Cell 3.22", 13226037, 359884},
  {"Cell 3.23", 13226134, 359887},
  {"Cell 3.24", 13226230, 359890},
  {"i:79", 13226323, 359893},
  {"c:39", 13226408, 359896},
  {"c:40", 13226499, 359899},
  {"i:68", 13226586, 359902},
  {"c:41", 13226684, 359905},
  {"i:100", 13226783, 359908},
  {"(3.2.43)", 13226875, 359911},
  {"(3.2.44)", 13226967, 359914},
  {"(3.2.45)", 13227059, 359917},
  {"i:80", 13227147, 359920},
  {"(3.2.46)", 13227244, 359923},
  {"i:106", 13227333, 359926},
  {"(3.2.47)", 13227424, 359929},
  {"(3.2.48)", 13227516, 359932},
  {"i:81", 13227604, 359935},
  {"(3.2.49)", 13227694, 359938},
  {"i:82", 13227782, 359941},
  {"Cell 3.25", 13227874, 359944},
  {"Cell 3.26", 13227971, 359947},
  {"(3.2.50)", 13228067, 359950},
  {"i:85", 13228155, 359953},
  {"Cell 3.27", 13228253, 359956},
  {"i:86", 13228343, 359959},
  {"Cell 3.28", 13228433, 359962},
  {"Cell 3.29", 13228529, 359965},
  {"i:87", 13228619, 359968},
  {"Cell 3.30", 13228710, 359971},
  {"(3.2.51)", 13228804, 359974},
  {"(3.2.52)", 13228896, 359977},
  {"Cell 3.31", 13228989, 359980},
  {"(3.2.53)", 13229085, 359983},
  {"(3.2.54)", 13229178, 359986},
  {"i:90", 13229267, 359989},
  {"(3.2.55)", 13229369, 359992},
  {"Cell 3.32", 13229472, 359995},
  {"Cell 3.33", 13229569, 359998},
  {"(3.2.56)", 13229665, 360001},
  {"i:107", 13229755, 360004},
  {"(3.2.57)", 13229846, 360007},
  {"Cell 3.34", 13229940, 360010},
  {"Cell 3.35", 13230037, 360013},
  {"Cell 3.36", 13230133, 360016},
  {"Cell 3.37", 13230229, 360019},
  {"i:91", 13230321, 360022},
  {"c:42", 13230406, 360025},
  {"(3.2.58)", 13230498, 360028},
  {"(3.2.59)", 13230590, 360031},
  {"i:88", 13230678, 360034},
  {"(3.2.60)", 13230768, 360037},
  {"i:89", 13230857, 360040},
  {"Cell 3.38", 13230949, 360043},
  {"Cell 3.39", 13231046, 360046},
  {"(3.2.61)", 13231142, 360049},
  {"c:43", 13231231, 360052},
  {"Fig. 3.13", 13231327, 360055},
  {"Fig. 3.14", 13231424, 360058},
  {"Fig. 3.15", 13231521, 360061},
  {"Fig. 3.16", 13231618, 360064},
  {"i:93", 13231710, 360067},
  {"i:94", 13231796, 360070},
  {"i:92", 13231882, 360073},
  {"Fig. 3.17", 13231973, 360076},
  {"(3.2.62)", 13232069, 360079},
  {"c:44", 13232157, 360082}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 92, 1, 107, "Title",
  CellTags->"c:1"],
Cell[1822, 55, 16, 0, 27, "Text"],
Cell[1841, 57, 347, 6, 61, "Text"],
Cell[2191, 65, 251, 6, 44, "Text"],

Cell[CellGroupData[{
Cell[2467, 75, 147, 4, 69, "Subtitle",
  CellTags->"c:3"],
Cell[2617, 81, 17, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2659, 85, 88, 1, 40, "Subsubtitle",
  CellTags->{"i:3", "c:4"}],

Cell[CellGroupData[{
Cell[2772, 90, 50, 1, 42, "Section",
  CellTags->"c:5"],
Cell[2825, 93, 369, 6, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3231, 104, 65, 1, 31, "Section",
  CellTags->{"i:4", "c:6"}],
Cell[3299, 107, 1606, 48, 129, "Text"],
Cell[4908, 157, 41189, 512, 98, 41073, 508, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[46100, 671, 76, 1, 16, "Caption",
  CellTags->"Fig. 3.1"],
Cell[46179, 674, 1634, 44, 129, "Text"],
Cell[47816, 720, 32541, 405, 89, 32422, 401, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[80360, 1127, 99, 1, 16, "Caption",
  CellTags->"Fig. 3.2"],
Cell[80462, 1130, 675, 21, 61, "Text"],
Cell[81140, 1153, 195, 6, 29, "NumberedEquation",
  CellTags->"(3.1.1)"],
Cell[81338, 1161, 470, 15, 44, "Text"],
Cell[81811, 1178, 156, 3, 27, "NumberedEquation",
  CellTags->"(3.1.2)"],
Cell[81970, 1183, 371, 10, 44, "Text"],
Cell[82344, 1195, 1208, 31, 129, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[83589, 1231, 72, 1, 31, "Section",
  CellTags->"c:7"],
Cell[83664, 1234, 794, 22, 78, "Text"],
Cell[84461, 1258, 66293, 822, 190, 66171, 818, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[150757, 2082, 159, 4, 16, "Caption",
  CellTags->"Fig. 3.3"],
Cell[150919, 2088, 953, 31, 80, "Text"],
Cell[151875, 2121, 295, 8, 38, "NumberedEquation",
  CellTags->"(3.1.3)"],
Cell[152173, 2131, 189, 6, 27, "Text"],
Cell[152365, 2139, 283, 4, 42, "NumberedEquation",
  CellTags->"(3.1.4)"],
Cell[152651, 2145, 1112, 33, 96, "Text"],
Cell[153766, 2180, 177, 6, 30, "NumberedEquation",
  CellTags->"(3.1.5)"],
Cell[153946, 2188, 1174, 35, 80, "Text"],
Cell[155123, 2225, 197, 7, 30, "NumberedEquation",
  CellTags->"(3.1.6)"],
Cell[155323, 2234, 343, 13, 27, "Text"],
Cell[155669, 2249, 312, 7, 45, "NumberedEquation",
  CellTags->{"(3.1.7)", "i:1"}],
Cell[155984, 2258, 1026, 31, 95, "Text"],
Cell[157013, 2291, 696, 18, 87, "Text"],
Cell[157712, 2311, 125, 2, 27, "NumberedEquation",
  CellTags->"(3.1.8)"],
Cell[157840, 2315, 41, 0, 27, "Text"],
Cell[157884, 2317, 258, 9, 56, "NumberedEquation",
  CellTags->"(3.1.9)"],
Cell[158145, 2328, 236, 8, 27, "Text"],
Cell[158384, 2338, 407, 13, 44, "Text"],
Cell[158794, 2353, 237, 6, 42, "NumberedEquation",
  CellTags->{"(3.1.10)", "i:2"}],
Cell[159034, 2361, 116, 5, 27, "Text"],
Cell[159153, 2368, 144, 5, 33, "NumberedEquation",
  CellTags->{"(3.1.11)", "i:49"}],
Cell[159300, 2375, 170, 4, 44, "Text"],
Cell[159473, 2381, 1011, 31, 65, "Text"],
Cell[160487, 2414, 585, 16, 32, "NumberedEquation",
  CellTags->"(3.1.12)"],
Cell[161075, 2432, 517, 19, 27, "Text"],
Cell[161595, 2453, 1419, 34, 163, "Text",
  CellTags->"i:95"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[163063, 2493, 117, 4, 29, "Subsubtitle",
  CellTags->"c:8"],

Cell[CellGroupData[{
Cell[163205, 2501, 113, 4, 42, "Section",
  CellTags->"c:9"],

Cell[CellGroupData[{
Cell[163343, 2509, 69, 0, 27, "Subsubsection"],
Cell[163415, 2511, 801, 26, 61, "Text",
  CellTags->"i:6"],
Cell[164219, 2539, 148, 5, 29, "NumberedEquation",
  CellTags->"(3.1.13)"],
Cell[164370, 2546, 553, 17, 78, "Text"],
Cell[164926, 2565, 371, 13, 27, "Text"],
Cell[165300, 2580, 263, 8, 46, "NumberedEquation",
  CellTags->"(3.1.14)"],
Cell[165566, 2590, 1202, 39, 115, "Text"],
Cell[166771, 2631, 199, 4, 46, "NumberedEquation",
  CellTags->"(3.1.15)"],
Cell[166973, 2637, 222, 7, 46, "NumberedEquation",
  CellTags->"(3.1.16)"],
Cell[167198, 2646, 862, 24, 78, "Text",
  CellTags->"i:8"]
}, Closed]],

Cell[CellGroupData[{
Cell[168097, 2675, 66, 1, 29, "Subsubsection",
  CellTags->"i:7"],
Cell[168166, 2678, 1388, 43, 70, "Text",
  CellTags->"i:9"],
Cell[169557, 2723, 384, 12, 70, "Text"],
Cell[169944, 2737, 209, 4, 70, "NumberedEquation",
  CellTags->"(3.1.17)"],
Cell[170156, 2743, 1213, 40, 70, "Text"],
Cell[171372, 2785, 286, 9, 70, "Text"],
Cell[171661, 2796, 240, 8, 70, "NumberedEquation",
  CellTags->"(3.1.18)"],
Cell[171904, 2806, 26, 0, 70, "Text"],
Cell[171933, 2808, 245, 6, 70, "NumberedEquation",
  CellTags->"(3.1.19)"],
Cell[172181, 2816, 340, 10, 70, "Text"],
Cell[172524, 2828, 854, 22, 70, "Text",
  CellTags->"i:14"]
}, Closed]],

Cell[CellGroupData[{
Cell[173415, 2855, 112, 4, 29, "Subsubsection"],
Cell[173530, 2861, 222, 6, 70, "Text"],
Cell[173755, 2869, 193, 7, 70, "Text"],
Cell[173951, 2878, 511, 19, 70, "Text"],
Cell[174465, 2899, 213, 7, 70, "Text"],
Cell[174681, 2908, 494, 16, 70, "Text"],
Cell[175178, 2926, 345, 9, 70, "NumberedEquation",
  CellTags->"(3.1.20)"],
Cell[175526, 2937, 342, 9, 70, "Text",
  CellTags->"i:18"]
}, Closed]],

Cell[CellGroupData[{
Cell[175905, 2951, 76, 1, 29, "Subsubsection",
  CellTags->"i:99"],
Cell[175984, 2954, 778, 18, 95, "Text",
  CellTags->"i:12"],

Cell[CellGroupData[{
Cell[176787, 2976, 587, 13, 200, "Input",
  CellTags->"Cell 3.1"],

Cell[CellGroupData[{
Cell[177399, 2993, 76269, 2311, 379, 26603, 1694, "GraphicsData", \
"PostScript", "Graphics"],
Cell[253671, 5306, 109636, 2723, 70, 26633, 1694, "GraphicsData", \
"PostScript", "Graphics"],
Cell[363310, 8031, 97603, 2574, 70, 26641, 1694, "GraphicsData", \
"PostScript", "Graphics"],
Cell[460916, 10607, 62471, 2141, 70, 26637, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[523390, 12750, 66316, 2189, 70, 26638, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[589709, 14941, 69729, 2231, 70, 26625, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[659441, 17174, 69988, 2234, 70, 26649, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[729432, 19410, 67082, 2198, 70, 26635, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[796517, 21610, 66876, 2196, 70, 26635, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[863396, 23808, 69680, 2230, 70, 26633, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[933079, 26040, 68909, 2221, 70, 26635, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1001991, 28263, 69290, 2225, 70, 26632, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1071284, 30490, 66737, 2194, 70, 26646, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1138024, 32686, 67039, 2198, 70, 26632, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1205066, 34886, 69909, 2233, 70, 26639, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1274978, 37121, 69590, 2229, 70, 26624, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1344571, 39352, 66219, 2187, 70, 26639, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1410793, 41541, 62410, 2140, 70, 26641, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1473206, 43683, 66800, 2194, 70, 26645, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1540009, 45879, 73858, 2282, 70, 26623, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1613870, 48163, 76410, 2314, 70, 26571, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1690283, 50479, 73858, 2282, 70, 26623, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1764144, 52763, 66800, 2194, 70, 26645, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1830947, 54959, 62410, 2140, 70, 26641, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1893360, 57101, 66219, 2187, 70, 26639, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1959582, 59290, 69590, 2229, 70, 26624, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2029175, 61521, 69909, 2233, 70, 26639, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2099087, 63756, 67039, 2198, 70, 26632, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2166129, 65956, 66737, 2194, 70, 26646, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2232869, 68152, 69290, 2225, 70, 26632, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2302162, 70379, 68909, 2221, 70, 26635, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2371074, 72602, 69680, 2230, 70, 26633, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2440757, 74834, 66876, 2196, 70, 26635, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2507636, 77032, 67082, 2198, 70, 26635, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2574721, 79232, 69988, 2234, 70, 26649, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2644712, 81468, 69729, 2231, 70, 26625, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2714444, 83701, 66316, 2189, 70, 26638, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2780763, 85892, 62471, 2141, 70, 26637, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2843237, 88035, 66481, 2191, 70, 26641, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2909721, 90228, 73698, 2280, 70, 26633, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2983422, 92510, 76300, 2312, 70, 26603, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],
Cell[3059749, 94826, 1114, 28, 170, "Text"],
Cell[3060866, 94856, 620, 12, 78, "Text"],
Cell[3061489, 94870, 777, 17, 95, "Text"],
Cell[3062269, 94889, 604, 12, 78, "Text"],
Cell[3062876, 94903, 702, 18, 78, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3063615, 94926, 56, 0, 29, "Subsubsection"],
Cell[3063674, 94928, 682, 25, 44, "Text",
  CellTags->"i:13"],
Cell[3064359, 94955, 231, 7, 30, "NumberedEquation",
  CellTags->"(3.1.21)"],
Cell[3064593, 94964, 296, 10, 27, "Text"],
Cell[3064892, 94976, 230, 6, 38, "NumberedEquation",
  CellTags->"(3.1.22)"],
Cell[3065125, 94984, 540, 17, 44, "Text"],
Cell[3065668, 95003, 237, 4, 29, "NumberedEquation",
  CellTags->"(3.1.23)"],
Cell[3065908, 95009, 149, 5, 27, "Text"],
Cell[3066060, 95016, 248, 7, 38, "NumberedEquation",
  CellTags->"(3.1.24)"],
Cell[3066311, 95025, 1221, 41, 95, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3067581, 95072, 47, 1, 31, "Section",
  CellTags->"c:10"],

Cell[CellGroupData[{
Cell[3067653, 95077, 53, 0, 27, "Subsubsection"],
Cell[3067709, 95079, 167, 4, 44, "Text"],
Cell[3067879, 95085, 729, 21, 64, "Text"],
Cell[3068611, 95108, 748, 25, 61, "Text"],
Cell[3069362, 95135, 476, 11, 37, "Text"],
Cell[3069841, 95148, 173, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[3070039, 95157, 288, 7, 124, "Input",
  CellTags->"Cell 3.2"],
Cell[3070330, 95166, 87, 1, 73, "Output"]
}, Open  ]],
Cell[3070432, 95170, 60, 0, 27, "Text"],
Cell[3070495, 95172, 234, 7, 30, "NumberedEquation",
  CellTags->"(3.1.25)"],
Cell[3070732, 95181, 852, 27, 78, "Text"],

Cell[CellGroupData[{
Cell[3071609, 95212, 467, 11, 143, "Input",
  CellTags->"Cell 3.3"],

Cell[CellGroupData[{
Cell[3072101, 95227, 25289, 654, 233, 6666, 419, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3097393, 95883, 26813, 746, 70, 8101, 510, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3124209, 96631, 28203, 843, 70, 9661, 609, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3152415, 97476, 29488, 934, 70, 11104, 702, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3181906, 98412, 30822, 1033, 70, 12681, 804, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3212731, 99447, 28700, 904, 70, 10749, 677, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3241434, 100353, 30646, 1031, 70, 12707, 804, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3272083, 101386, 29463, 934, 70, 11099, 702, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3301549, 102322, 28298, 844, 70, 9663, 609, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3329850, 103168, 26964, 748, 70, 8098, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3356817, 103918, 25287, 654, 70, 6668, 419, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3382107, 104574, 26831, 747, 70, 8098, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3408941, 105323, 28153, 843, 70, 9663, 609, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3437097, 106168, 29431, 934, 70, 11099, 702, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3466531, 107104, 30508, 1029, 70, 12707, 804, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3497042, 108135, 30010, 991, 70, 12140, 765, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3527055, 109128, 30798, 1033, 70, 12681, 804, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3557856, 110163, 29363, 933, 70, 11104, 702, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3587222, 111098, 28191, 843, 70, 9661, 609, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3615416, 111943, 26785, 746, 70, 8101, 510, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[3642228, 112693, 689, 15, 95, "Text"],
Cell[3642920, 112710, 362, 11, 44, "Text"],

Cell[CellGroupData[{
Cell[3643307, 112725, 523, 10, 200, "Input",
  CellTags->"Cell 3.4"],
Cell[3643833, 112737, 39331, 1153, 233, 15378, 853, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3683179, 113893, 1148, 27, 129, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3684364, 113925, 61, 0, 29, "Subsubsection"],
Cell[3684428, 113927, 206, 4, 44, "Text"],
Cell[3684637, 113933, 339, 11, 53, "Text"],
Cell[3684979, 113946, 361, 10, 44, "Text"],
Cell[3685343, 113958, 270, 6, 99, "Input",
  CellTags->"Cell 3.5"],
Cell[3685616, 113966, 316, 8, 44, "Text"],

Cell[CellGroupData[{
Cell[3685957, 113978, 454, 11, 124, "Input",
  CellTags->"Cell 3.6"],

Cell[CellGroupData[{
Cell[3686436, 113993, 35300, 866, 233, 8574, 531, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3721739, 114861, 8548, 521, 70, 8332, 515, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3730290, 115384, 8971, 549, 70, 8755, 543, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3739264, 115935, 8930, 546, 70, 8714, 540, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3748197, 116483, 8864, 542, 70, 8648, 536, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3757064, 117027, 8787, 537, 70, 8571, 531, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3765854, 117566, 8785, 537, 70, 8569, 531, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3774642, 118105, 8955, 548, 70, 8739, 542, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3783600, 118655, 9055, 554, 70, 8839, 548, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3792658, 119211, 9244, 566, 70, 9028, 560, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3801905, 119779, 10105, 620, 70, 9889, 614, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[3812013, 120401, 9200, 566, 70, 8984, 560, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3821216, 120969, 9052, 554, 70, 8836, 548, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3830271, 121525, 8953, 548, 70, 8737, 542, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3839227, 122075, 8786, 537, 70, 8570, 531, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3848016, 122614, 8787, 537, 70, 8571, 531, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3856806, 123153, 8862, 542, 70, 8646, 536, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3865671, 123697, 8928, 546, 70, 8712, 540, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3874602, 124245, 8969, 549, 70, 8753, 543, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3883574, 124796, 8532, 521, 70, 8316, 515, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3892109, 125319, 8776, 537, 70, 8560, 531, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3900888, 125858, 8532, 521, 70, 8316, 515, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3909423, 126381, 8969, 549, 70, 8753, 543, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3918395, 126932, 8928, 546, 70, 8712, 540, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3927326, 127480, 8862, 542, 70, 8646, 536, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3936191, 128024, 8787, 537, 70, 8571, 531, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3944981, 128563, 8786, 537, 70, 8570, 531, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3953770, 129102, 8953, 548, 70, 8737, 542, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3962726, 129652, 9052, 554, 70, 8836, 548, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3971781, 130208, 9200, 566, 70, 8984, 560, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3980984, 130776, 9477, 580, 70, 9261, 574, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3990464, 131358, 9244, 566, 70, 9028, 560, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3999711, 131926, 9055, 554, 70, 8839, 548, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[4008769, 132482, 8955, 548, 70, 8739, 542, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[4017727, 133032, 8785, 537, 70, 8569, 531, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[4026515, 133571, 8787, 537, 70, 8571, 531, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[4035305, 134110, 8864, 542, 70, 8648, 536, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[4044172, 134654, 8930, 546, 70, 8714, 540, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[4053105, 135202, 8971, 549, 70, 8755, 543, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[4062079, 135753, 8548, 521, 70, 8332, 515, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],
Cell[4070654, 136278, 835, 20, 95, "Text"],
Cell[4071492, 136300, 1113, 35, 65, "Text"],
Cell[4072608, 136337, 327, 8, 44, "Text"],
Cell[4072938, 136347, 161, 6, 29, "NumberedEquation",
  CellTags->"(3.1.26)"],
Cell[4073102, 136355, 356, 13, 27, "Text",
  CellTags->"i:15"],
Cell[4073461, 136370, 821, 22, 78, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4074331, 136398, 92, 1, 31, "Section",
  CellTags->"c:11"],

Cell[CellGroupData[{
Cell[4074448, 136403, 110, 3, 27, "Subsubsection"],
Cell[4074561, 136408, 440, 9, 61, "Text"],
Cell[4075004, 136419, 186, 8, 27, "Text"],
Cell[4075193, 136429, 1087, 31, 95, "Text",
  CellTags->"i:10"],
Cell[4076283, 136462, 1175, 30, 129, "Text",
  CellTags->"i:11"],
Cell[4077461, 136494, 1135, 29, 129, "Text"],
Cell[4078599, 136525, 296, 5, 42, "NumberedEquation",
  CellTags->"(3.1.27)"],
Cell[4078898, 136532, 420, 13, 44, "Text"],
Cell[4079321, 136547, 341, 9, 45, "NumberedEquation",
  CellTags->{"(3.1.28)", "i:17"}],
Cell[4079665, 136558, 457, 13, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4080159, 136576, 49, 0, 29, "Subsubsection"],
Cell[4080211, 136578, 716, 19, 70, "Text"],
Cell[4080930, 136599, 585, 17, 70, "NumberedEquation",
  CellTags->"(3.1.29)"],
Cell[4081518, 136618, 97, 3, 70, "Text"],
Cell[4081618, 136623, 560, 13, 70, "NumberedEquation",
  CellTags->"(3.1.30)"],
Cell[4082181, 136638, 220, 8, 70, "Text"],
Cell[4082404, 136648, 690, 13, 70, "NumberedEquation",
  CellTags->"(3.1.31)"],
Cell[4083097, 136663, 725, 22, 70, "Text"],
Cell[4083825, 136687, 258, 5, 70, "NumberedEquation",
  CellTags->{"(3.1.32)", "i:5"}],
Cell[4084086, 136694, 1314, 35, 70, "Text",
  CellTags->"i:19"]
}, Closed]],

Cell[CellGroupData[{
Cell[4085437, 136734, 55, 0, 29, "Subsubsection"],
Cell[4085495, 136736, 610, 18, 70, "Text"],
Cell[4086108, 136756, 418, 13, 70, "NumberedEquation",
  CellTags->"(3.1.33)"],
Cell[4086529, 136771, 983, 37, 70, "Text"],
Cell[4087515, 136810, 792, 21, 70, "NumberedEquation",
  CellTags->"(3.1.34)"],
Cell[4088310, 136833, 555, 18, 70, "NumberedEquation",
  CellTags->"(3.1.35)"],
Cell[4088868, 136853, 339, 13, 70, "Text"],
Cell[4089210, 136868, 751, 24, 70, "NumberedEquation",
  CellTags->"(3.1.36)"],
Cell[4089964, 136894, 527, 16, 70, "Text"],
Cell[4090494, 136912, 724, 17, 70, "Text",
  CellTags->"i:16"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4091267, 136935, 46, 1, 31, "Section",
  CellTags->"c:12"],
Cell[4091316, 136938, 567, 19, 70, "Text"],
Cell[4091886, 136959, 763, 24, 70, "Text"],
Cell[4092652, 136985, 701, 16, 70, "Text",
  CellTags->"i:103"],
Cell[4093356, 137003, 229, 4, 70, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4093634, 137013, 91, 1, 29, "Subsubtitle",
  CellTags->{"i:108", "c:13"}],

Cell[CellGroupData[{
Cell[4093750, 137018, 58, 1, 42, "Section",
  CellTags->{"i:20", "c:14"}],
Cell[4093811, 137021, 2086, 64, 70, "Text",
  CellTags->"i:101"],
Cell[4095900, 137087, 750, 22, 70, "Text"],
Cell[4096653, 137111, 204, 6, 70, "NumberedEquation",
  CellTags->{"(3.1.37)", "i:113"}],
Cell[4096860, 137119, 2319, 70, 70, "Text",
  CellTags->"i:21"],
Cell[4099182, 137191, 275, 5, 70, "Text"],
Cell[4099460, 137198, 50866, 631, 70, 50744, 627, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[4150329, 137831, 470, 18, 70, "Caption",
  CellTags->"Fig. 3.4"]
}, Closed]],

Cell[CellGroupData[{
Cell[4150836, 137854, 58, 1, 31, "Section",
  CellTags->"c:15"],
Cell[4150897, 137857, 696, 21, 70, "Text"],
Cell[4151596, 137880, 3351747, 46091, 70, 3311569, 45590, "GraphicsData", \
"PostScript", "Picture"],
Cell[7503346, 183973, 461, 16, 70, "Caption",
  CellTags->"Fig. 3.5"],
Cell[7503810, 183991, 3637, 106, 70, "Text",
  CellTags->"i:22"],
Cell[7507450, 184099, 1254, 32, 70, "Text"],
Cell[7508707, 184133, 1434, 36, 70, "Text",
  CellTags->"i:102"],
Cell[7510144, 184171, 228, 6, 70, "NumberedEquation",
  CellTags->{"(3.1.38)", "i:23"}]
}, Closed]],

Cell[CellGroupData[{
Cell[7510409, 184182, 137, 4, 31, "Section",
  CellTags->"c:16"],
Cell[7510549, 184188, 293, 10, 27, "Text"],
Cell[7510845, 184200, 249, 7, 38, "NumberedEquation",
  CellTags->"(3.1.39)"],
Cell[7511097, 184209, 313, 6, 61, "Text"],
Cell[7511413, 184217, 178, 6, 29, "NumberedEquation",
  CellTags->"(3.1.40)"],
Cell[7511594, 184225, 1619, 42, 137, "Text",
  CellTags->"i:24"],
Cell[7513216, 184269, 392, 16, 44, "Text"],
Cell[7513611, 184287, 289, 8, 38, "NumberedEquation",
  CellTags->{"(3.1.41)", "i:25"}],
Cell[7513903, 184297, 612, 20, 61, "Text"],
Cell[7514518, 184319, 204, 6, 42, "NumberedEquation",
  CellTags->"(3.1.42)"],
Cell[7514725, 184327, 219, 9, 27, "Text",
  CellTags->"i:26"],
Cell[7514947, 184338, 135, 5, 29, "NumberedEquation",
  CellTags->"(3.1.43)"],
Cell[7515085, 184345, 1229, 41, 48, "Text",
  CellTags->"i:114"],
Cell[7516317, 184388, 194, 4, 44, "Text"],
Cell[7516514, 184394, 148, 3, 27, "NumberedEquation",
  CellTags->"(3.1.44)"],
Cell[7516665, 184399, 545, 13, 78, "Text"],
Cell[7517213, 184414, 234, 6, 47, "NumberedEquation",
  CellTags->"(3.1.45)"],
Cell[7517450, 184422, 157, 4, 27, "Text",
  CellTags->"i:27"],
Cell[7517610, 184428, 554, 12, 61, "Text"],
Cell[7518167, 184442, 384, 7, 74, "NumberedEquation",
  CellTags->"(3.1.46)"],
Cell[7518554, 184451, 473, 12, 61, "Text",
  CellTags->"i:28"],
Cell[7519030, 184465, 358, 8, 61, "Text",
  CellTags->"i:29"],
Cell[7519391, 184475, 357, 9, 69, "NumberedEquation",
  CellTags->"(3.1.47)"],
Cell[7519751, 184486, 1339, 44, 112, "Text"],
Cell[7521093, 184532, 385, 9, 61, "Text"],
Cell[7521481, 184543, 1605, 41, 166, "2ColumnBox",
  CellTags->"Table 3.1"],
Cell[7523089, 184586, 242, 10, 26, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7523380, 184602, 118, 4, 29, "Subsubtitle",
  CellTags->"c:17"],

Cell[CellGroupData[{
Cell[7523523, 184610, 51, 1, 42, "Section",
  CellTags->"c:18"],
Cell[7523577, 184613, 539, 12, 70, "Text"],
Cell[7524119, 184627, 729, 19, 70, "Text"],
Cell[7524851, 184648, 268, 5, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7525156, 184658, 85, 1, 31, "Section",
  CellTags->"c:19"],

Cell[CellGroupData[{
Cell[7525266, 184663, 49, 0, 27, "Subsubsection"],
Cell[7525318, 184665, 452, 12, 70, "Text"],
Cell[7525773, 184679, 231, 6, 70, "NumberedEquation",
  CellTags->"(3.1.48)"],
Cell[7526007, 184687, 103, 3, 70, "Text"],
Cell[7526113, 184692, 544, 13, 70, "NumberedEquation",
  CellTags->"(3.1.49)"],
Cell[7526660, 184707, 502, 16, 70, "Text",
  CellTags->"i:30"],
Cell[7527165, 184725, 480, 13, 70, "Text"],
Cell[7527648, 184740, 646, 18, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7528331, 184763, 146, 4, 29, "Subsubsection",
  CellTags->"i:31"],
Cell[7528480, 184769, 294, 7, 44, "Text"],
Cell[7528777, 184778, 552, 15, 70, "NumberedEquation",
  CellTags->"(3.1.50)"],
Cell[7529332, 184795, 695, 18, 78, "Text"],
Cell[7530030, 184815, 553, 18, 44, "Text"],
Cell[7530586, 184835, 281, 8, 34, "NumberedEquation",
  CellTags->"(3.1.51)"],
Cell[7530870, 184845, 645, 16, 83, "Text"],
Cell[7531518, 184863, 386, 9, 37, "Text"],
Cell[7531907, 184874, 386, 11, 44, "Text"],
Cell[7532296, 184887, 1024, 26, 100, "Text"],
Cell[7533323, 184915, 1217, 32, 112, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7534577, 184952, 85, 1, 29, "Subsubsection"],
Cell[7534665, 184955, 557, 14, 61, "Text"],
Cell[7535225, 184971, 359, 12, 27, "Text"],
Cell[7535587, 184985, 419, 13, 30, "NumberedEquation",
  CellTags->"(3.1.52)"],
Cell[7536009, 185000, 578, 19, 44, "Text"],
Cell[7536590, 185021, 771, 20, 38, "NumberedEquation",
  CellTags->"(3.1.53)"],
Cell[7537364, 185043, 140, 5, 27, "Text"],
Cell[7537507, 185050, 383, 13, 30, "NumberedEquation",
  CellTags->"(3.1.54)"],
Cell[7537893, 185065, 1745, 49, 78, "Text"],
Cell[7539641, 185116, 829, 23, 98, "Text"],
Cell[7540473, 185141, 722, 24, 61, "Text"],
Cell[7541198, 185167, 610, 17, 42, "NumberedEquation",
  CellTags->"(3.1.55)"],
Cell[7541811, 185186, 622, 20, 44, "Text",
  CellTags->"i:43"],
Cell[7542436, 185208, 259, 7, 46, "NumberedEquation",
  CellTags->"(3.1.56)"],
Cell[7542698, 185217, 442, 14, 44, "Text"],
Cell[7543143, 185233, 187, 6, 42, "NumberedEquation",
  CellTags->"(3.1.57)"],
Cell[7543333, 185241, 211, 7, 46, "NumberedEquation",
  CellTags->"(3.1.58)"]
}, Closed]],

Cell[CellGroupData[{
Cell[7543581, 185253, 67, 1, 29, "Subsubsection",
  CellTags->"i:32"],
Cell[7543651, 185256, 701, 18, 78, "Text"],
Cell[7544355, 185276, 149, 3, 27, "NumberedEquation",
  CellTags->"(3.1.59)"],
Cell[7544507, 185281, 19, 0, 27, "Text"],
Cell[7544529, 185283, 254, 9, 32, "NumberedEquation",
  CellTags->"(3.1.60)"],
Cell[7544786, 185294, 156, 6, 27, "Text"],
Cell[7544945, 185302, 138, 5, 30, "Text"],
Cell[7545086, 185309, 249, 5, 44, "Text"],
Cell[7545338, 185316, 463, 13, 38, "NumberedEquation",
  CellTags->{"(3.1.61)", "i:33"}],
Cell[7545804, 185331, 398, 12, 44, "Text"],
Cell[7546205, 185345, 436, 14, 28, "Text"],
Cell[7546644, 185361, 167, 6, 27, "Text",
  CellTags->"i:34"],
Cell[7546814, 185369, 245, 4, 38, "NumberedEquation",
  CellTags->"(3.1.62)"],
Cell[7547062, 185375, 1496, 45, 113, "Text",
  CellTags->"i:35"],

Cell[CellGroupData[{
Cell[7548583, 185424, 595, 12, 162, "Input",
  CellTags->"Cell 3.7"],

Cell[CellGroupData[{
Cell[7549203, 185440, 146760, 3182, 428, 26603, 1694, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7695966, 188624, 27057, 1702, 70, 26636, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[7723026, 190328, 27072, 1702, 70, 26651, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[7750101, 192032, 27073, 1702, 70, 26652, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[7777177, 193736, 27040, 1702, 70, 26619, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[7804220, 195440, 26967, 1702, 70, 26546, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[7831190, 197144, 27071, 1702, 70, 26650, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[7858264, 198848, 27089, 1702, 70, 26668, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[7885356, 200552, 27086, 1702, 70, 26665, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[7912445, 202256, 27038, 1702, 70, 26617, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[7939486, 203960, 27070, 1702, 70, 26649, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[7966559, 205664, 27096, 1702, 70, 26675, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[7993658, 207368, 27080, 1702, 70, 26659, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8020741, 209072, 27094, 1702, 70, 26673, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8047838, 210776, 27090, 1702, 70, 26669, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8074931, 212480, 27083, 1702, 70, 26662, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8102017, 214184, 27066, 1702, 70, 26645, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8129086, 215888, 27094, 1702, 70, 26673, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8156183, 217592, 27093, 1702, 70, 26672, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8183279, 219296, 27085, 1702, 70, 26664, 1694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8210367, 221000, 85794, 2429, 70, 26604, 1694, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[8296188, 223433, 692, 17, 78, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8296917, 223455, 74, 1, 29, "Subsubsection"],
Cell[8296994, 223458, 755, 23, 64, "Text"],
Cell[8297752, 223483, 645, 21, 45, "Text"],
Cell[8298400, 223506, 197, 4, 29, "NumberedEquation",
  CellTags->"(3.1.63)"],
Cell[8298600, 223512, 273, 10, 27, "Text"],

Cell[CellGroupData[{
Cell[8298898, 223526, 267, 7, 88, "Input",
  CellTags->"Cell 3.8"],
Cell[8299168, 223535, 17358, 497, 233, 6279, 356, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[8316541, 224035, 1203, 42, 64, "Text"],

Cell[CellGroupData[{
Cell[8317769, 224081, 1482, 30, 317, "Input",
  CellTags->"Cell 3.9"],

Cell[CellGroupData[{
Cell[8319276, 224115, 16545, 535, 233, 6803, 411, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8335824, 224652, 23912, 607, 70, 6442, 387, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8359739, 225261, 23932, 607, 70, 6446, 387, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8383674, 225870, 23996, 608, 70, 6445, 387, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8407673, 226480, 24029, 608, 70, 6446, 387, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8431705, 227090, 23703, 605, 70, 6446, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8455411, 227697, 23940, 608, 70, 6444, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8479354, 228307, 23939, 608, 70, 6447, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8503296, 228917, 23990, 608, 70, 6446, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8527289, 229527, 24028, 609, 70, 6447, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8551320, 230138, 23742, 605, 70, 6445, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8575065, 230745, 23981, 608, 70, 6445, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8599049, 231355, 23973, 608, 70, 6449, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8623025, 231965, 24026, 609, 70, 6449, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8647054, 232576, 24052, 609, 70, 6443, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8671109, 233187, 23784, 606, 70, 6446, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8694896, 233795, 24017, 609, 70, 6444, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8718916, 234406, 23997, 608, 70, 6445, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8742916, 235016, 24065, 609, 70, 6448, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8766984, 235627, 24090, 609, 70, 6449, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8791077, 236238, 23747, 605, 70, 6446, 387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],
Cell[8814851, 236847, 439, 10, 62, "Text",
  CellTags->"i:115"],
Cell[8815293, 236859, 556, 13, 68, "Text",
  CellTags->"i:36"],
Cell[8815852, 236874, 299, 8, 37, "NumberedEquation",
  CellTags->"(3.1.64)"],
Cell[8816154, 236884, 923, 23, 105, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8817126, 236913, 82, 1, 31, "Section",
  CellTags->"c:20"],

Cell[CellGroupData[{
Cell[8817233, 236918, 57, 0, 27, "Subsubsection"],
Cell[8817293, 236920, 451, 10, 62, "Text"],
Cell[8817747, 236932, 187, 6, 42, "NumberedEquation",
  CellTags->"(3.1.65)"],
Cell[8817937, 236940, 64, 0, 27, "Text"],
Cell[8818004, 236942, 222, 4, 38, "NumberedEquation",
  CellTags->"(3.1.66)"],
Cell[8818229, 236948, 38, 0, 27, "Text"],
Cell[8818270, 236950, 148, 3, 27, "NumberedEquation",
  CellTags->"(3.1.67)"],
Cell[8818421, 236955, 708, 19, 78, "Text"],
Cell[8819132, 236976, 233, 7, 44, "Text"],
Cell[8819368, 236985, 308, 10, 27, "Text"],
Cell[8819679, 236997, 187, 6, 42, "NumberedEquation",
  CellTags->"(3.1.68)"],
Cell[8819869, 237005, 211, 7, 46, "NumberedEquation",
  CellTags->"(3.1.69)"]
}, Closed]],

Cell[CellGroupData[{
Cell[8820117, 237017, 67, 1, 29, "Subsubsection",
  CellTags->"i:37"],
Cell[8820187, 237020, 804, 23, 79, "Text"],
Cell[8820994, 237045, 1138, 35, 83, "Text",
  CellTags->"i:39"],
Cell[8822135, 237082, 149, 3, 27, "NumberedEquation",
  CellTags->"(3.1.70)"],
Cell[8822287, 237087, 19, 0, 27, "Text"],
Cell[8822309, 237089, 250, 8, 32, "NumberedEquation",
  CellTags->"(3.1.71)"],
Cell[8822562, 237099, 90, 3, 27, "Text"],
Cell[8822655, 237104, 256, 7, 38, "NumberedEquation",
  CellTags->{"(3.1.72)", "i:116"}],
Cell[8822914, 237113, 433, 14, 44, "Text"],
Cell[8823350, 237129, 264, 9, 27, "Text"],
Cell[8823617, 237140, 206, 7, 28, "Text"],
Cell[8823826, 237149, 196, 8, 27, "Text"],
Cell[8824025, 237159, 433, 13, 81, "NumberedEquation",
  CellTags->"(3.1.73)"],
Cell[8824461, 237174, 793, 15, 112, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8825291, 237194, 75, 1, 29, "Subsubsection"],
Cell[8825369, 237197, 486, 12, 74, "Text"],
Cell[8825858, 237211, 345, 12, 44, "Text"],
Cell[8826206, 237225, 339, 7, 160, "Input",
  CellTags->"Cell 3.10"],
Cell[8826548, 237234, 169, 8, 27, "Text"],

Cell[CellGroupData[{
Cell[8826742, 237246, 84, 3, 67, "Input",
  CellTags->"Cell 3.11"],
Cell[8826829, 237251, 39, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8826905, 237257, 117, 3, 67, "Input",
  CellTags->"Cell 3.12"],
Cell[8827025, 237262, 197, 3, 69, "Output"]
}, Open  ]],
Cell[8827237, 237268, 353, 12, 27, "Text"],

Cell[CellGroupData[{
Cell[8827615, 237284, 916, 20, 227, "Input",
  CellTags->"Cell 3.13"],

Cell[CellGroupData[{
Cell[8828556, 237308, 7914, 485, 233, 7729, 480, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8836473, 237795, 7937, 486, 70, 7752, 481, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8844413, 238283, 7938, 486, 70, 7753, 481, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8852354, 238771, 7949, 488, 70, 7764, 483, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8860306, 239261, 7571, 463, 70, 7386, 458, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8867880, 239726, 7538, 461, 70, 7353, 456, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8875421, 240189, 7541, 461, 70, 7356, 456, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8882965, 240652, 7523, 460, 70, 7338, 455, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8890491, 241114, 7502, 459, 70, 7317, 454, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8897996, 241575, 7502, 459, 70, 7317, 454, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8905501, 242036, 7507, 459, 70, 7322, 454, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8913011, 242497, 7521, 460, 70, 7336, 455, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8920535, 242959, 7523, 460, 70, 7338, 455, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8928061, 243421, 7521, 460, 70, 7336, 455, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8935585, 243883, 7520, 460, 70, 7335, 455, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8943108, 244345, 7522, 460, 70, 7337, 455, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8950633, 244807, 7521, 460, 70, 7336, 455, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8958157, 245269, 7526, 460, 70, 7341, 455, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8965686, 245731, 7524, 460, 70, 7339, 455, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8973213, 246193, 7519, 460, 70, 7334, 455, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8980735, 246655, 7519, 460, 70, 7334, 455, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],
Cell[8988281, 247119, 347, 7, 61, "Text"],
Cell[8988631, 247128, 250, 7, 34, "Text"],
Cell[8988884, 247137, 157, 3, 44, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8989090, 247146, 76, 1, 31, "Section",
  CellTags->"c:21"],
Cell[8989169, 247149, 111, 3, 27, "Text"],
Cell[8989283, 247154, 280, 7, 67, "Text"],
Cell[8989566, 247163, 1360, 46, 85, "Text",
  CellTags->"i:40"],
Cell[8990929, 247211, 281, 7, 70, "Text"],
Cell[8991213, 247220, 261, 9, 44, "Text"],
Cell[8991477, 247231, 277, 5, 46, "NumberedEquation",
  CellTags->"(3.1.74)"],
Cell[8991757, 247238, 177, 6, 27, "Text"],
Cell[8991937, 247246, 293, 9, 33, "NumberedEquation",
  CellTags->"(3.1.75)"],
Cell[8992233, 247257, 1344, 43, 99, "Text"],

Cell[CellGroupData[{
Cell[8993602, 247304, 193, 4, 67, "Input",
  CellTags->"Cell 3.14"],
Cell[8993798, 247310, 35909, 759, 233, 6040, 386, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[9029722, 248072, 741, 24, 61, "Text"],

Cell[CellGroupData[{
Cell[9030488, 248100, 291, 7, 105, "Input",
  CellTags->"Cell 3.15"],
Cell[9030782, 248109, 229, 4, 64, "Output"]
}, Open  ]],
Cell[9031026, 248116, 641, 23, 47, "Text",
  CellTags->"i:38"],

Cell[CellGroupData[{
Cell[9031692, 248143, 930, 19, 306, "Input",
  CellTags->"Cell 3.16"],

Cell[CellGroupData[{
Cell[9032647, 248166, 103805, 2647, 414, 26511, 1689, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9136455, 250815, 26931, 1697, 70, 26524, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9163389, 252514, 26924, 1697, 70, 26517, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9190316, 254213, 26940, 1697, 70, 26533, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9217259, 255912, 26914, 1697, 70, 26507, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9244176, 257611, 26942, 1697, 70, 26535, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9271121, 259310, 26910, 1697, 70, 26503, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9298034, 261009, 26869, 1697, 70, 26462, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9324906, 262708, 26941, 1697, 70, 26534, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9351850, 264407, 26925, 1697, 70, 26518, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9378778, 266106, 26945, 1697, 70, 26538, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9405726, 267805, 26924, 1697, 70, 26517, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9432653, 269504, 26948, 1697, 70, 26541, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9459604, 271203, 26955, 1697, 70, 26548, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9486562, 272902, 26931, 1697, 70, 26524, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9513496, 274601, 26946, 1697, 70, 26539, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9540445, 276300, 26923, 1697, 70, 26516, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9567371, 277999, 26943, 1697, 70, 26536, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9594317, 279698, 26947, 1697, 70, 26540, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9621267, 281397, 26874, 1697, 70, 26467, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[9648144, 283096, 26896, 1697, 70, 26489, 1689, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],
Cell[9675067, 284797, 447, 7, 78, "Text"],
Cell[9675517, 284806, 142, 3, 27, "Text"],
Cell[9675662, 284811, 273, 8, 38, "NumberedEquation",
  CellTags->{"i:42", "(3.1.76)"}],
Cell[9675938, 284821, 789, 26, 61, "Text"],
Cell[9676730, 284849, 107, 3, 27, "Text"],
Cell[9676840, 284854, 281, 10, 32, "Text",
  CellTags->"i:41"],
Cell[9677124, 284866, 47, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[9677196, 284870, 187, 5, 86, "Input",
  CellTags->"Cell 3.17"],
Cell[9677386, 284877, 701, 13, 120, "Output"]
}, Open  ]],
Cell[9678102, 284893, 192, 4, 44, "Text"],
Cell[9678297, 284899, 412, 14, 44, "Text"],
Cell[9678712, 284915, 168, 6, 27, "Text"],
Cell[9678883, 284923, 333, 14, 27, "Text"],
Cell[9679219, 284939, 302, 8, 36, "Text"],
Cell[9679524, 284949, 601, 16, 49, "Text"],
Cell[9680128, 284967, 310, 8, 34, "NumberedEquation",
  CellTags->"(3.1.77)"],
Cell[9680441, 284977, 590, 22, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9681068, 285004, 46, 1, 31, "Section",
  CellTags->"c:22"],
Cell[9681117, 285007, 516, 8, 70, "Text"],
Cell[9681636, 285017, 397, 7, 70, "Text"],
Cell[9682036, 285026, 362, 9, 70, "Text"],
Cell[9682401, 285037, 685, 17, 70, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9683135, 285060, 65, 1, 29, "Subsubtitle",
  CellTags->"c:23"],
Cell[9683203, 285063, 768, 27, 61, "Text",
  CellTags->"i:47"],
Cell[9683974, 285092, 1242, 38, 82, "Text",
  CellTags->"i:46"],
Cell[9685219, 285132, 1546, 35, 163, "Text",
  CellTags->"i:45"],
Cell[9686768, 285169, 1140558, 15318, 370, 692064, 9775, "GraphicsData", \
"PostScript", "Picture"],
Cell[10827329, 300489, 139, 4, 16, "Caption",
  CellTags->"Fig. 3.6"],
Cell[10827471, 300495, 403, 13, 44, "Text"],
Cell[10827877, 300510, 124, 5, 27, "Text"],
Cell[10828004, 300517, 2782, 67, 230, "Text"],
Cell[10830789, 300586, 1394, 38, 129, "Text"],
Cell[10832186, 300626, 559, 18, 61, "Text"],
Cell[10832748, 300646, 202, 7, 43, "Text"],
Cell[10832953, 300655, 1486, 43, 85, "Text"],
Cell[10834442, 300700, 258, 6, 44, "Text"],
Cell[10834703, 300708, 1350, 40, 95, "Text",
  CellTags->"i:48"],
Cell[10836056, 300750, 87353, 1082, 192, 87231, 1078, "GraphicsData", \
"Bitmap", "Picture",
  Evaluatable->False],
Cell[10923412, 301834, 120, 4, 16, "Caption",
  CellTags->"Fig. 3.7"],
Cell[10923535, 301840, 215, 5, 44, "Text"],
Cell[10923753, 301847, 131, 5, 27, "Text"],
Cell[10923887, 301854, 1082, 31, 78, "Text"],
Cell[10924972, 301887, 549, 18, 36, "Text"],
Cell[10925524, 301907, 380, 9, 58, "Text"],
Cell[10925907, 301918, 196, 6, 42, "NumberedEquation",
  CellTags->"(3.1.78)"],
Cell[10926106, 301926, 140, 6, 27, "Text",
  CellTags->"i:50"],
Cell[10926249, 301934, 115, 2, 31, "NumberedEquation",
  CellTags->"(3.1.79)"],
Cell[10926367, 301938, 407, 10, 61, "Text",
  CellTags->"i:97"],
Cell[10926777, 301950, 799, 28, 61, "Text",
  CellTags->"i:98"],
Cell[10927579, 301980, 187, 7, 27, "Text"],
Cell[10927769, 301989, 246, 10, 27, "Text"],
Cell[10928018, 302001, 1068, 35, 66, "Text"],
Cell[10929089, 302038, 536, 17, 61, "Text"],
Cell[10929628, 302057, 202, 5, 44, "Text"],
Cell[10929833, 302064, 581, 19, 40, "Text"],
Cell[10930417, 302085, 163, 5, 27, "Text"],
Cell[10930583, 302092, 724, 25, 36, "Text"],
Cell[10931310, 302119, 729, 25, 36, "Text"],
Cell[10932042, 302146, 1142, 36, 78, "Text",
  CellTags->"i:51"],
Cell[10933187, 302184, 1043, 32, 43, "NumberedEquation",
  CellTags->"(3.1.80)"],
Cell[10934233, 302218, 768, 27, 61, "Text"],
Cell[10935004, 302247, 1048, 36, 61, "Text",
  CellTags->"i:52"],
Cell[10936055, 302285, 583, 18, 44, "Text",
  CellTags->"i:96"],
Cell[10936641, 302305, 356, 9, 41, "Text"],
Cell[10937000, 302316, 617, 18, 89, "Text"],
Cell[10937620, 302336, 1421, 45, 95, "Text"],
Cell[10939044, 302383, 1587, 44, 140, "Text"],
Cell[10940634, 302429, 259, 8, 27, "Text"],
Cell[10940896, 302439, 1496, 46, 41, "Text"],
Cell[10942395, 302487, 581, 12, 78, "Text"],
Cell[10942979, 302501, 732, 24, 70, "Text"],
Cell[10943714, 302527, 494, 17, 44, "Text",
  CellTags->"i:53"],
Cell[10944211, 302546, 226, 7, 38, "NumberedEquation",
  CellTags->"(3.1.81)"],
Cell[10944440, 302555, 260, 9, 31, "Text",
  CellTags->"i:111"],
Cell[10944703, 302566, 195, 6, 42, "NumberedEquation",
  CellTags->"(3.1.82)"],
Cell[10944901, 302574, 1586, 50, 88, "Text"],
Cell[10946490, 302626, 456, 14, 45, "Text"],
Cell[10946949, 302642, 224, 10, 27, "Text"],
Cell[10947176, 302654, 203, 8, 36, "Text"],
Cell[10947382, 302664, 415, 12, 36, "Text"],
Cell[10947800, 302678, 1141, 29, 98, "Text"],
Cell[10948944, 302709, 317, 8, 44, "Text"],
Cell[10949264, 302719, 393, 12, 40, "Text"],
Cell[10949660, 302733, 68, 0, 27, "Text"],
Cell[10949731, 302735, 305, 13, 27, "Text"],
Cell[10950039, 302750, 363, 16, 27, "Text"],
Cell[10950405, 302768, 260, 10, 27, "Text"],
Cell[10950668, 302780, 1072, 33, 65, "Text"],
Cell[10951743, 302815, 574, 18, 61, "Text"],
Cell[10952320, 302835, 1258, 38, 99, "Text"],
Cell[10953581, 302875, 1820, 52, 122, "Text",
  CellTags->"i:55"],
Cell[10955404, 302929, 391, 14, 45, "Text"],
Cell[10955798, 302945, 494, 17, 44, "Text"],
Cell[10956295, 302964, 1070, 27, 31, "Text"],
Cell[10957368, 302993, 1106, 35, 65, "Text",
  CellTags->"i:56"],
Cell[10958477, 303030, 890, 27, 83, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10959416, 303063, 91, 1, 38, "Subtitle",
  CellTags->"c:24"],
Cell[10959510, 303066, 17, 0, 27, "Text"],
Cell[10959530, 303068, 357, 10, 44, "Text",
  CellTags->"i:112"],
Cell[10959890, 303080, 316, 11, 32, "NE2",
  CellTags->"(3.2.1)"],
Cell[10960209, 303093, 351, 12, 30, "Text"],
Cell[10960563, 303107, 225, 6, 45, "NE2",
  CellTags->"(3.2.2)"],
Cell[10960791, 303115, 970, 32, 61, "Text",
  CellTags->"i:57"],
Cell[10961764, 303149, 766, 28, 27, "Text",
  CellTags->"i:58"],
Cell[10962533, 303179, 1418, 47, 48, "Text",
  CellTags->"i:59"],
Cell[10963954, 303228, 2013, 68, 46, "Text",
  CellTags->"i:60"],
Cell[10965970, 303298, 870, 17, 112, "Text"],
Cell[10966843, 303317, 180284, 2229, 223, 180162, 2225, "GraphicsData", \
"Bitmap", "Picture",
  Evaluatable->False],
Cell[11147130, 305548, 258, 9, 16, "Caption",
  CellTags->"Fig. 3.8"],

Cell[CellGroupData[{
Cell[11147413, 305561, 89, 1, 40, "Subsubtitle",
  CellTags->"c:26"],
Cell[11147505, 305564, 144, 3, 44, "Text"],
Cell[11147652, 305569, 317, 6, 61, "Text",
  CellTags->"i:61"],
Cell[11147972, 305577, 393, 12, 61, "Text"],
Cell[11148368, 305591, 689, 18, 67, "Text"],
Cell[11149060, 305611, 812, 21, 32, "Text"],
Cell[11149875, 305634, 1430, 39, 102, "Text"],
Cell[11151308, 305675, 1751, 54, 63, "Text"],
Cell[11153062, 305731, 1320, 36, 91, "Text"],
Cell[11154385, 305769, 475, 12, 61, "Text"],
Cell[11154863, 305783, 629, 16, 61, "Text",
  CellTags->"i:62"],
Cell[11155495, 305801, 519, 16, 34, "NE2",
  CellTags->"(3.2.3)"],
Cell[11156017, 305819, 798, 21, 49, "Text"],
Cell[11156818, 305842, 595, 16, 61, "Text",
  CellTags->"i:63"],
Cell[11157416, 305860, 835, 24, 63, "Text"],
Cell[11158254, 305886, 178, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11158469, 305895, 69, 1, 29, "Subsubtitle",
  CellTags->"c:27"],

Cell[CellGroupData[{
Cell[11158563, 305900, 65, 1, 42, "Section",
  CellTags->{"i:64", "c:28"}],
Cell[11158631, 305903, 346, 10, 44, "Text",
  CellTags->"i:76"],
Cell[11158980, 305915, 119, 2, 27, "NE2",
  CellTags->"(3.2.4)"],
Cell[11159102, 305919, 344, 12, 44, "Text"],
Cell[11159449, 305933, 236, 7, 43, "Text"],
Cell[11159688, 305942, 226, 8, 27, "Text"],
Cell[11159917, 305952, 291, 6, 83, "NE2",
  CellTags->"(3.2.5)"],
Cell[11160211, 305960, 184, 6, 27, "Text"],
Cell[11160398, 305968, 405, 7, 65, "NE2",
  CellTags->"(3.2.6)"]
}, Closed]],

Cell[CellGroupData[{
Cell[11160840, 305980, 79, 1, 31, "Section",
  CellTags->"c:29"],
Cell[11160922, 305983, 321, 11, 44, "Text"],
Cell[11161246, 305996, 69101, 857, 230, 68982, 853, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[11230350, 306855, 51, 1, 16, "Caption",
  CellTags->"Fig. 3.9"],
Cell[11230404, 306858, 413, 15, 27, "Text"],
Cell[11230820, 306875, 1120, 36, 86, "Text",
  CellTags->"i:104"],
Cell[11231943, 306913, 143, 6, 29, "NE2",
  CellTags->"(3.2.7)"],
Cell[11232089, 306921, 22, 0, 27, "Text"],
Cell[11232114, 306923, 225, 8, 32, "NE2",
  CellTags->"(3.2.8)"],
Cell[11232342, 306933, 143, 3, 44, "Text"],
Cell[11232488, 306938, 303, 8, 38, "NE2",
  CellTags->"(3.2.9)"],
Cell[11232794, 306948, 287, 11, 27, "Text"],
Cell[11233084, 306961, 1290, 38, 103, "Text"],
Cell[11234377, 307001, 583, 19, 44, "Text"],
Cell[11234963, 307022, 206, 4, 28, "NE2",
  CellTags->"(3.2.10)"],
Cell[11235172, 307028, 448, 15, 27, "Text"],
Cell[11235623, 307045, 243, 7, 30, "NE2",
  CellTags->"(3.2.11)"],
Cell[11235869, 307054, 564, 19, 44, "Text"],
Cell[11236436, 307075, 257, 4, 38, "NE2",
  CellTags->"(3.2.12)"],
Cell[11236696, 307081, 690, 20, 69, "Text"],
Cell[11237389, 307103, 205, 7, 38, "Text"],
Cell[11237597, 307112, 295, 12, 27, "Text"],

Cell[CellGroupData[{
Cell[11237917, 307128, 495, 11, 177, "Input",
  CellTags->"Cell 3.18"],
Cell[11238415, 307141, 232790, 4234, 302, 77030, 2307, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[11471220, 311378, 184, 5, 27, "Text"],
Cell[11471407, 311385, 1124, 28, 112, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11472568, 311418, 133, 4, 31, "Section",
  CellTags->"c:30"],
Cell[11472704, 311424, 1073, 29, 70, "Text"],
Cell[11473780, 311455, 1748, 59, 70, "Text",
  CellTags->"i:77"],
Cell[11475531, 311516, 121175, 1499, 70, 121052, 1495, "GraphicsData", \
"Bitmap", "Picture",
  Evaluatable->False],
Cell[11596709, 313017, 79, 1, 70, "Caption",
  CellTags->"Fig. 3.10"],
Cell[11596791, 313020, 127, 3, 70, "Text"],
Cell[11596921, 313025, 185, 8, 70, "Text"],
Cell[11597109, 313035, 451, 8, 70, "Text"],
Cell[11597563, 313045, 211, 4, 70, "NE2",
  CellTags->"(3.2.13)"],
Cell[11597777, 313051, 753, 21, 70, "Text"],
Cell[11598533, 313074, 756, 25, 70, "Text"],
Cell[11599292, 313101, 1043, 30, 70, "Text"],
Cell[11600338, 313133, 172, 6, 70, "Text"],
Cell[11600513, 313141, 661, 23, 70, "Text"],
Cell[11601177, 313166, 294, 10, 70, "NE2",
  CellTags->"(3.2.14)"],
Cell[11601474, 313178, 660, 18, 70, "Text"],
Cell[11602137, 313198, 233, 6, 70, "Text"],
Cell[11602373, 313206, 640, 17, 70, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[11603062, 313229, 72, 1, 29, "Subsubtitle",
  CellTags->"c:31"],

Cell[CellGroupData[{
Cell[11603159, 313234, 72, 1, 42, "Section",
  CellTags->{"i:65", "c:32"}],
Cell[11603234, 313237, 970, 28, 78, "Text",
  CellTags->"i:75"],
Cell[11604207, 313267, 179, 6, 29, "NE2",
  CellTags->"(3.2.15)"],
Cell[11604389, 313275, 134, 5, 30, "Text"],
Cell[11604526, 313282, 305, 7, 43, "NE2",
  CellTags->{"i:109", "(3.2.16)"}],
Cell[11604834, 313291, 317, 12, 30, "Text"],
Cell[11605154, 313305, 311, 5, 44, "NE2",
  CellTags->"(3.2.17)"],
Cell[11605468, 313312, 713, 23, 59, "Text"],
Cell[11606184, 313337, 243, 7, 41, "NE2",
  CellTags->"(3.2.18)"],
Cell[11606430, 313346, 508, 15, 47, "Text"],
Cell[11606941, 313363, 205, 7, 42, "NE2",
  CellTags->"(3.2.19)"],
Cell[11607149, 313372, 1077, 30, 78, "Text",
  CellTags->"i:105"],
Cell[11608229, 313404, 290, 8, 32, "NE2",
  CellTags->"(3.2.20)"],
Cell[11608522, 313414, 698, 20, 47, "Text"],
Cell[11609223, 313436, 257, 8, 32, "NE2",
  CellTags->"(3.2.21)"],
Cell[11609483, 313446, 285, 10, 27, "Text"],
Cell[11609771, 313458, 265, 9, 30, "Text"],
Cell[11610039, 313469, 226, 6, 42, "NE2",
  CellTags->"(3.2.22)"],
Cell[11610268, 313477, 65, 0, 27, "Text"],
Cell[11610336, 313479, 853, 25, 70, "NE2",
  CellTags->"(3.2.23)"],
Cell[11611192, 313506, 139, 3, 27, "Text"],
Cell[11611334, 313511, 446, 11, 57, "NE2",
  CellTags->"(3.2.24)"]
}, Closed]],

Cell[CellGroupData[{
Cell[11611817, 313527, 46, 1, 31, "Section",
  CellTags->"c:33"],
Cell[11611866, 313530, 372, 10, 44, "Text"],
Cell[11612241, 313542, 150, 3, 27, "NE2",
  CellTags->"(3.2.25)"],
Cell[11612394, 313547, 1061, 37, 61, "Text"],
Cell[11613458, 313586, 263, 6, 43, "Text"],
Cell[11613724, 313594, 236, 7, 27, "Text"],
Cell[11613963, 313603, 308, 8, 38, "NE2",
  CellTags->"(3.2.26)"],
Cell[11614274, 313613, 321, 8, 60, "Text"],
Cell[11614598, 313623, 927, 25, 61, "Text"],
Cell[11615528, 313650, 164, 6, 33, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[11615741, 313662, 67, 1, 29, "Subsubtitle",
  CellTags->"c:34"],

Cell[CellGroupData[{
Cell[11615833, 313667, 72, 1, 42, "Section",
  CellTags->{"i:67", "c:35"}],
Cell[11615908, 313670, 667, 20, 61, "Text",
  CellTags->"i:78"],
Cell[11616578, 313692, 492, 11, 45, "NE2",
  CellTags->{"i:110", "(3.2.27)"}],
Cell[11617073, 313705, 319, 9, 44, "Text"],
Cell[11617395, 313716, 259, 9, 27, "Text"],
Cell[11617657, 313727, 168, 6, 31, "Text"],
Cell[11617828, 313735, 508, 11, 45, "NE2",
  CellTags->"(3.2.28)"],
Cell[11618339, 313748, 43682, 543, 175, 43564, 539, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[11662024, 314293, 171, 6, 16, "Caption",
  CellTags->"Fig. 3.11"],
Cell[11662198, 314301, 431, 16, 44, "Text"],
Cell[11662632, 314319, 191, 3, 45, "NE2",
  CellTags->"(3.2.29)"],
Cell[11662826, 314324, 365, 8, 42, "NE2",
  CellTags->"(3.2.30)"],
Cell[11663194, 314334, 231, 7, 38, "NE2",
  CellTags->"(3.2.31)"],
Cell[11663428, 314343, 515, 16, 44, "Text"],
Cell[11663946, 314361, 256, 9, 32, "NE2",
  CellTags->"(3.2.32)"]
}, Closed]],

Cell[CellGroupData[{
Cell[11664239, 314375, 161, 6, 31, "Section",
  CellTags->"c:36"],
Cell[11664403, 314383, 1111, 33, 58, "Text"],
Cell[11665517, 314418, 295, 5, 42, "NE2",
  CellTags->"(3.2.33)"],
Cell[11665815, 314425, 681, 17, 78, "Text",
  CellTags->"i:69"],
Cell[11666499, 314444, 335, 12, 29, "NE2",
  CellTags->"(3.2.34)"],
Cell[11666837, 314458, 212, 6, 44, "Text",
  CellTags->"i:70"],
Cell[11667052, 314466, 253, 9, 28, "Text"],
Cell[11667308, 314477, 734, 22, 68, "Text"],
Cell[11668045, 314501, 4281, 135, 183, "Text",
  CellTags->"Table 3.2"],
Cell[11672329, 314638, 16, 0, 27, "Text"],
Cell[11672348, 314640, 271, 8, 28, "Text"],
Cell[11672622, 314650, 747, 27, 62, "Text",
  CellTags->"i:83"],

Cell[CellGroupData[{
Cell[11673394, 314681, 420, 10, 143, "Input",
  CellTags->"Cell 3.19"],
Cell[11673817, 314693, 289, 4, 103, "Output"]
}, Open  ]],
Cell[11674121, 314700, 312, 10, 27, "Text"],

Cell[CellGroupData[{
Cell[11674458, 314714, 251, 7, 105, "Input",
  CellTags->"Cell 3.20"],
Cell[11674712, 314723, 70, 1, 51, "Output"]
}, Open  ]],
Cell[11674797, 314727, 21, 0, 27, "Text"],
Cell[11674821, 314729, 123, 5, 31, "Text"],
Cell[11674947, 314736, 167, 8, 27, "Text"],
Cell[11675117, 314746, 361, 10, 44, "Text"],
Cell[11675481, 314758, 464, 10, 40, "NE2",
  CellTags->"(3.2.35)"],
Cell[11675948, 314770, 785, 22, 78, "Text"],
Cell[11676736, 314794, 347, 10, 40, "NE2",
  CellTags->"(3.2.36)"],
Cell[11677086, 314806, 290, 5, 61, "Text"],
Cell[11677379, 314813, 392, 9, 40, "NE2",
  CellTags->{"i:72", "(3.2.37)"}],
Cell[11677774, 314824, 821, 22, 70, "Text"],
Cell[11678598, 314848, 521, 12, 40, "NE2",
  CellTags->"(3.2.38)"],
Cell[11679122, 314862, 180, 8, 27, "Text"],
Cell[11679305, 314872, 627, 18, 62, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11679969, 314895, 110, 2, 31, "Section",
  CellTags->{"i:71", "c:37"}],
Cell[11680082, 314899, 502, 13, 65, "Text"],
Cell[11680587, 314914, 342, 9, 57, "NE2",
  CellTags->"(3.2.39)"],
Cell[11680932, 314925, 710, 23, 61, "Text",
  CellTags->"i:84"],
Cell[11681645, 314950, 541, 15, 36, "NE2",
  CellTags->{"i:73", "(3.2.40)"}],
Cell[11682189, 314967, 630, 13, 78, "Text"],
Cell[11682822, 314982, 611, 17, 61, "Text"],

Cell[CellGroupData[{
Cell[11683458, 315003, 1460, 28, 333, "Input",
  CellTags->"Cell 3.21"],
Cell[11684921, 315033, 245397, 7387, 855, 82572, 5372, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[11930333, 322423, 869, 22, 95, "Text"],
Cell[11931205, 322447, 1285, 43, 78, "Text"],
Cell[11932493, 322492, 174035, 4864, 535, 50187, 3331, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12106531, 327358, 148, 6, 16, "Caption",
  CellTags->"Fig. 3.12"],
Cell[12106682, 327366, 1012, 30, 81, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12107731, 327401, 46, 1, 31, "Section",
  CellTags->"c:38"],
Cell[12107780, 327404, 203, 6, 27, "Text"],
Cell[12107986, 327412, 553, 17, 43, "Text"],
Cell[12108542, 327431, 283, 10, 31, "Text"],
Cell[12108828, 327443, 365, 8, 40, "NE2",
  CellTags->"(3.2.41)"],
Cell[12109196, 327453, 607, 16, 72, "Text"],
Cell[12109806, 327471, 325, 5, 34, "NE2",
  CellTags->"(3.2.42)"],
Cell[12110134, 327478, 298, 7, 44, "Text"],
Cell[12110435, 327487, 268, 7, 33, "Text"],
Cell[12110706, 327496, 436, 12, 44, "Text"],

Cell[CellGroupData[{
Cell[12111167, 327512, 273, 8, 105, "Input",
  CellTags->"Cell 3.22"],
Cell[12111443, 327522, 527, 10, 159, "Output"]
}, Open  ]],
Cell[12111985, 327535, 351, 12, 27, "Text"],
Cell[12112339, 327549, 255, 6, 86, "Input",
  CellTags->"Cell 3.23"],
Cell[12112597, 327557, 315, 12, 27, "Text"],

Cell[CellGroupData[{
Cell[12112937, 327573, 515, 11, 162, "Input",
  CellTags->"Cell 3.24"],
Cell[12113455, 327586, 486690, 17856, 319, 291558, 15442, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[12600160, 345445, 377, 9, 61, "Text",
  CellTags->"i:79"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12600586, 345460, 72, 1, 29, "Subsubtitle",
  CellTags->"c:39"],

Cell[CellGroupData[{
Cell[12600683, 345465, 51, 1, 42, "Section",
  CellTags->"c:40"],
Cell[12600737, 345468, 857, 29, 61, "Text"],
Cell[12601597, 345499, 152, 6, 27, "Text"],
Cell[12601752, 345507, 292, 9, 27, "Text"],
Cell[12602047, 345518, 254, 7, 45, "Text"],
Cell[12602304, 345527, 309, 5, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12602650, 345537, 143, 2, 31, "Section",
  CellTags->{"i:68", "c:41"}],
Cell[12602796, 345541, 1058, 31, 68, "Text",
  CellTags->"i:100"],
Cell[12603857, 345574, 341, 9, 46, "NE2",
  CellTags->"(3.2.43)"],
Cell[12604201, 345585, 151, 5, 27, "Text"],
Cell[12604355, 345592, 150, 5, 43, "NE2",
  CellTags->"(3.2.44)"],
Cell[12604508, 345599, 254, 8, 27, "Text"],
Cell[12604765, 345609, 272, 8, 37, "NE2",
  CellTags->"(3.2.45)"],
Cell[12605040, 345619, 617, 21, 49, "Text"],

Cell[CellGroupData[{
Cell[12605682, 345644, 61, 1, 27, "Subsubsection",
  CellTags->"i:80"],
Cell[12605746, 345647, 123, 5, 27, "Text"],
Cell[12605872, 345654, 245, 7, 42, "NE2",
  CellTags->"(3.2.46)"],
Cell[12606120, 345663, 930, 31, 78, "Text",
  CellTags->"i:106"],
Cell[12607053, 345696, 237, 8, 27, "Text"],
Cell[12607293, 345706, 130, 6, 33, "NE2",
  CellTags->"(3.2.47)"],
Cell[12607426, 345714, 24, 0, 27, "Text"],
Cell[12607453, 345716, 252, 7, 42, "NE2",
  CellTags->"(3.2.48)"],
Cell[12607708, 345725, 642, 22, 44, "Text",
  CellTags->"i:81"],
Cell[12608353, 345749, 169, 6, 29, "NE2",
  CellTags->"(3.2.49)"],
Cell[12608525, 345757, 1526, 58, 63, "Text",
  CellTags->"i:82"],

Cell[CellGroupData[{
Cell[12610076, 345819, 344, 7, 124, "Input",
  CellTags->"Cell 3.25"],
Cell[12610423, 345828, 60846, 1353, 233, 13218, 760, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12671306, 347186, 339, 6, 105, "Input",
  CellTags->"Cell 3.26"],
Cell[12671648, 347194, 51028, 1215, 233, 12771, 738, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[12722691, 348412, 302, 8, 44, "Text"],
Cell[12722996, 348422, 310, 7, 44, "Text"],
Cell[12723309, 348431, 143, 6, 29, "NE2",
  CellTags->"(3.2.50)"]
}, Closed]],

Cell[CellGroupData[{
Cell[12723489, 348442, 92, 2, 29, "Subsubsection",
  CellTags->"i:85"],
Cell[12723584, 348446, 944, 23, 95, "Text"],
Cell[12724531, 348471, 1000, 36, 61, "Text"],
Cell[12725534, 348509, 425, 11, 61, "Text"],
Cell[12725962, 348522, 97, 3, 67, "Input",
  CellTags->"Cell 3.27"],
Cell[12726062, 348527, 189, 6, 27, "Text",
  CellTags->"i:86"],

Cell[CellGroupData[{
Cell[12726276, 348537, 110, 3, 67, "Input",
  CellTags->"Cell 3.28"],
Cell[12726389, 348542, 261, 4, 65, "Output"]
}, Open  ]],
Cell[12726665, 348549, 676, 21, 46, "Text"],

Cell[CellGroupData[{
Cell[12727366, 348574, 98, 3, 67, "Input",
  CellTags->"Cell 3.29"],
Cell[12727467, 348579, 123, 2, 46, "Output"]
}, Open  ]],
Cell[12727605, 348584, 456, 16, 44, "Text",
  CellTags->"i:87"],

Cell[CellGroupData[{
Cell[12728086, 348604, 98, 3, 67, "Input",
  CellTags->"Cell 3.30"],
Cell[12728187, 348609, 170, 3, 46, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[12728406, 348618, 62, 0, 29, "Subsubsection"],
Cell[12728471, 348620, 742, 24, 66, "Text"],
Cell[12729216, 348646, 214, 8, 32, "NE2",
  CellTags->"(3.2.51)"],
Cell[12729433, 348656, 388, 14, 27, "Text"],
Cell[12729824, 348672, 171, 7, 29, "NE2",
  CellTags->"(3.2.52)"],
Cell[12729998, 348681, 231, 9, 27, "Text"],

Cell[CellGroupData[{
Cell[12730254, 348694, 349, 7, 105, "Input",
  CellTags->"Cell 3.31"],
Cell[12730606, 348703, 65630, 1413, 233, 13851, 769, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[12796251, 350119, 200, 6, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12796488, 350130, 119, 4, 29, "Subsubsection"],
Cell[12796610, 350136, 218, 6, 44, "Text"],
Cell[12796831, 350144, 464, 12, 38, "NE2",
  CellTags->"(3.2.53)"],
Cell[12797298, 350158, 670, 23, 61, "Text"],
Cell[12797971, 350183, 514, 12, 36, "Text"],
Cell[12798488, 350197, 604, 17, 64, "Text"],
Cell[12799095, 350216, 586, 15, 38, "NE2",
  CellTags->"(3.2.54)"],
Cell[12799684, 350233, 307, 7, 44, "Text"],
Cell[12799994, 350242, 330, 8, 42, "NE2",
  CellTags->{"i:90", "(3.2.55)"}],
Cell[12800327, 350252, 509, 16, 47, "Text"],

Cell[CellGroupData[{
Cell[12800861, 350272, 269, 7, 108, "Input",
  CellTags->"Cell 3.32"],
Cell[12801133, 350281, 35, 1, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12801205, 350287, 275, 7, 123, "Input",
  CellTags->"Cell 3.33"],
Cell[12801483, 350296, 35, 1, 46, "Output"]
}, Open  ]],
Cell[12801533, 350300, 589, 19, 47, "Text"],
Cell[12802125, 350321, 874, 19, 53, "Text"],
Cell[12803002, 350342, 338, 11, 44, "Text"],
Cell[12803343, 350355, 774, 18, 42, "NE2",
  CellTags->"(3.2.56)"],
Cell[12804120, 350375, 154, 5, 27, "Text"],
Cell[12804277, 350382, 387, 10, 44, "Text",
  CellTags->"i:107"],
Cell[12804667, 350394, 402, 10, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12805106, 350409, 32, 0, 29, "Subsubsection"],
Cell[12805141, 350411, 844, 26, 63, "Text"],
Cell[12805988, 350439, 368, 11, 31, "NE2",
  CellTags->"(3.2.57)"],
Cell[12806359, 350452, 254, 7, 44, "Text"],
Cell[12806616, 350461, 342, 8, 49, "Text"],
Cell[12806961, 350471, 150, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[12807136, 350480, 215, 5, 116, "Input",
  CellTags->"Cell 3.34"],
Cell[12807354, 350487, 90, 1, 80, "Output"]
}, Open  ]],
Cell[12807459, 350491, 375, 13, 44, "Text"],
Cell[12807837, 350506, 186, 5, 86, "Input",
  CellTags->"Cell 3.35"],
Cell[12808026, 350513, 217, 7, 27, "Text"],
Cell[12808246, 350522, 189, 5, 67, "Input",
  CellTags->"Cell 3.36"],
Cell[12808438, 350529, 530, 18, 29, "Text"],

Cell[CellGroupData[{
Cell[12808993, 350551, 371, 8, 124, "Input",
  CellTags->"Cell 3.37"],
Cell[12809367, 350561, 85455, 2288, 488, 23935, 1524, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[12894837, 352852, 334, 7, 61, "Text",
  CellTags->"i:91"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12895220, 352865, 115, 4, 31, "Section",
  CellTags->"c:42"],
Cell[12895338, 352871, 648, 22, 44, "Text"],
Cell[12895989, 352895, 1020, 30, 81, "Text"],
Cell[12897012, 352927, 435, 15, 44, "Text"],
Cell[12897450, 352944, 148, 6, 32, "NE2",
  CellTags->"(3.2.58)"],
Cell[12897601, 352952, 335, 10, 44, "Text"],
Cell[12897939, 352964, 450, 16, 27, "Text"],
Cell[12898392, 352982, 233, 7, 29, "NE2",
  CellTags->"(3.2.59)"],
Cell[12898628, 352991, 402, 15, 44, "Text",
  CellTags->"i:88"],
Cell[12899033, 353008, 578, 19, 59, "NE2",
  CellTags->"(3.2.60)"],
Cell[12899614, 353029, 1140, 42, 73, "Text",
  CellTags->"i:89"],

Cell[CellGroupData[{
Cell[12900779, 353075, 344, 7, 124, "Input",
  CellTags->"Cell 3.38"],
Cell[12901126, 353084, 37671, 847, 233, 8645, 484, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[12938812, 353934, 218, 8, 27, "Text"],

Cell[CellGroupData[{
Cell[12939055, 353946, 308, 6, 105, "Input",
  CellTags->"Cell 3.39"],
Cell[12939366, 353954, 38081, 917, 233, 9804, 563, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[12977462, 354874, 237, 9, 27, "Text"],
Cell[12977702, 354885, 880, 27, 61, "Text"],
Cell[12978585, 354914, 379, 10, 38, "NE2",
  CellTags->"(3.2.61)"],
Cell[12978967, 354926, 251, 8, 27, "Text"],
Cell[12979221, 354936, 417, 11, 36, "Text"],
Cell[12979641, 354949, 303, 10, 44, "Text"],
Cell[12979947, 354961, 460, 11, 36, "Text"],
Cell[12980410, 354974, 186, 4, 44, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12980645, 354984, 65, 1, 29, "Subsubtitle",
  CellTags->"c:43"],
Cell[12980713, 354987, 393, 14, 30, "Text"],
Cell[12981109, 355003, 236, 9, 27, "Text"],
Cell[12981348, 355014, 570, 17, 40, "Text"],
Cell[12981921, 355033, 259, 9, 40, "Text"],
Cell[12982183, 355044, 376, 9, 40, "Text"],
Cell[12982562, 355055, 711, 22, 61, "Text"],
Cell[12983276, 355079, 49145, 610, 172, 49023, 606, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[13032424, 355691, 67, 1, 16, "Caption",
  CellTags->"Fig. 3.13"],
Cell[13032494, 355694, 290, 8, 47, "Text"],
Cell[13032787, 355704, 235, 10, 27, "Text"],
Cell[13033025, 355716, 386, 16, 27, "Text"],
Cell[13033414, 355734, 531, 19, 44, "Text"],
Cell[13033948, 355755, 435, 15, 37, "Text"],
Cell[13034386, 355772, 618, 18, 61, "Text"],
Cell[13035007, 355792, 30236, 377, 207, 30114, 373, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[13065246, 356171, 67, 1, 16, "Caption",
  CellTags->"Fig. 3.14"],
Cell[13065316, 356174, 695, 22, 61, "Text"],
Cell[13066014, 356198, 11026, 140, 89, 10905, 136, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[13077043, 356340, 67, 1, 16, "Caption",
  CellTags->"Fig. 3.15"],
Cell[13077113, 356343, 607, 20, 47, "Text"],
Cell[13077723, 356365, 1665, 51, 129, "Text"],
Cell[13079391, 356418, 268, 8, 30, "Text"],
Cell[13079662, 356428, 197, 8, 30, "Text"],
Cell[13079862, 356438, 219, 8, 30, "Text"],
Cell[13080084, 356448, 226, 8, 36, "Text"],
Cell[13080313, 356458, 627, 19, 61, "Text"],
Cell[13080943, 356479, 32395, 403, 135, 32268, 399, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[13113341, 356884, 67, 1, 16, "Caption",
  CellTags->"Fig. 3.16"],
Cell[13113411, 356887, 1024, 31, 95, "Text"],
Cell[13114438, 356920, 1284, 42, 63, "Text"],
Cell[13115725, 356964, 495, 18, 44, "Text",
  CellTags->"i:93"],
Cell[13116223, 356984, 483, 19, 44, "Text"],
Cell[13116709, 357005, 279, 10, 27, "Text"],
Cell[13116991, 357017, 362, 14, 27, "Text",
  CellTags->"i:94"],
Cell[13117356, 357033, 822, 28, 61, "Text"],
Cell[13118181, 357063, 953, 29, 78, "Text"],
Cell[13119137, 357094, 527, 17, 61, "Text",
  CellTags->"i:92"],
Cell[13119667, 357113, 28987, 361, 99, 28870, 357, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[13148657, 357476, 68, 1, 16, "Caption",
  CellTags->"Fig. 3.17"],
Cell[13148728, 357479, 582, 21, 27, "Text"],
Cell[13149313, 357502, 550, 21, 27, "Text"],
Cell[13149866, 357525, 156, 6, 32, "NE2",
  CellTags->"(3.2.62)"],
Cell[13150025, 357533, 613, 23, 44, "Text"],
Cell[13150641, 357558, 424, 12, 44, "Text"],
Cell[13151068, 357572, 272, 8, 44, "Text"],
Cell[13151343, 357582, 283, 9, 45, "Text"],
Cell[13151629, 357593, 554, 18, 45, "Text"],
Cell[13152186, 357613, 2399, 77, 141, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13154634, 357696, 50, 1, 38, "Subtitle",
  CellTags->"c:44"],
Cell[13154687, 357699, 209, 7, 27, "Text"],
Cell[13154899, 357708, 241, 8, 27, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

